// Copyright 2024 xensik. All rights reserved.
//
// Use of this source code is governed by a GNU GPLv3 license
// that can be found in the LICENSE file.

#include "xsk/arc/engine/t7.hpp"

namespace xsk::arc::t7
{

extern std::array<std::pair<u16, opcode>, code_count> const code_list
{{
    { 0x0000, opcode::OP_Invalid },
    { 0x0001, opcode::OP_Invalid },
    { 0x0002, opcode::OP_Invalid },
    { 0x0003, opcode::OP_Invalid },
    { 0x0004, opcode::OP_Invalid },
    { 0x0005, opcode::OP_Invalid },
    { 0x0006, opcode::OP_Invalid },
    { 0x0007, opcode::OP_Invalid },
    { 0x0008, opcode::OP_EvalLocalVariableCachedDebug },
    { 0x0009, opcode::OP_EvalLocalVariableRefCachedDebug },
    { 0x000A, opcode::OP_Invalid },
    { 0x000B, opcode::OP_Invalid },
    { 0x000C, opcode::OP_ClearParams },
    { 0x000D, opcode::OP_CheckClearParams },
    { 0x000E, opcode::OP_PreScriptCall },
    { 0x000F, opcode::OP_CallBuiltin },
    { 0x0010, opcode::OP_End },
    { 0x0011, opcode::OP_EvalFieldVariableRef },
    { 0x0012, opcode::OP_Invalid },
    { 0x0013, opcode::OP_GetNegByte },
    { 0x0014, opcode::OP_Invalid },
    { 0x0015, opcode::OP_EndSwitch },
    { 0x0016, opcode::OP_Invalid },
    { 0x0017, opcode::OP_Invalid },
    { 0x0018, opcode::OP_ShiftLeft },
    { 0x0019, opcode::OP_ClearArray },
    { 0x001A, opcode::OP_Invalid },
    { 0x001B, opcode::OP_ScriptMethodCall },
    { 0x001C, opcode::OP_GetString },
    { 0x001D, opcode::OP_Invalid },
    { 0x001E, opcode::OP_GetString },
    { 0x001F, opcode::OP_Invalid },
    { 0x0020, opcode::OP_GetLevelObject },
    { 0x0021, opcode::OP_Invalid },
    { 0x0022, opcode::OP_Jump },
    { 0x0023, opcode::OP_GetAnimObject },
    { 0x0024, opcode::OP_SizeOf },
    { 0x0025, opcode::OP_NextArrayKey },
    { 0x0026, opcode::OP_GetAnimObject },
    { 0x0027, opcode::OP_LevelEvalFieldVariable },
    { 0x0028, opcode::OP_GetClasses },
    { 0x0029, opcode::OP_Invalid },
    { 0x002A, opcode::OP_GetZero },
    { 0x002B, opcode::OP_GetLevelObject },
    { 0x002C, opcode::OP_Dec },
    { 0x002D, opcode::OP_GetVector },
    { 0x002E, opcode::OP_ShiftLeft },
    { 0x002F, opcode::OP_Invalid },
    { 0x0030, opcode::OP_New },
    { 0x0031, opcode::OP_GetSelfObject },
    { 0x0032, opcode::OP_Invalid },
    { 0x0033, opcode::OP_GetVector },
    { 0x0034, opcode::OP_Invalid },
    { 0x0035, opcode::OP_ScriptMethodCallPointer },
    { 0x0036, opcode::OP_EvalFieldVariableRef },
    { 0x0037, opcode::OP_Invalid },
    { 0x0038, opcode::OP_Invalid },
    { 0x0039, opcode::OP_GetGameRef },
    { 0x003A, opcode::OP_ScriptFunctionCallPointer },
    { 0x003B, opcode::OP_Invalid },
    { 0x003C, opcode::OP_Jump },
    { 0x003D, opcode::OP_Invalid },
    { 0x003E, opcode::OP_ScriptFunctionCallClass },
    { 0x003F, opcode::OP_CastFieldObject },
    { 0x0040, opcode::OP_Invalid },
    { 0x0041, opcode::OP_GetNegUnsignedShort },
    { 0x0042, opcode::OP_GetWorld },
    { 0x0043, opcode::OP_GetFunction },
    { 0x0044, opcode::OP_Bit_Or },
    { 0x0045, opcode::OP_NotEqual },
    { 0x0046, opcode::OP_Notify },
    { 0x0047, opcode::OP_LessThan },
    { 0x0048, opcode::OP_Invalid },
    { 0x0049, opcode::OP_GreaterThan },
    { 0x004A, opcode::OP_GetFunction },
    { 0x004B, opcode::OP_GetUndefined },
    { 0x004C, opcode::OP_Bit_Or },
    { 0x004D, opcode::OP_Bit_Or },
    { 0x004E, opcode::OP_WaitTill },
    { 0x004F, opcode::OP_EvalArray },
    { 0x0050, opcode::OP_Divide },
    { 0x0051, opcode::OP_Invalid },
    { 0x0052, opcode::OP_Invalid },
    { 0x0053, opcode::OP_VectorConstant },
    { 0x0054, opcode::OP_GetFloat },
    { 0x0055, opcode::OP_Invalid },
    { 0x0056, opcode::OP_Invalid },
    { 0x0057, opcode::OP_EvalLocalVariableCached },
    { 0x0058, opcode::OP_Invalid },
    { 0x0059, opcode::OP_GetNegByte },
    { 0x005A, opcode::OP_VectorConstant },
    { 0x005B, opcode::OP_GetVector },
    { 0x005C, opcode::OP_Invalid },
    { 0x005D, opcode::OP_ShiftRight },
    { 0x005E, opcode::OP_Invalid },
    { 0x005F, opcode::OP_JumpOnTrue },
    { 0x0060, opcode::OP_GetUnsignedShort },
    { 0x0061, opcode::OP_Inc },
    { 0x0062, opcode::OP_WaitTillMatch },
    { 0x0063, opcode::OP_GetUintptr },
    { 0x0064, opcode::OP_DevblockBegin },
    { 0x0065, opcode::OP_Invalid },
    { 0x0066, opcode::OP_VectorScale },
    { 0x0067, opcode::OP_GetUintptr },
    { 0x0068, opcode::OP_EndSwitch },
    { 0x0069, opcode::OP_ShiftRight },
    { 0x006A, opcode::OP_VectorConstant },
    { 0x006B, opcode::OP_Switch },
    { 0x006C, opcode::OP_SuperEqual },
    { 0x006D, opcode::OP_Invalid },
    { 0x006E, opcode::OP_Invalid },
    { 0x006F, opcode::OP_Invalid },
    { 0x0070, opcode::OP_IsDefined },
    { 0x0071, opcode::OP_Invalid },
    { 0x0072, opcode::OP_GetVector },
    { 0x0073, opcode::OP_Invalid },
    { 0x0074, opcode::OP_Invalid },
    { 0x0075, opcode::OP_Bit_And },
    { 0x0076, opcode::OP_ScriptFunctionCall },
    { 0x0077, opcode::OP_ScriptMethodCallPointer },
    { 0x0078, opcode::OP_GetFloat },
    { 0x0079, opcode::OP_EvalArrayRef },
    { 0x007A, opcode::OP_BoolComplement },
    { 0x007B, opcode::OP_Invalid },
    { 0x007C, opcode::OP_Invalid },
    { 0x007D, opcode::OP_Jump },
    { 0x007E, opcode::OP_GetAPIFunction },
    { 0x007F, opcode::OP_Invalid },
    { 0x0080, opcode::OP_Invalid },
    { 0x0081, opcode::OP_Invalid },
    { 0x0082, opcode::OP_CallBuiltinMethod },
    { 0x0083, opcode::OP_GetAPIFunction },
    { 0x0084, opcode::OP_EvalFieldVariable },
    { 0x0085, opcode::OP_Invalid },
    { 0x0086, opcode::OP_GetHash },
    { 0x0087, opcode::OP_Invalid },
    { 0x0088, opcode::OP_Invalid },
    { 0x0089, opcode::OP_GreaterThan },
    { 0x008A, opcode::OP_GetAnimObject },
    { 0x008B, opcode::OP_EndOn },
    { 0x008C, opcode::OP_ClearFieldVariable },
    { 0x008D, opcode::OP_Invalid },
    { 0x008E, opcode::OP_Invalid },
    { 0x008F, opcode::OP_GetLevel },
    { 0x0090, opcode::OP_GreaterThan },
    { 0x0091, opcode::OP_Invalid },
    { 0x0092, opcode::OP_Invalid },
    { 0x0093, opcode::OP_Invalid },
    { 0x0094, opcode::OP_Invalid },
    { 0x0095, opcode::OP_Dec },
    { 0x0096, opcode::OP_JumpOnFalse },
    { 0x0097, opcode::OP_Invalid },
    { 0x0098, opcode::OP_CastBool },
    { 0x0099, opcode::OP_Invalid },
    { 0x009A, opcode::OP_Invalid },
    { 0x009B, opcode::OP_GetWorld },
    { 0x009C, opcode::OP_GetAnimation },
    { 0x009D, opcode::OP_GetClasses },
    { 0x009E, opcode::OP_Switch },
    { 0x009F, opcode::OP_LevelEvalFieldVariable },
    { 0x00A0, opcode::OP_ScriptThreadCallPointer },
    { 0x00A1, opcode::OP_Notify },
    { 0x00A2, opcode::OP_GetWorldObject },
    { 0x00A3, opcode::OP_Return },
    { 0x00A4, opcode::OP_Invalid },
    { 0x00A5, opcode::OP_Invalid },
    { 0x00A6, opcode::OP_GetClassesObject },
    { 0x00A7, opcode::OP_EvalArray },
    { 0x00A8, opcode::OP_ScriptFunctionCallClass },
    { 0x00A9, opcode::OP_CastFieldObject },
    { 0x00AA, opcode::OP_GetVector },
    { 0x00AB, opcode::OP_Bit_Or },
    { 0x00AC, opcode::OP_Invalid },
    { 0x00AD, opcode::OP_Bit_Xor },
    { 0x00AE, opcode::OP_LevelEvalFieldVariable },
    { 0x00AF, opcode::OP_GetHash },
    { 0x00B0, opcode::OP_EvalLocalVariableCached },
    { 0x00B1, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x00B2, opcode::OP_FirstArrayKey },
    { 0x00B3, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x00B4, opcode::OP_GetByte },
    { 0x00B5, opcode::OP_Invalid },
    { 0x00B6, opcode::OP_ScriptThreadCallPointer },
    { 0x00B7, opcode::OP_Vector },
    { 0x00B8, opcode::OP_Invalid },
    { 0x00B9, opcode::OP_Invalid },
    { 0x00BA, opcode::OP_Invalid },
    { 0x00BB, opcode::OP_EvalFieldVariableRef },
    { 0x00BC, opcode::OP_Switch },
    { 0x00BD, opcode::OP_Invalid },
    { 0x00BE, opcode::OP_Modulus },
    { 0x00BF, opcode::OP_Vector },
    { 0x00C0, opcode::OP_JumpOnFalseExpr },
    { 0x00C1, opcode::OP_EvalLocalVariableRefCached },
    { 0x00C2, opcode::OP_LessThan },
    { 0x00C3, opcode::OP_Invalid },
    { 0x00C4, opcode::OP_JumpOnFalseExpr },
    { 0x00C5, opcode::OP_Invalid },
    { 0x00C6, opcode::OP_ScriptMethodCall },
    { 0x00C7, opcode::OP_Modulus },
    { 0x00C8, opcode::OP_EvalLocalVariableCached },
    { 0x00C9, opcode::OP_GetIString },
    { 0x00CA, opcode::OP_EndSwitch },
    { 0x00CB, opcode::OP_Invalid },
    { 0x00CC, opcode::OP_SelfEvalFieldVariable },
    { 0x00CD, opcode::OP_Invalid },
    { 0x00CE, opcode::OP_ScriptFunctionCall },
    { 0x00CF, opcode::OP_Invalid },
    { 0x00D0, opcode::OP_GetClassesObject },
    { 0x00D1, opcode::OP_Invalid },
    { 0x00D2, opcode::OP_ScriptMethodCallPointer },
    { 0x00D3, opcode::OP_Invalid },
    { 0x00D4, opcode::OP_EvalLocalVariableCached },
    { 0x00D5, opcode::OP_RealWait },
    { 0x00D6, opcode::OP_Invalid },
    { 0x00D7, opcode::OP_GetIString },
    { 0x00D8, opcode::OP_ScriptMethodCall },
    { 0x00D9, opcode::OP_Multiply },
    { 0x00DA, opcode::OP_GetFloat },
    { 0x00DB, opcode::OP_GetGameRef },
    { 0x00DC, opcode::OP_SuperNotEqual },
    { 0x00DD, opcode::OP_Minus },
    { 0x00DE, opcode::OP_Invalid },
    { 0x00DF, opcode::OP_GetClasses },
    { 0x00E0, opcode::OP_SelfEvalFieldVariable },
    { 0x00E1, opcode::OP_Invalid },
    { 0x00E2, opcode::OP_Invalid },
    { 0x00E3, opcode::OP_EvalFieldVariableRef },
    { 0x00E4, opcode::OP_LessThan },
    { 0x00E5, opcode::OP_GetWorldObject },
    { 0x00E6, opcode::OP_Invalid },
    { 0x00E7, opcode::OP_Invalid },
    { 0x00E8, opcode::OP_Invalid },
    { 0x00E9, opcode::OP_GetByte },
    { 0x00EA, opcode::OP_ProfileStart },
    { 0x00EB, opcode::OP_GetAnimObject },
    { 0x00EC, opcode::OP_ClearArray },
    { 0x00ED, opcode::OP_JumpOnFalseExpr },
    { 0x00EE, opcode::OP_Invalid },
    { 0x00EF, opcode::OP_GetWorld },
    { 0x00F0, opcode::OP_WaitTillFrameEnd },
    { 0x00F1, opcode::OP_GetAPIFunction },
    { 0x00F2, opcode::OP_JumpOnTrueExpr },
    { 0x00F3, opcode::OP_Invalid },
    { 0x00F4, opcode::OP_GetUnsignedShort },
    { 0x00F5, opcode::OP_WaitTillMatch },
    { 0x00F6, opcode::OP_LessThanOrEqualTo },
    { 0x00F7, opcode::OP_GetAnim },
    { 0x00F8, opcode::OP_Invalid },
    { 0x00F9, opcode::OP_Invalid },
    { 0x00FA, opcode::OP_Invalid },
    { 0x00FB, opcode::OP_CastBool },
    { 0x00FC, opcode::OP_Dec },
    { 0x00FD, opcode::OP_Invalid },
    { 0x00FE, opcode::OP_EmptyArray },
    { 0x00FF, opcode::OP_GetSelfObject },
    { 0x0100, opcode::OP_GetInteger },
    { 0x0101, opcode::OP_Invalid },
    { 0x0102, opcode::OP_GetSelfObject },
    { 0x0103, opcode::OP_VectorScale },
    { 0x0104, opcode::OP_Wait },
    { 0x0105, opcode::OP_BoolNot },
    { 0x0106, opcode::OP_NextArrayKey },
    { 0x0107, opcode::OP_ShiftLeft },
    { 0x0108, opcode::OP_GetHash },
    { 0x0109, opcode::OP_SelfEvalFieldVariableRef },
    { 0x010A, opcode::OP_Invalid },
    { 0x010B, opcode::OP_EvalArrayRef },
    { 0x010C, opcode::OP_GetGameRef },
    { 0x010D, opcode::OP_GetWorldObject },
    { 0x010E, opcode::OP_VectorConstant },
    { 0x010F, opcode::OP_Invalid },
    { 0x0110, opcode::OP_SetVariableField },
    { 0x0111, opcode::OP_IsDefined },
    { 0x0112, opcode::OP_DecTop },
    { 0x0113, opcode::OP_Invalid },
    { 0x0114, opcode::OP_Invalid },
    { 0x0115, opcode::OP_GetFunction },
    { 0x0116, opcode::OP_EvalLocalVariableCached },
    { 0x0117, opcode::OP_GetTime },
    { 0x0118, opcode::OP_SafeSetVariableFieldCached },
    { 0x0119, opcode::OP_Invalid },
    { 0x011A, opcode::OP_ScriptThreadCallPointer },
    { 0x011B, opcode::OP_RealWait },
    { 0x011C, opcode::OP_EvalFieldVariableRef },
    { 0x011D, opcode::OP_GetNegUnsignedShort },
    { 0x011E, opcode::OP_Invalid },
    { 0x011F, opcode::OP_Invalid },
    { 0x0120, opcode::OP_Invalid },
    { 0x0121, opcode::OP_Invalid },
    { 0x0122, opcode::OP_GetLevelObject },
    { 0x0123, opcode::OP_GetIString },
    { 0x0124, opcode::OP_Switch },
    { 0x0125, opcode::OP_ShiftRight },
    { 0x0126, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x0127, opcode::OP_Invalid },
    { 0x0128, opcode::OP_EndSwitch },
    { 0x0129, opcode::OP_Invalid },
    { 0x012A, opcode::OP_Invalid },
    { 0x012B, opcode::OP_LevelEvalFieldVariable },
    { 0x012C, opcode::OP_ClearFieldVariable },
    { 0x012D, opcode::OP_Invalid },
    { 0x012E, opcode::OP_GetString },
    { 0x012F, opcode::OP_GetString },
    { 0x0130, opcode::OP_Invalid },
    { 0x0131, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x0132, opcode::OP_BoolNot },
    { 0x0133, opcode::OP_GetNegUnsignedShort },
    { 0x0134, opcode::OP_Invalid },
    { 0x0135, opcode::OP_Invalid },
    { 0x0136, opcode::OP_GetAnim },
    { 0x0137, opcode::OP_Wait },
    { 0x0138, opcode::OP_Invalid },
    { 0x0139, opcode::OP_Invalid },
    { 0x013A, opcode::OP_EvalFieldVariableRef },
    { 0x013B, opcode::OP_Modulus },
    { 0x013C, opcode::OP_Invalid },
    { 0x013D, opcode::OP_GetWorldObject },
    { 0x013E, opcode::OP_GetWorld },
    { 0x013F, opcode::OP_GetGame },
    { 0x0140, opcode::OP_Jump },
    { 0x0141, opcode::OP_LevelEvalFieldVariable },
    { 0x0142, opcode::OP_Invalid },
    { 0x0143, opcode::OP_Bit_Or },
    { 0x0144, opcode::OP_SelfEvalFieldVariableRef },
    { 0x0145, opcode::OP_BoolComplement },
    { 0x0146, opcode::OP_GetSelf },
    { 0x0147, opcode::OP_ScriptFunctionCallClass },
    { 0x0148, opcode::OP_Invalid },
    { 0x0149, opcode::OP_Equal },
    { 0x014A, opcode::OP_Inc },
    { 0x014B, opcode::OP_Jump },
    { 0x014C, opcode::OP_CastBool },
    { 0x014D, opcode::OP_Invalid },
    { 0x014E, opcode::OP_GetWorld },
    { 0x014F, opcode::OP_ScriptThreadCallPointer },
    { 0x0150, opcode::OP_GetFloat },
    { 0x0151, opcode::OP_Invalid },
    { 0x0152, opcode::OP_BoolComplement },
    { 0x0153, opcode::OP_GetLevelObject },
    { 0x0154, opcode::OP_Invalid },
    { 0x0155, opcode::OP_GetAnim },
    { 0x0156, opcode::OP_GetSelf },
    { 0x0157, opcode::OP_Vector },
    { 0x0158, opcode::OP_Modulus },
    { 0x0159, opcode::OP_Invalid },
    { 0x015A, opcode::OP_GetZero },
    { 0x015B, opcode::OP_DecTop },
    { 0x015C, opcode::OP_Invalid },
    { 0x015D, opcode::OP_Invalid },
    { 0x015E, opcode::OP_SuperNotEqual },
    { 0x015F, opcode::OP_JumpOnFalse },
    { 0x0160, opcode::OP_Invalid },
    { 0x0161, opcode::OP_ProfileStart },
    { 0x0162, opcode::OP_Wait },
    { 0x0163, opcode::OP_IsDefined },
    { 0x0164, opcode::OP_GetAnimObject },
    { 0x0165, opcode::OP_Invalid },
    { 0x0166, opcode::OP_GetAnim },
    { 0x0167, opcode::OP_GreaterThan },
    { 0x0168, opcode::OP_Invalid },
    { 0x0169, opcode::OP_Invalid },
    { 0x016A, opcode::OP_GetClassesObject },
    { 0x016B, opcode::OP_JumpOnFalseExpr },
    { 0x016C, opcode::OP_IsDefined },
    { 0x016D, opcode::OP_GetFloat },
    { 0x016E, opcode::OP_GetAnim },
    { 0x016F, opcode::OP_Invalid },
    { 0x0170, opcode::OP_GetNegByte },
    { 0x0171, opcode::OP_Invalid },
    { 0x0172, opcode::OP_GetInteger },
    { 0x0173, opcode::OP_GetAnimation },
    { 0x0174, opcode::OP_JumpOnTrue },
    { 0x0175, opcode::OP_Invalid },
    { 0x0176, opcode::OP_BoolNot },
    { 0x0177, opcode::OP_Invalid },
    { 0x0178, opcode::OP_BoolNot },
    { 0x0179, opcode::OP_GetUndefined },
    { 0x017A, opcode::OP_JumpOnFalse },
    { 0x017B, opcode::OP_Invalid },
    { 0x017C, opcode::OP_Invalid },
    { 0x017D, opcode::OP_Invalid },
    { 0x017E, opcode::OP_Invalid },
    { 0x017F, opcode::OP_VectorConstant },
    { 0x0180, opcode::OP_GetSelf },
    { 0x0181, opcode::OP_Invalid },
    { 0x0182, opcode::OP_GetSelfObject },
    { 0x0183, opcode::OP_Invalid },
    { 0x0184, opcode::OP_Invalid },
    { 0x0185, opcode::OP_EmptyArray },
    { 0x0186, opcode::OP_Invalid },
    { 0x0187, opcode::OP_Invalid },
    { 0x0188, opcode::OP_ScriptMethodCallPointer },
    { 0x0189, opcode::OP_Invalid },
    { 0x018A, opcode::OP_EndOn },
    { 0x018B, opcode::OP_Invalid },
    { 0x018C, opcode::OP_Invalid },
    { 0x018D, opcode::OP_Invalid },
    { 0x018E, opcode::OP_SuperNotEqual },
    { 0x018F, opcode::OP_LevelEvalFieldVariable },
    { 0x0190, opcode::OP_GetNegByte },
    { 0x0191, opcode::OP_Plus },
    { 0x0192, opcode::OP_SuperEqual },
    { 0x0193, opcode::OP_EmptyArray },
    { 0x0194, opcode::OP_EvalLocalVariableRefCached },
    { 0x0195, opcode::OP_GetNegByte },
    { 0x0196, opcode::OP_SuperNotEqual },
    { 0x0197, opcode::OP_IsDefined },
    { 0x0198, opcode::OP_GetUnsignedShort },
    { 0x0199, opcode::OP_EmptyArray },
    { 0x019A, opcode::OP_GetAPIFunction },
    { 0x019B, opcode::OP_ClearArray },
    { 0x019C, opcode::OP_Invalid },
    { 0x019D, opcode::OP_JumpOnTrue },
    { 0x019E, opcode::OP_Invalid },
    { 0x019F, opcode::OP_CastFieldObject },
    { 0x01A0, opcode::OP_Invalid },
    { 0x01A1, opcode::OP_Invalid },
    { 0x01A2, opcode::OP_GetInteger },
    { 0x01A3, opcode::OP_Bit_Or },
    { 0x01A4, opcode::OP_LessThan },
    { 0x01A5, opcode::OP_JumpOnFalseExpr },
    { 0x01A6, opcode::OP_NextArrayKey },
    { 0x01A7, opcode::OP_Dec },
    { 0x01A8, opcode::OP_RealWait },
    { 0x01A9, opcode::OP_GetUnsignedShort },
    { 0x01AA, opcode::OP_SuperNotEqual },
    { 0x01AB, opcode::OP_EvalLocalVariableRefCached },
    { 0x01AC, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x01AD, opcode::OP_Invalid },
    { 0x01AE, opcode::OP_GetLevel },
    { 0x01AF, opcode::OP_GetInteger },
    { 0x01B0, opcode::OP_GetWorld },
    { 0x01B1, opcode::OP_Invalid },
    { 0x01B2, opcode::OP_GetSelf },
    { 0x01B3, opcode::OP_Invalid },
    { 0x01B4, opcode::OP_Invalid },
    { 0x01B5, opcode::OP_GetHash },
    { 0x01B6, opcode::OP_GreaterThanOrEqualTo },
    { 0x01B7, opcode::OP_Minus },
    { 0x01B8, opcode::OP_Invalid },
    { 0x01B9, opcode::OP_Invalid },
    { 0x01BA, opcode::OP_Divide },
    { 0x01BB, opcode::OP_ClearArray },
    { 0x01BC, opcode::OP_Invalid },
    { 0x01BD, opcode::OP_Invalid },
    { 0x01BE, opcode::OP_Invalid },
    { 0x01BF, opcode::OP_LessThanOrEqualTo },
    { 0x01C0, opcode::OP_Switch },
    { 0x01C1, opcode::OP_Invalid },
    { 0x01C2, opcode::OP_Invalid },
    { 0x01C3, opcode::OP_Invalid },
    { 0x01C4, opcode::OP_GetFloat },
    { 0x01C5, opcode::OP_ScriptFunctionCall },
    { 0x01C6, opcode::OP_Invalid },
    { 0x01C7, opcode::OP_EvalFieldVariableRef },
    { 0x01C8, opcode::OP_VectorScale },
    { 0x01C9, opcode::OP_ScriptThreadCallClass },
    { 0x01CA, opcode::OP_Invalid },
    { 0x01CB, opcode::OP_LessThanOrEqualTo },
    { 0x01CC, opcode::OP_ClearFieldVariable },
    { 0x01CD, opcode::OP_Invalid },
    { 0x01CE, opcode::OP_Invalid },
    { 0x01CF, opcode::OP_Invalid },
    { 0x01D0, opcode::OP_Invalid },
    { 0x01D1, opcode::OP_GetNegByte },
    { 0x01D2, opcode::OP_SafeCreateLocalVariables },
    { 0x01D3, opcode::OP_GetHash },
    { 0x01D4, opcode::OP_GetGame },
    { 0x01D5, opcode::OP_Wait },
    { 0x01D6, opcode::OP_GetSelfObject },
    { 0x01D7, opcode::OP_Invalid },
    { 0x01D8, opcode::OP_SelfEvalFieldVariable },
    { 0x01D9, opcode::OP_GetGame },
    { 0x01DA, opcode::OP_New },
    { 0x01DB, opcode::OP_GetUndefined },
    { 0x01DC, opcode::OP_Invalid },
    { 0x01DD, opcode::OP_CastBool },
    { 0x01DE, opcode::OP_Invalid },
    { 0x01DF, opcode::OP_JumpOnFalse },
    { 0x01E0, opcode::OP_EndSwitch },
    { 0x01E1, opcode::OP_Invalid },
    { 0x01E2, opcode::OP_GetUndefined },
    { 0x01E3, opcode::OP_GetSelfObject },
    { 0x01E4, opcode::OP_Minus },
    { 0x01E5, opcode::OP_ScriptThreadCall },
    { 0x01E6, opcode::OP_ProfileStart },
    { 0x01E7, opcode::OP_Invalid },
    { 0x01E8, opcode::OP_GetAPIFunction },
    { 0x01E9, opcode::OP_EmptyArray },
    { 0x01EA, opcode::OP_GetZero },
    { 0x01EB, opcode::OP_Invalid },
    { 0x01EC, opcode::OP_JumpOnFalse },
    { 0x01ED, opcode::OP_EvalLocalVariableCached },
    { 0x01EE, opcode::OP_Invalid },
    { 0x01EF, opcode::OP_GetIString },
    { 0x01F0, opcode::OP_DecTop },
    { 0x01F1, opcode::OP_Invalid },
    { 0x01F2, opcode::OP_Invalid },
    { 0x01F3, opcode::OP_Invalid },
    { 0x01F4, opcode::OP_Invalid },
    { 0x01F5, opcode::OP_Invalid },
    { 0x01F6, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x01F7, opcode::OP_Invalid },
    { 0x01F8, opcode::OP_Switch },
    { 0x01F9, opcode::OP_Invalid },
    { 0x01FA, opcode::OP_GetNegUnsignedShort },
    { 0x01FB, opcode::OP_Invalid },
    { 0x01FC, opcode::OP_Invalid },
    { 0x01FD, opcode::OP_JumpOnTrue },
    { 0x01FE, opcode::OP_Invalid },
    { 0x01FF, opcode::OP_VectorScale },
    { 0x0200, opcode::OP_Invalid },
    { 0x0201, opcode::OP_Invalid },
    { 0x0202, opcode::OP_Invalid },
    { 0x0203, opcode::OP_ScriptFunctionCall },
    { 0x0204, opcode::OP_GetUintptr },
    { 0x0205, opcode::OP_Switch },
    { 0x0206, opcode::OP_JumpOnFalse },
    { 0x0207, opcode::OP_ScriptMethodCall },
    { 0x0208, opcode::OP_GetIString },
    { 0x0209, opcode::OP_ScriptThreadCallPointer },
    { 0x020A, opcode::OP_Bit_And },
    { 0x020B, opcode::OP_EvalLocalVariableCached },
    { 0x020C, opcode::OP_CallBuiltinMethod },
    { 0x020D, opcode::OP_JumpOnFalse },
    { 0x020E, opcode::OP_EndOn },
    { 0x020F, opcode::OP_BoolComplement },
    { 0x0210, opcode::OP_Bit_And },
    { 0x0211, opcode::OP_Vector },
    { 0x0212, opcode::OP_GetSelfObject },
    { 0x0213, opcode::OP_ScriptFunctionCall },
    { 0x0214, opcode::OP_EvalArray },
    { 0x0215, opcode::OP_GetSelf },
    { 0x0216, opcode::OP_SelfEvalFieldVariable },
    { 0x0217, opcode::OP_Invalid },
    { 0x0218, opcode::OP_Invalid },
    { 0x0219, opcode::OP_GetFloat },
    { 0x021A, opcode::OP_GetGameRef },
    { 0x021B, opcode::OP_GetIString },
    { 0x021C, opcode::OP_GetAnim },
    { 0x021D, opcode::OP_Bit_Or },
    { 0x021E, opcode::OP_LessThanOrEqualTo },
    { 0x021F, opcode::OP_ScriptMethodCallPointer },
    { 0x0220, opcode::OP_Invalid },
    { 0x0221, opcode::OP_Invalid },
    { 0x0222, opcode::OP_ClearArray },
    { 0x0223, opcode::OP_GetTime },
    { 0x0224, opcode::OP_Invalid },
    { 0x0225, opcode::OP_Vector },
    { 0x0226, opcode::OP_ScriptMethodCall },
    { 0x0227, opcode::OP_Invalid },
    { 0x0228, opcode::OP_GetByte },
    { 0x0229, opcode::OP_GetVector },
    { 0x022A, opcode::OP_Inc },
    { 0x022B, opcode::OP_ScriptMethodCallPointer },
    { 0x022C, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x022D, opcode::OP_Divide },
    { 0x022E, opcode::OP_Switch },
    { 0x022F, opcode::OP_New },
    { 0x0230, opcode::OP_GetTime },
    { 0x0231, opcode::OP_BoolComplement },
    { 0x0232, opcode::OP_EvalArray },
    { 0x0233, opcode::OP_EndSwitch },
    { 0x0234, opcode::OP_Divide },
    { 0x0235, opcode::OP_Plus },
    { 0x0236, opcode::OP_LessThan },
    { 0x0237, opcode::OP_GetAPIFunction },
    { 0x0238, opcode::OP_EvalArrayRef },
    { 0x0239, opcode::OP_Invalid },
    { 0x023A, opcode::OP_Invalid },
    { 0x023B, opcode::OP_WaitTillFrameEnd },
    { 0x023C, opcode::OP_Invalid },
    { 0x023D, opcode::OP_Wait },
    { 0x023E, opcode::OP_Minus },
    { 0x023F, opcode::OP_Invalid },
    { 0x0240, opcode::OP_Invalid },
    { 0x0241, opcode::OP_GetUndefined },
    { 0x0242, opcode::OP_LevelEvalFieldVariableRef },
    { 0x0243, opcode::OP_ProfileStop },
    { 0x0244, opcode::OP_JumpOnFalseExpr },
    { 0x0245, opcode::OP_CallBuiltinMethod },
    { 0x0246, opcode::OP_EvalLocalVariableCached },
    { 0x0247, opcode::OP_ScriptThreadCallClass },
    { 0x0248, opcode::OP_BoolNot },
    { 0x0249, opcode::OP_ProfileStop },
    { 0x024A, opcode::OP_GetHash },
    { 0x024B, opcode::OP_Invalid },
    { 0x024C, opcode::OP_GetClasses },
    { 0x024D, opcode::OP_Minus },
    { 0x024E, opcode::OP_JumpOnFalseExpr },
    { 0x024F, opcode::OP_SafeSetVariableFieldCached },
    { 0x0250, opcode::OP_Invalid },
    { 0x0251, opcode::OP_Invalid },
    { 0x0252, opcode::OP_Invalid },
    { 0x0253, opcode::OP_ScriptThreadCall },
    { 0x0254, opcode::OP_Invalid },
    { 0x0255, opcode::OP_Divide },
    { 0x0256, opcode::OP_Equal },
    { 0x0257, opcode::OP_Invalid },
    { 0x0258, opcode::OP_Invalid },
    { 0x0259, opcode::OP_Invalid },
    { 0x025A, opcode::OP_ProfileStop },
    { 0x025B, opcode::OP_Invalid },
    { 0x025C, opcode::OP_Invalid },
    { 0x025D, opcode::OP_Invalid },
    { 0x025E, opcode::OP_GetAPIFunction },
    { 0x025F, opcode::OP_Jump },
    { 0x0260, opcode::OP_Multiply },
    { 0x0261, opcode::OP_ClearArray },
    { 0x0262, opcode::OP_Invalid },
    { 0x0263, opcode::OP_Invalid },
    { 0x0264, opcode::OP_EvalArrayRef },
    { 0x0265, opcode::OP_BoolNot },
    { 0x0266, opcode::OP_GetSelfObject },
    { 0x0267, opcode::OP_SizeOf },
    { 0x0268, opcode::OP_ShiftLeft },
    { 0x0269, opcode::OP_Invalid },
    { 0x026A, opcode::OP_Invalid },
    { 0x026B, opcode::OP_ScriptFunctionCallPointer },
    { 0x026C, opcode::OP_GetIString },
    { 0x026D, opcode::OP_Invalid },
    { 0x026E, opcode::OP_ScriptMethodThreadCall },
    { 0x026F, opcode::OP_Invalid },
    { 0x0270, opcode::OP_Invalid },
    { 0x0271, opcode::OP_Bit_Xor },
    { 0x0272, opcode::OP_GetGame },
    { 0x0273, opcode::OP_SelfEvalFieldVariable },
    { 0x0274, opcode::OP_EvalLocalVariableRefCached },
    { 0x0275, opcode::OP_Invalid },
    { 0x0276, opcode::OP_VectorScale },
    { 0x0277, opcode::OP_GetTime },
    { 0x0278, opcode::OP_GetVector },
    { 0x0279, opcode::OP_Invalid },
    { 0x027A, opcode::OP_GetGameRef },
    { 0x027B, opcode::OP_Invalid },
    { 0x027C, opcode::OP_GetWorldObject },
    { 0x027D, opcode::OP_FirstArrayKey },
    { 0x027E, opcode::OP_Invalid },
    { 0x027F, opcode::OP_GetSelf },
    { 0x0280, opcode::OP_Vector },
    { 0x0281, opcode::OP_Equal },
    { 0x0282, opcode::OP_DecTop },
    { 0x0283, opcode::OP_Invalid },
    { 0x0284, opcode::OP_IsDefined },
    { 0x0285, opcode::OP_EvalLocalVariableCached },
    { 0x0286, opcode::OP_Invalid },
    { 0x0287, opcode::OP_EvalLocalVariableCached },
    { 0x0288, opcode::OP_GetNegUnsignedShort },
    { 0x0289, opcode::OP_JumpOnTrueExpr },
    { 0x028A, opcode::OP_Invalid },
    { 0x028B, opcode::OP_GetNegUnsignedShort },
    { 0x028C, opcode::OP_Invalid },
    { 0x028D, opcode::OP_DecTop },
    { 0x028E, opcode::OP_Invalid },
    { 0x028F, opcode::OP_Invalid },
    { 0x0290, opcode::OP_Invalid },
    { 0x0291, opcode::OP_GetAnim },
    { 0x0292, opcode::OP_SizeOf },
    { 0x0293, opcode::OP_Invalid },
    { 0x0294, opcode::OP_GetClasses },
    { 0x0295, opcode::OP_GetClassesObject },
    { 0x0296, opcode::OP_ClearArray },
    { 0x0297, opcode::OP_Invalid },
    { 0x0298, opcode::OP_Vector },
    { 0x0299, opcode::OP_SafeCreateLocalVariables },
    { 0x029A, opcode::OP_ScriptFunctionCall },
    { 0x029B, opcode::OP_DevblockBegin },
    { 0x029C, opcode::OP_GetFunction },
    { 0x029D, opcode::OP_GetSelf },
    { 0x029E, opcode::OP_GetString },
    { 0x029F, opcode::OP_ScriptThreadCallPointer },
    { 0x02A0, opcode::OP_SetVariableField },
    { 0x02A1, opcode::OP_GetClassesObject },
    { 0x02A2, opcode::OP_Invalid },
    { 0x02A3, opcode::OP_Return },
    { 0x02A4, opcode::OP_SuperNotEqual },
    { 0x02A5, opcode::OP_Invalid },
    { 0x02A6, opcode::OP_Invalid },
    { 0x02A7, opcode::OP_Invalid },
    { 0x02A8, opcode::OP_GetLevelObject },
    { 0x02A9, opcode::OP_GetGame },
    { 0x02AA, opcode::OP_LevelEvalFieldVariableRef },
    { 0x02AB, opcode::OP_JumpOnFalseExpr },
    { 0x02AC, opcode::OP_GetGame },
    { 0x02AD, opcode::OP_ScriptThreadCall },
    { 0x02AE, opcode::OP_NextArrayKey },
    { 0x02AF, opcode::OP_Invalid },
    { 0x02B0, opcode::OP_GreaterThanOrEqualTo },
    { 0x02B1, opcode::OP_GetGameRef },
    { 0x02B2, opcode::OP_WaitTill },
    { 0x02B3, opcode::OP_Bit_Or },
    { 0x02B4, opcode::OP_Invalid },
    { 0x02B5, opcode::OP_GetVector },
    { 0x02B6, opcode::OP_ScriptMethodCallPointer },
    { 0x02B7, opcode::OP_SizeOf },
    { 0x02B8, opcode::OP_Invalid },
    { 0x02B9, opcode::OP_Invalid },
    { 0x02BA, opcode::OP_LevelEvalFieldVariable },
    { 0x02BB, opcode::OP_Dec },
    { 0x02BC, opcode::OP_Invalid },
    { 0x02BD, opcode::OP_EvalLocalVariableRefCached },
    { 0x02BE, opcode::OP_VectorConstant },
    { 0x02BF, opcode::OP_ScriptMethodCallPointer },
    { 0x02C0, opcode::OP_EmptyArray },
    { 0x02C1, opcode::OP_JumpOnTrueExpr },
    { 0x02C2, opcode::OP_GetGameRef },
    { 0x02C3, opcode::OP_GetUnsignedShort },
    { 0x02C4, opcode::OP_Switch },
    { 0x02C5, opcode::OP_ScriptMethodThreadCall },
    { 0x02C6, opcode::OP_ClearFieldVariable },
    { 0x02C7, opcode::OP_ScriptThreadCallClass },
    { 0x02C8, opcode::OP_Invalid },
    { 0x02C9, opcode::OP_Invalid },
    { 0x02CA, opcode::OP_GetGame },
    { 0x02CB, opcode::OP_Invalid },
    { 0x02CC, opcode::OP_BoolNot },
    { 0x02CD, opcode::OP_ScriptFunctionCall },
    { 0x02CE, opcode::OP_ScriptFunctionCallPointer },
    { 0x02CF, opcode::OP_LevelEvalFieldVariableRef },
    { 0x02D0, opcode::OP_Invalid },
    { 0x02D1, opcode::OP_LevelEvalFieldVariableRef },
    { 0x02D2, opcode::OP_Invalid },
    { 0x02D3, opcode::OP_Invalid },
    { 0x02D4, opcode::OP_CallBuiltinMethod },
    { 0x02D5, opcode::OP_Invalid },
    { 0x02D6, opcode::OP_ShiftLeft },
    { 0x02D7, opcode::OP_GetFunction },
    { 0x02D8, opcode::OP_Invalid },
    { 0x02D9, opcode::OP_Invalid },
    { 0x02DA, opcode::OP_NotEqual },
    { 0x02DB, opcode::OP_ScriptFunctionCallPointer },
    { 0x02DC, opcode::OP_ProfileStop },
    { 0x02DD, opcode::OP_Invalid },
    { 0x02DE, opcode::OP_GetAPIFunction },
    { 0x02DF, opcode::OP_ScriptMethodCall },
    { 0x02E0, opcode::OP_GetByte },
    { 0x02E1, opcode::OP_Invalid },
    { 0x02E2, opcode::OP_GreaterThan },
    { 0x02E3, opcode::OP_Invalid },
    { 0x02E4, opcode::OP_GetTime },
    { 0x02E5, opcode::OP_Bit_Or },
    { 0x02E6, opcode::OP_Switch },
    { 0x02E7, opcode::OP_JumpOnFalse },
    { 0x02E8, opcode::OP_NextArrayKey },
    { 0x02E9, opcode::OP_Bit_Or },
    { 0x02EA, opcode::OP_Invalid },
    { 0x02EB, opcode::OP_Invalid },
    { 0x02EC, opcode::OP_Invalid },
    { 0x02ED, opcode::OP_Invalid },
    { 0x02EE, opcode::OP_JumpOnTrue },
    { 0x02EF, opcode::OP_VectorConstant },
    { 0x02F0, opcode::OP_NextArrayKey },
    { 0x02F1, opcode::OP_VectorScale },
    { 0x02F2, opcode::OP_CallBuiltinMethod },
    { 0x02F3, opcode::OP_ScriptMethodCall },
    { 0x02F4, opcode::OP_SelfEvalFieldVariableRef },
    { 0x02F5, opcode::OP_Multiply },
    { 0x02F6, opcode::OP_GetWorld },
    { 0x02F7, opcode::OP_SafeCreateLocalVariables },
    { 0x02F8, opcode::OP_Invalid },
    { 0x02F9, opcode::OP_Invalid },
    { 0x02FA, opcode::OP_JumpOnTrueExpr },
    { 0x02FB, opcode::OP_Invalid },
    { 0x02FC, opcode::OP_New },
    { 0x02FD, opcode::OP_ScriptFunctionCallPointer },
    { 0x02FE, opcode::OP_Invalid },
    { 0x02FF, opcode::OP_Invalid },
    { 0x0300, opcode::OP_SuperNotEqual },
    { 0x0301, opcode::OP_GetFloat },
    { 0x0302, opcode::OP_Invalid },
    { 0x0303, opcode::OP_RealWait },
    { 0x0304, opcode::OP_Return },
    { 0x0305, opcode::OP_Invalid },
    { 0x0306, opcode::OP_Invalid },
    { 0x0307, opcode::OP_EndOn },
    { 0x0308, opcode::OP_GetFloat },
    { 0x0309, opcode::OP_EvalFieldVariable },
    { 0x030A, opcode::OP_Bit_Or },
    { 0x030B, opcode::OP_Vector },
    { 0x030C, opcode::OP_Invalid },
    { 0x030D, opcode::OP_WaitTillFrameEnd },
    { 0x030E, opcode::OP_Switch },
    { 0x030F, opcode::OP_BoolNot },
    { 0x0310, opcode::OP_Invalid },
    { 0x0311, opcode::OP_RealWait },
    { 0x0312, opcode::OP_Invalid },
    { 0x0313, opcode::OP_ClearArray },
    { 0x0314, opcode::OP_GetAnim },
    { 0x0315, opcode::OP_Bit_Or },
    { 0x0316, opcode::OP_ScriptFunctionCallClass },
    { 0x0317, opcode::OP_SuperNotEqual },
    { 0x0318, opcode::OP_Wait },
    { 0x0319, opcode::OP_Invalid },
    { 0x031A, opcode::OP_LessThanOrEqualTo },
    { 0x031B, opcode::OP_GetGameRef },
    { 0x031C, opcode::OP_ScriptMethodCallPointer },
    { 0x031D, opcode::OP_Invalid },
    { 0x031E, opcode::OP_Invalid },
    { 0x031F, opcode::OP_Notify },
    { 0x0320, opcode::OP_BoolComplement },
    { 0x0321, opcode::OP_SelfEvalFieldVariableRef },
    { 0x0322, opcode::OP_ClearFieldVariable },
    { 0x0323, opcode::OP_ScriptThreadCallClass },
    { 0x0324, opcode::OP_Return },
    { 0x0325, opcode::OP_GetUintptr },
    { 0x0326, opcode::OP_IsDefined },
    { 0x0327, opcode::OP_GetLevel },
    { 0x0328, opcode::OP_Invalid },
    { 0x0329, opcode::OP_FirstArrayKey },
    { 0x032A, opcode::OP_ProfileStop },
    { 0x032B, opcode::OP_GetSelf },
    { 0x032C, opcode::OP_Minus },
    { 0x032D, opcode::OP_JumpOnTrue },
    { 0x032E, opcode::OP_GetClasses },
    { 0x032F, opcode::OP_RealWait },
    { 0x0330, opcode::OP_Minus },
    { 0x0331, opcode::OP_Invalid },
    { 0x0332, opcode::OP_Switch },
    { 0x0333, opcode::OP_GetByte },
    { 0x0334, opcode::OP_Invalid },
    { 0x0335, opcode::OP_LessThan },
    { 0x0336, opcode::OP_SafeCreateLocalVariables },
    { 0x0337, opcode::OP_Invalid },
    { 0x0338, opcode::OP_Invalid },
    { 0x0339, opcode::OP_Bit_Or },
    { 0x033A, opcode::OP_Invalid },
    { 0x033B, opcode::OP_ProfileStop },
    { 0x033C, opcode::OP_EndSwitch },
    { 0x033D, opcode::OP_Invalid },
    { 0x033E, opcode::OP_Invalid },
    { 0x033F, opcode::OP_FirstArrayKey },
    { 0x0340, opcode::OP_JumpOnFalseExpr },
    { 0x0341, opcode::OP_Bit_Xor },
    { 0x0342, opcode::OP_LevelEvalFieldVariable },
    { 0x0343, opcode::OP_GetInteger },
    { 0x0344, opcode::OP_LevelEvalFieldVariableRef },
    { 0x0345, opcode::OP_ScriptMethodCallPointer },
    { 0x0346, opcode::OP_Wait },
    { 0x0347, opcode::OP_LessThanOrEqualTo },
    { 0x0348, opcode::OP_Invalid },
    { 0x0349, opcode::OP_GetGameRef },
    { 0x034A, opcode::OP_Invalid },
    { 0x034B, opcode::OP_EvalArray },
    { 0x034C, opcode::OP_Invalid },
    { 0x034D, opcode::OP_Multiply },
    { 0x034E, opcode::OP_GetUintptr },
    { 0x034F, opcode::OP_SuperEqual },
    { 0x0350, opcode::OP_LessThanOrEqualTo },
    { 0x0351, opcode::OP_Bit_Or },
    { 0x0352, opcode::OP_GetAPIFunction },
    { 0x0353, opcode::OP_GetIString },
    { 0x0354, opcode::OP_GetUndefined },
    { 0x0355, opcode::OP_Invalid },
    { 0x0356, opcode::OP_EvalLocalVariableCached },
    { 0x0357, opcode::OP_WaitTillMatch },
    { 0x0358, opcode::OP_Invalid },
    { 0x0359, opcode::OP_JumpOnTrue },
    { 0x035A, opcode::OP_Invalid },
    { 0x035B, opcode::OP_Bit_Xor },
    { 0x035C, opcode::OP_Invalid },
    { 0x035D, opcode::OP_Invalid },
    { 0x035E, opcode::OP_Divide },
    { 0x035F, opcode::OP_GetVector },
    { 0x0360, opcode::OP_Invalid },
    { 0x0361, opcode::OP_Invalid },
    { 0x0362, opcode::OP_VectorConstant },
    { 0x0363, opcode::OP_SelfEvalFieldVariableRef },
    { 0x0364, opcode::OP_Invalid },
    { 0x0365, opcode::OP_Invalid },
    { 0x0366, opcode::OP_Divide },
    { 0x0367, opcode::OP_GetSelf },
    { 0x0368, opcode::OP_Plus },
    { 0x0369, opcode::OP_GetWorld },
    { 0x036A, opcode::OP_Invalid },
    { 0x036B, opcode::OP_ScriptFunctionCallPointer },
    { 0x036C, opcode::OP_EmptyArray },
    { 0x036D, opcode::OP_CallBuiltinMethod },
    { 0x036E, opcode::OP_Invalid },
    { 0x036F, opcode::OP_GetSelf },
    { 0x0370, opcode::OP_GetNegUnsignedShort },
    { 0x0371, opcode::OP_SuperNotEqual },
    { 0x0372, opcode::OP_ProfileStop },
    { 0x0373, opcode::OP_Invalid },
    { 0x0374, opcode::OP_Invalid },
    { 0x0375, opcode::OP_Inc },
    { 0x0376, opcode::OP_Invalid },
    { 0x0377, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x0378, opcode::OP_GetByte },
    { 0x0379, opcode::OP_Invalid },
    { 0x037A, opcode::OP_Switch },
    { 0x037B, opcode::OP_Invalid },
    { 0x037C, opcode::OP_Invalid },
    { 0x037D, opcode::OP_Invalid },
    { 0x037E, opcode::OP_Invalid },
    { 0x037F, opcode::OP_Invalid },
    { 0x0380, opcode::OP_Invalid },
    { 0x0381, opcode::OP_Invalid },
    { 0x0382, opcode::OP_Plus },
    { 0x0383, opcode::OP_GetWorldObject },
    { 0x0384, opcode::OP_Invalid },
    { 0x0385, opcode::OP_GetAPIFunction },
    { 0x0386, opcode::OP_DecTop },
    { 0x0387, opcode::OP_Inc },
    { 0x0388, opcode::OP_GetUnsignedShort },
    { 0x0389, opcode::OP_ScriptMethodThreadCall },
    { 0x038A, opcode::OP_EmptyArray },
    { 0x038B, opcode::OP_GetHash },
    { 0x038C, opcode::OP_Invalid },
    { 0x038D, opcode::OP_GetUnsignedShort },
    { 0x038E, opcode::OP_ProfileStop },
    { 0x038F, opcode::OP_GetAnim },
    { 0x0390, opcode::OP_VectorScale },
    { 0x0391, opcode::OP_ScriptFunctionCallClass },
    { 0x0392, opcode::OP_ScriptFunctionCall },
    { 0x0393, opcode::OP_Invalid },
    { 0x0394, opcode::OP_Dec },
    { 0x0395, opcode::OP_Invalid },
    { 0x0396, opcode::OP_GreaterThanOrEqualTo },
    { 0x0397, opcode::OP_GetUintptr },
    { 0x0398, opcode::OP_Invalid },
    { 0x0399, opcode::OP_Inc },
    { 0x039A, opcode::OP_JumpOnFalse },
    { 0x039B, opcode::OP_ScriptThreadCallPointer },
    { 0x039C, opcode::OP_VectorScale },
    { 0x039D, opcode::OP_Invalid },
    { 0x039E, opcode::OP_GetUnsignedShort },
    { 0x039F, opcode::OP_Invalid },
    { 0x03A0, opcode::OP_Invalid },
    { 0x03A1, opcode::OP_GetGameRef },
    { 0x03A2, opcode::OP_GetByte },
    { 0x03A3, opcode::OP_ProfileStart },
    { 0x03A4, opcode::OP_Invalid },
    { 0x03A5, opcode::OP_BoolComplement },
    { 0x03A6, opcode::OP_GetNegByte },
    { 0x03A7, opcode::OP_GetLevel },
    { 0x03A8, opcode::OP_SelfEvalFieldVariable },
    { 0x03A9, opcode::OP_GetByte },
    { 0x03AA, opcode::OP_ShiftLeft },
    { 0x03AB, opcode::OP_GetUndefined },
    { 0x03AC, opcode::OP_Plus },
    { 0x03AD, opcode::OP_ProfileStart },
    { 0x03AE, opcode::OP_GetLevel },
    { 0x03AF, opcode::OP_DevblockBegin },
    { 0x03B0, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x03B1, opcode::OP_Invalid },
    { 0x03B2, opcode::OP_New },
    { 0x03B3, opcode::OP_Invalid },
    { 0x03B4, opcode::OP_Invalid },
    { 0x03B5, opcode::OP_Plus },
    { 0x03B6, opcode::OP_Invalid },
    { 0x03B7, opcode::OP_Wait },
    { 0x03B8, opcode::OP_GetLevel },
    { 0x03B9, opcode::OP_Bit_Or },
    { 0x03BA, opcode::OP_GetClasses },
    { 0x03BB, opcode::OP_EvalLocalVariableCached },
    { 0x03BC, opcode::OP_EvalFieldVariable },
    { 0x03BD, opcode::OP_EvalFieldVariable },
    { 0x03BE, opcode::OP_Invalid },
    { 0x03BF, opcode::OP_GetAnimObject },
    { 0x03C0, opcode::OP_Invalid },
    { 0x03C1, opcode::OP_NotEqual },
    { 0x03C2, opcode::OP_Invalid },
    { 0x03C3, opcode::OP_CallBuiltinMethod },
    { 0x03C4, opcode::OP_Invalid },
    { 0x03C5, opcode::OP_Vector },
    { 0x03C6, opcode::OP_ScriptMethodCall },
    { 0x03C7, opcode::OP_GetAPIFunction },
    { 0x03C8, opcode::OP_CastFieldObject },
    { 0x03C9, opcode::OP_Invalid },
    { 0x03CA, opcode::OP_Invalid },
    { 0x03CB, opcode::OP_Invalid },
    { 0x03CC, opcode::OP_GetZero },
    { 0x03CD, opcode::OP_GetAnimObject },
    { 0x03CE, opcode::OP_Invalid },
    { 0x03CF, opcode::OP_LessThan },
    { 0x03D0, opcode::OP_GetFunction },
    { 0x03D1, opcode::OP_GetAnimObject },
    { 0x03D2, opcode::OP_SelfEvalFieldVariableRef },
    { 0x03D3, opcode::OP_EvalArrayRef },
    { 0x03D4, opcode::OP_ScriptFunctionCall },
    { 0x03D5, opcode::OP_GetUnsignedShort },
    { 0x03D6, opcode::OP_SizeOf },
    { 0x03D7, opcode::OP_Notify },
    { 0x03D8, opcode::OP_EvalArrayRef },
    { 0x03D9, opcode::OP_Invalid },
    { 0x03DA, opcode::OP_EvalLocalVariableRefCached },
    { 0x03DB, opcode::OP_GetVector },
    { 0x03DC, opcode::OP_GetUnsignedShort },
    { 0x03DD, opcode::OP_Invalid },
    { 0x03DE, opcode::OP_JumpOnFalseExpr },
    { 0x03DF, opcode::OP_ProfileStart },
    { 0x03E0, opcode::OP_JumpOnFalse },
    { 0x03E1, opcode::OP_Invalid },
    { 0x03E2, opcode::OP_Inc },
    { 0x03E3, opcode::OP_EvalArray },
    { 0x03E4, opcode::OP_GetClasses },
    { 0x03E5, opcode::OP_Invalid },
    { 0x03E6, opcode::OP_GetSelfObject },
    { 0x03E7, opcode::OP_GetInteger },
    { 0x03E8, opcode::OP_Invalid },
    { 0x03E9, opcode::OP_Invalid },
    { 0x03EA, opcode::OP_Invalid },
    { 0x03EB, opcode::OP_GreaterThanOrEqualTo },
    { 0x03EC, opcode::OP_Invalid },
    { 0x03ED, opcode::OP_GetAnimObject },
    { 0x03EE, opcode::OP_Plus },
    { 0x03EF, opcode::OP_Bit_And },
    { 0x03F0, opcode::OP_Invalid },
    { 0x03F1, opcode::OP_Invalid },
    { 0x03F2, opcode::OP_ScriptFunctionCallPointer },
    { 0x03F3, opcode::OP_GetIString },
    { 0x03F4, opcode::OP_GreaterThan },
    { 0x03F5, opcode::OP_GetNegByte },
    { 0x03F6, opcode::OP_GetNegByte },
    { 0x03F7, opcode::OP_Invalid },
    { 0x03F8, opcode::OP_Invalid },
    { 0x03F9, opcode::OP_Invalid },
    { 0x03FA, opcode::OP_SafeCreateLocalVariables },
    { 0x03FB, opcode::OP_GetByte },
    { 0x03FC, opcode::OP_GetIString },
    { 0x03FD, opcode::OP_EvalArray },
    { 0x03FE, opcode::OP_SafeDecTop },
    { 0x03FF, opcode::OP_GetUnsignedShort },
    { 0x0400, opcode::OP_Invalid },
    { 0x0401, opcode::OP_GetByte },
    { 0x0402, opcode::OP_EndOn },
    { 0x0403, opcode::OP_EndSwitch },
    { 0x0404, opcode::OP_CallBuiltinMethod },
    { 0x0405, opcode::OP_Minus },
    { 0x0406, opcode::OP_New },
    { 0x0407, opcode::OP_GetInteger },
    { 0x0408, opcode::OP_Invalid },
    { 0x0409, opcode::OP_EvalFieldVariable },
    { 0x040A, opcode::OP_FirstArrayKey },
    { 0x040B, opcode::OP_VectorScale },
    { 0x040C, opcode::OP_EvalFieldVariableRef },
    { 0x040D, opcode::OP_Invalid },
    { 0x040E, opcode::OP_New },
    { 0x040F, opcode::OP_BoolComplement },
    { 0x0410, opcode::OP_GetGameRef },
    { 0x0411, opcode::OP_Invalid },
    { 0x0412, opcode::OP_Invalid },
    { 0x0413, opcode::OP_Invalid },
    { 0x0414, opcode::OP_Invalid },
    { 0x0415, opcode::OP_Invalid },
    { 0x0416, opcode::OP_GetIString },
    { 0x0417, opcode::OP_Notify },
    { 0x0418, opcode::OP_Invalid },
    { 0x0419, opcode::OP_GetAnim },
    { 0x041A, opcode::OP_GetHash },
    { 0x041B, opcode::OP_Invalid },
    { 0x041C, opcode::OP_Invalid },
    { 0x041D, opcode::OP_LessThan },
    { 0x041E, opcode::OP_EndOn },
    { 0x041F, opcode::OP_Invalid },
    { 0x0420, opcode::OP_GetAnimation },
    { 0x0421, opcode::OP_GetZero },
    { 0x0422, opcode::OP_Invalid },
    { 0x0423, opcode::OP_LevelEvalFieldVariable },
    { 0x0424, opcode::OP_GetZero },
    { 0x0425, opcode::OP_ScriptThreadCallClass },
    { 0x0426, opcode::OP_GetNegUnsignedShort },
    { 0x0427, opcode::OP_EvalArrayRef },
    { 0x0428, opcode::OP_GetClassesObject },
    { 0x0429, opcode::OP_EndSwitch },
    { 0x042A, opcode::OP_Divide },
    { 0x042B, opcode::OP_Invalid },
    { 0x042C, opcode::OP_Return },
    { 0x042D, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x042E, opcode::OP_GetClassesObject },
    { 0x042F, opcode::OP_LevelEvalFieldVariable },
    { 0x0430, opcode::OP_EvalFieldVariable },
    { 0x0431, opcode::OP_Invalid },
    { 0x0432, opcode::OP_Invalid },
    { 0x0433, opcode::OP_SetVariableField },
    { 0x0434, opcode::OP_Minus },
    { 0x0435, opcode::OP_Invalid },
    { 0x0436, opcode::OP_WaitTillFrameEnd },
    { 0x0437, opcode::OP_SetVariableField },
    { 0x0438, opcode::OP_GetAnimObject },
    { 0x0439, opcode::OP_EvalLocalVariableRefCached },
    { 0x043A, opcode::OP_ScriptThreadCall },
    { 0x043B, opcode::OP_Invalid },
    { 0x043C, opcode::OP_GetSelf },
    { 0x043D, opcode::OP_Invalid },
    { 0x043E, opcode::OP_Invalid },
    { 0x043F, opcode::OP_Invalid },
    { 0x0440, opcode::OP_Invalid },
    { 0x0441, opcode::OP_EvalArrayRef },
    { 0x0442, opcode::OP_EndSwitch },
    { 0x0443, opcode::OP_Invalid },
    { 0x0444, opcode::OP_GetUndefined },
    { 0x0445, opcode::OP_GetClasses },
    { 0x0446, opcode::OP_EvalLocalVariableRefCached },
    { 0x0447, opcode::OP_Invalid },
    { 0x0448, opcode::OP_Wait },
    { 0x0449, opcode::OP_SelfEvalFieldVariable },
    { 0x044A, opcode::OP_Invalid },
    { 0x044B, opcode::OP_VectorConstant },
    { 0x044C, opcode::OP_DevblockBegin },
    { 0x044D, opcode::OP_ScriptThreadCallPointer },
    { 0x044E, opcode::OP_Invalid },
    { 0x044F, opcode::OP_NextArrayKey },
    { 0x0450, opcode::OP_New },
    { 0x0451, opcode::OP_Invalid },
    { 0x0452, opcode::OP_VectorConstant },
    { 0x0453, opcode::OP_JumpOnTrueExpr },
    { 0x0454, opcode::OP_Invalid },
    { 0x0455, opcode::OP_GetVector },
    { 0x0456, opcode::OP_Invalid },
    { 0x0457, opcode::OP_GetAnimation },
    { 0x0458, opcode::OP_Invalid },
    { 0x0459, opcode::OP_JumpOnTrue },
    { 0x045A, opcode::OP_SafeCreateLocalVariables },
    { 0x045B, opcode::OP_GetAnimObject },
    { 0x045C, opcode::OP_GetHash },
    { 0x045D, opcode::OP_New },
    { 0x045E, opcode::OP_GetAnimation },
    { 0x045F, opcode::OP_VectorConstant },
    { 0x0460, opcode::OP_Invalid },
    { 0x0461, opcode::OP_GetWorld },
    { 0x0462, opcode::OP_NotEqual },
    { 0x0463, opcode::OP_ScriptFunctionCall },
    { 0x0464, opcode::OP_VectorConstant },
    { 0x0465, opcode::OP_LessThanOrEqualTo },
    { 0x0466, opcode::OP_SetVariableField },
    { 0x0467, opcode::OP_Dec },
    { 0x0468, opcode::OP_CallBuiltinMethod },
    { 0x0469, opcode::OP_LevelEvalFieldVariableRef },
    { 0x046A, opcode::OP_Invalid },
    { 0x046B, opcode::OP_Bit_Or },
    { 0x046C, opcode::OP_Invalid },
    { 0x046D, opcode::OP_Invalid },
    { 0x046E, opcode::OP_Invalid },
    { 0x046F, opcode::OP_WaitTillFrameEnd },
    { 0x0470, opcode::OP_Invalid },
    { 0x0471, opcode::OP_Invalid },
    { 0x0472, opcode::OP_Plus },
    { 0x0473, opcode::OP_Invalid },
    { 0x0474, opcode::OP_EndOn },
    { 0x0475, opcode::OP_Invalid },
    { 0x0476, opcode::OP_ScriptMethodCall },
    { 0x0477, opcode::OP_NotEqual },
    { 0x0478, opcode::OP_Vector },
    { 0x0479, opcode::OP_SuperEqual },
    { 0x047A, opcode::OP_WaitTillFrameEnd },
    { 0x047B, opcode::OP_Invalid },
    { 0x047C, opcode::OP_Invalid },
    { 0x047D, opcode::OP_VectorScale },
    { 0x047E, opcode::OP_Vector },
    { 0x047F, opcode::OP_CastFieldObject },
    { 0x0480, opcode::OP_EvalFieldVariable },
    { 0x0481, opcode::OP_GetLevelObject },
    { 0x0482, opcode::OP_Invalid },
    { 0x0483, opcode::OP_LessThanOrEqualTo },
    { 0x0484, opcode::OP_Invalid },
    { 0x0485, opcode::OP_ScriptThreadCallClass },
    { 0x0486, opcode::OP_GetClassesObject },
    { 0x0487, opcode::OP_ClearArray },
    { 0x0488, opcode::OP_GreaterThanOrEqualTo },
    { 0x0489, opcode::OP_Invalid },
    { 0x048A, opcode::OP_SetVariableField },
    { 0x048B, opcode::OP_GetUnsignedShort },
    { 0x048C, opcode::OP_BoolNot },
    { 0x048D, opcode::OP_Plus },
    { 0x048E, opcode::OP_EvalLocalVariableRefCached },
    { 0x048F, opcode::OP_Return },
    { 0x0490, opcode::OP_Plus },
    { 0x0491, opcode::OP_EndSwitch },
    { 0x0492, opcode::OP_GetSelf },
    { 0x0493, opcode::OP_Invalid },
    { 0x0494, opcode::OP_GetSelf },
    { 0x0495, opcode::OP_Invalid },
    { 0x0496, opcode::OP_GetUnsignedShort },
    { 0x0497, opcode::OP_Invalid },
    { 0x0498, opcode::OP_ProfileStart },
    { 0x0499, opcode::OP_Plus },
    { 0x049A, opcode::OP_Invalid },
    { 0x049B, opcode::OP_ScriptFunctionCall },
    { 0x049C, opcode::OP_Invalid },
    { 0x049D, opcode::OP_WaitTill },
    { 0x049E, opcode::OP_Bit_Or },
    { 0x049F, opcode::OP_SafeCreateLocalVariables },
    { 0x04A0, opcode::OP_Invalid },
    { 0x04A1, opcode::OP_ProfileStart },
    { 0x04A2, opcode::OP_Invalid },
    { 0x04A3, opcode::OP_Invalid },
    { 0x04A4, opcode::OP_Invalid },
    { 0x04A5, opcode::OP_Notify },
    { 0x04A6, opcode::OP_ScriptThreadCallClass },
    { 0x04A7, opcode::OP_Invalid },
    { 0x04A8, opcode::OP_Wait },
    { 0x04A9, opcode::OP_Invalid },
    { 0x04AA, opcode::OP_JumpOnFalse },
    { 0x04AB, opcode::OP_Invalid },
    { 0x04AC, opcode::OP_Invalid },
    { 0x04AD, opcode::OP_Invalid },
    { 0x04AE, opcode::OP_Invalid },
    { 0x04AF, opcode::OP_Invalid },
    { 0x04B0, opcode::OP_LevelEvalFieldVariable },
    { 0x04B1, opcode::OP_EvalArray },
    { 0x04B2, opcode::OP_JumpOnTrueExpr },
    { 0x04B3, opcode::OP_EvalFieldVariableRef },
    { 0x04B4, opcode::OP_IsDefined },
    { 0x04B5, opcode::OP_Invalid },
    { 0x04B6, opcode::OP_ScriptMethodThreadCall },
    { 0x04B7, opcode::OP_Invalid },
    { 0x04B8, opcode::OP_GreaterThanOrEqualTo },
    { 0x04B9, opcode::OP_Jump },
    { 0x04BA, opcode::OP_Invalid },
    { 0x04BB, opcode::OP_EvalArrayRef },
    { 0x04BC, opcode::OP_GetInteger },
    { 0x04BD, opcode::OP_ShiftRight },
    { 0x04BE, opcode::OP_Invalid },
    { 0x04BF, opcode::OP_GreaterThanOrEqualTo },
    { 0x04C0, opcode::OP_EvalFieldVariable },
    { 0x04C1, opcode::OP_DevblockBegin },
    { 0x04C2, opcode::OP_Invalid },
    { 0x04C3, opcode::OP_EvalLocalVariableRefCached },
    { 0x04C4, opcode::OP_Invalid },
    { 0x04C5, opcode::OP_GetUnsignedShort },
    { 0x04C6, opcode::OP_IsDefined },
    { 0x04C7, opcode::OP_Notify },
    { 0x04C8, opcode::OP_NextArrayKey },
    { 0x04C9, opcode::OP_LevelEvalFieldVariable },
    { 0x04CA, opcode::OP_Invalid },
    { 0x04CB, opcode::OP_Invalid },
    { 0x04CC, opcode::OP_BoolComplement },
    { 0x04CD, opcode::OP_EvalLocalVariableRefCached },
    { 0x04CE, opcode::OP_ScriptMethodThreadCall },
    { 0x04CF, opcode::OP_Invalid },
    { 0x04D0, opcode::OP_GetZero },
    { 0x04D1, opcode::OP_GetAnimation },
    { 0x04D2, opcode::OP_VectorScale },
    { 0x04D3, opcode::OP_ScriptFunctionCallPointer },
    { 0x04D4, opcode::OP_Invalid },
    { 0x04D5, opcode::OP_Bit_And },
    { 0x04D6, opcode::OP_GreaterThan },
    { 0x04D7, opcode::OP_GetInteger },
    { 0x04D8, opcode::OP_ShiftLeft },
    { 0x04D9, opcode::OP_Invalid },
    { 0x04DA, opcode::OP_IsDefined },
    { 0x04DB, opcode::OP_Modulus },
    { 0x04DC, opcode::OP_GetAnimObject },
    { 0x04DD, opcode::OP_GetSelfObject },
    { 0x04DE, opcode::OP_EmptyArray },
    { 0x04DF, opcode::OP_GetInteger },
    { 0x04E0, opcode::OP_Invalid },
    { 0x04E1, opcode::OP_Invalid },
    { 0x04E2, opcode::OP_GetHash },
    { 0x04E3, opcode::OP_Inc },
    { 0x04E4, opcode::OP_JumpOnTrue },
    { 0x04E5, opcode::OP_SelfEvalFieldVariable },
    { 0x04E6, opcode::OP_Invalid },
    { 0x04E7, opcode::OP_Invalid },
    { 0x04E8, opcode::OP_Inc },
    { 0x04E9, opcode::OP_Invalid },
    { 0x04EA, opcode::OP_GreaterThan },
    { 0x04EB, opcode::OP_ScriptThreadCall },
    { 0x04EC, opcode::OP_Invalid },
    { 0x04ED, opcode::OP_CastFieldObject },
    { 0x04EE, opcode::OP_Invalid },
    { 0x04EF, opcode::OP_EvalLocalVariableCached },
    { 0x04F0, opcode::OP_ShiftLeft },
    { 0x04F1, opcode::OP_Invalid },
    { 0x04F2, opcode::OP_GetAnim },
    { 0x04F3, opcode::OP_EvalArrayRef },
    { 0x04F4, opcode::OP_LevelEvalFieldVariable },
    { 0x04F5, opcode::OP_Invalid },
    { 0x04F6, opcode::OP_EvalLocalVariableCached },
    { 0x04F7, opcode::OP_ScriptMethodCallPointer },
    { 0x04F8, opcode::OP_Invalid },
    { 0x04F9, opcode::OP_Invalid },
    { 0x04FA, opcode::OP_Jump },
    { 0x04FB, opcode::OP_Invalid },
    { 0x04FC, opcode::OP_Plus },
    { 0x04FD, opcode::OP_SizeOf },
    { 0x04FE, opcode::OP_WaitTillMatch },
    { 0x04FF, opcode::OP_Invalid },
    { 0x0500, opcode::OP_GetVector },
    { 0x0501, opcode::OP_Invalid },
    { 0x0502, opcode::OP_Modulus },
    { 0x0503, opcode::OP_CallBuiltinMethod },
    { 0x0504, opcode::OP_BoolComplement },
    { 0x0505, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x0506, opcode::OP_GetLevelObject },
    { 0x0507, opcode::OP_GetAnim },
    { 0x0508, opcode::OP_GetAnimation },
    { 0x0509, opcode::OP_Invalid },
    { 0x050A, opcode::OP_VectorConstant },
    { 0x050B, opcode::OP_ScriptThreadCallPointer },
    { 0x050C, opcode::OP_ScriptMethodThreadCall },
    { 0x050D, opcode::OP_Invalid },
    { 0x050E, opcode::OP_GetAnim },
    { 0x050F, opcode::OP_GetLevelObject },
    { 0x0510, opcode::OP_GetGameRef },
    { 0x0511, opcode::OP_Invalid },
    { 0x0512, opcode::OP_GetVector },
    { 0x0513, opcode::OP_Switch },
    { 0x0514, opcode::OP_GetFunction },
    { 0x0515, opcode::OP_ScriptThreadCallClass },
    { 0x0516, opcode::OP_NextArrayKey },
    { 0x0517, opcode::OP_ScriptMethodCall },
    { 0x0518, opcode::OP_EvalLocalVariableRefCached },
    { 0x0519, opcode::OP_GetTime },
    { 0x051A, opcode::OP_Invalid },
    { 0x051B, opcode::OP_EndOn },
    { 0x051C, opcode::OP_ScriptMethodCallPointer },
    { 0x051D, opcode::OP_SuperNotEqual },
    { 0x051E, opcode::OP_Invalid },
    { 0x051F, opcode::OP_Invalid },
    { 0x0520, opcode::OP_SuperNotEqual },
    { 0x0521, opcode::OP_Invalid },
    { 0x0522, opcode::OP_Invalid },
    { 0x0523, opcode::OP_EmptyArray },
    { 0x0524, opcode::OP_EvalFieldVariableRef },
    { 0x0525, opcode::OP_LessThanOrEqualTo },
    { 0x0526, opcode::OP_EvalFieldVariableRef },
    { 0x0527, opcode::OP_Notify },
    { 0x0528, opcode::OP_Invalid },
    { 0x0529, opcode::OP_NotEqual },
    { 0x052A, opcode::OP_ScriptMethodCallPointer },
    { 0x052B, opcode::OP_Invalid },
    { 0x052C, opcode::OP_VectorScale },
    { 0x052D, opcode::OP_Plus },
    { 0x052E, opcode::OP_Invalid },
    { 0x052F, opcode::OP_GetByte },
    { 0x0530, opcode::OP_LessThan },
    { 0x0531, opcode::OP_GetGameRef },
    { 0x0532, opcode::OP_Invalid },
    { 0x0533, opcode::OP_EvalFieldVariable },
    { 0x0534, opcode::OP_GetByte },
    { 0x0535, opcode::OP_GetAnimObject },
    { 0x0536, opcode::OP_Invalid },
    { 0x0537, opcode::OP_CastBool },
    { 0x0538, opcode::OP_Vector },
    { 0x0539, opcode::OP_EmptyArray },
    { 0x053A, opcode::OP_EvalArray },
    { 0x053B, opcode::OP_GreaterThanOrEqualTo },
    { 0x053C, opcode::OP_SafeDecTop },
    { 0x053D, opcode::OP_LessThanOrEqualTo },
    { 0x053E, opcode::OP_Invalid },
    { 0x053F, opcode::OP_Invalid },
    { 0x0540, opcode::OP_Wait },
    { 0x0541, opcode::OP_Jump },
    { 0x0542, opcode::OP_EvalArrayRef },
    { 0x0543, opcode::OP_Invalid },
    { 0x0544, opcode::OP_Invalid },
    { 0x0545, opcode::OP_EndSwitch },
    { 0x0546, opcode::OP_Invalid },
    { 0x0547, opcode::OP_Invalid },
    { 0x0548, opcode::OP_GetLevel },
    { 0x0549, opcode::OP_Invalid },
    { 0x054A, opcode::OP_GetUintptr },
    { 0x054B, opcode::OP_ProfileStop },
    { 0x054C, opcode::OP_Invalid },
    { 0x054D, opcode::OP_ShiftLeft },
    { 0x054E, opcode::OP_JumpOnFalse },
    { 0x054F, opcode::OP_Vector },
    { 0x0550, opcode::OP_WaitTillFrameEnd },
    { 0x0551, opcode::OP_Invalid },
    { 0x0552, opcode::OP_ProfileStop },
    { 0x0553, opcode::OP_Divide },
    { 0x0554, opcode::OP_GetNegUnsignedShort },
    { 0x0555, opcode::OP_ProfileStop },
    { 0x0556, opcode::OP_ScriptFunctionCallClass },
    { 0x0557, opcode::OP_EvalLocalVariableRefCached },
    { 0x0558, opcode::OP_Invalid },
    { 0x0559, opcode::OP_Invalid },
    { 0x055A, opcode::OP_GetFloat },
    { 0x055B, opcode::OP_DevblockBegin },
    { 0x055C, opcode::OP_GetClassesObject },
    { 0x055D, opcode::OP_SetVariableField },
    { 0x055E, opcode::OP_GetUndefined },
    { 0x055F, opcode::OP_Invalid },
    { 0x0560, opcode::OP_SelfEvalFieldVariable },
    { 0x0561, opcode::OP_VectorConstant },
    { 0x0562, opcode::OP_GetLevel },
    { 0x0563, opcode::OP_Invalid },
    { 0x0564, opcode::OP_Invalid },
    { 0x0565, opcode::OP_GetFunction },
    { 0x0566, opcode::OP_ScriptFunctionCallPointer },
    { 0x0567, opcode::OP_GetNegByte },
    { 0x0568, opcode::OP_ScriptMethodThreadCall },
    { 0x0569, opcode::OP_Invalid },
    { 0x056A, opcode::OP_Inc },
    { 0x056B, opcode::OP_Invalid },
    { 0x056C, opcode::OP_Invalid },
    { 0x056D, opcode::OP_GetString },
    { 0x056E, opcode::OP_Return },
    { 0x056F, opcode::OP_Plus },
    { 0x0570, opcode::OP_Invalid },
    { 0x0571, opcode::OP_EndOn },
    { 0x0572, opcode::OP_ClearArray },
    { 0x0573, opcode::OP_ScriptThreadCallClass },
    { 0x0574, opcode::OP_EvalLocalVariableCached },
    { 0x0575, opcode::OP_SafeSetVariableFieldCached },
    { 0x0576, opcode::OP_Return },
    { 0x0577, opcode::OP_GetTime },
    { 0x0578, opcode::OP_Vector },
    { 0x0579, opcode::OP_JumpOnFalseExpr },
    { 0x057A, opcode::OP_Invalid },
    { 0x057B, opcode::OP_New },
    { 0x057C, opcode::OP_Invalid },
    { 0x057D, opcode::OP_SizeOf },
    { 0x057E, opcode::OP_Invalid },
    { 0x057F, opcode::OP_CastBool },
    { 0x0580, opcode::OP_New },
    { 0x0581, opcode::OP_SelfEvalFieldVariableRef },
    { 0x0582, opcode::OP_Invalid },
    { 0x0583, opcode::OP_GetTime },
    { 0x0584, opcode::OP_GreaterThan },
    { 0x0585, opcode::OP_GetGame },
    { 0x0586, opcode::OP_Invalid },
    { 0x0587, opcode::OP_VectorConstant },
    { 0x0588, opcode::OP_Invalid },
    { 0x0589, opcode::OP_GetZero },
    { 0x058A, opcode::OP_WaitTill },
    { 0x058B, opcode::OP_SetVariableField },
    { 0x058C, opcode::OP_Invalid },
    { 0x058D, opcode::OP_BoolNot },
    { 0x058E, opcode::OP_Modulus },
    { 0x058F, opcode::OP_Invalid },
    { 0x0590, opcode::OP_SuperNotEqual },
    { 0x0591, opcode::OP_Invalid },
    { 0x0592, opcode::OP_JumpOnTrueExpr },
    { 0x0593, opcode::OP_Invalid },
    { 0x0594, opcode::OP_CastBool },
    { 0x0595, opcode::OP_GreaterThan },
    { 0x0596, opcode::OP_EvalLocalVariableCached },
    { 0x0597, opcode::OP_GetUintptr },
    { 0x0598, opcode::OP_Invalid },
    { 0x0599, opcode::OP_Invalid },
    { 0x059A, opcode::OP_Invalid },
    { 0x059B, opcode::OP_Invalid },
    { 0x059C, opcode::OP_Invalid },
    { 0x059D, opcode::OP_ProfileStart },
    { 0x059E, opcode::OP_Return },
    { 0x059F, opcode::OP_GetSelfObject },
    { 0x05A0, opcode::OP_ProfileStop },
    { 0x05A1, opcode::OP_Invalid },
    { 0x05A2, opcode::OP_GetGame },
    { 0x05A3, opcode::OP_JumpOnTrueExpr },
    { 0x05A4, opcode::OP_Invalid },
    { 0x05A5, opcode::OP_Invalid },
    { 0x05A6, opcode::OP_GetByte },
    { 0x05A7, opcode::OP_DevblockBegin },
    { 0x05A8, opcode::OP_EvalLocalVariableRefCached },
    { 0x05A9, opcode::OP_Invalid },
    { 0x05AA, opcode::OP_RealWait },
    { 0x05AB, opcode::OP_Switch },
    { 0x05AC, opcode::OP_Jump },
    { 0x05AD, opcode::OP_Invalid },
    { 0x05AE, opcode::OP_ShiftRight },
    { 0x05AF, opcode::OP_LessThan },
    { 0x05B0, opcode::OP_ScriptThreadCallPointer },
    { 0x05B1, opcode::OP_Invalid },
    { 0x05B2, opcode::OP_ProfileStop },
    { 0x05B3, opcode::OP_SafeCreateLocalVariables },
    { 0x05B4, opcode::OP_GetUndefined },
    { 0x05B5, opcode::OP_IsDefined },
    { 0x05B6, opcode::OP_EndOn },
    { 0x05B7, opcode::OP_Invalid },
    { 0x05B8, opcode::OP_CastFieldObject },
    { 0x05B9, opcode::OP_Switch },
    { 0x05BA, opcode::OP_SizeOf },
    { 0x05BB, opcode::OP_ScriptMethodCall },
    { 0x05BC, opcode::OP_Invalid },
    { 0x05BD, opcode::OP_Bit_Or },
    { 0x05BE, opcode::OP_Invalid },
    { 0x05BF, opcode::OP_GetGameRef },
    { 0x05C0, opcode::OP_ProfileStop },
    { 0x05C1, opcode::OP_BoolNot },
    { 0x05C2, opcode::OP_JumpOnTrueExpr },
    { 0x05C3, opcode::OP_Invalid },
    { 0x05C4, opcode::OP_Invalid },
    { 0x05C5, opcode::OP_CastBool },
    { 0x05C6, opcode::OP_Dec },
    { 0x05C7, opcode::OP_BoolNot },
    { 0x05C8, opcode::OP_EvalFieldVariableRef },
    { 0x05C9, opcode::OP_Invalid },
    { 0x05CA, opcode::OP_ScriptFunctionCallPointer },
    { 0x05CB, opcode::OP_Invalid },
    { 0x05CC, opcode::OP_GetLevel },
    { 0x05CD, opcode::OP_LessThan },
    { 0x05CE, opcode::OP_BoolComplement },
    { 0x05CF, opcode::OP_GetClassesObject },
    { 0x05D0, opcode::OP_ShiftRight },
    { 0x05D1, opcode::OP_Invalid },
    { 0x05D2, opcode::OP_ScriptFunctionCallPointer },
    { 0x05D3, opcode::OP_GetLevelObject },
    { 0x05D4, opcode::OP_Invalid },
    { 0x05D5, opcode::OP_BoolComplement },
    { 0x05D6, opcode::OP_EvalLocalVariableCached },
    { 0x05D7, opcode::OP_Invalid },
    { 0x05D8, opcode::OP_GetInteger },
    { 0x05D9, opcode::OP_ScriptFunctionCallClass },
    { 0x05DA, opcode::OP_JumpOnFalseExpr },
    { 0x05DB, opcode::OP_GetFunction },
    { 0x05DC, opcode::OP_GetGame },
    { 0x05DD, opcode::OP_Invalid },
    { 0x05DE, opcode::OP_SafeSetVariableFieldCached },
    { 0x05DF, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x05E0, opcode::OP_GetLevel },
    { 0x05E1, opcode::OP_GetUnsignedShort },
    { 0x05E2, opcode::OP_JumpOnFalseExpr },
    { 0x05E3, opcode::OP_Switch },
    { 0x05E4, opcode::OP_JumpOnFalseExpr },
    { 0x05E5, opcode::OP_JumpOnTrue },
    { 0x05E6, opcode::OP_DevblockBegin },
    { 0x05E7, opcode::OP_GreaterThanOrEqualTo },
    { 0x05E8, opcode::OP_GetSelf },
    { 0x05E9, opcode::OP_GetZero },
    { 0x05EA, opcode::OP_Invalid },
    { 0x05EB, opcode::OP_Invalid },
    { 0x05EC, opcode::OP_GetSelf },
    { 0x05ED, opcode::OP_Invalid },
    { 0x05EE, opcode::OP_GetUnsignedShort },
    { 0x05EF, opcode::OP_Invalid },
    { 0x05F0, opcode::OP_Invalid },
    { 0x05F1, opcode::OP_Invalid },
    { 0x05F2, opcode::OP_Invalid },
    { 0x05F3, opcode::OP_FirstArrayKey },
    { 0x05F4, opcode::OP_Dec },
    { 0x05F5, opcode::OP_Bit_Xor },
    { 0x05F6, opcode::OP_ProfileStart },
    { 0x05F7, opcode::OP_GetAPIFunction },
    { 0x05F8, opcode::OP_LessThan },
    { 0x05F9, opcode::OP_Invalid },
    { 0x05FA, opcode::OP_SetVariableField },
    { 0x05FB, opcode::OP_Dec },
    { 0x05FC, opcode::OP_EvalFieldVariable },
    { 0x05FD, opcode::OP_GetClasses },
    { 0x05FE, opcode::OP_ScriptThreadCallPointer },
    { 0x05FF, opcode::OP_Notify },
    { 0x0600, opcode::OP_GetByte },
    { 0x0601, opcode::OP_GetClasses },
    { 0x0602, opcode::OP_Equal },
    { 0x0603, opcode::OP_Multiply },
    { 0x0604, opcode::OP_Invalid },
    { 0x0605, opcode::OP_Notify },
    { 0x0606, opcode::OP_WaitTill },
    { 0x0607, opcode::OP_Invalid },
    { 0x0608, opcode::OP_EvalFieldVariable },
    { 0x0609, opcode::OP_Invalid },
    { 0x060A, opcode::OP_SetVariableField },
    { 0x060B, opcode::OP_Invalid },
    { 0x060C, opcode::OP_GetAnim },
    { 0x060D, opcode::OP_WaitTill },
    { 0x060E, opcode::OP_Invalid },
    { 0x060F, opcode::OP_BoolNot },
    { 0x0610, opcode::OP_RealWait },
    { 0x0611, opcode::OP_Invalid },
    { 0x0612, opcode::OP_Invalid },
    { 0x0613, opcode::OP_GreaterThan },
    { 0x0614, opcode::OP_NextArrayKey },
    { 0x0615, opcode::OP_GetWorld },
    { 0x0616, opcode::OP_GetNegUnsignedShort },
    { 0x0617, opcode::OP_ScriptMethodThreadCall },
    { 0x0618, opcode::OP_Invalid },
    { 0x0619, opcode::OP_FirstArrayKey },
    { 0x061A, opcode::OP_Invalid },
    { 0x061B, opcode::OP_Invalid },
    { 0x061C, opcode::OP_GetHash },
    { 0x061D, opcode::OP_ShiftRight },
    { 0x061E, opcode::OP_Multiply },
    { 0x061F, opcode::OP_Invalid },
    { 0x0620, opcode::OP_ScriptThreadCallClass },
    { 0x0621, opcode::OP_SafeSetVariableFieldCached },
    { 0x0622, opcode::OP_Invalid },
    { 0x0623, opcode::OP_SizeOf },
    { 0x0624, opcode::OP_Invalid },
    { 0x0625, opcode::OP_Invalid },
    { 0x0626, opcode::OP_Multiply },
    { 0x0627, opcode::OP_Invalid },
    { 0x0628, opcode::OP_GetFunction },
    { 0x0629, opcode::OP_ScriptThreadCallPointer },
    { 0x062A, opcode::OP_Invalid },
    { 0x062B, opcode::OP_ProfileStart },
    { 0x062C, opcode::OP_GetLevelObject },
    { 0x062D, opcode::OP_ScriptFunctionCallClass },
    { 0x062E, opcode::OP_GetUndefined },
    { 0x062F, opcode::OP_Invalid },
    { 0x0630, opcode::OP_LessThanOrEqualTo },
    { 0x0631, opcode::OP_RealWait },
    { 0x0632, opcode::OP_Invalid },
    { 0x0633, opcode::OP_ShiftRight },
    { 0x0634, opcode::OP_GetFunction },
    { 0x0635, opcode::OP_Invalid },
    { 0x0636, opcode::OP_Invalid },
    { 0x0637, opcode::OP_RealWait },
    { 0x0638, opcode::OP_Invalid },
    { 0x0639, opcode::OP_LessThanOrEqualTo },
    { 0x063A, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x063B, opcode::OP_ShiftRight },
    { 0x063C, opcode::OP_EvalArray },
    { 0x063D, opcode::OP_GetLevelObject },
    { 0x063E, opcode::OP_Invalid },
    { 0x063F, opcode::OP_GetString },
    { 0x0640, opcode::OP_SafeSetVariableFieldCached },
    { 0x0641, opcode::OP_Invalid },
    { 0x0642, opcode::OP_GetLevelObject },
    { 0x0643, opcode::OP_EndOn },
    { 0x0644, opcode::OP_Invalid },
    { 0x0645, opcode::OP_Bit_Or },
    { 0x0646, opcode::OP_Invalid },
    { 0x0647, opcode::OP_CastBool },
    { 0x0648, opcode::OP_JumpOnFalse },
    { 0x0649, opcode::OP_Invalid },
    { 0x064A, opcode::OP_SelfEvalFieldVariable },
    { 0x064B, opcode::OP_GetFloat },
    { 0x064C, opcode::OP_Invalid },
    { 0x064D, opcode::OP_GetUintptr },
    { 0x064E, opcode::OP_Invalid },
    { 0x064F, opcode::OP_GetTime },
    { 0x0650, opcode::OP_ScriptFunctionCallPointer },
    { 0x0651, opcode::OP_Invalid },
    { 0x0652, opcode::OP_Jump },
    { 0x0653, opcode::OP_ScriptFunctionCallPointer },
    { 0x0654, opcode::OP_Invalid },
    { 0x0655, opcode::OP_EvalFieldVariableRef },
    { 0x0656, opcode::OP_ScriptMethodCallPointer },
    { 0x0657, opcode::OP_GetInteger },
    { 0x0658, opcode::OP_ShiftRight },
    { 0x0659, opcode::OP_GetClasses },
    { 0x065A, opcode::OP_ProfileStop },
    { 0x065B, opcode::OP_Invalid },
    { 0x065C, opcode::OP_DevblockBegin },
    { 0x065D, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x065E, opcode::OP_ScriptThreadCallPointer },
    { 0x065F, opcode::OP_GetString },
    { 0x0660, opcode::OP_GetClasses },
    { 0x0661, opcode::OP_GetAnim },
    { 0x0662, opcode::OP_New },
    { 0x0663, opcode::OP_Invalid },
    { 0x0664, opcode::OP_EvalLocalVariableCached },
    { 0x0665, opcode::OP_Invalid },
    { 0x0666, opcode::OP_Invalid },
    { 0x0667, opcode::OP_Invalid },
    { 0x0668, opcode::OP_CastFieldObject },
    { 0x0669, opcode::OP_SafeSetVariableFieldCached },
    { 0x066A, opcode::OP_Invalid },
    { 0x066B, opcode::OP_Bit_Or },
    { 0x066C, opcode::OP_GetLevelObject },
    { 0x066D, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x066E, opcode::OP_GetUnsignedShort },
    { 0x066F, opcode::OP_Invalid },
    { 0x0670, opcode::OP_Vector },
    { 0x0671, opcode::OP_EndSwitch },
    { 0x0672, opcode::OP_GetUintptr },
    { 0x0673, opcode::OP_Invalid },
    { 0x0674, opcode::OP_ScriptThreadCall },
    { 0x0675, opcode::OP_WaitTillMatch },
    { 0x0676, opcode::OP_Invalid },
    { 0x0677, opcode::OP_Invalid },
    { 0x0678, opcode::OP_SelfEvalFieldVariable },
    { 0x0679, opcode::OP_Equal },
    { 0x067A, opcode::OP_Equal },
    { 0x067B, opcode::OP_Invalid },
    { 0x067C, opcode::OP_ScriptFunctionCallPointer },
    { 0x067D, opcode::OP_Invalid },
    { 0x067E, opcode::OP_LessThan },
    { 0x067F, opcode::OP_JumpOnFalse },
    { 0x0680, opcode::OP_JumpOnFalseExpr },
    { 0x0681, opcode::OP_Invalid },
    { 0x0682, opcode::OP_EvalArrayRef },
    { 0x0683, opcode::OP_Modulus },
    { 0x0684, opcode::OP_JumpOnTrueExpr },
    { 0x0685, opcode::OP_ProfileStop },
    { 0x0686, opcode::OP_GetString },
    { 0x0687, opcode::OP_Invalid },
    { 0x0688, opcode::OP_GetIString },
    { 0x0689, opcode::OP_ScriptThreadCallClass },
    { 0x068A, opcode::OP_Invalid },
    { 0x068B, opcode::OP_GetLevelObject },
    { 0x068C, opcode::OP_LevelEvalFieldVariableRef },
    { 0x068D, opcode::OP_ScriptThreadCallPointer },
    { 0x068E, opcode::OP_SelfEvalFieldVariableRef },
    { 0x068F, opcode::OP_Switch },
    { 0x0690, opcode::OP_Invalid },
    { 0x0691, opcode::OP_ScriptMethodCall },
    { 0x0692, opcode::OP_SetVariableField },
    { 0x0693, opcode::OP_Invalid },
    { 0x0694, opcode::OP_Invalid },
    { 0x0695, opcode::OP_DevblockBegin },
    { 0x0696, opcode::OP_GetWorld },
    { 0x0697, opcode::OP_Invalid },
    { 0x0698, opcode::OP_GetClasses },
    { 0x0699, opcode::OP_LevelEvalFieldVariableRef },
    { 0x069A, opcode::OP_GetAPIFunction },
    { 0x069B, opcode::OP_LessThan },
    { 0x069C, opcode::OP_ClearArray },
    { 0x069D, opcode::OP_Invalid },
    { 0x069E, opcode::OP_ShiftRight },
    { 0x069F, opcode::OP_LevelEvalFieldVariableRef },
    { 0x06A0, opcode::OP_Invalid },
    { 0x06A1, opcode::OP_Invalid },
    { 0x06A2, opcode::OP_Invalid },
    { 0x06A3, opcode::OP_GetAnim },
    { 0x06A4, opcode::OP_Invalid },
    { 0x06A5, opcode::OP_ScriptMethodCall },
    { 0x06A6, opcode::OP_Invalid },
    { 0x06A7, opcode::OP_SafeCreateLocalVariables },
    { 0x06A8, opcode::OP_Invalid },
    { 0x06A9, opcode::OP_GetUnsignedShort },
    { 0x06AA, opcode::OP_Plus },
    { 0x06AB, opcode::OP_Invalid },
    { 0x06AC, opcode::OP_GetNegUnsignedShort },
    { 0x06AD, opcode::OP_Bit_And },
    { 0x06AE, opcode::OP_Invalid },
    { 0x06AF, opcode::OP_GetFunction },
    { 0x06B0, opcode::OP_ScriptThreadCallClass },
    { 0x06B1, opcode::OP_Invalid },
    { 0x06B2, opcode::OP_Invalid },
    { 0x06B3, opcode::OP_GetFunction },
    { 0x06B4, opcode::OP_Switch },
    { 0x06B5, opcode::OP_GetWorld },
    { 0x06B6, opcode::OP_Invalid },
    { 0x06B7, opcode::OP_JumpOnFalse },
    { 0x06B8, opcode::OP_Invalid },
    { 0x06B9, opcode::OP_Invalid },
    { 0x06BA, opcode::OP_EvalLocalVariableCached },
    { 0x06BB, opcode::OP_New },
    { 0x06BC, opcode::OP_SuperEqual },
    { 0x06BD, opcode::OP_ScriptMethodCall },
    { 0x06BE, opcode::OP_Invalid },
    { 0x06BF, opcode::OP_GetWorldObject },
    { 0x06C0, opcode::OP_GetAnimation },
    { 0x06C1, opcode::OP_NextArrayKey },
    { 0x06C2, opcode::OP_GetLevelObject },
    { 0x06C3, opcode::OP_Jump },
    { 0x06C4, opcode::OP_GetZero },
    { 0x06C5, opcode::OP_LevelEvalFieldVariableRef },
    { 0x06C6, opcode::OP_GetString },
    { 0x06C7, opcode::OP_Invalid },
    { 0x06C8, opcode::OP_Invalid },
    { 0x06C9, opcode::OP_GetGame },
    { 0x06CA, opcode::OP_Invalid },
    { 0x06CB, opcode::OP_SelfEvalFieldVariable },
    { 0x06CC, opcode::OP_LevelEvalFieldVariable },
    { 0x06CD, opcode::OP_NextArrayKey },
    { 0x06CE, opcode::OP_GetGame },
    { 0x06CF, opcode::OP_Invalid },
    { 0x06D0, opcode::OP_SetVariableField },
    { 0x06D1, opcode::OP_Invalid },
    { 0x06D2, opcode::OP_JumpOnFalse },
    { 0x06D3, opcode::OP_Invalid },
    { 0x06D4, opcode::OP_EvalFieldVariableRef },
    { 0x06D5, opcode::OP_Invalid },
    { 0x06D6, opcode::OP_Invalid },
    { 0x06D7, opcode::OP_Wait },
    { 0x06D8, opcode::OP_GetVector },
    { 0x06D9, opcode::OP_Invalid },
    { 0x06DA, opcode::OP_Plus },
    { 0x06DB, opcode::OP_GetHash },
    { 0x06DC, opcode::OP_LevelEvalFieldVariable },
    { 0x06DD, opcode::OP_Inc },
    { 0x06DE, opcode::OP_GetGame },
    { 0x06DF, opcode::OP_GetAnim },
    { 0x06E0, opcode::OP_Invalid },
    { 0x06E1, opcode::OP_Vector },
    { 0x06E2, opcode::OP_Inc },
    { 0x06E3, opcode::OP_Invalid },
    { 0x06E4, opcode::OP_GetWorldObject },
    { 0x06E5, opcode::OP_EvalLocalVariableRefCached },
    { 0x06E6, opcode::OP_Invalid },
    { 0x06E7, opcode::OP_Invalid },
    { 0x06E8, opcode::OP_GetSelf },
    { 0x06E9, opcode::OP_Invalid },
    { 0x06EA, opcode::OP_WaitTillMatch },
    { 0x06EB, opcode::OP_JumpOnFalseExpr },
    { 0x06EC, opcode::OP_GetLevelObject },
    { 0x06ED, opcode::OP_Invalid },
    { 0x06EE, opcode::OP_JumpOnTrue },
    { 0x06EF, opcode::OP_CastFieldObject },
    { 0x06F0, opcode::OP_Invalid },
    { 0x06F1, opcode::OP_EvalArrayRef },
    { 0x06F2, opcode::OP_GetString },
    { 0x06F3, opcode::OP_GetTime },
    { 0x06F4, opcode::OP_Invalid },
    { 0x06F5, opcode::OP_GetTime },
    { 0x06F6, opcode::OP_RealWait },
    { 0x06F7, opcode::OP_Invalid },
    { 0x06F8, opcode::OP_Invalid },
    { 0x06F9, opcode::OP_Jump },
    { 0x06FA, opcode::OP_JumpOnFalseExpr },
    { 0x06FB, opcode::OP_LessThan },
    { 0x06FC, opcode::OP_Invalid },
    { 0x06FD, opcode::OP_Invalid },
    { 0x06FE, opcode::OP_WaitTill },
    { 0x06FF, opcode::OP_WaitTillFrameEnd },
    { 0x0700, opcode::OP_Invalid },
    { 0x0701, opcode::OP_Bit_Xor },
    { 0x0702, opcode::OP_Switch },
    { 0x0703, opcode::OP_Dec },
    { 0x0704, opcode::OP_ScriptFunctionCall },
    { 0x0705, opcode::OP_JumpOnFalseExpr },
    { 0x0706, opcode::OP_VectorConstant },
    { 0x0707, opcode::OP_Invalid },
    { 0x0708, opcode::OP_GetNegUnsignedShort },
    { 0x0709, opcode::OP_GetUnsignedShort },
    { 0x070A, opcode::OP_GetVector },
    { 0x070B, opcode::OP_Invalid },
    { 0x070C, opcode::OP_ScriptFunctionCall },
    { 0x070D, opcode::OP_GetLevelObject },
    { 0x070E, opcode::OP_SelfEvalFieldVariableRef },
    { 0x070F, opcode::OP_GetUnsignedShort },
    { 0x0710, opcode::OP_GetGameRef },
    { 0x0711, opcode::OP_SuperEqual },
    { 0x0712, opcode::OP_SuperNotEqual },
    { 0x0713, opcode::OP_Invalid },
    { 0x0714, opcode::OP_Invalid },
    { 0x0715, opcode::OP_LessThanOrEqualTo },
    { 0x0716, opcode::OP_GetNegUnsignedShort },
    { 0x0717, opcode::OP_GetUndefined },
    { 0x0718, opcode::OP_GetAnimation },
    { 0x0719, opcode::OP_GetGame },
    { 0x071A, opcode::OP_GetByte },
    { 0x071B, opcode::OP_Invalid },
    { 0x071C, opcode::OP_Minus },
    { 0x071D, opcode::OP_VectorScale },
    { 0x071E, opcode::OP_GetFloat },
    { 0x071F, opcode::OP_GetNegByte },
    { 0x0720, opcode::OP_IsDefined },
    { 0x0721, opcode::OP_ProfileStart },
    { 0x0722, opcode::OP_FirstArrayKey },
    { 0x0723, opcode::OP_Invalid },
    { 0x0724, opcode::OP_Invalid },
    { 0x0725, opcode::OP_GetLevel },
    { 0x0726, opcode::OP_Switch },
    { 0x0727, opcode::OP_GetClassesObject },
    { 0x0728, opcode::OP_ScriptMethodCallPointer },
    { 0x0729, opcode::OP_GetVector },
    { 0x072A, opcode::OP_Invalid },
    { 0x072B, opcode::OP_GetString },
    { 0x072C, opcode::OP_Invalid },
    { 0x072D, opcode::OP_VectorConstant },
    { 0x072E, opcode::OP_Invalid },
    { 0x072F, opcode::OP_ScriptMethodCallPointer },
    { 0x0730, opcode::OP_Invalid },
    { 0x0731, opcode::OP_GetByte },
    { 0x0732, opcode::OP_ClearArray },
    { 0x0733, opcode::OP_LessThan },
    { 0x0734, opcode::OP_Wait },
    { 0x0735, opcode::OP_ScriptMethodThreadCall },
    { 0x0736, opcode::OP_LevelEvalFieldVariable },
    { 0x0737, opcode::OP_Invalid },
    { 0x0738, opcode::OP_Dec },
    { 0x0739, opcode::OP_Minus },
    { 0x073A, opcode::OP_Invalid },
    { 0x073B, opcode::OP_IsDefined },
    { 0x073C, opcode::OP_Invalid },
    { 0x073D, opcode::OP_GetAnimObject },
    { 0x073E, opcode::OP_Invalid },
    { 0x073F, opcode::OP_Invalid },
    { 0x0740, opcode::OP_WaitTillFrameEnd },
    { 0x0741, opcode::OP_Invalid },
    { 0x0742, opcode::OP_EvalArray },
    { 0x0743, opcode::OP_GetIString },
    { 0x0744, opcode::OP_JumpOnTrueExpr },
    { 0x0745, opcode::OP_Invalid },
    { 0x0746, opcode::OP_GetAPIFunction },
    { 0x0747, opcode::OP_Invalid },
    { 0x0748, opcode::OP_Invalid },
    { 0x0749, opcode::OP_ProfileStart },
    { 0x074A, opcode::OP_Invalid },
    { 0x074B, opcode::OP_GetZero },
    { 0x074C, opcode::OP_Invalid },
    { 0x074D, opcode::OP_WaitTillMatch },
    { 0x074E, opcode::OP_SelfEvalFieldVariable },
    { 0x074F, opcode::OP_ScriptMethodCallPointer },
    { 0x0750, opcode::OP_Invalid },
    { 0x0751, opcode::OP_Invalid },
    { 0x0752, opcode::OP_Invalid },
    { 0x0753, opcode::OP_GetSelf },
    { 0x0754, opcode::OP_LevelEvalFieldVariableRef },
    { 0x0755, opcode::OP_GetUndefined },
    { 0x0756, opcode::OP_CastFieldObject },
    { 0x0757, opcode::OP_GetClasses },
    { 0x0758, opcode::OP_CastBool },
    { 0x0759, opcode::OP_Invalid },
    { 0x075A, opcode::OP_Invalid },
    { 0x075B, opcode::OP_GetUnsignedShort },
    { 0x075C, opcode::OP_EvalLocalVariableCached },
    { 0x075D, opcode::OP_GetAnim },
    { 0x075E, opcode::OP_Invalid },
    { 0x075F, opcode::OP_GetClasses },
    { 0x0760, opcode::OP_Invalid },
    { 0x0761, opcode::OP_Invalid },
    { 0x0762, opcode::OP_GetString },
    { 0x0763, opcode::OP_EndOn },
    { 0x0764, opcode::OP_Minus },
    { 0x0765, opcode::OP_Invalid },
    { 0x0766, opcode::OP_Invalid },
    { 0x0767, opcode::OP_EvalLocalVariableCached },
    { 0x0768, opcode::OP_GetUndefined },
    { 0x0769, opcode::OP_GetUnsignedShort },
    { 0x076A, opcode::OP_JumpOnFalse },
    { 0x076B, opcode::OP_Invalid },
    { 0x076C, opcode::OP_CallBuiltinMethod },
    { 0x076D, opcode::OP_GreaterThan },
    { 0x076E, opcode::OP_WaitTillFrameEnd },
    { 0x076F, opcode::OP_New },
    { 0x0770, opcode::OP_Invalid },
    { 0x0771, opcode::OP_EvalArray },
    { 0x0772, opcode::OP_Invalid },
    { 0x0773, opcode::OP_Invalid },
    { 0x0774, opcode::OP_Bit_Xor },
    { 0x0775, opcode::OP_VectorConstant },
    { 0x0776, opcode::OP_WaitTillMatch },
    { 0x0777, opcode::OP_GetUndefined },
    { 0x0778, opcode::OP_Bit_Xor },
    { 0x0779, opcode::OP_Divide },
    { 0x077A, opcode::OP_EndSwitch },
    { 0x077B, opcode::OP_GetAnim },
    { 0x077C, opcode::OP_ClearArray },
    { 0x077D, opcode::OP_EvalArray },
    { 0x077E, opcode::OP_Invalid },
    { 0x077F, opcode::OP_EvalFieldVariableRef },
    { 0x0780, opcode::OP_Invalid },
    { 0x0781, opcode::OP_LevelEvalFieldVariableRef },
    { 0x0782, opcode::OP_Invalid },
    { 0x0783, opcode::OP_GetFloat },
    { 0x0784, opcode::OP_Divide },
    { 0x0785, opcode::OP_JumpOnFalse },
    { 0x0786, opcode::OP_Invalid },
    { 0x0787, opcode::OP_GetSelfObject },
    { 0x0788, opcode::OP_Bit_Or },
    { 0x0789, opcode::OP_GetClassesObject },
    { 0x078A, opcode::OP_Invalid },
    { 0x078B, opcode::OP_Invalid },
    { 0x078C, opcode::OP_Invalid },
    { 0x078D, opcode::OP_JumpOnTrue },
    { 0x078E, opcode::OP_GetFloat },
    { 0x078F, opcode::OP_Plus },
    { 0x0790, opcode::OP_SelfEvalFieldVariable },
    { 0x0791, opcode::OP_BoolComplement },
    { 0x0792, opcode::OP_GetSelf },
    { 0x0793, opcode::OP_Invalid },
    { 0x0794, opcode::OP_New },
    { 0x0795, opcode::OP_GetAnimObject },
    { 0x0796, opcode::OP_Minus },
    { 0x0797, opcode::OP_EvalLocalVariableCached },
    { 0x0798, opcode::OP_GetSelf },
    { 0x0799, opcode::OP_ScriptMethodThreadCall },
    { 0x079A, opcode::OP_ProfileStop },
    { 0x079B, opcode::OP_ScriptMethodCallPointer },
    { 0x079C, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x079D, opcode::OP_IsDefined },
    { 0x079E, opcode::OP_EndOn },
    { 0x079F, opcode::OP_GetAnimation },
    { 0x07A0, opcode::OP_SuperEqual },
    { 0x07A1, opcode::OP_Inc },
    { 0x07A2, opcode::OP_Invalid },
    { 0x07A3, opcode::OP_EndSwitch },
    { 0x07A4, opcode::OP_Invalid },
    { 0x07A5, opcode::OP_GreaterThan },
    { 0x07A6, opcode::OP_EvalArray },
    { 0x07A7, opcode::OP_ScriptMethodThreadCall },
    { 0x07A8, opcode::OP_GetWorld },
    { 0x07A9, opcode::OP_SafeSetVariableFieldCached },
    { 0x07AA, opcode::OP_GetFloat },
    { 0x07AB, opcode::OP_GetClassesObject },
    { 0x07AC, opcode::OP_Invalid },
    { 0x07AD, opcode::OP_CastBool },
    { 0x07AE, opcode::OP_GetAnim },
    { 0x07AF, opcode::OP_EvalArrayRef },
    { 0x07B0, opcode::OP_EvalFieldVariableRef },
    { 0x07B1, opcode::OP_SafeCreateLocalVariables },
    { 0x07B2, opcode::OP_SuperNotEqual },
    { 0x07B3, opcode::OP_Divide },
    { 0x07B4, opcode::OP_LevelEvalFieldVariable },
    { 0x07B5, opcode::OP_Invalid },
    { 0x07B6, opcode::OP_Invalid },
    { 0x07B7, opcode::OP_Invalid },
    { 0x07B8, opcode::OP_Invalid },
    { 0x07B9, opcode::OP_Invalid },
    { 0x07BA, opcode::OP_ScriptFunctionCallClass },
    { 0x07BB, opcode::OP_Invalid },
    { 0x07BC, opcode::OP_Invalid },
    { 0x07BD, opcode::OP_EvalArrayRef },
    { 0x07BE, opcode::OP_GetByte },
    { 0x07BF, opcode::OP_Invalid },
    { 0x07C0, opcode::OP_CastFieldObject },
    { 0x07C1, opcode::OP_JumpOnFalseExpr },
    { 0x07C2, opcode::OP_Modulus },
    { 0x07C3, opcode::OP_VectorScale },
    { 0x07C4, opcode::OP_ScriptMethodCallPointer },
    { 0x07C5, opcode::OP_LessThan },
    { 0x07C6, opcode::OP_Invalid },
    { 0x07C7, opcode::OP_Invalid },
    { 0x07C8, opcode::OP_ClearFieldVariable },
    { 0x07C9, opcode::OP_GetFunction },
    { 0x07CA, opcode::OP_Invalid },
    { 0x07CB, opcode::OP_Invalid },
    { 0x07CC, opcode::OP_LessThanOrEqualTo },
    { 0x07CD, opcode::OP_ScriptFunctionCallClass },
    { 0x07CE, opcode::OP_ShiftRight },
    { 0x07CF, opcode::OP_GetWorld },
    { 0x07D0, opcode::OP_GetGame },
    { 0x07D1, opcode::OP_GetLevel },
    { 0x07D2, opcode::OP_GetTime },
    { 0x07D3, opcode::OP_VectorScale },
    { 0x07D4, opcode::OP_Minus },
    { 0x07D5, opcode::OP_ProfileStart },
    { 0x07D6, opcode::OP_Vector },
    { 0x07D7, opcode::OP_EvalArrayRef },
    { 0x07D8, opcode::OP_Plus },
    { 0x07D9, opcode::OP_Invalid },
    { 0x07DA, opcode::OP_Invalid },
    { 0x07DB, opcode::OP_New },
    { 0x07DC, opcode::OP_ShiftRight },
    { 0x07DD, opcode::OP_ClearFieldVariable },
    { 0x07DE, opcode::OP_Invalid },
    { 0x07DF, opcode::OP_Dec },
    { 0x07E0, opcode::OP_Invalid },
    { 0x07E1, opcode::OP_Invalid },
    { 0x07E2, opcode::OP_EvalFieldVariableRef },
    { 0x07E3, opcode::OP_GetNegUnsignedShort },
    { 0x07E4, opcode::OP_Invalid },
    { 0x07E5, opcode::OP_SuperEqual },
    { 0x07E6, opcode::OP_GetGame },
    { 0x07E7, opcode::OP_Invalid },
    { 0x07E8, opcode::OP_GetUnsignedShort },
    { 0x07E9, opcode::OP_ScriptFunctionCall },
    { 0x07EA, opcode::OP_EvalArrayRef },
    { 0x07EB, opcode::OP_CallBuiltinMethod },
    { 0x07EC, opcode::OP_Invalid },
    { 0x07ED, opcode::OP_ScriptFunctionCallClass },
    { 0x07EE, opcode::OP_ProfileStop },
    { 0x07EF, opcode::OP_Invalid },
    { 0x07F0, opcode::OP_Notify },
    { 0x07F1, opcode::OP_GetByte },
    { 0x07F2, opcode::OP_GetNegUnsignedShort },
    { 0x07F3, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x07F4, opcode::OP_GetVector },
    { 0x07F5, opcode::OP_Invalid },
    { 0x07F6, opcode::OP_GetAPIFunction },
    { 0x07F7, opcode::OP_GetIString },
    { 0x07F8, opcode::OP_CastBool },
    { 0x07F9, opcode::OP_EndOn },
    { 0x07FA, opcode::OP_GetClasses },
    { 0x07FB, opcode::OP_Invalid },
    { 0x07FC, opcode::OP_JumpOnFalseExpr },
    { 0x07FD, opcode::OP_ScriptThreadCall },
    { 0x07FE, opcode::OP_VectorConstant },
    { 0x07FF, opcode::OP_Invalid },
    { 0x0800, opcode::OP_SuperEqual },
    { 0x0801, opcode::OP_Invalid },
    { 0x0802, opcode::OP_Inc },
    { 0x0803, opcode::OP_WaitTillMatch },
    { 0x0804, opcode::OP_Invalid },
    { 0x0805, opcode::OP_EvalArray },
    { 0x0806, opcode::OP_DevblockBegin },
    { 0x0807, opcode::OP_Divide },
    { 0x0808, opcode::OP_EvalFieldVariableRef },
    { 0x0809, opcode::OP_GetAnim },
    { 0x080A, opcode::OP_Invalid },
    { 0x080B, opcode::OP_GetIString },
    { 0x080C, opcode::OP_SafeCreateLocalVariables },
    { 0x080D, opcode::OP_SuperNotEqual },
    { 0x080E, opcode::OP_Invalid },
    { 0x080F, opcode::OP_Invalid },
    { 0x0810, opcode::OP_JumpOnTrue },
    { 0x0811, opcode::OP_EndOn },
    { 0x0812, opcode::OP_Invalid },
    { 0x0813, opcode::OP_ProfileStop },
    { 0x0814, opcode::OP_GetClassesObject },
    { 0x0815, opcode::OP_EvalLocalVariableRefCached },
    { 0x0816, opcode::OP_Invalid },
    { 0x0817, opcode::OP_EndSwitch },
    { 0x0818, opcode::OP_Invalid },
    { 0x0819, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x081A, opcode::OP_EvalArrayRef },
    { 0x081B, opcode::OP_GetUnsignedShort },
    { 0x081C, opcode::OP_Invalid },
    { 0x081D, opcode::OP_ClearFieldVariable },
    { 0x081E, opcode::OP_ScriptMethodThreadCall },
    { 0x081F, opcode::OP_SelfEvalFieldVariable },
    { 0x0820, opcode::OP_Invalid },
    { 0x0821, opcode::OP_Invalid },
    { 0x0822, opcode::OP_ScriptThreadCallPointer },
    { 0x0823, opcode::OP_Invalid },
    { 0x0824, opcode::OP_Invalid },
    { 0x0825, opcode::OP_ClearArray },
    { 0x0826, opcode::OP_Invalid },
    { 0x0827, opcode::OP_ClearFieldVariable },
    { 0x0828, opcode::OP_GetAPIFunction },
    { 0x0829, opcode::OP_ScriptFunctionCallClass },
    { 0x082A, opcode::OP_Invalid },
    { 0x082B, opcode::OP_FirstArrayKey },
    { 0x082C, opcode::OP_ScriptMethodCall },
    { 0x082D, opcode::OP_GetClassesObject },
    { 0x082E, opcode::OP_Equal },
    { 0x082F, opcode::OP_SelfEvalFieldVariable },
    { 0x0830, opcode::OP_Invalid },
    { 0x0831, opcode::OP_EvalArrayRef },
    { 0x0832, opcode::OP_Invalid },
    { 0x0833, opcode::OP_GetAnimObject },
    { 0x0834, opcode::OP_Invalid },
    { 0x0835, opcode::OP_EvalFieldVariableRef },
    { 0x0836, opcode::OP_ScriptMethodThreadCall },
    { 0x0837, opcode::OP_Notify },
    { 0x0838, opcode::OP_Invalid },
    { 0x0839, opcode::OP_Dec },
    { 0x083A, opcode::OP_WaitTillMatch },
    { 0x083B, opcode::OP_Invalid },
    { 0x083C, opcode::OP_Invalid },
    { 0x083D, opcode::OP_Invalid },
    { 0x083E, opcode::OP_SafeCreateLocalVariables },
    { 0x083F, opcode::OP_DecTop },
    { 0x0840, opcode::OP_Jump },
    { 0x0841, opcode::OP_Invalid },
    { 0x0842, opcode::OP_GetByte },
    { 0x0843, opcode::OP_Invalid },
    { 0x0844, opcode::OP_RealWait },
    { 0x0845, opcode::OP_EndOn },
    { 0x0846, opcode::OP_Invalid },
    { 0x0847, opcode::OP_Invalid },
    { 0x0848, opcode::OP_GetClasses },
    { 0x0849, opcode::OP_EvalLocalVariableCached },
    { 0x084A, opcode::OP_GetHash },
    { 0x084B, opcode::OP_SafeDecTop },
    { 0x084C, opcode::OP_ShiftRight },
    { 0x084D, opcode::OP_WaitTill },
    { 0x084E, opcode::OP_Vector },
    { 0x084F, opcode::OP_Inc },
    { 0x0850, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x0851, opcode::OP_ScriptFunctionCall },
    { 0x0852, opcode::OP_Invalid },
    { 0x0853, opcode::OP_LessThan },
    { 0x0854, opcode::OP_SelfEvalFieldVariableRef },
    { 0x0855, opcode::OP_Invalid },
    { 0x0856, opcode::OP_LessThan },
    { 0x0857, opcode::OP_GetByte },
    { 0x0858, opcode::OP_EmptyArray },
    { 0x0859, opcode::OP_SafeDecTop },
    { 0x085A, opcode::OP_GetNegUnsignedShort },
    { 0x085B, opcode::OP_GetUnsignedShort },
    { 0x085C, opcode::OP_Invalid },
    { 0x085D, opcode::OP_Invalid },
    { 0x085E, opcode::OP_Invalid },
    { 0x085F, opcode::OP_Invalid },
    { 0x0860, opcode::OP_EvalArrayRef },
    { 0x0861, opcode::OP_GetSelf },
    { 0x0862, opcode::OP_Invalid },
    { 0x0863, opcode::OP_Invalid },
    { 0x0864, opcode::OP_Inc },
    { 0x0865, opcode::OP_DecTop },
    { 0x0866, opcode::OP_Invalid },
    { 0x0867, opcode::OP_Invalid },
    { 0x0868, opcode::OP_GetLevelObject },
    { 0x0869, opcode::OP_Invalid },
    { 0x086A, opcode::OP_Invalid },
    { 0x086B, opcode::OP_Invalid },
    { 0x086C, opcode::OP_Invalid },
    { 0x086D, opcode::OP_GetAnim },
    { 0x086E, opcode::OP_Multiply },
    { 0x086F, opcode::OP_Invalid },
    { 0x0870, opcode::OP_Dec },
    { 0x0871, opcode::OP_ShiftLeft },
    { 0x0872, opcode::OP_ScriptThreadCallClass },
    { 0x0873, opcode::OP_GetString },
    { 0x0874, opcode::OP_Equal },
    { 0x0875, opcode::OP_Invalid },
    { 0x0876, opcode::OP_New },
    { 0x0877, opcode::OP_Invalid },
    { 0x0878, opcode::OP_Invalid },
    { 0x0879, opcode::OP_IsDefined },
    { 0x087A, opcode::OP_GreaterThan },
    { 0x087B, opcode::OP_LevelEvalFieldVariable },
    { 0x087C, opcode::OP_Notify },
    { 0x087D, opcode::OP_Notify },
    { 0x087E, opcode::OP_Invalid },
    { 0x087F, opcode::OP_GetNegUnsignedShort },
    { 0x0880, opcode::OP_Invalid },
    { 0x0881, opcode::OP_Invalid },
    { 0x0882, opcode::OP_LevelEvalFieldVariableRef },
    { 0x0883, opcode::OP_Invalid },
    { 0x0884, opcode::OP_Invalid },
    { 0x0885, opcode::OP_SelfEvalFieldVariable },
    { 0x0886, opcode::OP_Invalid },
    { 0x0887, opcode::OP_SelfEvalFieldVariable },
    { 0x0888, opcode::OP_Invalid },
    { 0x0889, opcode::OP_Modulus },
    { 0x088A, opcode::OP_EvalLocalVariableCached },
    { 0x088B, opcode::OP_CastBool },
    { 0x088C, opcode::OP_Bit_Or },
    { 0x088D, opcode::OP_GetZero },
    { 0x088E, opcode::OP_Inc },
    { 0x088F, opcode::OP_ScriptThreadCallClass },
    { 0x0890, opcode::OP_EvalLocalVariableCached },
    { 0x0891, opcode::OP_GetGame },
    { 0x0892, opcode::OP_Invalid },
    { 0x0893, opcode::OP_WaitTill },
    { 0x0894, opcode::OP_GetIString },
    { 0x0895, opcode::OP_RealWait },
    { 0x0896, opcode::OP_EvalLocalVariableRefCached },
    { 0x0897, opcode::OP_GetVector },
    { 0x0898, opcode::OP_ScriptThreadCallClass },
    { 0x0899, opcode::OP_GreaterThanOrEqualTo },
    { 0x089A, opcode::OP_Invalid },
    { 0x089B, opcode::OP_Invalid },
    { 0x089C, opcode::OP_ScriptMethodCall },
    { 0x089D, opcode::OP_Invalid },
    { 0x089E, opcode::OP_Invalid },
    { 0x089F, opcode::OP_Jump },
    { 0x08A0, opcode::OP_GetGame },
    { 0x08A1, opcode::OP_GetGame },
    { 0x08A2, opcode::OP_Invalid },
    { 0x08A3, opcode::OP_GetSelf },
    { 0x08A4, opcode::OP_GetAnim },
    { 0x08A5, opcode::OP_Invalid },
    { 0x08A6, opcode::OP_EvalLocalVariableCached },
    { 0x08A7, opcode::OP_ScriptThreadCallClass },
    { 0x08A8, opcode::OP_ScriptFunctionCallClass },
    { 0x08A9, opcode::OP_SelfEvalFieldVariable },
    { 0x08AA, opcode::OP_GetAnimation },
    { 0x08AB, opcode::OP_GetUndefined },
    { 0x08AC, opcode::OP_Switch },
    { 0x08AD, opcode::OP_SafeDecTop },
    { 0x08AE, opcode::OP_Invalid },
    { 0x08AF, opcode::OP_Invalid },
    { 0x08B0, opcode::OP_Multiply },
    { 0x08B1, opcode::OP_Invalid },
    { 0x08B2, opcode::OP_Invalid },
    { 0x08B3, opcode::OP_BoolComplement },
    { 0x08B4, opcode::OP_Inc },
    { 0x08B5, opcode::OP_Invalid },
    { 0x08B6, opcode::OP_ClearArray },
    { 0x08B7, opcode::OP_JumpOnTrue },
    { 0x08B8, opcode::OP_Equal },
    { 0x08B9, opcode::OP_Invalid },
    { 0x08BA, opcode::OP_GetAnimation },
    { 0x08BB, opcode::OP_Invalid },
    { 0x08BC, opcode::OP_IsDefined },
    { 0x08BD, opcode::OP_GetGame },
    { 0x08BE, opcode::OP_WaitTill },
    { 0x08BF, opcode::OP_GetZero },
    { 0x08C0, opcode::OP_GetFunction },
    { 0x08C1, opcode::OP_Invalid },
    { 0x08C2, opcode::OP_CallBuiltinMethod },
    { 0x08C3, opcode::OP_GreaterThan },
    { 0x08C4, opcode::OP_Invalid },
    { 0x08C5, opcode::OP_GetZero },
    { 0x08C6, opcode::OP_Invalid },
    { 0x08C7, opcode::OP_GetString },
    { 0x08C8, opcode::OP_RealWait },
    { 0x08C9, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x08CA, opcode::OP_Invalid },
    { 0x08CB, opcode::OP_Wait },
    { 0x08CC, opcode::OP_ShiftLeft },
    { 0x08CD, opcode::OP_CastFieldObject },
    { 0x08CE, opcode::OP_Invalid },
    { 0x08CF, opcode::OP_JumpOnFalseExpr },
    { 0x08D0, opcode::OP_Invalid },
    { 0x08D1, opcode::OP_GetAnim },
    { 0x08D2, opcode::OP_Invalid },
    { 0x08D3, opcode::OP_GetUintptr },
    { 0x08D4, opcode::OP_Invalid },
    { 0x08D5, opcode::OP_Invalid },
    { 0x08D6, opcode::OP_DevblockBegin },
    { 0x08D7, opcode::OP_ScriptFunctionCallClass },
    { 0x08D8, opcode::OP_Invalid },
    { 0x08D9, opcode::OP_Invalid },
    { 0x08DA, opcode::OP_Invalid },
    { 0x08DB, opcode::OP_GetByte },
    { 0x08DC, opcode::OP_JumpOnFalse },
    { 0x08DD, opcode::OP_Invalid },
    { 0x08DE, opcode::OP_ProfileStart },
    { 0x08DF, opcode::OP_ScriptThreadCallClass },
    { 0x08E0, opcode::OP_Invalid },
    { 0x08E1, opcode::OP_Notify },
    { 0x08E2, opcode::OP_GetIString },
    { 0x08E3, opcode::OP_Return },
    { 0x08E4, opcode::OP_EvalArrayRef },
    { 0x08E5, opcode::OP_GetString },
    { 0x08E6, opcode::OP_BoolNot },
    { 0x08E7, opcode::OP_BoolComplement },
    { 0x08E8, opcode::OP_JumpOnFalse },
    { 0x08E9, opcode::OP_ScriptMethodThreadCall },
    { 0x08EA, opcode::OP_GetAnimObject },
    { 0x08EB, opcode::OP_Bit_Xor },
    { 0x08EC, opcode::OP_NotEqual },
    { 0x08ED, opcode::OP_Invalid },
    { 0x08EE, opcode::OP_Bit_Or },
    { 0x08EF, opcode::OP_CastBool },
    { 0x08F0, opcode::OP_ProfileStart },
    { 0x08F1, opcode::OP_Invalid },
    { 0x08F2, opcode::OP_Return },
    { 0x08F3, opcode::OP_Invalid },
    { 0x08F4, opcode::OP_EvalFieldVariableRef },
    { 0x08F5, opcode::OP_GetInteger },
    { 0x08F6, opcode::OP_GetInteger },
    { 0x08F7, opcode::OP_GetHash },
    { 0x08F8, opcode::OP_Invalid },
    { 0x08F9, opcode::OP_Equal },
    { 0x08FA, opcode::OP_VectorConstant },
    { 0x08FB, opcode::OP_Invalid },
    { 0x08FC, opcode::OP_SafeSetVariableFieldCached },
    { 0x08FD, opcode::OP_Invalid },
    { 0x08FE, opcode::OP_GetNegByte },
    { 0x08FF, opcode::OP_Invalid },
    { 0x0900, opcode::OP_Invalid },
    { 0x0901, opcode::OP_Invalid },
    { 0x0902, opcode::OP_GetNegByte },
    { 0x0903, opcode::OP_GetAnimation },
    { 0x0904, opcode::OP_Invalid },
    { 0x0905, opcode::OP_Multiply },
    { 0x0906, opcode::OP_Invalid },
    { 0x0907, opcode::OP_Invalid },
    { 0x0908, opcode::OP_Invalid },
    { 0x0909, opcode::OP_JumpOnFalse },
    { 0x090A, opcode::OP_Invalid },
    { 0x090B, opcode::OP_SelfEvalFieldVariable },
    { 0x090C, opcode::OP_Invalid },
    { 0x090D, opcode::OP_Invalid },
    { 0x090E, opcode::OP_ScriptMethodThreadCall },
    { 0x090F, opcode::OP_GetGame },
    { 0x0910, opcode::OP_LevelEvalFieldVariable },
    { 0x0911, opcode::OP_JumpOnTrueExpr },
    { 0x0912, opcode::OP_IsDefined },
    { 0x0913, opcode::OP_GetUnsignedShort },
    { 0x0914, opcode::OP_Invalid },
    { 0x0915, opcode::OP_Invalid },
    { 0x0916, opcode::OP_GetFloat },
    { 0x0917, opcode::OP_JumpOnTrue },
    { 0x0918, opcode::OP_Invalid },
    { 0x0919, opcode::OP_GetUintptr },
    { 0x091A, opcode::OP_GetNegByte },
    { 0x091B, opcode::OP_Invalid },
    { 0x091C, opcode::OP_SuperNotEqual },
    { 0x091D, opcode::OP_EvalFieldVariable },
    { 0x091E, opcode::OP_Modulus },
    { 0x091F, opcode::OP_Invalid },
    { 0x0920, opcode::OP_Notify },
    { 0x0921, opcode::OP_ClearArray },
    { 0x0922, opcode::OP_LessThan },
    { 0x0923, opcode::OP_Minus },
    { 0x0924, opcode::OP_GetZero },
    { 0x0925, opcode::OP_Invalid },
    { 0x0926, opcode::OP_GetTime },
    { 0x0927, opcode::OP_GetIString },
    { 0x0928, opcode::OP_EvalFieldVariable },
    { 0x0929, opcode::OP_GetSelf },
    { 0x092A, opcode::OP_SafeDecTop },
    { 0x092B, opcode::OP_Invalid },
    { 0x092C, opcode::OP_EmptyArray },
    { 0x092D, opcode::OP_JumpOnTrueExpr },
    { 0x092E, opcode::OP_ScriptMethodCall },
    { 0x092F, opcode::OP_LevelEvalFieldVariableRef },
    { 0x0930, opcode::OP_GetNegByte },
    { 0x0931, opcode::OP_ScriptMethodCall },
    { 0x0932, opcode::OP_Invalid },
    { 0x0933, opcode::OP_BoolNot },
    { 0x0934, opcode::OP_WaitTillFrameEnd },
    { 0x0935, opcode::OP_NotEqual },
    { 0x0936, opcode::OP_Invalid },
    { 0x0937, opcode::OP_Invalid },
    { 0x0938, opcode::OP_Switch },
    { 0x0939, opcode::OP_Invalid },
    { 0x093A, opcode::OP_Invalid },
    { 0x093B, opcode::OP_Inc },
    { 0x093C, opcode::OP_GetSelfObject },
    { 0x093D, opcode::OP_Invalid },
    { 0x093E, opcode::OP_GetClasses },
    { 0x093F, opcode::OP_GetUintptr },
    { 0x0940, opcode::OP_EvalFieldVariableRef },
    { 0x0941, opcode::OP_ClearFieldVariable },
    { 0x0942, opcode::OP_Invalid },
    { 0x0943, opcode::OP_GetInteger },
    { 0x0944, opcode::OP_Invalid },
    { 0x0945, opcode::OP_Jump },
    { 0x0946, opcode::OP_EvalFieldVariable },
    { 0x0947, opcode::OP_Invalid },
    { 0x0948, opcode::OP_WaitTill },
    { 0x0949, opcode::OP_GetUnsignedShort },
    { 0x094A, opcode::OP_GetFunction },
    { 0x094B, opcode::OP_GetGameRef },
    { 0x094C, opcode::OP_Invalid },
    { 0x094D, opcode::OP_Equal },
    { 0x094E, opcode::OP_Vector },
    { 0x094F, opcode::OP_GetHash },
    { 0x0950, opcode::OP_SetVariableField },
    { 0x0951, opcode::OP_GetInteger },
    { 0x0952, opcode::OP_Invalid },
    { 0x0953, opcode::OP_EndSwitch },
    { 0x0954, opcode::OP_SuperNotEqual },
    { 0x0955, opcode::OP_CastBool },
    { 0x0956, opcode::OP_Invalid },
    { 0x0957, opcode::OP_GreaterThan },
    { 0x0958, opcode::OP_SafeCreateLocalVariables },
    { 0x0959, opcode::OP_ScriptMethodThreadCall },
    { 0x095A, opcode::OP_ProfileStop },
    { 0x095B, opcode::OP_EvalFieldVariableRef },
    { 0x095C, opcode::OP_Invalid },
    { 0x095D, opcode::OP_Invalid },
    { 0x095E, opcode::OP_LessThanOrEqualTo },
    { 0x095F, opcode::OP_GetGame },
    { 0x0960, opcode::OP_Invalid },
    { 0x0961, opcode::OP_GetByte },
    { 0x0962, opcode::OP_Invalid },
    { 0x0963, opcode::OP_GetSelf },
    { 0x0964, opcode::OP_ScriptMethodCall },
    { 0x0965, opcode::OP_Invalid },
    { 0x0966, opcode::OP_GetNegUnsignedShort },
    { 0x0967, opcode::OP_GetString },
    { 0x0968, opcode::OP_LessThanOrEqualTo },
    { 0x0969, opcode::OP_ProfileStop },
    { 0x096A, opcode::OP_GetHash },
    { 0x096B, opcode::OP_GetWorldObject },
    { 0x096C, opcode::OP_VectorConstant },
    { 0x096D, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x096E, opcode::OP_ScriptMethodThreadCall },
    { 0x096F, opcode::OP_Switch },
    { 0x0970, opcode::OP_VectorConstant },
    { 0x0971, opcode::OP_GreaterThanOrEqualTo },
    { 0x0972, opcode::OP_LessThan },
    { 0x0973, opcode::OP_JumpOnTrue },
    { 0x0974, opcode::OP_Invalid },
    { 0x0975, opcode::OP_ScriptFunctionCallClass },
    { 0x0976, opcode::OP_Invalid },
    { 0x0977, opcode::OP_Invalid },
    { 0x0978, opcode::OP_GetAnimation },
    { 0x0979, opcode::OP_ClearFieldVariable },
    { 0x097A, opcode::OP_Invalid },
    { 0x097B, opcode::OP_SetVariableField },
    { 0x097C, opcode::OP_Invalid },
    { 0x097D, opcode::OP_LessThan },
    { 0x097E, opcode::OP_Invalid },
    { 0x097F, opcode::OP_GetTime },
    { 0x0980, opcode::OP_JumpOnFalse },
    { 0x0981, opcode::OP_Invalid },
    { 0x0982, opcode::OP_GetInteger },
    { 0x0983, opcode::OP_GetInteger },
    { 0x0984, opcode::OP_EndOn },
    { 0x0985, opcode::OP_SafeSetVariableFieldCached },
    { 0x0986, opcode::OP_ProfileStart },
    { 0x0987, opcode::OP_FirstArrayKey },
    { 0x0988, opcode::OP_IsDefined },
    { 0x0989, opcode::OP_Invalid },
    { 0x098A, opcode::OP_Return },
    { 0x098B, opcode::OP_Inc },
    { 0x098C, opcode::OP_EvalLocalVariableCached },
    { 0x098D, opcode::OP_CastBool },
    { 0x098E, opcode::OP_EvalLocalVariableRefCached },
    { 0x098F, opcode::OP_ScriptMethodCallPointer },
    { 0x0990, opcode::OP_Multiply },
    { 0x0991, opcode::OP_Invalid },
    { 0x0992, opcode::OP_GetClasses },
    { 0x0993, opcode::OP_GetAnimObject },
    { 0x0994, opcode::OP_Minus },
    { 0x0995, opcode::OP_GetSelf },
    { 0x0996, opcode::OP_Invalid },
    { 0x0997, opcode::OP_GetGameRef },
    { 0x0998, opcode::OP_SuperNotEqual },
    { 0x0999, opcode::OP_Invalid },
    { 0x099A, opcode::OP_GetHash },
    { 0x099B, opcode::OP_EvalLocalVariableRefCached },
    { 0x099C, opcode::OP_Invalid },
    { 0x099D, opcode::OP_Invalid },
    { 0x099E, opcode::OP_Vector },
    { 0x099F, opcode::OP_ClearFieldVariable },
    { 0x09A0, opcode::OP_DevblockBegin },
    { 0x09A1, opcode::OP_Invalid },
    { 0x09A2, opcode::OP_Invalid },
    { 0x09A3, opcode::OP_Plus },
    { 0x09A4, opcode::OP_GetTime },
    { 0x09A5, opcode::OP_Divide },
    { 0x09A6, opcode::OP_Invalid },
    { 0x09A7, opcode::OP_BoolNot },
    { 0x09A8, opcode::OP_GetLevelObject },
    { 0x09A9, opcode::OP_SizeOf },
    { 0x09AA, opcode::OP_GetGame },
    { 0x09AB, opcode::OP_Invalid },
    { 0x09AC, opcode::OP_Invalid },
    { 0x09AD, opcode::OP_LevelEvalFieldVariable },
    { 0x09AE, opcode::OP_GetUnsignedShort },
    { 0x09AF, opcode::OP_GetAnim },
    { 0x09B0, opcode::OP_SuperNotEqual },
    { 0x09B1, opcode::OP_ProfileStop },
    { 0x09B2, opcode::OP_JumpOnTrueExpr },
    { 0x09B3, opcode::OP_JumpOnFalse },
    { 0x09B4, opcode::OP_GetZero },
    { 0x09B5, opcode::OP_Multiply },
    { 0x09B6, opcode::OP_Invalid },
    { 0x09B7, opcode::OP_SetVariableField },
    { 0x09B8, opcode::OP_GetGame },
    { 0x09B9, opcode::OP_GetFloat },
    { 0x09BA, opcode::OP_ScriptFunctionCallClass },
    { 0x09BB, opcode::OP_EvalLocalVariableCached },
    { 0x09BC, opcode::OP_GreaterThanOrEqualTo },
    { 0x09BD, opcode::OP_GreaterThanOrEqualTo },
    { 0x09BE, opcode::OP_Invalid },
    { 0x09BF, opcode::OP_Invalid },
    { 0x09C0, opcode::OP_GetInteger },
    { 0x09C1, opcode::OP_LevelEvalFieldVariable },
    { 0x09C2, opcode::OP_ScriptMethodCall },
    { 0x09C3, opcode::OP_EndOn },
    { 0x09C4, opcode::OP_GetIString },
    { 0x09C5, opcode::OP_GreaterThan },
    { 0x09C6, opcode::OP_WaitTill },
    { 0x09C7, opcode::OP_Equal },
    { 0x09C8, opcode::OP_WaitTill },
    { 0x09C9, opcode::OP_Invalid },
    { 0x09CA, opcode::OP_Invalid },
    { 0x09CB, opcode::OP_CastBool },
    { 0x09CC, opcode::OP_Bit_Or },
    { 0x09CD, opcode::OP_DecTop },
    { 0x09CE, opcode::OP_ClearArray },
    { 0x09CF, opcode::OP_Invalid },
    { 0x09D0, opcode::OP_Invalid },
    { 0x09D1, opcode::OP_Invalid },
    { 0x09D2, opcode::OP_Invalid },
    { 0x09D3, opcode::OP_SafeDecTop },
    { 0x09D4, opcode::OP_CastFieldObject },
    { 0x09D5, opcode::OP_Bit_And },
    { 0x09D6, opcode::OP_Invalid },
    { 0x09D7, opcode::OP_EvalFieldVariableRef },
    { 0x09D8, opcode::OP_EvalArray },
    { 0x09D9, opcode::OP_EvalLocalVariableRefCached },
    { 0x09DA, opcode::OP_Invalid },
    { 0x09DB, opcode::OP_SizeOf },
    { 0x09DC, opcode::OP_LessThan },
    { 0x09DD, opcode::OP_EvalFieldVariableRef },
    { 0x09DE, opcode::OP_Invalid },
    { 0x09DF, opcode::OP_WaitTillMatch },
    { 0x09E0, opcode::OP_Invalid },
    { 0x09E1, opcode::OP_Invalid },
    { 0x09E2, opcode::OP_New },
    { 0x09E3, opcode::OP_Invalid },
    { 0x09E4, opcode::OP_Invalid },
    { 0x09E5, opcode::OP_Invalid },
    { 0x09E6, opcode::OP_Invalid },
    { 0x09E7, opcode::OP_Invalid },
    { 0x09E8, opcode::OP_LevelEvalFieldVariableRef },
    { 0x09E9, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x09EA, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x09EB, opcode::OP_GetUintptr },
    { 0x09EC, opcode::OP_ScriptMethodThreadCall },
    { 0x09ED, opcode::OP_Bit_Or },
    { 0x09EE, opcode::OP_ShiftLeft },
    { 0x09EF, opcode::OP_EndOn },
    { 0x09F0, opcode::OP_VectorConstant },
    { 0x09F1, opcode::OP_GetLevelObject },
    { 0x09F2, opcode::OP_GetGame },
    { 0x09F3, opcode::OP_ScriptFunctionCallPointer },
    { 0x09F4, opcode::OP_ScriptMethodCallPointer },
    { 0x09F5, opcode::OP_LevelEvalFieldVariableRef },
    { 0x09F6, opcode::OP_SuperEqual },
    { 0x09F7, opcode::OP_RealWait },
    { 0x09F8, opcode::OP_GetFunction },
    { 0x09F9, opcode::OP_Invalid },
    { 0x09FA, opcode::OP_Inc },
    { 0x09FB, opcode::OP_Invalid },
    { 0x09FC, opcode::OP_JumpOnFalseExpr },
    { 0x09FD, opcode::OP_Invalid },
    { 0x09FE, opcode::OP_Invalid },
    { 0x09FF, opcode::OP_Invalid },
    { 0x0A00, opcode::OP_ScriptThreadCallPointer },
    { 0x0A01, opcode::OP_RealWait },
    { 0x0A02, opcode::OP_Invalid },
    { 0x0A03, opcode::OP_CallBuiltinMethod },
    { 0x0A04, opcode::OP_Invalid },
    { 0x0A05, opcode::OP_Invalid },
    { 0x0A06, opcode::OP_Invalid },
    { 0x0A07, opcode::OP_ScriptMethodCall },
    { 0x0A08, opcode::OP_SelfEvalFieldVariable },
    { 0x0A09, opcode::OP_GetUndefined },
    { 0x0A0A, opcode::OP_Bit_Or },
    { 0x0A0B, opcode::OP_JumpOnTrue },
    { 0x0A0C, opcode::OP_GetVector },
    { 0x0A0D, opcode::OP_GetFunction },
    { 0x0A0E, opcode::OP_GetHash },
    { 0x0A0F, opcode::OP_Invalid },
    { 0x0A10, opcode::OP_JumpOnTrueExpr },
    { 0x0A11, opcode::OP_EvalFieldVariable },
    { 0x0A12, opcode::OP_Multiply },
    { 0x0A13, opcode::OP_GetByte },
    { 0x0A14, opcode::OP_Invalid },
    { 0x0A15, opcode::OP_Plus },
    { 0x0A16, opcode::OP_NextArrayKey },
    { 0x0A17, opcode::OP_Invalid },
    { 0x0A18, opcode::OP_Multiply },
    { 0x0A19, opcode::OP_Invalid },
    { 0x0A1A, opcode::OP_Invalid },
    { 0x0A1B, opcode::OP_GetString },
    { 0x0A1C, opcode::OP_SelfEvalFieldVariableRef },
    { 0x0A1D, opcode::OP_RealWait },
    { 0x0A1E, opcode::OP_LessThan },
    { 0x0A1F, opcode::OP_Wait },
    { 0x0A20, opcode::OP_WaitTill },
    { 0x0A21, opcode::OP_ProfileStop },
    { 0x0A22, opcode::OP_Invalid },
    { 0x0A23, opcode::OP_Invalid },
    { 0x0A24, opcode::OP_LessThanOrEqualTo },
    { 0x0A25, opcode::OP_EmptyArray },
    { 0x0A26, opcode::OP_ScriptFunctionCall },
    { 0x0A27, opcode::OP_Invalid },
    { 0x0A28, opcode::OP_Invalid },
    { 0x0A29, opcode::OP_Bit_And },
    { 0x0A2A, opcode::OP_Invalid },
    { 0x0A2B, opcode::OP_GetSelfObject },
    { 0x0A2C, opcode::OP_CallBuiltinMethod },
    { 0x0A2D, opcode::OP_Notify },
    { 0x0A2E, opcode::OP_GetClassesObject },
    { 0x0A2F, opcode::OP_IsDefined },
    { 0x0A30, opcode::OP_Modulus },
    { 0x0A31, opcode::OP_GetUintptr },
    { 0x0A32, opcode::OP_Invalid },
    { 0x0A33, opcode::OP_Invalid },
    { 0x0A34, opcode::OP_ScriptFunctionCallClass },
    { 0x0A35, opcode::OP_GetInteger },
    { 0x0A36, opcode::OP_GetWorldObject },
    { 0x0A37, opcode::OP_Invalid },
    { 0x0A38, opcode::OP_GetLevelObject },
    { 0x0A39, opcode::OP_Inc },
    { 0x0A3A, opcode::OP_GetWorld },
    { 0x0A3B, opcode::OP_LessThan },
    { 0x0A3C, opcode::OP_Invalid },
    { 0x0A3D, opcode::OP_Invalid },
    { 0x0A3E, opcode::OP_GetLevelObject },
    { 0x0A3F, opcode::OP_FirstArrayKey },
    { 0x0A40, opcode::OP_RealWait },
    { 0x0A41, opcode::OP_EvalArray },
    { 0x0A42, opcode::OP_GreaterThan },
    { 0x0A43, opcode::OP_GetLevelObject },
    { 0x0A44, opcode::OP_EvalFieldVariable },
    { 0x0A45, opcode::OP_GetLevel },
    { 0x0A46, opcode::OP_Bit_Xor },
    { 0x0A47, opcode::OP_Notify },
    { 0x0A48, opcode::OP_Invalid },
    { 0x0A49, opcode::OP_GetClassesObject },
    { 0x0A4A, opcode::OP_EvalFieldVariable },
    { 0x0A4B, opcode::OP_Invalid },
    { 0x0A4C, opcode::OP_GreaterThanOrEqualTo },
    { 0x0A4D, opcode::OP_Invalid },
    { 0x0A4E, opcode::OP_JumpOnFalseExpr },
    { 0x0A4F, opcode::OP_Invalid },
    { 0x0A50, opcode::OP_Invalid },
    { 0x0A51, opcode::OP_WaitTillMatch },
    { 0x0A52, opcode::OP_GetAnimObject },
    { 0x0A53, opcode::OP_ScriptThreadCallClass },
    { 0x0A54, opcode::OP_Invalid },
    { 0x0A55, opcode::OP_IsDefined },
    { 0x0A56, opcode::OP_WaitTill },
    { 0x0A57, opcode::OP_SuperEqual },
    { 0x0A58, opcode::OP_LessThan },
    { 0x0A59, opcode::OP_SelfEvalFieldVariable },
    { 0x0A5A, opcode::OP_GetAPIFunction },
    { 0x0A5B, opcode::OP_Invalid },
    { 0x0A5C, opcode::OP_GetUndefined },
    { 0x0A5D, opcode::OP_ProfileStart },
    { 0x0A5E, opcode::OP_GetNegUnsignedShort },
    { 0x0A5F, opcode::OP_Invalid },
    { 0x0A60, opcode::OP_Equal },
    { 0x0A61, opcode::OP_Invalid },
    { 0x0A62, opcode::OP_Invalid },
    { 0x0A63, opcode::OP_GetByte },
    { 0x0A64, opcode::OP_NextArrayKey },
    { 0x0A65, opcode::OP_GreaterThan },
    { 0x0A66, opcode::OP_JumpOnTrueExpr },
    { 0x0A67, opcode::OP_VectorScale },
    { 0x0A68, opcode::OP_Invalid },
    { 0x0A69, opcode::OP_Invalid },
    { 0x0A6A, opcode::OP_Invalid },
    { 0x0A6B, opcode::OP_GetLevelObject },
    { 0x0A6C, opcode::OP_Invalid },
    { 0x0A6D, opcode::OP_EndSwitch },
    { 0x0A6E, opcode::OP_Invalid },
    { 0x0A6F, opcode::OP_GetByte },
    { 0x0A70, opcode::OP_GetGame },
    { 0x0A71, opcode::OP_GreaterThan },
    { 0x0A72, opcode::OP_Invalid },
    { 0x0A73, opcode::OP_VectorScale },
    { 0x0A74, opcode::OP_ScriptThreadCallClass },
    { 0x0A75, opcode::OP_JumpOnFalseExpr },
    { 0x0A76, opcode::OP_ScriptMethodThreadCall },
    { 0x0A77, opcode::OP_GetIString },
    { 0x0A78, opcode::OP_Invalid },
    { 0x0A79, opcode::OP_GreaterThan },
    { 0x0A7A, opcode::OP_JumpOnTrue },
    { 0x0A7B, opcode::OP_Invalid },
    { 0x0A7C, opcode::OP_Vector },
    { 0x0A7D, opcode::OP_GetVector },
    { 0x0A7E, opcode::OP_LevelEvalFieldVariable },
    { 0x0A7F, opcode::OP_Bit_Or },
    { 0x0A80, opcode::OP_Invalid },
    { 0x0A81, opcode::OP_Invalid },
    { 0x0A82, opcode::OP_Plus },
    { 0x0A83, opcode::OP_GetUnsignedShort },
    { 0x0A84, opcode::OP_Invalid },
    { 0x0A85, opcode::OP_Invalid },
    { 0x0A86, opcode::OP_GetClasses },
    { 0x0A87, opcode::OP_Invalid },
    { 0x0A88, opcode::OP_EvalArrayRef },
    { 0x0A89, opcode::OP_SelfEvalFieldVariableRef },
    { 0x0A8A, opcode::OP_Bit_Xor },
    { 0x0A8B, opcode::OP_JumpOnFalseExpr },
    { 0x0A8C, opcode::OP_EndSwitch },
    { 0x0A8D, opcode::OP_DecTop },
    { 0x0A8E, opcode::OP_SafeSetVariableFieldCached },
    { 0x0A8F, opcode::OP_CastBool },
    { 0x0A90, opcode::OP_IsDefined },
    { 0x0A91, opcode::OP_Invalid },
    { 0x0A92, opcode::OP_Inc },
    { 0x0A93, opcode::OP_GetClassesObject },
    { 0x0A94, opcode::OP_Vector },
    { 0x0A95, opcode::OP_Jump },
    { 0x0A96, opcode::OP_Wait },
    { 0x0A97, opcode::OP_ScriptMethodThreadCall },
    { 0x0A98, opcode::OP_NextArrayKey },
    { 0x0A99, opcode::OP_LessThan },
    { 0x0A9A, opcode::OP_SafeCreateLocalVariables },
    { 0x0A9B, opcode::OP_EmptyArray },
    { 0x0A9C, opcode::OP_GreaterThanOrEqualTo },
    { 0x0A9D, opcode::OP_ShiftRight },
    { 0x0A9E, opcode::OP_SelfEvalFieldVariableRef },
    { 0x0A9F, opcode::OP_New },
    { 0x0AA0, opcode::OP_Dec },
    { 0x0AA1, opcode::OP_SafeCreateLocalVariables },
    { 0x0AA2, opcode::OP_WaitTill },
    { 0x0AA3, opcode::OP_EvalArray },
    { 0x0AA4, opcode::OP_ScriptMethodThreadCall },
    { 0x0AA5, opcode::OP_FirstArrayKey },
    { 0x0AA6, opcode::OP_GetAnimation },
    { 0x0AA7, opcode::OP_Invalid },
    { 0x0AA8, opcode::OP_Invalid },
    { 0x0AA9, opcode::OP_EvalLocalVariableRefCached },
    { 0x0AAA, opcode::OP_ClearArray },
    { 0x0AAB, opcode::OP_NextArrayKey },
    { 0x0AAC, opcode::OP_Invalid },
    { 0x0AAD, opcode::OP_ShiftRight },
    { 0x0AAE, opcode::OP_ClearArray },
    { 0x0AAF, opcode::OP_SetVariableField },
    { 0x0AB0, opcode::OP_GetLevel },
    { 0x0AB1, opcode::OP_Minus },
    { 0x0AB2, opcode::OP_SuperEqual },
    { 0x0AB3, opcode::OP_CastFieldObject },
    { 0x0AB4, opcode::OP_GetUintptr },
    { 0x0AB5, opcode::OP_ShiftRight },
    { 0x0AB6, opcode::OP_Invalid },
    { 0x0AB7, opcode::OP_SelfEvalFieldVariable },
    { 0x0AB8, opcode::OP_Equal },
    { 0x0AB9, opcode::OP_LevelEvalFieldVariableRef },
    { 0x0ABA, opcode::OP_SizeOf },
    { 0x0ABB, opcode::OP_Bit_Xor },
    { 0x0ABC, opcode::OP_GetLevelObject },
    { 0x0ABD, opcode::OP_Invalid },
    { 0x0ABE, opcode::OP_Invalid },
    { 0x0ABF, opcode::OP_SuperNotEqual },
    { 0x0AC0, opcode::OP_Invalid },
    { 0x0AC1, opcode::OP_Return },
    { 0x0AC2, opcode::OP_New },
    { 0x0AC3, opcode::OP_ScriptMethodThreadCall },
    { 0x0AC4, opcode::OP_Switch },
    { 0x0AC5, opcode::OP_Invalid },
    { 0x0AC6, opcode::OP_GetLevel },
    { 0x0AC7, opcode::OP_ScriptThreadCallClass },
    { 0x0AC8, opcode::OP_Invalid },
    { 0x0AC9, opcode::OP_Invalid },
    { 0x0ACA, opcode::OP_Invalid },
    { 0x0ACB, opcode::OP_SelfEvalFieldVariable },
    { 0x0ACC, opcode::OP_Invalid },
    { 0x0ACD, opcode::OP_CastFieldObject },
    { 0x0ACE, opcode::OP_Invalid },
    { 0x0ACF, opcode::OP_Invalid },
    { 0x0AD0, opcode::OP_WaitTillMatch },
    { 0x0AD1, opcode::OP_Invalid },
    { 0x0AD2, opcode::OP_LessThanOrEqualTo },
    { 0x0AD3, opcode::OP_Inc },
    { 0x0AD4, opcode::OP_Invalid },
    { 0x0AD5, opcode::OP_NextArrayKey },
    { 0x0AD6, opcode::OP_Invalid },
    { 0x0AD7, opcode::OP_SelfEvalFieldVariableRef },
    { 0x0AD8, opcode::OP_ClearArray },
    { 0x0AD9, opcode::OP_Invalid },
    { 0x0ADA, opcode::OP_Invalid },
    { 0x0ADB, opcode::OP_GetSelfObject },
    { 0x0ADC, opcode::OP_GetInteger },
    { 0x0ADD, opcode::OP_GetAnimation },
    { 0x0ADE, opcode::OP_EvalFieldVariableRef },
    { 0x0ADF, opcode::OP_Invalid },
    { 0x0AE0, opcode::OP_Invalid },
    { 0x0AE1, opcode::OP_EvalArrayRef },
    { 0x0AE2, opcode::OP_EmptyArray },
    { 0x0AE3, opcode::OP_Invalid },
    { 0x0AE4, opcode::OP_Invalid },
    { 0x0AE5, opcode::OP_NextArrayKey },
    { 0x0AE6, opcode::OP_Invalid },
    { 0x0AE7, opcode::OP_BoolComplement },
    { 0x0AE8, opcode::OP_EvalArrayRef },
    { 0x0AE9, opcode::OP_Invalid },
    { 0x0AEA, opcode::OP_ShiftLeft },
    { 0x0AEB, opcode::OP_Notify },
    { 0x0AEC, opcode::OP_GetWorld },
    { 0x0AED, opcode::OP_Invalid },
    { 0x0AEE, opcode::OP_Invalid },
    { 0x0AEF, opcode::OP_GetGameRef },
    { 0x0AF0, opcode::OP_EndSwitch },
    { 0x0AF1, opcode::OP_Notify },
    { 0x0AF2, opcode::OP_GreaterThan },
    { 0x0AF3, opcode::OP_SelfEvalFieldVariableRef },
    { 0x0AF4, opcode::OP_LevelEvalFieldVariableRef },
    { 0x0AF5, opcode::OP_Invalid },
    { 0x0AF6, opcode::OP_New },
    { 0x0AF7, opcode::OP_JumpOnFalse },
    { 0x0AF8, opcode::OP_ShiftRight },
    { 0x0AF9, opcode::OP_VectorConstant },
    { 0x0AFA, opcode::OP_Invalid },
    { 0x0AFB, opcode::OP_Invalid },
    { 0x0AFC, opcode::OP_GetFloat },
    { 0x0AFD, opcode::OP_Notify },
    { 0x0AFE, opcode::OP_ScriptMethodCallPointer },
    { 0x0AFF, opcode::OP_EvalFieldVariableRef },
    { 0x0B00, opcode::OP_LevelEvalFieldVariable },
    { 0x0B01, opcode::OP_Invalid },
    { 0x0B02, opcode::OP_Invalid },
    { 0x0B03, opcode::OP_WaitTillFrameEnd },
    { 0x0B04, opcode::OP_Dec },
    { 0x0B05, opcode::OP_GetByte },
    { 0x0B06, opcode::OP_ScriptThreadCallClass },
    { 0x0B07, opcode::OP_SetVariableField },
    { 0x0B08, opcode::OP_ScriptMethodCallPointer },
    { 0x0B09, opcode::OP_VectorConstant },
    { 0x0B0A, opcode::OP_GetAnimObject },
    { 0x0B0B, opcode::OP_GetWorldObject },
    { 0x0B0C, opcode::OP_Modulus },
    { 0x0B0D, opcode::OP_GetNegUnsignedShort },
    { 0x0B0E, opcode::OP_GetNegUnsignedShort },
    { 0x0B0F, opcode::OP_DevblockBegin },
    { 0x0B10, opcode::OP_JumpOnTrue },
    { 0x0B11, opcode::OP_Invalid },
    { 0x0B12, opcode::OP_Invalid },
    { 0x0B13, opcode::OP_GetInteger },
    { 0x0B14, opcode::OP_Invalid },
    { 0x0B15, opcode::OP_Invalid },
    { 0x0B16, opcode::OP_GetUndefined },
    { 0x0B17, opcode::OP_SafeCreateLocalVariables },
    { 0x0B18, opcode::OP_GetTime },
    { 0x0B19, opcode::OP_BoolComplement },
    { 0x0B1A, opcode::OP_NextArrayKey },
    { 0x0B1B, opcode::OP_ClearArray },
    { 0x0B1C, opcode::OP_Jump },
    { 0x0B1D, opcode::OP_GetWorld },
    { 0x0B1E, opcode::OP_Invalid },
    { 0x0B1F, opcode::OP_Invalid },
    { 0x0B20, opcode::OP_Invalid },
    { 0x0B21, opcode::OP_JumpOnFalseExpr },
    { 0x0B22, opcode::OP_LevelEvalFieldVariable },
    { 0x0B23, opcode::OP_GetGame },
    { 0x0B24, opcode::OP_Bit_And },
    { 0x0B25, opcode::OP_BoolComplement },
    { 0x0B26, opcode::OP_Invalid },
    { 0x0B27, opcode::OP_RealWait },
    { 0x0B28, opcode::OP_Wait },
    { 0x0B29, opcode::OP_EvalFieldVariableRef },
    { 0x0B2A, opcode::OP_SelfEvalFieldVariableRef },
    { 0x0B2B, opcode::OP_LessThanOrEqualTo },
    { 0x0B2C, opcode::OP_Invalid },
    { 0x0B2D, opcode::OP_Invalid },
    { 0x0B2E, opcode::OP_GetWorld },
    { 0x0B2F, opcode::OP_Bit_And },
    { 0x0B30, opcode::OP_ScriptFunctionCall },
    { 0x0B31, opcode::OP_GetLevel },
    { 0x0B32, opcode::OP_Invalid },
    { 0x0B33, opcode::OP_New },
    { 0x0B34, opcode::OP_Bit_Or },
    { 0x0B35, opcode::OP_IsDefined },
    { 0x0B36, opcode::OP_Equal },
    { 0x0B37, opcode::OP_Invalid },
    { 0x0B38, opcode::OP_CallBuiltinMethod },
    { 0x0B39, opcode::OP_GetAnim },
    { 0x0B3A, opcode::OP_ScriptMethodCallPointer },
    { 0x0B3B, opcode::OP_GetWorld },
    { 0x0B3C, opcode::OP_ProfileStop },
    { 0x0B3D, opcode::OP_GetGameRef },
    { 0x0B3E, opcode::OP_Invalid },
    { 0x0B3F, opcode::OP_Jump },
    { 0x0B40, opcode::OP_Invalid },
    { 0x0B41, opcode::OP_Invalid },
    { 0x0B42, opcode::OP_Divide },
    { 0x0B43, opcode::OP_RealWait },
    { 0x0B44, opcode::OP_Invalid },
    { 0x0B45, opcode::OP_EvalLocalVariableCached },
    { 0x0B46, opcode::OP_Invalid },
    { 0x0B47, opcode::OP_Minus },
    { 0x0B48, opcode::OP_Invalid },
    { 0x0B49, opcode::OP_Invalid },
    { 0x0B4A, opcode::OP_GetSelf },
    { 0x0B4B, opcode::OP_ScriptThreadCall },
    { 0x0B4C, opcode::OP_GetNegUnsignedShort },
    { 0x0B4D, opcode::OP_DecTop },
    { 0x0B4E, opcode::OP_Dec },
    { 0x0B4F, opcode::OP_Invalid },
    { 0x0B50, opcode::OP_Invalid },
    { 0x0B51, opcode::OP_ProfileStop },
    { 0x0B52, opcode::OP_EndSwitch },
    { 0x0B53, opcode::OP_DecTop },
    { 0x0B54, opcode::OP_GetGameRef },
    { 0x0B55, opcode::OP_GetGameRef },
    { 0x0B56, opcode::OP_ClearFieldVariable },
    { 0x0B57, opcode::OP_JumpOnFalse },
    { 0x0B58, opcode::OP_WaitTillMatch },
    { 0x0B59, opcode::OP_SuperEqual },
    { 0x0B5A, opcode::OP_GetAnimObject },
    { 0x0B5B, opcode::OP_Invalid },
    { 0x0B5C, opcode::OP_CallBuiltinMethod },
    { 0x0B5D, opcode::OP_GreaterThanOrEqualTo },
    { 0x0B5E, opcode::OP_GetUintptr },
    { 0x0B5F, opcode::OP_GetAnimation },
    { 0x0B60, opcode::OP_GetNegUnsignedShort },
    { 0x0B61, opcode::OP_NextArrayKey },
    { 0x0B62, opcode::OP_CallBuiltinMethod },
    { 0x0B63, opcode::OP_Invalid },
    { 0x0B64, opcode::OP_DecTop },
    { 0x0B65, opcode::OP_Invalid },
    { 0x0B66, opcode::OP_SuperEqual },
    { 0x0B67, opcode::OP_GetString },
    { 0x0B68, opcode::OP_EvalLocalVariableCached },
    { 0x0B69, opcode::OP_WaitTillFrameEnd },
    { 0x0B6A, opcode::OP_JumpOnFalseExpr },
    { 0x0B6B, opcode::OP_Invalid },
    { 0x0B6C, opcode::OP_GetAnimation },
    { 0x0B6D, opcode::OP_Invalid },
    { 0x0B6E, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x0B6F, opcode::OP_Invalid },
    { 0x0B70, opcode::OP_CastBool },
    { 0x0B71, opcode::OP_DevblockBegin },
    { 0x0B72, opcode::OP_Invalid },
    { 0x0B73, opcode::OP_Invalid },
    { 0x0B74, opcode::OP_EvalArrayRef },
    { 0x0B75, opcode::OP_GetByte },
    { 0x0B76, opcode::OP_Vector },
    { 0x0B77, opcode::OP_Invalid },
    { 0x0B78, opcode::OP_GetAPIFunction },
    { 0x0B79, opcode::OP_GreaterThanOrEqualTo },
    { 0x0B7A, opcode::OP_Invalid },
    { 0x0B7B, opcode::OP_EvalFieldVariableRef },
    { 0x0B7C, opcode::OP_GetWorldObject },
    { 0x0B7D, opcode::OP_GetSelf },
    { 0x0B7E, opcode::OP_ScriptFunctionCallClass },
    { 0x0B7F, opcode::OP_Invalid },
    { 0x0B80, opcode::OP_LevelEvalFieldVariable },
    { 0x0B81, opcode::OP_NextArrayKey },
    { 0x0B82, opcode::OP_JumpOnTrueExpr },
    { 0x0B83, opcode::OP_New },
    { 0x0B84, opcode::OP_GetHash },
    { 0x0B85, opcode::OP_Invalid },
    { 0x0B86, opcode::OP_Return },
    { 0x0B87, opcode::OP_ScriptThreadCall },
    { 0x0B88, opcode::OP_Invalid },
    { 0x0B89, opcode::OP_SuperEqual },
    { 0x0B8A, opcode::OP_Invalid },
    { 0x0B8B, opcode::OP_Notify },
    { 0x0B8C, opcode::OP_Invalid },
    { 0x0B8D, opcode::OP_GetHash },
    { 0x0B8E, opcode::OP_Notify },
    { 0x0B8F, opcode::OP_GetFunction },
    { 0x0B90, opcode::OP_ScriptMethodCallPointer },
    { 0x0B91, opcode::OP_Invalid },
    { 0x0B92, opcode::OP_Invalid },
    { 0x0B93, opcode::OP_Invalid },
    { 0x0B94, opcode::OP_ScriptThreadCall },
    { 0x0B95, opcode::OP_GetTime },
    { 0x0B96, opcode::OP_EvalArrayRef },
    { 0x0B97, opcode::OP_GetAPIFunction },
    { 0x0B98, opcode::OP_JumpOnFalseExpr },
    { 0x0B99, opcode::OP_Notify },
    { 0x0B9A, opcode::OP_EvalArrayRef },
    { 0x0B9B, opcode::OP_Invalid },
    { 0x0B9C, opcode::OP_EndSwitch },
    { 0x0B9D, opcode::OP_ScriptMethodCall },
    { 0x0B9E, opcode::OP_VectorScale },
    { 0x0B9F, opcode::OP_Invalid },
    { 0x0BA0, opcode::OP_Jump },
    { 0x0BA1, opcode::OP_GetVector },
    { 0x0BA2, opcode::OP_BoolComplement },
    { 0x0BA3, opcode::OP_Invalid },
    { 0x0BA4, opcode::OP_GreaterThanOrEqualTo },
    { 0x0BA5, opcode::OP_GetTime },
    { 0x0BA6, opcode::OP_Invalid },
    { 0x0BA7, opcode::OP_LessThanOrEqualTo },
    { 0x0BA8, opcode::OP_JumpOnTrue },
    { 0x0BA9, opcode::OP_Vector },
    { 0x0BAA, opcode::OP_WaitTillFrameEnd },
    { 0x0BAB, opcode::OP_New },
    { 0x0BAC, opcode::OP_GetUndefined },
    { 0x0BAD, opcode::OP_Invalid },
    { 0x0BAE, opcode::OP_Dec },
    { 0x0BAF, opcode::OP_Dec },
    { 0x0BB0, opcode::OP_Invalid },
    { 0x0BB1, opcode::OP_ProfileStart },
    { 0x0BB2, opcode::OP_GetZero },
    { 0x0BB3, opcode::OP_Invalid },
    { 0x0BB4, opcode::OP_Multiply },
    { 0x0BB5, opcode::OP_CastBool },
    { 0x0BB6, opcode::OP_GetSelfObject },
    { 0x0BB7, opcode::OP_EvalLocalVariableRefCached },
    { 0x0BB8, opcode::OP_EvalFieldVariable },
    { 0x0BB9, opcode::OP_Invalid },
    { 0x0BBA, opcode::OP_Invalid },
    { 0x0BBB, opcode::OP_JumpOnTrueExpr },
    { 0x0BBC, opcode::OP_Invalid },
    { 0x0BBD, opcode::OP_SelfEvalFieldVariableRef },
    { 0x0BBE, opcode::OP_Invalid },
    { 0x0BBF, opcode::OP_EvalArrayRef },
    { 0x0BC0, opcode::OP_Modulus },
    { 0x0BC1, opcode::OP_LessThan },
    { 0x0BC2, opcode::OP_FirstArrayKey },
    { 0x0BC3, opcode::OP_Invalid },
    { 0x0BC4, opcode::OP_SuperEqual },
    { 0x0BC5, opcode::OP_ScriptMethodThreadCall },
    { 0x0BC6, opcode::OP_Inc },
    { 0x0BC7, opcode::OP_Invalid },
    { 0x0BC8, opcode::OP_GetLevelObject },
    { 0x0BC9, opcode::OP_Jump },
    { 0x0BCA, opcode::OP_Switch },
    { 0x0BCB, opcode::OP_GetWorldObject },
    { 0x0BCC, opcode::OP_GetIString },
    { 0x0BCD, opcode::OP_FirstArrayKey },
    { 0x0BCE, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x0BCF, opcode::OP_ScriptFunctionCall },
    { 0x0BD0, opcode::OP_DevblockBegin },
    { 0x0BD1, opcode::OP_SuperNotEqual },
    { 0x0BD2, opcode::OP_EndOn },
    { 0x0BD3, opcode::OP_ScriptFunctionCallPointer },
    { 0x0BD4, opcode::OP_VectorScale },
    { 0x0BD5, opcode::OP_ScriptThreadCallPointer },
    { 0x0BD6, opcode::OP_Inc },
    { 0x0BD7, opcode::OP_Invalid },
    { 0x0BD8, opcode::OP_Invalid },
    { 0x0BD9, opcode::OP_GetHash },
    { 0x0BDA, opcode::OP_Invalid },
    { 0x0BDB, opcode::OP_Invalid },
    { 0x0BDC, opcode::OP_CallBuiltinMethod },
    { 0x0BDD, opcode::OP_LessThan },
    { 0x0BDE, opcode::OP_Notify },
    { 0x0BDF, opcode::OP_ScriptFunctionCallPointer },
    { 0x0BE0, opcode::OP_EvalFieldVariable },
    { 0x0BE1, opcode::OP_Invalid },
    { 0x0BE2, opcode::OP_Invalid },
    { 0x0BE3, opcode::OP_Invalid },
    { 0x0BE4, opcode::OP_ClearArray },
    { 0x0BE5, opcode::OP_GetSelf },
    { 0x0BE6, opcode::OP_Invalid },
    { 0x0BE7, opcode::OP_JumpOnTrue },
    { 0x0BE8, opcode::OP_Invalid },
    { 0x0BE9, opcode::OP_Invalid },
    { 0x0BEA, opcode::OP_GetTime },
    { 0x0BEB, opcode::OP_Bit_Or },
    { 0x0BEC, opcode::OP_NotEqual },
    { 0x0BED, opcode::OP_Divide },
    { 0x0BEE, opcode::OP_GetGameRef },
    { 0x0BEF, opcode::OP_Invalid },
    { 0x0BF0, opcode::OP_RealWait },
    { 0x0BF1, opcode::OP_GetHash },
    { 0x0BF2, opcode::OP_EvalArray },
    { 0x0BF3, opcode::OP_GetInteger },
    { 0x0BF4, opcode::OP_Vector },
    { 0x0BF5, opcode::OP_JumpOnFalse },
    { 0x0BF6, opcode::OP_Invalid },
    { 0x0BF7, opcode::OP_GetInteger },
    { 0x0BF8, opcode::OP_EvalArray },
    { 0x0BF9, opcode::OP_GetClassesObject },
    { 0x0BFA, opcode::OP_GetByte },
    { 0x0BFB, opcode::OP_EvalArrayRef },
    { 0x0BFC, opcode::OP_Invalid },
    { 0x0BFD, opcode::OP_GetByte },
    { 0x0BFE, opcode::OP_Invalid },
    { 0x0BFF, opcode::OP_GetFunction },
    { 0x0C00, opcode::OP_Invalid },
    { 0x0C01, opcode::OP_Multiply },
    { 0x0C02, opcode::OP_Invalid },
    { 0x0C03, opcode::OP_GetLevel },
    { 0x0C04, opcode::OP_GetClasses },
    { 0x0C05, opcode::OP_WaitTillFrameEnd },
    { 0x0C06, opcode::OP_GetString },
    { 0x0C07, opcode::OP_Dec },
    { 0x0C08, opcode::OP_ScriptMethodThreadCall },
    { 0x0C09, opcode::OP_BoolNot },
    { 0x0C0A, opcode::OP_Invalid },
    { 0x0C0B, opcode::OP_SetVariableField },
    { 0x0C0C, opcode::OP_GetClasses },
    { 0x0C0D, opcode::OP_Invalid },
    { 0x0C0E, opcode::OP_ProfileStop },
    { 0x0C0F, opcode::OP_GetByte },
    { 0x0C10, opcode::OP_ScriptFunctionCall },
    { 0x0C11, opcode::OP_Invalid },
    { 0x0C12, opcode::OP_LevelEvalFieldVariableRef },
    { 0x0C13, opcode::OP_Invalid },
    { 0x0C14, opcode::OP_ScriptMethodCallPointer },
    { 0x0C15, opcode::OP_Invalid },
    { 0x0C16, opcode::OP_Return },
    { 0x0C17, opcode::OP_GetByte },
    { 0x0C18, opcode::OP_CallBuiltinMethod },
    { 0x0C19, opcode::OP_Invalid },
    { 0x0C1A, opcode::OP_GetLevelObject },
    { 0x0C1B, opcode::OP_NextArrayKey },
    { 0x0C1C, opcode::OP_LessThan },
    { 0x0C1D, opcode::OP_GetFunction },
    { 0x0C1E, opcode::OP_Invalid },
    { 0x0C1F, opcode::OP_Invalid },
    { 0x0C20, opcode::OP_Switch },
    { 0x0C21, opcode::OP_Invalid },
    { 0x0C22, opcode::OP_GetAnim },
    { 0x0C23, opcode::OP_Invalid },
    { 0x0C24, opcode::OP_CastFieldObject },
    { 0x0C25, opcode::OP_GetString },
    { 0x0C26, opcode::OP_GetUintptr },
    { 0x0C27, opcode::OP_ScriptFunctionCallClass },
    { 0x0C28, opcode::OP_EndSwitch },
    { 0x0C29, opcode::OP_Invalid },
    { 0x0C2A, opcode::OP_LevelEvalFieldVariable },
    { 0x0C2B, opcode::OP_LessThanOrEqualTo },
    { 0x0C2C, opcode::OP_GetAnim },
    { 0x0C2D, opcode::OP_ShiftRight },
    { 0x0C2E, opcode::OP_Invalid },
    { 0x0C2F, opcode::OP_GetSelf },
    { 0x0C30, opcode::OP_SelfEvalFieldVariable },
    { 0x0C31, opcode::OP_Invalid },
    { 0x0C32, opcode::OP_GetLevelObject },
    { 0x0C33, opcode::OP_ScriptFunctionCallPointer },
    { 0x0C34, opcode::OP_LevelEvalFieldVariable },
    { 0x0C35, opcode::OP_GetLevelObject },
    { 0x0C36, opcode::OP_Invalid },
    { 0x0C37, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x0C38, opcode::OP_BoolNot },
    { 0x0C39, opcode::OP_GetTime },
    { 0x0C3A, opcode::OP_Invalid },
    { 0x0C3B, opcode::OP_Invalid },
    { 0x0C3C, opcode::OP_ScriptThreadCallPointer },
    { 0x0C3D, opcode::OP_GetVector },
    { 0x0C3E, opcode::OP_GetHash },
    { 0x0C3F, opcode::OP_Jump },
    { 0x0C40, opcode::OP_GetWorld },
    { 0x0C41, opcode::OP_Invalid },
    { 0x0C42, opcode::OP_Invalid },
    { 0x0C43, opcode::OP_Vector },
    { 0x0C44, opcode::OP_GetFunction },
    { 0x0C45, opcode::OP_FirstArrayKey },
    { 0x0C46, opcode::OP_GetFunction },
    { 0x0C47, opcode::OP_Vector },
    { 0x0C48, opcode::OP_Invalid },
    { 0x0C49, opcode::OP_VectorScale },
    { 0x0C4A, opcode::OP_New },
    { 0x0C4B, opcode::OP_EndOn },
    { 0x0C4C, opcode::OP_Invalid },
    { 0x0C4D, opcode::OP_GetLevelObject },
    { 0x0C4E, opcode::OP_GetClassesObject },
    { 0x0C4F, opcode::OP_GetGameRef },
    { 0x0C50, opcode::OP_GetNegByte },
    { 0x0C51, opcode::OP_Jump },
    { 0x0C52, opcode::OP_Modulus },
    { 0x0C53, opcode::OP_Invalid },
    { 0x0C54, opcode::OP_Invalid },
    { 0x0C55, opcode::OP_NextArrayKey },
    { 0x0C56, opcode::OP_ClearArray },
    { 0x0C57, opcode::OP_EvalArray },
    { 0x0C58, opcode::OP_GetByte },
    { 0x0C59, opcode::OP_Invalid },
    { 0x0C5A, opcode::OP_Notify },
    { 0x0C5B, opcode::OP_GetNegByte },
    { 0x0C5C, opcode::OP_Equal },
    { 0x0C5D, opcode::OP_Dec },
    { 0x0C5E, opcode::OP_GetLevelObject },
    { 0x0C5F, opcode::OP_Jump },
    { 0x0C60, opcode::OP_GetLevel },
    { 0x0C61, opcode::OP_SizeOf },
    { 0x0C62, opcode::OP_Divide },
    { 0x0C63, opcode::OP_Invalid },
    { 0x0C64, opcode::OP_GetString },
    { 0x0C65, opcode::OP_Notify },
    { 0x0C66, opcode::OP_Invalid },
    { 0x0C67, opcode::OP_SafeCreateLocalVariables },
    { 0x0C68, opcode::OP_Invalid },
    { 0x0C69, opcode::OP_Invalid },
    { 0x0C6A, opcode::OP_ProfileStop },
    { 0x0C6B, opcode::OP_Invalid },
    { 0x0C6C, opcode::OP_LessThan },
    { 0x0C6D, opcode::OP_GetZero },
    { 0x0C6E, opcode::OP_GetFloat },
    { 0x0C6F, opcode::OP_GetByte },
    { 0x0C70, opcode::OP_GetLevel },
    { 0x0C71, opcode::OP_Invalid },
    { 0x0C72, opcode::OP_ScriptThreadCallPointer },
    { 0x0C73, opcode::OP_Switch },
    { 0x0C74, opcode::OP_GetUintptr },
    { 0x0C75, opcode::OP_EmptyArray },
    { 0x0C76, opcode::OP_Invalid },
    { 0x0C77, opcode::OP_GetNegUnsignedShort },
    { 0x0C78, opcode::OP_CallBuiltinMethod },
    { 0x0C79, opcode::OP_Invalid },
    { 0x0C7A, opcode::OP_GetSelf },
    { 0x0C7B, opcode::OP_ScriptFunctionCall },
    { 0x0C7C, opcode::OP_Invalid },
    { 0x0C7D, opcode::OP_Inc },
    { 0x0C7E, opcode::OP_Invalid },
    { 0x0C7F, opcode::OP_GetFunction },
    { 0x0C80, opcode::OP_Invalid },
    { 0x0C81, opcode::OP_Bit_Or },
    { 0x0C82, opcode::OP_Invalid },
    { 0x0C83, opcode::OP_ShiftRight },
    { 0x0C84, opcode::OP_Invalid },
    { 0x0C85, opcode::OP_VectorScale },
    { 0x0C86, opcode::OP_RealWait },
    { 0x0C87, opcode::OP_GreaterThan },
    { 0x0C88, opcode::OP_Invalid },
    { 0x0C89, opcode::OP_LessThan },
    { 0x0C8A, opcode::OP_Plus },
    { 0x0C8B, opcode::OP_GetUnsignedShort },
    { 0x0C8C, opcode::OP_GetNegUnsignedShort },
    { 0x0C8D, opcode::OP_Invalid },
    { 0x0C8E, opcode::OP_GetUintptr },
    { 0x0C8F, opcode::OP_SuperEqual },
    { 0x0C90, opcode::OP_Invalid },
    { 0x0C91, opcode::OP_GetWorldObject },
    { 0x0C92, opcode::OP_RealWait },
    { 0x0C93, opcode::OP_GetZero },
    { 0x0C94, opcode::OP_Invalid },
    { 0x0C95, opcode::OP_GetHash },
    { 0x0C96, opcode::OP_Invalid },
    { 0x0C97, opcode::OP_Invalid },
    { 0x0C98, opcode::OP_GetVector },
    { 0x0C99, opcode::OP_Invalid },
    { 0x0C9A, opcode::OP_Minus },
    { 0x0C9B, opcode::OP_CallBuiltinMethod },
    { 0x0C9C, opcode::OP_EvalArrayRef },
    { 0x0C9D, opcode::OP_GetAnim },
    { 0x0C9E, opcode::OP_Invalid },
    { 0x0C9F, opcode::OP_Invalid },
    { 0x0CA0, opcode::OP_Invalid },
    { 0x0CA1, opcode::OP_Invalid },
    { 0x0CA2, opcode::OP_GetUndefined },
    { 0x0CA3, opcode::OP_ClearFieldVariable },
    { 0x0CA4, opcode::OP_SuperEqual },
    { 0x0CA5, opcode::OP_LessThan },
    { 0x0CA6, opcode::OP_Invalid },
    { 0x0CA7, opcode::OP_LessThanOrEqualTo },
    { 0x0CA8, opcode::OP_GetClassesObject },
    { 0x0CA9, opcode::OP_FirstArrayKey },
    { 0x0CAA, opcode::OP_LessThanOrEqualTo },
    { 0x0CAB, opcode::OP_Invalid },
    { 0x0CAC, opcode::OP_WaitTillMatch },
    { 0x0CAD, opcode::OP_CastBool },
    { 0x0CAE, opcode::OP_GetSelfObject },
    { 0x0CAF, opcode::OP_Invalid },
    { 0x0CB0, opcode::OP_SafeSetVariableFieldCached },
    { 0x0CB1, opcode::OP_Invalid },
    { 0x0CB2, opcode::OP_EndOn },
    { 0x0CB3, opcode::OP_CastBool },
    { 0x0CB4, opcode::OP_ShiftRight },
    { 0x0CB5, opcode::OP_Invalid },
    { 0x0CB6, opcode::OP_Invalid },
    { 0x0CB7, opcode::OP_JumpOnFalse },
    { 0x0CB8, opcode::OP_SuperNotEqual },
    { 0x0CB9, opcode::OP_Invalid },
    { 0x0CBA, opcode::OP_ScriptMethodCall },
    { 0x0CBB, opcode::OP_Invalid },
    { 0x0CBC, opcode::OP_New },
    { 0x0CBD, opcode::OP_RealWait },
    { 0x0CBE, opcode::OP_Invalid },
    { 0x0CBF, opcode::OP_WaitTillMatch },
    { 0x0CC0, opcode::OP_SafeDecTop },
    { 0x0CC1, opcode::OP_Invalid },
    { 0x0CC2, opcode::OP_SelfEvalFieldVariable },
    { 0x0CC3, opcode::OP_Inc },
    { 0x0CC4, opcode::OP_Invalid },
    { 0x0CC5, opcode::OP_Return },
    { 0x0CC6, opcode::OP_Invalid },
    { 0x0CC7, opcode::OP_Invalid },
    { 0x0CC8, opcode::OP_Invalid },
    { 0x0CC9, opcode::OP_EvalArrayRef },
    { 0x0CCA, opcode::OP_NextArrayKey },
    { 0x0CCB, opcode::OP_Invalid },
    { 0x0CCC, opcode::OP_EvalLocalVariableCached },
    { 0x0CCD, opcode::OP_EvalFieldVariable },
    { 0x0CCE, opcode::OP_Invalid },
    { 0x0CCF, opcode::OP_EvalArray },
    { 0x0CD0, opcode::OP_SizeOf },
    { 0x0CD1, opcode::OP_Invalid },
    { 0x0CD2, opcode::OP_Invalid },
    { 0x0CD3, opcode::OP_Invalid },
    { 0x0CD4, opcode::OP_Notify },
    { 0x0CD5, opcode::OP_GetString },
    { 0x0CD6, opcode::OP_GetAnimObject },
    { 0x0CD7, opcode::OP_SafeCreateLocalVariables },
    { 0x0CD8, opcode::OP_WaitTillMatch },
    { 0x0CD9, opcode::OP_Equal },
    { 0x0CDA, opcode::OP_Invalid },
    { 0x0CDB, opcode::OP_GetHash },
    { 0x0CDC, opcode::OP_Invalid },
    { 0x0CDD, opcode::OP_BoolComplement },
    { 0x0CDE, opcode::OP_EvalArray },
    { 0x0CDF, opcode::OP_Invalid },
    { 0x0CE0, opcode::OP_Invalid },
    { 0x0CE1, opcode::OP_Return },
    { 0x0CE2, opcode::OP_Dec },
    { 0x0CE3, opcode::OP_Wait },
    { 0x0CE4, opcode::OP_Invalid },
    { 0x0CE5, opcode::OP_Invalid },
    { 0x0CE6, opcode::OP_JumpOnFalse },
    { 0x0CE7, opcode::OP_GetSelfObject },
    { 0x0CE8, opcode::OP_Switch },
    { 0x0CE9, opcode::OP_Invalid },
    { 0x0CEA, opcode::OP_EvalArray },
    { 0x0CEB, opcode::OP_ScriptThreadCallClass },
    { 0x0CEC, opcode::OP_Invalid },
    { 0x0CED, opcode::OP_Invalid },
    { 0x0CEE, opcode::OP_EvalArray },
    { 0x0CEF, opcode::OP_SafeCreateLocalVariables },
    { 0x0CF0, opcode::OP_Invalid },
    { 0x0CF1, opcode::OP_IsDefined },
    { 0x0CF2, opcode::OP_IsDefined },
    { 0x0CF3, opcode::OP_Switch },
    { 0x0CF4, opcode::OP_GetAnim },
    { 0x0CF5, opcode::OP_GetUintptr },
    { 0x0CF6, opcode::OP_Invalid },
    { 0x0CF7, opcode::OP_Notify },
    { 0x0CF8, opcode::OP_GetNegUnsignedShort },
    { 0x0CF9, opcode::OP_Divide },
    { 0x0CFA, opcode::OP_Invalid },
    { 0x0CFB, opcode::OP_GreaterThan },
    { 0x0CFC, opcode::OP_ScriptFunctionCall },
    { 0x0CFD, opcode::OP_WaitTillMatch },
    { 0x0CFE, opcode::OP_GetLevelObject },
    { 0x0CFF, opcode::OP_Minus },
    { 0x0D00, opcode::OP_GetNegUnsignedShort },
    { 0x0D01, opcode::OP_Invalid },
    { 0x0D02, opcode::OP_Invalid },
    { 0x0D03, opcode::OP_Invalid },
    { 0x0D04, opcode::OP_CastBool },
    { 0x0D05, opcode::OP_SizeOf },
    { 0x0D06, opcode::OP_SafeDecTop },
    { 0x0D07, opcode::OP_Minus },
    { 0x0D08, opcode::OP_Invalid },
    { 0x0D09, opcode::OP_Invalid },
    { 0x0D0A, opcode::OP_JumpOnTrueExpr },
    { 0x0D0B, opcode::OP_Invalid },
    { 0x0D0C, opcode::OP_Invalid },
    { 0x0D0D, opcode::OP_JumpOnTrue },
    { 0x0D0E, opcode::OP_ProfileStop },
    { 0x0D0F, opcode::OP_GetWorld },
    { 0x0D10, opcode::OP_Invalid },
    { 0x0D11, opcode::OP_Invalid },
    { 0x0D12, opcode::OP_BoolNot },
    { 0x0D13, opcode::OP_Invalid },
    { 0x0D14, opcode::OP_Invalid },
    { 0x0D15, opcode::OP_Invalid },
    { 0x0D16, opcode::OP_Invalid },
    { 0x0D17, opcode::OP_GetInteger },
    { 0x0D18, opcode::OP_ScriptMethodThreadCall },
    { 0x0D19, opcode::OP_CastFieldObject },
    { 0x0D1A, opcode::OP_Divide },
    { 0x0D1B, opcode::OP_GreaterThan },
    { 0x0D1C, opcode::OP_Invalid },
    { 0x0D1D, opcode::OP_SizeOf },
    { 0x0D1E, opcode::OP_Invalid },
    { 0x0D1F, opcode::OP_Invalid },
    { 0x0D20, opcode::OP_Invalid },
    { 0x0D21, opcode::OP_SuperNotEqual },
    { 0x0D22, opcode::OP_Invalid },
    { 0x0D23, opcode::OP_Invalid },
    { 0x0D24, opcode::OP_GetAnimation },
    { 0x0D25, opcode::OP_Invalid },
    { 0x0D26, opcode::OP_Invalid },
    { 0x0D27, opcode::OP_ClearArray },
    { 0x0D28, opcode::OP_JumpOnTrueExpr },
    { 0x0D29, opcode::OP_SafeSetVariableFieldCached },
    { 0x0D2A, opcode::OP_GetInteger },
    { 0x0D2B, opcode::OP_SafeDecTop },
    { 0x0D2C, opcode::OP_Invalid },
    { 0x0D2D, opcode::OP_Invalid },
    { 0x0D2E, opcode::OP_LessThanOrEqualTo },
    { 0x0D2F, opcode::OP_LessThan },
    { 0x0D30, opcode::OP_Invalid },
    { 0x0D31, opcode::OP_Modulus },
    { 0x0D32, opcode::OP_ScriptFunctionCallPointer },
    { 0x0D33, opcode::OP_Invalid },
    { 0x0D34, opcode::OP_Invalid },
    { 0x0D35, opcode::OP_Invalid },
    { 0x0D36, opcode::OP_SafeSetVariableFieldCached },
    { 0x0D37, opcode::OP_WaitTill },
    { 0x0D38, opcode::OP_GetClassesObject },
    { 0x0D39, opcode::OP_GetClasses },
    { 0x0D3A, opcode::OP_GetGame },
    { 0x0D3B, opcode::OP_EvalArrayRef },
    { 0x0D3C, opcode::OP_Invalid },
    { 0x0D3D, opcode::OP_Invalid },
    { 0x0D3E, opcode::OP_GetAPIFunction },
    { 0x0D3F, opcode::OP_ScriptFunctionCallClass },
    { 0x0D40, opcode::OP_ScriptMethodCallPointer },
    { 0x0D41, opcode::OP_Invalid },
    { 0x0D42, opcode::OP_Invalid },
    { 0x0D43, opcode::OP_NextArrayKey },
    { 0x0D44, opcode::OP_Invalid },
    { 0x0D45, opcode::OP_GetUintptr },
    { 0x0D46, opcode::OP_GetClassesObject },
    { 0x0D47, opcode::OP_LessThanOrEqualTo },
    { 0x0D48, opcode::OP_GetNegUnsignedShort },
    { 0x0D49, opcode::OP_GetUnsignedShort },
    { 0x0D4A, opcode::OP_Invalid },
    { 0x0D4B, opcode::OP_GetSelf },
    { 0x0D4C, opcode::OP_GetUndefined },
    { 0x0D4D, opcode::OP_Invalid },
    { 0x0D4E, opcode::OP_ShiftLeft },
    { 0x0D4F, opcode::OP_GetNegUnsignedShort },
    { 0x0D50, opcode::OP_ScriptMethodCall },
    { 0x0D51, opcode::OP_EvalFieldVariable },
    { 0x0D52, opcode::OP_Invalid },
    { 0x0D53, opcode::OP_Invalid },
    { 0x0D54, opcode::OP_Invalid },
    { 0x0D55, opcode::OP_ProfileStart },
    { 0x0D56, opcode::OP_Dec },
    { 0x0D57, opcode::OP_Equal },
    { 0x0D58, opcode::OP_Invalid },
    { 0x0D59, opcode::OP_Invalid },
    { 0x0D5A, opcode::OP_IsDefined },
    { 0x0D5B, opcode::OP_GetUintptr },
    { 0x0D5C, opcode::OP_Invalid },
    { 0x0D5D, opcode::OP_GreaterThan },
    { 0x0D5E, opcode::OP_ShiftLeft },
    { 0x0D5F, opcode::OP_Invalid },
    { 0x0D60, opcode::OP_Return },
    { 0x0D61, opcode::OP_Invalid },
    { 0x0D62, opcode::OP_GetFunction },
    { 0x0D63, opcode::OP_JumpOnTrue },
    { 0x0D64, opcode::OP_GetLevelObject },
    { 0x0D65, opcode::OP_Invalid },
    { 0x0D66, opcode::OP_JumpOnFalseExpr },
    { 0x0D67, opcode::OP_Invalid },
    { 0x0D68, opcode::OP_ProfileStart },
    { 0x0D69, opcode::OP_SetVariableField },
    { 0x0D6A, opcode::OP_Invalid },
    { 0x0D6B, opcode::OP_SizeOf },
    { 0x0D6C, opcode::OP_Invalid },
    { 0x0D6D, opcode::OP_IsDefined },
    { 0x0D6E, opcode::OP_Invalid },
    { 0x0D6F, opcode::OP_ScriptMethodCall },
    { 0x0D70, opcode::OP_Invalid },
    { 0x0D71, opcode::OP_Invalid },
    { 0x0D72, opcode::OP_GetAPIFunction },
    { 0x0D73, opcode::OP_GetIString },
    { 0x0D74, opcode::OP_Invalid },
    { 0x0D75, opcode::OP_JumpOnTrueExpr },
    { 0x0D76, opcode::OP_SuperEqual },
    { 0x0D77, opcode::OP_ShiftLeft },
    { 0x0D78, opcode::OP_Notify },
    { 0x0D79, opcode::OP_Invalid },
    { 0x0D7A, opcode::OP_Invalid },
    { 0x0D7B, opcode::OP_GetUndefined },
    { 0x0D7C, opcode::OP_Invalid },
    { 0x0D7D, opcode::OP_GetTime },
    { 0x0D7E, opcode::OP_Invalid },
    { 0x0D7F, opcode::OP_ScriptMethodCallPointer },
    { 0x0D80, opcode::OP_GetFunction },
    { 0x0D81, opcode::OP_Invalid },
    { 0x0D82, opcode::OP_GetZero },
    { 0x0D83, opcode::OP_GetGame },
    { 0x0D84, opcode::OP_GetAnim },
    { 0x0D85, opcode::OP_Invalid },
    { 0x0D86, opcode::OP_RealWait },
    { 0x0D87, opcode::OP_Bit_Xor },
    { 0x0D88, opcode::OP_Invalid },
    { 0x0D89, opcode::OP_SelfEvalFieldVariable },
    { 0x0D8A, opcode::OP_Invalid },
    { 0x0D8B, opcode::OP_Dec },
    { 0x0D8C, opcode::OP_Invalid },
    { 0x0D8D, opcode::OP_JumpOnTrueExpr },
    { 0x0D8E, opcode::OP_Invalid },
    { 0x0D8F, opcode::OP_Invalid },
    { 0x0D90, opcode::OP_Invalid },
    { 0x0D91, opcode::OP_EndOn },
    { 0x0D92, opcode::OP_GreaterThanOrEqualTo },
    { 0x0D93, opcode::OP_Invalid },
    { 0x0D94, opcode::OP_Dec },
    { 0x0D95, opcode::OP_Invalid },
    { 0x0D96, opcode::OP_Invalid },
    { 0x0D97, opcode::OP_Invalid },
    { 0x0D98, opcode::OP_SelfEvalFieldVariable },
    { 0x0D99, opcode::OP_Invalid },
    { 0x0D9A, opcode::OP_Invalid },
    { 0x0D9B, opcode::OP_Invalid },
    { 0x0D9C, opcode::OP_Invalid },
    { 0x0D9D, opcode::OP_VectorConstant },
    { 0x0D9E, opcode::OP_BoolNot },
    { 0x0D9F, opcode::OP_Invalid },
    { 0x0DA0, opcode::OP_SelfEvalFieldVariable },
    { 0x0DA1, opcode::OP_GetAnimation },
    { 0x0DA2, opcode::OP_Bit_Xor },
    { 0x0DA3, opcode::OP_GetGame },
    { 0x0DA4, opcode::OP_LevelEvalFieldVariableRef },
    { 0x0DA5, opcode::OP_Invalid },
    { 0x0DA6, opcode::OP_Bit_Xor },
    { 0x0DA7, opcode::OP_Invalid },
    { 0x0DA8, opcode::OP_GetAnimation },
    { 0x0DA9, opcode::OP_Invalid },
    { 0x0DAA, opcode::OP_Invalid },
    { 0x0DAB, opcode::OP_GetFunction },
    { 0x0DAC, opcode::OP_SelfEvalFieldVariable },
    { 0x0DAD, opcode::OP_Multiply },
    { 0x0DAE, opcode::OP_LevelEvalFieldVariable },
    { 0x0DAF, opcode::OP_LessThanOrEqualTo },
    { 0x0DB0, opcode::OP_CallBuiltinMethod },
    { 0x0DB1, opcode::OP_Invalid },
    { 0x0DB2, opcode::OP_Invalid },
    { 0x0DB3, opcode::OP_Invalid },
    { 0x0DB4, opcode::OP_Invalid },
    { 0x0DB5, opcode::OP_Vector },
    { 0x0DB6, opcode::OP_ProfileStop },
    { 0x0DB7, opcode::OP_CallBuiltinMethod },
    { 0x0DB8, opcode::OP_SafeDecTop },
    { 0x0DB9, opcode::OP_WaitTill },
    { 0x0DBA, opcode::OP_CastFieldObject },
    { 0x0DBB, opcode::OP_Invalid },
    { 0x0DBC, opcode::OP_Invalid },
    { 0x0DBD, opcode::OP_JumpOnTrue },
    { 0x0DBE, opcode::OP_GetAPIFunction },
    { 0x0DBF, opcode::OP_Jump },
    { 0x0DC0, opcode::OP_GetString },
    { 0x0DC1, opcode::OP_EndOn },
    { 0x0DC2, opcode::OP_Invalid },
    { 0x0DC3, opcode::OP_LessThan },
    { 0x0DC4, opcode::OP_Invalid },
    { 0x0DC5, opcode::OP_ProfileStop },
    { 0x0DC6, opcode::OP_EvalArrayRef },
    { 0x0DC7, opcode::OP_Invalid },
    { 0x0DC8, opcode::OP_Invalid },
    { 0x0DC9, opcode::OP_Inc },
    { 0x0DCA, opcode::OP_EvalLocalVariableRefCached },
    { 0x0DCB, opcode::OP_SuperNotEqual },
    { 0x0DCC, opcode::OP_Switch },
    { 0x0DCD, opcode::OP_JumpOnTrue },
    { 0x0DCE, opcode::OP_Divide },
    { 0x0DCF, opcode::OP_CallBuiltinMethod },
    { 0x0DD0, opcode::OP_Equal },
    { 0x0DD1, opcode::OP_GetIString },
    { 0x0DD2, opcode::OP_GetAnimation },
    { 0x0DD3, opcode::OP_New },
    { 0x0DD4, opcode::OP_GetUndefined },
    { 0x0DD5, opcode::OP_Divide },
    { 0x0DD6, opcode::OP_ScriptThreadCall },
    { 0x0DD7, opcode::OP_ScriptFunctionCall },
    { 0x0DD8, opcode::OP_GetAnimObject },
    { 0x0DD9, opcode::OP_GetUndefined },
    { 0x0DDA, opcode::OP_Invalid },
    { 0x0DDB, opcode::OP_GetUndefined },
    { 0x0DDC, opcode::OP_ScriptMethodCallPointer },
    { 0x0DDD, opcode::OP_Dec },
    { 0x0DDE, opcode::OP_Invalid },
    { 0x0DDF, opcode::OP_Invalid },
    { 0x0DE0, opcode::OP_GetAPIFunction },
    { 0x0DE1, opcode::OP_ScriptThreadCallPointer },
    { 0x0DE2, opcode::OP_GetByte },
    { 0x0DE3, opcode::OP_Invalid },
    { 0x0DE4, opcode::OP_Jump },
    { 0x0DE5, opcode::OP_ScriptMethodThreadCall },
    { 0x0DE6, opcode::OP_Invalid },
    { 0x0DE7, opcode::OP_EvalArrayRef },
    { 0x0DE8, opcode::OP_Invalid },
    { 0x0DE9, opcode::OP_Bit_Or },
    { 0x0DEA, opcode::OP_CallBuiltinMethod },
    { 0x0DEB, opcode::OP_Notify },
    { 0x0DEC, opcode::OP_ProfileStart },
    { 0x0DED, opcode::OP_Invalid },
    { 0x0DEE, opcode::OP_Jump },
    { 0x0DEF, opcode::OP_CallBuiltinMethod },
    { 0x0DF0, opcode::OP_Invalid },
    { 0x0DF1, opcode::OP_Invalid },
    { 0x0DF2, opcode::OP_Invalid },
    { 0x0DF3, opcode::OP_CastFieldObject },
    { 0x0DF4, opcode::OP_Invalid },
    { 0x0DF5, opcode::OP_Invalid },
    { 0x0DF6, opcode::OP_Invalid },
    { 0x0DF7, opcode::OP_Invalid },
    { 0x0DF8, opcode::OP_Dec },
    { 0x0DF9, opcode::OP_Invalid },
    { 0x0DFA, opcode::OP_LevelEvalFieldVariableRef },
    { 0x0DFB, opcode::OP_Invalid },
    { 0x0DFC, opcode::OP_GetUnsignedShort },
    { 0x0DFD, opcode::OP_GetAnim },
    { 0x0DFE, opcode::OP_EndSwitch },
    { 0x0DFF, opcode::OP_GetHash },
    { 0x0E00, opcode::OP_Switch },
    { 0x0E01, opcode::OP_Wait },
    { 0x0E02, opcode::OP_Invalid },
    { 0x0E03, opcode::OP_Invalid },
    { 0x0E04, opcode::OP_NotEqual },
    { 0x0E05, opcode::OP_NextArrayKey },
    { 0x0E06, opcode::OP_ScriptThreadCallPointer },
    { 0x0E07, opcode::OP_EvalLocalVariableRefCached },
    { 0x0E08, opcode::OP_ScriptFunctionCall },
    { 0x0E09, opcode::OP_Invalid },
    { 0x0E0A, opcode::OP_GetIString },
    { 0x0E0B, opcode::OP_Invalid },
    { 0x0E0C, opcode::OP_Plus },
    { 0x0E0D, opcode::OP_Invalid },
    { 0x0E0E, opcode::OP_Invalid },
    { 0x0E0F, opcode::OP_Invalid },
    { 0x0E10, opcode::OP_Notify },
    { 0x0E11, opcode::OP_Switch },
    { 0x0E12, opcode::OP_Invalid },
    { 0x0E13, opcode::OP_EvalArray },
    { 0x0E14, opcode::OP_ScriptFunctionCallPointer },
    { 0x0E15, opcode::OP_ScriptThreadCall },
    { 0x0E16, opcode::OP_EvalLocalVariableRefCached },
    { 0x0E17, opcode::OP_SafeDecTop },
    { 0x0E18, opcode::OP_GetNegByte },
    { 0x0E19, opcode::OP_EvalLocalVariableRefCached },
    { 0x0E1A, opcode::OP_Multiply },
    { 0x0E1B, opcode::OP_EvalFieldVariable },
    { 0x0E1C, opcode::OP_Invalid },
    { 0x0E1D, opcode::OP_GetSelfObject },
    { 0x0E1E, opcode::OP_Invalid },
    { 0x0E1F, opcode::OP_GetNegByte },
    { 0x0E20, opcode::OP_GetTime },
    { 0x0E21, opcode::OP_SafeCreateLocalVariables },
    { 0x0E22, opcode::OP_Invalid },
    { 0x0E23, opcode::OP_JumpOnTrue },
    { 0x0E24, opcode::OP_EvalLocalVariableCached },
    { 0x0E25, opcode::OP_GetClassesObject },
    { 0x0E26, opcode::OP_Invalid },
    { 0x0E27, opcode::OP_EndOn },
    { 0x0E28, opcode::OP_ScriptFunctionCallClass },
    { 0x0E29, opcode::OP_GetNegUnsignedShort },
    { 0x0E2A, opcode::OP_GetNegUnsignedShort },
    { 0x0E2B, opcode::OP_Divide },
    { 0x0E2C, opcode::OP_Invalid },
    { 0x0E2D, opcode::OP_ScriptThreadCallClass },
    { 0x0E2E, opcode::OP_IsDefined },
    { 0x0E2F, opcode::OP_CallBuiltinMethod },
    { 0x0E30, opcode::OP_GetInteger },
    { 0x0E31, opcode::OP_GetSelfObject },
    { 0x0E32, opcode::OP_GetSelfObject },
    { 0x0E33, opcode::OP_Invalid },
    { 0x0E34, opcode::OP_GetTime },
    { 0x0E35, opcode::OP_JumpOnTrueExpr },
    { 0x0E36, opcode::OP_Plus },
    { 0x0E37, opcode::OP_ScriptFunctionCallClass },
    { 0x0E38, opcode::OP_Switch },
    { 0x0E39, opcode::OP_CallBuiltinMethod },
    { 0x0E3A, opcode::OP_GetFunction },
    { 0x0E3B, opcode::OP_GreaterThan },
    { 0x0E3C, opcode::OP_ScriptFunctionCall },
    { 0x0E3D, opcode::OP_GetInteger },
    { 0x0E3E, opcode::OP_GetFloat },
    { 0x0E3F, opcode::OP_LessThanOrEqualTo },
    { 0x0E40, opcode::OP_GetLevelObject },
    { 0x0E41, opcode::OP_Bit_Or },
    { 0x0E42, opcode::OP_VectorConstant },
    { 0x0E43, opcode::OP_CastFieldObject },
    { 0x0E44, opcode::OP_Invalid },
    { 0x0E45, opcode::OP_LessThanOrEqualTo },
    { 0x0E46, opcode::OP_EvalFieldVariableRef },
    { 0x0E47, opcode::OP_Invalid },
    { 0x0E48, opcode::OP_Invalid },
    { 0x0E49, opcode::OP_Invalid },
    { 0x0E4A, opcode::OP_SizeOf },
    { 0x0E4B, opcode::OP_GetAnimation },
    { 0x0E4C, opcode::OP_Vector },
    { 0x0E4D, opcode::OP_DevblockBegin },
    { 0x0E4E, opcode::OP_Invalid },
    { 0x0E4F, opcode::OP_EvalArray },
    { 0x0E50, opcode::OP_Invalid },
    { 0x0E51, opcode::OP_Jump },
    { 0x0E52, opcode::OP_GreaterThan },
    { 0x0E53, opcode::OP_LessThanOrEqualTo },
    { 0x0E54, opcode::OP_JumpOnFalseExpr },
    { 0x0E55, opcode::OP_GetIString },
    { 0x0E56, opcode::OP_Bit_And },
    { 0x0E57, opcode::OP_GetWorldObject },
    { 0x0E58, opcode::OP_GetGame },
    { 0x0E59, opcode::OP_BoolComplement },
    { 0x0E5A, opcode::OP_EndSwitch },
    { 0x0E5B, opcode::OP_Invalid },
    { 0x0E5C, opcode::OP_LessThan },
    { 0x0E5D, opcode::OP_LevelEvalFieldVariable },
    { 0x0E5E, opcode::OP_GetAPIFunction },
    { 0x0E5F, opcode::OP_ClearArray },
    { 0x0E60, opcode::OP_Invalid },
    { 0x0E61, opcode::OP_LevelEvalFieldVariable },
    { 0x0E62, opcode::OP_Plus },
    { 0x0E63, opcode::OP_Inc },
    { 0x0E64, opcode::OP_EvalLocalVariableRefCached },
    { 0x0E65, opcode::OP_Invalid },
    { 0x0E66, opcode::OP_Invalid },
    { 0x0E67, opcode::OP_Invalid },
    { 0x0E68, opcode::OP_ScriptFunctionCallClass },
    { 0x0E69, opcode::OP_GetClassesObject },
    { 0x0E6A, opcode::OP_GetSelfObject },
    { 0x0E6B, opcode::OP_Invalid },
    { 0x0E6C, opcode::OP_Invalid },
    { 0x0E6D, opcode::OP_Invalid },
    { 0x0E6E, opcode::OP_Invalid },
    { 0x0E6F, opcode::OP_EvalArray },
    { 0x0E70, opcode::OP_Invalid },
    { 0x0E71, opcode::OP_BoolComplement },
    { 0x0E72, opcode::OP_Invalid },
    { 0x0E73, opcode::OP_Invalid },
    { 0x0E74, opcode::OP_Invalid },
    { 0x0E75, opcode::OP_GetInteger },
    { 0x0E76, opcode::OP_GetWorldObject },
    { 0x0E77, opcode::OP_Invalid },
    { 0x0E78, opcode::OP_EvalFieldVariable },
    { 0x0E79, opcode::OP_GetUnsignedShort },
    { 0x0E7A, opcode::OP_Invalid },
    { 0x0E7B, opcode::OP_Notify },
    { 0x0E7C, opcode::OP_SuperNotEqual },
    { 0x0E7D, opcode::OP_EvalFieldVariableRef },
    { 0x0E7E, opcode::OP_ClearFieldVariable },
    { 0x0E7F, opcode::OP_Invalid },
    { 0x0E80, opcode::OP_ScriptMethodThreadCall },
    { 0x0E81, opcode::OP_Invalid },
    { 0x0E82, opcode::OP_GreaterThanOrEqualTo },
    { 0x0E83, opcode::OP_Invalid },
    { 0x0E84, opcode::OP_DecTop },
    { 0x0E85, opcode::OP_Invalid },
    { 0x0E86, opcode::OP_EvalFieldVariableRef },
    { 0x0E87, opcode::OP_DecTop },
    { 0x0E88, opcode::OP_ScriptFunctionCallClass },
    { 0x0E89, opcode::OP_Invalid },
    { 0x0E8A, opcode::OP_GetFloat },
    { 0x0E8B, opcode::OP_Invalid },
    { 0x0E8C, opcode::OP_DecTop },
    { 0x0E8D, opcode::OP_Invalid },
    { 0x0E8E, opcode::OP_Invalid },
    { 0x0E8F, opcode::OP_Invalid },
    { 0x0E90, opcode::OP_Invalid },
    { 0x0E91, opcode::OP_GetClasses },
    { 0x0E92, opcode::OP_Inc },
    { 0x0E93, opcode::OP_Invalid },
    { 0x0E94, opcode::OP_GetSelf },
    { 0x0E95, opcode::OP_Invalid },
    { 0x0E96, opcode::OP_GreaterThanOrEqualTo },
    { 0x0E97, opcode::OP_Divide },
    { 0x0E98, opcode::OP_Invalid },
    { 0x0E99, opcode::OP_ScriptFunctionCallClass },
    { 0x0E9A, opcode::OP_GetInteger },
    { 0x0E9B, opcode::OP_GetUnsignedShort },
    { 0x0E9C, opcode::OP_WaitTillFrameEnd },
    { 0x0E9D, opcode::OP_ScriptThreadCallPointer },
    { 0x0E9E, opcode::OP_GetSelf },
    { 0x0E9F, opcode::OP_Plus },
    { 0x0EA0, opcode::OP_Multiply },
    { 0x0EA1, opcode::OP_ClearArray },
    { 0x0EA2, opcode::OP_EvalFieldVariable },
    { 0x0EA3, opcode::OP_Invalid },
    { 0x0EA4, opcode::OP_SafeDecTop },
    { 0x0EA5, opcode::OP_GetClassesObject },
    { 0x0EA6, opcode::OP_Switch },
    { 0x0EA7, opcode::OP_Invalid },
    { 0x0EA8, opcode::OP_RealWait },
    { 0x0EA9, opcode::OP_DecTop },
    { 0x0EAA, opcode::OP_GetUndefined },
    { 0x0EAB, opcode::OP_ShiftRight },
    { 0x0EAC, opcode::OP_Invalid },
    { 0x0EAD, opcode::OP_LessThan },
    { 0x0EAE, opcode::OP_DecTop },
    { 0x0EAF, opcode::OP_NotEqual },
    { 0x0EB0, opcode::OP_Invalid },
    { 0x0EB1, opcode::OP_Invalid },
    { 0x0EB2, opcode::OP_Invalid },
    { 0x0EB3, opcode::OP_GetInteger },
    { 0x0EB4, opcode::OP_Bit_Or },
    { 0x0EB5, opcode::OP_Bit_Or },
    { 0x0EB6, opcode::OP_GetFunction },
    { 0x0EB7, opcode::OP_Invalid },
    { 0x0EB8, opcode::OP_NotEqual },
    { 0x0EB9, opcode::OP_Jump },
    { 0x0EBA, opcode::OP_GetUndefined },
    { 0x0EBB, opcode::OP_JumpOnTrueExpr },
    { 0x0EBC, opcode::OP_RealWait },
    { 0x0EBD, opcode::OP_EvalFieldVariableRef },
    { 0x0EBE, opcode::OP_Invalid },
    { 0x0EBF, opcode::OP_GetNegUnsignedShort },
    { 0x0EC0, opcode::OP_GetUnsignedShort },
    { 0x0EC1, opcode::OP_Invalid },
    { 0x0EC2, opcode::OP_GreaterThanOrEqualTo },
    { 0x0EC3, opcode::OP_Invalid },
    { 0x0EC4, opcode::OP_GetZero },
    { 0x0EC5, opcode::OP_Wait },
    { 0x0EC6, opcode::OP_GetTime },
    { 0x0EC7, opcode::OP_Invalid },
    { 0x0EC8, opcode::OP_Invalid },
    { 0x0EC9, opcode::OP_GetWorldObject },
    { 0x0ECA, opcode::OP_GetUndefined },
    { 0x0ECB, opcode::OP_Invalid },
    { 0x0ECC, opcode::OP_Invalid },
    { 0x0ECD, opcode::OP_Invalid },
    { 0x0ECE, opcode::OP_EndOn },
    { 0x0ECF, opcode::OP_Invalid },
    { 0x0ED0, opcode::OP_JumpOnTrue },
    { 0x0ED1, opcode::OP_GreaterThan },
    { 0x0ED2, opcode::OP_LessThan },
    { 0x0ED3, opcode::OP_GetGameRef },
    { 0x0ED4, opcode::OP_EmptyArray },
    { 0x0ED5, opcode::OP_WaitTillFrameEnd },
    { 0x0ED6, opcode::OP_Divide },
    { 0x0ED7, opcode::OP_GetSelfObject },
    { 0x0ED8, opcode::OP_ScriptFunctionCall },
    { 0x0ED9, opcode::OP_ShiftRight },
    { 0x0EDA, opcode::OP_FirstArrayKey },
    { 0x0EDB, opcode::OP_GetHash },
    { 0x0EDC, opcode::OP_WaitTillFrameEnd },
    { 0x0EDD, opcode::OP_GreaterThan },
    { 0x0EDE, opcode::OP_Invalid },
    { 0x0EDF, opcode::OP_Vector },
    { 0x0EE0, opcode::OP_GetHash },
    { 0x0EE1, opcode::OP_BoolNot },
    { 0x0EE2, opcode::OP_GetUintptr },
    { 0x0EE3, opcode::OP_EvalArrayRef },
    { 0x0EE4, opcode::OP_GetIString },
    { 0x0EE5, opcode::OP_Invalid },
    { 0x0EE6, opcode::OP_IsDefined },
    { 0x0EE7, opcode::OP_Invalid },
    { 0x0EE8, opcode::OP_GetUnsignedShort },
    { 0x0EE9, opcode::OP_Invalid },
    { 0x0EEA, opcode::OP_Invalid },
    { 0x0EEB, opcode::OP_Invalid },
    { 0x0EEC, opcode::OP_ScriptFunctionCall },
    { 0x0EED, opcode::OP_GetVector },
    { 0x0EEE, opcode::OP_Notify },
    { 0x0EEF, opcode::OP_Modulus },
    { 0x0EF0, opcode::OP_JumpOnTrueExpr },
    { 0x0EF1, opcode::OP_ClearArray },
    { 0x0EF2, opcode::OP_LevelEvalFieldVariable },
    { 0x0EF3, opcode::OP_Invalid },
    { 0x0EF4, opcode::OP_GetLevelObject },
    { 0x0EF5, opcode::OP_Bit_Or },
    { 0x0EF6, opcode::OP_JumpOnFalseExpr },
    { 0x0EF7, opcode::OP_JumpOnTrue },
    { 0x0EF8, opcode::OP_VectorScale },
    { 0x0EF9, opcode::OP_BoolComplement },
    { 0x0EFA, opcode::OP_JumpOnTrueExpr },
    { 0x0EFB, opcode::OP_ScriptMethodThreadCall },
    { 0x0EFC, opcode::OP_VectorConstant },
    { 0x0EFD, opcode::OP_Inc },
    { 0x0EFE, opcode::OP_Invalid },
    { 0x0EFF, opcode::OP_GetAnim },
    { 0x0F00, opcode::OP_ScriptFunctionCallClass },
    { 0x0F01, opcode::OP_GetFloat },
    { 0x0F02, opcode::OP_ScriptThreadCallClass },
    { 0x0F03, opcode::OP_EvalLocalVariableRefCached },
    { 0x0F04, opcode::OP_NextArrayKey },
    { 0x0F05, opcode::OP_ClearArray },
    { 0x0F06, opcode::OP_Invalid },
    { 0x0F07, opcode::OP_GetByte },
    { 0x0F08, opcode::OP_GetUnsignedShort },
    { 0x0F09, opcode::OP_ProfileStart },
    { 0x0F0A, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x0F0B, opcode::OP_EvalFieldVariableRef },
    { 0x0F0C, opcode::OP_Multiply },
    { 0x0F0D, opcode::OP_GreaterThan },
    { 0x0F0E, opcode::OP_SafeDecTop },
    { 0x0F0F, opcode::OP_Invalid },
    { 0x0F10, opcode::OP_Invalid },
    { 0x0F11, opcode::OP_LessThan },
    { 0x0F12, opcode::OP_Return },
    { 0x0F13, opcode::OP_GetAPIFunction },
    { 0x0F14, opcode::OP_Invalid },
    { 0x0F15, opcode::OP_Invalid },
    { 0x0F16, opcode::OP_Invalid },
    { 0x0F17, opcode::OP_GetByte },
    { 0x0F18, opcode::OP_Invalid },
    { 0x0F19, opcode::OP_ScriptFunctionCallClass },
    { 0x0F1A, opcode::OP_ScriptFunctionCallClass },
    { 0x0F1B, opcode::OP_Vector },
    { 0x0F1C, opcode::OP_Switch },
    { 0x0F1D, opcode::OP_JumpOnFalseExpr },
    { 0x0F1E, opcode::OP_Bit_And },
    { 0x0F1F, opcode::OP_GetUndefined },
    { 0x0F20, opcode::OP_Inc },
    { 0x0F21, opcode::OP_GetWorld },
    { 0x0F22, opcode::OP_GreaterThan },
    { 0x0F23, opcode::OP_GetAPIFunction },
    { 0x0F24, opcode::OP_EvalFieldVariable },
    { 0x0F25, opcode::OP_Invalid },
    { 0x0F26, opcode::OP_Jump },
    { 0x0F27, opcode::OP_SelfEvalFieldVariable },
    { 0x0F28, opcode::OP_SafeDecTop },
    { 0x0F29, opcode::OP_Invalid },
    { 0x0F2A, opcode::OP_Invalid },
    { 0x0F2B, opcode::OP_GetAPIFunction },
    { 0x0F2C, opcode::OP_GetTime },
    { 0x0F2D, opcode::OP_Invalid },
    { 0x0F2E, opcode::OP_FirstArrayKey },
    { 0x0F2F, opcode::OP_Invalid },
    { 0x0F30, opcode::OP_Invalid },
    { 0x0F31, opcode::OP_EndOn },
    { 0x0F32, opcode::OP_Invalid },
    { 0x0F33, opcode::OP_ScriptThreadCall },
    { 0x0F34, opcode::OP_Invalid },
    { 0x0F35, opcode::OP_GetSelf },
    { 0x0F36, opcode::OP_Invalid },
    { 0x0F37, opcode::OP_BoolComplement },
    { 0x0F38, opcode::OP_Invalid },
    { 0x0F39, opcode::OP_ShiftLeft },
    { 0x0F3A, opcode::OP_Bit_Or },
    { 0x0F3B, opcode::OP_Invalid },
    { 0x0F3C, opcode::OP_Invalid },
    { 0x0F3D, opcode::OP_ScriptFunctionCall },
    { 0x0F3E, opcode::OP_GetAnimObject },
    { 0x0F3F, opcode::OP_ProfileStop },
    { 0x0F40, opcode::OP_GetLevelObject },
    { 0x0F41, opcode::OP_VectorScale },
    { 0x0F42, opcode::OP_Invalid },
    { 0x0F43, opcode::OP_Invalid },
    { 0x0F44, opcode::OP_Return },
    { 0x0F45, opcode::OP_Invalid },
    { 0x0F46, opcode::OP_GetAnimObject },
    { 0x0F47, opcode::OP_ScriptThreadCall },
    { 0x0F48, opcode::OP_GetClassesObject },
    { 0x0F49, opcode::OP_GetAnim },
    { 0x0F4A, opcode::OP_GetGameRef },
    { 0x0F4B, opcode::OP_SizeOf },
    { 0x0F4C, opcode::OP_GetWorldObject },
    { 0x0F4D, opcode::OP_GetIString },
    { 0x0F4E, opcode::OP_Invalid },
    { 0x0F4F, opcode::OP_Invalid },
    { 0x0F50, opcode::OP_GetGame },
    { 0x0F51, opcode::OP_GetFloat },
    { 0x0F52, opcode::OP_Invalid },
    { 0x0F53, opcode::OP_LessThan },
    { 0x0F54, opcode::OP_ScriptThreadCall },
    { 0x0F55, opcode::OP_SuperEqual },
    { 0x0F56, opcode::OP_ClearArray },
    { 0x0F57, opcode::OP_LevelEvalFieldVariableRef },
    { 0x0F58, opcode::OP_GetSelfObject },
    { 0x0F59, opcode::OP_Invalid },
    { 0x0F5A, opcode::OP_ProfileStop },
    { 0x0F5B, opcode::OP_Notify },
    { 0x0F5C, opcode::OP_BoolComplement },
    { 0x0F5D, opcode::OP_Invalid },
    { 0x0F5E, opcode::OP_SelfEvalFieldVariableRef },
    { 0x0F5F, opcode::OP_VectorConstant },
    { 0x0F60, opcode::OP_Invalid },
    { 0x0F61, opcode::OP_GetHash },
    { 0x0F62, opcode::OP_SelfEvalFieldVariable },
    { 0x0F63, opcode::OP_DecTop },
    { 0x0F64, opcode::OP_Invalid },
    { 0x0F65, opcode::OP_JumpOnFalseExpr },
    { 0x0F66, opcode::OP_Invalid },
    { 0x0F67, opcode::OP_GetNegUnsignedShort },
    { 0x0F68, opcode::OP_LevelEvalFieldVariable },
    { 0x0F69, opcode::OP_RealWait },
    { 0x0F6A, opcode::OP_GetAnim },
    { 0x0F6B, opcode::OP_Invalid },
    { 0x0F6C, opcode::OP_Invalid },
    { 0x0F6D, opcode::OP_Invalid },
    { 0x0F6E, opcode::OP_Invalid },
    { 0x0F6F, opcode::OP_GetGameRef },
    { 0x0F70, opcode::OP_DecTop },
    { 0x0F71, opcode::OP_EvalFieldVariable },
    { 0x0F72, opcode::OP_GetNegByte },
    { 0x0F73, opcode::OP_WaitTill },
    { 0x0F74, opcode::OP_ScriptMethodCallPointer },
    { 0x0F75, opcode::OP_SelfEvalFieldVariable },
    { 0x0F76, opcode::OP_Invalid },
    { 0x0F77, opcode::OP_NotEqual },
    { 0x0F78, opcode::OP_Invalid },
    { 0x0F79, opcode::OP_Invalid },
    { 0x0F7A, opcode::OP_ScriptMethodThreadCall },
    { 0x0F7B, opcode::OP_GetSelfObject },
    { 0x0F7C, opcode::OP_GetWorldObject },
    { 0x0F7D, opcode::OP_GetLevel },
    { 0x0F7E, opcode::OP_Invalid },
    { 0x0F7F, opcode::OP_Plus },
    { 0x0F80, opcode::OP_Invalid },
    { 0x0F81, opcode::OP_Invalid },
    { 0x0F82, opcode::OP_Jump },
    { 0x0F83, opcode::OP_GetString },
    { 0x0F84, opcode::OP_LevelEvalFieldVariableRef },
    { 0x0F85, opcode::OP_GreaterThan },
    { 0x0F86, opcode::OP_GetUndefined },
    { 0x0F87, opcode::OP_Minus },
    { 0x0F88, opcode::OP_GetAPIFunction },
    { 0x0F89, opcode::OP_LessThanOrEqualTo },
    { 0x0F8A, opcode::OP_Invalid },
    { 0x0F8B, opcode::OP_IsDefined },
    { 0x0F8C, opcode::OP_Invalid },
    { 0x0F8D, opcode::OP_Modulus },
    { 0x0F8E, opcode::OP_GetClasses },
    { 0x0F8F, opcode::OP_Wait },
    { 0x0F90, opcode::OP_RealWait },
    { 0x0F91, opcode::OP_Invalid },
    { 0x0F92, opcode::OP_GetGame },
    { 0x0F93, opcode::OP_ScriptMethodCall },
    { 0x0F94, opcode::OP_Invalid },
    { 0x0F95, opcode::OP_Invalid },
    { 0x0F96, opcode::OP_GetHash },
    { 0x0F97, opcode::OP_EvalArrayRef },
    { 0x0F98, opcode::OP_Invalid },
    { 0x0F99, opcode::OP_GetTime },
    { 0x0F9A, opcode::OP_Invalid },
    { 0x0F9B, opcode::OP_Invalid },
    { 0x0F9C, opcode::OP_Invalid },
    { 0x0F9D, opcode::OP_LessThanOrEqualTo },
    { 0x0F9E, opcode::OP_GetUnsignedShort },
    { 0x0F9F, opcode::OP_GetSelfObject },
    { 0x0FA0, opcode::OP_Switch },
    { 0x0FA1, opcode::OP_GetAPIFunction },
    { 0x0FA2, opcode::OP_GetAnimation },
    { 0x0FA3, opcode::OP_ClearArray },
    { 0x0FA4, opcode::OP_ScriptThreadCall },
    { 0x0FA5, opcode::OP_GetByte },
    { 0x0FA6, opcode::OP_LevelEvalFieldVariableRef },
    { 0x0FA7, opcode::OP_RealWait },
    { 0x0FA8, opcode::OP_GetVector },
    { 0x0FA9, opcode::OP_GreaterThan },
    { 0x0FAA, opcode::OP_GetClassesObject },
    { 0x0FAB, opcode::OP_Invalid },
    { 0x0FAC, opcode::OP_Invalid },
    { 0x0FAD, opcode::OP_Modulus },
    { 0x0FAE, opcode::OP_SuperNotEqual },
    { 0x0FAF, opcode::OP_ScriptFunctionCallClass },
    { 0x0FB0, opcode::OP_Bit_And },
    { 0x0FB1, opcode::OP_Invalid },
    { 0x0FB2, opcode::OP_Invalid },
    { 0x0FB3, opcode::OP_Invalid },
    { 0x0FB4, opcode::OP_Dec },
    { 0x0FB5, opcode::OP_SelfEvalFieldVariable },
    { 0x0FB6, opcode::OP_EvalLocalVariableCached },
    { 0x0FB7, opcode::OP_Switch },
    { 0x0FB8, opcode::OP_Return },
    { 0x0FB9, opcode::OP_GetLevel },
    { 0x0FBA, opcode::OP_ScriptMethodThreadCall },
    { 0x0FBB, opcode::OP_Notify },
    { 0x0FBC, opcode::OP_GetSelf },
    { 0x0FBD, opcode::OP_Invalid },
    { 0x0FBE, opcode::OP_Invalid },
    { 0x0FBF, opcode::OP_Dec },
    { 0x0FC0, opcode::OP_EvalFieldVariable },
    { 0x0FC1, opcode::OP_NextArrayKey },
    { 0x0FC2, opcode::OP_Dec },
    { 0x0FC3, opcode::OP_Notify },
    { 0x0FC4, opcode::OP_JumpOnTrueExpr },
    { 0x0FC5, opcode::OP_Invalid },
    { 0x0FC6, opcode::OP_Invalid },
    { 0x0FC7, opcode::OP_LessThanOrEqualTo },
    { 0x0FC8, opcode::OP_SafeSetVariableFieldCached },
    { 0x0FC9, opcode::OP_GetZero },
    { 0x0FCA, opcode::OP_GetByte },
    { 0x0FCB, opcode::OP_Invalid },
    { 0x0FCC, opcode::OP_ScriptMethodThreadCall },
    { 0x0FCD, opcode::OP_EndSwitch },
    { 0x0FCE, opcode::OP_GetNegUnsignedShort },
    { 0x0FCF, opcode::OP_Invalid },
    { 0x0FD0, opcode::OP_EvalLocalVariableCached },
    { 0x0FD1, opcode::OP_GreaterThanOrEqualTo },
    { 0x0FD2, opcode::OP_GetAnim },
    { 0x0FD3, opcode::OP_EvalLocalVariableCached },
    { 0x0FD4, opcode::OP_ScriptFunctionCall },
    { 0x0FD5, opcode::OP_NotEqual },
    { 0x0FD6, opcode::OP_Switch },
    { 0x0FD7, opcode::OP_Invalid },
    { 0x0FD8, opcode::OP_ScriptFunctionCallClass },
    { 0x0FD9, opcode::OP_Jump },
    { 0x0FDA, opcode::OP_ProfileStop },
    { 0x0FDB, opcode::OP_GetByte },
    { 0x0FDC, opcode::OP_Invalid },
    { 0x0FDD, opcode::OP_Invalid },
    { 0x0FDE, opcode::OP_Invalid },
    { 0x0FDF, opcode::OP_Invalid },
    { 0x0FE0, opcode::OP_GetSelf },
    { 0x0FE1, opcode::OP_Invalid },
    { 0x0FE2, opcode::OP_DecTop },
    { 0x0FE3, opcode::OP_Invalid },
    { 0x0FE4, opcode::OP_Invalid },
    { 0x0FE5, opcode::OP_ProfileStop },
    { 0x0FE6, opcode::OP_DevblockBegin },
    { 0x0FE7, opcode::OP_Plus },
    { 0x0FE8, opcode::OP_SelfEvalFieldVariableRef },
    { 0x0FE9, opcode::OP_Invalid },
    { 0x0FEA, opcode::OP_Invalid },
    { 0x0FEB, opcode::OP_Invalid },
    { 0x0FEC, opcode::OP_Invalid },
    { 0x0FED, opcode::OP_NextArrayKey },
    { 0x0FEE, opcode::OP_DevblockBegin },
    { 0x0FEF, opcode::OP_ScriptFunctionCallClass },
    { 0x0FF0, opcode::OP_GetWorldObject },
    { 0x0FF1, opcode::OP_Invalid },
    { 0x0FF2, opcode::OP_Invalid },
    { 0x0FF3, opcode::OP_Switch },
    { 0x0FF4, opcode::OP_Invalid },
    { 0x0FF5, opcode::OP_Invalid },
    { 0x0FF6, opcode::OP_Invalid },
    { 0x0FF7, opcode::OP_Invalid },
    { 0x0FF8, opcode::OP_Invalid },
    { 0x0FF9, opcode::OP_Invalid },
    { 0x0FFA, opcode::OP_Bit_Xor },
    { 0x0FFB, opcode::OP_Invalid },
    { 0x0FFC, opcode::OP_GetAPIFunction },
    { 0x0FFD, opcode::OP_Invalid },
    { 0x0FFE, opcode::OP_EvalLocalVariableRefCached },
    { 0x0FFF, opcode::OP_Invalid },
    { 0x1000, opcode::OP_CastFieldObject },
    { 0x1001, opcode::OP_Invalid },
    { 0x1002, opcode::OP_Bit_Xor },
    { 0x1003, opcode::OP_Invalid },
    { 0x1004, opcode::OP_Invalid },
    { 0x1005, opcode::OP_EvalFieldVariable },
    { 0x1006, opcode::OP_Bit_Xor },
    { 0x1007, opcode::OP_ScriptThreadCallPointer },
    { 0x1008, opcode::OP_GetGameRef },
    { 0x1009, opcode::OP_GetInteger },
    { 0x100A, opcode::OP_NextArrayKey },
    { 0x100B, opcode::OP_GetZero },
    { 0x100C, opcode::OP_EndOn },
    { 0x100D, opcode::OP_Multiply },
    { 0x100E, opcode::OP_EndSwitch },
    { 0x100F, opcode::OP_EvalFieldVariable },
    { 0x1010, opcode::OP_GetFunction },
    { 0x1011, opcode::OP_Invalid },
    { 0x1012, opcode::OP_GetInteger },
    { 0x1013, opcode::OP_Notify },
    { 0x1014, opcode::OP_Invalid },
    { 0x1015, opcode::OP_GetAPIFunction },
    { 0x1016, opcode::OP_Invalid },
    { 0x1017, opcode::OP_Invalid },
    { 0x1018, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x1019, opcode::OP_GetUnsignedShort },
    { 0x101A, opcode::OP_GreaterThanOrEqualTo },
    { 0x101B, opcode::OP_JumpOnTrue },
    { 0x101C, opcode::OP_GetAPIFunction },
    { 0x101D, opcode::OP_ProfileStop },
    { 0x101E, opcode::OP_RealWait },
    { 0x101F, opcode::OP_GetSelfObject },
    { 0x1020, opcode::OP_Inc },
    { 0x1021, opcode::OP_GetIString },
    { 0x1022, opcode::OP_EvalLocalVariableRefCached },
    { 0x1023, opcode::OP_GetClassesObject },
    { 0x1024, opcode::OP_Invalid },
    { 0x1025, opcode::OP_ScriptFunctionCall },
    { 0x1026, opcode::OP_Switch },
    { 0x1027, opcode::OP_Invalid },
    { 0x1028, opcode::OP_BoolComplement },
    { 0x1029, opcode::OP_GetNegUnsignedShort },
    { 0x102A, opcode::OP_GetNegByte },
    { 0x102B, opcode::OP_JumpOnTrue },
    { 0x102C, opcode::OP_Multiply },
    { 0x102D, opcode::OP_ProfileStart },
    { 0x102E, opcode::OP_Modulus },
    { 0x102F, opcode::OP_Invalid },
    { 0x1030, opcode::OP_IsDefined },
    { 0x1031, opcode::OP_Invalid },
    { 0x1032, opcode::OP_Invalid },
    { 0x1033, opcode::OP_Invalid },
    { 0x1034, opcode::OP_Invalid },
    { 0x1035, opcode::OP_RealWait },
    { 0x1036, opcode::OP_Divide },
    { 0x1037, opcode::OP_GetLevel },
    { 0x1038, opcode::OP_Vector },
    { 0x1039, opcode::OP_GetUndefined },
    { 0x103A, opcode::OP_Invalid },
    { 0x103B, opcode::OP_LessThan },
    { 0x103C, opcode::OP_Invalid },
    { 0x103D, opcode::OP_Invalid },
    { 0x103E, opcode::OP_SizeOf },
    { 0x103F, opcode::OP_Invalid },
    { 0x1040, opcode::OP_GetUnsignedShort },
    { 0x1041, opcode::OP_Invalid },
    { 0x1042, opcode::OP_GreaterThan },
    { 0x1043, opcode::OP_Invalid },
    { 0x1044, opcode::OP_GetAPIFunction },
    { 0x1045, opcode::OP_Invalid },
    { 0x1046, opcode::OP_Invalid },
    { 0x1047, opcode::OP_Invalid },
    { 0x1048, opcode::OP_Invalid },
    { 0x1049, opcode::OP_Invalid },
    { 0x104A, opcode::OP_Invalid },
    { 0x104B, opcode::OP_RealWait },
    { 0x104C, opcode::OP_GetGame },
    { 0x104D, opcode::OP_Invalid },
    { 0x104E, opcode::OP_Inc },
    { 0x104F, opcode::OP_Dec },
    { 0x1050, opcode::OP_GetNegUnsignedShort },
    { 0x1051, opcode::OP_Invalid },
    { 0x1052, opcode::OP_NextArrayKey },
    { 0x1053, opcode::OP_SelfEvalFieldVariableRef },
    { 0x1054, opcode::OP_Invalid },
    { 0x1055, opcode::OP_GetLevel },
    { 0x1056, opcode::OP_ScriptFunctionCallClass },
    { 0x1057, opcode::OP_Invalid },
    { 0x1058, opcode::OP_Invalid },
    { 0x1059, opcode::OP_GetGame },
    { 0x105A, opcode::OP_LevelEvalFieldVariableRef },
    { 0x105B, opcode::OP_ShiftLeft },
    { 0x105C, opcode::OP_Invalid },
    { 0x105D, opcode::OP_Invalid },
    { 0x105E, opcode::OP_Invalid },
    { 0x105F, opcode::OP_Invalid },
    { 0x1060, opcode::OP_Invalid },
    { 0x1061, opcode::OP_GreaterThanOrEqualTo },
    { 0x1062, opcode::OP_Invalid },
    { 0x1063, opcode::OP_Invalid },
    { 0x1064, opcode::OP_Invalid },
    { 0x1065, opcode::OP_ScriptMethodThreadCall },
    { 0x1066, opcode::OP_GetHash },
    { 0x1067, opcode::OP_SuperNotEqual },
    { 0x1068, opcode::OP_ScriptFunctionCallClass },
    { 0x1069, opcode::OP_Invalid },
    { 0x106A, opcode::OP_GetUndefined },
    { 0x106B, opcode::OP_GetAnimObject },
    { 0x106C, opcode::OP_ShiftRight },
    { 0x106D, opcode::OP_LevelEvalFieldVariableRef },
    { 0x106E, opcode::OP_ShiftRight },
    { 0x106F, opcode::OP_GetNegByte },
    { 0x1070, opcode::OP_GetHash },
    { 0x1071, opcode::OP_Invalid },
    { 0x1072, opcode::OP_JumpOnTrue },
    { 0x1073, opcode::OP_Invalid },
    { 0x1074, opcode::OP_GetLevel },
    { 0x1075, opcode::OP_ScriptMethodThreadCall },
    { 0x1076, opcode::OP_Invalid },
    { 0x1077, opcode::OP_Invalid },
    { 0x1078, opcode::OP_JumpOnFalse },
    { 0x1079, opcode::OP_LessThan },
    { 0x107A, opcode::OP_Divide },
    { 0x107B, opcode::OP_WaitTillMatch },
    { 0x107C, opcode::OP_Invalid },
    { 0x107D, opcode::OP_Invalid },
    { 0x107E, opcode::OP_Divide },
    { 0x107F, opcode::OP_IsDefined },
    { 0x1080, opcode::OP_ScriptMethodCallPointer },
    { 0x1081, opcode::OP_Wait },
    { 0x1082, opcode::OP_NextArrayKey },
    { 0x1083, opcode::OP_EmptyArray },
    { 0x1084, opcode::OP_Invalid },
    { 0x1085, opcode::OP_Notify },
    { 0x1086, opcode::OP_Invalid },
    { 0x1087, opcode::OP_Invalid },
    { 0x1088, opcode::OP_ScriptThreadCall },
    { 0x1089, opcode::OP_GetHash },
    { 0x108A, opcode::OP_ClearArray },
    { 0x108B, opcode::OP_Invalid },
    { 0x108C, opcode::OP_Return },
    { 0x108D, opcode::OP_Invalid },
    { 0x108E, opcode::OP_Invalid },
    { 0x108F, opcode::OP_EndOn },
    { 0x1090, opcode::OP_GetGameRef },
    { 0x1091, opcode::OP_WaitTill },
    { 0x1092, opcode::OP_ClearFieldVariable },
    { 0x1093, opcode::OP_Invalid },
    { 0x1094, opcode::OP_GetTime },
    { 0x1095, opcode::OP_Invalid },
    { 0x1096, opcode::OP_GetAPIFunction },
    { 0x1097, opcode::OP_JumpOnFalseExpr },
    { 0x1098, opcode::OP_GetFloat },
    { 0x1099, opcode::OP_Invalid },
    { 0x109A, opcode::OP_Invalid },
    { 0x109B, opcode::OP_Invalid },
    { 0x109C, opcode::OP_GetAnimation },
    { 0x109D, opcode::OP_ScriptThreadCall },
    { 0x109E, opcode::OP_WaitTillFrameEnd },
    { 0x109F, opcode::OP_NotEqual },
    { 0x10A0, opcode::OP_Plus },
    { 0x10A1, opcode::OP_Invalid },
    { 0x10A2, opcode::OP_GetIString },
    { 0x10A3, opcode::OP_BoolComplement },
    { 0x10A4, opcode::OP_Invalid },
    { 0x10A5, opcode::OP_Invalid },
    { 0x10A6, opcode::OP_Vector },
    { 0x10A7, opcode::OP_GetGameRef },
    { 0x10A8, opcode::OP_GreaterThanOrEqualTo },
    { 0x10A9, opcode::OP_Jump },
    { 0x10AA, opcode::OP_Divide },
    { 0x10AB, opcode::OP_GetLevel },
    { 0x10AC, opcode::OP_EvalFieldVariableRef },
    { 0x10AD, opcode::OP_ProfileStart },
    { 0x10AE, opcode::OP_Inc },
    { 0x10AF, opcode::OP_EvalLocalVariableCached },
    { 0x10B0, opcode::OP_GetSelfObject },
    { 0x10B1, opcode::OP_GetGame },
    { 0x10B2, opcode::OP_SetVariableField },
    { 0x10B3, opcode::OP_GetHash },
    { 0x10B4, opcode::OP_ScriptMethodCallPointer },
    { 0x10B5, opcode::OP_NotEqual },
    { 0x10B6, opcode::OP_GetInteger },
    { 0x10B7, opcode::OP_GetAPIFunction },
    { 0x10B8, opcode::OP_GetZero },
    { 0x10B9, opcode::OP_LevelEvalFieldVariable },
    { 0x10BA, opcode::OP_CastFieldObject },
    { 0x10BB, opcode::OP_Invalid },
    { 0x10BC, opcode::OP_Divide },
    { 0x10BD, opcode::OP_Invalid },
    { 0x10BE, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x10BF, opcode::OP_ShiftLeft },
    { 0x10C0, opcode::OP_New },
    { 0x10C1, opcode::OP_IsDefined },
    { 0x10C2, opcode::OP_FirstArrayKey },
    { 0x10C3, opcode::OP_GetClassesObject },
    { 0x10C4, opcode::OP_EvalFieldVariableRef },
    { 0x10C5, opcode::OP_GetZero },
    { 0x10C6, opcode::OP_Invalid },
    { 0x10C7, opcode::OP_Vector },
    { 0x10C8, opcode::OP_CallBuiltinMethod },
    { 0x10C9, opcode::OP_JumpOnTrueExpr },
    { 0x10CA, opcode::OP_GetTime },
    { 0x10CB, opcode::OP_GetNegByte },
    { 0x10CC, opcode::OP_Divide },
    { 0x10CD, opcode::OP_Plus },
    { 0x10CE, opcode::OP_EvalLocalVariableRefCached },
    { 0x10CF, opcode::OP_JumpOnFalse },
    { 0x10D0, opcode::OP_Invalid },
    { 0x10D1, opcode::OP_Invalid },
    { 0x10D2, opcode::OP_JumpOnTrue },
    { 0x10D3, opcode::OP_Invalid },
    { 0x10D4, opcode::OP_Invalid },
    { 0x10D5, opcode::OP_CallBuiltinMethod },
    { 0x10D6, opcode::OP_GetZero },
    { 0x10D7, opcode::OP_Invalid },
    { 0x10D8, opcode::OP_EvalArrayRef },
    { 0x10D9, opcode::OP_Invalid },
    { 0x10DA, opcode::OP_Wait },
    { 0x10DB, opcode::OP_CallBuiltinMethod },
    { 0x10DC, opcode::OP_Invalid },
    { 0x10DD, opcode::OP_Modulus },
    { 0x10DE, opcode::OP_EndOn },
    { 0x10DF, opcode::OP_Divide },
    { 0x10E0, opcode::OP_GetLevelObject },
    { 0x10E1, opcode::OP_GetWorld },
    { 0x10E2, opcode::OP_IsDefined },
    { 0x10E3, opcode::OP_CastFieldObject },
    { 0x10E4, opcode::OP_Inc },
    { 0x10E5, opcode::OP_GetUintptr },
    { 0x10E6, opcode::OP_Invalid },
    { 0x10E7, opcode::OP_Invalid },
    { 0x10E8, opcode::OP_GetGameRef },
    { 0x10E9, opcode::OP_GetUndefined },
    { 0x10EA, opcode::OP_ScriptThreadCallClass },
    { 0x10EB, opcode::OP_Dec },
    { 0x10EC, opcode::OP_Invalid },
    { 0x10ED, opcode::OP_GetSelfObject },
    { 0x10EE, opcode::OP_GetNegUnsignedShort },
    { 0x10EF, opcode::OP_Invalid },
    { 0x10F0, opcode::OP_GetString },
    { 0x10F1, opcode::OP_GetByte },
    { 0x10F2, opcode::OP_Invalid },
    { 0x10F3, opcode::OP_Invalid },
    { 0x10F4, opcode::OP_ScriptThreadCall },
    { 0x10F5, opcode::OP_Invalid },
    { 0x10F6, opcode::OP_Invalid },
    { 0x10F7, opcode::OP_Dec },
    { 0x10F8, opcode::OP_LessThan },
    { 0x10F9, opcode::OP_GetSelfObject },
    { 0x10FA, opcode::OP_WaitTill },
    { 0x10FB, opcode::OP_New },
    { 0x10FC, opcode::OP_Minus },
    { 0x10FD, opcode::OP_GetString },
    { 0x10FE, opcode::OP_ClearFieldVariable },
    { 0x10FF, opcode::OP_FirstArrayKey },
    { 0x1100, opcode::OP_GetZero },
    { 0x1101, opcode::OP_SafeSetVariableFieldCached },
    { 0x1102, opcode::OP_ShiftRight },
    { 0x1103, opcode::OP_Dec },
    { 0x1104, opcode::OP_SuperNotEqual },
    { 0x1105, opcode::OP_Bit_Xor },
    { 0x1106, opcode::OP_GetInteger },
    { 0x1107, opcode::OP_EvalArray },
    { 0x1108, opcode::OP_GetNegUnsignedShort },
    { 0x1109, opcode::OP_NextArrayKey },
    { 0x110A, opcode::OP_Minus },
    { 0x110B, opcode::OP_GetGameRef },
    { 0x110C, opcode::OP_ShiftLeft },
    { 0x110D, opcode::OP_LevelEvalFieldVariable },
    { 0x110E, opcode::OP_Invalid },
    { 0x110F, opcode::OP_EvalFieldVariableRef },
    { 0x1110, opcode::OP_Invalid },
    { 0x1111, opcode::OP_SetVariableField },
    { 0x1112, opcode::OP_GetString },
    { 0x1113, opcode::OP_EmptyArray },
    { 0x1114, opcode::OP_ClearFieldVariable },
    { 0x1115, opcode::OP_Invalid },
    { 0x1116, opcode::OP_RealWait },
    { 0x1117, opcode::OP_SelfEvalFieldVariableRef },
    { 0x1118, opcode::OP_GetClasses },
    { 0x1119, opcode::OP_DevblockBegin },
    { 0x111A, opcode::OP_BoolNot },
    { 0x111B, opcode::OP_Invalid },
    { 0x111C, opcode::OP_GetNegByte },
    { 0x111D, opcode::OP_BoolComplement },
    { 0x111E, opcode::OP_EvalLocalVariableCached },
    { 0x111F, opcode::OP_EvalFieldVariable },
    { 0x1120, opcode::OP_BoolNot },
    { 0x1121, opcode::OP_Invalid },
    { 0x1122, opcode::OP_GreaterThanOrEqualTo },
    { 0x1123, opcode::OP_IsDefined },
    { 0x1124, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x1125, opcode::OP_GetUndefined },
    { 0x1126, opcode::OP_GetClasses },
    { 0x1127, opcode::OP_New },
    { 0x1128, opcode::OP_VectorScale },
    { 0x1129, opcode::OP_Multiply },
    { 0x112A, opcode::OP_LessThanOrEqualTo },
    { 0x112B, opcode::OP_ScriptMethodCallPointer },
    { 0x112C, opcode::OP_Return },
    { 0x112D, opcode::OP_JumpOnFalse },
    { 0x112E, opcode::OP_Plus },
    { 0x112F, opcode::OP_SuperEqual },
    { 0x1130, opcode::OP_GetWorldObject },
    { 0x1131, opcode::OP_EvalFieldVariableRef },
    { 0x1132, opcode::OP_Return },
    { 0x1133, opcode::OP_GetHash },
    { 0x1134, opcode::OP_GetIString },
    { 0x1135, opcode::OP_LessThanOrEqualTo },
    { 0x1136, opcode::OP_JumpOnFalseExpr },
    { 0x1137, opcode::OP_Invalid },
    { 0x1138, opcode::OP_GetWorldObject },
    { 0x1139, opcode::OP_GetString },
    { 0x113A, opcode::OP_LessThan },
    { 0x113B, opcode::OP_GetVector },
    { 0x113C, opcode::OP_Invalid },
    { 0x113D, opcode::OP_Invalid },
    { 0x113E, opcode::OP_Notify },
    { 0x113F, opcode::OP_DevblockBegin },
    { 0x1140, opcode::OP_LessThan },
    { 0x1141, opcode::OP_LessThan },
    { 0x1142, opcode::OP_GetIString },
    { 0x1143, opcode::OP_EvalLocalVariableCached },
    { 0x1144, opcode::OP_ClearFieldVariable },
    { 0x1145, opcode::OP_GetAnim },
    { 0x1146, opcode::OP_GetClassesObject },
    { 0x1147, opcode::OP_Invalid },
    { 0x1148, opcode::OP_SizeOf },
    { 0x1149, opcode::OP_ShiftLeft },
    { 0x114A, opcode::OP_Equal },
    { 0x114B, opcode::OP_RealWait },
    { 0x114C, opcode::OP_EvalLocalVariableRefCached },
    { 0x114D, opcode::OP_GetAPIFunction },
    { 0x114E, opcode::OP_New },
    { 0x114F, opcode::OP_Invalid },
    { 0x1150, opcode::OP_GetVector },
    { 0x1151, opcode::OP_GetWorldObject },
    { 0x1152, opcode::OP_GetByte },
    { 0x1153, opcode::OP_DevblockBegin },
    { 0x1154, opcode::OP_LessThanOrEqualTo },
    { 0x1155, opcode::OP_GetUndefined },
    { 0x1156, opcode::OP_JumpOnTrue },
    { 0x1157, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x1158, opcode::OP_SelfEvalFieldVariableRef },
    { 0x1159, opcode::OP_Invalid },
    { 0x115A, opcode::OP_ShiftLeft },
    { 0x115B, opcode::OP_Switch },
    { 0x115C, opcode::OP_EvalLocalVariableCached },
    { 0x115D, opcode::OP_GetUintptr },
    { 0x115E, opcode::OP_CallBuiltinMethod },
    { 0x115F, opcode::OP_VectorScale },
    { 0x1160, opcode::OP_VectorConstant },
    { 0x1161, opcode::OP_Invalid },
    { 0x1162, opcode::OP_Invalid },
    { 0x1163, opcode::OP_LessThanOrEqualTo },
    { 0x1164, opcode::OP_GetUnsignedShort },
    { 0x1165, opcode::OP_GetAPIFunction },
    { 0x1166, opcode::OP_ScriptFunctionCallPointer },
    { 0x1167, opcode::OP_GetSelf },
    { 0x1168, opcode::OP_EvalFieldVariable },
    { 0x1169, opcode::OP_Invalid },
    { 0x116A, opcode::OP_GetNegUnsignedShort },
    { 0x116B, opcode::OP_Invalid },
    { 0x116C, opcode::OP_JumpOnFalse },
    { 0x116D, opcode::OP_Equal },
    { 0x116E, opcode::OP_ScriptFunctionCallClass },
    { 0x116F, opcode::OP_Plus },
    { 0x1170, opcode::OP_Invalid },
    { 0x1171, opcode::OP_NextArrayKey },
    { 0x1172, opcode::OP_GetSelf },
    { 0x1173, opcode::OP_GetFunction },
    { 0x1174, opcode::OP_FirstArrayKey },
    { 0x1175, opcode::OP_Invalid },
    { 0x1176, opcode::OP_Invalid },
    { 0x1177, opcode::OP_Invalid },
    { 0x1178, opcode::OP_Invalid },
    { 0x1179, opcode::OP_EndOn },
    { 0x117A, opcode::OP_VectorScale },
    { 0x117B, opcode::OP_Multiply },
    { 0x117C, opcode::OP_CastFieldObject },
    { 0x117D, opcode::OP_GetNegUnsignedShort },
    { 0x117E, opcode::OP_Invalid },
    { 0x117F, opcode::OP_Switch },
    { 0x1180, opcode::OP_Invalid },
    { 0x1181, opcode::OP_GetIString },
    { 0x1182, opcode::OP_GetUintptr },
    { 0x1183, opcode::OP_GetTime },
    { 0x1184, opcode::OP_LessThan },
    { 0x1185, opcode::OP_GetSelfObject },
    { 0x1186, opcode::OP_Invalid },
    { 0x1187, opcode::OP_Notify },
    { 0x1188, opcode::OP_GetAnim },
    { 0x1189, opcode::OP_LessThanOrEqualTo },
    { 0x118A, opcode::OP_Invalid },
    { 0x118B, opcode::OP_Switch },
    { 0x118C, opcode::OP_ShiftRight },
    { 0x118D, opcode::OP_Plus },
    { 0x118E, opcode::OP_Invalid },
    { 0x118F, opcode::OP_GreaterThanOrEqualTo },
    { 0x1190, opcode::OP_ClearFieldVariable },
    { 0x1191, opcode::OP_Bit_Xor },
    { 0x1192, opcode::OP_Bit_Xor },
    { 0x1193, opcode::OP_Bit_And },
    { 0x1194, opcode::OP_ClearArray },
    { 0x1195, opcode::OP_Invalid },
    { 0x1196, opcode::OP_ScriptMethodThreadCall },
    { 0x1197, opcode::OP_ShiftLeft },
    { 0x1198, opcode::OP_CallBuiltinMethod },
    { 0x1199, opcode::OP_VectorConstant },
    { 0x119A, opcode::OP_GetClassesObject },
    { 0x119B, opcode::OP_GetSelfObject },
    { 0x119C, opcode::OP_GetAnim },
    { 0x119D, opcode::OP_JumpOnFalseExpr },
    { 0x119E, opcode::OP_BoolNot },
    { 0x119F, opcode::OP_Invalid },
    { 0x11A0, opcode::OP_EvalFieldVariableRef },
    { 0x11A1, opcode::OP_BoolComplement },
    { 0x11A2, opcode::OP_Invalid },
    { 0x11A3, opcode::OP_GetClassesObject },
    { 0x11A4, opcode::OP_BoolComplement },
    { 0x11A5, opcode::OP_Invalid },
    { 0x11A6, opcode::OP_GetInteger },
    { 0x11A7, opcode::OP_GreaterThanOrEqualTo },
    { 0x11A8, opcode::OP_SafeDecTop },
    { 0x11A9, opcode::OP_Invalid },
    { 0x11AA, opcode::OP_BoolComplement },
    { 0x11AB, opcode::OP_GetHash },
    { 0x11AC, opcode::OP_GreaterThan },
    { 0x11AD, opcode::OP_Invalid },
    { 0x11AE, opcode::OP_GetSelfObject },
    { 0x11AF, opcode::OP_SafeSetVariableFieldCached },
    { 0x11B0, opcode::OP_LessThan },
    { 0x11B1, opcode::OP_EvalArrayRef },
    { 0x11B2, opcode::OP_GetNegByte },
    { 0x11B3, opcode::OP_LessThanOrEqualTo },
    { 0x11B4, opcode::OP_Invalid },
    { 0x11B5, opcode::OP_LevelEvalFieldVariableRef },
    { 0x11B6, opcode::OP_JumpOnFalseExpr },
    { 0x11B7, opcode::OP_SafeDecTop },
    { 0x11B8, opcode::OP_LevelEvalFieldVariable },
    { 0x11B9, opcode::OP_EvalArray },
    { 0x11BA, opcode::OP_EmptyArray },
    { 0x11BB, opcode::OP_ShiftLeft },
    { 0x11BC, opcode::OP_EndSwitch },
    { 0x11BD, opcode::OP_WaitTill },
    { 0x11BE, opcode::OP_GetSelf },
    { 0x11BF, opcode::OP_Invalid },
    { 0x11C0, opcode::OP_Invalid },
    { 0x11C1, opcode::OP_ClearFieldVariable },
    { 0x11C2, opcode::OP_EndSwitch },
    { 0x11C3, opcode::OP_WaitTill },
    { 0x11C4, opcode::OP_Invalid },
    { 0x11C5, opcode::OP_Invalid },
    { 0x11C6, opcode::OP_Invalid },
    { 0x11C7, opcode::OP_ScriptMethodCallPointer },
    { 0x11C8, opcode::OP_Jump },
    { 0x11C9, opcode::OP_GetInteger },
    { 0x11CA, opcode::OP_Notify },
    { 0x11CB, opcode::OP_Invalid },
    { 0x11CC, opcode::OP_BoolComplement },
    { 0x11CD, opcode::OP_Switch },
    { 0x11CE, opcode::OP_New },
    { 0x11CF, opcode::OP_SuperNotEqual },
    { 0x11D0, opcode::OP_EndOn },
    { 0x11D1, opcode::OP_GetAPIFunction },
    { 0x11D2, opcode::OP_Invalid },
    { 0x11D3, opcode::OP_Invalid },
    { 0x11D4, opcode::OP_EvalLocalVariableRefCached },
    { 0x11D5, opcode::OP_Vector },
    { 0x11D6, opcode::OP_Invalid },
    { 0x11D7, opcode::OP_Notify },
    { 0x11D8, opcode::OP_DevblockBegin },
    { 0x11D9, opcode::OP_Invalid },
    { 0x11DA, opcode::OP_Plus },
    { 0x11DB, opcode::OP_Invalid },
    { 0x11DC, opcode::OP_Invalid },
    { 0x11DD, opcode::OP_GetSelf },
    { 0x11DE, opcode::OP_WaitTill },
    { 0x11DF, opcode::OP_CastBool },
    { 0x11E0, opcode::OP_Invalid },
    { 0x11E1, opcode::OP_BoolNot },
    { 0x11E2, opcode::OP_Invalid },
    { 0x11E3, opcode::OP_Invalid },
    { 0x11E4, opcode::OP_Invalid },
    { 0x11E5, opcode::OP_LevelEvalFieldVariableRef },
    { 0x11E6, opcode::OP_Invalid },
    { 0x11E7, opcode::OP_Invalid },
    { 0x11E8, opcode::OP_Invalid },
    { 0x11E9, opcode::OP_ScriptThreadCall },
    { 0x11EA, opcode::OP_GreaterThan },
    { 0x11EB, opcode::OP_New },
    { 0x11EC, opcode::OP_SafeSetVariableFieldCached },
    { 0x11ED, opcode::OP_Invalid },
    { 0x11EE, opcode::OP_EmptyArray },
    { 0x11EF, opcode::OP_GetAnim },
    { 0x11F0, opcode::OP_Invalid },
    { 0x11F1, opcode::OP_GreaterThanOrEqualTo },
    { 0x11F2, opcode::OP_Invalid },
    { 0x11F3, opcode::OP_GetSelfObject },
    { 0x11F4, opcode::OP_GetGame },
    { 0x11F5, opcode::OP_GetUndefined },
    { 0x11F6, opcode::OP_VectorConstant },
    { 0x11F7, opcode::OP_SafeSetVariableFieldCached },
    { 0x11F8, opcode::OP_GetGameRef },
    { 0x11F9, opcode::OP_GetUintptr },
    { 0x11FA, opcode::OP_Invalid },
    { 0x11FB, opcode::OP_GetUintptr },
    { 0x11FC, opcode::OP_Invalid },
    { 0x11FD, opcode::OP_Invalid },
    { 0x11FE, opcode::OP_Invalid },
    { 0x11FF, opcode::OP_Invalid },
    { 0x1200, opcode::OP_ScriptThreadCallClass },
    { 0x1201, opcode::OP_Invalid },
    { 0x1202, opcode::OP_SizeOf },
    { 0x1203, opcode::OP_Invalid },
    { 0x1204, opcode::OP_Invalid },
    { 0x1205, opcode::OP_RealWait },
    { 0x1206, opcode::OP_Equal },
    { 0x1207, opcode::OP_Notify },
    { 0x1208, opcode::OP_Invalid },
    { 0x1209, opcode::OP_Invalid },
    { 0x120A, opcode::OP_Invalid },
    { 0x120B, opcode::OP_EndSwitch },
    { 0x120C, opcode::OP_LessThan },
    { 0x120D, opcode::OP_SuperEqual },
    { 0x120E, opcode::OP_Bit_Or },
    { 0x120F, opcode::OP_Invalid },
    { 0x1210, opcode::OP_SafeCreateLocalVariables },
    { 0x1211, opcode::OP_ScriptThreadCallClass },
    { 0x1212, opcode::OP_JumpOnFalse },
    { 0x1213, opcode::OP_GreaterThan },
    { 0x1214, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x1215, opcode::OP_ScriptFunctionCall },
    { 0x1216, opcode::OP_Invalid },
    { 0x1217, opcode::OP_GetWorld },
    { 0x1218, opcode::OP_ScriptFunctionCall },
    { 0x1219, opcode::OP_Invalid },
    { 0x121A, opcode::OP_Invalid },
    { 0x121B, opcode::OP_SuperEqual },
    { 0x121C, opcode::OP_RealWait },
    { 0x121D, opcode::OP_ScriptThreadCall },
    { 0x121E, opcode::OP_Invalid },
    { 0x121F, opcode::OP_LessThanOrEqualTo },
    { 0x1220, opcode::OP_GetNegUnsignedShort },
    { 0x1221, opcode::OP_GetClassesObject },
    { 0x1222, opcode::OP_Jump },
    { 0x1223, opcode::OP_Invalid },
    { 0x1224, opcode::OP_SafeCreateLocalVariables },
    { 0x1225, opcode::OP_Invalid },
    { 0x1226, opcode::OP_GetFloat },
    { 0x1227, opcode::OP_Invalid },
    { 0x1228, opcode::OP_Invalid },
    { 0x1229, opcode::OP_ScriptThreadCallPointer },
    { 0x122A, opcode::OP_GetClasses },
    { 0x122B, opcode::OP_Invalid },
    { 0x122C, opcode::OP_GetLevel },
    { 0x122D, opcode::OP_LessThan },
    { 0x122E, opcode::OP_Invalid },
    { 0x122F, opcode::OP_Invalid },
    { 0x1230, opcode::OP_Invalid },
    { 0x1231, opcode::OP_Wait },
    { 0x1232, opcode::OP_Invalid },
    { 0x1233, opcode::OP_Equal },
    { 0x1234, opcode::OP_LevelEvalFieldVariableRef },
    { 0x1235, opcode::OP_Invalid },
    { 0x1236, opcode::OP_GetByte },
    { 0x1237, opcode::OP_GetUnsignedShort },
    { 0x1238, opcode::OP_ScriptThreadCall },
    { 0x1239, opcode::OP_Invalid },
    { 0x123A, opcode::OP_Invalid },
    { 0x123B, opcode::OP_Invalid },
    { 0x123C, opcode::OP_GetClasses },
    { 0x123D, opcode::OP_ProfileStart },
    { 0x123E, opcode::OP_GetClasses },
    { 0x123F, opcode::OP_GetAnimation },
    { 0x1240, opcode::OP_ScriptMethodThreadCall },
    { 0x1241, opcode::OP_GetVector },
    { 0x1242, opcode::OP_ScriptThreadCallClass },
    { 0x1243, opcode::OP_VectorScale },
    { 0x1244, opcode::OP_Invalid },
    { 0x1245, opcode::OP_Notify },
    { 0x1246, opcode::OP_GetInteger },
    { 0x1247, opcode::OP_Invalid },
    { 0x1248, opcode::OP_Bit_Xor },
    { 0x1249, opcode::OP_Inc },
    { 0x124A, opcode::OP_Invalid },
    { 0x124B, opcode::OP_Minus },
    { 0x124C, opcode::OP_JumpOnFalse },
    { 0x124D, opcode::OP_GetWorld },
    { 0x124E, opcode::OP_Invalid },
    { 0x124F, opcode::OP_Invalid },
    { 0x1250, opcode::OP_NotEqual },
    { 0x1251, opcode::OP_GetUnsignedShort },
    { 0x1252, opcode::OP_EvalArrayRef },
    { 0x1253, opcode::OP_GetNegByte },
    { 0x1254, opcode::OP_GetFloat },
    { 0x1255, opcode::OP_GetAnim },
    { 0x1256, opcode::OP_Minus },
    { 0x1257, opcode::OP_Inc },
    { 0x1258, opcode::OP_BoolNot },
    { 0x1259, opcode::OP_Jump },
    { 0x125A, opcode::OP_Switch },
    { 0x125B, opcode::OP_JumpOnTrueExpr },
    { 0x125C, opcode::OP_ClearArray },
    { 0x125D, opcode::OP_GetClassesObject },
    { 0x125E, opcode::OP_Invalid },
    { 0x125F, opcode::OP_ScriptMethodCallPointer },
    { 0x1260, opcode::OP_SafeCreateLocalVariables },
    { 0x1261, opcode::OP_LessThan },
    { 0x1262, opcode::OP_GetInteger },
    { 0x1263, opcode::OP_GreaterThanOrEqualTo },
    { 0x1264, opcode::OP_GetLevel },
    { 0x1265, opcode::OP_ScriptFunctionCallClass },
    { 0x1266, opcode::OP_ShiftLeft },
    { 0x1267, opcode::OP_Invalid },
    { 0x1268, opcode::OP_GetFloat },
    { 0x1269, opcode::OP_Invalid },
    { 0x126A, opcode::OP_JumpOnTrue },
    { 0x126B, opcode::OP_GetNegByte },
    { 0x126C, opcode::OP_ScriptMethodThreadCall },
    { 0x126D, opcode::OP_GetZero },
    { 0x126E, opcode::OP_JumpOnTrueExpr },
    { 0x126F, opcode::OP_ScriptThreadCallPointer },
    { 0x1270, opcode::OP_GetLevel },
    { 0x1271, opcode::OP_CallBuiltinMethod },
    { 0x1272, opcode::OP_GetFloat },
    { 0x1273, opcode::OP_SetVariableField },
    { 0x1274, opcode::OP_LessThan },
    { 0x1275, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x1276, opcode::OP_JumpOnTrue },
    { 0x1277, opcode::OP_ProfileStop },
    { 0x1278, opcode::OP_Invalid },
    { 0x1279, opcode::OP_EvalLocalVariableRefCached },
    { 0x127A, opcode::OP_IsDefined },
    { 0x127B, opcode::OP_CallBuiltinMethod },
    { 0x127C, opcode::OP_Bit_Xor },
    { 0x127D, opcode::OP_EvalLocalVariableRefCached },
    { 0x127E, opcode::OP_WaitTill },
    { 0x127F, opcode::OP_VectorConstant },
    { 0x1280, opcode::OP_Invalid },
    { 0x1281, opcode::OP_Invalid },
    { 0x1282, opcode::OP_GetNegUnsignedShort },
    { 0x1283, opcode::OP_EndSwitch },
    { 0x1284, opcode::OP_Vector },
    { 0x1285, opcode::OP_ScriptThreadCallPointer },
    { 0x1286, opcode::OP_DevblockBegin },
    { 0x1287, opcode::OP_Invalid },
    { 0x1288, opcode::OP_Invalid },
    { 0x1289, opcode::OP_FirstArrayKey },
    { 0x128A, opcode::OP_EmptyArray },
    { 0x128B, opcode::OP_NotEqual },
    { 0x128C, opcode::OP_VectorScale },
    { 0x128D, opcode::OP_Invalid },
    { 0x128E, opcode::OP_Invalid },
    { 0x128F, opcode::OP_GetUintptr },
    { 0x1290, opcode::OP_GetAPIFunction },
    { 0x1291, opcode::OP_GetNegUnsignedShort },
    { 0x1292, opcode::OP_Invalid },
    { 0x1293, opcode::OP_CastBool },
    { 0x1294, opcode::OP_GetNegUnsignedShort },
    { 0x1295, opcode::OP_IsDefined },
    { 0x1296, opcode::OP_Invalid },
    { 0x1297, opcode::OP_Invalid },
    { 0x1298, opcode::OP_GetUintptr },
    { 0x1299, opcode::OP_GetZero },
    { 0x129A, opcode::OP_Invalid },
    { 0x129B, opcode::OP_JumpOnTrue },
    { 0x129C, opcode::OP_EvalArrayRef },
    { 0x129D, opcode::OP_Minus },
    { 0x129E, opcode::OP_Invalid },
    { 0x129F, opcode::OP_WaitTill },
    { 0x12A0, opcode::OP_VectorScale },
    { 0x12A1, opcode::OP_GetFloat },
    { 0x12A2, opcode::OP_Invalid },
    { 0x12A3, opcode::OP_Plus },
    { 0x12A4, opcode::OP_Multiply },
    { 0x12A5, opcode::OP_WaitTill },
    { 0x12A6, opcode::OP_GetClassesObject },
    { 0x12A7, opcode::OP_CallBuiltinMethod },
    { 0x12A8, opcode::OP_GetFunction },
    { 0x12A9, opcode::OP_Jump },
    { 0x12AA, opcode::OP_GetWorldObject },
    { 0x12AB, opcode::OP_Invalid },
    { 0x12AC, opcode::OP_Invalid },
    { 0x12AD, opcode::OP_GetUnsignedShort },
    { 0x12AE, opcode::OP_Invalid },
    { 0x12AF, opcode::OP_EvalLocalVariableCached },
    { 0x12B0, opcode::OP_GetGameRef },
    { 0x12B1, opcode::OP_GetAnimation },
    { 0x12B2, opcode::OP_EvalFieldVariableRef },
    { 0x12B3, opcode::OP_GetGame },
    { 0x12B4, opcode::OP_Invalid },
    { 0x12B5, opcode::OP_EvalArrayRef },
    { 0x12B6, opcode::OP_Bit_And },
    { 0x12B7, opcode::OP_SuperEqual },
    { 0x12B8, opcode::OP_Invalid },
    { 0x12B9, opcode::OP_Multiply },
    { 0x12BA, opcode::OP_Bit_Or },
    { 0x12BB, opcode::OP_Invalid },
    { 0x12BC, opcode::OP_SetVariableField },
    { 0x12BD, opcode::OP_SelfEvalFieldVariableRef },
    { 0x12BE, opcode::OP_Invalid },
    { 0x12BF, opcode::OP_Invalid },
    { 0x12C0, opcode::OP_JumpOnTrue },
    { 0x12C1, opcode::OP_JumpOnFalse },
    { 0x12C2, opcode::OP_GetUndefined },
    { 0x12C3, opcode::OP_Plus },
    { 0x12C4, opcode::OP_GetNegUnsignedShort },
    { 0x12C5, opcode::OP_Minus },
    { 0x12C6, opcode::OP_ShiftLeft },
    { 0x12C7, opcode::OP_GetWorld },
    { 0x12C8, opcode::OP_LessThan },
    { 0x12C9, opcode::OP_Switch },
    { 0x12CA, opcode::OP_EvalLocalVariableRefCached },
    { 0x12CB, opcode::OP_Invalid },
    { 0x12CC, opcode::OP_GetGameRef },
    { 0x12CD, opcode::OP_BoolNot },
    { 0x12CE, opcode::OP_Invalid },
    { 0x12CF, opcode::OP_EvalLocalVariableRefCached },
    { 0x12D0, opcode::OP_Invalid },
    { 0x12D1, opcode::OP_Invalid },
    { 0x12D2, opcode::OP_GetHash },
    { 0x12D3, opcode::OP_Invalid },
    { 0x12D4, opcode::OP_GetGame },
    { 0x12D5, opcode::OP_GetClasses },
    { 0x12D6, opcode::OP_IsDefined },
    { 0x12D7, opcode::OP_SafeDecTop },
    { 0x12D8, opcode::OP_SafeDecTop },
    { 0x12D9, opcode::OP_WaitTillMatch },
    { 0x12DA, opcode::OP_SetVariableField },
    { 0x12DB, opcode::OP_Invalid },
    { 0x12DC, opcode::OP_BoolNot },
    { 0x12DD, opcode::OP_Invalid },
    { 0x12DE, opcode::OP_GetUintptr },
    { 0x12DF, opcode::OP_Invalid },
    { 0x12E0, opcode::OP_GetNegUnsignedShort },
    { 0x12E1, opcode::OP_ScriptFunctionCall },
    { 0x12E2, opcode::OP_SafeCreateLocalVariables },
    { 0x12E3, opcode::OP_SetVariableField },
    { 0x12E4, opcode::OP_GetAPIFunction },
    { 0x12E5, opcode::OP_Invalid },
    { 0x12E6, opcode::OP_Invalid },
    { 0x12E7, opcode::OP_GetNegUnsignedShort },
    { 0x12E8, opcode::OP_Switch },
    { 0x12E9, opcode::OP_ScriptMethodCallPointer },
    { 0x12EA, opcode::OP_ClearFieldVariable },
    { 0x12EB, opcode::OP_SuperNotEqual },
    { 0x12EC, opcode::OP_GetAPIFunction },
    { 0x12ED, opcode::OP_Invalid },
    { 0x12EE, opcode::OP_CallBuiltinMethod },
    { 0x12EF, opcode::OP_NextArrayKey },
    { 0x12F0, opcode::OP_VectorScale },
    { 0x12F1, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x12F2, opcode::OP_Invalid },
    { 0x12F3, opcode::OP_WaitTill },
    { 0x12F4, opcode::OP_Invalid },
    { 0x12F5, opcode::OP_Invalid },
    { 0x12F6, opcode::OP_BoolNot },
    { 0x12F7, opcode::OP_EvalFieldVariable },
    { 0x12F8, opcode::OP_GetNegByte },
    { 0x12F9, opcode::OP_Minus },
    { 0x12FA, opcode::OP_GetFloat },
    { 0x12FB, opcode::OP_Bit_Or },
    { 0x12FC, opcode::OP_SafeSetVariableFieldCached },
    { 0x12FD, opcode::OP_GetClassesObject },
    { 0x12FE, opcode::OP_GetLevelObject },
    { 0x12FF, opcode::OP_EvalArray },
    { 0x1300, opcode::OP_Invalid },
    { 0x1301, opcode::OP_EvalFieldVariableRef },
    { 0x1302, opcode::OP_JumpOnFalseExpr },
    { 0x1303, opcode::OP_Wait },
    { 0x1304, opcode::OP_Modulus },
    { 0x1305, opcode::OP_Invalid },
    { 0x1306, opcode::OP_Invalid },
    { 0x1307, opcode::OP_Jump },
    { 0x1308, opcode::OP_Invalid },
    { 0x1309, opcode::OP_Invalid },
    { 0x130A, opcode::OP_VectorConstant },
    { 0x130B, opcode::OP_Invalid },
    { 0x130C, opcode::OP_SuperEqual },
    { 0x130D, opcode::OP_GetByte },
    { 0x130E, opcode::OP_Equal },
    { 0x130F, opcode::OP_Invalid },
    { 0x1310, opcode::OP_LevelEvalFieldVariableRef },
    { 0x1311, opcode::OP_Invalid },
    { 0x1312, opcode::OP_GetAnimObject },
    { 0x1313, opcode::OP_Invalid },
    { 0x1314, opcode::OP_Invalid },
    { 0x1315, opcode::OP_Bit_Or },
    { 0x1316, opcode::OP_Invalid },
    { 0x1317, opcode::OP_Vector },
    { 0x1318, opcode::OP_Invalid },
    { 0x1319, opcode::OP_NotEqual },
    { 0x131A, opcode::OP_DecTop },
    { 0x131B, opcode::OP_Jump },
    { 0x131C, opcode::OP_Invalid },
    { 0x131D, opcode::OP_DecTop },
    { 0x131E, opcode::OP_ClearFieldVariable },
    { 0x131F, opcode::OP_Invalid },
    { 0x1320, opcode::OP_FirstArrayKey },
    { 0x1321, opcode::OP_GetGame },
    { 0x1322, opcode::OP_ScriptFunctionCall },
    { 0x1323, opcode::OP_Invalid },
    { 0x1324, opcode::OP_Invalid },
    { 0x1325, opcode::OP_EvalLocalVariableCached },
    { 0x1326, opcode::OP_Invalid },
    { 0x1327, opcode::OP_Invalid },
    { 0x1328, opcode::OP_Invalid },
    { 0x1329, opcode::OP_Invalid },
    { 0x132A, opcode::OP_Bit_Or },
    { 0x132B, opcode::OP_EvalLocalVariableCached },
    { 0x132C, opcode::OP_GetHash },
    { 0x132D, opcode::OP_Invalid },
    { 0x132E, opcode::OP_NextArrayKey },
    { 0x132F, opcode::OP_Invalid },
    { 0x1330, opcode::OP_SelfEvalFieldVariable },
    { 0x1331, opcode::OP_Invalid },
    { 0x1332, opcode::OP_Invalid },
    { 0x1333, opcode::OP_IsDefined },
    { 0x1334, opcode::OP_EvalFieldVariable },
    { 0x1335, opcode::OP_Invalid },
    { 0x1336, opcode::OP_GetNegByte },
    { 0x1337, opcode::OP_ShiftRight },
    { 0x1338, opcode::OP_GetInteger },
    { 0x1339, opcode::OP_GetWorld },
    { 0x133A, opcode::OP_FirstArrayKey },
    { 0x133B, opcode::OP_GetIString },
    { 0x133C, opcode::OP_LessThanOrEqualTo },
    { 0x133D, opcode::OP_Invalid },
    { 0x133E, opcode::OP_GetClassesObject },
    { 0x133F, opcode::OP_ProfileStop },
    { 0x1340, opcode::OP_Invalid },
    { 0x1341, opcode::OP_Jump },
    { 0x1342, opcode::OP_Invalid },
    { 0x1343, opcode::OP_EvalArray },
    { 0x1344, opcode::OP_SuperNotEqual },
    { 0x1345, opcode::OP_Invalid },
    { 0x1346, opcode::OP_GetNegUnsignedShort },
    { 0x1347, opcode::OP_EvalFieldVariableRef },
    { 0x1348, opcode::OP_JumpOnTrueExpr },
    { 0x1349, opcode::OP_Bit_Xor },
    { 0x134A, opcode::OP_ClearArray },
    { 0x134B, opcode::OP_GetHash },
    { 0x134C, opcode::OP_Modulus },
    { 0x134D, opcode::OP_Invalid },
    { 0x134E, opcode::OP_RealWait },
    { 0x134F, opcode::OP_GetAnimObject },
    { 0x1350, opcode::OP_Invalid },
    { 0x1351, opcode::OP_EvalLocalVariableRefCached },
    { 0x1352, opcode::OP_FirstArrayKey },
    { 0x1353, opcode::OP_EvalFieldVariableRef },
    { 0x1354, opcode::OP_GetSelfObject },
    { 0x1355, opcode::OP_Invalid },
    { 0x1356, opcode::OP_Invalid },
    { 0x1357, opcode::OP_SelfEvalFieldVariable },
    { 0x1358, opcode::OP_Invalid },
    { 0x1359, opcode::OP_GetAnimation },
    { 0x135A, opcode::OP_GetUintptr },
    { 0x135B, opcode::OP_Invalid },
    { 0x135C, opcode::OP_Invalid },
    { 0x135D, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x135E, opcode::OP_SelfEvalFieldVariableRef },
    { 0x135F, opcode::OP_Invalid },
    { 0x1360, opcode::OP_GetString },
    { 0x1361, opcode::OP_Dec },
    { 0x1362, opcode::OP_New },
    { 0x1363, opcode::OP_Invalid },
    { 0x1364, opcode::OP_LevelEvalFieldVariable },
    { 0x1365, opcode::OP_Jump },
    { 0x1366, opcode::OP_Invalid },
    { 0x1367, opcode::OP_EvalFieldVariableRef },
    { 0x1368, opcode::OP_Invalid },
    { 0x1369, opcode::OP_BoolNot },
    { 0x136A, opcode::OP_Invalid },
    { 0x136B, opcode::OP_Notify },
    { 0x136C, opcode::OP_CastFieldObject },
    { 0x136D, opcode::OP_BoolNot },
    { 0x136E, opcode::OP_NextArrayKey },
    { 0x136F, opcode::OP_Invalid },
    { 0x1370, opcode::OP_Invalid },
    { 0x1371, opcode::OP_Invalid },
    { 0x1372, opcode::OP_Invalid },
    { 0x1373, opcode::OP_DevblockBegin },
    { 0x1374, opcode::OP_GetSelf },
    { 0x1375, opcode::OP_Invalid },
    { 0x1376, opcode::OP_Invalid },
    { 0x1377, opcode::OP_GetAnim },
    { 0x1378, opcode::OP_GetNegUnsignedShort },
    { 0x1379, opcode::OP_Invalid },
    { 0x137A, opcode::OP_GetWorld },
    { 0x137B, opcode::OP_Invalid },
    { 0x137C, opcode::OP_Invalid },
    { 0x137D, opcode::OP_GetWorld },
    { 0x137E, opcode::OP_Invalid },
    { 0x137F, opcode::OP_Invalid },
    { 0x1380, opcode::OP_Invalid },
    { 0x1381, opcode::OP_LessThanOrEqualTo },
    { 0x1382, opcode::OP_Bit_Xor },
    { 0x1383, opcode::OP_Invalid },
    { 0x1384, opcode::OP_GetClassesObject },
    { 0x1385, opcode::OP_Invalid },
    { 0x1386, opcode::OP_SafeCreateLocalVariables },
    { 0x1387, opcode::OP_WaitTill },
    { 0x1388, opcode::OP_GetTime },
    { 0x1389, opcode::OP_WaitTill },
    { 0x138A, opcode::OP_Invalid },
    { 0x138B, opcode::OP_Invalid },
    { 0x138C, opcode::OP_Invalid },
    { 0x138D, opcode::OP_GetSelf },
    { 0x138E, opcode::OP_DecTop },
    { 0x138F, opcode::OP_VectorConstant },
    { 0x1390, opcode::OP_GetAnimation },
    { 0x1391, opcode::OP_GetLevel },
    { 0x1392, opcode::OP_GreaterThanOrEqualTo },
    { 0x1393, opcode::OP_Invalid },
    { 0x1394, opcode::OP_Invalid },
    { 0x1395, opcode::OP_GetSelf },
    { 0x1396, opcode::OP_ShiftLeft },
    { 0x1397, opcode::OP_Invalid },
    { 0x1398, opcode::OP_GreaterThanOrEqualTo },
    { 0x1399, opcode::OP_Invalid },
    { 0x139A, opcode::OP_WaitTillFrameEnd },
    { 0x139B, opcode::OP_EvalLocalVariableCached },
    { 0x139C, opcode::OP_ScriptMethodCallPointer },
    { 0x139D, opcode::OP_ShiftRight },
    { 0x139E, opcode::OP_Invalid },
    { 0x139F, opcode::OP_EvalLocalVariableCached },
    { 0x13A0, opcode::OP_EndSwitch },
    { 0x13A1, opcode::OP_Invalid },
    { 0x13A2, opcode::OP_Invalid },
    { 0x13A3, opcode::OP_Invalid },
    { 0x13A4, opcode::OP_EvalArray },
    { 0x13A5, opcode::OP_EvalFieldVariable },
    { 0x13A6, opcode::OP_GreaterThan },
    { 0x13A7, opcode::OP_Invalid },
    { 0x13A8, opcode::OP_Inc },
    { 0x13A9, opcode::OP_Invalid },
    { 0x13AA, opcode::OP_Invalid },
    { 0x13AB, opcode::OP_GetClassesObject },
    { 0x13AC, opcode::OP_GetWorld },
    { 0x13AD, opcode::OP_GetWorldObject },
    { 0x13AE, opcode::OP_Invalid },
    { 0x13AF, opcode::OP_Invalid },
    { 0x13B0, opcode::OP_ProfileStop },
    { 0x13B1, opcode::OP_VectorConstant },
    { 0x13B2, opcode::OP_Invalid },
    { 0x13B3, opcode::OP_Invalid },
    { 0x13B4, opcode::OP_ScriptThreadCallPointer },
    { 0x13B5, opcode::OP_Invalid },
    { 0x13B6, opcode::OP_Inc },
    { 0x13B7, opcode::OP_Invalid },
    { 0x13B8, opcode::OP_Invalid },
    { 0x13B9, opcode::OP_Minus },
    { 0x13BA, opcode::OP_Invalid },
    { 0x13BB, opcode::OP_Minus },
    { 0x13BC, opcode::OP_DecTop },
    { 0x13BD, opcode::OP_GetVector },
    { 0x13BE, opcode::OP_GetLevelObject },
    { 0x13BF, opcode::OP_Invalid },
    { 0x13C0, opcode::OP_ClearArray },
    { 0x13C1, opcode::OP_Invalid },
    { 0x13C2, opcode::OP_WaitTill },
    { 0x13C3, opcode::OP_SafeCreateLocalVariables },
    { 0x13C4, opcode::OP_Invalid },
    { 0x13C5, opcode::OP_SuperEqual },
    { 0x13C6, opcode::OP_GetUintptr },
    { 0x13C7, opcode::OP_ShiftRight },
    { 0x13C8, opcode::OP_Invalid },
    { 0x13C9, opcode::OP_Invalid },
    { 0x13CA, opcode::OP_Inc },
    { 0x13CB, opcode::OP_Invalid },
    { 0x13CC, opcode::OP_Bit_And },
    { 0x13CD, opcode::OP_Bit_And },
    { 0x13CE, opcode::OP_GetByte },
    { 0x13CF, opcode::OP_GetFloat },
    { 0x13D0, opcode::OP_Invalid },
    { 0x13D1, opcode::OP_Divide },
    { 0x13D2, opcode::OP_GetWorld },
    { 0x13D3, opcode::OP_Divide },
    { 0x13D4, opcode::OP_CallBuiltinMethod },
    { 0x13D5, opcode::OP_Vector },
    { 0x13D6, opcode::OP_Invalid },
    { 0x13D7, opcode::OP_Invalid },
    { 0x13D8, opcode::OP_GetClasses },
    { 0x13D9, opcode::OP_Invalid },
    { 0x13DA, opcode::OP_Invalid },
    { 0x13DB, opcode::OP_Invalid },
    { 0x13DC, opcode::OP_BoolComplement },
    { 0x13DD, opcode::OP_Invalid },
    { 0x13DE, opcode::OP_Return },
    { 0x13DF, opcode::OP_VectorConstant },
    { 0x13E0, opcode::OP_GetFloat },
    { 0x13E1, opcode::OP_VectorConstant },
    { 0x13E2, opcode::OP_Bit_And },
    { 0x13E3, opcode::OP_GetAnimObject },
    { 0x13E4, opcode::OP_EvalLocalVariableCached },
    { 0x13E5, opcode::OP_GetGameRef },
    { 0x13E6, opcode::OP_GetUnsignedShort },
    { 0x13E7, opcode::OP_GreaterThan },
    { 0x13E8, opcode::OP_ClearArray },
    { 0x13E9, opcode::OP_Invalid },
    { 0x13EA, opcode::OP_Invalid },
    { 0x13EB, opcode::OP_Invalid },
    { 0x13EC, opcode::OP_GetAnimation },
    { 0x13ED, opcode::OP_SafeCreateLocalVariables },
    { 0x13EE, opcode::OP_Invalid },
    { 0x13EF, opcode::OP_Equal },
    { 0x13F0, opcode::OP_ScriptThreadCallClass },
    { 0x13F1, opcode::OP_GetGame },
    { 0x13F2, opcode::OP_Invalid },
    { 0x13F3, opcode::OP_GetSelfObject },
    { 0x13F4, opcode::OP_EvalArrayRef },
    { 0x13F5, opcode::OP_WaitTill },
    { 0x13F6, opcode::OP_Invalid },
    { 0x13F7, opcode::OP_Plus },
    { 0x13F8, opcode::OP_Equal },
    { 0x13F9, opcode::OP_Invalid },
    { 0x13FA, opcode::OP_Invalid },
    { 0x13FB, opcode::OP_GetSelf },
    { 0x13FC, opcode::OP_Invalid },
    { 0x13FD, opcode::OP_GetUintptr },
    { 0x13FE, opcode::OP_GetClassesObject },
    { 0x13FF, opcode::OP_Invalid },
    { 0x1400, opcode::OP_Jump },
    { 0x1401, opcode::OP_GetGameRef },
    { 0x1402, opcode::OP_Invalid },
    { 0x1403, opcode::OP_IsDefined },
    { 0x1404, opcode::OP_Bit_Or },
    { 0x1405, opcode::OP_Bit_Xor },
    { 0x1406, opcode::OP_ShiftRight },
    { 0x1407, opcode::OP_Invalid },
    { 0x1408, opcode::OP_GetWorldObject },
    { 0x1409, opcode::OP_Plus },
    { 0x140A, opcode::OP_DecTop },
    { 0x140B, opcode::OP_ShiftRight },
    { 0x140C, opcode::OP_RealWait },
    { 0x140D, opcode::OP_EvalArray },
    { 0x140E, opcode::OP_Multiply },
    { 0x140F, opcode::OP_Invalid },
    { 0x1410, opcode::OP_SelfEvalFieldVariableRef },
    { 0x1411, opcode::OP_Invalid },
    { 0x1412, opcode::OP_Invalid },
    { 0x1413, opcode::OP_ScriptMethodThreadCall },
    { 0x1414, opcode::OP_Invalid },
    { 0x1415, opcode::OP_LessThan },
    { 0x1416, opcode::OP_IsDefined },
    { 0x1417, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x1418, opcode::OP_Invalid },
    { 0x1419, opcode::OP_ScriptFunctionCall },
    { 0x141A, opcode::OP_JumpOnFalseExpr },
    { 0x141B, opcode::OP_ScriptMethodThreadCall },
    { 0x141C, opcode::OP_Invalid },
    { 0x141D, opcode::OP_Invalid },
    { 0x141E, opcode::OP_GetSelf },
    { 0x141F, opcode::OP_ClearFieldVariable },
    { 0x1420, opcode::OP_GetVector },
    { 0x1421, opcode::OP_RealWait },
    { 0x1422, opcode::OP_Invalid },
    { 0x1423, opcode::OP_GetString },
    { 0x1424, opcode::OP_SuperEqual },
    { 0x1425, opcode::OP_GetUndefined },
    { 0x1426, opcode::OP_Inc },
    { 0x1427, opcode::OP_ScriptMethodCall },
    { 0x1428, opcode::OP_Return },
    { 0x1429, opcode::OP_Invalid },
    { 0x142A, opcode::OP_GetSelf },
    { 0x142B, opcode::OP_LevelEvalFieldVariable },
    { 0x142C, opcode::OP_Invalid },
    { 0x142D, opcode::OP_Invalid },
    { 0x142E, opcode::OP_GetSelfObject },
    { 0x142F, opcode::OP_EvalArray },
    { 0x1430, opcode::OP_GetClasses },
    { 0x1431, opcode::OP_GetLevel },
    { 0x1432, opcode::OP_VectorConstant },
    { 0x1433, opcode::OP_Invalid },
    { 0x1434, opcode::OP_GetAPIFunction },
    { 0x1435, opcode::OP_Notify },
    { 0x1436, opcode::OP_Jump },
    { 0x1437, opcode::OP_GetVector },
    { 0x1438, opcode::OP_Invalid },
    { 0x1439, opcode::OP_Dec },
    { 0x143A, opcode::OP_Bit_And },
    { 0x143B, opcode::OP_GetGame },
    { 0x143C, opcode::OP_ScriptFunctionCallPointer },
    { 0x143D, opcode::OP_ScriptThreadCallClass },
    { 0x143E, opcode::OP_Invalid },
    { 0x143F, opcode::OP_VectorConstant },
    { 0x1440, opcode::OP_Invalid },
    { 0x1441, opcode::OP_Invalid },
    { 0x1442, opcode::OP_Divide },
    { 0x1443, opcode::OP_GetNegUnsignedShort },
    { 0x1444, opcode::OP_GetGameRef },
    { 0x1445, opcode::OP_Invalid },
    { 0x1446, opcode::OP_GetLevel },
    { 0x1447, opcode::OP_RealWait },
    { 0x1448, opcode::OP_GetAnim },
    { 0x1449, opcode::OP_ScriptThreadCallPointer },
    { 0x144A, opcode::OP_GetAnim },
    { 0x144B, opcode::OP_GetAnimObject },
    { 0x144C, opcode::OP_GetString },
    { 0x144D, opcode::OP_Invalid },
    { 0x144E, opcode::OP_EndSwitch },
    { 0x144F, opcode::OP_Invalid },
    { 0x1450, opcode::OP_GetClasses },
    { 0x1451, opcode::OP_ScriptMethodCallPointer },
    { 0x1452, opcode::OP_Jump },
    { 0x1453, opcode::OP_ScriptFunctionCallClass },
    { 0x1454, opcode::OP_Invalid },
    { 0x1455, opcode::OP_Bit_Or },
    { 0x1456, opcode::OP_SuperNotEqual },
    { 0x1457, opcode::OP_GetTime },
    { 0x1458, opcode::OP_EvalLocalVariableRefCached },
    { 0x1459, opcode::OP_ShiftRight },
    { 0x145A, opcode::OP_Bit_Or },
    { 0x145B, opcode::OP_Invalid },
    { 0x145C, opcode::OP_EmptyArray },
    { 0x145D, opcode::OP_Invalid },
    { 0x145E, opcode::OP_ScriptFunctionCall },
    { 0x145F, opcode::OP_GetAnim },
    { 0x1460, opcode::OP_Invalid },
    { 0x1461, opcode::OP_Invalid },
    { 0x1462, opcode::OP_Invalid },
    { 0x1463, opcode::OP_BoolComplement },
    { 0x1464, opcode::OP_LessThanOrEqualTo },
    { 0x1465, opcode::OP_LessThanOrEqualTo },
    { 0x1466, opcode::OP_GetLevelObject },
    { 0x1467, opcode::OP_New },
    { 0x1468, opcode::OP_Bit_And },
    { 0x1469, opcode::OP_Invalid },
    { 0x146A, opcode::OP_EvalLocalVariableCached },
    { 0x146B, opcode::OP_Invalid },
    { 0x146C, opcode::OP_ScriptThreadCallClass },
    { 0x146D, opcode::OP_GetLevelObject },
    { 0x146E, opcode::OP_JumpOnFalseExpr },
    { 0x146F, opcode::OP_Equal },
    { 0x1470, opcode::OP_GetUndefined },
    { 0x1471, opcode::OP_IsDefined },
    { 0x1472, opcode::OP_Switch },
    { 0x1473, opcode::OP_Invalid },
    { 0x1474, opcode::OP_NotEqual },
    { 0x1475, opcode::OP_Invalid },
    { 0x1476, opcode::OP_BoolComplement },
    { 0x1477, opcode::OP_EvalArrayRef },
    { 0x1478, opcode::OP_EndSwitch },
    { 0x1479, opcode::OP_GetClassesObject },
    { 0x147A, opcode::OP_GetFunction },
    { 0x147B, opcode::OP_Invalid },
    { 0x147C, opcode::OP_Invalid },
    { 0x147D, opcode::OP_Invalid },
    { 0x147E, opcode::OP_GetClassesObject },
    { 0x147F, opcode::OP_Invalid },
    { 0x1480, opcode::OP_Invalid },
    { 0x1481, opcode::OP_ProfileStop },
    { 0x1482, opcode::OP_ScriptMethodThreadCall },
    { 0x1483, opcode::OP_Invalid },
    { 0x1484, opcode::OP_Inc },
    { 0x1485, opcode::OP_Invalid },
    { 0x1486, opcode::OP_NextArrayKey },
    { 0x1487, opcode::OP_Invalid },
    { 0x1488, opcode::OP_GetInteger },
    { 0x1489, opcode::OP_ScriptMethodCall },
    { 0x148A, opcode::OP_Invalid },
    { 0x148B, opcode::OP_GetNegByte },
    { 0x148C, opcode::OP_ScriptMethodCall },
    { 0x148D, opcode::OP_EmptyArray },
    { 0x148E, opcode::OP_Equal },
    { 0x148F, opcode::OP_Invalid },
    { 0x1490, opcode::OP_Invalid },
    { 0x1491, opcode::OP_Invalid },
    { 0x1492, opcode::OP_JumpOnTrue },
    { 0x1493, opcode::OP_ScriptMethodThreadCall },
    { 0x1494, opcode::OP_Invalid },
    { 0x1495, opcode::OP_Invalid },
    { 0x1496, opcode::OP_EvalFieldVariableRef },
    { 0x1497, opcode::OP_Invalid },
    { 0x1498, opcode::OP_GetGameRef },
    { 0x1499, opcode::OP_ShiftRight },
    { 0x149A, opcode::OP_GetIString },
    { 0x149B, opcode::OP_EvalArray },
    { 0x149C, opcode::OP_Wait },
    { 0x149D, opcode::OP_Bit_Or },
    { 0x149E, opcode::OP_Invalid },
    { 0x149F, opcode::OP_New },
    { 0x14A0, opcode::OP_ClearFieldVariable },
    { 0x14A1, opcode::OP_EvalLocalVariableCached },
    { 0x14A2, opcode::OP_ShiftLeft },
    { 0x14A3, opcode::OP_Invalid },
    { 0x14A4, opcode::OP_Return },
    { 0x14A5, opcode::OP_ScriptFunctionCall },
    { 0x14A6, opcode::OP_CastFieldObject },
    { 0x14A7, opcode::OP_Invalid },
    { 0x14A8, opcode::OP_Invalid },
    { 0x14A9, opcode::OP_Invalid },
    { 0x14AA, opcode::OP_ScriptThreadCallPointer },
    { 0x14AB, opcode::OP_ProfileStop },
    { 0x14AC, opcode::OP_WaitTillMatch },
    { 0x14AD, opcode::OP_SetVariableField },
    { 0x14AE, opcode::OP_Invalid },
    { 0x14AF, opcode::OP_SelfEvalFieldVariable },
    { 0x14B0, opcode::OP_Invalid },
    { 0x14B1, opcode::OP_New },
    { 0x14B2, opcode::OP_Invalid },
    { 0x14B3, opcode::OP_VectorConstant },
    { 0x14B4, opcode::OP_SelfEvalFieldVariable },
    { 0x14B5, opcode::OP_Invalid },
    { 0x14B6, opcode::OP_ScriptThreadCallClass },
    { 0x14B7, opcode::OP_GetGameRef },
    { 0x14B8, opcode::OP_GetFloat },
    { 0x14B9, opcode::OP_JumpOnTrue },
    { 0x14BA, opcode::OP_Dec },
    { 0x14BB, opcode::OP_GreaterThanOrEqualTo },
    { 0x14BC, opcode::OP_SizeOf },
    { 0x14BD, opcode::OP_GetAPIFunction },
    { 0x14BE, opcode::OP_Modulus },
    { 0x14BF, opcode::OP_GetSelf },
    { 0x14C0, opcode::OP_Inc },
    { 0x14C1, opcode::OP_Invalid },
    { 0x14C2, opcode::OP_Invalid },
    { 0x14C3, opcode::OP_Invalid },
    { 0x14C4, opcode::OP_Invalid },
    { 0x14C5, opcode::OP_Invalid },
    { 0x14C6, opcode::OP_Invalid },
    { 0x14C7, opcode::OP_Minus },
    { 0x14C8, opcode::OP_Plus },
    { 0x14C9, opcode::OP_GetZero },
    { 0x14CA, opcode::OP_WaitTill },
    { 0x14CB, opcode::OP_Invalid },
    { 0x14CC, opcode::OP_NextArrayKey },
    { 0x14CD, opcode::OP_EvalLocalVariableCached },
    { 0x14CE, opcode::OP_ShiftLeft },
    { 0x14CF, opcode::OP_Divide },
    { 0x14D0, opcode::OP_GetAnimObject },
    { 0x14D1, opcode::OP_Multiply },
    { 0x14D2, opcode::OP_GetAPIFunction },
    { 0x14D3, opcode::OP_GetUnsignedShort },
    { 0x14D4, opcode::OP_Invalid },
    { 0x14D5, opcode::OP_FirstArrayKey },
    { 0x14D6, opcode::OP_GetFunction },
    { 0x14D7, opcode::OP_Invalid },
    { 0x14D8, opcode::OP_SuperNotEqual },
    { 0x14D9, opcode::OP_Invalid },
    { 0x14DA, opcode::OP_Invalid },
    { 0x14DB, opcode::OP_Invalid },
    { 0x14DC, opcode::OP_Jump },
    { 0x14DD, opcode::OP_Invalid },
    { 0x14DE, opcode::OP_ClearArray },
    { 0x14DF, opcode::OP_ClearFieldVariable },
    { 0x14E0, opcode::OP_GetLevel },
    { 0x14E1, opcode::OP_EndSwitch },
    { 0x14E2, opcode::OP_Invalid },
    { 0x14E3, opcode::OP_GetString },
    { 0x14E4, opcode::OP_Inc },
    { 0x14E5, opcode::OP_Minus },
    { 0x14E6, opcode::OP_ScriptMethodCallPointer },
    { 0x14E7, opcode::OP_ScriptFunctionCall },
    { 0x14E8, opcode::OP_Invalid },
    { 0x14E9, opcode::OP_Invalid },
    { 0x14EA, opcode::OP_ScriptMethodThreadCall },
    { 0x14EB, opcode::OP_Invalid },
    { 0x14EC, opcode::OP_GetWorld },
    { 0x14ED, opcode::OP_GetGameRef },
    { 0x14EE, opcode::OP_Invalid },
    { 0x14EF, opcode::OP_EndOn },
    { 0x14F0, opcode::OP_VectorScale },
    { 0x14F1, opcode::OP_LessThanOrEqualTo },
    { 0x14F2, opcode::OP_GetHash },
    { 0x14F3, opcode::OP_NextArrayKey },
    { 0x14F4, opcode::OP_Switch },
    { 0x14F5, opcode::OP_Invalid },
    { 0x14F6, opcode::OP_GetGame },
    { 0x14F7, opcode::OP_LevelEvalFieldVariable },
    { 0x14F8, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x14F9, opcode::OP_VectorConstant },
    { 0x14FA, opcode::OP_EvalFieldVariableRef },
    { 0x14FB, opcode::OP_Dec },
    { 0x14FC, opcode::OP_Invalid },
    { 0x14FD, opcode::OP_Bit_Xor },
    { 0x14FE, opcode::OP_GetClasses },
    { 0x14FF, opcode::OP_GetByte },
    { 0x1500, opcode::OP_FirstArrayKey },
    { 0x1501, opcode::OP_NextArrayKey },
    { 0x1502, opcode::OP_GetNegUnsignedShort },
    { 0x1503, opcode::OP_ScriptFunctionCallClass },
    { 0x1504, opcode::OP_GetAnim },
    { 0x1505, opcode::OP_SafeSetVariableFieldCached },
    { 0x1506, opcode::OP_ClearFieldVariable },
    { 0x1507, opcode::OP_GetUnsignedShort },
    { 0x1508, opcode::OP_Invalid },
    { 0x1509, opcode::OP_Invalid },
    { 0x150A, opcode::OP_JumpOnTrueExpr },
    { 0x150B, opcode::OP_Invalid },
    { 0x150C, opcode::OP_GetClassesObject },
    { 0x150D, opcode::OP_WaitTill },
    { 0x150E, opcode::OP_JumpOnTrueExpr },
    { 0x150F, opcode::OP_ScriptMethodThreadCall },
    { 0x1510, opcode::OP_Invalid },
    { 0x1511, opcode::OP_GetUintptr },
    { 0x1512, opcode::OP_GetLevel },
    { 0x1513, opcode::OP_VectorScale },
    { 0x1514, opcode::OP_Invalid },
    { 0x1515, opcode::OP_GetSelf },
    { 0x1516, opcode::OP_ScriptThreadCallClass },
    { 0x1517, opcode::OP_Dec },
    { 0x1518, opcode::OP_Invalid },
    { 0x1519, opcode::OP_Invalid },
    { 0x151A, opcode::OP_Bit_Or },
    { 0x151B, opcode::OP_GetGameRef },
    { 0x151C, opcode::OP_ShiftRight },
    { 0x151D, opcode::OP_ProfileStart },
    { 0x151E, opcode::OP_Invalid },
    { 0x151F, opcode::OP_Invalid },
    { 0x1520, opcode::OP_GetVector },
    { 0x1521, opcode::OP_EvalFieldVariable },
    { 0x1522, opcode::OP_GetGame },
    { 0x1523, opcode::OP_GetVector },
    { 0x1524, opcode::OP_Invalid },
    { 0x1525, opcode::OP_Invalid },
    { 0x1526, opcode::OP_ShiftRight },
    { 0x1527, opcode::OP_Invalid },
    { 0x1528, opcode::OP_EvalLocalVariableCached },
    { 0x1529, opcode::OP_GetNegByte },
    { 0x152A, opcode::OP_Invalid },
    { 0x152B, opcode::OP_EmptyArray },
    { 0x152C, opcode::OP_CastBool },
    { 0x152D, opcode::OP_BoolComplement },
    { 0x152E, opcode::OP_DecTop },
    { 0x152F, opcode::OP_GetUintptr },
    { 0x1530, opcode::OP_GetFloat },
    { 0x1531, opcode::OP_Invalid },
    { 0x1532, opcode::OP_EndSwitch },
    { 0x1533, opcode::OP_Dec },
    { 0x1534, opcode::OP_GetUintptr },
    { 0x1535, opcode::OP_GetGame },
    { 0x1536, opcode::OP_GetClassesObject },
    { 0x1537, opcode::OP_Invalid },
    { 0x1538, opcode::OP_GetClassesObject },
    { 0x1539, opcode::OP_JumpOnFalse },
    { 0x153A, opcode::OP_Invalid },
    { 0x153B, opcode::OP_ScriptThreadCallPointer },
    { 0x153C, opcode::OP_EvalLocalVariableCached },
    { 0x153D, opcode::OP_Invalid },
    { 0x153E, opcode::OP_Invalid },
    { 0x153F, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x1540, opcode::OP_GetZero },
    { 0x1541, opcode::OP_Invalid },
    { 0x1542, opcode::OP_GetNegUnsignedShort },
    { 0x1543, opcode::OP_Invalid },
    { 0x1544, opcode::OP_Invalid },
    { 0x1545, opcode::OP_DecTop },
    { 0x1546, opcode::OP_SizeOf },
    { 0x1547, opcode::OP_DevblockBegin },
    { 0x1548, opcode::OP_ScriptMethodCallPointer },
    { 0x1549, opcode::OP_SafeSetVariableFieldCached },
    { 0x154A, opcode::OP_EvalArrayRef },
    { 0x154B, opcode::OP_GetLevel },
    { 0x154C, opcode::OP_Invalid },
    { 0x154D, opcode::OP_ClearArray },
    { 0x154E, opcode::OP_Bit_And },
    { 0x154F, opcode::OP_Switch },
    { 0x1550, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x1551, opcode::OP_Invalid },
    { 0x1552, opcode::OP_GreaterThanOrEqualTo },
    { 0x1553, opcode::OP_Equal },
    { 0x1554, opcode::OP_GetAnimation },
    { 0x1555, opcode::OP_EndOn },
    { 0x1556, opcode::OP_DecTop },
    { 0x1557, opcode::OP_Divide },
    { 0x1558, opcode::OP_Invalid },
    { 0x1559, opcode::OP_Invalid },
    { 0x155A, opcode::OP_BoolNot },
    { 0x155B, opcode::OP_GetLevelObject },
    { 0x155C, opcode::OP_Bit_And },
    { 0x155D, opcode::OP_GetWorldObject },
    { 0x155E, opcode::OP_Bit_Or },
    { 0x155F, opcode::OP_Dec },
    { 0x1560, opcode::OP_Notify },
    { 0x1561, opcode::OP_Invalid },
    { 0x1562, opcode::OP_Invalid },
    { 0x1563, opcode::OP_Invalid },
    { 0x1564, opcode::OP_EvalLocalVariableCached },
    { 0x1565, opcode::OP_Invalid },
    { 0x1566, opcode::OP_Invalid },
    { 0x1567, opcode::OP_GetAnim },
    { 0x1568, opcode::OP_Invalid },
    { 0x1569, opcode::OP_DevblockBegin },
    { 0x156A, opcode::OP_Invalid },
    { 0x156B, opcode::OP_GreaterThan },
    { 0x156C, opcode::OP_GetClassesObject },
    { 0x156D, opcode::OP_GetClasses },
    { 0x156E, opcode::OP_DevblockBegin },
    { 0x156F, opcode::OP_Invalid },
    { 0x1570, opcode::OP_Invalid },
    { 0x1571, opcode::OP_GetAPIFunction },
    { 0x1572, opcode::OP_Invalid },
    { 0x1573, opcode::OP_ShiftLeft },
    { 0x1574, opcode::OP_JumpOnFalseExpr },
    { 0x1575, opcode::OP_SelfEvalFieldVariable },
    { 0x1576, opcode::OP_GetUintptr },
    { 0x1577, opcode::OP_Invalid },
    { 0x1578, opcode::OP_Invalid },
    { 0x1579, opcode::OP_GetHash },
    { 0x157A, opcode::OP_ShiftRight },
    { 0x157B, opcode::OP_Invalid },
    { 0x157C, opcode::OP_Invalid },
    { 0x157D, opcode::OP_Invalid },
    { 0x157E, opcode::OP_GetClassesObject },
    { 0x157F, opcode::OP_GetSelf },
    { 0x1580, opcode::OP_Invalid },
    { 0x1581, opcode::OP_Invalid },
    { 0x1582, opcode::OP_Wait },
    { 0x1583, opcode::OP_Invalid },
    { 0x1584, opcode::OP_LevelEvalFieldVariable },
    { 0x1585, opcode::OP_Bit_Xor },
    { 0x1586, opcode::OP_Invalid },
    { 0x1587, opcode::OP_EndSwitch },
    { 0x1588, opcode::OP_Invalid },
    { 0x1589, opcode::OP_Notify },
    { 0x158A, opcode::OP_GetFloat },
    { 0x158B, opcode::OP_GetLevel },
    { 0x158C, opcode::OP_Invalid },
    { 0x158D, opcode::OP_ScriptFunctionCallClass },
    { 0x158E, opcode::OP_VectorScale },
    { 0x158F, opcode::OP_ScriptThreadCallClass },
    { 0x1590, opcode::OP_VectorConstant },
    { 0x1591, opcode::OP_ProfileStart },
    { 0x1592, opcode::OP_EvalLocalVariableRefCached },
    { 0x1593, opcode::OP_SafeDecTop },
    { 0x1594, opcode::OP_DevblockBegin },
    { 0x1595, opcode::OP_RealWait },
    { 0x1596, opcode::OP_GetByte },
    { 0x1597, opcode::OP_GetLevelObject },
    { 0x1598, opcode::OP_Bit_And },
    { 0x1599, opcode::OP_GetGame },
    { 0x159A, opcode::OP_GetInteger },
    { 0x159B, opcode::OP_SelfEvalFieldVariable },
    { 0x159C, opcode::OP_Invalid },
    { 0x159D, opcode::OP_GetVector },
    { 0x159E, opcode::OP_ShiftRight },
    { 0x159F, opcode::OP_JumpOnFalse },
    { 0x15A0, opcode::OP_ScriptFunctionCall },
    { 0x15A1, opcode::OP_SafeCreateLocalVariables },
    { 0x15A2, opcode::OP_GetFloat },
    { 0x15A3, opcode::OP_ProfileStart },
    { 0x15A4, opcode::OP_Invalid },
    { 0x15A5, opcode::OP_GetSelf },
    { 0x15A6, opcode::OP_GetTime },
    { 0x15A7, opcode::OP_Invalid },
    { 0x15A8, opcode::OP_GetUndefined },
    { 0x15A9, opcode::OP_Invalid },
    { 0x15AA, opcode::OP_ScriptThreadCallPointer },
    { 0x15AB, opcode::OP_GetSelf },
    { 0x15AC, opcode::OP_LessThan },
    { 0x15AD, opcode::OP_Invalid },
    { 0x15AE, opcode::OP_Dec },
    { 0x15AF, opcode::OP_SelfEvalFieldVariableRef },
    { 0x15B0, opcode::OP_Invalid },
    { 0x15B1, opcode::OP_ScriptThreadCallPointer },
    { 0x15B2, opcode::OP_IsDefined },
    { 0x15B3, opcode::OP_Invalid },
    { 0x15B4, opcode::OP_Vector },
    { 0x15B5, opcode::OP_IsDefined },
    { 0x15B6, opcode::OP_DevblockBegin },
    { 0x15B7, opcode::OP_GetTime },
    { 0x15B8, opcode::OP_CallBuiltinMethod },
    { 0x15B9, opcode::OP_Invalid },
    { 0x15BA, opcode::OP_Invalid },
    { 0x15BB, opcode::OP_Minus },
    { 0x15BC, opcode::OP_ProfileStart },
    { 0x15BD, opcode::OP_EndSwitch },
    { 0x15BE, opcode::OP_Invalid },
    { 0x15BF, opcode::OP_Invalid },
    { 0x15C0, opcode::OP_Divide },
    { 0x15C1, opcode::OP_BoolNot },
    { 0x15C2, opcode::OP_GetByte },
    { 0x15C3, opcode::OP_GetByte },
    { 0x15C4, opcode::OP_ScriptMethodThreadCall },
    { 0x15C5, opcode::OP_JumpOnFalseExpr },
    { 0x15C6, opcode::OP_GetLevel },
    { 0x15C7, opcode::OP_Invalid },
    { 0x15C8, opcode::OP_Invalid },
    { 0x15C9, opcode::OP_IsDefined },
    { 0x15CA, opcode::OP_SuperEqual },
    { 0x15CB, opcode::OP_Invalid },
    { 0x15CC, opcode::OP_Invalid },
    { 0x15CD, opcode::OP_ProfileStop },
    { 0x15CE, opcode::OP_GetFunction },
    { 0x15CF, opcode::OP_Invalid },
    { 0x15D0, opcode::OP_WaitTill },
    { 0x15D1, opcode::OP_GetAnimObject },
    { 0x15D2, opcode::OP_Vector },
    { 0x15D3, opcode::OP_EvalArray },
    { 0x15D4, opcode::OP_Invalid },
    { 0x15D5, opcode::OP_Invalid },
    { 0x15D6, opcode::OP_Divide },
    { 0x15D7, opcode::OP_GetFloat },
    { 0x15D8, opcode::OP_Invalid },
    { 0x15D9, opcode::OP_Invalid },
    { 0x15DA, opcode::OP_Invalid },
    { 0x15DB, opcode::OP_BoolComplement },
    { 0x15DC, opcode::OP_Invalid },
    { 0x15DD, opcode::OP_Invalid },
    { 0x15DE, opcode::OP_EvalArrayRef },
    { 0x15DF, opcode::OP_Invalid },
    { 0x15E0, opcode::OP_New },
    { 0x15E1, opcode::OP_GetVector },
    { 0x15E2, opcode::OP_FirstArrayKey },
    { 0x15E3, opcode::OP_GetAPIFunction },
    { 0x15E4, opcode::OP_SuperNotEqual },
    { 0x15E5, opcode::OP_GetClasses },
    { 0x15E6, opcode::OP_Invalid },
    { 0x15E7, opcode::OP_Invalid },
    { 0x15E8, opcode::OP_GetGame },
    { 0x15E9, opcode::OP_JumpOnTrue },
    { 0x15EA, opcode::OP_WaitTill },
    { 0x15EB, opcode::OP_BoolComplement },
    { 0x15EC, opcode::OP_Invalid },
    { 0x15ED, opcode::OP_GetNegUnsignedShort },
    { 0x15EE, opcode::OP_GetSelf },
    { 0x15EF, opcode::OP_Invalid },
    { 0x15F0, opcode::OP_Invalid },
    { 0x15F1, opcode::OP_Invalid },
    { 0x15F2, opcode::OP_Modulus },
    { 0x15F3, opcode::OP_Invalid },
    { 0x15F4, opcode::OP_SizeOf },
    { 0x15F5, opcode::OP_GetFloat },
    { 0x15F6, opcode::OP_GetTime },
    { 0x15F7, opcode::OP_ScriptThreadCall },
    { 0x15F8, opcode::OP_New },
    { 0x15F9, opcode::OP_LessThanOrEqualTo },
    { 0x15FA, opcode::OP_LevelEvalFieldVariableRef },
    { 0x15FB, opcode::OP_ProfileStart },
    { 0x15FC, opcode::OP_GetWorld },
    { 0x15FD, opcode::OP_RealWait },
    { 0x15FE, opcode::OP_BoolNot },
    { 0x15FF, opcode::OP_Divide },
    { 0x1600, opcode::OP_Invalid },
    { 0x1601, opcode::OP_ScriptThreadCallPointer },
    { 0x1602, opcode::OP_ScriptMethodCall },
    { 0x1603, opcode::OP_BoolComplement },
    { 0x1604, opcode::OP_Inc },
    { 0x1605, opcode::OP_Wait },
    { 0x1606, opcode::OP_Invalid },
    { 0x1607, opcode::OP_Invalid },
    { 0x1608, opcode::OP_Plus },
    { 0x1609, opcode::OP_Invalid },
    { 0x160A, opcode::OP_Invalid },
    { 0x160B, opcode::OP_GetNegUnsignedShort },
    { 0x160C, opcode::OP_Invalid },
    { 0x160D, opcode::OP_Invalid },
    { 0x160E, opcode::OP_EndOn },
    { 0x160F, opcode::OP_ClearArray },
    { 0x1610, opcode::OP_ProfileStop },
    { 0x1611, opcode::OP_SelfEvalFieldVariable },
    { 0x1612, opcode::OP_Invalid },
    { 0x1613, opcode::OP_GetByte },
    { 0x1614, opcode::OP_GetByte },
    { 0x1615, opcode::OP_GetAPIFunction },
    { 0x1616, opcode::OP_Notify },
    { 0x1617, opcode::OP_Invalid },
    { 0x1618, opcode::OP_Invalid },
    { 0x1619, opcode::OP_GetFunction },
    { 0x161A, opcode::OP_GetAPIFunction },
    { 0x161B, opcode::OP_GetByte },
    { 0x161C, opcode::OP_SafeDecTop },
    { 0x161D, opcode::OP_Invalid },
    { 0x161E, opcode::OP_ClearArray },
    { 0x161F, opcode::OP_WaitTill },
    { 0x1620, opcode::OP_ShiftRight },
    { 0x1621, opcode::OP_GetNegUnsignedShort },
    { 0x1622, opcode::OP_GetZero },
    { 0x1623, opcode::OP_GreaterThanOrEqualTo },
    { 0x1624, opcode::OP_Invalid },
    { 0x1625, opcode::OP_LevelEvalFieldVariableRef },
    { 0x1626, opcode::OP_Invalid },
    { 0x1627, opcode::OP_GetTime },
    { 0x1628, opcode::OP_Invalid },
    { 0x1629, opcode::OP_New },
    { 0x162A, opcode::OP_FirstArrayKey },
    { 0x162B, opcode::OP_BoolNot },
    { 0x162C, opcode::OP_GetLevelObject },
    { 0x162D, opcode::OP_Invalid },
    { 0x162E, opcode::OP_Invalid },
    { 0x162F, opcode::OP_Invalid },
    { 0x1630, opcode::OP_GetNegByte },
    { 0x1631, opcode::OP_EvalLocalVariableCached },
    { 0x1632, opcode::OP_Invalid },
    { 0x1633, opcode::OP_BoolComplement },
    { 0x1634, opcode::OP_GetFunction },
    { 0x1635, opcode::OP_Invalid },
    { 0x1636, opcode::OP_ScriptFunctionCallClass },
    { 0x1637, opcode::OP_LevelEvalFieldVariable },
    { 0x1638, opcode::OP_Invalid },
    { 0x1639, opcode::OP_Plus },
    { 0x163A, opcode::OP_IsDefined },
    { 0x163B, opcode::OP_ScriptThreadCall },
    { 0x163C, opcode::OP_GetClasses },
    { 0x163D, opcode::OP_GetClassesObject },
    { 0x163E, opcode::OP_Invalid },
    { 0x163F, opcode::OP_Multiply },
    { 0x1640, opcode::OP_LessThan },
    { 0x1641, opcode::OP_SafeSetVariableFieldCached },
    { 0x1642, opcode::OP_Minus },
    { 0x1643, opcode::OP_Vector },
    { 0x1644, opcode::OP_Invalid },
    { 0x1645, opcode::OP_GetNegByte },
    { 0x1646, opcode::OP_Invalid },
    { 0x1647, opcode::OP_Invalid },
    { 0x1648, opcode::OP_Notify },
    { 0x1649, opcode::OP_GetLevel },
    { 0x164A, opcode::OP_IsDefined },
    { 0x164B, opcode::OP_DevblockBegin },
    { 0x164C, opcode::OP_Invalid },
    { 0x164D, opcode::OP_SizeOf },
    { 0x164E, opcode::OP_Invalid },
    { 0x164F, opcode::OP_GetInteger },
    { 0x1650, opcode::OP_Invalid },
    { 0x1651, opcode::OP_ScriptMethodCallPointer },
    { 0x1652, opcode::OP_GetAPIFunction },
    { 0x1653, opcode::OP_Invalid },
    { 0x1654, opcode::OP_SafeCreateLocalVariables },
    { 0x1655, opcode::OP_Invalid },
    { 0x1656, opcode::OP_Wait },
    { 0x1657, opcode::OP_Invalid },
    { 0x1658, opcode::OP_Bit_Or },
    { 0x1659, opcode::OP_DevblockBegin },
    { 0x165A, opcode::OP_GetAnimation },
    { 0x165B, opcode::OP_GetZero },
    { 0x165C, opcode::OP_GetClasses },
    { 0x165D, opcode::OP_Dec },
    { 0x165E, opcode::OP_Invalid },
    { 0x165F, opcode::OP_BoolComplement },
    { 0x1660, opcode::OP_LessThan },
    { 0x1661, opcode::OP_GreaterThan },
    { 0x1662, opcode::OP_Invalid },
    { 0x1663, opcode::OP_GetAnim },
    { 0x1664, opcode::OP_SelfEvalFieldVariable },
    { 0x1665, opcode::OP_EvalFieldVariableRef },
    { 0x1666, opcode::OP_Notify },
    { 0x1667, opcode::OP_Invalid },
    { 0x1668, opcode::OP_Invalid },
    { 0x1669, opcode::OP_GetAPIFunction },
    { 0x166A, opcode::OP_SafeDecTop },
    { 0x166B, opcode::OP_Invalid },
    { 0x166C, opcode::OP_GetFunction },
    { 0x166D, opcode::OP_Invalid },
    { 0x166E, opcode::OP_GetAnimObject },
    { 0x166F, opcode::OP_GetAnim },
    { 0x1670, opcode::OP_FirstArrayKey },
    { 0x1671, opcode::OP_New },
    { 0x1672, opcode::OP_Invalid },
    { 0x1673, opcode::OP_GetAPIFunction },
    { 0x1674, opcode::OP_EndOn },
    { 0x1675, opcode::OP_GetAnim },
    { 0x1676, opcode::OP_ScriptThreadCallClass },
    { 0x1677, opcode::OP_GetZero },
    { 0x1678, opcode::OP_Plus },
    { 0x1679, opcode::OP_GetUintptr },
    { 0x167A, opcode::OP_JumpOnTrue },
    { 0x167B, opcode::OP_Invalid },
    { 0x167C, opcode::OP_ClearFieldVariable },
    { 0x167D, opcode::OP_Invalid },
    { 0x167E, opcode::OP_GetClassesObject },
    { 0x167F, opcode::OP_New },
    { 0x1680, opcode::OP_Invalid },
    { 0x1681, opcode::OP_EndSwitch },
    { 0x1682, opcode::OP_GetLevelObject },
    { 0x1683, opcode::OP_Invalid },
    { 0x1684, opcode::OP_EvalFieldVariable },
    { 0x1685, opcode::OP_JumpOnFalse },
    { 0x1686, opcode::OP_Invalid },
    { 0x1687, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x1688, opcode::OP_SuperEqual },
    { 0x1689, opcode::OP_ProfileStop },
    { 0x168A, opcode::OP_VectorScale },
    { 0x168B, opcode::OP_ProfileStart },
    { 0x168C, opcode::OP_Invalid },
    { 0x168D, opcode::OP_Invalid },
    { 0x168E, opcode::OP_EvalLocalVariableRefCached },
    { 0x168F, opcode::OP_Invalid },
    { 0x1690, opcode::OP_Dec },
    { 0x1691, opcode::OP_GetWorld },
    { 0x1692, opcode::OP_BoolNot },
    { 0x1693, opcode::OP_Minus },
    { 0x1694, opcode::OP_GetIString },
    { 0x1695, opcode::OP_Invalid },
    { 0x1696, opcode::OP_GetZero },
    { 0x1697, opcode::OP_Invalid },
    { 0x1698, opcode::OP_NextArrayKey },
    { 0x1699, opcode::OP_VectorConstant },
    { 0x169A, opcode::OP_Invalid },
    { 0x169B, opcode::OP_Vector },
    { 0x169C, opcode::OP_Invalid },
    { 0x169D, opcode::OP_ScriptFunctionCallPointer },
    { 0x169E, opcode::OP_Invalid },
    { 0x169F, opcode::OP_Inc },
    { 0x16A0, opcode::OP_GetWorld },
    { 0x16A1, opcode::OP_Invalid },
    { 0x16A2, opcode::OP_ScriptFunctionCallPointer },
    { 0x16A3, opcode::OP_GetSelf },
    { 0x16A4, opcode::OP_IsDefined },
    { 0x16A5, opcode::OP_BoolComplement },
    { 0x16A6, opcode::OP_EvalLocalVariableCached },
    { 0x16A7, opcode::OP_Notify },
    { 0x16A8, opcode::OP_Notify },
    { 0x16A9, opcode::OP_Invalid },
    { 0x16AA, opcode::OP_CastFieldObject },
    { 0x16AB, opcode::OP_EvalFieldVariableRef },
    { 0x16AC, opcode::OP_Invalid },
    { 0x16AD, opcode::OP_Invalid },
    { 0x16AE, opcode::OP_GetGameRef },
    { 0x16AF, opcode::OP_NextArrayKey },
    { 0x16B0, opcode::OP_GetWorld },
    { 0x16B1, opcode::OP_GetAPIFunction },
    { 0x16B2, opcode::OP_Invalid },
    { 0x16B3, opcode::OP_LessThan },
    { 0x16B4, opcode::OP_Invalid },
    { 0x16B5, opcode::OP_Invalid },
    { 0x16B6, opcode::OP_JumpOnFalse },
    { 0x16B7, opcode::OP_GetSelfObject },
    { 0x16B8, opcode::OP_SelfEvalFieldVariableRef },
    { 0x16B9, opcode::OP_Notify },
    { 0x16BA, opcode::OP_Invalid },
    { 0x16BB, opcode::OP_Invalid },
    { 0x16BC, opcode::OP_DecTop },
    { 0x16BD, opcode::OP_SelfEvalFieldVariableRef },
    { 0x16BE, opcode::OP_Notify },
    { 0x16BF, opcode::OP_GetNegUnsignedShort },
    { 0x16C0, opcode::OP_ShiftRight },
    { 0x16C1, opcode::OP_Notify },
    { 0x16C2, opcode::OP_Invalid },
    { 0x16C3, opcode::OP_IsDefined },
    { 0x16C4, opcode::OP_Invalid },
    { 0x16C5, opcode::OP_Invalid },
    { 0x16C6, opcode::OP_Invalid },
    { 0x16C7, opcode::OP_Invalid },
    { 0x16C8, opcode::OP_ShiftLeft },
    { 0x16C9, opcode::OP_GetWorldObject },
    { 0x16CA, opcode::OP_RealWait },
    { 0x16CB, opcode::OP_ScriptFunctionCallClass },
    { 0x16CC, opcode::OP_Invalid },
    { 0x16CD, opcode::OP_Invalid },
    { 0x16CE, opcode::OP_RealWait },
    { 0x16CF, opcode::OP_LessThan },
    { 0x16D0, opcode::OP_SuperNotEqual },
    { 0x16D1, opcode::OP_Invalid },
    { 0x16D2, opcode::OP_GetClasses },
    { 0x16D3, opcode::OP_GetClasses },
    { 0x16D4, opcode::OP_GetGameRef },
    { 0x16D5, opcode::OP_Invalid },
    { 0x16D6, opcode::OP_Switch },
    { 0x16D7, opcode::OP_Invalid },
    { 0x16D8, opcode::OP_NotEqual },
    { 0x16D9, opcode::OP_GetByte },
    { 0x16DA, opcode::OP_Invalid },
    { 0x16DB, opcode::OP_GetLevelObject },
    { 0x16DC, opcode::OP_Invalid },
    { 0x16DD, opcode::OP_Return },
    { 0x16DE, opcode::OP_Invalid },
    { 0x16DF, opcode::OP_Invalid },
    { 0x16E0, opcode::OP_Bit_And },
    { 0x16E1, opcode::OP_Equal },
    { 0x16E2, opcode::OP_GetFunction },
    { 0x16E3, opcode::OP_SetVariableField },
    { 0x16E4, opcode::OP_WaitTillFrameEnd },
    { 0x16E5, opcode::OP_JumpOnFalse },
    { 0x16E6, opcode::OP_Invalid },
    { 0x16E7, opcode::OP_GetGameRef },
    { 0x16E8, opcode::OP_GetHash },
    { 0x16E9, opcode::OP_ScriptMethodThreadCall },
    { 0x16EA, opcode::OP_GetInteger },
    { 0x16EB, opcode::OP_GetNegByte },
    { 0x16EC, opcode::OP_ScriptThreadCall },
    { 0x16ED, opcode::OP_JumpOnFalseExpr },
    { 0x16EE, opcode::OP_ScriptFunctionCall },
    { 0x16EF, opcode::OP_EndSwitch },
    { 0x16F0, opcode::OP_Invalid },
    { 0x16F1, opcode::OP_NextArrayKey },
    { 0x16F2, opcode::OP_GetHash },
    { 0x16F3, opcode::OP_Invalid },
    { 0x16F4, opcode::OP_Invalid },
    { 0x16F5, opcode::OP_SelfEvalFieldVariable },
    { 0x16F6, opcode::OP_GetNegByte },
    { 0x16F7, opcode::OP_WaitTillMatch },
    { 0x16F8, opcode::OP_GetUndefined },
    { 0x16F9, opcode::OP_Inc },
    { 0x16FA, opcode::OP_SizeOf },
    { 0x16FB, opcode::OP_New },
    { 0x16FC, opcode::OP_Switch },
    { 0x16FD, opcode::OP_LevelEvalFieldVariable },
    { 0x16FE, opcode::OP_Invalid },
    { 0x16FF, opcode::OP_GetGame },
    { 0x1700, opcode::OP_Dec },
    { 0x1701, opcode::OP_Invalid },
    { 0x1702, opcode::OP_Invalid },
    { 0x1703, opcode::OP_Switch },
    { 0x1704, opcode::OP_ScriptFunctionCallPointer },
    { 0x1705, opcode::OP_Invalid },
    { 0x1706, opcode::OP_GetTime },
    { 0x1707, opcode::OP_EvalArrayRef },
    { 0x1708, opcode::OP_ScriptThreadCallClass },
    { 0x1709, opcode::OP_IsDefined },
    { 0x170A, opcode::OP_GetClassesObject },
    { 0x170B, opcode::OP_Invalid },
    { 0x170C, opcode::OP_Invalid },
    { 0x170D, opcode::OP_ScriptMethodCall },
    { 0x170E, opcode::OP_Invalid },
    { 0x170F, opcode::OP_Invalid },
    { 0x1710, opcode::OP_WaitTillMatch },
    { 0x1711, opcode::OP_DevblockBegin },
    { 0x1712, opcode::OP_GetSelfObject },
    { 0x1713, opcode::OP_Invalid },
    { 0x1714, opcode::OP_Invalid },
    { 0x1715, opcode::OP_Invalid },
    { 0x1716, opcode::OP_GetClasses },
    { 0x1717, opcode::OP_Invalid },
    { 0x1718, opcode::OP_ScriptMethodThreadCall },
    { 0x1719, opcode::OP_Invalid },
    { 0x171A, opcode::OP_VectorConstant },
    { 0x171B, opcode::OP_ScriptFunctionCall },
    { 0x171C, opcode::OP_SelfEvalFieldVariable },
    { 0x171D, opcode::OP_EvalLocalVariableRefCached },
    { 0x171E, opcode::OP_Invalid },
    { 0x171F, opcode::OP_IsDefined },
    { 0x1720, opcode::OP_GetSelfObject },
    { 0x1721, opcode::OP_JumpOnFalseExpr },
    { 0x1722, opcode::OP_EvalFieldVariableRef },
    { 0x1723, opcode::OP_Dec },
    { 0x1724, opcode::OP_LessThanOrEqualTo },
    { 0x1725, opcode::OP_Invalid },
    { 0x1726, opcode::OP_EndSwitch },
    { 0x1727, opcode::OP_Invalid },
    { 0x1728, opcode::OP_Invalid },
    { 0x1729, opcode::OP_GetSelfObject },
    { 0x172A, opcode::OP_Plus },
    { 0x172B, opcode::OP_SafeDecTop },
    { 0x172C, opcode::OP_ScriptMethodCallPointer },
    { 0x172D, opcode::OP_GetUndefined },
    { 0x172E, opcode::OP_Invalid },
    { 0x172F, opcode::OP_Invalid },
    { 0x1730, opcode::OP_EvalFieldVariable },
    { 0x1731, opcode::OP_VectorScale },
    { 0x1732, opcode::OP_Invalid },
    { 0x1733, opcode::OP_Invalid },
    { 0x1734, opcode::OP_Invalid },
    { 0x1735, opcode::OP_Jump },
    { 0x1736, opcode::OP_WaitTillMatch },
    { 0x1737, opcode::OP_ScriptMethodCall },
    { 0x1738, opcode::OP_JumpOnFalseExpr },
    { 0x1739, opcode::OP_Invalid },
    { 0x173A, opcode::OP_EvalArray },
    { 0x173B, opcode::OP_JumpOnFalse },
    { 0x173C, opcode::OP_GetNegByte },
    { 0x173D, opcode::OP_GetNegUnsignedShort },
    { 0x173E, opcode::OP_VectorConstant },
    { 0x173F, opcode::OP_ScriptMethodCall },
    { 0x1740, opcode::OP_Invalid },
    { 0x1741, opcode::OP_Invalid },
    { 0x1742, opcode::OP_SuperNotEqual },
    { 0x1743, opcode::OP_Invalid },
    { 0x1744, opcode::OP_ScriptMethodCallPointer },
    { 0x1745, opcode::OP_Invalid },
    { 0x1746, opcode::OP_LevelEvalFieldVariable },
    { 0x1747, opcode::OP_GetWorld },
    { 0x1748, opcode::OP_GetUnsignedShort },
    { 0x1749, opcode::OP_ScriptThreadCallClass },
    { 0x174A, opcode::OP_Bit_Or },
    { 0x174B, opcode::OP_EvalFieldVariableRef },
    { 0x174C, opcode::OP_Invalid },
    { 0x174D, opcode::OP_EvalFieldVariable },
    { 0x174E, opcode::OP_GetWorldObject },
    { 0x174F, opcode::OP_Invalid },
    { 0x1750, opcode::OP_GetSelfObject },
    { 0x1751, opcode::OP_SuperNotEqual },
    { 0x1752, opcode::OP_Invalid },
    { 0x1753, opcode::OP_Invalid },
    { 0x1754, opcode::OP_ClearArray },
    { 0x1755, opcode::OP_GetWorldObject },
    { 0x1756, opcode::OP_Invalid },
    { 0x1757, opcode::OP_Invalid },
    { 0x1758, opcode::OP_GetIString },
    { 0x1759, opcode::OP_Invalid },
    { 0x175A, opcode::OP_IsDefined },
    { 0x175B, opcode::OP_VectorConstant },
    { 0x175C, opcode::OP_LevelEvalFieldVariable },
    { 0x175D, opcode::OP_GetSelf },
    { 0x175E, opcode::OP_ScriptMethodCallPointer },
    { 0x175F, opcode::OP_ScriptThreadCallClass },
    { 0x1760, opcode::OP_SelfEvalFieldVariable },
    { 0x1761, opcode::OP_GetZero },
    { 0x1762, opcode::OP_GetNegByte },
    { 0x1763, opcode::OP_ScriptThreadCall },
    { 0x1764, opcode::OP_EvalArrayRef },
    { 0x1765, opcode::OP_LevelEvalFieldVariable },
    { 0x1766, opcode::OP_Invalid },
    { 0x1767, opcode::OP_Invalid },
    { 0x1768, opcode::OP_VectorConstant },
    { 0x1769, opcode::OP_DevblockBegin },
    { 0x176A, opcode::OP_RealWait },
    { 0x176B, opcode::OP_GetAnimObject },
    { 0x176C, opcode::OP_Invalid },
    { 0x176D, opcode::OP_ScriptMethodCallPointer },
    { 0x176E, opcode::OP_Invalid },
    { 0x176F, opcode::OP_Invalid },
    { 0x1770, opcode::OP_GetWorldObject },
    { 0x1771, opcode::OP_GetGame },
    { 0x1772, opcode::OP_GetAnimation },
    { 0x1773, opcode::OP_GetZero },
    { 0x1774, opcode::OP_Bit_And },
    { 0x1775, opcode::OP_Bit_Or },
    { 0x1776, opcode::OP_Invalid },
    { 0x1777, opcode::OP_GetSelf },
    { 0x1778, opcode::OP_Dec },
    { 0x1779, opcode::OP_Invalid },
    { 0x177A, opcode::OP_Dec },
    { 0x177B, opcode::OP_Wait },
    { 0x177C, opcode::OP_GetUintptr },
    { 0x177D, opcode::OP_BoolComplement },
    { 0x177E, opcode::OP_CastBool },
    { 0x177F, opcode::OP_Invalid },
    { 0x1780, opcode::OP_GetSelfObject },
    { 0x1781, opcode::OP_Invalid },
    { 0x1782, opcode::OP_Invalid },
    { 0x1783, opcode::OP_Invalid },
    { 0x1784, opcode::OP_ScriptMethodCallPointer },
    { 0x1785, opcode::OP_JumpOnFalse },
    { 0x1786, opcode::OP_Invalid },
    { 0x1787, opcode::OP_Invalid },
    { 0x1788, opcode::OP_Multiply },
    { 0x1789, opcode::OP_GetLevelObject },
    { 0x178A, opcode::OP_JumpOnFalse },
    { 0x178B, opcode::OP_SafeSetVariableFieldCached },
    { 0x178C, opcode::OP_ScriptMethodCall },
    { 0x178D, opcode::OP_GetUnsignedShort },
    { 0x178E, opcode::OP_Bit_And },
    { 0x178F, opcode::OP_Equal },
    { 0x1790, opcode::OP_Invalid },
    { 0x1791, opcode::OP_LevelEvalFieldVariableRef },
    { 0x1792, opcode::OP_FirstArrayKey },
    { 0x1793, opcode::OP_Invalid },
    { 0x1794, opcode::OP_Invalid },
    { 0x1795, opcode::OP_New },
    { 0x1796, opcode::OP_LevelEvalFieldVariableRef },
    { 0x1797, opcode::OP_GetGameRef },
    { 0x1798, opcode::OP_New },
    { 0x1799, opcode::OP_VectorScale },
    { 0x179A, opcode::OP_GetUnsignedShort },
    { 0x179B, opcode::OP_ScriptMethodCall },
    { 0x179C, opcode::OP_Notify },
    { 0x179D, opcode::OP_Invalid },
    { 0x179E, opcode::OP_BoolComplement },
    { 0x179F, opcode::OP_GetTime },
    { 0x17A0, opcode::OP_GetSelf },
    { 0x17A1, opcode::OP_SafeDecTop },
    { 0x17A2, opcode::OP_Inc },
    { 0x17A3, opcode::OP_GetSelfObject },
    { 0x17A4, opcode::OP_Invalid },
    { 0x17A5, opcode::OP_Invalid },
    { 0x17A6, opcode::OP_LessThan },
    { 0x17A7, opcode::OP_Jump },
    { 0x17A8, opcode::OP_Multiply },
    { 0x17A9, opcode::OP_SuperNotEqual },
    { 0x17AA, opcode::OP_GetFloat },
    { 0x17AB, opcode::OP_New },
    { 0x17AC, opcode::OP_VectorScale },
    { 0x17AD, opcode::OP_Modulus },
    { 0x17AE, opcode::OP_CallBuiltinMethod },
    { 0x17AF, opcode::OP_ClearFieldVariable },
    { 0x17B0, opcode::OP_EndOn },
    { 0x17B1, opcode::OP_WaitTillFrameEnd },
    { 0x17B2, opcode::OP_Bit_Or },
    { 0x17B3, opcode::OP_GetByte },
    { 0x17B4, opcode::OP_NextArrayKey },
    { 0x17B5, opcode::OP_JumpOnFalseExpr },
    { 0x17B6, opcode::OP_GetGameRef },
    { 0x17B7, opcode::OP_Invalid },
    { 0x17B8, opcode::OP_LessThanOrEqualTo },
    { 0x17B9, opcode::OP_Return },
    { 0x17BA, opcode::OP_LessThan },
    { 0x17BB, opcode::OP_BoolComplement },
    { 0x17BC, opcode::OP_DecTop },
    { 0x17BD, opcode::OP_Invalid },
    { 0x17BE, opcode::OP_Invalid },
    { 0x17BF, opcode::OP_GetZero },
    { 0x17C0, opcode::OP_Invalid },
    { 0x17C1, opcode::OP_GetTime },
    { 0x17C2, opcode::OP_GetGame },
    { 0x17C3, opcode::OP_Invalid },
    { 0x17C4, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x17C5, opcode::OP_Invalid },
    { 0x17C6, opcode::OP_ClearArray },
    { 0x17C7, opcode::OP_Invalid },
    { 0x17C8, opcode::OP_Inc },
    { 0x17C9, opcode::OP_Invalid },
    { 0x17CA, opcode::OP_ScriptThreadCallPointer },
    { 0x17CB, opcode::OP_GetUintptr },
    { 0x17CC, opcode::OP_GetGame },
    { 0x17CD, opcode::OP_GetClasses },
    { 0x17CE, opcode::OP_Minus },
    { 0x17CF, opcode::OP_Invalid },
    { 0x17D0, opcode::OP_GetLevelObject },
    { 0x17D1, opcode::OP_EndOn },
    { 0x17D2, opcode::OP_ShiftRight },
    { 0x17D3, opcode::OP_Invalid },
    { 0x17D4, opcode::OP_WaitTillMatch },
    { 0x17D5, opcode::OP_GetFunction },
    { 0x17D6, opcode::OP_Invalid },
    { 0x17D7, opcode::OP_GetNegByte },
    { 0x17D8, opcode::OP_GetUnsignedShort },
    { 0x17D9, opcode::OP_Invalid },
    { 0x17DA, opcode::OP_ProfileStart },
    { 0x17DB, opcode::OP_Invalid },
    { 0x17DC, opcode::OP_EndSwitch },
    { 0x17DD, opcode::OP_WaitTill },
    { 0x17DE, opcode::OP_GetTime },
    { 0x17DF, opcode::OP_ScriptThreadCallClass },
    { 0x17E0, opcode::OP_EndSwitch },
    { 0x17E1, opcode::OP_GetHash },
    { 0x17E2, opcode::OP_Switch },
    { 0x17E3, opcode::OP_GreaterThanOrEqualTo },
    { 0x17E4, opcode::OP_Invalid },
    { 0x17E5, opcode::OP_SelfEvalFieldVariable },
    { 0x17E6, opcode::OP_WaitTillMatch },
    { 0x17E7, opcode::OP_Invalid },
    { 0x17E8, opcode::OP_Invalid },
    { 0x17E9, opcode::OP_RealWait },
    { 0x17EA, opcode::OP_Multiply },
    { 0x17EB, opcode::OP_GetSelfObject },
    { 0x17EC, opcode::OP_GreaterThan },
    { 0x17ED, opcode::OP_Inc },
    { 0x17EE, opcode::OP_GetClasses },
    { 0x17EF, opcode::OP_Invalid },
    { 0x17F0, opcode::OP_NextArrayKey },
    { 0x17F1, opcode::OP_ScriptMethodCallPointer },
    { 0x17F2, opcode::OP_GetLevel },
    { 0x17F3, opcode::OP_EvalArrayRef },
    { 0x17F4, opcode::OP_EvalLocalVariableRefCached },
    { 0x17F5, opcode::OP_ScriptFunctionCall },
    { 0x17F6, opcode::OP_ProfileStop },
    { 0x17F7, opcode::OP_Invalid },
    { 0x17F8, opcode::OP_Invalid },
    { 0x17F9, opcode::OP_Invalid },
    { 0x17FA, opcode::OP_GetString },
    { 0x17FB, opcode::OP_Invalid },
    { 0x17FC, opcode::OP_Invalid },
    { 0x17FD, opcode::OP_JumpOnFalse },
    { 0x17FE, opcode::OP_GetFloat },
    { 0x17FF, opcode::OP_LessThan },
    { 0x1800, opcode::OP_WaitTillMatch },
    { 0x1801, opcode::OP_Invalid },
    { 0x1802, opcode::OP_GetByte },
    { 0x1803, opcode::OP_Invalid },
    { 0x1804, opcode::OP_GetWorld },
    { 0x1805, opcode::OP_GetInteger },
    { 0x1806, opcode::OP_WaitTill },
    { 0x1807, opcode::OP_Invalid },
    { 0x1808, opcode::OP_Inc },
    { 0x1809, opcode::OP_Invalid },
    { 0x180A, opcode::OP_Invalid },
    { 0x180B, opcode::OP_ScriptFunctionCallPointer },
    { 0x180C, opcode::OP_EvalArrayRef },
    { 0x180D, opcode::OP_ProfileStart },
    { 0x180E, opcode::OP_Invalid },
    { 0x180F, opcode::OP_ClearFieldVariable },
    { 0x1810, opcode::OP_Invalid },
    { 0x1811, opcode::OP_Invalid },
    { 0x1812, opcode::OP_ScriptFunctionCallClass },
    { 0x1813, opcode::OP_ShiftRight },
    { 0x1814, opcode::OP_Invalid },
    { 0x1815, opcode::OP_Return },
    { 0x1816, opcode::OP_Invalid },
    { 0x1817, opcode::OP_ShiftLeft },
    { 0x1818, opcode::OP_GetAnimation },
    { 0x1819, opcode::OP_Invalid },
    { 0x181A, opcode::OP_Invalid },
    { 0x181B, opcode::OP_Invalid },
    { 0x181C, opcode::OP_FirstArrayKey },
    { 0x181D, opcode::OP_Dec },
    { 0x181E, opcode::OP_BoolNot },
    { 0x181F, opcode::OP_GetZero },
    { 0x1820, opcode::OP_WaitTill },
    { 0x1821, opcode::OP_Invalid },
    { 0x1822, opcode::OP_EvalFieldVariableRef },
    { 0x1823, opcode::OP_Inc },
    { 0x1824, opcode::OP_BoolComplement },
    { 0x1825, opcode::OP_Equal },
    { 0x1826, opcode::OP_Invalid },
    { 0x1827, opcode::OP_ScriptThreadCallClass },
    { 0x1828, opcode::OP_EvalLocalVariableRefCached },
    { 0x1829, opcode::OP_Invalid },
    { 0x182A, opcode::OP_ScriptThreadCallPointer },
    { 0x182B, opcode::OP_GetNegByte },
    { 0x182C, opcode::OP_DecTop },
    { 0x182D, opcode::OP_Invalid },
    { 0x182E, opcode::OP_ProfileStart },
    { 0x182F, opcode::OP_Invalid },
    { 0x1830, opcode::OP_ShiftLeft },
    { 0x1831, opcode::OP_Invalid },
    { 0x1832, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x1833, opcode::OP_GetInteger },
    { 0x1834, opcode::OP_GetLevelObject },
    { 0x1835, opcode::OP_LevelEvalFieldVariableRef },
    { 0x1836, opcode::OP_Invalid },
    { 0x1837, opcode::OP_CallBuiltinMethod },
    { 0x1838, opcode::OP_Invalid },
    { 0x1839, opcode::OP_GetUintptr },
    { 0x183A, opcode::OP_Invalid },
    { 0x183B, opcode::OP_GetLevel },
    { 0x183C, opcode::OP_ScriptMethodCallPointer },
    { 0x183D, opcode::OP_Invalid },
    { 0x183E, opcode::OP_JumpOnTrueExpr },
    { 0x183F, opcode::OP_GetByte },
    { 0x1840, opcode::OP_BoolComplement },
    { 0x1841, opcode::OP_ScriptThreadCall },
    { 0x1842, opcode::OP_Invalid },
    { 0x1843, opcode::OP_Invalid },
    { 0x1844, opcode::OP_GetNegUnsignedShort },
    { 0x1845, opcode::OP_JumpOnFalseExpr },
    { 0x1846, opcode::OP_GetWorld },
    { 0x1847, opcode::OP_SuperEqual },
    { 0x1848, opcode::OP_LevelEvalFieldVariableRef },
    { 0x1849, opcode::OP_GetAPIFunction },
    { 0x184A, opcode::OP_EmptyArray },
    { 0x184B, opcode::OP_Invalid },
    { 0x184C, opcode::OP_GetString },
    { 0x184D, opcode::OP_Jump },
    { 0x184E, opcode::OP_VectorConstant },
    { 0x184F, opcode::OP_SelfEvalFieldVariable },
    { 0x1850, opcode::OP_GetClassesObject },
    { 0x1851, opcode::OP_Invalid },
    { 0x1852, opcode::OP_EvalArray },
    { 0x1853, opcode::OP_GetIString },
    { 0x1854, opcode::OP_Multiply },
    { 0x1855, opcode::OP_VectorConstant },
    { 0x1856, opcode::OP_DecTop },
    { 0x1857, opcode::OP_GetTime },
    { 0x1858, opcode::OP_ScriptThreadCallPointer },
    { 0x1859, opcode::OP_Switch },
    { 0x185A, opcode::OP_GetSelf },
    { 0x185B, opcode::OP_VectorScale },
    { 0x185C, opcode::OP_Invalid },
    { 0x185D, opcode::OP_Invalid },
    { 0x185E, opcode::OP_Invalid },
    { 0x185F, opcode::OP_Invalid },
    { 0x1860, opcode::OP_JumpOnFalseExpr },
    { 0x1861, opcode::OP_GetHash },
    { 0x1862, opcode::OP_CastBool },
    { 0x1863, opcode::OP_EvalArray },
    { 0x1864, opcode::OP_Invalid },
    { 0x1865, opcode::OP_Inc },
    { 0x1866, opcode::OP_Invalid },
    { 0x1867, opcode::OP_EvalFieldVariableRef },
    { 0x1868, opcode::OP_GetWorld },
    { 0x1869, opcode::OP_Invalid },
    { 0x186A, opcode::OP_DecTop },
    { 0x186B, opcode::OP_SetVariableField },
    { 0x186C, opcode::OP_GetUnsignedShort },
    { 0x186D, opcode::OP_EvalFieldVariable },
    { 0x186E, opcode::OP_ScriptFunctionCallClass },
    { 0x186F, opcode::OP_Invalid },
    { 0x1870, opcode::OP_EndOn },
    { 0x1871, opcode::OP_Dec },
    { 0x1872, opcode::OP_JumpOnFalseExpr },
    { 0x1873, opcode::OP_WaitTillFrameEnd },
    { 0x1874, opcode::OP_JumpOnFalse },
    { 0x1875, opcode::OP_LessThanOrEqualTo },
    { 0x1876, opcode::OP_NotEqual },
    { 0x1877, opcode::OP_Invalid },
    { 0x1878, opcode::OP_GetWorld },
    { 0x1879, opcode::OP_ScriptMethodThreadCall },
    { 0x187A, opcode::OP_ClearArray },
    { 0x187B, opcode::OP_EmptyArray },
    { 0x187C, opcode::OP_EvalLocalVariableCached },
    { 0x187D, opcode::OP_ShiftRight },
    { 0x187E, opcode::OP_JumpOnFalse },
    { 0x187F, opcode::OP_GetSelfObject },
    { 0x1880, opcode::OP_Notify },
    { 0x1881, opcode::OP_EvalFieldVariableRef },
    { 0x1882, opcode::OP_GetIString },
    { 0x1883, opcode::OP_GetVector },
    { 0x1884, opcode::OP_Invalid },
    { 0x1885, opcode::OP_GetNegByte },
    { 0x1886, opcode::OP_ProfileStart },
    { 0x1887, opcode::OP_NextArrayKey },
    { 0x1888, opcode::OP_Invalid },
    { 0x1889, opcode::OP_Invalid },
    { 0x188A, opcode::OP_LevelEvalFieldVariable },
    { 0x188B, opcode::OP_Plus },
    { 0x188C, opcode::OP_Invalid },
    { 0x188D, opcode::OP_Invalid },
    { 0x188E, opcode::OP_Invalid },
    { 0x188F, opcode::OP_ShiftLeft },
    { 0x1890, opcode::OP_Invalid },
    { 0x1891, opcode::OP_SafeDecTop },
    { 0x1892, opcode::OP_ScriptFunctionCall },
    { 0x1893, opcode::OP_ScriptFunctionCallClass },
    { 0x1894, opcode::OP_Bit_Xor },
    { 0x1895, opcode::OP_SelfEvalFieldVariableRef },
    { 0x1896, opcode::OP_ProfileStop },
    { 0x1897, opcode::OP_SafeCreateLocalVariables },
    { 0x1898, opcode::OP_Invalid },
    { 0x1899, opcode::OP_GetIString },
    { 0x189A, opcode::OP_Divide },
    { 0x189B, opcode::OP_ClearFieldVariable },
    { 0x189C, opcode::OP_Invalid },
    { 0x189D, opcode::OP_GetNegByte },
    { 0x189E, opcode::OP_Invalid },
    { 0x189F, opcode::OP_Invalid },
    { 0x18A0, opcode::OP_BoolNot },
    { 0x18A1, opcode::OP_VectorConstant },
    { 0x18A2, opcode::OP_JumpOnTrueExpr },
    { 0x18A3, opcode::OP_SizeOf },
    { 0x18A4, opcode::OP_SafeCreateLocalVariables },
    { 0x18A5, opcode::OP_EndSwitch },
    { 0x18A6, opcode::OP_Invalid },
    { 0x18A7, opcode::OP_FirstArrayKey },
    { 0x18A8, opcode::OP_GetSelfObject },
    { 0x18A9, opcode::OP_SetVariableField },
    { 0x18AA, opcode::OP_ScriptFunctionCall },
    { 0x18AB, opcode::OP_Invalid },
    { 0x18AC, opcode::OP_EvalArrayRef },
    { 0x18AD, opcode::OP_Invalid },
    { 0x18AE, opcode::OP_ScriptThreadCallClass },
    { 0x18AF, opcode::OP_Invalid },
    { 0x18B0, opcode::OP_GetByte },
    { 0x18B1, opcode::OP_Invalid },
    { 0x18B2, opcode::OP_Jump },
    { 0x18B3, opcode::OP_Jump },
    { 0x18B4, opcode::OP_Invalid },
    { 0x18B5, opcode::OP_Invalid },
    { 0x18B6, opcode::OP_Invalid },
    { 0x18B7, opcode::OP_IsDefined },
    { 0x18B8, opcode::OP_ScriptThreadCall },
    { 0x18B9, opcode::OP_Wait },
    { 0x18BA, opcode::OP_GetFloat },
    { 0x18BB, opcode::OP_Invalid },
    { 0x18BC, opcode::OP_Invalid },
    { 0x18BD, opcode::OP_BoolComplement },
    { 0x18BE, opcode::OP_ScriptMethodThreadCall },
    { 0x18BF, opcode::OP_GetGame },
    { 0x18C0, opcode::OP_GetUnsignedShort },
    { 0x18C1, opcode::OP_ClearFieldVariable },
    { 0x18C2, opcode::OP_LevelEvalFieldVariable },
    { 0x18C3, opcode::OP_Invalid },
    { 0x18C4, opcode::OP_EvalLocalVariableCached },
    { 0x18C5, opcode::OP_Invalid },
    { 0x18C6, opcode::OP_WaitTillMatch },
    { 0x18C7, opcode::OP_Invalid },
    { 0x18C8, opcode::OP_DecTop },
    { 0x18C9, opcode::OP_GetVector },
    { 0x18CA, opcode::OP_Invalid },
    { 0x18CB, opcode::OP_Equal },
    { 0x18CC, opcode::OP_GetClasses },
    { 0x18CD, opcode::OP_Bit_Or },
    { 0x18CE, opcode::OP_GetByte },
    { 0x18CF, opcode::OP_New },
    { 0x18D0, opcode::OP_BoolComplement },
    { 0x18D1, opcode::OP_ClearArray },
    { 0x18D2, opcode::OP_Plus },
    { 0x18D3, opcode::OP_Plus },
    { 0x18D4, opcode::OP_Invalid },
    { 0x18D5, opcode::OP_GetInteger },
    { 0x18D6, opcode::OP_EvalFieldVariable },
    { 0x18D7, opcode::OP_Invalid },
    { 0x18D8, opcode::OP_JumpOnTrueExpr },
    { 0x18D9, opcode::OP_ScriptThreadCallClass },
    { 0x18DA, opcode::OP_ScriptMethodCall },
    { 0x18DB, opcode::OP_Invalid },
    { 0x18DC, opcode::OP_Invalid },
    { 0x18DD, opcode::OP_Bit_Or },
    { 0x18DE, opcode::OP_Multiply },
    { 0x18DF, opcode::OP_LevelEvalFieldVariable },
    { 0x18E0, opcode::OP_Divide },
    { 0x18E1, opcode::OP_WaitTill },
    { 0x18E2, opcode::OP_Invalid },
    { 0x18E3, opcode::OP_Invalid },
    { 0x18E4, opcode::OP_RealWait },
    { 0x18E5, opcode::OP_Invalid },
    { 0x18E6, opcode::OP_Invalid },
    { 0x18E7, opcode::OP_ScriptFunctionCall },
    { 0x18E8, opcode::OP_Invalid },
    { 0x18E9, opcode::OP_Equal },
    { 0x18EA, opcode::OP_WaitTill },
    { 0x18EB, opcode::OP_Invalid },
    { 0x18EC, opcode::OP_ShiftLeft },
    { 0x18ED, opcode::OP_Invalid },
    { 0x18EE, opcode::OP_GetByte },
    { 0x18EF, opcode::OP_Invalid },
    { 0x18F0, opcode::OP_ProfileStart },
    { 0x18F1, opcode::OP_Invalid },
    { 0x18F2, opcode::OP_Invalid },
    { 0x18F3, opcode::OP_BoolNot },
    { 0x18F4, opcode::OP_ScriptFunctionCallClass },
    { 0x18F5, opcode::OP_ScriptMethodCall },
    { 0x18F6, opcode::OP_SelfEvalFieldVariable },
    { 0x18F7, opcode::OP_EndOn },
    { 0x18F8, opcode::OP_Invalid },
    { 0x18F9, opcode::OP_New },
    { 0x18FA, opcode::OP_JumpOnTrueExpr },
    { 0x18FB, opcode::OP_BoolComplement },
    { 0x18FC, opcode::OP_Invalid },
    { 0x18FD, opcode::OP_GetWorldObject },
    { 0x18FE, opcode::OP_Invalid },
    { 0x18FF, opcode::OP_GetString },
    { 0x1900, opcode::OP_VectorScale },
    { 0x1901, opcode::OP_JumpOnTrueExpr },
    { 0x1902, opcode::OP_BoolComplement },
    { 0x1903, opcode::OP_GreaterThanOrEqualTo },
    { 0x1904, opcode::OP_EvalFieldVariableRef },
    { 0x1905, opcode::OP_ScriptFunctionCallPointer },
    { 0x1906, opcode::OP_ScriptMethodThreadCall },
    { 0x1907, opcode::OP_Invalid },
    { 0x1908, opcode::OP_Invalid },
    { 0x1909, opcode::OP_Invalid },
    { 0x190A, opcode::OP_ScriptFunctionCall },
    { 0x190B, opcode::OP_GetAnim },
    { 0x190C, opcode::OP_Multiply },
    { 0x190D, opcode::OP_Invalid },
    { 0x190E, opcode::OP_Plus },
    { 0x190F, opcode::OP_GreaterThanOrEqualTo },
    { 0x1910, opcode::OP_Invalid },
    { 0x1911, opcode::OP_SelfEvalFieldVariable },
    { 0x1912, opcode::OP_LessThan },
    { 0x1913, opcode::OP_FirstArrayKey },
    { 0x1914, opcode::OP_Invalid },
    { 0x1915, opcode::OP_EvalLocalVariableRefCached },
    { 0x1916, opcode::OP_SetVariableField },
    { 0x1917, opcode::OP_Return },
    { 0x1918, opcode::OP_Invalid },
    { 0x1919, opcode::OP_Plus },
    { 0x191A, opcode::OP_ClearArray },
    { 0x191B, opcode::OP_Invalid },
    { 0x191C, opcode::OP_Invalid },
    { 0x191D, opcode::OP_Invalid },
    { 0x191E, opcode::OP_Notify },
    { 0x191F, opcode::OP_Invalid },
    { 0x1920, opcode::OP_SafeSetVariableFieldCached },
    { 0x1921, opcode::OP_GetSelf },
    { 0x1922, opcode::OP_Invalid },
    { 0x1923, opcode::OP_GetAnimation },
    { 0x1924, opcode::OP_GetAPIFunction },
    { 0x1925, opcode::OP_Invalid },
    { 0x1926, opcode::OP_Invalid },
    { 0x1927, opcode::OP_Inc },
    { 0x1928, opcode::OP_Invalid },
    { 0x1929, opcode::OP_GetFloat },
    { 0x192A, opcode::OP_SelfEvalFieldVariable },
    { 0x192B, opcode::OP_Divide },
    { 0x192C, opcode::OP_Divide },
    { 0x192D, opcode::OP_Invalid },
    { 0x192E, opcode::OP_Invalid },
    { 0x192F, opcode::OP_BoolComplement },
    { 0x1930, opcode::OP_Invalid },
    { 0x1931, opcode::OP_RealWait },
    { 0x1932, opcode::OP_JumpOnFalse },
    { 0x1933, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x1934, opcode::OP_EvalArrayRef },
    { 0x1935, opcode::OP_Invalid },
    { 0x1936, opcode::OP_GetNegByte },
    { 0x1937, opcode::OP_GetAnimation },
    { 0x1938, opcode::OP_Invalid },
    { 0x1939, opcode::OP_Notify },
    { 0x193A, opcode::OP_GreaterThan },
    { 0x193B, opcode::OP_GetLevel },
    { 0x193C, opcode::OP_Invalid },
    { 0x193D, opcode::OP_GetAnim },
    { 0x193E, opcode::OP_Invalid },
    { 0x193F, opcode::OP_NotEqual },
    { 0x1940, opcode::OP_Invalid },
    { 0x1941, opcode::OP_SizeOf },
    { 0x1942, opcode::OP_Invalid },
    { 0x1943, opcode::OP_Invalid },
    { 0x1944, opcode::OP_GetAnim },
    { 0x1945, opcode::OP_VectorScale },
    { 0x1946, opcode::OP_Invalid },
    { 0x1947, opcode::OP_GetFloat },
    { 0x1948, opcode::OP_Invalid },
    { 0x1949, opcode::OP_EvalLocalVariableCached },
    { 0x194A, opcode::OP_Invalid },
    { 0x194B, opcode::OP_CallBuiltinMethod },
    { 0x194C, opcode::OP_Invalid },
    { 0x194D, opcode::OP_Invalid },
    { 0x194E, opcode::OP_GetAnimObject },
    { 0x194F, opcode::OP_Invalid },
    { 0x1950, opcode::OP_GetIString },
    { 0x1951, opcode::OP_GetZero },
    { 0x1952, opcode::OP_SafeDecTop },
    { 0x1953, opcode::OP_ProfileStop },
    { 0x1954, opcode::OP_SuperEqual },
    { 0x1955, opcode::OP_JumpOnTrue },
    { 0x1956, opcode::OP_GetAnimation },
    { 0x1957, opcode::OP_Invalid },
    { 0x1958, opcode::OP_EvalArray },
    { 0x1959, opcode::OP_GetUintptr },
    { 0x195A, opcode::OP_GetWorldObject },
    { 0x195B, opcode::OP_Wait },
    { 0x195C, opcode::OP_Invalid },
    { 0x195D, opcode::OP_FirstArrayKey },
    { 0x195E, opcode::OP_Invalid },
    { 0x195F, opcode::OP_SafeCreateLocalVariables },
    { 0x1960, opcode::OP_EvalFieldVariableRef },
    { 0x1961, opcode::OP_GetFloat },
    { 0x1962, opcode::OP_SetVariableField },
    { 0x1963, opcode::OP_GetUnsignedShort },
    { 0x1964, opcode::OP_Invalid },
    { 0x1965, opcode::OP_GetClassesObject },
    { 0x1966, opcode::OP_NextArrayKey },
    { 0x1967, opcode::OP_ClearFieldVariable },
    { 0x1968, opcode::OP_GetHash },
    { 0x1969, opcode::OP_GetSelfObject },
    { 0x196A, opcode::OP_Invalid },
    { 0x196B, opcode::OP_BoolNot },
    { 0x196C, opcode::OP_GetUintptr },
    { 0x196D, opcode::OP_Invalid },
    { 0x196E, opcode::OP_Invalid },
    { 0x196F, opcode::OP_Bit_And },
    { 0x1970, opcode::OP_Bit_Or },
    { 0x1971, opcode::OP_Invalid },
    { 0x1972, opcode::OP_Invalid },
    { 0x1973, opcode::OP_Invalid },
    { 0x1974, opcode::OP_EvalArrayRef },
    { 0x1975, opcode::OP_Invalid },
    { 0x1976, opcode::OP_EvalLocalVariableCached },
    { 0x1977, opcode::OP_VectorConstant },
    { 0x1978, opcode::OP_JumpOnTrueExpr },
    { 0x1979, opcode::OP_ScriptThreadCallClass },
    { 0x197A, opcode::OP_Invalid },
    { 0x197B, opcode::OP_Invalid },
    { 0x197C, opcode::OP_SuperEqual },
    { 0x197D, opcode::OP_LessThan },
    { 0x197E, opcode::OP_ScriptFunctionCallPointer },
    { 0x197F, opcode::OP_ScriptMethodCall },
    { 0x1980, opcode::OP_SetVariableField },
    { 0x1981, opcode::OP_Invalid },
    { 0x1982, opcode::OP_DecTop },
    { 0x1983, opcode::OP_Invalid },
    { 0x1984, opcode::OP_Invalid },
    { 0x1985, opcode::OP_Invalid },
    { 0x1986, opcode::OP_JumpOnTrueExpr },
    { 0x1987, opcode::OP_Invalid },
    { 0x1988, opcode::OP_Invalid },
    { 0x1989, opcode::OP_ClearArray },
    { 0x198A, opcode::OP_GetUnsignedShort },
    { 0x198B, opcode::OP_ScriptThreadCallPointer },
    { 0x198C, opcode::OP_ScriptMethodThreadCall },
    { 0x198D, opcode::OP_WaitTillFrameEnd },
    { 0x198E, opcode::OP_Invalid },
    { 0x198F, opcode::OP_Invalid },
    { 0x1990, opcode::OP_Invalid },
    { 0x1991, opcode::OP_GetInteger },
    { 0x1992, opcode::OP_GetUintptr },
    { 0x1993, opcode::OP_New },
    { 0x1994, opcode::OP_EndSwitch },
    { 0x1995, opcode::OP_SafeCreateLocalVariables },
    { 0x1996, opcode::OP_Bit_Or },
    { 0x1997, opcode::OP_Invalid },
    { 0x1998, opcode::OP_ScriptMethodThreadCall },
    { 0x1999, opcode::OP_LevelEvalFieldVariableRef },
    { 0x199A, opcode::OP_LessThanOrEqualTo },
    { 0x199B, opcode::OP_WaitTillMatch },
    { 0x199C, opcode::OP_SuperNotEqual },
    { 0x199D, opcode::OP_VectorScale },
    { 0x199E, opcode::OP_GreaterThanOrEqualTo },
    { 0x199F, opcode::OP_GetTime },
    { 0x19A0, opcode::OP_Invalid },
    { 0x19A1, opcode::OP_Invalid },
    { 0x19A2, opcode::OP_Invalid },
    { 0x19A3, opcode::OP_Invalid },
    { 0x19A4, opcode::OP_GetUnsignedShort },
    { 0x19A5, opcode::OP_WaitTillMatch },
    { 0x19A6, opcode::OP_New },
    { 0x19A7, opcode::OP_Invalid },
    { 0x19A8, opcode::OP_Invalid },
    { 0x19A9, opcode::OP_Invalid },
    { 0x19AA, opcode::OP_Invalid },
    { 0x19AB, opcode::OP_Dec },
    { 0x19AC, opcode::OP_Multiply },
    { 0x19AD, opcode::OP_GetNegByte },
    { 0x19AE, opcode::OP_CallBuiltinMethod },
    { 0x19AF, opcode::OP_GetZero },
    { 0x19B0, opcode::OP_Inc },
    { 0x19B1, opcode::OP_GetUnsignedShort },
    { 0x19B2, opcode::OP_Invalid },
    { 0x19B3, opcode::OP_Plus },
    { 0x19B4, opcode::OP_Invalid },
    { 0x19B5, opcode::OP_ScriptThreadCall },
    { 0x19B6, opcode::OP_Invalid },
    { 0x19B7, opcode::OP_ScriptFunctionCallClass },
    { 0x19B8, opcode::OP_EvalFieldVariable },
    { 0x19B9, opcode::OP_Invalid },
    { 0x19BA, opcode::OP_GetZero },
    { 0x19BB, opcode::OP_ScriptFunctionCallPointer },
    { 0x19BC, opcode::OP_GreaterThanOrEqualTo },
    { 0x19BD, opcode::OP_Equal },
    { 0x19BE, opcode::OP_Invalid },
    { 0x19BF, opcode::OP_ScriptMethodThreadCall },
    { 0x19C0, opcode::OP_DecTop },
    { 0x19C1, opcode::OP_Vector },
    { 0x19C2, opcode::OP_RealWait },
    { 0x19C3, opcode::OP_JumpOnTrueExpr },
    { 0x19C4, opcode::OP_GetNegByte },
    { 0x19C5, opcode::OP_GetLevel },
    { 0x19C6, opcode::OP_SizeOf },
    { 0x19C7, opcode::OP_Invalid },
    { 0x19C8, opcode::OP_EvalArray },
    { 0x19C9, opcode::OP_GetClassesObject },
    { 0x19CA, opcode::OP_Modulus },
    { 0x19CB, opcode::OP_Invalid },
    { 0x19CC, opcode::OP_Invalid },
    { 0x19CD, opcode::OP_Invalid },
    { 0x19CE, opcode::OP_ScriptMethodCallPointer },
    { 0x19CF, opcode::OP_Invalid },
    { 0x19D0, opcode::OP_Bit_Or },
    { 0x19D1, opcode::OP_Invalid },
    { 0x19D2, opcode::OP_Invalid },
    { 0x19D3, opcode::OP_GetWorldObject },
    { 0x19D4, opcode::OP_JumpOnTrue },
    { 0x19D5, opcode::OP_ScriptThreadCall },
    { 0x19D6, opcode::OP_GetNegByte },
    { 0x19D7, opcode::OP_LevelEvalFieldVariableRef },
    { 0x19D8, opcode::OP_Invalid },
    { 0x19D9, opcode::OP_GetNegByte },
    { 0x19DA, opcode::OP_GetWorld },
    { 0x19DB, opcode::OP_DevblockBegin },
    { 0x19DC, opcode::OP_SetVariableField },
    { 0x19DD, opcode::OP_LevelEvalFieldVariableRef },
    { 0x19DE, opcode::OP_Invalid },
    { 0x19DF, opcode::OP_Invalid },
    { 0x19E0, opcode::OP_ScriptMethodCallPointer },
    { 0x19E1, opcode::OP_BoolComplement },
    { 0x19E2, opcode::OP_ScriptFunctionCallClass },
    { 0x19E3, opcode::OP_Invalid },
    { 0x19E4, opcode::OP_RealWait },
    { 0x19E5, opcode::OP_ShiftRight },
    { 0x19E6, opcode::OP_EvalFieldVariable },
    { 0x19E7, opcode::OP_New },
    { 0x19E8, opcode::OP_Invalid },
    { 0x19E9, opcode::OP_GetVector },
    { 0x19EA, opcode::OP_Invalid },
    { 0x19EB, opcode::OP_New },
    { 0x19EC, opcode::OP_IsDefined },
    { 0x19ED, opcode::OP_Invalid },
    { 0x19EE, opcode::OP_LessThan },
    { 0x19EF, opcode::OP_Invalid },
    { 0x19F0, opcode::OP_Invalid },
    { 0x19F1, opcode::OP_Invalid },
    { 0x19F2, opcode::OP_GetString },
    { 0x19F3, opcode::OP_NotEqual },
    { 0x19F4, opcode::OP_GetSelfObject },
    { 0x19F5, opcode::OP_EvalFieldVariableRef },
    { 0x19F6, opcode::OP_GetVector },
    { 0x19F7, opcode::OP_GetUndefined },
    { 0x19F8, opcode::OP_GetClassesObject },
    { 0x19F9, opcode::OP_WaitTillFrameEnd },
    { 0x19FA, opcode::OP_ProfileStop },
    { 0x19FB, opcode::OP_ScriptFunctionCall },
    { 0x19FC, opcode::OP_NextArrayKey },
    { 0x19FD, opcode::OP_Invalid },
    { 0x19FE, opcode::OP_GetUndefined },
    { 0x19FF, opcode::OP_GetSelfObject },
    { 0x1A00, opcode::OP_SelfEvalFieldVariableRef },
    { 0x1A01, opcode::OP_Invalid },
    { 0x1A02, opcode::OP_Invalid },
    { 0x1A03, opcode::OP_Invalid },
    { 0x1A04, opcode::OP_Bit_And },
    { 0x1A05, opcode::OP_Switch },
    { 0x1A06, opcode::OP_EvalArray },
    { 0x1A07, opcode::OP_GetWorldObject },
    { 0x1A08, opcode::OP_GetAnimObject },
    { 0x1A09, opcode::OP_IsDefined },
    { 0x1A0A, opcode::OP_Invalid },
    { 0x1A0B, opcode::OP_Invalid },
    { 0x1A0C, opcode::OP_JumpOnTrue },
    { 0x1A0D, opcode::OP_Invalid },
    { 0x1A0E, opcode::OP_Invalid },
    { 0x1A0F, opcode::OP_GetClassesObject },
    { 0x1A10, opcode::OP_ScriptMethodCallPointer },
    { 0x1A11, opcode::OP_Divide },
    { 0x1A12, opcode::OP_LevelEvalFieldVariable },
    { 0x1A13, opcode::OP_Wait },
    { 0x1A14, opcode::OP_Invalid },
    { 0x1A15, opcode::OP_Invalid },
    { 0x1A16, opcode::OP_Inc },
    { 0x1A17, opcode::OP_DevblockBegin },
    { 0x1A18, opcode::OP_GetFunction },
    { 0x1A19, opcode::OP_GetInteger },
    { 0x1A1A, opcode::OP_Invalid },
    { 0x1A1B, opcode::OP_EndOn },
    { 0x1A1C, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x1A1D, opcode::OP_Invalid },
    { 0x1A1E, opcode::OP_Invalid },
    { 0x1A1F, opcode::OP_GetInteger },
    { 0x1A20, opcode::OP_GetLevel },
    { 0x1A21, opcode::OP_IsDefined },
    { 0x1A22, opcode::OP_GetUndefined },
    { 0x1A23, opcode::OP_GetVector },
    { 0x1A24, opcode::OP_Invalid },
    { 0x1A25, opcode::OP_Invalid },
    { 0x1A26, opcode::OP_Invalid },
    { 0x1A27, opcode::OP_Invalid },
    { 0x1A28, opcode::OP_SuperEqual },
    { 0x1A29, opcode::OP_EndOn },
    { 0x1A2A, opcode::OP_GreaterThan },
    { 0x1A2B, opcode::OP_LessThanOrEqualTo },
    { 0x1A2C, opcode::OP_Invalid },
    { 0x1A2D, opcode::OP_Invalid },
    { 0x1A2E, opcode::OP_New },
    { 0x1A2F, opcode::OP_RealWait },
    { 0x1A30, opcode::OP_GetByte },
    { 0x1A31, opcode::OP_GreaterThanOrEqualTo },
    { 0x1A32, opcode::OP_VectorConstant },
    { 0x1A33, opcode::OP_ScriptMethodCall },
    { 0x1A34, opcode::OP_GetFunction },
    { 0x1A35, opcode::OP_GetLevel },
    { 0x1A36, opcode::OP_Invalid },
    { 0x1A37, opcode::OP_SafeSetVariableFieldCached },
    { 0x1A38, opcode::OP_Invalid },
    { 0x1A39, opcode::OP_GetFunction },
    { 0x1A3A, opcode::OP_Invalid },
    { 0x1A3B, opcode::OP_VectorScale },
    { 0x1A3C, opcode::OP_Invalid },
    { 0x1A3D, opcode::OP_SelfEvalFieldVariableRef },
    { 0x1A3E, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x1A3F, opcode::OP_SafeDecTop },
    { 0x1A40, opcode::OP_GetClassesObject },
    { 0x1A41, opcode::OP_Invalid },
    { 0x1A42, opcode::OP_Invalid },
    { 0x1A43, opcode::OP_VectorConstant },
    { 0x1A44, opcode::OP_NextArrayKey },
    { 0x1A45, opcode::OP_Inc },
    { 0x1A46, opcode::OP_Divide },
    { 0x1A47, opcode::OP_Invalid },
    { 0x1A48, opcode::OP_Divide },
    { 0x1A49, opcode::OP_CallBuiltinMethod },
    { 0x1A4A, opcode::OP_ScriptMethodCall },
    { 0x1A4B, opcode::OP_JumpOnFalseExpr },
    { 0x1A4C, opcode::OP_BoolComplement },
    { 0x1A4D, opcode::OP_DevblockBegin },
    { 0x1A4E, opcode::OP_Invalid },
    { 0x1A4F, opcode::OP_SafeDecTop },
    { 0x1A50, opcode::OP_EvalLocalVariableRefCached },
    { 0x1A51, opcode::OP_Switch },
    { 0x1A52, opcode::OP_GetFunction },
    { 0x1A53, opcode::OP_SuperEqual },
    { 0x1A54, opcode::OP_JumpOnFalseExpr },
    { 0x1A55, opcode::OP_DecTop },
    { 0x1A56, opcode::OP_EvalFieldVariableRef },
    { 0x1A57, opcode::OP_Plus },
    { 0x1A58, opcode::OP_JumpOnFalseExpr },
    { 0x1A59, opcode::OP_Multiply },
    { 0x1A5A, opcode::OP_Invalid },
    { 0x1A5B, opcode::OP_LevelEvalFieldVariableRef },
    { 0x1A5C, opcode::OP_GetGameRef },
    { 0x1A5D, opcode::OP_Invalid },
    { 0x1A5E, opcode::OP_JumpOnFalseExpr },
    { 0x1A5F, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x1A60, opcode::OP_Plus },
    { 0x1A61, opcode::OP_WaitTillMatch },
    { 0x1A62, opcode::OP_Invalid },
    { 0x1A63, opcode::OP_GetWorldObject },
    { 0x1A64, opcode::OP_SafeDecTop },
    { 0x1A65, opcode::OP_SafeSetVariableFieldCached },
    { 0x1A66, opcode::OP_GetLevelObject },
    { 0x1A67, opcode::OP_GetFloat },
    { 0x1A68, opcode::OP_GetUintptr },
    { 0x1A69, opcode::OP_Invalid },
    { 0x1A6A, opcode::OP_NotEqual },
    { 0x1A6B, opcode::OP_Invalid },
    { 0x1A6C, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x1A6D, opcode::OP_Invalid },
    { 0x1A6E, opcode::OP_Bit_Or },
    { 0x1A6F, opcode::OP_Invalid },
    { 0x1A70, opcode::OP_Invalid },
    { 0x1A71, opcode::OP_ShiftRight },
    { 0x1A72, opcode::OP_DecTop },
    { 0x1A73, opcode::OP_CastBool },
    { 0x1A74, opcode::OP_ScriptMethodCall },
    { 0x1A75, opcode::OP_Invalid },
    { 0x1A76, opcode::OP_GetClassesObject },
    { 0x1A77, opcode::OP_JumpOnFalseExpr },
    { 0x1A78, opcode::OP_Bit_Or },
    { 0x1A79, opcode::OP_EndOn },
    { 0x1A7A, opcode::OP_IsDefined },
    { 0x1A7B, opcode::OP_GetGame },
    { 0x1A7C, opcode::OP_Invalid },
    { 0x1A7D, opcode::OP_ScriptThreadCallClass },
    { 0x1A7E, opcode::OP_SafeSetVariableFieldCached },
    { 0x1A7F, opcode::OP_ShiftRight },
    { 0x1A80, opcode::OP_LessThanOrEqualTo },
    { 0x1A81, opcode::OP_ScriptThreadCall },
    { 0x1A82, opcode::OP_ShiftRight },
    { 0x1A83, opcode::OP_ScriptFunctionCallPointer },
    { 0x1A84, opcode::OP_EvalLocalVariableCached },
    { 0x1A85, opcode::OP_EvalArray },
    { 0x1A86, opcode::OP_EvalLocalVariableRefCached },
    { 0x1A87, opcode::OP_Invalid },
    { 0x1A88, opcode::OP_Invalid },
    { 0x1A89, opcode::OP_NextArrayKey },
    { 0x1A8A, opcode::OP_Invalid },
    { 0x1A8B, opcode::OP_Invalid },
    { 0x1A8C, opcode::OP_GetZero },
    { 0x1A8D, opcode::OP_ScriptMethodCall },
    { 0x1A8E, opcode::OP_Invalid },
    { 0x1A8F, opcode::OP_Bit_And },
    { 0x1A90, opcode::OP_LessThan },
    { 0x1A91, opcode::OP_ProfileStart },
    { 0x1A92, opcode::OP_Invalid },
    { 0x1A93, opcode::OP_Bit_Xor },
    { 0x1A94, opcode::OP_Invalid },
    { 0x1A95, opcode::OP_Invalid },
    { 0x1A96, opcode::OP_GetIString },
    { 0x1A97, opcode::OP_Invalid },
    { 0x1A98, opcode::OP_WaitTill },
    { 0x1A99, opcode::OP_ClearFieldVariable },
    { 0x1A9A, opcode::OP_Invalid },
    { 0x1A9B, opcode::OP_GetByte },
    { 0x1A9C, opcode::OP_SelfEvalFieldVariable },
    { 0x1A9D, opcode::OP_EndSwitch },
    { 0x1A9E, opcode::OP_Invalid },
    { 0x1A9F, opcode::OP_Equal },
    { 0x1AA0, opcode::OP_GetWorld },
    { 0x1AA1, opcode::OP_SuperNotEqual },
    { 0x1AA2, opcode::OP_SuperNotEqual },
    { 0x1AA3, opcode::OP_JumpOnTrue },
    { 0x1AA4, opcode::OP_Inc },
    { 0x1AA5, opcode::OP_ProfileStop },
    { 0x1AA6, opcode::OP_Invalid },
    { 0x1AA7, opcode::OP_JumpOnTrue },
    { 0x1AA8, opcode::OP_SafeDecTop },
    { 0x1AA9, opcode::OP_WaitTillMatch },
    { 0x1AAA, opcode::OP_Invalid },
    { 0x1AAB, opcode::OP_GetWorld },
    { 0x1AAC, opcode::OP_Invalid },
    { 0x1AAD, opcode::OP_GetInteger },
    { 0x1AAE, opcode::OP_Invalid },
    { 0x1AAF, opcode::OP_Multiply },
    { 0x1AB0, opcode::OP_Minus },
    { 0x1AB1, opcode::OP_Invalid },
    { 0x1AB2, opcode::OP_LessThanOrEqualTo },
    { 0x1AB3, opcode::OP_Invalid },
    { 0x1AB4, opcode::OP_Invalid },
    { 0x1AB5, opcode::OP_VectorConstant },
    { 0x1AB6, opcode::OP_ProfileStop },
    { 0x1AB7, opcode::OP_SelfEvalFieldVariableRef },
    { 0x1AB8, opcode::OP_Invalid },
    { 0x1AB9, opcode::OP_ScriptMethodCallPointer },
    { 0x1ABA, opcode::OP_ScriptThreadCallPointer },
    { 0x1ABB, opcode::OP_ClearFieldVariable },
    { 0x1ABC, opcode::OP_Divide },
    { 0x1ABD, opcode::OP_Invalid },
    { 0x1ABE, opcode::OP_LessThanOrEqualTo },
    { 0x1ABF, opcode::OP_GetGameRef },
    { 0x1AC0, opcode::OP_Invalid },
    { 0x1AC1, opcode::OP_EvalFieldVariableRef },
    { 0x1AC2, opcode::OP_New },
    { 0x1AC3, opcode::OP_Invalid },
    { 0x1AC4, opcode::OP_ClearFieldVariable },
    { 0x1AC5, opcode::OP_SelfEvalFieldVariableRef },
    { 0x1AC6, opcode::OP_EvalArray },
    { 0x1AC7, opcode::OP_Invalid },
    { 0x1AC8, opcode::OP_JumpOnTrue },
    { 0x1AC9, opcode::OP_Invalid },
    { 0x1ACA, opcode::OP_DevblockBegin },
    { 0x1ACB, opcode::OP_VectorConstant },
    { 0x1ACC, opcode::OP_ScriptFunctionCallPointer },
    { 0x1ACD, opcode::OP_SuperNotEqual },
    { 0x1ACE, opcode::OP_LevelEvalFieldVariableRef },
    { 0x1ACF, opcode::OP_Dec },
    { 0x1AD0, opcode::OP_Invalid },
    { 0x1AD1, opcode::OP_Invalid },
    { 0x1AD2, opcode::OP_Divide },
    { 0x1AD3, opcode::OP_GetTime },
    { 0x1AD4, opcode::OP_ProfileStop },
    { 0x1AD5, opcode::OP_Invalid },
    { 0x1AD6, opcode::OP_LessThanOrEqualTo },
    { 0x1AD7, opcode::OP_Notify },
    { 0x1AD8, opcode::OP_GetGameRef },
    { 0x1AD9, opcode::OP_Invalid },
    { 0x1ADA, opcode::OP_Invalid },
    { 0x1ADB, opcode::OP_Invalid },
    { 0x1ADC, opcode::OP_Invalid },
    { 0x1ADD, opcode::OP_JumpOnFalse },
    { 0x1ADE, opcode::OP_WaitTill },
    { 0x1ADF, opcode::OP_VectorScale },
    { 0x1AE0, opcode::OP_ScriptThreadCallPointer },
    { 0x1AE1, opcode::OP_GetLevel },
    { 0x1AE2, opcode::OP_Invalid },
    { 0x1AE3, opcode::OP_EvalArrayRef },
    { 0x1AE4, opcode::OP_GreaterThan },
    { 0x1AE5, opcode::OP_LevelEvalFieldVariableRef },
    { 0x1AE6, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x1AE7, opcode::OP_Invalid },
    { 0x1AE8, opcode::OP_RealWait },
    { 0x1AE9, opcode::OP_GetAPIFunction },
    { 0x1AEA, opcode::OP_ScriptMethodThreadCall },
    { 0x1AEB, opcode::OP_GetIString },
    { 0x1AEC, opcode::OP_Invalid },
    { 0x1AED, opcode::OP_GetVector },
    { 0x1AEE, opcode::OP_ScriptMethodCall },
    { 0x1AEF, opcode::OP_GetHash },
    { 0x1AF0, opcode::OP_GetVector },
    { 0x1AF1, opcode::OP_GetLevelObject },
    { 0x1AF2, opcode::OP_LessThan },
    { 0x1AF3, opcode::OP_Invalid },
    { 0x1AF4, opcode::OP_Invalid },
    { 0x1AF5, opcode::OP_Invalid },
    { 0x1AF6, opcode::OP_NextArrayKey },
    { 0x1AF7, opcode::OP_JumpOnTrue },
    { 0x1AF8, opcode::OP_JumpOnFalseExpr },
    { 0x1AF9, opcode::OP_EndSwitch },
    { 0x1AFA, opcode::OP_EndSwitch },
    { 0x1AFB, opcode::OP_EndSwitch },
    { 0x1AFC, opcode::OP_GetGameRef },
    { 0x1AFD, opcode::OP_GetAnimation },
    { 0x1AFE, opcode::OP_GetZero },
    { 0x1AFF, opcode::OP_Bit_Or },
    { 0x1B00, opcode::OP_JumpOnFalseExpr },
    { 0x1B01, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x1B02, opcode::OP_ShiftRight },
    { 0x1B03, opcode::OP_GetVector },
    { 0x1B04, opcode::OP_GetAnim },
    { 0x1B05, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x1B06, opcode::OP_ProfileStop },
    { 0x1B07, opcode::OP_GetLevel },
    { 0x1B08, opcode::OP_JumpOnTrue },
    { 0x1B09, opcode::OP_GetClasses },
    { 0x1B0A, opcode::OP_Jump },
    { 0x1B0B, opcode::OP_GetVector },
    { 0x1B0C, opcode::OP_Invalid },
    { 0x1B0D, opcode::OP_GetUnsignedShort },
    { 0x1B0E, opcode::OP_GetGameRef },
    { 0x1B0F, opcode::OP_GetFunction },
    { 0x1B10, opcode::OP_ScriptFunctionCall },
    { 0x1B11, opcode::OP_GetClasses },
    { 0x1B12, opcode::OP_Invalid },
    { 0x1B13, opcode::OP_Invalid },
    { 0x1B14, opcode::OP_GetString },
    { 0x1B15, opcode::OP_Bit_And },
    { 0x1B16, opcode::OP_GetIString },
    { 0x1B17, opcode::OP_Invalid },
    { 0x1B18, opcode::OP_WaitTillMatch },
    { 0x1B19, opcode::OP_ShiftRight },
    { 0x1B1A, opcode::OP_Notify },
    { 0x1B1B, opcode::OP_Invalid },
    { 0x1B1C, opcode::OP_Invalid },
    { 0x1B1D, opcode::OP_Invalid },
    { 0x1B1E, opcode::OP_Invalid },
    { 0x1B1F, opcode::OP_Invalid },
    { 0x1B20, opcode::OP_GetAPIFunction },
    { 0x1B21, opcode::OP_GetInteger },
    { 0x1B22, opcode::OP_Invalid },
    { 0x1B23, opcode::OP_Invalid },
    { 0x1B24, opcode::OP_Invalid },
    { 0x1B25, opcode::OP_Inc },
    { 0x1B26, opcode::OP_GetGame },
    { 0x1B27, opcode::OP_CallBuiltinMethod },
    { 0x1B28, opcode::OP_Invalid },
    { 0x1B29, opcode::OP_EmptyArray },
    { 0x1B2A, opcode::OP_FirstArrayKey },
    { 0x1B2B, opcode::OP_ProfileStart },
    { 0x1B2C, opcode::OP_GetAPIFunction },
    { 0x1B2D, opcode::OP_SafeDecTop },
    { 0x1B2E, opcode::OP_Invalid },
    { 0x1B2F, opcode::OP_ScriptMethodCallPointer },
    { 0x1B30, opcode::OP_Invalid },
    { 0x1B31, opcode::OP_GetAnim },
    { 0x1B32, opcode::OP_Invalid },
    { 0x1B33, opcode::OP_Invalid },
    { 0x1B34, opcode::OP_New },
    { 0x1B35, opcode::OP_GetInteger },
    { 0x1B36, opcode::OP_BoolComplement },
    { 0x1B37, opcode::OP_GetSelf },
    { 0x1B38, opcode::OP_GetGameRef },
    { 0x1B39, opcode::OP_SelfEvalFieldVariable },
    { 0x1B3A, opcode::OP_Invalid },
    { 0x1B3B, opcode::OP_Invalid },
    { 0x1B3C, opcode::OP_RealWait },
    { 0x1B3D, opcode::OP_Invalid },
    { 0x1B3E, opcode::OP_JumpOnFalseExpr },
    { 0x1B3F, opcode::OP_CastBool },
    { 0x1B40, opcode::OP_JumpOnFalse },
    { 0x1B41, opcode::OP_Invalid },
    { 0x1B42, opcode::OP_Switch },
    { 0x1B43, opcode::OP_Invalid },
    { 0x1B44, opcode::OP_Invalid },
    { 0x1B45, opcode::OP_EvalFieldVariable },
    { 0x1B46, opcode::OP_Invalid },
    { 0x1B47, opcode::OP_Invalid },
    { 0x1B48, opcode::OP_VectorConstant },
    { 0x1B49, opcode::OP_Invalid },
    { 0x1B4A, opcode::OP_GetNegByte },
    { 0x1B4B, opcode::OP_Invalid },
    { 0x1B4C, opcode::OP_WaitTillFrameEnd },
    { 0x1B4D, opcode::OP_ScriptFunctionCall },
    { 0x1B4E, opcode::OP_GetLevelObject },
    { 0x1B4F, opcode::OP_ShiftLeft },
    { 0x1B50, opcode::OP_ScriptThreadCallPointer },
    { 0x1B51, opcode::OP_VectorScale },
    { 0x1B52, opcode::OP_Invalid },
    { 0x1B53, opcode::OP_JumpOnTrueExpr },
    { 0x1B54, opcode::OP_Dec },
    { 0x1B55, opcode::OP_GetHash },
    { 0x1B56, opcode::OP_ScriptMethodCallPointer },
    { 0x1B57, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x1B58, opcode::OP_Invalid },
    { 0x1B59, opcode::OP_Bit_Xor },
    { 0x1B5A, opcode::OP_GetAnim },
    { 0x1B5B, opcode::OP_GetClassesObject },
    { 0x1B5C, opcode::OP_Invalid },
    { 0x1B5D, opcode::OP_CastBool },
    { 0x1B5E, opcode::OP_GetHash },
    { 0x1B5F, opcode::OP_GreaterThanOrEqualTo },
    { 0x1B60, opcode::OP_SafeCreateLocalVariables },
    { 0x1B61, opcode::OP_Dec },
    { 0x1B62, opcode::OP_GetAnim },
    { 0x1B63, opcode::OP_Invalid },
    { 0x1B64, opcode::OP_EvalLocalVariableRefCached },
    { 0x1B65, opcode::OP_NextArrayKey },
    { 0x1B66, opcode::OP_GreaterThanOrEqualTo },
    { 0x1B67, opcode::OP_Invalid },
    { 0x1B68, opcode::OP_Invalid },
    { 0x1B69, opcode::OP_Invalid },
    { 0x1B6A, opcode::OP_Return },
    { 0x1B6B, opcode::OP_SafeCreateLocalVariables },
    { 0x1B6C, opcode::OP_Invalid },
    { 0x1B6D, opcode::OP_RealWait },
    { 0x1B6E, opcode::OP_Invalid },
    { 0x1B6F, opcode::OP_ClearArray },
    { 0x1B70, opcode::OP_Invalid },
    { 0x1B71, opcode::OP_ClearArray },
    { 0x1B72, opcode::OP_BoolNot },
    { 0x1B73, opcode::OP_GreaterThanOrEqualTo },
    { 0x1B74, opcode::OP_ProfileStop },
    { 0x1B75, opcode::OP_ScriptMethodCallPointer },
    { 0x1B76, opcode::OP_ScriptMethodThreadCall },
    { 0x1B77, opcode::OP_Invalid },
    { 0x1B78, opcode::OP_Bit_Or },
    { 0x1B79, opcode::OP_Invalid },
    { 0x1B7A, opcode::OP_Invalid },
    { 0x1B7B, opcode::OP_GetZero },
    { 0x1B7C, opcode::OP_GetByte },
    { 0x1B7D, opcode::OP_Switch },
    { 0x1B7E, opcode::OP_Invalid },
    { 0x1B7F, opcode::OP_Divide },
    { 0x1B80, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x1B81, opcode::OP_ScriptMethodCall },
    { 0x1B82, opcode::OP_GetUnsignedShort },
    { 0x1B83, opcode::OP_Divide },
    { 0x1B84, opcode::OP_DevblockBegin },
    { 0x1B85, opcode::OP_Invalid },
    { 0x1B86, opcode::OP_GetAnimation },
    { 0x1B87, opcode::OP_EvalFieldVariable },
    { 0x1B88, opcode::OP_Divide },
    { 0x1B89, opcode::OP_Dec },
    { 0x1B8A, opcode::OP_Invalid },
    { 0x1B8B, opcode::OP_GetVector },
    { 0x1B8C, opcode::OP_Invalid },
    { 0x1B8D, opcode::OP_NotEqual },
    { 0x1B8E, opcode::OP_SuperEqual },
    { 0x1B8F, opcode::OP_GetTime },
    { 0x1B90, opcode::OP_Invalid },
    { 0x1B91, opcode::OP_ScriptThreadCall },
    { 0x1B92, opcode::OP_ScriptMethodCallPointer },
    { 0x1B93, opcode::OP_VectorConstant },
    { 0x1B94, opcode::OP_Invalid },
    { 0x1B95, opcode::OP_SetVariableField },
    { 0x1B96, opcode::OP_LevelEvalFieldVariable },
    { 0x1B97, opcode::OP_GetTime },
    { 0x1B98, opcode::OP_ScriptFunctionCallClass },
    { 0x1B99, opcode::OP_Invalid },
    { 0x1B9A, opcode::OP_JumpOnTrueExpr },
    { 0x1B9B, opcode::OP_BoolComplement },
    { 0x1B9C, opcode::OP_Return },
    { 0x1B9D, opcode::OP_JumpOnFalseExpr },
    { 0x1B9E, opcode::OP_Invalid },
    { 0x1B9F, opcode::OP_LevelEvalFieldVariable },
    { 0x1BA0, opcode::OP_Invalid },
    { 0x1BA1, opcode::OP_EvalFieldVariableRef },
    { 0x1BA2, opcode::OP_Invalid },
    { 0x1BA3, opcode::OP_Invalid },
    { 0x1BA4, opcode::OP_GetSelf },
    { 0x1BA5, opcode::OP_GetLevel },
    { 0x1BA6, opcode::OP_WaitTillFrameEnd },
    { 0x1BA7, opcode::OP_Invalid },
    { 0x1BA8, opcode::OP_Invalid },
    { 0x1BA9, opcode::OP_Invalid },
    { 0x1BAA, opcode::OP_New },
    { 0x1BAB, opcode::OP_CastFieldObject },
    { 0x1BAC, opcode::OP_Divide },
    { 0x1BAD, opcode::OP_GetNegByte },
    { 0x1BAE, opcode::OP_GreaterThanOrEqualTo },
    { 0x1BAF, opcode::OP_ScriptMethodCall },
    { 0x1BB0, opcode::OP_Invalid },
    { 0x1BB1, opcode::OP_Invalid },
    { 0x1BB2, opcode::OP_LevelEvalFieldVariable },
    { 0x1BB3, opcode::OP_ScriptMethodThreadCall },
    { 0x1BB4, opcode::OP_WaitTill },
    { 0x1BB5, opcode::OP_Invalid },
    { 0x1BB6, opcode::OP_Invalid },
    { 0x1BB7, opcode::OP_EvalArray },
    { 0x1BB8, opcode::OP_GetFunction },
    { 0x1BB9, opcode::OP_EvalArrayRef },
    { 0x1BBA, opcode::OP_SizeOf },
    { 0x1BBB, opcode::OP_Notify },
    { 0x1BBC, opcode::OP_Invalid },
    { 0x1BBD, opcode::OP_GetInteger },
    { 0x1BBE, opcode::OP_Invalid },
    { 0x1BBF, opcode::OP_Switch },
    { 0x1BC0, opcode::OP_Plus },
    { 0x1BC1, opcode::OP_NextArrayKey },
    { 0x1BC2, opcode::OP_Invalid },
    { 0x1BC3, opcode::OP_EvalFieldVariableRef },
    { 0x1BC4, opcode::OP_Bit_Or },
    { 0x1BC5, opcode::OP_GetIString },
    { 0x1BC6, opcode::OP_EvalArray },
    { 0x1BC7, opcode::OP_Multiply },
    { 0x1BC8, opcode::OP_GetLevelObject },
    { 0x1BC9, opcode::OP_SafeSetVariableFieldCached },
    { 0x1BCA, opcode::OP_CastBool },
    { 0x1BCB, opcode::OP_Invalid },
    { 0x1BCC, opcode::OP_Invalid },
    { 0x1BCD, opcode::OP_Divide },
    { 0x1BCE, opcode::OP_ScriptFunctionCall },
    { 0x1BCF, opcode::OP_Invalid },
    { 0x1BD0, opcode::OP_Invalid },
    { 0x1BD1, opcode::OP_GetGame },
    { 0x1BD2, opcode::OP_Invalid },
    { 0x1BD3, opcode::OP_Invalid },
    { 0x1BD4, opcode::OP_CastFieldObject },
    { 0x1BD5, opcode::OP_GetByte },
    { 0x1BD6, opcode::OP_GreaterThan },
    { 0x1BD7, opcode::OP_ClearArray },
    { 0x1BD8, opcode::OP_ScriptMethodThreadCall },
    { 0x1BD9, opcode::OP_Dec },
    { 0x1BDA, opcode::OP_Invalid },
    { 0x1BDB, opcode::OP_Invalid },
    { 0x1BDC, opcode::OP_Dec },
    { 0x1BDD, opcode::OP_GetSelfObject },
    { 0x1BDE, opcode::OP_GetFunction },
    { 0x1BDF, opcode::OP_EndOn },
    { 0x1BE0, opcode::OP_Invalid },
    { 0x1BE1, opcode::OP_GetGame },
    { 0x1BE2, opcode::OP_GetUnsignedShort },
    { 0x1BE3, opcode::OP_Invalid },
    { 0x1BE4, opcode::OP_Invalid },
    { 0x1BE5, opcode::OP_GetGame },
    { 0x1BE6, opcode::OP_GetAnim },
    { 0x1BE7, opcode::OP_Invalid },
    { 0x1BE8, opcode::OP_GetTime },
    { 0x1BE9, opcode::OP_GetVector },
    { 0x1BEA, opcode::OP_GetByte },
    { 0x1BEB, opcode::OP_Invalid },
    { 0x1BEC, opcode::OP_ScriptMethodCallPointer },
    { 0x1BED, opcode::OP_GetHash },
    { 0x1BEE, opcode::OP_Return },
    { 0x1BEF, opcode::OP_GetVector },
    { 0x1BF0, opcode::OP_Invalid },
    { 0x1BF1, opcode::OP_Invalid },
    { 0x1BF2, opcode::OP_LevelEvalFieldVariableRef },
    { 0x1BF3, opcode::OP_JumpOnTrueExpr },
    { 0x1BF4, opcode::OP_Invalid },
    { 0x1BF5, opcode::OP_GetIString },
    { 0x1BF6, opcode::OP_ScriptFunctionCall },
    { 0x1BF7, opcode::OP_GetZero },
    { 0x1BF8, opcode::OP_ScriptFunctionCallClass },
    { 0x1BF9, opcode::OP_GetGame },
    { 0x1BFA, opcode::OP_ShiftLeft },
    { 0x1BFB, opcode::OP_GetNegUnsignedShort },
    { 0x1BFC, opcode::OP_Invalid },
    { 0x1BFD, opcode::OP_GetClassesObject },
    { 0x1BFE, opcode::OP_Divide },
    { 0x1BFF, opcode::OP_Modulus },
    { 0x1C00, opcode::OP_EvalArray },
    { 0x1C01, opcode::OP_Bit_And },
    { 0x1C02, opcode::OP_GetIString },
    { 0x1C03, opcode::OP_GetInteger },
    { 0x1C04, opcode::OP_GetString },
    { 0x1C05, opcode::OP_GetGameRef },
    { 0x1C06, opcode::OP_GetTime },
    { 0x1C07, opcode::OP_ScriptThreadCall },
    { 0x1C08, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x1C09, opcode::OP_GetAnim },
    { 0x1C0A, opcode::OP_GetNegUnsignedShort },
    { 0x1C0B, opcode::OP_Invalid },
    { 0x1C0C, opcode::OP_GetWorldObject },
    { 0x1C0D, opcode::OP_ScriptThreadCallPointer },
    { 0x1C0E, opcode::OP_Invalid },
    { 0x1C0F, opcode::OP_Invalid },
    { 0x1C10, opcode::OP_Invalid },
    { 0x1C11, opcode::OP_ScriptFunctionCall },
    { 0x1C12, opcode::OP_Invalid },
    { 0x1C13, opcode::OP_GetZero },
    { 0x1C14, opcode::OP_Invalid },
    { 0x1C15, opcode::OP_GetString },
    { 0x1C16, opcode::OP_WaitTill },
    { 0x1C17, opcode::OP_Invalid },
    { 0x1C18, opcode::OP_Minus },
    { 0x1C19, opcode::OP_LevelEvalFieldVariable },
    { 0x1C1A, opcode::OP_GetInteger },
    { 0x1C1B, opcode::OP_Invalid },
    { 0x1C1C, opcode::OP_RealWait },
    { 0x1C1D, opcode::OP_GetClassesObject },
    { 0x1C1E, opcode::OP_EvalArray },
    { 0x1C1F, opcode::OP_DecTop },
    { 0x1C20, opcode::OP_Invalid },
    { 0x1C21, opcode::OP_SetVariableField },
    { 0x1C22, opcode::OP_Jump },
    { 0x1C23, opcode::OP_Invalid },
    { 0x1C24, opcode::OP_GetUintptr },
    { 0x1C25, opcode::OP_GetNegByte },
    { 0x1C26, opcode::OP_EvalLocalVariableCached },
    { 0x1C27, opcode::OP_Invalid },
    { 0x1C28, opcode::OP_GetString },
    { 0x1C29, opcode::OP_GreaterThan },
    { 0x1C2A, opcode::OP_EvalFieldVariable },
    { 0x1C2B, opcode::OP_GetFloat },
    { 0x1C2C, opcode::OP_GetGameRef },
    { 0x1C2D, opcode::OP_Invalid },
    { 0x1C2E, opcode::OP_Invalid },
    { 0x1C2F, opcode::OP_Invalid },
    { 0x1C30, opcode::OP_Invalid },
    { 0x1C31, opcode::OP_Invalid },
    { 0x1C32, opcode::OP_Dec },
    { 0x1C33, opcode::OP_SelfEvalFieldVariable },
    { 0x1C34, opcode::OP_Multiply },
    { 0x1C35, opcode::OP_DevblockBegin },
    { 0x1C36, opcode::OP_JumpOnTrue },
    { 0x1C37, opcode::OP_Vector },
    { 0x1C38, opcode::OP_GetAPIFunction },
    { 0x1C39, opcode::OP_Invalid },
    { 0x1C3A, opcode::OP_Invalid },
    { 0x1C3B, opcode::OP_SelfEvalFieldVariable },
    { 0x1C3C, opcode::OP_GetClasses },
    { 0x1C3D, opcode::OP_Invalid },
    { 0x1C3E, opcode::OP_LevelEvalFieldVariableRef },
    { 0x1C3F, opcode::OP_ScriptThreadCallPointer },
    { 0x1C40, opcode::OP_IsDefined },
    { 0x1C41, opcode::OP_Invalid },
    { 0x1C42, opcode::OP_Invalid },
    { 0x1C43, opcode::OP_SafeSetVariableFieldCached },
    { 0x1C44, opcode::OP_SuperEqual },
    { 0x1C45, opcode::OP_GetInteger },
    { 0x1C46, opcode::OP_ScriptMethodThreadCall },
    { 0x1C47, opcode::OP_Invalid },
    { 0x1C48, opcode::OP_BoolComplement },
    { 0x1C49, opcode::OP_VectorScale },
    { 0x1C4A, opcode::OP_WaitTillMatch },
    { 0x1C4B, opcode::OP_WaitTillMatch },
    { 0x1C4C, opcode::OP_LevelEvalFieldVariable },
    { 0x1C4D, opcode::OP_NotEqual },
    { 0x1C4E, opcode::OP_Invalid },
    { 0x1C4F, opcode::OP_Invalid },
    { 0x1C50, opcode::OP_Invalid },
    { 0x1C51, opcode::OP_GetByte },
    { 0x1C52, opcode::OP_GetAPIFunction },
    { 0x1C53, opcode::OP_EvalFieldVariableRef },
    { 0x1C54, opcode::OP_Invalid },
    { 0x1C55, opcode::OP_Invalid },
    { 0x1C56, opcode::OP_Jump },
    { 0x1C57, opcode::OP_Invalid },
    { 0x1C58, opcode::OP_ProfileStop },
    { 0x1C59, opcode::OP_Invalid },
    { 0x1C5A, opcode::OP_GetClassesObject },
    { 0x1C5B, opcode::OP_GetSelfObject },
    { 0x1C5C, opcode::OP_Invalid },
    { 0x1C5D, opcode::OP_EndOn },
    { 0x1C5E, opcode::OP_Wait },
    { 0x1C5F, opcode::OP_EndSwitch },
    { 0x1C60, opcode::OP_ScriptFunctionCallClass },
    { 0x1C61, opcode::OP_GetTime },
    { 0x1C62, opcode::OP_GetAPIFunction },
    { 0x1C63, opcode::OP_Wait },
    { 0x1C64, opcode::OP_GetGameRef },
    { 0x1C65, opcode::OP_GetWorldObject },
    { 0x1C66, opcode::OP_Invalid },
    { 0x1C67, opcode::OP_LessThanOrEqualTo },
    { 0x1C68, opcode::OP_Plus },
    { 0x1C69, opcode::OP_Invalid },
    { 0x1C6A, opcode::OP_Bit_And },
    { 0x1C6B, opcode::OP_SelfEvalFieldVariable },
    { 0x1C6C, opcode::OP_ScriptThreadCall },
    { 0x1C6D, opcode::OP_SafeCreateLocalVariables },
    { 0x1C6E, opcode::OP_Invalid },
    { 0x1C6F, opcode::OP_EmptyArray },
    { 0x1C70, opcode::OP_New },
    { 0x1C71, opcode::OP_VectorConstant },
    { 0x1C72, opcode::OP_GetLevelObject },
    { 0x1C73, opcode::OP_EndSwitch },
    { 0x1C74, opcode::OP_Invalid },
    { 0x1C75, opcode::OP_Invalid },
    { 0x1C76, opcode::OP_Invalid },
    { 0x1C77, opcode::OP_GetSelf },
    { 0x1C78, opcode::OP_WaitTillFrameEnd },
    { 0x1C79, opcode::OP_ScriptMethodThreadCall },
    { 0x1C7A, opcode::OP_Invalid },
    { 0x1C7B, opcode::OP_Invalid },
    { 0x1C7C, opcode::OP_GetNegUnsignedShort },
    { 0x1C7D, opcode::OP_GetSelfObject },
    { 0x1C7E, opcode::OP_Notify },
    { 0x1C7F, opcode::OP_ShiftRight },
    { 0x1C80, opcode::OP_EndSwitch },
    { 0x1C81, opcode::OP_GetGame },
    { 0x1C82, opcode::OP_GetAPIFunction },
    { 0x1C83, opcode::OP_Invalid },
    { 0x1C84, opcode::OP_EvalArrayRef },
    { 0x1C85, opcode::OP_WaitTillMatch },
    { 0x1C86, opcode::OP_GetClasses },
    { 0x1C87, opcode::OP_FirstArrayKey },
    { 0x1C88, opcode::OP_GetClasses },
    { 0x1C89, opcode::OP_CallBuiltinMethod },
    { 0x1C8A, opcode::OP_ScriptFunctionCallClass },
    { 0x1C8B, opcode::OP_GetClasses },
    { 0x1C8C, opcode::OP_New },
    { 0x1C8D, opcode::OP_Invalid },
    { 0x1C8E, opcode::OP_Invalid },
    { 0x1C8F, opcode::OP_ScriptFunctionCall },
    { 0x1C90, opcode::OP_Invalid },
    { 0x1C91, opcode::OP_SizeOf },
    { 0x1C92, opcode::OP_Invalid },
    { 0x1C93, opcode::OP_LevelEvalFieldVariable },
    { 0x1C94, opcode::OP_Invalid },
    { 0x1C95, opcode::OP_JumpOnFalseExpr },
    { 0x1C96, opcode::OP_LessThanOrEqualTo },
    { 0x1C97, opcode::OP_Invalid },
    { 0x1C98, opcode::OP_SuperNotEqual },
    { 0x1C99, opcode::OP_Invalid },
    { 0x1C9A, opcode::OP_Invalid },
    { 0x1C9B, opcode::OP_Invalid },
    { 0x1C9C, opcode::OP_SelfEvalFieldVariable },
    { 0x1C9D, opcode::OP_EvalArrayRef },
    { 0x1C9E, opcode::OP_GetZero },
    { 0x1C9F, opcode::OP_GetGameRef },
    { 0x1CA0, opcode::OP_Invalid },
    { 0x1CA1, opcode::OP_ScriptFunctionCall },
    { 0x1CA2, opcode::OP_Invalid },
    { 0x1CA3, opcode::OP_Invalid },
    { 0x1CA4, opcode::OP_LevelEvalFieldVariableRef },
    { 0x1CA5, opcode::OP_Jump },
    { 0x1CA6, opcode::OP_GetUintptr },
    { 0x1CA7, opcode::OP_GetLevel },
    { 0x1CA8, opcode::OP_EndSwitch },
    { 0x1CA9, opcode::OP_Invalid },
    { 0x1CAA, opcode::OP_New },
    { 0x1CAB, opcode::OP_GetIString },
    { 0x1CAC, opcode::OP_Vector },
    { 0x1CAD, opcode::OP_GetAPIFunction },
    { 0x1CAE, opcode::OP_Invalid },
    { 0x1CAF, opcode::OP_LessThanOrEqualTo },
    { 0x1CB0, opcode::OP_Invalid },
    { 0x1CB1, opcode::OP_Invalid },
    { 0x1CB2, opcode::OP_GetString },
    { 0x1CB3, opcode::OP_GetWorld },
    { 0x1CB4, opcode::OP_GetGame },
    { 0x1CB5, opcode::OP_LevelEvalFieldVariable },
    { 0x1CB6, opcode::OP_JumpOnFalse },
    { 0x1CB7, opcode::OP_Invalid },
    { 0x1CB8, opcode::OP_GetFloat },
    { 0x1CB9, opcode::OP_ClearArray },
    { 0x1CBA, opcode::OP_Invalid },
    { 0x1CBB, opcode::OP_ShiftLeft },
    { 0x1CBC, opcode::OP_CallBuiltinMethod },
    { 0x1CBD, opcode::OP_Invalid },
    { 0x1CBE, opcode::OP_Equal },
    { 0x1CBF, opcode::OP_Invalid },
    { 0x1CC0, opcode::OP_New },
    { 0x1CC1, opcode::OP_Invalid },
    { 0x1CC2, opcode::OP_Switch },
    { 0x1CC3, opcode::OP_GetZero },
    { 0x1CC4, opcode::OP_Bit_Xor },
    { 0x1CC5, opcode::OP_Vector },
    { 0x1CC6, opcode::OP_GetLevel },
    { 0x1CC7, opcode::OP_SizeOf },
    { 0x1CC8, opcode::OP_Invalid },
    { 0x1CC9, opcode::OP_WaitTillMatch },
    { 0x1CCA, opcode::OP_Invalid },
    { 0x1CCB, opcode::OP_Return },
    { 0x1CCC, opcode::OP_Equal },
    { 0x1CCD, opcode::OP_GetLevel },
    { 0x1CCE, opcode::OP_Invalid },
    { 0x1CCF, opcode::OP_Invalid },
    { 0x1CD0, opcode::OP_GetZero },
    { 0x1CD1, opcode::OP_GetLevelObject },
    { 0x1CD2, opcode::OP_Modulus },
    { 0x1CD3, opcode::OP_ScriptFunctionCall },
    { 0x1CD4, opcode::OP_Wait },
    { 0x1CD5, opcode::OP_Invalid },
    { 0x1CD6, opcode::OP_GetTime },
    { 0x1CD7, opcode::OP_Invalid },
    { 0x1CD8, opcode::OP_GetUndefined },
    { 0x1CD9, opcode::OP_SuperNotEqual },
    { 0x1CDA, opcode::OP_Vector },
    { 0x1CDB, opcode::OP_CastFieldObject },
    { 0x1CDC, opcode::OP_ScriptThreadCallPointer },
    { 0x1CDD, opcode::OP_GetHash },
    { 0x1CDE, opcode::OP_EvalLocalVariableCached },
    { 0x1CDF, opcode::OP_SelfEvalFieldVariable },
    { 0x1CE0, opcode::OP_SuperEqual },
    { 0x1CE1, opcode::OP_EvalArray },
    { 0x1CE2, opcode::OP_GreaterThanOrEqualTo },
    { 0x1CE3, opcode::OP_Invalid },
    { 0x1CE4, opcode::OP_EvalLocalVariableRefCached },
    { 0x1CE5, opcode::OP_DecTop },
    { 0x1CE6, opcode::OP_GetIString },
    { 0x1CE7, opcode::OP_Invalid },
    { 0x1CE8, opcode::OP_SizeOf },
    { 0x1CE9, opcode::OP_GetGameRef },
    { 0x1CEA, opcode::OP_GetGame },
    { 0x1CEB, opcode::OP_Invalid },
    { 0x1CEC, opcode::OP_Invalid },
    { 0x1CED, opcode::OP_GetUnsignedShort },
    { 0x1CEE, opcode::OP_Invalid },
    { 0x1CEF, opcode::OP_GetAnim },
    { 0x1CF0, opcode::OP_GetTime },
    { 0x1CF1, opcode::OP_Invalid },
    { 0x1CF2, opcode::OP_SafeDecTop },
    { 0x1CF3, opcode::OP_Jump },
    { 0x1CF4, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x1CF5, opcode::OP_WaitTill },
    { 0x1CF6, opcode::OP_SafeSetVariableFieldCached },
    { 0x1CF7, opcode::OP_GetHash },
    { 0x1CF8, opcode::OP_ShiftRight },
    { 0x1CF9, opcode::OP_ShiftLeft },
    { 0x1CFA, opcode::OP_Invalid },
    { 0x1CFB, opcode::OP_ProfileStop },
    { 0x1CFC, opcode::OP_GetFloat },
    { 0x1CFD, opcode::OP_Invalid },
    { 0x1CFE, opcode::OP_WaitTillFrameEnd },
    { 0x1CFF, opcode::OP_LessThanOrEqualTo },
    { 0x1D00, opcode::OP_GetVector },
    { 0x1D01, opcode::OP_Notify },
    { 0x1D02, opcode::OP_Invalid },
    { 0x1D03, opcode::OP_Invalid },
    { 0x1D04, opcode::OP_New },
    { 0x1D05, opcode::OP_GetGameRef },
    { 0x1D06, opcode::OP_Invalid },
    { 0x1D07, opcode::OP_Invalid },
    { 0x1D08, opcode::OP_Inc },
    { 0x1D09, opcode::OP_RealWait },
    { 0x1D0A, opcode::OP_Invalid },
    { 0x1D0B, opcode::OP_GetGame },
    { 0x1D0C, opcode::OP_GetVector },
    { 0x1D0D, opcode::OP_ShiftLeft },
    { 0x1D0E, opcode::OP_Invalid },
    { 0x1D0F, opcode::OP_Invalid },
    { 0x1D10, opcode::OP_Invalid },
    { 0x1D11, opcode::OP_GetSelf },
    { 0x1D12, opcode::OP_WaitTillFrameEnd },
    { 0x1D13, opcode::OP_GetTime },
    { 0x1D14, opcode::OP_GetAnimObject },
    { 0x1D15, opcode::OP_Invalid },
    { 0x1D16, opcode::OP_ScriptThreadCallPointer },
    { 0x1D17, opcode::OP_Invalid },
    { 0x1D18, opcode::OP_GetAPIFunction },
    { 0x1D19, opcode::OP_Invalid },
    { 0x1D1A, opcode::OP_Invalid },
    { 0x1D1B, opcode::OP_SafeDecTop },
    { 0x1D1C, opcode::OP_Invalid },
    { 0x1D1D, opcode::OP_EvalArray },
    { 0x1D1E, opcode::OP_GetClassesObject },
    { 0x1D1F, opcode::OP_EndSwitch },
    { 0x1D20, opcode::OP_GetZero },
    { 0x1D21, opcode::OP_Invalid },
    { 0x1D22, opcode::OP_Invalid },
    { 0x1D23, opcode::OP_ScriptFunctionCall },
    { 0x1D24, opcode::OP_Invalid },
    { 0x1D25, opcode::OP_BoolComplement },
    { 0x1D26, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x1D27, opcode::OP_GetByte },
    { 0x1D28, opcode::OP_Invalid },
    { 0x1D29, opcode::OP_ScriptThreadCallClass },
    { 0x1D2A, opcode::OP_Plus },
    { 0x1D2B, opcode::OP_GetAnimation },
    { 0x1D2C, opcode::OP_Invalid },
    { 0x1D2D, opcode::OP_Invalid },
    { 0x1D2E, opcode::OP_SelfEvalFieldVariableRef },
    { 0x1D2F, opcode::OP_Invalid },
    { 0x1D30, opcode::OP_ScriptThreadCallPointer },
    { 0x1D31, opcode::OP_Invalid },
    { 0x1D32, opcode::OP_GetUintptr },
    { 0x1D33, opcode::OP_Invalid },
    { 0x1D34, opcode::OP_ProfileStop },
    { 0x1D35, opcode::OP_EmptyArray },
    { 0x1D36, opcode::OP_GetInteger },
    { 0x1D37, opcode::OP_ShiftRight },
    { 0x1D38, opcode::OP_Return },
    { 0x1D39, opcode::OP_SelfEvalFieldVariableRef },
    { 0x1D3A, opcode::OP_Multiply },
    { 0x1D3B, opcode::OP_GetWorldObject },
    { 0x1D3C, opcode::OP_ScriptMethodThreadCall },
    { 0x1D3D, opcode::OP_Invalid },
    { 0x1D3E, opcode::OP_ScriptMethodCall },
    { 0x1D3F, opcode::OP_Plus },
    { 0x1D40, opcode::OP_WaitTillMatch },
    { 0x1D41, opcode::OP_GetAnimation },
    { 0x1D42, opcode::OP_GetUnsignedShort },
    { 0x1D43, opcode::OP_CallBuiltinMethod },
    { 0x1D44, opcode::OP_GetAnim },
    { 0x1D45, opcode::OP_Invalid },
    { 0x1D46, opcode::OP_VectorConstant },
    { 0x1D47, opcode::OP_Invalid },
    { 0x1D48, opcode::OP_Invalid },
    { 0x1D49, opcode::OP_ScriptMethodCallPointer },
    { 0x1D4A, opcode::OP_Invalid },
    { 0x1D4B, opcode::OP_Invalid },
    { 0x1D4C, opcode::OP_Dec },
    { 0x1D4D, opcode::OP_GetHash },
    { 0x1D4E, opcode::OP_EvalLocalVariableRefCached },
    { 0x1D4F, opcode::OP_GetNegUnsignedShort },
    { 0x1D50, opcode::OP_Plus },
    { 0x1D51, opcode::OP_GetLevelObject },
    { 0x1D52, opcode::OP_Modulus },
    { 0x1D53, opcode::OP_Bit_And },
    { 0x1D54, opcode::OP_GreaterThan },
    { 0x1D55, opcode::OP_EndOn },
    { 0x1D56, opcode::OP_WaitTillMatch },
    { 0x1D57, opcode::OP_Invalid },
    { 0x1D58, opcode::OP_Dec },
    { 0x1D59, opcode::OP_Invalid },
    { 0x1D5A, opcode::OP_Invalid },
    { 0x1D5B, opcode::OP_ClearArray },
    { 0x1D5C, opcode::OP_Inc },
    { 0x1D5D, opcode::OP_ShiftRight },
    { 0x1D5E, opcode::OP_EvalFieldVariableRef },
    { 0x1D5F, opcode::OP_Invalid },
    { 0x1D60, opcode::OP_EvalFieldVariable },
    { 0x1D61, opcode::OP_GetGameRef },
    { 0x1D62, opcode::OP_ShiftLeft },
    { 0x1D63, opcode::OP_GetTime },
    { 0x1D64, opcode::OP_EvalFieldVariableRef },
    { 0x1D65, opcode::OP_GetFloat },
    { 0x1D66, opcode::OP_Invalid },
    { 0x1D67, opcode::OP_Invalid },
    { 0x1D68, opcode::OP_GetNegUnsignedShort },
    { 0x1D69, opcode::OP_LevelEvalFieldVariable },
    { 0x1D6A, opcode::OP_WaitTillFrameEnd },
    { 0x1D6B, opcode::OP_Vector },
    { 0x1D6C, opcode::OP_Invalid },
    { 0x1D6D, opcode::OP_Invalid },
    { 0x1D6E, opcode::OP_LessThanOrEqualTo },
    { 0x1D6F, opcode::OP_GetString },
    { 0x1D70, opcode::OP_Invalid },
    { 0x1D71, opcode::OP_Invalid },
    { 0x1D72, opcode::OP_Invalid },
    { 0x1D73, opcode::OP_Invalid },
    { 0x1D74, opcode::OP_ScriptMethodCall },
    { 0x1D75, opcode::OP_Invalid },
    { 0x1D76, opcode::OP_Invalid },
    { 0x1D77, opcode::OP_Vector },
    { 0x1D78, opcode::OP_GetZero },
    { 0x1D79, opcode::OP_LessThanOrEqualTo },
    { 0x1D7A, opcode::OP_Plus },
    { 0x1D7B, opcode::OP_Invalid },
    { 0x1D7C, opcode::OP_ScriptMethodCallPointer },
    { 0x1D7D, opcode::OP_Invalid },
    { 0x1D7E, opcode::OP_LessThan },
    { 0x1D7F, opcode::OP_GetSelf },
    { 0x1D80, opcode::OP_Invalid },
    { 0x1D81, opcode::OP_Divide },
    { 0x1D82, opcode::OP_Invalid },
    { 0x1D83, opcode::OP_GetLevel },
    { 0x1D84, opcode::OP_Invalid },
    { 0x1D85, opcode::OP_Plus },
    { 0x1D86, opcode::OP_GetSelfObject },
    { 0x1D87, opcode::OP_Invalid },
    { 0x1D88, opcode::OP_Invalid },
    { 0x1D89, opcode::OP_LevelEvalFieldVariable },
    { 0x1D8A, opcode::OP_SetVariableField },
    { 0x1D8B, opcode::OP_GetLevelObject },
    { 0x1D8C, opcode::OP_GetAnimation },
    { 0x1D8D, opcode::OP_Invalid },
    { 0x1D8E, opcode::OP_JumpOnFalseExpr },
    { 0x1D8F, opcode::OP_ScriptFunctionCallClass },
    { 0x1D90, opcode::OP_Invalid },
    { 0x1D91, opcode::OP_Invalid },
    { 0x1D92, opcode::OP_GetWorld },
    { 0x1D93, opcode::OP_DecTop },
    { 0x1D94, opcode::OP_Inc },
    { 0x1D95, opcode::OP_Invalid },
    { 0x1D96, opcode::OP_Modulus },
    { 0x1D97, opcode::OP_Invalid },
    { 0x1D98, opcode::OP_ScriptMethodCall },
    { 0x1D99, opcode::OP_WaitTillMatch },
    { 0x1D9A, opcode::OP_GetAnim },
    { 0x1D9B, opcode::OP_GetByte },
    { 0x1D9C, opcode::OP_CastFieldObject },
    { 0x1D9D, opcode::OP_Invalid },
    { 0x1D9E, opcode::OP_GetAnim },
    { 0x1D9F, opcode::OP_Invalid },
    { 0x1DA0, opcode::OP_GetSelf },
    { 0x1DA1, opcode::OP_Wait },
    { 0x1DA2, opcode::OP_Invalid },
    { 0x1DA3, opcode::OP_Invalid },
    { 0x1DA4, opcode::OP_LessThan },
    { 0x1DA5, opcode::OP_SelfEvalFieldVariable },
    { 0x1DA6, opcode::OP_Invalid },
    { 0x1DA7, opcode::OP_EvalLocalVariableCached },
    { 0x1DA8, opcode::OP_Invalid },
    { 0x1DA9, opcode::OP_ScriptMethodCall },
    { 0x1DAA, opcode::OP_Invalid },
    { 0x1DAB, opcode::OP_DevblockBegin },
    { 0x1DAC, opcode::OP_Invalid },
    { 0x1DAD, opcode::OP_Invalid },
    { 0x1DAE, opcode::OP_WaitTillMatch },
    { 0x1DAF, opcode::OP_Invalid },
    { 0x1DB0, opcode::OP_EndOn },
    { 0x1DB1, opcode::OP_BoolComplement },
    { 0x1DB2, opcode::OP_ScriptMethodThreadCall },
    { 0x1DB3, opcode::OP_Invalid },
    { 0x1DB4, opcode::OP_GetLevel },
    { 0x1DB5, opcode::OP_ScriptThreadCallClass },
    { 0x1DB6, opcode::OP_Switch },
    { 0x1DB7, opcode::OP_RealWait },
    { 0x1DB8, opcode::OP_Invalid },
    { 0x1DB9, opcode::OP_LevelEvalFieldVariable },
    { 0x1DBA, opcode::OP_ScriptThreadCall },
    { 0x1DBB, opcode::OP_ProfileStart },
    { 0x1DBC, opcode::OP_Invalid },
    { 0x1DBD, opcode::OP_Invalid },
    { 0x1DBE, opcode::OP_BoolNot },
    { 0x1DBF, opcode::OP_GetUnsignedShort },
    { 0x1DC0, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x1DC1, opcode::OP_Invalid },
    { 0x1DC2, opcode::OP_Invalid },
    { 0x1DC3, opcode::OP_JumpOnFalse },
    { 0x1DC4, opcode::OP_Invalid },
    { 0x1DC5, opcode::OP_Notify },
    { 0x1DC6, opcode::OP_BoolComplement },
    { 0x1DC7, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x1DC8, opcode::OP_Invalid },
    { 0x1DC9, opcode::OP_Jump },
    { 0x1DCA, opcode::OP_Invalid },
    { 0x1DCB, opcode::OP_GetFunction },
    { 0x1DCC, opcode::OP_GetUnsignedShort },
    { 0x1DCD, opcode::OP_Invalid },
    { 0x1DCE, opcode::OP_GetFloat },
    { 0x1DCF, opcode::OP_GetClasses },
    { 0x1DD0, opcode::OP_Invalid },
    { 0x1DD1, opcode::OP_Invalid },
    { 0x1DD2, opcode::OP_Jump },
    { 0x1DD3, opcode::OP_Invalid },
    { 0x1DD4, opcode::OP_Invalid },
    { 0x1DD5, opcode::OP_GetNegUnsignedShort },
    { 0x1DD6, opcode::OP_Invalid },
    { 0x1DD7, opcode::OP_GetString },
    { 0x1DD8, opcode::OP_DecTop },
    { 0x1DD9, opcode::OP_JumpOnTrue },
    { 0x1DDA, opcode::OP_ScriptThreadCallClass },
    { 0x1DDB, opcode::OP_Bit_Or },
    { 0x1DDC, opcode::OP_ScriptFunctionCallClass },
    { 0x1DDD, opcode::OP_Plus },
    { 0x1DDE, opcode::OP_ShiftLeft },
    { 0x1DDF, opcode::OP_JumpOnTrue },
    { 0x1DE0, opcode::OP_GetUnsignedShort },
    { 0x1DE1, opcode::OP_Notify },
    { 0x1DE2, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x1DE3, opcode::OP_SafeDecTop },
    { 0x1DE4, opcode::OP_JumpOnTrue },
    { 0x1DE5, opcode::OP_ProfileStop },
    { 0x1DE6, opcode::OP_Dec },
    { 0x1DE7, opcode::OP_IsDefined },
    { 0x1DE8, opcode::OP_VectorConstant },
    { 0x1DE9, opcode::OP_Invalid },
    { 0x1DEA, opcode::OP_ShiftRight },
    { 0x1DEB, opcode::OP_Divide },
    { 0x1DEC, opcode::OP_GetLevel },
    { 0x1DED, opcode::OP_Invalid },
    { 0x1DEE, opcode::OP_ScriptFunctionCallClass },
    { 0x1DEF, opcode::OP_GetClasses },
    { 0x1DF0, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x1DF1, opcode::OP_GetFunction },
    { 0x1DF2, opcode::OP_SuperEqual },
    { 0x1DF3, opcode::OP_EvalFieldVariableRef },
    { 0x1DF4, opcode::OP_Modulus },
    { 0x1DF5, opcode::OP_Invalid },
    { 0x1DF6, opcode::OP_Divide },
    { 0x1DF7, opcode::OP_SelfEvalFieldVariable },
    { 0x1DF8, opcode::OP_Inc },
    { 0x1DF9, opcode::OP_RealWait },
    { 0x1DFA, opcode::OP_GetAPIFunction },
    { 0x1DFB, opcode::OP_Invalid },
    { 0x1DFC, opcode::OP_EmptyArray },
    { 0x1DFD, opcode::OP_New },
    { 0x1DFE, opcode::OP_ClearArray },
    { 0x1DFF, opcode::OP_GetFloat },
    { 0x1E00, opcode::OP_GetVector },
    { 0x1E01, opcode::OP_IsDefined },
    { 0x1E02, opcode::OP_GetClassesObject },
    { 0x1E03, opcode::OP_Invalid },
    { 0x1E04, opcode::OP_Invalid },
    { 0x1E05, opcode::OP_Invalid },
    { 0x1E06, opcode::OP_GetAnim },
    { 0x1E07, opcode::OP_SizeOf },
    { 0x1E08, opcode::OP_RealWait },
    { 0x1E09, opcode::OP_Invalid },
    { 0x1E0A, opcode::OP_ScriptMethodCall },
    { 0x1E0B, opcode::OP_NotEqual },
    { 0x1E0C, opcode::OP_GetLevelObject },
    { 0x1E0D, opcode::OP_Invalid },
    { 0x1E0E, opcode::OP_Invalid },
    { 0x1E0F, opcode::OP_EvalArrayRef },
    { 0x1E10, opcode::OP_ScriptThreadCallPointer },
    { 0x1E11, opcode::OP_ScriptThreadCallClass },
    { 0x1E12, opcode::OP_EvalFieldVariable },
    { 0x1E13, opcode::OP_Invalid },
    { 0x1E14, opcode::OP_New },
    { 0x1E15, opcode::OP_GetUndefined },
    { 0x1E16, opcode::OP_JumpOnFalse },
    { 0x1E17, opcode::OP_ScriptThreadCallPointer },
    { 0x1E18, opcode::OP_ClearFieldVariable },
    { 0x1E19, opcode::OP_Invalid },
    { 0x1E1A, opcode::OP_EvalFieldVariableRef },
    { 0x1E1B, opcode::OP_Invalid },
    { 0x1E1C, opcode::OP_JumpOnTrueExpr },
    { 0x1E1D, opcode::OP_RealWait },
    { 0x1E1E, opcode::OP_Invalid },
    { 0x1E1F, opcode::OP_Invalid },
    { 0x1E20, opcode::OP_Invalid },
    { 0x1E21, opcode::OP_Jump },
    { 0x1E22, opcode::OP_RealWait },
    { 0x1E23, opcode::OP_Multiply },
    { 0x1E24, opcode::OP_GetAnimObject },
    { 0x1E25, opcode::OP_Invalid },
    { 0x1E26, opcode::OP_Bit_Xor },
    { 0x1E27, opcode::OP_GetSelfObject },
    { 0x1E28, opcode::OP_DecTop },
    { 0x1E29, opcode::OP_Return },
    { 0x1E2A, opcode::OP_GetWorld },
    { 0x1E2B, opcode::OP_Dec },
    { 0x1E2C, opcode::OP_Invalid },
    { 0x1E2D, opcode::OP_CastFieldObject },
    { 0x1E2E, opcode::OP_ProfileStop },
    { 0x1E2F, opcode::OP_EvalArrayRef },
    { 0x1E30, opcode::OP_Invalid },
    { 0x1E31, opcode::OP_GetUnsignedShort },
    { 0x1E32, opcode::OP_Invalid },
    { 0x1E33, opcode::OP_GetLevel },
    { 0x1E34, opcode::OP_GetGameRef },
    { 0x1E35, opcode::OP_Return },
    { 0x1E36, opcode::OP_Invalid },
    { 0x1E37, opcode::OP_Inc },
    { 0x1E38, opcode::OP_Invalid },
    { 0x1E39, opcode::OP_GetUintptr },
    { 0x1E3A, opcode::OP_ShiftRight },
    { 0x1E3B, opcode::OP_Invalid },
    { 0x1E3C, opcode::OP_Plus },
    { 0x1E3D, opcode::OP_SafeCreateLocalVariables },
    { 0x1E3E, opcode::OP_Invalid },
    { 0x1E3F, opcode::OP_Return },
    { 0x1E40, opcode::OP_Invalid },
    { 0x1E41, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x1E42, opcode::OP_SelfEvalFieldVariableRef },
    { 0x1E43, opcode::OP_WaitTill },
    { 0x1E44, opcode::OP_EvalArray },
    { 0x1E45, opcode::OP_EvalArray },
    { 0x1E46, opcode::OP_Invalid },
    { 0x1E47, opcode::OP_Invalid },
    { 0x1E48, opcode::OP_Invalid },
    { 0x1E49, opcode::OP_Invalid },
    { 0x1E4A, opcode::OP_SizeOf },
    { 0x1E4B, opcode::OP_Invalid },
    { 0x1E4C, opcode::OP_Invalid },
    { 0x1E4D, opcode::OP_ProfileStart },
    { 0x1E4E, opcode::OP_GetTime },
    { 0x1E4F, opcode::OP_JumpOnTrueExpr },
    { 0x1E50, opcode::OP_Invalid },
    { 0x1E51, opcode::OP_VectorScale },
    { 0x1E52, opcode::OP_EndOn },
    { 0x1E53, opcode::OP_Invalid },
    { 0x1E54, opcode::OP_Invalid },
    { 0x1E55, opcode::OP_GetClassesObject },
    { 0x1E56, opcode::OP_Bit_Xor },
    { 0x1E57, opcode::OP_EndSwitch },
    { 0x1E58, opcode::OP_GetFloat },
    { 0x1E59, opcode::OP_WaitTill },
    { 0x1E5A, opcode::OP_EvalArray },
    { 0x1E5B, opcode::OP_Invalid },
    { 0x1E5C, opcode::OP_Invalid },
    { 0x1E5D, opcode::OP_Equal },
    { 0x1E5E, opcode::OP_Invalid },
    { 0x1E5F, opcode::OP_RealWait },
    { 0x1E60, opcode::OP_GetUndefined },
    { 0x1E61, opcode::OP_Equal },
    { 0x1E62, opcode::OP_Invalid },
    { 0x1E63, opcode::OP_ScriptThreadCallClass },
    { 0x1E64, opcode::OP_Invalid },
    { 0x1E65, opcode::OP_GetUnsignedShort },
    { 0x1E66, opcode::OP_SuperNotEqual },
    { 0x1E67, opcode::OP_Invalid },
    { 0x1E68, opcode::OP_Invalid },
    { 0x1E69, opcode::OP_ScriptThreadCallClass },
    { 0x1E6A, opcode::OP_VectorConstant },
    { 0x1E6B, opcode::OP_GreaterThan },
    { 0x1E6C, opcode::OP_WaitTill },
    { 0x1E6D, opcode::OP_DevblockBegin },
    { 0x1E6E, opcode::OP_Invalid },
    { 0x1E6F, opcode::OP_GetHash },
    { 0x1E70, opcode::OP_CastFieldObject },
    { 0x1E71, opcode::OP_Invalid },
    { 0x1E72, opcode::OP_GetInteger },
    { 0x1E73, opcode::OP_Invalid },
    { 0x1E74, opcode::OP_Invalid },
    { 0x1E75, opcode::OP_Vector },
    { 0x1E76, opcode::OP_Invalid },
    { 0x1E77, opcode::OP_Invalid },
    { 0x1E78, opcode::OP_BoolComplement },
    { 0x1E79, opcode::OP_Invalid },
    { 0x1E7A, opcode::OP_Invalid },
    { 0x1E7B, opcode::OP_EvalFieldVariable },
    { 0x1E7C, opcode::OP_NotEqual },
    { 0x1E7D, opcode::OP_Invalid },
    { 0x1E7E, opcode::OP_ScriptMethodCall },
    { 0x1E7F, opcode::OP_DecTop },
    { 0x1E80, opcode::OP_Invalid },
    { 0x1E81, opcode::OP_Invalid },
    { 0x1E82, opcode::OP_GetNegUnsignedShort },
    { 0x1E83, opcode::OP_Invalid },
    { 0x1E84, opcode::OP_GetHash },
    { 0x1E85, opcode::OP_GetInteger },
    { 0x1E86, opcode::OP_GetTime },
    { 0x1E87, opcode::OP_Invalid },
    { 0x1E88, opcode::OP_EvalArray },
    { 0x1E89, opcode::OP_ScriptFunctionCallClass },
    { 0x1E8A, opcode::OP_GetHash },
    { 0x1E8B, opcode::OP_EndOn },
    { 0x1E8C, opcode::OP_GetGame },
    { 0x1E8D, opcode::OP_SetVariableField },
    { 0x1E8E, opcode::OP_Wait },
    { 0x1E8F, opcode::OP_ScriptThreadCallClass },
    { 0x1E90, opcode::OP_GetHash },
    { 0x1E91, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x1E92, opcode::OP_GetLevel },
    { 0x1E93, opcode::OP_EndOn },
    { 0x1E94, opcode::OP_Divide },
    { 0x1E95, opcode::OP_Invalid },
    { 0x1E96, opcode::OP_ShiftRight },
    { 0x1E97, opcode::OP_LessThanOrEqualTo },
    { 0x1E98, opcode::OP_Invalid },
    { 0x1E99, opcode::OP_Jump },
    { 0x1E9A, opcode::OP_GetLevelObject },
    { 0x1E9B, opcode::OP_GetAPIFunction },
    { 0x1E9C, opcode::OP_DecTop },
    { 0x1E9D, opcode::OP_GetGame },
    { 0x1E9E, opcode::OP_Invalid },
    { 0x1E9F, opcode::OP_ScriptFunctionCallPointer },
    { 0x1EA0, opcode::OP_JumpOnTrueExpr },
    { 0x1EA1, opcode::OP_ShiftLeft },
    { 0x1EA2, opcode::OP_GetNegUnsignedShort },
    { 0x1EA3, opcode::OP_Invalid },
    { 0x1EA4, opcode::OP_GetWorld },
    { 0x1EA5, opcode::OP_Invalid },
    { 0x1EA6, opcode::OP_DevblockBegin },
    { 0x1EA7, opcode::OP_Invalid },
    { 0x1EA8, opcode::OP_WaitTillFrameEnd },
    { 0x1EA9, opcode::OP_ProfileStart },
    { 0x1EAA, opcode::OP_Invalid },
    { 0x1EAB, opcode::OP_Invalid },
    { 0x1EAC, opcode::OP_Vector },
    { 0x1EAD, opcode::OP_ScriptMethodCall },
    { 0x1EAE, opcode::OP_Invalid },
    { 0x1EAF, opcode::OP_Invalid },
    { 0x1EB0, opcode::OP_Invalid },
    { 0x1EB1, opcode::OP_GetFunction },
    { 0x1EB2, opcode::OP_Inc },
    { 0x1EB3, opcode::OP_CastBool },
    { 0x1EB4, opcode::OP_GetString },
    { 0x1EB5, opcode::OP_Invalid },
    { 0x1EB6, opcode::OP_Invalid },
    { 0x1EB7, opcode::OP_Divide },
    { 0x1EB8, opcode::OP_GetLevel },
    { 0x1EB9, opcode::OP_Invalid },
    { 0x1EBA, opcode::OP_Equal },
    { 0x1EBB, opcode::OP_Invalid },
    { 0x1EBC, opcode::OP_NextArrayKey },
    { 0x1EBD, opcode::OP_Invalid },
    { 0x1EBE, opcode::OP_Jump },
    { 0x1EBF, opcode::OP_Jump },
    { 0x1EC0, opcode::OP_Invalid },
    { 0x1EC1, opcode::OP_EvalFieldVariableRef },
    { 0x1EC2, opcode::OP_EvalFieldVariable },
    { 0x1EC3, opcode::OP_Bit_Or },
    { 0x1EC4, opcode::OP_EvalArray },
    { 0x1EC5, opcode::OP_GetSelfObject },
    { 0x1EC6, opcode::OP_Invalid },
    { 0x1EC7, opcode::OP_Invalid },
    { 0x1EC8, opcode::OP_WaitTillFrameEnd },
    { 0x1EC9, opcode::OP_BoolComplement },
    { 0x1ECA, opcode::OP_Invalid },
    { 0x1ECB, opcode::OP_Divide },
    { 0x1ECC, opcode::OP_JumpOnFalse },
    { 0x1ECD, opcode::OP_Invalid },
    { 0x1ECE, opcode::OP_NotEqual },
    { 0x1ECF, opcode::OP_GetGame },
    { 0x1ED0, opcode::OP_Invalid },
    { 0x1ED1, opcode::OP_Invalid },
    { 0x1ED2, opcode::OP_LevelEvalFieldVariable },
    { 0x1ED3, opcode::OP_Multiply },
    { 0x1ED4, opcode::OP_Invalid },
    { 0x1ED5, opcode::OP_VectorScale },
    { 0x1ED6, opcode::OP_JumpOnFalse },
    { 0x1ED7, opcode::OP_SuperNotEqual },
    { 0x1ED8, opcode::OP_Invalid },
    { 0x1ED9, opcode::OP_ScriptMethodCall },
    { 0x1EDA, opcode::OP_Multiply },
    { 0x1EDB, opcode::OP_Invalid },
    { 0x1EDC, opcode::OP_RealWait },
    { 0x1EDD, opcode::OP_GetTime },
    { 0x1EDE, opcode::OP_ScriptFunctionCallPointer },
    { 0x1EDF, opcode::OP_WaitTill },
    { 0x1EE0, opcode::OP_Vector },
    { 0x1EE1, opcode::OP_EndSwitch },
    { 0x1EE2, opcode::OP_GetAnimObject },
    { 0x1EE3, opcode::OP_FirstArrayKey },
    { 0x1EE4, opcode::OP_Invalid },
    { 0x1EE5, opcode::OP_GetNegByte },
    { 0x1EE6, opcode::OP_GetLevelObject },
    { 0x1EE7, opcode::OP_Vector },
    { 0x1EE8, opcode::OP_Invalid },
    { 0x1EE9, opcode::OP_GetUnsignedShort },
    { 0x1EEA, opcode::OP_WaitTillFrameEnd },
    { 0x1EEB, opcode::OP_GreaterThan },
    { 0x1EEC, opcode::OP_Invalid },
    { 0x1EED, opcode::OP_Dec },
    { 0x1EEE, opcode::OP_GetAnimObject },
    { 0x1EEF, opcode::OP_NotEqual },
    { 0x1EF0, opcode::OP_GetClassesObject },
    { 0x1EF1, opcode::OP_GetGame },
    { 0x1EF2, opcode::OP_GetWorldObject },
    { 0x1EF3, opcode::OP_Invalid },
    { 0x1EF4, opcode::OP_JumpOnFalseExpr },
    { 0x1EF5, opcode::OP_Invalid },
    { 0x1EF6, opcode::OP_Invalid },
    { 0x1EF7, opcode::OP_ProfileStart },
    { 0x1EF8, opcode::OP_Jump },
    { 0x1EF9, opcode::OP_GetGame },
    { 0x1EFA, opcode::OP_Invalid },
    { 0x1EFB, opcode::OP_GetLevelObject },
    { 0x1EFC, opcode::OP_SizeOf },
    { 0x1EFD, opcode::OP_EvalArrayRef },
    { 0x1EFE, opcode::OP_ScriptThreadCallClass },
    { 0x1EFF, opcode::OP_GetAPIFunction },
    { 0x1F00, opcode::OP_WaitTillMatch },
    { 0x1F01, opcode::OP_GetGame },
    { 0x1F02, opcode::OP_Invalid },
    { 0x1F03, opcode::OP_Invalid },
    { 0x1F04, opcode::OP_SafeDecTop },
    { 0x1F05, opcode::OP_SuperEqual },
    { 0x1F06, opcode::OP_Invalid },
    { 0x1F07, opcode::OP_ScriptMethodCallPointer },
    { 0x1F08, opcode::OP_Invalid },
    { 0x1F09, opcode::OP_Notify },
    { 0x1F0A, opcode::OP_SuperEqual },
    { 0x1F0B, opcode::OP_Invalid },
    { 0x1F0C, opcode::OP_GetHash },
    { 0x1F0D, opcode::OP_SetVariableField },
    { 0x1F0E, opcode::OP_Bit_Or },
    { 0x1F0F, opcode::OP_GreaterThan },
    { 0x1F10, opcode::OP_GetUintptr },
    { 0x1F11, opcode::OP_DevblockBegin },
    { 0x1F12, opcode::OP_GetAPIFunction },
    { 0x1F13, opcode::OP_ProfileStop },
    { 0x1F14, opcode::OP_GetNegByte },
    { 0x1F15, opcode::OP_Invalid },
    { 0x1F16, opcode::OP_GetFloat },
    { 0x1F17, opcode::OP_WaitTillFrameEnd },
    { 0x1F18, opcode::OP_Divide },
    { 0x1F19, opcode::OP_JumpOnFalse },
    { 0x1F1A, opcode::OP_EvalFieldVariable },
    { 0x1F1B, opcode::OP_Invalid },
    { 0x1F1C, opcode::OP_Invalid },
    { 0x1F1D, opcode::OP_Invalid },
    { 0x1F1E, opcode::OP_VectorConstant },
    { 0x1F1F, opcode::OP_Invalid },
    { 0x1F20, opcode::OP_Invalid },
    { 0x1F21, opcode::OP_GetAnimObject },
    { 0x1F22, opcode::OP_Jump },
    { 0x1F23, opcode::OP_Bit_And },
    { 0x1F24, opcode::OP_GetLevelObject },
    { 0x1F25, opcode::OP_GetSelfObject },
    { 0x1F26, opcode::OP_Plus },
    { 0x1F27, opcode::OP_SuperNotEqual },
    { 0x1F28, opcode::OP_Inc },
    { 0x1F29, opcode::OP_DecTop },
    { 0x1F2A, opcode::OP_Vector },
    { 0x1F2B, opcode::OP_SuperNotEqual },
    { 0x1F2C, opcode::OP_Invalid },
    { 0x1F2D, opcode::OP_GetString },
    { 0x1F2E, opcode::OP_ScriptFunctionCall },
    { 0x1F2F, opcode::OP_LessThan },
    { 0x1F30, opcode::OP_GetGame },
    { 0x1F31, opcode::OP_Invalid },
    { 0x1F32, opcode::OP_EvalArray },
    { 0x1F33, opcode::OP_Bit_Xor },
    { 0x1F34, opcode::OP_Invalid },
    { 0x1F35, opcode::OP_ScriptMethodThreadCall },
    { 0x1F36, opcode::OP_CallBuiltinMethod },
    { 0x1F37, opcode::OP_GetUnsignedShort },
    { 0x1F38, opcode::OP_GetAnim },
    { 0x1F39, opcode::OP_Invalid },
    { 0x1F3A, opcode::OP_CallBuiltinMethod },
    { 0x1F3B, opcode::OP_LevelEvalFieldVariableRef },
    { 0x1F3C, opcode::OP_New },
    { 0x1F3D, opcode::OP_Plus },
    { 0x1F3E, opcode::OP_CastFieldObject },
    { 0x1F3F, opcode::OP_Switch },
    { 0x1F40, opcode::OP_GetIString },
    { 0x1F41, opcode::OP_Invalid },
    { 0x1F42, opcode::OP_Invalid },
    { 0x1F43, opcode::OP_Invalid },
    { 0x1F44, opcode::OP_Invalid },
    { 0x1F45, opcode::OP_Jump },
    { 0x1F46, opcode::OP_ProfileStop },
    { 0x1F47, opcode::OP_Invalid },
    { 0x1F48, opcode::OP_JumpOnFalseExpr },
    { 0x1F49, opcode::OP_EvalFieldVariable },
    { 0x1F4A, opcode::OP_SuperNotEqual },
    { 0x1F4B, opcode::OP_GetAnimation },
    { 0x1F4C, opcode::OP_GetSelf },
    { 0x1F4D, opcode::OP_EvalLocalVariableCached },
    { 0x1F4E, opcode::OP_GetInteger },
    { 0x1F4F, opcode::OP_Invalid },
    { 0x1F50, opcode::OP_IsDefined },
    { 0x1F51, opcode::OP_GetSelfObject },
    { 0x1F52, opcode::OP_GetString },
    { 0x1F53, opcode::OP_GetString },
    { 0x1F54, opcode::OP_Invalid },
    { 0x1F55, opcode::OP_LessThanOrEqualTo },
    { 0x1F56, opcode::OP_GetGameRef },
    { 0x1F57, opcode::OP_Divide },
    { 0x1F58, opcode::OP_Invalid },
    { 0x1F59, opcode::OP_Equal },
    { 0x1F5A, opcode::OP_JumpOnTrueExpr },
    { 0x1F5B, opcode::OP_GetGame },
    { 0x1F5C, opcode::OP_GetByte },
    { 0x1F5D, opcode::OP_Invalid },
    { 0x1F5E, opcode::OP_ClearFieldVariable },
    { 0x1F5F, opcode::OP_CastFieldObject },
    { 0x1F60, opcode::OP_Invalid },
    { 0x1F61, opcode::OP_JumpOnFalseExpr },
    { 0x1F62, opcode::OP_Invalid },
    { 0x1F63, opcode::OP_ScriptThreadCallClass },
    { 0x1F64, opcode::OP_Inc },
    { 0x1F65, opcode::OP_SafeCreateLocalVariables },
    { 0x1F66, opcode::OP_EvalLocalVariableRefCached },
    { 0x1F67, opcode::OP_Dec },
    { 0x1F68, opcode::OP_Return },
    { 0x1F69, opcode::OP_GetLevelObject },
    { 0x1F6A, opcode::OP_SafeCreateLocalVariables },
    { 0x1F6B, opcode::OP_GetAnimObject },
    { 0x1F6C, opcode::OP_VectorConstant },
    { 0x1F6D, opcode::OP_ScriptFunctionCallClass },
    { 0x1F6E, opcode::OP_GetZero },
    { 0x1F6F, opcode::OP_GetAnimation },
    { 0x1F70, opcode::OP_Notify },
    { 0x1F71, opcode::OP_Invalid },
    { 0x1F72, opcode::OP_Invalid },
    { 0x1F73, opcode::OP_ScriptThreadCallPointer },
    { 0x1F74, opcode::OP_Invalid },
    { 0x1F75, opcode::OP_GetHash },
    { 0x1F76, opcode::OP_Invalid },
    { 0x1F77, opcode::OP_Invalid },
    { 0x1F78, opcode::OP_Invalid },
    { 0x1F79, opcode::OP_ScriptFunctionCall },
    { 0x1F7A, opcode::OP_GetUintptr },
    { 0x1F7B, opcode::OP_Invalid },
    { 0x1F7C, opcode::OP_Invalid },
    { 0x1F7D, opcode::OP_Wait },
    { 0x1F7E, opcode::OP_Invalid },
    { 0x1F7F, opcode::OP_JumpOnFalseExpr },
    { 0x1F80, opcode::OP_CastBool },
    { 0x1F81, opcode::OP_ScriptMethodThreadCall },
    { 0x1F82, opcode::OP_Divide },
    { 0x1F83, opcode::OP_ScriptFunctionCallClass },
    { 0x1F84, opcode::OP_SelfEvalFieldVariableRef },
    { 0x1F85, opcode::OP_ScriptMethodCallPointer },
    { 0x1F86, opcode::OP_BoolNot },
    { 0x1F87, opcode::OP_Invalid },
    { 0x1F88, opcode::OP_Invalid },
    { 0x1F89, opcode::OP_Invalid },
    { 0x1F8A, opcode::OP_Invalid },
    { 0x1F8B, opcode::OP_Invalid },
    { 0x1F8C, opcode::OP_VectorScale },
    { 0x1F8D, opcode::OP_Invalid },
    { 0x1F8E, opcode::OP_GreaterThan },
    { 0x1F8F, opcode::OP_SelfEvalFieldVariable },
    { 0x1F90, opcode::OP_EvalFieldVariableRef },
    { 0x1F91, opcode::OP_Invalid },
    { 0x1F92, opcode::OP_VectorScale },
    { 0x1F93, opcode::OP_Invalid },
    { 0x1F94, opcode::OP_GetTime },
    { 0x1F95, opcode::OP_FirstArrayKey },
    { 0x1F96, opcode::OP_Invalid },
    { 0x1F97, opcode::OP_Invalid },
    { 0x1F98, opcode::OP_ScriptMethodThreadCall },
    { 0x1F99, opcode::OP_EvalLocalVariableRefCached },
    { 0x1F9A, opcode::OP_Equal },
    { 0x1F9B, opcode::OP_EvalFieldVariable },
    { 0x1F9C, opcode::OP_Invalid },
    { 0x1F9D, opcode::OP_Invalid },
    { 0x1F9E, opcode::OP_GetSelf },
    { 0x1F9F, opcode::OP_Invalid },
    { 0x1FA0, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x1FA1, opcode::OP_Invalid },
    { 0x1FA2, opcode::OP_Equal },
    { 0x1FA3, opcode::OP_EvalArray },
    { 0x1FA4, opcode::OP_JumpOnFalse },
    { 0x1FA5, opcode::OP_Invalid },
    { 0x1FA6, opcode::OP_Invalid },
    { 0x1FA7, opcode::OP_Modulus },
    { 0x1FA8, opcode::OP_GetUintptr },
    { 0x1FA9, opcode::OP_SafeCreateLocalVariables },
    { 0x1FAA, opcode::OP_Invalid },
    { 0x1FAB, opcode::OP_GetTime },
    { 0x1FAC, opcode::OP_GetSelfObject },
    { 0x1FAD, opcode::OP_Wait },
    { 0x1FAE, opcode::OP_Invalid },
    { 0x1FAF, opcode::OP_DevblockBegin },
    { 0x1FB0, opcode::OP_GetByte },
    { 0x1FB1, opcode::OP_GetWorld },
    { 0x1FB2, opcode::OP_SuperNotEqual },
    { 0x1FB3, opcode::OP_Plus },
    { 0x1FB4, opcode::OP_GetAnim },
    { 0x1FB5, opcode::OP_GetNegByte },
    { 0x1FB6, opcode::OP_CallBuiltinMethod },
    { 0x1FB7, opcode::OP_GetByte },
    { 0x1FB8, opcode::OP_GetNegUnsignedShort },
    { 0x1FB9, opcode::OP_Invalid },
    { 0x1FBA, opcode::OP_ProfileStop },
    { 0x1FBB, opcode::OP_Invalid },
    { 0x1FBC, opcode::OP_GetLevelObject },
    { 0x1FBD, opcode::OP_Switch },
    { 0x1FBE, opcode::OP_VectorConstant },
    { 0x1FBF, opcode::OP_New },
    { 0x1FC0, opcode::OP_Invalid },
    { 0x1FC1, opcode::OP_GetAnim },
    { 0x1FC2, opcode::OP_Invalid },
    { 0x1FC3, opcode::OP_Invalid },
    { 0x1FC4, opcode::OP_Bit_Xor },
    { 0x1FC5, opcode::OP_Invalid },
    { 0x1FC6, opcode::OP_GetString },
    { 0x1FC7, opcode::OP_CastBool },
    { 0x1FC8, opcode::OP_JumpOnTrueExpr },
    { 0x1FC9, opcode::OP_GetFloat },
    { 0x1FCA, opcode::OP_GetUintptr },
    { 0x1FCB, opcode::OP_FirstArrayKey },
    { 0x1FCC, opcode::OP_ScriptMethodCall },
    { 0x1FCD, opcode::OP_Invalid },
    { 0x1FCE, opcode::OP_JumpOnFalseExpr },
    { 0x1FCF, opcode::OP_Switch },
    { 0x1FD0, opcode::OP_Invalid },
    { 0x1FD1, opcode::OP_GreaterThanOrEqualTo },
    { 0x1FD2, opcode::OP_NextArrayKey },
    { 0x1FD3, opcode::OP_Invalid },
    { 0x1FD4, opcode::OP_SafeDecTop },
    { 0x1FD5, opcode::OP_Bit_Or },
    { 0x1FD6, opcode::OP_Invalid },
    { 0x1FD7, opcode::OP_GetLevelObject },
    { 0x1FD8, opcode::OP_SuperEqual },
    { 0x1FD9, opcode::OP_EvalFieldVariableRef },
    { 0x1FDA, opcode::OP_ShiftLeft },
    { 0x1FDB, opcode::OP_EmptyArray },
    { 0x1FDC, opcode::OP_GetClasses },
    { 0x1FDD, opcode::OP_EvalArrayRef },
    { 0x1FDE, opcode::OP_Multiply },
    { 0x1FDF, opcode::OP_Plus },
    { 0x1FE0, opcode::OP_JumpOnTrue },
    { 0x1FE1, opcode::OP_Invalid },
    { 0x1FE2, opcode::OP_Bit_Xor },
    { 0x1FE3, opcode::OP_RealWait },
    { 0x1FE4, opcode::OP_EvalLocalVariableCached },
    { 0x1FE5, opcode::OP_ProfileStart },
    { 0x1FE6, opcode::OP_SuperNotEqual },
    { 0x1FE7, opcode::OP_ProfileStart },
    { 0x1FE8, opcode::OP_Invalid },
    { 0x1FE9, opcode::OP_Invalid },
    { 0x1FEA, opcode::OP_GetGameRef },
    { 0x1FEB, opcode::OP_NextArrayKey },
    { 0x1FEC, opcode::OP_GetUndefined },
    { 0x1FED, opcode::OP_Invalid },
    { 0x1FEE, opcode::OP_GreaterThanOrEqualTo },
    { 0x1FEF, opcode::OP_SuperNotEqual },
    { 0x1FF0, opcode::OP_ScriptMethodThreadCall },
    { 0x1FF1, opcode::OP_Invalid },
    { 0x1FF2, opcode::OP_Invalid },
    { 0x1FF3, opcode::OP_SelfEvalFieldVariable },
    { 0x1FF4, opcode::OP_ProfileStop },
    { 0x1FF5, opcode::OP_Invalid },
    { 0x1FF6, opcode::OP_EvalFieldVariableRef },
    { 0x1FF7, opcode::OP_GetUintptr },
    { 0x1FF8, opcode::OP_JumpOnTrue },
    { 0x1FF9, opcode::OP_RealWait },
    { 0x1FFA, opcode::OP_GetLevelObject },
    { 0x1FFB, opcode::OP_VectorScale },
    { 0x1FFC, opcode::OP_SafeSetVariableFieldCached },
    { 0x1FFD, opcode::OP_LevelEvalFieldVariable },
    { 0x1FFE, opcode::OP_Bit_And },
    { 0x1FFF, opcode::OP_Equal },

    { 0x2000, opcode::OP_Invalid },
    { 0x2001, opcode::OP_Invalid },
    { 0x2002, opcode::OP_Invalid },
    { 0x2003, opcode::OP_Invalid },
    { 0x2004, opcode::OP_Invalid },
    { 0x2005, opcode::OP_Invalid },
    { 0x2006, opcode::OP_Invalid },
    { 0x2007, opcode::OP_Invalid },
    { 0x2008, opcode::OP_EvalLocalVariableCachedDebug },
    { 0x2009, opcode::OP_EvalLocalVariableRefCachedDebug },
    { 0x200A, opcode::OP_Invalid },
    { 0x200B, opcode::OP_Invalid },
    { 0x200C, opcode::OP_ClearParams },
    { 0x200D, opcode::OP_CheckClearParams },
    { 0x200E, opcode::OP_PreScriptCall },
    { 0x200F, opcode::OP_CallBuiltin },
    { 0x2010, opcode::OP_End },
    { 0x2011, opcode::OP_Invalid },
    { 0x2012, opcode::OP_New },
    { 0x2013, opcode::OP_JumpOnTrue },
    { 0x2014, opcode::OP_Invalid },
    { 0x2015, opcode::OP_Invalid },
    { 0x2016, opcode::OP_Invalid },
    { 0x2017, opcode::OP_Plus },
    { 0x2018, opcode::OP_Bit_Xor },
    { 0x2019, opcode::OP_Invalid },
    { 0x201A, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x201B, opcode::OP_Invalid },
    { 0x201C, opcode::OP_Jump },
    { 0x201D, opcode::OP_JumpOnFalseExpr },
    { 0x201E, opcode::OP_Bit_Or },
    { 0x201F, opcode::OP_Invalid },
    { 0x2020, opcode::OP_GreaterThan },
    { 0x2021, opcode::OP_Bit_And },
    { 0x2022, opcode::OP_ScriptThreadCallPointer },
    { 0x2023, opcode::OP_Invalid },
    { 0x2024, opcode::OP_Invalid },
    { 0x2025, opcode::OP_Wait },
    { 0x2026, opcode::OP_Invalid },
    { 0x2027, opcode::OP_GetWorldObject },
    { 0x2028, opcode::OP_Invalid },
    { 0x2029, opcode::OP_EndSwitch },
    { 0x202A, opcode::OP_GetAnim },
    { 0x202B, opcode::OP_Minus },
    { 0x202C, opcode::OP_CastFieldObject },
    { 0x202D, opcode::OP_ShiftLeft },
    { 0x202E, opcode::OP_Invalid },
    { 0x202F, opcode::OP_BoolComplement },
    { 0x2030, opcode::OP_WaitTillFrameEnd },
    { 0x2031, opcode::OP_GetWorld },
    { 0x2032, opcode::OP_Invalid },
    { 0x2033, opcode::OP_BoolNot },
    { 0x2034, opcode::OP_SizeOf },
    { 0x2035, opcode::OP_Wait },
    { 0x2036, opcode::OP_LevelEvalFieldVariable },
    { 0x2037, opcode::OP_ProfileStop },
    { 0x2038, opcode::OP_LessThan },
    { 0x2039, opcode::OP_Invalid },
    { 0x203A, opcode::OP_SuperNotEqual },
    { 0x203B, opcode::OP_Invalid },
    { 0x203C, opcode::OP_Multiply },
    { 0x203D, opcode::OP_BoolNot },
    { 0x203E, opcode::OP_Invalid },
    { 0x203F, opcode::OP_Wait },
    { 0x2040, opcode::OP_Invalid },
    { 0x2041, opcode::OP_NotEqual },
    { 0x2042, opcode::OP_Invalid },
    { 0x2043, opcode::OP_GetVector },
    { 0x2044, opcode::OP_Invalid },
    { 0x2045, opcode::OP_ClearFieldVariable },
    { 0x2046, opcode::OP_New },
    { 0x2047, opcode::OP_Invalid },
    { 0x2048, opcode::OP_SafeDecTop },
    { 0x2049, opcode::OP_JumpOnFalse },
    { 0x204A, opcode::OP_Invalid },
    { 0x204B, opcode::OP_ShiftLeft },
    { 0x204C, opcode::OP_Invalid },
    { 0x204D, opcode::OP_Invalid },
    { 0x204E, opcode::OP_ClearArray },
    { 0x204F, opcode::OP_Invalid },
    { 0x2050, opcode::OP_Invalid },
    { 0x2051, opcode::OP_FirstArrayKey },
    { 0x2052, opcode::OP_Invalid },
    { 0x2053, opcode::OP_EndOn },
    { 0x2054, opcode::OP_EvalFieldVariableRef },
    { 0x2055, opcode::OP_Equal },
    { 0x2056, opcode::OP_Invalid },
    { 0x2057, opcode::OP_Invalid },
    { 0x2058, opcode::OP_Invalid },
    { 0x2059, opcode::OP_GetAnim },
    { 0x205A, opcode::OP_Equal },
    { 0x205B, opcode::OP_Bit_And },
    { 0x205C, opcode::OP_ScriptMethodCall },
    { 0x205D, opcode::OP_GetFunction },
    { 0x205E, opcode::OP_EndSwitch },
    { 0x205F, opcode::OP_SafeSetVariableFieldCached },
    { 0x2060, opcode::OP_Invalid },
    { 0x2061, opcode::OP_Invalid },
    { 0x2062, opcode::OP_Bit_Xor },
    { 0x2063, opcode::OP_GreaterThan },
    { 0x2064, opcode::OP_Invalid },
    { 0x2065, opcode::OP_Invalid },
    { 0x2066, opcode::OP_Invalid },
    { 0x2067, opcode::OP_Modulus },
    { 0x2068, opcode::OP_ScriptThreadCallPointer },
    { 0x2069, opcode::OP_Invalid },
    { 0x206A, opcode::OP_Switch },
    { 0x206B, opcode::OP_EvalArray },
    { 0x206C, opcode::OP_GetSelfObject },
    { 0x206D, opcode::OP_SetVariableField },
    { 0x206E, opcode::OP_ClearFieldVariable },
    { 0x206F, opcode::OP_ScriptMethodCall },
    { 0x2070, opcode::OP_ProfileStart },
    { 0x2071, opcode::OP_EndSwitch },
    { 0x2072, opcode::OP_Invalid },
    { 0x2073, opcode::OP_SuperNotEqual },
    { 0x2074, opcode::OP_Invalid },
    { 0x2075, opcode::OP_ScriptMethodCall },
    { 0x2076, opcode::OP_Invalid },
    { 0x2077, opcode::OP_Invalid },
    { 0x2078, opcode::OP_ProfileStop },
    { 0x2079, opcode::OP_DecTop },
    { 0x207A, opcode::OP_GetHash },
    { 0x207B, opcode::OP_EvalLocalVariableRefCached },
    { 0x207C, opcode::OP_GetAnim },
    { 0x207D, opcode::OP_Plus },
    { 0x207E, opcode::OP_GetWorldObject },
    { 0x207F, opcode::OP_Invalid },
    { 0x2080, opcode::OP_FirstArrayKey },
    { 0x2081, opcode::OP_Dec },
    { 0x2082, opcode::OP_Invalid },
    { 0x2083, opcode::OP_Invalid },
    { 0x2084, opcode::OP_Invalid },
    { 0x2085, opcode::OP_Invalid },
    { 0x2086, opcode::OP_Return },
    { 0x2087, opcode::OP_GetAnimObject },
    { 0x2088, opcode::OP_WaitTillMatch },
    { 0x2089, opcode::OP_Modulus },
    { 0x208A, opcode::OP_Invalid },
    { 0x208B, opcode::OP_ProfileStart },
    { 0x208C, opcode::OP_GetIString },
    { 0x208D, opcode::OP_ScriptFunctionCallPointer },
    { 0x208E, opcode::OP_EndOn },
    { 0x208F, opcode::OP_JumpOnFalse },
    { 0x2090, opcode::OP_GetGameRef },
    { 0x2091, opcode::OP_GetFunction },
    { 0x2092, opcode::OP_Invalid },
    { 0x2093, opcode::OP_ClearFieldVariable },
    { 0x2094, opcode::OP_Invalid },
    { 0x2095, opcode::OP_GetClassesObject },
    { 0x2096, opcode::OP_GetSelfObject },
    { 0x2097, opcode::OP_Invalid },
    { 0x2098, opcode::OP_GetByte },
    { 0x2099, opcode::OP_Invalid },
    { 0x209A, opcode::OP_WaitTillFrameEnd },
    { 0x209B, opcode::OP_Invalid },
    { 0x209C, opcode::OP_Minus },
    { 0x209D, opcode::OP_EndOn },
    { 0x209E, opcode::OP_SafeCreateLocalVariables },
    { 0x209F, opcode::OP_LessThan },
    { 0x20A0, opcode::OP_JumpOnTrueExpr },
    { 0x20A1, opcode::OP_GetLevelObject },
    { 0x20A2, opcode::OP_GreaterThan },
    { 0x20A3, opcode::OP_BoolComplement },
    { 0x20A4, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x20A5, opcode::OP_Invalid },
    { 0x20A6, opcode::OP_Invalid },
    { 0x20A7, opcode::OP_Invalid },
    { 0x20A8, opcode::OP_Invalid },
    { 0x20A9, opcode::OP_Invalid },
    { 0x20AA, opcode::OP_Invalid },
    { 0x20AB, opcode::OP_Invalid },
    { 0x20AC, opcode::OP_GetNegUnsignedShort },
    { 0x20AD, opcode::OP_JumpOnFalse },
    { 0x20AE, opcode::OP_Vector },
    { 0x20AF, opcode::OP_LevelEvalFieldVariableRef },
    { 0x20B0, opcode::OP_GetAnim },
    { 0x20B1, opcode::OP_RealWait },
    { 0x20B2, opcode::OP_WaitTillFrameEnd },
    { 0x20B3, opcode::OP_JumpOnFalseExpr },
    { 0x20B4, opcode::OP_Invalid },
    { 0x20B5, opcode::OP_ClearArray },
    { 0x20B6, opcode::OP_EmptyArray },
    { 0x20B7, opcode::OP_Invalid },
    { 0x20B8, opcode::OP_GetVector },
    { 0x20B9, opcode::OP_New },
    { 0x20BA, opcode::OP_ClearArray },
    { 0x20BB, opcode::OP_Invalid },
    { 0x20BC, opcode::OP_EvalLocalVariableCached },
    { 0x20BD, opcode::OP_Invalid },
    { 0x20BE, opcode::OP_EvalFieldVariableRef },
    { 0x20BF, opcode::OP_Invalid },
    { 0x20C0, opcode::OP_GetFloat },
    { 0x20C1, opcode::OP_EvalFieldVariable },
    { 0x20C2, opcode::OP_GetGame },
    { 0x20C3, opcode::OP_Invalid },
    { 0x20C4, opcode::OP_GetAnim },
    { 0x20C5, opcode::OP_FirstArrayKey },
    { 0x20C6, opcode::OP_JumpOnFalse },
    { 0x20C7, opcode::OP_Invalid },
    { 0x20C8, opcode::OP_Invalid },
    { 0x20C9, opcode::OP_GetAnimation },
    { 0x20CA, opcode::OP_Invalid },
    { 0x20CB, opcode::OP_Return },
    { 0x20CC, opcode::OP_ShiftLeft },
    { 0x20CD, opcode::OP_Invalid },
    { 0x20CE, opcode::OP_CastFieldObject },
    { 0x20CF, opcode::OP_Invalid },
    { 0x20D0, opcode::OP_LessThanOrEqualTo },
    { 0x20D1, opcode::OP_Invalid },
    { 0x20D2, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x20D3, opcode::OP_DevblockBegin },
    { 0x20D4, opcode::OP_Invalid },
    { 0x20D5, opcode::OP_Invalid },
    { 0x20D6, opcode::OP_GetZero },
    { 0x20D7, opcode::OP_EmptyArray },
    { 0x20D8, opcode::OP_EvalLocalVariableCached },
    { 0x20D9, opcode::OP_Invalid },
    { 0x20DA, opcode::OP_ScriptMethodCallPointer },
    { 0x20DB, opcode::OP_Invalid },
    { 0x20DC, opcode::OP_Invalid },
    { 0x20DD, opcode::OP_EvalArray },
    { 0x20DE, opcode::OP_LevelEvalFieldVariable },
    { 0x20DF, opcode::OP_GetInteger },
    { 0x20E0, opcode::OP_GetInteger },
    { 0x20E1, opcode::OP_EndOn },
    { 0x20E2, opcode::OP_Invalid },
    { 0x20E3, opcode::OP_ScriptMethodThreadCall },
    { 0x20E4, opcode::OP_Invalid },
    { 0x20E5, opcode::OP_GetUintptr },
    { 0x20E6, opcode::OP_Invalid },
    { 0x20E7, opcode::OP_Invalid },
    { 0x20E8, opcode::OP_GetGame },
    { 0x20E9, opcode::OP_Minus },
    { 0x20EA, opcode::OP_Equal },
    { 0x20EB, opcode::OP_Invalid },
    { 0x20EC, opcode::OP_Invalid },
    { 0x20ED, opcode::OP_Invalid },
    { 0x20EE, opcode::OP_GetSelfObject },
    { 0x20EF, opcode::OP_NextArrayKey },
    { 0x20F0, opcode::OP_Invalid },
    { 0x20F1, opcode::OP_Invalid },
    { 0x20F2, opcode::OP_GetInteger },
    { 0x20F3, opcode::OP_GetInteger },
    { 0x20F4, opcode::OP_Invalid },
    { 0x20F5, opcode::OP_Invalid },
    { 0x20F6, opcode::OP_GetSelfObject },
    { 0x20F7, opcode::OP_EvalFieldVariable },
    { 0x20F8, opcode::OP_ShiftRight },
    { 0x20F9, opcode::OP_GetAnimObject },
    { 0x20FA, opcode::OP_GetClassesObject },
    { 0x20FB, opcode::OP_Invalid },
    { 0x20FC, opcode::OP_SafeDecTop },
    { 0x20FD, opcode::OP_EndOn },
    { 0x20FE, opcode::OP_Bit_Xor },
    { 0x20FF, opcode::OP_GetGame },
    { 0x2100, opcode::OP_Invalid },
    { 0x2101, opcode::OP_Invalid },
    { 0x2102, opcode::OP_Invalid },
    { 0x2103, opcode::OP_NextArrayKey },
    { 0x2104, opcode::OP_GetAnimation },
    { 0x2105, opcode::OP_ProfileStop },
    { 0x2106, opcode::OP_ProfileStop },
    { 0x2107, opcode::OP_Invalid },
    { 0x2108, opcode::OP_ClearArray },
    { 0x2109, opcode::OP_GetUnsignedShort },
    { 0x210A, opcode::OP_EvalLocalVariableRefCached },
    { 0x210B, opcode::OP_Invalid },
    { 0x210C, opcode::OP_Invalid },
    { 0x210D, opcode::OP_NotEqual },
    { 0x210E, opcode::OP_SizeOf },
    { 0x210F, opcode::OP_WaitTill },
    { 0x2110, opcode::OP_Invalid },
    { 0x2111, opcode::OP_Return },
    { 0x2112, opcode::OP_WaitTillMatch },
    { 0x2113, opcode::OP_Invalid },
    { 0x2114, opcode::OP_GetTime },
    { 0x2115, opcode::OP_Invalid },
    { 0x2116, opcode::OP_GetLevelObject },
    { 0x2117, opcode::OP_GetUndefined },
    { 0x2118, opcode::OP_LevelEvalFieldVariable },
    { 0x2119, opcode::OP_GreaterThanOrEqualTo },
    { 0x211A, opcode::OP_Invalid },
    { 0x211B, opcode::OP_Invalid },
    { 0x211C, opcode::OP_Minus },
    { 0x211D, opcode::OP_ClearArray },
    { 0x211E, opcode::OP_SuperNotEqual },
    { 0x211F, opcode::OP_Invalid },
    { 0x2120, opcode::OP_Invalid },
    { 0x2121, opcode::OP_GetAPIFunction },
    { 0x2122, opcode::OP_BoolComplement },
    { 0x2123, opcode::OP_GetHash },
    { 0x2124, opcode::OP_GetLevel },
    { 0x2125, opcode::OP_SelfEvalFieldVariableRef },
    { 0x2126, opcode::OP_GetWorldObject },
    { 0x2127, opcode::OP_Jump },
    { 0x2128, opcode::OP_WaitTill },
    { 0x2129, opcode::OP_Invalid },
    { 0x212A, opcode::OP_Invalid },
    { 0x212B, opcode::OP_Minus },
    { 0x212C, opcode::OP_ShiftRight },
    { 0x212D, opcode::OP_FirstArrayKey },
    { 0x212E, opcode::OP_Invalid },
    { 0x212F, opcode::OP_LessThan },
    { 0x2130, opcode::OP_SizeOf },
    { 0x2131, opcode::OP_Wait },
    { 0x2132, opcode::OP_Invalid },
    { 0x2133, opcode::OP_SelfEvalFieldVariableRef },
    { 0x2134, opcode::OP_Bit_And },
    { 0x2135, opcode::OP_Invalid },
    { 0x2136, opcode::OP_ClearFieldVariable },
    { 0x2137, opcode::OP_EvalFieldVariable },
    { 0x2138, opcode::OP_Invalid },
    { 0x2139, opcode::OP_GetClassesObject },
    { 0x213A, opcode::OP_BoolComplement },
    { 0x213B, opcode::OP_SafeCreateLocalVariables },
    { 0x213C, opcode::OP_Invalid },
    { 0x213D, opcode::OP_Invalid },
    { 0x213E, opcode::OP_Invalid },
    { 0x213F, opcode::OP_Multiply },
    { 0x2140, opcode::OP_GreaterThan },
    { 0x2141, opcode::OP_BoolNot },
    { 0x2142, opcode::OP_Invalid },
    { 0x2143, opcode::OP_Invalid },
    { 0x2144, opcode::OP_Invalid },
    { 0x2145, opcode::OP_Invalid },
    { 0x2146, opcode::OP_ScriptThreadCallPointer },
    { 0x2147, opcode::OP_Invalid },
    { 0x2148, opcode::OP_Invalid },
    { 0x2149, opcode::OP_GetLevelObject },
    { 0x214A, opcode::OP_GetFloat },
    { 0x214B, opcode::OP_Invalid },
    { 0x214C, opcode::OP_GetAnimation },
    { 0x214D, opcode::OP_Invalid },
    { 0x214E, opcode::OP_GetTime },
    { 0x214F, opcode::OP_CallBuiltinMethod },
    { 0x2150, opcode::OP_ScriptThreadCallClass },
    { 0x2151, opcode::OP_Invalid },
    { 0x2152, opcode::OP_WaitTillFrameEnd },
    { 0x2153, opcode::OP_GetClasses },
    { 0x2154, opcode::OP_GetTime },
    { 0x2155, opcode::OP_New },
    { 0x2156, opcode::OP_EvalLocalVariableCached },
    { 0x2157, opcode::OP_Dec },
    { 0x2158, opcode::OP_SelfEvalFieldVariable },
    { 0x2159, opcode::OP_EvalArrayRef },
    { 0x215A, opcode::OP_Invalid },
    { 0x215B, opcode::OP_CastFieldObject },
    { 0x215C, opcode::OP_BoolComplement },
    { 0x215D, opcode::OP_Divide },
    { 0x215E, opcode::OP_Bit_Xor },
    { 0x215F, opcode::OP_SelfEvalFieldVariable },
    { 0x2160, opcode::OP_NextArrayKey },
    { 0x2161, opcode::OP_Invalid },
    { 0x2162, opcode::OP_CallBuiltinMethod },
    { 0x2163, opcode::OP_Switch },
    { 0x2164, opcode::OP_SelfEvalFieldVariable },
    { 0x2165, opcode::OP_Invalid },
    { 0x2166, opcode::OP_EvalFieldVariable },
    { 0x2167, opcode::OP_Bit_Xor },
    { 0x2168, opcode::OP_CallBuiltinMethod },
    { 0x2169, opcode::OP_ShiftRight },
    { 0x216A, opcode::OP_ScriptMethodCallPointer },
    { 0x216B, opcode::OP_Invalid },
    { 0x216C, opcode::OP_Invalid },
    { 0x216D, opcode::OP_GetClassesObject },
    { 0x216E, opcode::OP_Wait },
    { 0x216F, opcode::OP_New },
    { 0x2170, opcode::OP_LessThanOrEqualTo },
    { 0x2171, opcode::OP_Invalid },
    { 0x2172, opcode::OP_LessThan },
    { 0x2173, opcode::OP_Divide },
    { 0x2174, opcode::OP_WaitTillFrameEnd },
    { 0x2175, opcode::OP_Invalid },
    { 0x2176, opcode::OP_Invalid },
    { 0x2177, opcode::OP_Invalid },
    { 0x2178, opcode::OP_GetByte },
    { 0x2179, opcode::OP_SuperNotEqual },
    { 0x217A, opcode::OP_Invalid },
    { 0x217B, opcode::OP_Jump },
    { 0x217C, opcode::OP_ScriptThreadCall },
    { 0x217D, opcode::OP_WaitTillFrameEnd },
    { 0x217E, opcode::OP_JumpOnFalseExpr },
    { 0x217F, opcode::OP_Invalid },
    { 0x2180, opcode::OP_JumpOnTrueExpr },
    { 0x2181, opcode::OP_Dec },
    { 0x2182, opcode::OP_WaitTill },
    { 0x2183, opcode::OP_Bit_Xor },
    { 0x2184, opcode::OP_Invalid },
    { 0x2185, opcode::OP_Invalid },
    { 0x2186, opcode::OP_ScriptMethodCall },
    { 0x2187, opcode::OP_ScriptThreadCall },
    { 0x2188, opcode::OP_GetUintptr },
    { 0x2189, opcode::OP_CallBuiltinMethod },
    { 0x218A, opcode::OP_Invalid },
    { 0x218B, opcode::OP_SuperNotEqual },
    { 0x218C, opcode::OP_Invalid },
    { 0x218D, opcode::OP_Invalid },
    { 0x218E, opcode::OP_LessThan },
    { 0x218F, opcode::OP_JumpOnTrue },
    { 0x2190, opcode::OP_EvalLocalVariableRefCached },
    { 0x2191, opcode::OP_SetVariableField },
    { 0x2192, opcode::OP_New },
    { 0x2193, opcode::OP_RealWait },
    { 0x2194, opcode::OP_Invalid },
    { 0x2195, opcode::OP_GetIString },
    { 0x2196, opcode::OP_Invalid },
    { 0x2197, opcode::OP_ScriptThreadCallClass },
    { 0x2198, opcode::OP_ScriptMethodThreadCall },
    { 0x2199, opcode::OP_EvalArray },
    { 0x219A, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x219B, opcode::OP_ScriptFunctionCallPointer },
    { 0x219C, opcode::OP_Invalid },
    { 0x219D, opcode::OP_Invalid },
    { 0x219E, opcode::OP_SuperEqual },
    { 0x219F, opcode::OP_FirstArrayKey },
    { 0x21A0, opcode::OP_Invalid },
    { 0x21A1, opcode::OP_Invalid },
    { 0x21A2, opcode::OP_Invalid },
    { 0x21A3, opcode::OP_Invalid },
    { 0x21A4, opcode::OP_SafeDecTop },
    { 0x21A5, opcode::OP_GetZero },
    { 0x21A6, opcode::OP_GetWorld },
    { 0x21A7, opcode::OP_EmptyArray },
    { 0x21A8, opcode::OP_SuperEqual },
    { 0x21A9, opcode::OP_EvalLocalVariableCached },
    { 0x21AA, opcode::OP_Invalid },
    { 0x21AB, opcode::OP_CastBool },
    { 0x21AC, opcode::OP_Wait },
    { 0x21AD, opcode::OP_GreaterThan },
    { 0x21AE, opcode::OP_GetSelfObject },
    { 0x21AF, opcode::OP_Invalid },
    { 0x21B0, opcode::OP_ScriptMethodCallPointer },
    { 0x21B1, opcode::OP_JumpOnFalseExpr },
    { 0x21B2, opcode::OP_LevelEvalFieldVariableRef },
    { 0x21B3, opcode::OP_JumpOnTrueExpr },
    { 0x21B4, opcode::OP_LessThanOrEqualTo },
    { 0x21B5, opcode::OP_GetUndefined },
    { 0x21B6, opcode::OP_Invalid },
    { 0x21B7, opcode::OP_SelfEvalFieldVariable },
    { 0x21B8, opcode::OP_JumpOnFalseExpr },
    { 0x21B9, opcode::OP_Invalid },
    { 0x21BA, opcode::OP_JumpOnTrueExpr },
    { 0x21BB, opcode::OP_Switch },
    { 0x21BC, opcode::OP_GetAnimation },
    { 0x21BD, opcode::OP_ScriptThreadCallClass },
    { 0x21BE, opcode::OP_Invalid },
    { 0x21BF, opcode::OP_Jump },
    { 0x21C0, opcode::OP_Invalid },
    { 0x21C1, opcode::OP_Invalid },
    { 0x21C2, opcode::OP_Invalid },
    { 0x21C3, opcode::OP_GetSelfObject },
    { 0x21C4, opcode::OP_ClearFieldVariable },
    { 0x21C5, opcode::OP_GetLevelObject },
    { 0x21C6, opcode::OP_EvalLocalVariableRefCached },
    { 0x21C7, opcode::OP_VectorScale },
    { 0x21C8, opcode::OP_Invalid },
    { 0x21C9, opcode::OP_Invalid },
    { 0x21CA, opcode::OP_GetClassesObject },
    { 0x21CB, opcode::OP_Invalid },
    { 0x21CC, opcode::OP_JumpOnTrue },
    { 0x21CD, opcode::OP_FirstArrayKey },
    { 0x21CE, opcode::OP_GetUnsignedShort },
    { 0x21CF, opcode::OP_Invalid },
    { 0x21D0, opcode::OP_GetIString },
    { 0x21D1, opcode::OP_Invalid },
    { 0x21D2, opcode::OP_GetNegByte },
    { 0x21D3, opcode::OP_Invalid },
    { 0x21D4, opcode::OP_EvalArray },
    { 0x21D5, opcode::OP_Wait },
    { 0x21D6, opcode::OP_GetUintptr },
    { 0x21D7, opcode::OP_GetUintptr },
    { 0x21D8, opcode::OP_ScriptMethodCallPointer },
    { 0x21D9, opcode::OP_CallBuiltinMethod },
    { 0x21DA, opcode::OP_Invalid },
    { 0x21DB, opcode::OP_GetZero },
    { 0x21DC, opcode::OP_WaitTill },
    { 0x21DD, opcode::OP_JumpOnTrueExpr },
    { 0x21DE, opcode::OP_Bit_And },
    { 0x21DF, opcode::OP_GetSelfObject },
    { 0x21E0, opcode::OP_Invalid },
    { 0x21E1, opcode::OP_SelfEvalFieldVariable },
    { 0x21E2, opcode::OP_Inc },
    { 0x21E3, opcode::OP_Invalid },
    { 0x21E4, opcode::OP_Invalid },
    { 0x21E5, opcode::OP_SuperEqual },
    { 0x21E6, opcode::OP_Invalid },
    { 0x21E7, opcode::OP_Equal },
    { 0x21E8, opcode::OP_Notify },
    { 0x21E9, opcode::OP_Jump },
    { 0x21EA, opcode::OP_GetString },
    { 0x21EB, opcode::OP_GetWorldObject },
    { 0x21EC, opcode::OP_EmptyArray },
    { 0x21ED, opcode::OP_VectorScale },
    { 0x21EE, opcode::OP_EvalLocalVariableCached },
    { 0x21EF, opcode::OP_GetIString },
    { 0x21F0, opcode::OP_Invalid },
    { 0x21F1, opcode::OP_GetClassesObject },
    { 0x21F2, opcode::OP_Dec },
    { 0x21F3, opcode::OP_EvalLocalVariableCached },
    { 0x21F4, opcode::OP_GreaterThan },
    { 0x21F5, opcode::OP_Bit_Xor },
    { 0x21F6, opcode::OP_ScriptMethodCallPointer },
    { 0x21F7, opcode::OP_Divide },
    { 0x21F8, opcode::OP_GetUndefined },
    { 0x21F9, opcode::OP_JumpOnTrueExpr },
    { 0x21FA, opcode::OP_GetNegUnsignedShort },
    { 0x21FB, opcode::OP_Invalid },
    { 0x21FC, opcode::OP_SelfEvalFieldVariableRef },
    { 0x21FD, opcode::OP_Invalid },
    { 0x21FE, opcode::OP_GetSelf },
    { 0x21FF, opcode::OP_GreaterThanOrEqualTo },
    { 0x2200, opcode::OP_Switch },
    { 0x2201, opcode::OP_LevelEvalFieldVariable },
    { 0x2202, opcode::OP_GetFloat },
    { 0x2203, opcode::OP_Invalid },
    { 0x2204, opcode::OP_JumpOnTrueExpr },
    { 0x2205, opcode::OP_LevelEvalFieldVariableRef },
    { 0x2206, opcode::OP_ScriptFunctionCall },
    { 0x2207, opcode::OP_Invalid },
    { 0x2208, opcode::OP_SelfEvalFieldVariable },
    { 0x2209, opcode::OP_Wait },
    { 0x220A, opcode::OP_ScriptThreadCallPointer },
    { 0x220B, opcode::OP_Invalid },
    { 0x220C, opcode::OP_Invalid },
    { 0x220D, opcode::OP_IsDefined },
    { 0x220E, opcode::OP_EvalArray },
    { 0x220F, opcode::OP_JumpOnFalse },
    { 0x2210, opcode::OP_Invalid },
    { 0x2211, opcode::OP_Invalid },
    { 0x2212, opcode::OP_Invalid },
    { 0x2213, opcode::OP_Invalid },
    { 0x2214, opcode::OP_Invalid },
    { 0x2215, opcode::OP_EndOn },
    { 0x2216, opcode::OP_Invalid },
    { 0x2217, opcode::OP_Invalid },
    { 0x2218, opcode::OP_Wait },
    { 0x2219, opcode::OP_GetUintptr },
    { 0x221A, opcode::OP_DecTop },
    { 0x221B, opcode::OP_SafeCreateLocalVariables },
    { 0x221C, opcode::OP_GetAnimObject },
    { 0x221D, opcode::OP_Return },
    { 0x221E, opcode::OP_JumpOnTrue },
    { 0x221F, opcode::OP_Invalid },
    { 0x2220, opcode::OP_Invalid },
    { 0x2221, opcode::OP_SelfEvalFieldVariable },
    { 0x2222, opcode::OP_RealWait },
    { 0x2223, opcode::OP_GetHash },
    { 0x2224, opcode::OP_GetLevelObject },
    { 0x2225, opcode::OP_FirstArrayKey },
    { 0x2226, opcode::OP_EvalArray },
    { 0x2227, opcode::OP_Invalid },
    { 0x2228, opcode::OP_Invalid },
    { 0x2229, opcode::OP_GetFloat },
    { 0x222A, opcode::OP_Invalid },
    { 0x222B, opcode::OP_Invalid },
    { 0x222C, opcode::OP_EvalArrayRef },
    { 0x222D, opcode::OP_EvalArray },
    { 0x222E, opcode::OP_Invalid },
    { 0x222F, opcode::OP_GetZero },
    { 0x2230, opcode::OP_ScriptFunctionCallPointer },
    { 0x2231, opcode::OP_Invalid },
    { 0x2232, opcode::OP_GetNegUnsignedShort },
    { 0x2233, opcode::OP_VectorConstant },
    { 0x2234, opcode::OP_JumpOnFalse },
    { 0x2235, opcode::OP_EndOn },
    { 0x2236, opcode::OP_GetLevelObject },
    { 0x2237, opcode::OP_Return },
    { 0x2238, opcode::OP_IsDefined },
    { 0x2239, opcode::OP_Invalid },
    { 0x223A, opcode::OP_Invalid },
    { 0x223B, opcode::OP_Invalid },
    { 0x223C, opcode::OP_Invalid },
    { 0x223D, opcode::OP_JumpOnFalse },
    { 0x223E, opcode::OP_Invalid },
    { 0x223F, opcode::OP_Invalid },
    { 0x2240, opcode::OP_GetSelfObject },
    { 0x2241, opcode::OP_ScriptMethodThreadCall },
    { 0x2242, opcode::OP_Bit_Xor },
    { 0x2243, opcode::OP_LessThanOrEqualTo },
    { 0x2244, opcode::OP_Invalid },
    { 0x2245, opcode::OP_SelfEvalFieldVariable },
    { 0x2246, opcode::OP_Return },
    { 0x2247, opcode::OP_GetWorld },
    { 0x2248, opcode::OP_GetString },
    { 0x2249, opcode::OP_SuperEqual },
    { 0x224A, opcode::OP_VectorConstant },
    { 0x224B, opcode::OP_Switch },
    { 0x224C, opcode::OP_Invalid },
    { 0x224D, opcode::OP_DecTop },
    { 0x224E, opcode::OP_Bit_Xor },
    { 0x224F, opcode::OP_JumpOnTrueExpr },
    { 0x2250, opcode::OP_Notify },
    { 0x2251, opcode::OP_SafeSetVariableFieldCached },
    { 0x2252, opcode::OP_Return },
    { 0x2253, opcode::OP_Invalid },
    { 0x2254, opcode::OP_Invalid },
    { 0x2255, opcode::OP_SizeOf },
    { 0x2256, opcode::OP_Invalid },
    { 0x2257, opcode::OP_Equal },
    { 0x2258, opcode::OP_GetUnsignedShort },
    { 0x2259, opcode::OP_Invalid },
    { 0x225A, opcode::OP_GetInteger },
    { 0x225B, opcode::OP_Invalid },
    { 0x225C, opcode::OP_Invalid },
    { 0x225D, opcode::OP_GetFunction },
    { 0x225E, opcode::OP_SuperNotEqual },
    { 0x225F, opcode::OP_Bit_Xor },
    { 0x2260, opcode::OP_Invalid },
    { 0x2261, opcode::OP_Minus },
    { 0x2262, opcode::OP_BoolNot },
    { 0x2263, opcode::OP_Invalid },
    { 0x2264, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x2265, opcode::OP_Invalid },
    { 0x2266, opcode::OP_Invalid },
    { 0x2267, opcode::OP_BoolComplement },
    { 0x2268, opcode::OP_Modulus },
    { 0x2269, opcode::OP_GetLevel },
    { 0x226A, opcode::OP_Invalid },
    { 0x226B, opcode::OP_Invalid },
    { 0x226C, opcode::OP_Invalid },
    { 0x226D, opcode::OP_VectorScale },
    { 0x226E, opcode::OP_ShiftRight },
    { 0x226F, opcode::OP_Invalid },
    { 0x2270, opcode::OP_Invalid },
    { 0x2271, opcode::OP_Invalid },
    { 0x2272, opcode::OP_Invalid },
    { 0x2273, opcode::OP_JumpOnTrue },
    { 0x2274, opcode::OP_GetInteger },
    { 0x2275, opcode::OP_Invalid },
    { 0x2276, opcode::OP_Invalid },
    { 0x2277, opcode::OP_Invalid },
    { 0x2278, opcode::OP_ScriptThreadCallClass },
    { 0x2279, opcode::OP_SuperEqual },
    { 0x227A, opcode::OP_JumpOnFalse },
    { 0x227B, opcode::OP_GetGameRef },
    { 0x227C, opcode::OP_ShiftRight },
    { 0x227D, opcode::OP_GetClassesObject },
    { 0x227E, opcode::OP_GetGame },
    { 0x227F, opcode::OP_Invalid },
    { 0x2280, opcode::OP_SuperEqual },
    { 0x2281, opcode::OP_GetAPIFunction },
    { 0x2282, opcode::OP_Invalid },
    { 0x2283, opcode::OP_SuperNotEqual },
    { 0x2284, opcode::OP_Invalid },
    { 0x2285, opcode::OP_Invalid },
    { 0x2286, opcode::OP_GetSelfObject },
    { 0x2287, opcode::OP_ClearArray },
    { 0x2288, opcode::OP_SizeOf },
    { 0x2289, opcode::OP_RealWait },
    { 0x228A, opcode::OP_ScriptThreadCall },
    { 0x228B, opcode::OP_Invalid },
    { 0x228C, opcode::OP_GetFloat },
    { 0x228D, opcode::OP_Invalid },
    { 0x228E, opcode::OP_Return },
    { 0x228F, opcode::OP_ShiftRight },
    { 0x2290, opcode::OP_SizeOf },
    { 0x2291, opcode::OP_GetInteger },
    { 0x2292, opcode::OP_GetSelfObject },
    { 0x2293, opcode::OP_GetAnimation },
    { 0x2294, opcode::OP_GetString },
    { 0x2295, opcode::OP_Invalid },
    { 0x2296, opcode::OP_Invalid },
    { 0x2297, opcode::OP_SizeOf },
    { 0x2298, opcode::OP_ScriptThreadCall },
    { 0x2299, opcode::OP_SafeDecTop },
    { 0x229A, opcode::OP_Bit_Xor },
    { 0x229B, opcode::OP_Invalid },
    { 0x229C, opcode::OP_RealWait },
    { 0x229D, opcode::OP_Invalid },
    { 0x229E, opcode::OP_Invalid },
    { 0x229F, opcode::OP_Notify },
    { 0x22A0, opcode::OP_Wait },
    { 0x22A1, opcode::OP_GetZero },
    { 0x22A2, opcode::OP_Invalid },
    { 0x22A3, opcode::OP_JumpOnTrue },
    { 0x22A4, opcode::OP_Invalid },
    { 0x22A5, opcode::OP_Multiply },
    { 0x22A6, opcode::OP_ShiftRight },
    { 0x22A7, opcode::OP_FirstArrayKey },
    { 0x22A8, opcode::OP_GetUndefined },
    { 0x22A9, opcode::OP_EvalArray },
    { 0x22AA, opcode::OP_ScriptMethodThreadCall },
    { 0x22AB, opcode::OP_EndOn },
    { 0x22AC, opcode::OP_Invalid },
    { 0x22AD, opcode::OP_Invalid },
    { 0x22AE, opcode::OP_Invalid },
    { 0x22AF, opcode::OP_Plus },
    { 0x22B0, opcode::OP_Invalid },
    { 0x22B1, opcode::OP_GetSelf },
    { 0x22B2, opcode::OP_JumpOnFalse },
    { 0x22B3, opcode::OP_ScriptThreadCall },
    { 0x22B4, opcode::OP_FirstArrayKey },
    { 0x22B5, opcode::OP_Invalid },
    { 0x22B6, opcode::OP_Invalid },
    { 0x22B7, opcode::OP_ScriptMethodThreadCall },
    { 0x22B8, opcode::OP_SelfEvalFieldVariable },
    { 0x22B9, opcode::OP_CallBuiltinMethod },
    { 0x22BA, opcode::OP_Invalid },
    { 0x22BB, opcode::OP_LessThan },
    { 0x22BC, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x22BD, opcode::OP_Invalid },
    { 0x22BE, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x22BF, opcode::OP_GetClassesObject },
    { 0x22C0, opcode::OP_ScriptThreadCallClass },
    { 0x22C1, opcode::OP_ScriptMethodCallPointer },
    { 0x22C2, opcode::OP_GetLevel },
    { 0x22C3, opcode::OP_CastFieldObject },
    { 0x22C4, opcode::OP_SuperNotEqual },
    { 0x22C5, opcode::OP_GetIString },
    { 0x22C6, opcode::OP_Invalid },
    { 0x22C7, opcode::OP_Vector },
    { 0x22C8, opcode::OP_Invalid },
    { 0x22C9, opcode::OP_WaitTillFrameEnd },
    { 0x22CA, opcode::OP_EvalLocalVariableCached },
    { 0x22CB, opcode::OP_Invalid },
    { 0x22CC, opcode::OP_Invalid },
    { 0x22CD, opcode::OP_Invalid },
    { 0x22CE, opcode::OP_Multiply },
    { 0x22CF, opcode::OP_JumpOnTrueExpr },
    { 0x22D0, opcode::OP_EvalLocalVariableRefCached },
    { 0x22D1, opcode::OP_ProfileStop },
    { 0x22D2, opcode::OP_ClearFieldVariable },
    { 0x22D3, opcode::OP_GetUndefined },
    { 0x22D4, opcode::OP_GetIString },
    { 0x22D5, opcode::OP_WaitTillMatch },
    { 0x22D6, opcode::OP_GetClasses },
    { 0x22D7, opcode::OP_JumpOnTrue },
    { 0x22D8, opcode::OP_NextArrayKey },
    { 0x22D9, opcode::OP_Divide },
    { 0x22DA, opcode::OP_GetLevel },
    { 0x22DB, opcode::OP_EndOn },
    { 0x22DC, opcode::OP_ClearFieldVariable },
    { 0x22DD, opcode::OP_EvalFieldVariableRef },
    { 0x22DE, opcode::OP_Dec },
    { 0x22DF, opcode::OP_GetVector },
    { 0x22E0, opcode::OP_JumpOnFalseExpr },
    { 0x22E1, opcode::OP_GetGame },
    { 0x22E2, opcode::OP_Invalid },
    { 0x22E3, opcode::OP_GetWorldObject },
    { 0x22E4, opcode::OP_Invalid },
    { 0x22E5, opcode::OP_EndOn },
    { 0x22E6, opcode::OP_VectorConstant },
    { 0x22E7, opcode::OP_Invalid },
    { 0x22E8, opcode::OP_SelfEvalFieldVariableRef },
    { 0x22E9, opcode::OP_Invalid },
    { 0x22EA, opcode::OP_ScriptThreadCall },
    { 0x22EB, opcode::OP_New },
    { 0x22EC, opcode::OP_GetAnim },
    { 0x22ED, opcode::OP_Dec },
    { 0x22EE, opcode::OP_LessThan },
    { 0x22EF, opcode::OP_Invalid },
    { 0x22F0, opcode::OP_WaitTillFrameEnd },
    { 0x22F1, opcode::OP_Invalid },
    { 0x22F2, opcode::OP_GetAnim },
    { 0x22F3, opcode::OP_Invalid },
    { 0x22F4, opcode::OP_Invalid },
    { 0x22F5, opcode::OP_Bit_Xor },
    { 0x22F6, opcode::OP_Invalid },
    { 0x22F7, opcode::OP_Invalid },
    { 0x22F8, opcode::OP_LevelEvalFieldVariableRef },
    { 0x22F9, opcode::OP_Minus },
    { 0x22FA, opcode::OP_EvalLocalVariableRefCached },
    { 0x22FB, opcode::OP_LessThan },
    { 0x22FC, opcode::OP_NextArrayKey },
    { 0x22FD, opcode::OP_GetWorld },
    { 0x22FE, opcode::OP_Invalid },
    { 0x22FF, opcode::OP_SafeSetVariableFieldCached },
    { 0x2300, opcode::OP_Invalid },
    { 0x2301, opcode::OP_Bit_And },
    { 0x2302, opcode::OP_EndSwitch },
    { 0x2303, opcode::OP_Invalid },
    { 0x2304, opcode::OP_ScriptMethodCallPointer },
    { 0x2305, opcode::OP_Invalid },
    { 0x2306, opcode::OP_GetIString },
    { 0x2307, opcode::OP_RealWait },
    { 0x2308, opcode::OP_GetString },
    { 0x2309, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x230A, opcode::OP_Invalid },
    { 0x230B, opcode::OP_GetSelfObject },
    { 0x230C, opcode::OP_Invalid },
    { 0x230D, opcode::OP_EvalFieldVariable },
    { 0x230E, opcode::OP_GetNegByte },
    { 0x230F, opcode::OP_GreaterThan },
    { 0x2310, opcode::OP_ShiftRight },
    { 0x2311, opcode::OP_NextArrayKey },
    { 0x2312, opcode::OP_WaitTillFrameEnd },
    { 0x2313, opcode::OP_Invalid },
    { 0x2314, opcode::OP_Invalid },
    { 0x2315, opcode::OP_EvalLocalVariableCached },
    { 0x2316, opcode::OP_Invalid },
    { 0x2317, opcode::OP_SizeOf },
    { 0x2318, opcode::OP_Invalid },
    { 0x2319, opcode::OP_Invalid },
    { 0x231A, opcode::OP_EvalFieldVariable },
    { 0x231B, opcode::OP_GetNegByte },
    { 0x231C, opcode::OP_JumpOnFalse },
    { 0x231D, opcode::OP_SelfEvalFieldVariable },
    { 0x231E, opcode::OP_Invalid },
    { 0x231F, opcode::OP_Invalid },
    { 0x2320, opcode::OP_WaitTill },
    { 0x2321, opcode::OP_GetIString },
    { 0x2322, opcode::OP_SafeDecTop },
    { 0x2323, opcode::OP_GetVector },
    { 0x2324, opcode::OP_GetGame },
    { 0x2325, opcode::OP_Invalid },
    { 0x2326, opcode::OP_ScriptFunctionCall },
    { 0x2327, opcode::OP_ScriptFunctionCallPointer },
    { 0x2328, opcode::OP_GetSelfObject },
    { 0x2329, opcode::OP_Invalid },
    { 0x232A, opcode::OP_VectorConstant },
    { 0x232B, opcode::OP_Invalid },
    { 0x232C, opcode::OP_GetAPIFunction },
    { 0x232D, opcode::OP_Invalid },
    { 0x232E, opcode::OP_ScriptThreadCallPointer },
    { 0x232F, opcode::OP_SafeDecTop },
    { 0x2330, opcode::OP_GetUintptr },
    { 0x2331, opcode::OP_ShiftLeft },
    { 0x2332, opcode::OP_GetUnsignedShort },
    { 0x2333, opcode::OP_Bit_Xor },
    { 0x2334, opcode::OP_EmptyArray },
    { 0x2335, opcode::OP_Invalid },
    { 0x2336, opcode::OP_WaitTillFrameEnd },
    { 0x2337, opcode::OP_BoolNot },
    { 0x2338, opcode::OP_Invalid },
    { 0x2339, opcode::OP_DecTop },
    { 0x233A, opcode::OP_GetWorldObject },
    { 0x233B, opcode::OP_Return },
    { 0x233C, opcode::OP_ProfileStart },
    { 0x233D, opcode::OP_VectorConstant },
    { 0x233E, opcode::OP_Invalid },
    { 0x233F, opcode::OP_GetIString },
    { 0x2340, opcode::OP_ProfileStop },
    { 0x2341, opcode::OP_JumpOnFalseExpr },
    { 0x2342, opcode::OP_Invalid },
    { 0x2343, opcode::OP_Invalid },
    { 0x2344, opcode::OP_Invalid },
    { 0x2345, opcode::OP_Invalid },
    { 0x2346, opcode::OP_SuperNotEqual },
    { 0x2347, opcode::OP_ScriptMethodThreadCall },
    { 0x2348, opcode::OP_ScriptMethodCall },
    { 0x2349, opcode::OP_Invalid },
    { 0x234A, opcode::OP_Invalid },
    { 0x234B, opcode::OP_EvalLocalVariableRefCached },
    { 0x234C, opcode::OP_Invalid },
    { 0x234D, opcode::OP_Invalid },
    { 0x234E, opcode::OP_Invalid },
    { 0x234F, opcode::OP_Invalid },
    { 0x2350, opcode::OP_Invalid },
    { 0x2351, opcode::OP_Invalid },
    { 0x2352, opcode::OP_IsDefined },
    { 0x2353, opcode::OP_VectorScale },
    { 0x2354, opcode::OP_JumpOnTrueExpr },
    { 0x2355, opcode::OP_Invalid },
    { 0x2356, opcode::OP_GetString },
    { 0x2357, opcode::OP_Divide },
    { 0x2358, opcode::OP_Bit_And },
    { 0x2359, opcode::OP_Invalid },
    { 0x235A, opcode::OP_JumpOnFalse },
    { 0x235B, opcode::OP_Invalid },
    { 0x235C, opcode::OP_Invalid },
    { 0x235D, opcode::OP_SuperNotEqual },
    { 0x235E, opcode::OP_Invalid },
    { 0x235F, opcode::OP_LevelEvalFieldVariable },
    { 0x2360, opcode::OP_ScriptThreadCallPointer },
    { 0x2361, opcode::OP_WaitTillFrameEnd },
    { 0x2362, opcode::OP_GetWorldObject },
    { 0x2363, opcode::OP_Invalid },
    { 0x2364, opcode::OP_WaitTillFrameEnd },
    { 0x2365, opcode::OP_Invalid },
    { 0x2366, opcode::OP_Invalid },
    { 0x2367, opcode::OP_Invalid },
    { 0x2368, opcode::OP_Invalid },
    { 0x2369, opcode::OP_EvalArrayRef },
    { 0x236A, opcode::OP_Invalid },
    { 0x236B, opcode::OP_DevblockBegin },
    { 0x236C, opcode::OP_Invalid },
    { 0x236D, opcode::OP_GreaterThan },
    { 0x236E, opcode::OP_GetClassesObject },
    { 0x236F, opcode::OP_Invalid },
    { 0x2370, opcode::OP_Invalid },
    { 0x2371, opcode::OP_New },
    { 0x2372, opcode::OP_GreaterThan },
    { 0x2373, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x2374, opcode::OP_WaitTillMatch },
    { 0x2375, opcode::OP_Invalid },
    { 0x2376, opcode::OP_LessThan },
    { 0x2377, opcode::OP_Invalid },
    { 0x2378, opcode::OP_Return },
    { 0x2379, opcode::OP_Invalid },
    { 0x237A, opcode::OP_GetGame },
    { 0x237B, opcode::OP_GetWorldObject },
    { 0x237C, opcode::OP_Invalid },
    { 0x237D, opcode::OP_Invalid },
    { 0x237E, opcode::OP_Invalid },
    { 0x237F, opcode::OP_ShiftLeft },
    { 0x2380, opcode::OP_GetAPIFunction },
    { 0x2381, opcode::OP_GreaterThan },
    { 0x2382, opcode::OP_EvalLocalVariableCached },
    { 0x2383, opcode::OP_Bit_And },
    { 0x2384, opcode::OP_Invalid },
    { 0x2385, opcode::OP_Switch },
    { 0x2386, opcode::OP_Invalid },
    { 0x2387, opcode::OP_GetSelf },
    { 0x2388, opcode::OP_Invalid },
    { 0x2389, opcode::OP_SelfEvalFieldVariable },
    { 0x238A, opcode::OP_DecTop },
    { 0x238B, opcode::OP_GetClassesObject },
    { 0x238C, opcode::OP_GetZero },
    { 0x238D, opcode::OP_Invalid },
    { 0x238E, opcode::OP_Minus },
    { 0x238F, opcode::OP_GetFloat },
    { 0x2390, opcode::OP_SelfEvalFieldVariableRef },
    { 0x2391, opcode::OP_Invalid },
    { 0x2392, opcode::OP_JumpOnTrue },
    { 0x2393, opcode::OP_Invalid },
    { 0x2394, opcode::OP_GetAnim },
    { 0x2395, opcode::OP_GetClasses },
    { 0x2396, opcode::OP_Invalid },
    { 0x2397, opcode::OP_Bit_Or },
    { 0x2398, opcode::OP_Invalid },
    { 0x2399, opcode::OP_Notify },
    { 0x239A, opcode::OP_ScriptThreadCallPointer },
    { 0x239B, opcode::OP_NotEqual },
    { 0x239C, opcode::OP_Invalid },
    { 0x239D, opcode::OP_Bit_Xor },
    { 0x239E, opcode::OP_ShiftLeft },
    { 0x239F, opcode::OP_WaitTill },
    { 0x23A0, opcode::OP_EmptyArray },
    { 0x23A1, opcode::OP_GreaterThan },
    { 0x23A2, opcode::OP_SuperEqual },
    { 0x23A3, opcode::OP_ShiftRight },
    { 0x23A4, opcode::OP_EvalLocalVariableRefCached },
    { 0x23A5, opcode::OP_EvalLocalVariableCached },
    { 0x23A6, opcode::OP_GetFunction },
    { 0x23A7, opcode::OP_Bit_Xor },
    { 0x23A8, opcode::OP_SelfEvalFieldVariable },
    { 0x23A9, opcode::OP_Invalid },
    { 0x23AA, opcode::OP_ScriptMethodCall },
    { 0x23AB, opcode::OP_GetSelfObject },
    { 0x23AC, opcode::OP_Invalid },
    { 0x23AD, opcode::OP_Invalid },
    { 0x23AE, opcode::OP_GetSelf },
    { 0x23AF, opcode::OP_Invalid },
    { 0x23B0, opcode::OP_GetString },
    { 0x23B1, opcode::OP_NotEqual },
    { 0x23B2, opcode::OP_Invalid },
    { 0x23B3, opcode::OP_Bit_And },
    { 0x23B4, opcode::OP_SelfEvalFieldVariable },
    { 0x23B5, opcode::OP_ScriptThreadCall },
    { 0x23B6, opcode::OP_CastBool },
    { 0x23B7, opcode::OP_GetFloat },
    { 0x23B8, opcode::OP_LessThan },
    { 0x23B9, opcode::OP_Jump },
    { 0x23BA, opcode::OP_SetVariableField },
    { 0x23BB, opcode::OP_EvalArray },
    { 0x23BC, opcode::OP_Invalid },
    { 0x23BD, opcode::OP_EndSwitch },
    { 0x23BE, opcode::OP_Modulus },
    { 0x23BF, opcode::OP_Invalid },
    { 0x23C0, opcode::OP_WaitTill },
    { 0x23C1, opcode::OP_Invalid },
    { 0x23C2, opcode::OP_Invalid },
    { 0x23C3, opcode::OP_Invalid },
    { 0x23C4, opcode::OP_CallBuiltinMethod },
    { 0x23C5, opcode::OP_GetUintptr },
    { 0x23C6, opcode::OP_Modulus },
    { 0x23C7, opcode::OP_LessThan },
    { 0x23C8, opcode::OP_Invalid },
    { 0x23C9, opcode::OP_Invalid },
    { 0x23CA, opcode::OP_GetAnim },
    { 0x23CB, opcode::OP_GetSelfObject },
    { 0x23CC, opcode::OP_GetFloat },
    { 0x23CD, opcode::OP_NextArrayKey },
    { 0x23CE, opcode::OP_Invalid },
    { 0x23CF, opcode::OP_ScriptFunctionCall },
    { 0x23D0, opcode::OP_FirstArrayKey },
    { 0x23D1, opcode::OP_Invalid },
    { 0x23D2, opcode::OP_Invalid },
    { 0x23D3, opcode::OP_ScriptMethodThreadCall },
    { 0x23D4, opcode::OP_ClearArray },
    { 0x23D5, opcode::OP_BoolNot },
    { 0x23D6, opcode::OP_SafeCreateLocalVariables },
    { 0x23D7, opcode::OP_Invalid },
    { 0x23D8, opcode::OP_JumpOnTrue },
    { 0x23D9, opcode::OP_EmptyArray },
    { 0x23DA, opcode::OP_ScriptThreadCallClass },
    { 0x23DB, opcode::OP_CallBuiltinMethod },
    { 0x23DC, opcode::OP_Invalid },
    { 0x23DD, opcode::OP_GetUintptr },
    { 0x23DE, opcode::OP_GetWorld },
    { 0x23DF, opcode::OP_Dec },
    { 0x23E0, opcode::OP_WaitTill },
    { 0x23E1, opcode::OP_NextArrayKey },
    { 0x23E2, opcode::OP_Invalid },
    { 0x23E3, opcode::OP_GetFunction },
    { 0x23E4, opcode::OP_ScriptFunctionCall },
    { 0x23E5, opcode::OP_Invalid },
    { 0x23E6, opcode::OP_Invalid },
    { 0x23E7, opcode::OP_ScriptThreadCallPointer },
    { 0x23E8, opcode::OP_GetAnimObject },
    { 0x23E9, opcode::OP_EvalLocalVariableRefCached },
    { 0x23EA, opcode::OP_Multiply },
    { 0x23EB, opcode::OP_Invalid },
    { 0x23EC, opcode::OP_Invalid },
    { 0x23ED, opcode::OP_Invalid },
    { 0x23EE, opcode::OP_GetLevel },
    { 0x23EF, opcode::OP_ScriptThreadCall },
    { 0x23F0, opcode::OP_Invalid },
    { 0x23F1, opcode::OP_NextArrayKey },
    { 0x23F2, opcode::OP_Invalid },
    { 0x23F3, opcode::OP_Invalid },
    { 0x23F4, opcode::OP_Invalid },
    { 0x23F5, opcode::OP_FirstArrayKey },
    { 0x23F6, opcode::OP_Return },
    { 0x23F7, opcode::OP_Invalid },
    { 0x23F8, opcode::OP_RealWait },
    { 0x23F9, opcode::OP_JumpOnTrue },
    { 0x23FA, opcode::OP_GreaterThanOrEqualTo },
    { 0x23FB, opcode::OP_GetWorldObject },
    { 0x23FC, opcode::OP_Invalid },
    { 0x23FD, opcode::OP_Invalid },
    { 0x23FE, opcode::OP_Invalid },
    { 0x23FF, opcode::OP_ScriptMethodThreadCall },
    { 0x2400, opcode::OP_Invalid },
    { 0x2401, opcode::OP_GetSelf },
    { 0x2402, opcode::OP_Invalid },
    { 0x2403, opcode::OP_EndSwitch },
    { 0x2404, opcode::OP_GetNegUnsignedShort },
    { 0x2405, opcode::OP_DevblockBegin },
    { 0x2406, opcode::OP_Vector },
    { 0x2407, opcode::OP_Invalid },
    { 0x2408, opcode::OP_Invalid },
    { 0x2409, opcode::OP_ClearFieldVariable },
    { 0x240A, opcode::OP_Invalid },
    { 0x240B, opcode::OP_ShiftLeft },
    { 0x240C, opcode::OP_GetLevel },
    { 0x240D, opcode::OP_EvalFieldVariable },
    { 0x240E, opcode::OP_VectorScale },
    { 0x240F, opcode::OP_EvalArrayRef },
    { 0x2410, opcode::OP_GetClasses },
    { 0x2411, opcode::OP_Invalid },
    { 0x2412, opcode::OP_GetFloat },
    { 0x2413, opcode::OP_EvalLocalVariableRefCached },
    { 0x2414, opcode::OP_SizeOf },
    { 0x2415, opcode::OP_ScriptFunctionCallPointer },
    { 0x2416, opcode::OP_Switch },
    { 0x2417, opcode::OP_GetUndefined },
    { 0x2418, opcode::OP_DecTop },
    { 0x2419, opcode::OP_Invalid },
    { 0x241A, opcode::OP_ScriptThreadCallPointer },
    { 0x241B, opcode::OP_GetGame },
    { 0x241C, opcode::OP_Invalid },
    { 0x241D, opcode::OP_Invalid },
    { 0x241E, opcode::OP_ProfileStop },
    { 0x241F, opcode::OP_EvalFieldVariable },
    { 0x2420, opcode::OP_JumpOnTrue },
    { 0x2421, opcode::OP_Modulus },
    { 0x2422, opcode::OP_GreaterThan },
    { 0x2423, opcode::OP_Invalid },
    { 0x2424, opcode::OP_Vector },
    { 0x2425, opcode::OP_Inc },
    { 0x2426, opcode::OP_Invalid },
    { 0x2427, opcode::OP_ShiftLeft },
    { 0x2428, opcode::OP_LessThan },
    { 0x2429, opcode::OP_Invalid },
    { 0x242A, opcode::OP_Invalid },
    { 0x242B, opcode::OP_GetFunction },
    { 0x242C, opcode::OP_EvalLocalVariableCached },
    { 0x242D, opcode::OP_CastFieldObject },
    { 0x242E, opcode::OP_GetUintptr },
    { 0x242F, opcode::OP_Invalid },
    { 0x2430, opcode::OP_Invalid },
    { 0x2431, opcode::OP_CallBuiltinMethod },
    { 0x2432, opcode::OP_ShiftRight },
    { 0x2433, opcode::OP_Invalid },
    { 0x2434, opcode::OP_NotEqual },
    { 0x2435, opcode::OP_Invalid },
    { 0x2436, opcode::OP_Invalid },
    { 0x2437, opcode::OP_EvalArrayRef },
    { 0x2438, opcode::OP_Invalid },
    { 0x2439, opcode::OP_Invalid },
    { 0x243A, opcode::OP_VectorConstant },
    { 0x243B, opcode::OP_EvalArray },
    { 0x243C, opcode::OP_Divide },
    { 0x243D, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x243E, opcode::OP_ProfileStart },
    { 0x243F, opcode::OP_WaitTill },
    { 0x2440, opcode::OP_Invalid },
    { 0x2441, opcode::OP_SetVariableField },
    { 0x2442, opcode::OP_Wait },
    { 0x2443, opcode::OP_ProfileStop },
    { 0x2444, opcode::OP_Invalid },
    { 0x2445, opcode::OP_GetClasses },
    { 0x2446, opcode::OP_Invalid },
    { 0x2447, opcode::OP_BoolNot },
    { 0x2448, opcode::OP_Invalid },
    { 0x2449, opcode::OP_Minus },
    { 0x244A, opcode::OP_Invalid },
    { 0x244B, opcode::OP_Dec },
    { 0x244C, opcode::OP_EvalArray },
    { 0x244D, opcode::OP_CastFieldObject },
    { 0x244E, opcode::OP_Invalid },
    { 0x244F, opcode::OP_DevblockBegin },
    { 0x2450, opcode::OP_EvalFieldVariable },
    { 0x2451, opcode::OP_SuperNotEqual },
    { 0x2452, opcode::OP_Invalid },
    { 0x2453, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x2454, opcode::OP_DevblockBegin },
    { 0x2455, opcode::OP_GetUndefined },
    { 0x2456, opcode::OP_EvalFieldVariable },
    { 0x2457, opcode::OP_EndOn },
    { 0x2458, opcode::OP_ScriptMethodThreadCall },
    { 0x2459, opcode::OP_Plus },
    { 0x245A, opcode::OP_EvalArrayRef },
    { 0x245B, opcode::OP_GetUnsignedShort },
    { 0x245C, opcode::OP_RealWait },
    { 0x245D, opcode::OP_ProfileStop },
    { 0x245E, opcode::OP_GetAnimation },
    { 0x245F, opcode::OP_Multiply },
    { 0x2460, opcode::OP_GetIString },
    { 0x2461, opcode::OP_Invalid },
    { 0x2462, opcode::OP_GetIString },
    { 0x2463, opcode::OP_Modulus },
    { 0x2464, opcode::OP_NextArrayKey },
    { 0x2465, opcode::OP_Invalid },
    { 0x2466, opcode::OP_IsDefined },
    { 0x2467, opcode::OP_Invalid },
    { 0x2468, opcode::OP_Switch },
    { 0x2469, opcode::OP_JumpOnTrue },
    { 0x246A, opcode::OP_EvalFieldVariable },
    { 0x246B, opcode::OP_LevelEvalFieldVariable },
    { 0x246C, opcode::OP_GreaterThanOrEqualTo },
    { 0x246D, opcode::OP_Invalid },
    { 0x246E, opcode::OP_ShiftLeft },
    { 0x246F, opcode::OP_GetNegByte },
    { 0x2470, opcode::OP_Invalid },
    { 0x2471, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x2472, opcode::OP_SizeOf },
    { 0x2473, opcode::OP_Return },
    { 0x2474, opcode::OP_GetUnsignedShort },
    { 0x2475, opcode::OP_GetWorldObject },
    { 0x2476, opcode::OP_Invalid },
    { 0x2477, opcode::OP_EndSwitch },
    { 0x2478, opcode::OP_Return },
    { 0x2479, opcode::OP_Invalid },
    { 0x247A, opcode::OP_LessThan },
    { 0x247B, opcode::OP_SizeOf },
    { 0x247C, opcode::OP_JumpOnFalseExpr },
    { 0x247D, opcode::OP_CastBool },
    { 0x247E, opcode::OP_Invalid },
    { 0x247F, opcode::OP_Invalid },
    { 0x2480, opcode::OP_ScriptThreadCallClass },
    { 0x2481, opcode::OP_DecTop },
    { 0x2482, opcode::OP_Invalid },
    { 0x2483, opcode::OP_CallBuiltinMethod },
    { 0x2484, opcode::OP_LessThanOrEqualTo },
    { 0x2485, opcode::OP_GetFloat },
    { 0x2486, opcode::OP_Invalid },
    { 0x2487, opcode::OP_ScriptFunctionCallPointer },
    { 0x2488, opcode::OP_Invalid },
    { 0x2489, opcode::OP_ProfileStop },
    { 0x248A, opcode::OP_WaitTillFrameEnd },
    { 0x248B, opcode::OP_Invalid },
    { 0x248C, opcode::OP_Plus },
    { 0x248D, opcode::OP_SafeDecTop },
    { 0x248E, opcode::OP_FirstArrayKey },
    { 0x248F, opcode::OP_SetVariableField },
    { 0x2490, opcode::OP_GetSelfObject },
    { 0x2491, opcode::OP_Invalid },
    { 0x2492, opcode::OP_Invalid },
    { 0x2493, opcode::OP_GetIString },
    { 0x2494, opcode::OP_GetZero },
    { 0x2495, opcode::OP_EvalFieldVariable },
    { 0x2496, opcode::OP_Invalid },
    { 0x2497, opcode::OP_GetByte },
    { 0x2498, opcode::OP_SafeSetVariableFieldCached },
    { 0x2499, opcode::OP_BoolNot },
    { 0x249A, opcode::OP_Invalid },
    { 0x249B, opcode::OP_Invalid },
    { 0x249C, opcode::OP_Wait },
    { 0x249D, opcode::OP_Wait },
    { 0x249E, opcode::OP_ScriptMethodThreadCall },
    { 0x249F, opcode::OP_DevblockBegin },
    { 0x24A0, opcode::OP_Invalid },
    { 0x24A1, opcode::OP_ScriptMethodThreadCall },
    { 0x24A2, opcode::OP_Invalid },
    { 0x24A3, opcode::OP_JumpOnTrueExpr },
    { 0x24A4, opcode::OP_Invalid },
    { 0x24A5, opcode::OP_Invalid },
    { 0x24A6, opcode::OP_RealWait },
    { 0x24A7, opcode::OP_GetSelf },
    { 0x24A8, opcode::OP_Vector },
    { 0x24A9, opcode::OP_Vector },
    { 0x24AA, opcode::OP_LessThanOrEqualTo },
    { 0x24AB, opcode::OP_Multiply },
    { 0x24AC, opcode::OP_Wait },
    { 0x24AD, opcode::OP_EvalFieldVariableRef },
    { 0x24AE, opcode::OP_EvalLocalVariableRefCached },
    { 0x24AF, opcode::OP_GreaterThan },
    { 0x24B0, opcode::OP_Notify },
    { 0x24B1, opcode::OP_ScriptMethodCallPointer },
    { 0x24B2, opcode::OP_Invalid },
    { 0x24B3, opcode::OP_Invalid },
    { 0x24B4, opcode::OP_Bit_Xor },
    { 0x24B5, opcode::OP_Multiply },
    { 0x24B6, opcode::OP_GetHash },
    { 0x24B7, opcode::OP_RealWait },
    { 0x24B8, opcode::OP_Invalid },
    { 0x24B9, opcode::OP_Invalid },
    { 0x24BA, opcode::OP_EvalFieldVariable },
    { 0x24BB, opcode::OP_JumpOnTrueExpr },
    { 0x24BC, opcode::OP_EndOn },
    { 0x24BD, opcode::OP_Equal },
    { 0x24BE, opcode::OP_Invalid },
    { 0x24BF, opcode::OP_Wait },
    { 0x24C0, opcode::OP_Invalid },
    { 0x24C1, opcode::OP_Invalid },
    { 0x24C2, opcode::OP_GetZero },
    { 0x24C3, opcode::OP_Invalid },
    { 0x24C4, opcode::OP_GetInteger },
    { 0x24C5, opcode::OP_JumpOnFalseExpr },
    { 0x24C6, opcode::OP_Invalid },
    { 0x24C7, opcode::OP_EvalFieldVariable },
    { 0x24C8, opcode::OP_Invalid },
    { 0x24C9, opcode::OP_Invalid },
    { 0x24CA, opcode::OP_Invalid },
    { 0x24CB, opcode::OP_New },
    { 0x24CC, opcode::OP_New },
    { 0x24CD, opcode::OP_WaitTillMatch },
    { 0x24CE, opcode::OP_GetVector },
    { 0x24CF, opcode::OP_Invalid },
    { 0x24D0, opcode::OP_SetVariableField },
    { 0x24D1, opcode::OP_FirstArrayKey },
    { 0x24D2, opcode::OP_GetSelf },
    { 0x24D3, opcode::OP_Invalid },
    { 0x24D4, opcode::OP_Plus },
    { 0x24D5, opcode::OP_Invalid },
    { 0x24D6, opcode::OP_ClearArray },
    { 0x24D7, opcode::OP_WaitTill },
    { 0x24D8, opcode::OP_LevelEvalFieldVariable },
    { 0x24D9, opcode::OP_Invalid },
    { 0x24DA, opcode::OP_Invalid },
    { 0x24DB, opcode::OP_Invalid },
    { 0x24DC, opcode::OP_Invalid },
    { 0x24DD, opcode::OP_GetZero },
    { 0x24DE, opcode::OP_GetZero },
    { 0x24DF, opcode::OP_Invalid },
    { 0x24E0, opcode::OP_Invalid },
    { 0x24E1, opcode::OP_ScriptFunctionCallPointer },
    { 0x24E2, opcode::OP_EvalLocalVariableCached },
    { 0x24E3, opcode::OP_FirstArrayKey },
    { 0x24E4, opcode::OP_Bit_Or },
    { 0x24E5, opcode::OP_Invalid },
    { 0x24E6, opcode::OP_NextArrayKey },
    { 0x24E7, opcode::OP_Invalid },
    { 0x24E8, opcode::OP_ScriptFunctionCallClass },
    { 0x24E9, opcode::OP_GetSelfObject },
    { 0x24EA, opcode::OP_GetLevelObject },
    { 0x24EB, opcode::OP_JumpOnTrueExpr },
    { 0x24EC, opcode::OP_EndOn },
    { 0x24ED, opcode::OP_GetString },
    { 0x24EE, opcode::OP_Invalid },
    { 0x24EF, opcode::OP_New },
    { 0x24F0, opcode::OP_CastBool },
    { 0x24F1, opcode::OP_Invalid },
    { 0x24F2, opcode::OP_Invalid },
    { 0x24F3, opcode::OP_Invalid },
    { 0x24F4, opcode::OP_GetSelf },
    { 0x24F5, opcode::OP_ScriptThreadCallClass },
    { 0x24F6, opcode::OP_RealWait },
    { 0x24F7, opcode::OP_Invalid },
    { 0x24F8, opcode::OP_ShiftLeft },
    { 0x24F9, opcode::OP_RealWait },
    { 0x24FA, opcode::OP_Invalid },
    { 0x24FB, opcode::OP_WaitTillMatch },
    { 0x24FC, opcode::OP_SafeDecTop },
    { 0x24FD, opcode::OP_EvalArray },
    { 0x24FE, opcode::OP_GetIString },
    { 0x24FF, opcode::OP_Invalid },
    { 0x2500, opcode::OP_Invalid },
    { 0x2501, opcode::OP_EvalFieldVariable },
    { 0x2502, opcode::OP_RealWait },
    { 0x2503, opcode::OP_EvalLocalVariableCached },
    { 0x2504, opcode::OP_ScriptThreadCallClass },
    { 0x2505, opcode::OP_Invalid },
    { 0x2506, opcode::OP_Invalid },
    { 0x2507, opcode::OP_ClearFieldVariable },
    { 0x2508, opcode::OP_Invalid },
    { 0x2509, opcode::OP_GetUnsignedShort },
    { 0x250A, opcode::OP_GetTime },
    { 0x250B, opcode::OP_EmptyArray },
    { 0x250C, opcode::OP_RealWait },
    { 0x250D, opcode::OP_SafeSetVariableFieldCached },
    { 0x250E, opcode::OP_Invalid },
    { 0x250F, opcode::OP_Invalid },
    { 0x2510, opcode::OP_GetClasses },
    { 0x2511, opcode::OP_ClearFieldVariable },
    { 0x2512, opcode::OP_GetSelfObject },
    { 0x2513, opcode::OP_JumpOnFalseExpr },
    { 0x2514, opcode::OP_Invalid },
    { 0x2515, opcode::OP_WaitTillMatch },
    { 0x2516, opcode::OP_EvalFieldVariableRef },
    { 0x2517, opcode::OP_GetAPIFunction },
    { 0x2518, opcode::OP_SelfEvalFieldVariable },
    { 0x2519, opcode::OP_Invalid },
    { 0x251A, opcode::OP_JumpOnTrueExpr },
    { 0x251B, opcode::OP_Invalid },
    { 0x251C, opcode::OP_ShiftLeft },
    { 0x251D, opcode::OP_EndSwitch },
    { 0x251E, opcode::OP_GetLevel },
    { 0x251F, opcode::OP_Bit_Or },
    { 0x2520, opcode::OP_Invalid },
    { 0x2521, opcode::OP_JumpOnTrueExpr },
    { 0x2522, opcode::OP_FirstArrayKey },
    { 0x2523, opcode::OP_CastBool },
    { 0x2524, opcode::OP_Invalid },
    { 0x2525, opcode::OP_Invalid },
    { 0x2526, opcode::OP_Invalid },
    { 0x2527, opcode::OP_ScriptFunctionCall },
    { 0x2528, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x2529, opcode::OP_EvalLocalVariableCached },
    { 0x252A, opcode::OP_SafeDecTop },
    { 0x252B, opcode::OP_ShiftRight },
    { 0x252C, opcode::OP_FirstArrayKey },
    { 0x252D, opcode::OP_SafeCreateLocalVariables },
    { 0x252E, opcode::OP_Invalid },
    { 0x252F, opcode::OP_SafeDecTop },
    { 0x2530, opcode::OP_EmptyArray },
    { 0x2531, opcode::OP_Invalid },
    { 0x2532, opcode::OP_Invalid },
    { 0x2533, opcode::OP_SafeSetVariableFieldCached },
    { 0x2534, opcode::OP_Invalid },
    { 0x2535, opcode::OP_Invalid },
    { 0x2536, opcode::OP_Invalid },
    { 0x2537, opcode::OP_Dec },
    { 0x2538, opcode::OP_Invalid },
    { 0x2539, opcode::OP_GetAnimation },
    { 0x253A, opcode::OP_JumpOnTrueExpr },
    { 0x253B, opcode::OP_Divide },
    { 0x253C, opcode::OP_EndSwitch },
    { 0x253D, opcode::OP_Invalid },
    { 0x253E, opcode::OP_Invalid },
    { 0x253F, opcode::OP_ClearFieldVariable },
    { 0x2540, opcode::OP_VectorScale },
    { 0x2541, opcode::OP_GetWorld },
    { 0x2542, opcode::OP_GetZero },
    { 0x2543, opcode::OP_Invalid },
    { 0x2544, opcode::OP_EvalLocalVariableCached },
    { 0x2545, opcode::OP_BoolNot },
    { 0x2546, opcode::OP_Invalid },
    { 0x2547, opcode::OP_GetAnimObject },
    { 0x2548, opcode::OP_ProfileStop },
    { 0x2549, opcode::OP_Bit_Xor },
    { 0x254A, opcode::OP_Invalid },
    { 0x254B, opcode::OP_ClearFieldVariable },
    { 0x254C, opcode::OP_ProfileStart },
    { 0x254D, opcode::OP_JumpOnFalseExpr },
    { 0x254E, opcode::OP_Invalid },
    { 0x254F, opcode::OP_GetAPIFunction },
    { 0x2550, opcode::OP_WaitTillFrameEnd },
    { 0x2551, opcode::OP_JumpOnTrue },
    { 0x2552, opcode::OP_EvalLocalVariableRefCached },
    { 0x2553, opcode::OP_Bit_And },
    { 0x2554, opcode::OP_Invalid },
    { 0x2555, opcode::OP_GetUnsignedShort },
    { 0x2556, opcode::OP_Invalid },
    { 0x2557, opcode::OP_Invalid },
    { 0x2558, opcode::OP_GetAnim },
    { 0x2559, opcode::OP_GetClasses },
    { 0x255A, opcode::OP_Invalid },
    { 0x255B, opcode::OP_GreaterThan },
    { 0x255C, opcode::OP_GetGameRef },
    { 0x255D, opcode::OP_Invalid },
    { 0x255E, opcode::OP_SuperEqual },
    { 0x255F, opcode::OP_Return },
    { 0x2560, opcode::OP_ScriptMethodCallPointer },
    { 0x2561, opcode::OP_BoolComplement },
    { 0x2562, opcode::OP_GetInteger },
    { 0x2563, opcode::OP_Invalid },
    { 0x2564, opcode::OP_Invalid },
    { 0x2565, opcode::OP_Invalid },
    { 0x2566, opcode::OP_Invalid },
    { 0x2567, opcode::OP_ShiftRight },
    { 0x2568, opcode::OP_Invalid },
    { 0x2569, opcode::OP_NextArrayKey },
    { 0x256A, opcode::OP_Vector },
    { 0x256B, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x256C, opcode::OP_Invalid },
    { 0x256D, opcode::OP_Invalid },
    { 0x256E, opcode::OP_ScriptThreadCallPointer },
    { 0x256F, opcode::OP_Invalid },
    { 0x2570, opcode::OP_GetUnsignedShort },
    { 0x2571, opcode::OP_Invalid },
    { 0x2572, opcode::OP_SizeOf },
    { 0x2573, opcode::OP_ScriptThreadCallPointer },
    { 0x2574, opcode::OP_WaitTillMatch },
    { 0x2575, opcode::OP_GetFloat },
    { 0x2576, opcode::OP_EvalLocalVariableCached },
    { 0x2577, opcode::OP_Invalid },
    { 0x2578, opcode::OP_RealWait },
    { 0x2579, opcode::OP_Invalid },
    { 0x257A, opcode::OP_Return },
    { 0x257B, opcode::OP_Bit_Xor },
    { 0x257C, opcode::OP_Invalid },
    { 0x257D, opcode::OP_Invalid },
    { 0x257E, opcode::OP_Invalid },
    { 0x257F, opcode::OP_LevelEvalFieldVariableRef },
    { 0x2580, opcode::OP_EvalLocalVariableCached },
    { 0x2581, opcode::OP_LessThan },
    { 0x2582, opcode::OP_Multiply },
    { 0x2583, opcode::OP_Invalid },
    { 0x2584, opcode::OP_GetNegByte },
    { 0x2585, opcode::OP_Invalid },
    { 0x2586, opcode::OP_Invalid },
    { 0x2587, opcode::OP_Switch },
    { 0x2588, opcode::OP_ScriptThreadCall },
    { 0x2589, opcode::OP_GetIString },
    { 0x258A, opcode::OP_EndOn },
    { 0x258B, opcode::OP_BoolComplement },
    { 0x258C, opcode::OP_JumpOnTrueExpr },
    { 0x258D, opcode::OP_Invalid },
    { 0x258E, opcode::OP_EvalFieldVariableRef },
    { 0x258F, opcode::OP_ScriptMethodCallPointer },
    { 0x2590, opcode::OP_EvalFieldVariable },
    { 0x2591, opcode::OP_Invalid },
    { 0x2592, opcode::OP_JumpOnFalse },
    { 0x2593, opcode::OP_GetVector },
    { 0x2594, opcode::OP_Invalid },
    { 0x2595, opcode::OP_Invalid },
    { 0x2596, opcode::OP_BoolComplement },
    { 0x2597, opcode::OP_GetTime },
    { 0x2598, opcode::OP_Invalid },
    { 0x2599, opcode::OP_Invalid },
    { 0x259A, opcode::OP_ClearFieldVariable },
    { 0x259B, opcode::OP_FirstArrayKey },
    { 0x259C, opcode::OP_Invalid },
    { 0x259D, opcode::OP_Invalid },
    { 0x259E, opcode::OP_DecTop },
    { 0x259F, opcode::OP_GetZero },
    { 0x25A0, opcode::OP_Invalid },
    { 0x25A1, opcode::OP_ScriptMethodCall },
    { 0x25A2, opcode::OP_EvalFieldVariableRef },
    { 0x25A3, opcode::OP_Jump },
    { 0x25A4, opcode::OP_ScriptFunctionCall },
    { 0x25A5, opcode::OP_GetString },
    { 0x25A6, opcode::OP_ProfileStop },
    { 0x25A7, opcode::OP_LessThan },
    { 0x25A8, opcode::OP_Invalid },
    { 0x25A9, opcode::OP_CastFieldObject },
    { 0x25AA, opcode::OP_Invalid },
    { 0x25AB, opcode::OP_NextArrayKey },
    { 0x25AC, opcode::OP_GetUndefined },
    { 0x25AD, opcode::OP_Invalid },
    { 0x25AE, opcode::OP_Invalid },
    { 0x25AF, opcode::OP_Invalid },
    { 0x25B0, opcode::OP_GetClasses },
    { 0x25B1, opcode::OP_Dec },
    { 0x25B2, opcode::OP_SelfEvalFieldVariable },
    { 0x25B3, opcode::OP_GetWorldObject },
    { 0x25B4, opcode::OP_DecTop },
    { 0x25B5, opcode::OP_Dec },
    { 0x25B6, opcode::OP_GetUndefined },
    { 0x25B7, opcode::OP_Invalid },
    { 0x25B8, opcode::OP_Invalid },
    { 0x25B9, opcode::OP_GetClasses },
    { 0x25BA, opcode::OP_SuperNotEqual },
    { 0x25BB, opcode::OP_Invalid },
    { 0x25BC, opcode::OP_Wait },
    { 0x25BD, opcode::OP_GetHash },
    { 0x25BE, opcode::OP_Invalid },
    { 0x25BF, opcode::OP_GetHash },
    { 0x25C0, opcode::OP_Invalid },
    { 0x25C1, opcode::OP_JumpOnFalseExpr },
    { 0x25C2, opcode::OP_Wait },
    { 0x25C3, opcode::OP_GetAnim },
    { 0x25C4, opcode::OP_WaitTillMatch },
    { 0x25C5, opcode::OP_VectorScale },
    { 0x25C6, opcode::OP_FirstArrayKey },
    { 0x25C7, opcode::OP_ScriptMethodCall },
    { 0x25C8, opcode::OP_Invalid },
    { 0x25C9, opcode::OP_ClearFieldVariable },
    { 0x25CA, opcode::OP_Invalid },
    { 0x25CB, opcode::OP_Invalid },
    { 0x25CC, opcode::OP_Invalid },
    { 0x25CD, opcode::OP_JumpOnTrue },
    { 0x25CE, opcode::OP_Invalid },
    { 0x25CF, opcode::OP_EndSwitch },
    { 0x25D0, opcode::OP_JumpOnTrueExpr },
    { 0x25D1, opcode::OP_Invalid },
    { 0x25D2, opcode::OP_Minus },
    { 0x25D3, opcode::OP_Invalid },
    { 0x25D4, opcode::OP_Invalid },
    { 0x25D5, opcode::OP_GetAnimation },
    { 0x25D6, opcode::OP_GetIString },
    { 0x25D7, opcode::OP_GetNegUnsignedShort },
    { 0x25D8, opcode::OP_Jump },
    { 0x25D9, opcode::OP_Invalid },
    { 0x25DA, opcode::OP_Invalid },
    { 0x25DB, opcode::OP_JumpOnFalse },
    { 0x25DC, opcode::OP_Invalid },
    { 0x25DD, opcode::OP_CallBuiltinMethod },
    { 0x25DE, opcode::OP_JumpOnTrue },
    { 0x25DF, opcode::OP_BoolNot },
    { 0x25E0, opcode::OP_GetString },
    { 0x25E1, opcode::OP_Invalid },
    { 0x25E2, opcode::OP_Invalid },
    { 0x25E3, opcode::OP_GetSelfObject },
    { 0x25E4, opcode::OP_IsDefined },
    { 0x25E5, opcode::OP_JumpOnFalseExpr },
    { 0x25E6, opcode::OP_GetSelfObject },
    { 0x25E7, opcode::OP_Invalid },
    { 0x25E8, opcode::OP_GetNegByte },
    { 0x25E9, opcode::OP_Invalid },
    { 0x25EA, opcode::OP_GetClasses },
    { 0x25EB, opcode::OP_Dec },
    { 0x25EC, opcode::OP_Invalid },
    { 0x25ED, opcode::OP_WaitTill },
    { 0x25EE, opcode::OP_GetUndefined },
    { 0x25EF, opcode::OP_GetFloat },
    { 0x25F0, opcode::OP_EvalFieldVariable },
    { 0x25F1, opcode::OP_Invalid },
    { 0x25F2, opcode::OP_Invalid },
    { 0x25F3, opcode::OP_Invalid },
    { 0x25F4, opcode::OP_Invalid },
    { 0x25F5, opcode::OP_DecTop },
    { 0x25F6, opcode::OP_Notify },
    { 0x25F7, opcode::OP_GetAnim },
    { 0x25F8, opcode::OP_ScriptMethodCall },
    { 0x25F9, opcode::OP_Invalid },
    { 0x25FA, opcode::OP_EvalLocalVariableRefCached },
    { 0x25FB, opcode::OP_SafeDecTop },
    { 0x25FC, opcode::OP_JumpOnTrueExpr },
    { 0x25FD, opcode::OP_Invalid },
    { 0x25FE, opcode::OP_Invalid },
    { 0x25FF, opcode::OP_Equal },
    { 0x2600, opcode::OP_EvalArray },
    { 0x2601, opcode::OP_Invalid },
    { 0x2602, opcode::OP_Invalid },
    { 0x2603, opcode::OP_Invalid },
    { 0x2604, opcode::OP_Invalid },
    { 0x2605, opcode::OP_SetVariableField },
    { 0x2606, opcode::OP_GetWorld },
    { 0x2607, opcode::OP_Plus },
    { 0x2608, opcode::OP_Invalid },
    { 0x2609, opcode::OP_ClearArray },
    { 0x260A, opcode::OP_Invalid },
    { 0x260B, opcode::OP_Invalid },
    { 0x260C, opcode::OP_Invalid },
    { 0x260D, opcode::OP_WaitTillMatch },
    { 0x260E, opcode::OP_ScriptFunctionCall },
    { 0x260F, opcode::OP_LevelEvalFieldVariableRef },
    { 0x2610, opcode::OP_Invalid },
    { 0x2611, opcode::OP_Invalid },
    { 0x2612, opcode::OP_NextArrayKey },
    { 0x2613, opcode::OP_LessThanOrEqualTo },
    { 0x2614, opcode::OP_GreaterThan },
    { 0x2615, opcode::OP_GetGame },
    { 0x2616, opcode::OP_CastBool },
    { 0x2617, opcode::OP_Invalid },
    { 0x2618, opcode::OP_Notify },
    { 0x2619, opcode::OP_GetWorld },
    { 0x261A, opcode::OP_NextArrayKey },
    { 0x261B, opcode::OP_Invalid },
    { 0x261C, opcode::OP_ScriptMethodCall },
    { 0x261D, opcode::OP_LessThanOrEqualTo },
    { 0x261E, opcode::OP_GetGame },
    { 0x261F, opcode::OP_GetFunction },
    { 0x2620, opcode::OP_JumpOnFalseExpr },
    { 0x2621, opcode::OP_VectorConstant },
    { 0x2622, opcode::OP_EvalArray },
    { 0x2623, opcode::OP_Divide },
    { 0x2624, opcode::OP_Invalid },
    { 0x2625, opcode::OP_Invalid },
    { 0x2626, opcode::OP_Invalid },
    { 0x2627, opcode::OP_JumpOnFalseExpr },
    { 0x2628, opcode::OP_Invalid },
    { 0x2629, opcode::OP_Invalid },
    { 0x262A, opcode::OP_WaitTill },
    { 0x262B, opcode::OP_JumpOnFalseExpr },
    { 0x262C, opcode::OP_GetNegByte },
    { 0x262D, opcode::OP_ShiftRight },
    { 0x262E, opcode::OP_SafeSetVariableFieldCached },
    { 0x262F, opcode::OP_Return },
    { 0x2630, opcode::OP_GetLevel },
    { 0x2631, opcode::OP_Invalid },
    { 0x2632, opcode::OP_ScriptMethodCall },
    { 0x2633, opcode::OP_Multiply },
    { 0x2634, opcode::OP_SafeCreateLocalVariables },
    { 0x2635, opcode::OP_ClearArray },
    { 0x2636, opcode::OP_Invalid },
    { 0x2637, opcode::OP_Invalid },
    { 0x2638, opcode::OP_Invalid },
    { 0x2639, opcode::OP_GetClasses },
    { 0x263A, opcode::OP_EvalFieldVariable },
    { 0x263B, opcode::OP_BoolNot },
    { 0x263C, opcode::OP_WaitTillFrameEnd },
    { 0x263D, opcode::OP_Invalid },
    { 0x263E, opcode::OP_SafeSetVariableFieldCached },
    { 0x263F, opcode::OP_SelfEvalFieldVariableRef },
    { 0x2640, opcode::OP_WaitTillMatch },
    { 0x2641, opcode::OP_Invalid },
    { 0x2642, opcode::OP_ScriptFunctionCall },
    { 0x2643, opcode::OP_Invalid },
    { 0x2644, opcode::OP_Invalid },
    { 0x2645, opcode::OP_WaitTillFrameEnd },
    { 0x2646, opcode::OP_EvalFieldVariableRef },
    { 0x2647, opcode::OP_ScriptFunctionCallClass },
    { 0x2648, opcode::OP_GetAnimObject },
    { 0x2649, opcode::OP_Invalid },
    { 0x264A, opcode::OP_Invalid },
    { 0x264B, opcode::OP_GetAnimation },
    { 0x264C, opcode::OP_GetAnimObject },
    { 0x264D, opcode::OP_Switch },
    { 0x264E, opcode::OP_EvalLocalVariableCached },
    { 0x264F, opcode::OP_CallBuiltinMethod },
    { 0x2650, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x2651, opcode::OP_JumpOnFalseExpr },
    { 0x2652, opcode::OP_CastBool },
    { 0x2653, opcode::OP_Multiply },
    { 0x2654, opcode::OP_Invalid },
    { 0x2655, opcode::OP_Invalid },
    { 0x2656, opcode::OP_Multiply },
    { 0x2657, opcode::OP_Invalid },
    { 0x2658, opcode::OP_ScriptMethodThreadCall },
    { 0x2659, opcode::OP_SizeOf },
    { 0x265A, opcode::OP_WaitTillMatch },
    { 0x265B, opcode::OP_GetFloat },
    { 0x265C, opcode::OP_EmptyArray },
    { 0x265D, opcode::OP_ScriptFunctionCallPointer },
    { 0x265E, opcode::OP_GetNegUnsignedShort },
    { 0x265F, opcode::OP_SizeOf },
    { 0x2660, opcode::OP_EvalLocalVariableCached },
    { 0x2661, opcode::OP_LevelEvalFieldVariable },
    { 0x2662, opcode::OP_EvalLocalVariableCached },
    { 0x2663, opcode::OP_ScriptThreadCallClass },
    { 0x2664, opcode::OP_Invalid },
    { 0x2665, opcode::OP_Invalid },
    { 0x2666, opcode::OP_GetFloat },
    { 0x2667, opcode::OP_Invalid },
    { 0x2668, opcode::OP_ScriptMethodCallPointer },
    { 0x2669, opcode::OP_LevelEvalFieldVariable },
    { 0x266A, opcode::OP_ClearFieldVariable },
    { 0x266B, opcode::OP_Invalid },
    { 0x266C, opcode::OP_Invalid },
    { 0x266D, opcode::OP_CastBool },
    { 0x266E, opcode::OP_Invalid },
    { 0x266F, opcode::OP_Invalid },
    { 0x2670, opcode::OP_GetByte },
    { 0x2671, opcode::OP_Invalid },
    { 0x2672, opcode::OP_ScriptFunctionCall },
    { 0x2673, opcode::OP_GetLevel },
    { 0x2674, opcode::OP_Invalid },
    { 0x2675, opcode::OP_GetAnim },
    { 0x2676, opcode::OP_GreaterThan },
    { 0x2677, opcode::OP_JumpOnFalseExpr },
    { 0x2678, opcode::OP_ProfileStart },
    { 0x2679, opcode::OP_SizeOf },
    { 0x267A, opcode::OP_ScriptThreadCallClass },
    { 0x267B, opcode::OP_Invalid },
    { 0x267C, opcode::OP_Invalid },
    { 0x267D, opcode::OP_NotEqual },
    { 0x267E, opcode::OP_Invalid },
    { 0x267F, opcode::OP_Invalid },
    { 0x2680, opcode::OP_Invalid },
    { 0x2681, opcode::OP_Switch },
    { 0x2682, opcode::OP_GetByte },
    { 0x2683, opcode::OP_Invalid },
    { 0x2684, opcode::OP_Invalid },
    { 0x2685, opcode::OP_WaitTillMatch },
    { 0x2686, opcode::OP_NextArrayKey },
    { 0x2687, opcode::OP_Invalid },
    { 0x2688, opcode::OP_BoolNot },
    { 0x2689, opcode::OP_Invalid },
    { 0x268A, opcode::OP_SetVariableField },
    { 0x268B, opcode::OP_GetFloat },
    { 0x268C, opcode::OP_GetGameRef },
    { 0x268D, opcode::OP_FirstArrayKey },
    { 0x268E, opcode::OP_Jump },
    { 0x268F, opcode::OP_EvalLocalVariableRefCached },
    { 0x2690, opcode::OP_ScriptThreadCallClass },
    { 0x2691, opcode::OP_Invalid },
    { 0x2692, opcode::OP_Return },
    { 0x2693, opcode::OP_Invalid },
    { 0x2694, opcode::OP_NextArrayKey },
    { 0x2695, opcode::OP_GetSelf },
    { 0x2696, opcode::OP_VectorScale },
    { 0x2697, opcode::OP_GetLevelObject },
    { 0x2698, opcode::OP_JumpOnFalseExpr },
    { 0x2699, opcode::OP_GetNegUnsignedShort },
    { 0x269A, opcode::OP_Invalid },
    { 0x269B, opcode::OP_Invalid },
    { 0x269C, opcode::OP_GreaterThan },
    { 0x269D, opcode::OP_GetUndefined },
    { 0x269E, opcode::OP_Invalid },
    { 0x269F, opcode::OP_GetAnimation },
    { 0x26A0, opcode::OP_Invalid },
    { 0x26A1, opcode::OP_Invalid },
    { 0x26A2, opcode::OP_GetUndefined },
    { 0x26A3, opcode::OP_Bit_And },
    { 0x26A4, opcode::OP_Invalid },
    { 0x26A5, opcode::OP_Invalid },
    { 0x26A6, opcode::OP_JumpOnTrue },
    { 0x26A7, opcode::OP_SelfEvalFieldVariableRef },
    { 0x26A8, opcode::OP_Invalid },
    { 0x26A9, opcode::OP_NotEqual },
    { 0x26AA, opcode::OP_SuperNotEqual },
    { 0x26AB, opcode::OP_RealWait },
    { 0x26AC, opcode::OP_Invalid },
    { 0x26AD, opcode::OP_GetWorldObject },
    { 0x26AE, opcode::OP_GetAnimObject },
    { 0x26AF, opcode::OP_ScriptMethodCall },
    { 0x26B0, opcode::OP_Invalid },
    { 0x26B1, opcode::OP_Invalid },
    { 0x26B2, opcode::OP_GetAnimation },
    { 0x26B3, opcode::OP_Invalid },
    { 0x26B4, opcode::OP_Invalid },
    { 0x26B5, opcode::OP_GetFloat },
    { 0x26B6, opcode::OP_Invalid },
    { 0x26B7, opcode::OP_GetUndefined },
    { 0x26B8, opcode::OP_GetZero },
    { 0x26B9, opcode::OP_ShiftRight },
    { 0x26BA, opcode::OP_Invalid },
    { 0x26BB, opcode::OP_New },
    { 0x26BC, opcode::OP_CastFieldObject },
    { 0x26BD, opcode::OP_EndSwitch },
    { 0x26BE, opcode::OP_GetZero },
    { 0x26BF, opcode::OP_CastBool },
    { 0x26C0, opcode::OP_WaitTillFrameEnd },
    { 0x26C1, opcode::OP_Bit_And },
    { 0x26C2, opcode::OP_Invalid },
    { 0x26C3, opcode::OP_ScriptMethodCall },
    { 0x26C4, opcode::OP_EmptyArray },
    { 0x26C5, opcode::OP_Invalid },
    { 0x26C6, opcode::OP_SafeDecTop },
    { 0x26C7, opcode::OP_SizeOf },
    { 0x26C8, opcode::OP_Invalid },
    { 0x26C9, opcode::OP_GetClassesObject },
    { 0x26CA, opcode::OP_Invalid },
    { 0x26CB, opcode::OP_Notify },
    { 0x26CC, opcode::OP_GetGameRef },
    { 0x26CD, opcode::OP_Invalid },
    { 0x26CE, opcode::OP_ScriptThreadCallPointer },
    { 0x26CF, opcode::OP_Invalid },
    { 0x26D0, opcode::OP_Wait },
    { 0x26D1, opcode::OP_SuperNotEqual },
    { 0x26D2, opcode::OP_SizeOf },
    { 0x26D3, opcode::OP_GetLevel },
    { 0x26D4, opcode::OP_ScriptThreadCall },
    { 0x26D5, opcode::OP_JumpOnFalseExpr },
    { 0x26D6, opcode::OP_Invalid },
    { 0x26D7, opcode::OP_GetSelfObject },
    { 0x26D8, opcode::OP_Invalid },
    { 0x26D9, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x26DA, opcode::OP_GetSelfObject },
    { 0x26DB, opcode::OP_GetUndefined },
    { 0x26DC, opcode::OP_CastFieldObject },
    { 0x26DD, opcode::OP_GetSelf },
    { 0x26DE, opcode::OP_Divide },
    { 0x26DF, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x26E0, opcode::OP_NextArrayKey },
    { 0x26E1, opcode::OP_Invalid },
    { 0x26E2, opcode::OP_LessThanOrEqualTo },
    { 0x26E3, opcode::OP_Invalid },
    { 0x26E4, opcode::OP_Divide },
    { 0x26E5, opcode::OP_SelfEvalFieldVariable },
    { 0x26E6, opcode::OP_VectorScale },
    { 0x26E7, opcode::OP_JumpOnTrueExpr },
    { 0x26E8, opcode::OP_Invalid },
    { 0x26E9, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x26EA, opcode::OP_Modulus },
    { 0x26EB, opcode::OP_SafeCreateLocalVariables },
    { 0x26EC, opcode::OP_Invalid },
    { 0x26ED, opcode::OP_Invalid },
    { 0x26EE, opcode::OP_ScriptThreadCallClass },
    { 0x26EF, opcode::OP_GetAnimObject },
    { 0x26F0, opcode::OP_DevblockBegin },
    { 0x26F1, opcode::OP_Invalid },
    { 0x26F2, opcode::OP_GetUnsignedShort },
    { 0x26F3, opcode::OP_Minus },
    { 0x26F4, opcode::OP_Invalid },
    { 0x26F5, opcode::OP_Invalid },
    { 0x26F6, opcode::OP_SuperEqual },
    { 0x26F7, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x26F8, opcode::OP_Invalid },
    { 0x26F9, opcode::OP_Invalid },
    { 0x26FA, opcode::OP_DevblockBegin },
    { 0x26FB, opcode::OP_Invalid },
    { 0x26FC, opcode::OP_Invalid },
    { 0x26FD, opcode::OP_Invalid },
    { 0x26FE, opcode::OP_Invalid },
    { 0x26FF, opcode::OP_GetIString },
    { 0x2700, opcode::OP_GetAPIFunction },
    { 0x2701, opcode::OP_Invalid },
    { 0x2702, opcode::OP_EndOn },
    { 0x2703, opcode::OP_Invalid },
    { 0x2704, opcode::OP_GetAnimation },
    { 0x2705, opcode::OP_GetClasses },
    { 0x2706, opcode::OP_BoolComplement },
    { 0x2707, opcode::OP_Invalid },
    { 0x2708, opcode::OP_Invalid },
    { 0x2709, opcode::OP_JumpOnTrue },
    { 0x270A, opcode::OP_GetUndefined },
    { 0x270B, opcode::OP_JumpOnTrue },
    { 0x270C, opcode::OP_GetHash },
    { 0x270D, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x270E, opcode::OP_ShiftLeft },
    { 0x270F, opcode::OP_Invalid },
    { 0x2710, opcode::OP_EvalLocalVariableRefCached },
    { 0x2711, opcode::OP_CastBool },
    { 0x2712, opcode::OP_LessThan },
    { 0x2713, opcode::OP_GetString },
    { 0x2714, opcode::OP_Invalid },
    { 0x2715, opcode::OP_JumpOnFalse },
    { 0x2716, opcode::OP_Invalid },
    { 0x2717, opcode::OP_Equal },
    { 0x2718, opcode::OP_GetIString },
    { 0x2719, opcode::OP_Invalid },
    { 0x271A, opcode::OP_Invalid },
    { 0x271B, opcode::OP_Invalid },
    { 0x271C, opcode::OP_GetInteger },
    { 0x271D, opcode::OP_DecTop },
    { 0x271E, opcode::OP_ShiftRight },
    { 0x271F, opcode::OP_WaitTill },
    { 0x2720, opcode::OP_WaitTill },
    { 0x2721, opcode::OP_GreaterThanOrEqualTo },
    { 0x2722, opcode::OP_GetUndefined },
    { 0x2723, opcode::OP_GetIString },
    { 0x2724, opcode::OP_Invalid },
    { 0x2725, opcode::OP_GreaterThan },
    { 0x2726, opcode::OP_SelfEvalFieldVariableRef },
    { 0x2727, opcode::OP_GetInteger },
    { 0x2728, opcode::OP_BoolNot },
    { 0x2729, opcode::OP_GreaterThan },
    { 0x272A, opcode::OP_Invalid },
    { 0x272B, opcode::OP_LessThanOrEqualTo },
    { 0x272C, opcode::OP_EmptyArray },
    { 0x272D, opcode::OP_SafeCreateLocalVariables },
    { 0x272E, opcode::OP_Invalid },
    { 0x272F, opcode::OP_ScriptFunctionCallClass },
    { 0x2730, opcode::OP_GetAnimation },
    { 0x2731, opcode::OP_Invalid },
    { 0x2732, opcode::OP_CastFieldObject },
    { 0x2733, opcode::OP_ScriptThreadCall },
    { 0x2734, opcode::OP_Return },
    { 0x2735, opcode::OP_CallBuiltinMethod },
    { 0x2736, opcode::OP_Invalid },
    { 0x2737, opcode::OP_GetAnimation },
    { 0x2738, opcode::OP_Invalid },
    { 0x2739, opcode::OP_LessThan },
    { 0x273A, opcode::OP_SuperEqual },
    { 0x273B, opcode::OP_Jump },
    { 0x273C, opcode::OP_JumpOnTrue },
    { 0x273D, opcode::OP_GetHash },
    { 0x273E, opcode::OP_New },
    { 0x273F, opcode::OP_EvalArray },
    { 0x2740, opcode::OP_EndOn },
    { 0x2741, opcode::OP_GetWorld },
    { 0x2742, opcode::OP_JumpOnFalse },
    { 0x2743, opcode::OP_Invalid },
    { 0x2744, opcode::OP_Invalid },
    { 0x2745, opcode::OP_Invalid },
    { 0x2746, opcode::OP_Invalid },
    { 0x2747, opcode::OP_Invalid },
    { 0x2748, opcode::OP_DecTop },
    { 0x2749, opcode::OP_Invalid },
    { 0x274A, opcode::OP_ScriptMethodCall },
    { 0x274B, opcode::OP_Invalid },
    { 0x274C, opcode::OP_Invalid },
    { 0x274D, opcode::OP_Invalid },
    { 0x274E, opcode::OP_Invalid },
    { 0x274F, opcode::OP_CastBool },
    { 0x2750, opcode::OP_GreaterThan },
    { 0x2751, opcode::OP_Invalid },
    { 0x2752, opcode::OP_Invalid },
    { 0x2753, opcode::OP_GetClasses },
    { 0x2754, opcode::OP_IsDefined },
    { 0x2755, opcode::OP_GetLevelObject },
    { 0x2756, opcode::OP_Invalid },
    { 0x2757, opcode::OP_WaitTill },
    { 0x2758, opcode::OP_Invalid },
    { 0x2759, opcode::OP_Multiply },
    { 0x275A, opcode::OP_EvalFieldVariableRef },
    { 0x275B, opcode::OP_Invalid },
    { 0x275C, opcode::OP_Invalid },
    { 0x275D, opcode::OP_Invalid },
    { 0x275E, opcode::OP_EvalLocalVariableRefCached },
    { 0x275F, opcode::OP_Invalid },
    { 0x2760, opcode::OP_BoolNot },
    { 0x2761, opcode::OP_Invalid },
    { 0x2762, opcode::OP_Invalid },
    { 0x2763, opcode::OP_Invalid },
    { 0x2764, opcode::OP_Invalid },
    { 0x2765, opcode::OP_ShiftLeft },
    { 0x2766, opcode::OP_SetVariableField },
    { 0x2767, opcode::OP_GetAnimation },
    { 0x2768, opcode::OP_Invalid },
    { 0x2769, opcode::OP_Invalid },
    { 0x276A, opcode::OP_Invalid },
    { 0x276B, opcode::OP_GetVector },
    { 0x276C, opcode::OP_NextArrayKey },
    { 0x276D, opcode::OP_RealWait },
    { 0x276E, opcode::OP_SelfEvalFieldVariable },
    { 0x276F, opcode::OP_EndOn },
    { 0x2770, opcode::OP_GetWorld },
    { 0x2771, opcode::OP_WaitTill },
    { 0x2772, opcode::OP_Invalid },
    { 0x2773, opcode::OP_CallBuiltinMethod },
    { 0x2774, opcode::OP_Invalid },
    { 0x2775, opcode::OP_VectorScale },
    { 0x2776, opcode::OP_Return },
    { 0x2777, opcode::OP_GetIString },
    { 0x2778, opcode::OP_Invalid },
    { 0x2779, opcode::OP_Multiply },
    { 0x277A, opcode::OP_SafeDecTop },
    { 0x277B, opcode::OP_Invalid },
    { 0x277C, opcode::OP_SelfEvalFieldVariableRef },
    { 0x277D, opcode::OP_SizeOf },
    { 0x277E, opcode::OP_GetGame },
    { 0x277F, opcode::OP_GetHash },
    { 0x2780, opcode::OP_ScriptMethodThreadCall },
    { 0x2781, opcode::OP_GetUintptr },
    { 0x2782, opcode::OP_Return },
    { 0x2783, opcode::OP_Invalid },
    { 0x2784, opcode::OP_Invalid },
    { 0x2785, opcode::OP_Invalid },
    { 0x2786, opcode::OP_New },
    { 0x2787, opcode::OP_NextArrayKey },
    { 0x2788, opcode::OP_Return },
    { 0x2789, opcode::OP_New },
    { 0x278A, opcode::OP_Invalid },
    { 0x278B, opcode::OP_SuperNotEqual },
    { 0x278C, opcode::OP_Invalid },
    { 0x278D, opcode::OP_Invalid },
    { 0x278E, opcode::OP_Inc },
    { 0x278F, opcode::OP_EvalLocalVariableCached },
    { 0x2790, opcode::OP_EvalLocalVariableRefCached },
    { 0x2791, opcode::OP_WaitTillMatch },
    { 0x2792, opcode::OP_Invalid },
    { 0x2793, opcode::OP_GetFloat },
    { 0x2794, opcode::OP_Invalid },
    { 0x2795, opcode::OP_WaitTillMatch },
    { 0x2796, opcode::OP_WaitTillMatch },
    { 0x2797, opcode::OP_Bit_Xor },
    { 0x2798, opcode::OP_Invalid },
    { 0x2799, opcode::OP_WaitTillMatch },
    { 0x279A, opcode::OP_Invalid },
    { 0x279B, opcode::OP_GreaterThanOrEqualTo },
    { 0x279C, opcode::OP_EndOn },
    { 0x279D, opcode::OP_Invalid },
    { 0x279E, opcode::OP_WaitTillMatch },
    { 0x279F, opcode::OP_Modulus },
    { 0x27A0, opcode::OP_EvalArrayRef },
    { 0x27A1, opcode::OP_Invalid },
    { 0x27A2, opcode::OP_New },
    { 0x27A3, opcode::OP_Invalid },
    { 0x27A4, opcode::OP_ShiftLeft },
    { 0x27A5, opcode::OP_Divide },
    { 0x27A6, opcode::OP_Invalid },
    { 0x27A7, opcode::OP_Equal },
    { 0x27A8, opcode::OP_Invalid },
    { 0x27A9, opcode::OP_GreaterThanOrEqualTo },
    { 0x27AA, opcode::OP_Notify },
    { 0x27AB, opcode::OP_GetHash },
    { 0x27AC, opcode::OP_GetHash },
    { 0x27AD, opcode::OP_ScriptMethodThreadCall },
    { 0x27AE, opcode::OP_Invalid },
    { 0x27AF, opcode::OP_GetNegByte },
    { 0x27B0, opcode::OP_GetHash },
    { 0x27B1, opcode::OP_Invalid },
    { 0x27B2, opcode::OP_GreaterThanOrEqualTo },
    { 0x27B3, opcode::OP_Invalid },
    { 0x27B4, opcode::OP_GetUnsignedShort },
    { 0x27B5, opcode::OP_Modulus },
    { 0x27B6, opcode::OP_Invalid },
    { 0x27B7, opcode::OP_SafeSetVariableFieldCached },
    { 0x27B8, opcode::OP_SafeDecTop },
    { 0x27B9, opcode::OP_Invalid },
    { 0x27BA, opcode::OP_Invalid },
    { 0x27BB, opcode::OP_SafeSetVariableFieldCached },
    { 0x27BC, opcode::OP_GetString },
    { 0x27BD, opcode::OP_SuperEqual },
    { 0x27BE, opcode::OP_JumpOnFalseExpr },
    { 0x27BF, opcode::OP_Invalid },
    { 0x27C0, opcode::OP_ScriptMethodCallPointer },
    { 0x27C1, opcode::OP_Bit_Xor },
    { 0x27C2, opcode::OP_GetInteger },
    { 0x27C3, opcode::OP_Invalid },
    { 0x27C4, opcode::OP_WaitTill },
    { 0x27C5, opcode::OP_ClearFieldVariable },
    { 0x27C6, opcode::OP_SafeCreateLocalVariables },
    { 0x27C7, opcode::OP_SelfEvalFieldVariable },
    { 0x27C8, opcode::OP_GetGameRef },
    { 0x27C9, opcode::OP_Invalid },
    { 0x27CA, opcode::OP_Invalid },
    { 0x27CB, opcode::OP_GetClassesObject },
    { 0x27CC, opcode::OP_WaitTillMatch },
    { 0x27CD, opcode::OP_GreaterThanOrEqualTo },
    { 0x27CE, opcode::OP_GetVector },
    { 0x27CF, opcode::OP_EmptyArray },
    { 0x27D0, opcode::OP_Switch },
    { 0x27D1, opcode::OP_GetAPIFunction },
    { 0x27D2, opcode::OP_GetLevelObject },
    { 0x27D3, opcode::OP_Invalid },
    { 0x27D4, opcode::OP_Bit_And },
    { 0x27D5, opcode::OP_ScriptMethodCall },
    { 0x27D6, opcode::OP_DevblockBegin },
    { 0x27D7, opcode::OP_Invalid },
    { 0x27D8, opcode::OP_Multiply },
    { 0x27D9, opcode::OP_DevblockBegin },
    { 0x27DA, opcode::OP_Invalid },
    { 0x27DB, opcode::OP_GetLevel },
    { 0x27DC, opcode::OP_Invalid },
    { 0x27DD, opcode::OP_GetLevel },
    { 0x27DE, opcode::OP_JumpOnTrue },
    { 0x27DF, opcode::OP_ScriptThreadCall },
    { 0x27E0, opcode::OP_Invalid },
    { 0x27E1, opcode::OP_GetSelfObject },
    { 0x27E2, opcode::OP_Invalid },
    { 0x27E3, opcode::OP_Invalid },
    { 0x27E4, opcode::OP_GetZero },
    { 0x27E5, opcode::OP_Invalid },
    { 0x27E6, opcode::OP_VectorScale },
    { 0x27E7, opcode::OP_Invalid },
    { 0x27E8, opcode::OP_Invalid },
    { 0x27E9, opcode::OP_GetWorld },
    { 0x27EA, opcode::OP_EndSwitch },
    { 0x27EB, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x27EC, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x27ED, opcode::OP_Invalid },
    { 0x27EE, opcode::OP_GetClasses },
    { 0x27EF, opcode::OP_Invalid },
    { 0x27F0, opcode::OP_Jump },
    { 0x27F1, opcode::OP_GreaterThan },
    { 0x27F2, opcode::OP_ScriptThreadCallPointer },
    { 0x27F3, opcode::OP_GetSelf },
    { 0x27F4, opcode::OP_Switch },
    { 0x27F5, opcode::OP_FirstArrayKey },
    { 0x27F6, opcode::OP_Invalid },
    { 0x27F7, opcode::OP_Invalid },
    { 0x27F8, opcode::OP_Invalid },
    { 0x27F9, opcode::OP_Equal },
    { 0x27FA, opcode::OP_Invalid },
    { 0x27FB, opcode::OP_JumpOnTrue },
    { 0x27FC, opcode::OP_GetSelfObject },
    { 0x27FD, opcode::OP_GetFloat },
    { 0x27FE, opcode::OP_Invalid },
    { 0x27FF, opcode::OP_Invalid },
    { 0x2800, opcode::OP_GetUintptr },
    { 0x2801, opcode::OP_Invalid },
    { 0x2802, opcode::OP_EvalLocalVariableRefCached },
    { 0x2803, opcode::OP_IsDefined },
    { 0x2804, opcode::OP_GetUnsignedShort },
    { 0x2805, opcode::OP_EndSwitch },
    { 0x2806, opcode::OP_GetFunction },
    { 0x2807, opcode::OP_GreaterThan },
    { 0x2808, opcode::OP_ProfileStop },
    { 0x2809, opcode::OP_Invalid },
    { 0x280A, opcode::OP_GetUndefined },
    { 0x280B, opcode::OP_Invalid },
    { 0x280C, opcode::OP_SafeCreateLocalVariables },
    { 0x280D, opcode::OP_GetUnsignedShort },
    { 0x280E, opcode::OP_Invalid },
    { 0x280F, opcode::OP_Invalid },
    { 0x2810, opcode::OP_DevblockBegin },
    { 0x2811, opcode::OP_Invalid },
    { 0x2812, opcode::OP_Invalid },
    { 0x2813, opcode::OP_Divide },
    { 0x2814, opcode::OP_SafeSetVariableFieldCached },
    { 0x2815, opcode::OP_Bit_Or },
    { 0x2816, opcode::OP_Invalid },
    { 0x2817, opcode::OP_Invalid },
    { 0x2818, opcode::OP_Bit_And },
    { 0x2819, opcode::OP_GetNegByte },
    { 0x281A, opcode::OP_GetFunction },
    { 0x281B, opcode::OP_ShiftLeft },
    { 0x281C, opcode::OP_Invalid },
    { 0x281D, opcode::OP_NextArrayKey },
    { 0x281E, opcode::OP_GetSelfObject },
    { 0x281F, opcode::OP_GetAnimObject },
    { 0x2820, opcode::OP_ScriptThreadCall },
    { 0x2821, opcode::OP_ScriptThreadCallPointer },
    { 0x2822, opcode::OP_Invalid },
    { 0x2823, opcode::OP_Invalid },
    { 0x2824, opcode::OP_EvalFieldVariable },
    { 0x2825, opcode::OP_GetWorld },
    { 0x2826, opcode::OP_JumpOnTrueExpr },
    { 0x2827, opcode::OP_ShiftLeft },
    { 0x2828, opcode::OP_Invalid },
    { 0x2829, opcode::OP_Invalid },
    { 0x282A, opcode::OP_Plus },
    { 0x282B, opcode::OP_Return },
    { 0x282C, opcode::OP_GetClassesObject },
    { 0x282D, opcode::OP_Invalid },
    { 0x282E, opcode::OP_Invalid },
    { 0x282F, opcode::OP_Return },
    { 0x2830, opcode::OP_ScriptThreadCallPointer },
    { 0x2831, opcode::OP_Bit_Xor },
    { 0x2832, opcode::OP_Invalid },
    { 0x2833, opcode::OP_VectorScale },
    { 0x2834, opcode::OP_GetUndefined },
    { 0x2835, opcode::OP_Equal },
    { 0x2836, opcode::OP_SafeCreateLocalVariables },
    { 0x2837, opcode::OP_Invalid },
    { 0x2838, opcode::OP_Bit_And },
    { 0x2839, opcode::OP_GetNegByte },
    { 0x283A, opcode::OP_Bit_And },
    { 0x283B, opcode::OP_Invalid },
    { 0x283C, opcode::OP_EvalLocalVariableCached },
    { 0x283D, opcode::OP_WaitTillFrameEnd },
    { 0x283E, opcode::OP_Invalid },
    { 0x283F, opcode::OP_Invalid },
    { 0x2840, opcode::OP_Invalid },
    { 0x2841, opcode::OP_Invalid },
    { 0x2842, opcode::OP_Invalid },
    { 0x2843, opcode::OP_Vector },
    { 0x2844, opcode::OP_GetFunction },
    { 0x2845, opcode::OP_GetAnim },
    { 0x2846, opcode::OP_NextArrayKey },
    { 0x2847, opcode::OP_Notify },
    { 0x2848, opcode::OP_EvalFieldVariableRef },
    { 0x2849, opcode::OP_ScriptMethodCall },
    { 0x284A, opcode::OP_GetFunction },
    { 0x284B, opcode::OP_GetUintptr },
    { 0x284C, opcode::OP_Switch },
    { 0x284D, opcode::OP_GetAnimation },
    { 0x284E, opcode::OP_Invalid },
    { 0x284F, opcode::OP_SuperNotEqual },
    { 0x2850, opcode::OP_SelfEvalFieldVariable },
    { 0x2851, opcode::OP_New },
    { 0x2852, opcode::OP_NotEqual },
    { 0x2853, opcode::OP_Invalid },
    { 0x2854, opcode::OP_GetWorldObject },
    { 0x2855, opcode::OP_Invalid },
    { 0x2856, opcode::OP_ShiftLeft },
    { 0x2857, opcode::OP_Bit_Xor },
    { 0x2858, opcode::OP_GetAPIFunction },
    { 0x2859, opcode::OP_Invalid },
    { 0x285A, opcode::OP_GetGameRef },
    { 0x285B, opcode::OP_Invalid },
    { 0x285C, opcode::OP_Invalid },
    { 0x285D, opcode::OP_Invalid },
    { 0x285E, opcode::OP_WaitTillFrameEnd },
    { 0x285F, opcode::OP_Invalid },
    { 0x2860, opcode::OP_Inc },
    { 0x2861, opcode::OP_DevblockBegin },
    { 0x2862, opcode::OP_Invalid },
    { 0x2863, opcode::OP_GetZero },
    { 0x2864, opcode::OP_IsDefined },
    { 0x2865, opcode::OP_Invalid },
    { 0x2866, opcode::OP_BoolNot },
    { 0x2867, opcode::OP_Invalid },
    { 0x2868, opcode::OP_Invalid },
    { 0x2869, opcode::OP_EvalArray },
    { 0x286A, opcode::OP_CallBuiltinMethod },
    { 0x286B, opcode::OP_Invalid },
    { 0x286C, opcode::OP_Invalid },
    { 0x286D, opcode::OP_SafeDecTop },
    { 0x286E, opcode::OP_GetLevel },
    { 0x286F, opcode::OP_ProfileStart },
    { 0x2870, opcode::OP_ScriptFunctionCall },
    { 0x2871, opcode::OP_Invalid },
    { 0x2872, opcode::OP_Invalid },
    { 0x2873, opcode::OP_Return },
    { 0x2874, opcode::OP_SelfEvalFieldVariableRef },
    { 0x2875, opcode::OP_WaitTillMatch },
    { 0x2876, opcode::OP_WaitTillFrameEnd },
    { 0x2877, opcode::OP_Invalid },
    { 0x2878, opcode::OP_GetAnimObject },
    { 0x2879, opcode::OP_GetNegUnsignedShort },
    { 0x287A, opcode::OP_Invalid },
    { 0x287B, opcode::OP_Invalid },
    { 0x287C, opcode::OP_GetVector },
    { 0x287D, opcode::OP_LevelEvalFieldVariable },
    { 0x287E, opcode::OP_GetIString },
    { 0x287F, opcode::OP_EmptyArray },
    { 0x2880, opcode::OP_Invalid },
    { 0x2881, opcode::OP_Equal },
    { 0x2882, opcode::OP_GetLevel },
    { 0x2883, opcode::OP_GetAnim },
    { 0x2884, opcode::OP_Invalid },
    { 0x2885, opcode::OP_Equal },
    { 0x2886, opcode::OP_GetGame },
    { 0x2887, opcode::OP_Invalid },
    { 0x2888, opcode::OP_SelfEvalFieldVariableRef },
    { 0x2889, opcode::OP_Invalid },
    { 0x288A, opcode::OP_GetAnimObject },
    { 0x288B, opcode::OP_GetAnim },
    { 0x288C, opcode::OP_Switch },
    { 0x288D, opcode::OP_Minus },
    { 0x288E, opcode::OP_LevelEvalFieldVariable },
    { 0x288F, opcode::OP_SizeOf },
    { 0x2890, opcode::OP_GetString },
    { 0x2891, opcode::OP_Invalid },
    { 0x2892, opcode::OP_New },
    { 0x2893, opcode::OP_EndSwitch },
    { 0x2894, opcode::OP_Invalid },
    { 0x2895, opcode::OP_IsDefined },
    { 0x2896, opcode::OP_GreaterThanOrEqualTo },
    { 0x2897, opcode::OP_GetLevel },
    { 0x2898, opcode::OP_SafeCreateLocalVariables },
    { 0x2899, opcode::OP_Invalid },
    { 0x289A, opcode::OP_WaitTillMatch },
    { 0x289B, opcode::OP_GetAPIFunction },
    { 0x289C, opcode::OP_IsDefined },
    { 0x289D, opcode::OP_Invalid },
    { 0x289E, opcode::OP_Invalid },
    { 0x289F, opcode::OP_Bit_And },
    { 0x28A0, opcode::OP_Minus },
    { 0x28A1, opcode::OP_EmptyArray },
    { 0x28A2, opcode::OP_JumpOnFalse },
    { 0x28A3, opcode::OP_JumpOnFalse },
    { 0x28A4, opcode::OP_Bit_Xor },
    { 0x28A5, opcode::OP_Invalid },
    { 0x28A6, opcode::OP_Invalid },
    { 0x28A7, opcode::OP_GetAnim },
    { 0x28A8, opcode::OP_Invalid },
    { 0x28A9, opcode::OP_Invalid },
    { 0x28AA, opcode::OP_JumpOnTrueExpr },
    { 0x28AB, opcode::OP_GetUnsignedShort },
    { 0x28AC, opcode::OP_Invalid },
    { 0x28AD, opcode::OP_LessThanOrEqualTo },
    { 0x28AE, opcode::OP_Invalid },
    { 0x28AF, opcode::OP_EmptyArray },
    { 0x28B0, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x28B1, opcode::OP_Invalid },
    { 0x28B2, opcode::OP_SelfEvalFieldVariable },
    { 0x28B3, opcode::OP_SelfEvalFieldVariable },
    { 0x28B4, opcode::OP_WaitTillMatch },
    { 0x28B5, opcode::OP_GetByte },
    { 0x28B6, opcode::OP_GreaterThan },
    { 0x28B7, opcode::OP_Inc },
    { 0x28B8, opcode::OP_GetSelfObject },
    { 0x28B9, opcode::OP_Invalid },
    { 0x28BA, opcode::OP_Invalid },
    { 0x28BB, opcode::OP_SetVariableField },
    { 0x28BC, opcode::OP_Invalid },
    { 0x28BD, opcode::OP_FirstArrayKey },
    { 0x28BE, opcode::OP_Invalid },
    { 0x28BF, opcode::OP_ScriptFunctionCall },
    { 0x28C0, opcode::OP_LessThan },
    { 0x28C1, opcode::OP_GetClassesObject },
    { 0x28C2, opcode::OP_JumpOnFalseExpr },
    { 0x28C3, opcode::OP_CallBuiltinMethod },
    { 0x28C4, opcode::OP_GetClasses },
    { 0x28C5, opcode::OP_GetUintptr },
    { 0x28C6, opcode::OP_Invalid },
    { 0x28C7, opcode::OP_WaitTillMatch },
    { 0x28C8, opcode::OP_Invalid },
    { 0x28C9, opcode::OP_NotEqual },
    { 0x28CA, opcode::OP_SizeOf },
    { 0x28CB, opcode::OP_Invalid },
    { 0x28CC, opcode::OP_GetSelf },
    { 0x28CD, opcode::OP_Invalid },
    { 0x28CE, opcode::OP_VectorConstant },
    { 0x28CF, opcode::OP_SelfEvalFieldVariableRef },
    { 0x28D0, opcode::OP_RealWait },
    { 0x28D1, opcode::OP_ScriptMethodCallPointer },
    { 0x28D2, opcode::OP_LessThan },
    { 0x28D3, opcode::OP_Invalid },
    { 0x28D4, opcode::OP_Invalid },
    { 0x28D5, opcode::OP_Invalid },
    { 0x28D6, opcode::OP_VectorConstant },
    { 0x28D7, opcode::OP_ScriptThreadCallPointer },
    { 0x28D8, opcode::OP_GetLevelObject },
    { 0x28D9, opcode::OP_EvalArray },
    { 0x28DA, opcode::OP_EvalFieldVariable },
    { 0x28DB, opcode::OP_ScriptThreadCall },
    { 0x28DC, opcode::OP_Invalid },
    { 0x28DD, opcode::OP_ProfileStop },
    { 0x28DE, opcode::OP_Bit_Xor },
    { 0x28DF, opcode::OP_GetString },
    { 0x28E0, opcode::OP_JumpOnTrue },
    { 0x28E1, opcode::OP_BoolNot },
    { 0x28E2, opcode::OP_Invalid },
    { 0x28E3, opcode::OP_ScriptFunctionCall },
    { 0x28E4, opcode::OP_Invalid },
    { 0x28E5, opcode::OP_Invalid },
    { 0x28E6, opcode::OP_BoolComplement },
    { 0x28E7, opcode::OP_GetVector },
    { 0x28E8, opcode::OP_ShiftLeft },
    { 0x28E9, opcode::OP_LessThanOrEqualTo },
    { 0x28EA, opcode::OP_LessThan },
    { 0x28EB, opcode::OP_Invalid },
    { 0x28EC, opcode::OP_Dec },
    { 0x28ED, opcode::OP_Jump },
    { 0x28EE, opcode::OP_WaitTill },
    { 0x28EF, opcode::OP_GetIString },
    { 0x28F0, opcode::OP_Invalid },
    { 0x28F1, opcode::OP_BoolNot },
    { 0x28F2, opcode::OP_Invalid },
    { 0x28F3, opcode::OP_LevelEvalFieldVariable },
    { 0x28F4, opcode::OP_Invalid },
    { 0x28F5, opcode::OP_BoolComplement },
    { 0x28F6, opcode::OP_VectorScale },
    { 0x28F7, opcode::OP_New },
    { 0x28F8, opcode::OP_GetAPIFunction },
    { 0x28F9, opcode::OP_GreaterThan },
    { 0x28FA, opcode::OP_VectorScale },
    { 0x28FB, opcode::OP_GetWorldObject },
    { 0x28FC, opcode::OP_Invalid },
    { 0x28FD, opcode::OP_Invalid },
    { 0x28FE, opcode::OP_LessThanOrEqualTo },
    { 0x28FF, opcode::OP_New },
    { 0x2900, opcode::OP_VectorConstant },
    { 0x2901, opcode::OP_ScriptFunctionCallPointer },
    { 0x2902, opcode::OP_GetWorld },
    { 0x2903, opcode::OP_IsDefined },
    { 0x2904, opcode::OP_WaitTill },
    { 0x2905, opcode::OP_VectorConstant },
    { 0x2906, opcode::OP_ScriptFunctionCallClass },
    { 0x2907, opcode::OP_Plus },
    { 0x2908, opcode::OP_LessThanOrEqualTo },
    { 0x2909, opcode::OP_GetSelfObject },
    { 0x290A, opcode::OP_JumpOnFalse },
    { 0x290B, opcode::OP_ScriptThreadCallClass },
    { 0x290C, opcode::OP_Invalid },
    { 0x290D, opcode::OP_Notify },
    { 0x290E, opcode::OP_Invalid },
    { 0x290F, opcode::OP_SafeSetVariableFieldCached },
    { 0x2910, opcode::OP_ScriptThreadCall },
    { 0x2911, opcode::OP_Invalid },
    { 0x2912, opcode::OP_Invalid },
    { 0x2913, opcode::OP_GetIString },
    { 0x2914, opcode::OP_Invalid },
    { 0x2915, opcode::OP_GetAnimation },
    { 0x2916, opcode::OP_LessThan },
    { 0x2917, opcode::OP_JumpOnTrue },
    { 0x2918, opcode::OP_Bit_Or },
    { 0x2919, opcode::OP_Invalid },
    { 0x291A, opcode::OP_Invalid },
    { 0x291B, opcode::OP_SizeOf },
    { 0x291C, opcode::OP_Inc },
    { 0x291D, opcode::OP_Invalid },
    { 0x291E, opcode::OP_Invalid },
    { 0x291F, opcode::OP_Invalid },
    { 0x2920, opcode::OP_New },
    { 0x2921, opcode::OP_Invalid },
    { 0x2922, opcode::OP_GetWorld },
    { 0x2923, opcode::OP_BoolComplement },
    { 0x2924, opcode::OP_Invalid },
    { 0x2925, opcode::OP_Wait },
    { 0x2926, opcode::OP_Invalid },
    { 0x2927, opcode::OP_Invalid },
    { 0x2928, opcode::OP_Equal },
    { 0x2929, opcode::OP_GetAnim },
    { 0x292A, opcode::OP_CallBuiltinMethod },
    { 0x292B, opcode::OP_EvalLocalVariableCached },
    { 0x292C, opcode::OP_EvalLocalVariableCached },
    { 0x292D, opcode::OP_ShiftLeft },
    { 0x292E, opcode::OP_NextArrayKey },
    { 0x292F, opcode::OP_Switch },
    { 0x2930, opcode::OP_Invalid },
    { 0x2931, opcode::OP_GetVector },
    { 0x2932, opcode::OP_Invalid },
    { 0x2933, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x2934, opcode::OP_JumpOnTrue },
    { 0x2935, opcode::OP_EvalFieldVariableRef },
    { 0x2936, opcode::OP_Invalid },
    { 0x2937, opcode::OP_GetAnimObject },
    { 0x2938, opcode::OP_New },
    { 0x2939, opcode::OP_ScriptFunctionCall },
    { 0x293A, opcode::OP_New },
    { 0x293B, opcode::OP_WaitTill },
    { 0x293C, opcode::OP_Invalid },
    { 0x293D, opcode::OP_SizeOf },
    { 0x293E, opcode::OP_GreaterThanOrEqualTo },
    { 0x293F, opcode::OP_Invalid },
    { 0x2940, opcode::OP_Invalid },
    { 0x2941, opcode::OP_Dec },
    { 0x2942, opcode::OP_ScriptMethodCall },
    { 0x2943, opcode::OP_Invalid },
    { 0x2944, opcode::OP_GetGame },
    { 0x2945, opcode::OP_Invalid },
    { 0x2946, opcode::OP_Invalid },
    { 0x2947, opcode::OP_Vector },
    { 0x2948, opcode::OP_SetVariableField },
    { 0x2949, opcode::OP_ScriptThreadCallPointer },
    { 0x294A, opcode::OP_GetHash },
    { 0x294B, opcode::OP_EvalFieldVariableRef },
    { 0x294C, opcode::OP_ScriptFunctionCallPointer },
    { 0x294D, opcode::OP_Invalid },
    { 0x294E, opcode::OP_LevelEvalFieldVariableRef },
    { 0x294F, opcode::OP_Invalid },
    { 0x2950, opcode::OP_GetWorldObject },
    { 0x2951, opcode::OP_Invalid },
    { 0x2952, opcode::OP_Invalid },
    { 0x2953, opcode::OP_Invalid },
    { 0x2954, opcode::OP_EvalFieldVariable },
    { 0x2955, opcode::OP_Invalid },
    { 0x2956, opcode::OP_GetTime },
    { 0x2957, opcode::OP_EvalFieldVariable },
    { 0x2958, opcode::OP_Invalid },
    { 0x2959, opcode::OP_GetFloat },
    { 0x295A, opcode::OP_SetVariableField },
    { 0x295B, opcode::OP_Bit_Or },
    { 0x295C, opcode::OP_EvalArray },
    { 0x295D, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x295E, opcode::OP_VectorScale },
    { 0x295F, opcode::OP_ScriptMethodCall },
    { 0x2960, opcode::OP_Divide },
    { 0x2961, opcode::OP_NextArrayKey },
    { 0x2962, opcode::OP_Invalid },
    { 0x2963, opcode::OP_EvalArray },
    { 0x2964, opcode::OP_Invalid },
    { 0x2965, opcode::OP_Invalid },
    { 0x2966, opcode::OP_Bit_And },
    { 0x2967, opcode::OP_Equal },
    { 0x2968, opcode::OP_Invalid },
    { 0x2969, opcode::OP_SafeSetVariableFieldCached },
    { 0x296A, opcode::OP_Minus },
    { 0x296B, opcode::OP_FirstArrayKey },
    { 0x296C, opcode::OP_Invalid },
    { 0x296D, opcode::OP_Plus },
    { 0x296E, opcode::OP_GetLevel },
    { 0x296F, opcode::OP_GetAPIFunction },
    { 0x2970, opcode::OP_ProfileStart },
    { 0x2971, opcode::OP_Invalid },
    { 0x2972, opcode::OP_WaitTillFrameEnd },
    { 0x2973, opcode::OP_BoolComplement },
    { 0x2974, opcode::OP_Invalid },
    { 0x2975, opcode::OP_Invalid },
    { 0x2976, opcode::OP_Notify },
    { 0x2977, opcode::OP_Invalid },
    { 0x2978, opcode::OP_GetHash },
    { 0x2979, opcode::OP_GetAnimObject },
    { 0x297A, opcode::OP_ScriptThreadCall },
    { 0x297B, opcode::OP_Invalid },
    { 0x297C, opcode::OP_Invalid },
    { 0x297D, opcode::OP_Bit_And },
    { 0x297E, opcode::OP_EvalFieldVariableRef },
    { 0x297F, opcode::OP_JumpOnTrueExpr },
    { 0x2980, opcode::OP_Bit_Xor },
    { 0x2981, opcode::OP_Invalid },
    { 0x2982, opcode::OP_GetSelfObject },
    { 0x2983, opcode::OP_Invalid },
    { 0x2984, opcode::OP_Invalid },
    { 0x2985, opcode::OP_GetFunction },
    { 0x2986, opcode::OP_GetAnimObject },
    { 0x2987, opcode::OP_GetUnsignedShort },
    { 0x2988, opcode::OP_Invalid },
    { 0x2989, opcode::OP_Invalid },
    { 0x298A, opcode::OP_ScriptFunctionCall },
    { 0x298B, opcode::OP_EvalLocalVariableCached },
    { 0x298C, opcode::OP_Invalid },
    { 0x298D, opcode::OP_ScriptMethodThreadCall },
    { 0x298E, opcode::OP_Invalid },
    { 0x298F, opcode::OP_Invalid },
    { 0x2990, opcode::OP_EvalArray },
    { 0x2991, opcode::OP_GetNegUnsignedShort },
    { 0x2992, opcode::OP_EvalArray },
    { 0x2993, opcode::OP_Invalid },
    { 0x2994, opcode::OP_Invalid },
    { 0x2995, opcode::OP_Invalid },
    { 0x2996, opcode::OP_Invalid },
    { 0x2997, opcode::OP_GetUintptr },
    { 0x2998, opcode::OP_GetGameRef },
    { 0x2999, opcode::OP_Invalid },
    { 0x299A, opcode::OP_EvalFieldVariableRef },
    { 0x299B, opcode::OP_JumpOnFalse },
    { 0x299C, opcode::OP_GetIString },
    { 0x299D, opcode::OP_Jump },
    { 0x299E, opcode::OP_GetZero },
    { 0x299F, opcode::OP_GreaterThanOrEqualTo },
    { 0x29A0, opcode::OP_Invalid },
    { 0x29A1, opcode::OP_Invalid },
    { 0x29A2, opcode::OP_Invalid },
    { 0x29A3, opcode::OP_Invalid },
    { 0x29A4, opcode::OP_Invalid },
    { 0x29A5, opcode::OP_GetWorldObject },
    { 0x29A6, opcode::OP_LevelEvalFieldVariable },
    { 0x29A7, opcode::OP_WaitTillMatch },
    { 0x29A8, opcode::OP_GetString },
    { 0x29A9, opcode::OP_Invalid },
    { 0x29AA, opcode::OP_Invalid },
    { 0x29AB, opcode::OP_IsDefined },
    { 0x29AC, opcode::OP_EvalArray },
    { 0x29AD, opcode::OP_GetNegByte },
    { 0x29AE, opcode::OP_GetGame },
    { 0x29AF, opcode::OP_WaitTillMatch },
    { 0x29B0, opcode::OP_Invalid },
    { 0x29B1, opcode::OP_Wait },
    { 0x29B2, opcode::OP_Invalid },
    { 0x29B3, opcode::OP_Invalid },
    { 0x29B4, opcode::OP_EndSwitch },
    { 0x29B5, opcode::OP_GetString },
    { 0x29B6, opcode::OP_Wait },
    { 0x29B7, opcode::OP_Minus },
    { 0x29B8, opcode::OP_Invalid },
    { 0x29B9, opcode::OP_Invalid },
    { 0x29BA, opcode::OP_GetLevel },
    { 0x29BB, opcode::OP_ScriptThreadCallClass },
    { 0x29BC, opcode::OP_Minus },
    { 0x29BD, opcode::OP_BoolNot },
    { 0x29BE, opcode::OP_Invalid },
    { 0x29BF, opcode::OP_EvalFieldVariableRef },
    { 0x29C0, opcode::OP_ScriptMethodCallPointer },
    { 0x29C1, opcode::OP_Wait },
    { 0x29C2, opcode::OP_RealWait },
    { 0x29C3, opcode::OP_EvalFieldVariableRef },
    { 0x29C4, opcode::OP_Invalid },
    { 0x29C5, opcode::OP_LessThanOrEqualTo },
    { 0x29C6, opcode::OP_SelfEvalFieldVariable },
    { 0x29C7, opcode::OP_Invalid },
    { 0x29C8, opcode::OP_ScriptMethodCall },
    { 0x29C9, opcode::OP_Invalid },
    { 0x29CA, opcode::OP_WaitTillFrameEnd },
    { 0x29CB, opcode::OP_EmptyArray },
    { 0x29CC, opcode::OP_GreaterThan },
    { 0x29CD, opcode::OP_Bit_And },
    { 0x29CE, opcode::OP_EvalArray },
    { 0x29CF, opcode::OP_ProfileStop },
    { 0x29D0, opcode::OP_Invalid },
    { 0x29D1, opcode::OP_Notify },
    { 0x29D2, opcode::OP_VectorConstant },
    { 0x29D3, opcode::OP_ClearFieldVariable },
    { 0x29D4, opcode::OP_Plus },
    { 0x29D5, opcode::OP_Invalid },
    { 0x29D6, opcode::OP_SafeDecTop },
    { 0x29D7, opcode::OP_VectorConstant },
    { 0x29D8, opcode::OP_Invalid },
    { 0x29D9, opcode::OP_EvalLocalVariableRefCached },
    { 0x29DA, opcode::OP_GetAnimObject },
    { 0x29DB, opcode::OP_SafeCreateLocalVariables },
    { 0x29DC, opcode::OP_GetSelf },
    { 0x29DD, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x29DE, opcode::OP_GetClassesObject },
    { 0x29DF, opcode::OP_Invalid },
    { 0x29E0, opcode::OP_SelfEvalFieldVariableRef },
    { 0x29E1, opcode::OP_Invalid },
    { 0x29E2, opcode::OP_Invalid },
    { 0x29E3, opcode::OP_GetByte },
    { 0x29E4, opcode::OP_GreaterThan },
    { 0x29E5, opcode::OP_ScriptFunctionCall },
    { 0x29E6, opcode::OP_Inc },
    { 0x29E7, opcode::OP_EndSwitch },
    { 0x29E8, opcode::OP_SizeOf },
    { 0x29E9, opcode::OP_Invalid },
    { 0x29EA, opcode::OP_Invalid },
    { 0x29EB, opcode::OP_Invalid },
    { 0x29EC, opcode::OP_LessThan },
    { 0x29ED, opcode::OP_Invalid },
    { 0x29EE, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x29EF, opcode::OP_Invalid },
    { 0x29F0, opcode::OP_Invalid },
    { 0x29F1, opcode::OP_ScriptThreadCallPointer },
    { 0x29F2, opcode::OP_WaitTillFrameEnd },
    { 0x29F3, opcode::OP_Invalid },
    { 0x29F4, opcode::OP_SelfEvalFieldVariableRef },
    { 0x29F5, opcode::OP_ScriptFunctionCall },
    { 0x29F6, opcode::OP_SelfEvalFieldVariable },
    { 0x29F7, opcode::OP_Invalid },
    { 0x29F8, opcode::OP_ClearArray },
    { 0x29F9, opcode::OP_CallBuiltinMethod },
    { 0x29FA, opcode::OP_Invalid },
    { 0x29FB, opcode::OP_LevelEvalFieldVariable },
    { 0x29FC, opcode::OP_GetZero },
    { 0x29FD, opcode::OP_Invalid },
    { 0x29FE, opcode::OP_Invalid },
    { 0x29FF, opcode::OP_Invalid },
    { 0x2A00, opcode::OP_Invalid },
    { 0x2A01, opcode::OP_Invalid },
    { 0x2A02, opcode::OP_CallBuiltinMethod },
    { 0x2A03, opcode::OP_Invalid },
    { 0x2A04, opcode::OP_Invalid },
    { 0x2A05, opcode::OP_GetUndefined },
    { 0x2A06, opcode::OP_EvalLocalVariableRefCached },
    { 0x2A07, opcode::OP_Invalid },
    { 0x2A08, opcode::OP_RealWait },
    { 0x2A09, opcode::OP_SelfEvalFieldVariable },
    { 0x2A0A, opcode::OP_GreaterThan },
    { 0x2A0B, opcode::OP_Invalid },
    { 0x2A0C, opcode::OP_Invalid },
    { 0x2A0D, opcode::OP_JumpOnFalseExpr },
    { 0x2A0E, opcode::OP_Invalid },
    { 0x2A0F, opcode::OP_Invalid },
    { 0x2A10, opcode::OP_GetAnim },
    { 0x2A11, opcode::OP_ScriptFunctionCallPointer },
    { 0x2A12, opcode::OP_FirstArrayKey },
    { 0x2A13, opcode::OP_ScriptFunctionCallPointer },
    { 0x2A14, opcode::OP_Invalid },
    { 0x2A15, opcode::OP_GetFloat },
    { 0x2A16, opcode::OP_Invalid },
    { 0x2A17, opcode::OP_Invalid },
    { 0x2A18, opcode::OP_Invalid },
    { 0x2A19, opcode::OP_ClearFieldVariable },
    { 0x2A1A, opcode::OP_Invalid },
    { 0x2A1B, opcode::OP_WaitTillFrameEnd },
    { 0x2A1C, opcode::OP_VectorConstant },
    { 0x2A1D, opcode::OP_LessThan },
    { 0x2A1E, opcode::OP_Bit_And },
    { 0x2A1F, opcode::OP_ShiftRight },
    { 0x2A20, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x2A21, opcode::OP_Invalid },
    { 0x2A22, opcode::OP_Invalid },
    { 0x2A23, opcode::OP_BoolNot },
    { 0x2A24, opcode::OP_JumpOnTrue },
    { 0x2A25, opcode::OP_SizeOf },
    { 0x2A26, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x2A27, opcode::OP_GetSelf },
    { 0x2A28, opcode::OP_Invalid },
    { 0x2A29, opcode::OP_Invalid },
    { 0x2A2A, opcode::OP_GetClasses },
    { 0x2A2B, opcode::OP_Notify },
    { 0x2A2C, opcode::OP_ClearFieldVariable },
    { 0x2A2D, opcode::OP_JumpOnFalse },
    { 0x2A2E, opcode::OP_ShiftRight },
    { 0x2A2F, opcode::OP_Invalid },
    { 0x2A30, opcode::OP_Bit_And },
    { 0x2A31, opcode::OP_LessThan },
    { 0x2A32, opcode::OP_GetSelf },
    { 0x2A33, opcode::OP_EvalFieldVariableRef },
    { 0x2A34, opcode::OP_GetUnsignedShort },
    { 0x2A35, opcode::OP_EvalLocalVariableRefCached },
    { 0x2A36, opcode::OP_IsDefined },
    { 0x2A37, opcode::OP_GetAPIFunction },
    { 0x2A38, opcode::OP_JumpOnTrue },
    { 0x2A39, opcode::OP_GetGame },
    { 0x2A3A, opcode::OP_Invalid },
    { 0x2A3B, opcode::OP_Invalid },
    { 0x2A3C, opcode::OP_EndSwitch },
    { 0x2A3D, opcode::OP_GetUndefined },
    { 0x2A3E, opcode::OP_Wait },
    { 0x2A3F, opcode::OP_Invalid },
    { 0x2A40, opcode::OP_WaitTill },
    { 0x2A41, opcode::OP_Inc },
    { 0x2A42, opcode::OP_Bit_Xor },
    { 0x2A43, opcode::OP_GetAnim },
    { 0x2A44, opcode::OP_Invalid },
    { 0x2A45, opcode::OP_GetWorld },
    { 0x2A46, opcode::OP_GetInteger },
    { 0x2A47, opcode::OP_EndOn },
    { 0x2A48, opcode::OP_SafeDecTop },
    { 0x2A49, opcode::OP_WaitTill },
    { 0x2A4A, opcode::OP_GetAnimation },
    { 0x2A4B, opcode::OP_EndSwitch },
    { 0x2A4C, opcode::OP_Wait },
    { 0x2A4D, opcode::OP_Modulus },
    { 0x2A4E, opcode::OP_RealWait },
    { 0x2A4F, opcode::OP_Invalid },
    { 0x2A50, opcode::OP_SelfEvalFieldVariableRef },
    { 0x2A51, opcode::OP_Invalid },
    { 0x2A52, opcode::OP_FirstArrayKey },
    { 0x2A53, opcode::OP_Bit_Xor },
    { 0x2A54, opcode::OP_Invalid },
    { 0x2A55, opcode::OP_GetSelfObject },
    { 0x2A56, opcode::OP_GetUintptr },
    { 0x2A57, opcode::OP_GetSelfObject },
    { 0x2A58, opcode::OP_WaitTillMatch },
    { 0x2A59, opcode::OP_EvalLocalVariableCached },
    { 0x2A5A, opcode::OP_Invalid },
    { 0x2A5B, opcode::OP_CastBool },
    { 0x2A5C, opcode::OP_FirstArrayKey },
    { 0x2A5D, opcode::OP_GetString },
    { 0x2A5E, opcode::OP_Notify },
    { 0x2A5F, opcode::OP_LessThanOrEqualTo },
    { 0x2A60, opcode::OP_EvalFieldVariable },
    { 0x2A61, opcode::OP_Invalid },
    { 0x2A62, opcode::OP_Invalid },
    { 0x2A63, opcode::OP_Invalid },
    { 0x2A64, opcode::OP_Invalid },
    { 0x2A65, opcode::OP_Invalid },
    { 0x2A66, opcode::OP_GreaterThan },
    { 0x2A67, opcode::OP_SafeCreateLocalVariables },
    { 0x2A68, opcode::OP_Invalid },
    { 0x2A69, opcode::OP_EvalLocalVariableRefCached },
    { 0x2A6A, opcode::OP_GetLevel },
    { 0x2A6B, opcode::OP_Dec },
    { 0x2A6C, opcode::OP_Invalid },
    { 0x2A6D, opcode::OP_Invalid },
    { 0x2A6E, opcode::OP_ScriptThreadCallPointer },
    { 0x2A6F, opcode::OP_Invalid },
    { 0x2A70, opcode::OP_SuperEqual },
    { 0x2A71, opcode::OP_GetLevelObject },
    { 0x2A72, opcode::OP_Invalid },
    { 0x2A73, opcode::OP_SelfEvalFieldVariableRef },
    { 0x2A74, opcode::OP_Invalid },
    { 0x2A75, opcode::OP_EvalLocalVariableCached },
    { 0x2A76, opcode::OP_Invalid },
    { 0x2A77, opcode::OP_Invalid },
    { 0x2A78, opcode::OP_GetGame },
    { 0x2A79, opcode::OP_Invalid },
    { 0x2A7A, opcode::OP_GetTime },
    { 0x2A7B, opcode::OP_Equal },
    { 0x2A7C, opcode::OP_Invalid },
    { 0x2A7D, opcode::OP_Invalid },
    { 0x2A7E, opcode::OP_Invalid },
    { 0x2A7F, opcode::OP_Switch },
    { 0x2A80, opcode::OP_Invalid },
    { 0x2A81, opcode::OP_Invalid },
    { 0x2A82, opcode::OP_Bit_Xor },
    { 0x2A83, opcode::OP_Invalid },
    { 0x2A84, opcode::OP_Invalid },
    { 0x2A85, opcode::OP_Invalid },
    { 0x2A86, opcode::OP_GetInteger },
    { 0x2A87, opcode::OP_DevblockBegin },
    { 0x2A88, opcode::OP_GetFloat },
    { 0x2A89, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x2A8A, opcode::OP_Invalid },
    { 0x2A8B, opcode::OP_Invalid },
    { 0x2A8C, opcode::OP_Invalid },
    { 0x2A8D, opcode::OP_Invalid },
    { 0x2A8E, opcode::OP_EndOn },
    { 0x2A8F, opcode::OP_Invalid },
    { 0x2A90, opcode::OP_GreaterThanOrEqualTo },
    { 0x2A91, opcode::OP_Invalid },
    { 0x2A92, opcode::OP_Multiply },
    { 0x2A93, opcode::OP_EvalArrayRef },
    { 0x2A94, opcode::OP_Invalid },
    { 0x2A95, opcode::OP_CastBool },
    { 0x2A96, opcode::OP_DevblockBegin },
    { 0x2A97, opcode::OP_Invalid },
    { 0x2A98, opcode::OP_Invalid },
    { 0x2A99, opcode::OP_LessThanOrEqualTo },
    { 0x2A9A, opcode::OP_SelfEvalFieldVariable },
    { 0x2A9B, opcode::OP_Invalid },
    { 0x2A9C, opcode::OP_EvalLocalVariableCached },
    { 0x2A9D, opcode::OP_Invalid },
    { 0x2A9E, opcode::OP_Invalid },
    { 0x2A9F, opcode::OP_GetGame },
    { 0x2AA0, opcode::OP_Return },
    { 0x2AA1, opcode::OP_Invalid },
    { 0x2AA2, opcode::OP_SelfEvalFieldVariable },
    { 0x2AA3, opcode::OP_Bit_And },
    { 0x2AA4, opcode::OP_Invalid },
    { 0x2AA5, opcode::OP_SuperNotEqual },
    { 0x2AA6, opcode::OP_Multiply },
    { 0x2AA7, opcode::OP_EndSwitch },
    { 0x2AA8, opcode::OP_Invalid },
    { 0x2AA9, opcode::OP_SelfEvalFieldVariable },
    { 0x2AAA, opcode::OP_Invalid },
    { 0x2AAB, opcode::OP_Invalid },
    { 0x2AAC, opcode::OP_LevelEvalFieldVariable },
    { 0x2AAD, opcode::OP_ShiftRight },
    { 0x2AAE, opcode::OP_GetNegByte },
    { 0x2AAF, opcode::OP_Invalid },
    { 0x2AB0, opcode::OP_Invalid },
    { 0x2AB1, opcode::OP_GetLevel },
    { 0x2AB2, opcode::OP_Bit_Xor },
    { 0x2AB3, opcode::OP_EvalLocalVariableRefCached },
    { 0x2AB4, opcode::OP_JumpOnFalse },
    { 0x2AB5, opcode::OP_Inc },
    { 0x2AB6, opcode::OP_GetGame },
    { 0x2AB7, opcode::OP_GetUnsignedShort },
    { 0x2AB8, opcode::OP_SuperNotEqual },
    { 0x2AB9, opcode::OP_LevelEvalFieldVariable },
    { 0x2ABA, opcode::OP_GetSelf },
    { 0x2ABB, opcode::OP_Invalid },
    { 0x2ABC, opcode::OP_GetIString },
    { 0x2ABD, opcode::OP_Invalid },
    { 0x2ABE, opcode::OP_Invalid },
    { 0x2ABF, opcode::OP_Invalid },
    { 0x2AC0, opcode::OP_GetUnsignedShort },
    { 0x2AC1, opcode::OP_Invalid },
    { 0x2AC2, opcode::OP_Bit_And },
    { 0x2AC3, opcode::OP_Inc },
    { 0x2AC4, opcode::OP_BoolNot },
    { 0x2AC5, opcode::OP_NotEqual },
    { 0x2AC6, opcode::OP_GetUnsignedShort },
    { 0x2AC7, opcode::OP_GetVector },
    { 0x2AC8, opcode::OP_GetUndefined },
    { 0x2AC9, opcode::OP_Invalid },
    { 0x2ACA, opcode::OP_CastFieldObject },
    { 0x2ACB, opcode::OP_ScriptFunctionCall },
    { 0x2ACC, opcode::OP_Invalid },
    { 0x2ACD, opcode::OP_LevelEvalFieldVariable },
    { 0x2ACE, opcode::OP_FirstArrayKey },
    { 0x2ACF, opcode::OP_Invalid },
    { 0x2AD0, opcode::OP_Invalid },
    { 0x2AD1, opcode::OP_GetUndefined },
    { 0x2AD2, opcode::OP_Invalid },
    { 0x2AD3, opcode::OP_SafeDecTop },
    { 0x2AD4, opcode::OP_GetUndefined },
    { 0x2AD5, opcode::OP_Invalid },
    { 0x2AD6, opcode::OP_EvalArrayRef },
    { 0x2AD7, opcode::OP_Bit_Xor },
    { 0x2AD8, opcode::OP_EvalLocalVariableRefCached },
    { 0x2AD9, opcode::OP_SafeDecTop },
    { 0x2ADA, opcode::OP_Invalid },
    { 0x2ADB, opcode::OP_GreaterThan },
    { 0x2ADC, opcode::OP_GetSelf },
    { 0x2ADD, opcode::OP_Invalid },
    { 0x2ADE, opcode::OP_Invalid },
    { 0x2ADF, opcode::OP_Invalid },
    { 0x2AE0, opcode::OP_ShiftLeft },
    { 0x2AE1, opcode::OP_GetClassesObject },
    { 0x2AE2, opcode::OP_GetVector },
    { 0x2AE3, opcode::OP_Invalid },
    { 0x2AE4, opcode::OP_Bit_Xor },
    { 0x2AE5, opcode::OP_Invalid },
    { 0x2AE6, opcode::OP_Invalid },
    { 0x2AE7, opcode::OP_JumpOnFalseExpr },
    { 0x2AE8, opcode::OP_GreaterThan },
    { 0x2AE9, opcode::OP_GetAnim },
    { 0x2AEA, opcode::OP_Minus },
    { 0x2AEB, opcode::OP_GetString },
    { 0x2AEC, opcode::OP_Invalid },
    { 0x2AED, opcode::OP_EvalLocalVariableRefCached },
    { 0x2AEE, opcode::OP_EmptyArray },
    { 0x2AEF, opcode::OP_Modulus },
    { 0x2AF0, opcode::OP_GetWorldObject },
    { 0x2AF1, opcode::OP_GetAnimation },
    { 0x2AF2, opcode::OP_Invalid },
    { 0x2AF3, opcode::OP_GetGame },
    { 0x2AF4, opcode::OP_GetAnimation },
    { 0x2AF5, opcode::OP_Invalid },
    { 0x2AF6, opcode::OP_Return },
    { 0x2AF7, opcode::OP_Minus },
    { 0x2AF8, opcode::OP_Invalid },
    { 0x2AF9, opcode::OP_Invalid },
    { 0x2AFA, opcode::OP_EmptyArray },
    { 0x2AFB, opcode::OP_Invalid },
    { 0x2AFC, opcode::OP_JumpOnTrue },
    { 0x2AFD, opcode::OP_Invalid },
    { 0x2AFE, opcode::OP_GetWorldObject },
    { 0x2AFF, opcode::OP_BoolComplement },
    { 0x2B00, opcode::OP_Invalid },
    { 0x2B01, opcode::OP_Invalid },
    { 0x2B02, opcode::OP_Invalid },
    { 0x2B03, opcode::OP_Divide },
    { 0x2B04, opcode::OP_Invalid },
    { 0x2B05, opcode::OP_SafeDecTop },
    { 0x2B06, opcode::OP_Invalid },
    { 0x2B07, opcode::OP_Invalid },
    { 0x2B08, opcode::OP_ProfileStart },
    { 0x2B09, opcode::OP_ScriptFunctionCallPointer },
    { 0x2B0A, opcode::OP_EvalArrayRef },
    { 0x2B0B, opcode::OP_ScriptThreadCall },
    { 0x2B0C, opcode::OP_New },
    { 0x2B0D, opcode::OP_GetFunction },
    { 0x2B0E, opcode::OP_Invalid },
    { 0x2B0F, opcode::OP_GetAnimation },
    { 0x2B10, opcode::OP_Invalid },
    { 0x2B11, opcode::OP_Invalid },
    { 0x2B12, opcode::OP_Invalid },
    { 0x2B13, opcode::OP_SafeCreateLocalVariables },
    { 0x2B14, opcode::OP_GetClassesObject },
    { 0x2B15, opcode::OP_Invalid },
    { 0x2B16, opcode::OP_Return },
    { 0x2B17, opcode::OP_GetVector },
    { 0x2B18, opcode::OP_Invalid },
    { 0x2B19, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x2B1A, opcode::OP_NotEqual },
    { 0x2B1B, opcode::OP_Jump },
    { 0x2B1C, opcode::OP_Divide },
    { 0x2B1D, opcode::OP_ScriptMethodThreadCall },
    { 0x2B1E, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x2B1F, opcode::OP_Invalid },
    { 0x2B20, opcode::OP_Invalid },
    { 0x2B21, opcode::OP_Invalid },
    { 0x2B22, opcode::OP_EndSwitch },
    { 0x2B23, opcode::OP_GetUndefined },
    { 0x2B24, opcode::OP_Invalid },
    { 0x2B25, opcode::OP_GetLevelObject },
    { 0x2B26, opcode::OP_Modulus },
    { 0x2B27, opcode::OP_GetString },
    { 0x2B28, opcode::OP_Invalid },
    { 0x2B29, opcode::OP_RealWait },
    { 0x2B2A, opcode::OP_Invalid },
    { 0x2B2B, opcode::OP_Invalid },
    { 0x2B2C, opcode::OP_JumpOnFalseExpr },
    { 0x2B2D, opcode::OP_GreaterThanOrEqualTo },
    { 0x2B2E, opcode::OP_EvalLocalVariableRefCached },
    { 0x2B2F, opcode::OP_GetWorldObject },
    { 0x2B30, opcode::OP_GetIString },
    { 0x2B31, opcode::OP_SelfEvalFieldVariable },
    { 0x2B32, opcode::OP_CastFieldObject },
    { 0x2B33, opcode::OP_GetVector },
    { 0x2B34, opcode::OP_Invalid },
    { 0x2B35, opcode::OP_Switch },
    { 0x2B36, opcode::OP_Invalid },
    { 0x2B37, opcode::OP_LessThanOrEqualTo },
    { 0x2B38, opcode::OP_GetAPIFunction },
    { 0x2B39, opcode::OP_GetWorld },
    { 0x2B3A, opcode::OP_EmptyArray },
    { 0x2B3B, opcode::OP_GetTime },
    { 0x2B3C, opcode::OP_Vector },
    { 0x2B3D, opcode::OP_VectorScale },
    { 0x2B3E, opcode::OP_SelfEvalFieldVariable },
    { 0x2B3F, opcode::OP_GetVector },
    { 0x2B40, opcode::OP_JumpOnTrueExpr },
    { 0x2B41, opcode::OP_Invalid },
    { 0x2B42, opcode::OP_SafeCreateLocalVariables },
    { 0x2B43, opcode::OP_SelfEvalFieldVariable },
    { 0x2B44, opcode::OP_JumpOnFalseExpr },
    { 0x2B45, opcode::OP_WaitTillFrameEnd },
    { 0x2B46, opcode::OP_JumpOnFalseExpr },
    { 0x2B47, opcode::OP_BoolComplement },
    { 0x2B48, opcode::OP_EmptyArray },
    { 0x2B49, opcode::OP_DevblockBegin },
    { 0x2B4A, opcode::OP_SafeDecTop },
    { 0x2B4B, opcode::OP_Invalid },
    { 0x2B4C, opcode::OP_GetWorld },
    { 0x2B4D, opcode::OP_GetNegByte },
    { 0x2B4E, opcode::OP_Plus },
    { 0x2B4F, opcode::OP_Invalid },
    { 0x2B50, opcode::OP_Notify },
    { 0x2B51, opcode::OP_EvalLocalVariableRefCached },
    { 0x2B52, opcode::OP_GetGame },
    { 0x2B53, opcode::OP_Invalid },
    { 0x2B54, opcode::OP_GetFloat },
    { 0x2B55, opcode::OP_EvalLocalVariableCached },
    { 0x2B56, opcode::OP_Invalid },
    { 0x2B57, opcode::OP_SafeSetVariableFieldCached },
    { 0x2B58, opcode::OP_WaitTill },
    { 0x2B59, opcode::OP_LevelEvalFieldVariable },
    { 0x2B5A, opcode::OP_ShiftRight },
    { 0x2B5B, opcode::OP_SuperNotEqual },
    { 0x2B5C, opcode::OP_EmptyArray },
    { 0x2B5D, opcode::OP_Wait },
    { 0x2B5E, opcode::OP_Modulus },
    { 0x2B5F, opcode::OP_BoolNot },
    { 0x2B60, opcode::OP_GetWorldObject },
    { 0x2B61, opcode::OP_GetNegByte },
    { 0x2B62, opcode::OP_GetFloat },
    { 0x2B63, opcode::OP_ScriptFunctionCallClass },
    { 0x2B64, opcode::OP_SafeDecTop },
    { 0x2B65, opcode::OP_EndOn },
    { 0x2B66, opcode::OP_Invalid },
    { 0x2B67, opcode::OP_GetAnimation },
    { 0x2B68, opcode::OP_IsDefined },
    { 0x2B69, opcode::OP_Invalid },
    { 0x2B6A, opcode::OP_Invalid },
    { 0x2B6B, opcode::OP_CallBuiltinMethod },
    { 0x2B6C, opcode::OP_GetHash },
    { 0x2B6D, opcode::OP_Invalid },
    { 0x2B6E, opcode::OP_GetString },
    { 0x2B6F, opcode::OP_GetFloat },
    { 0x2B70, opcode::OP_SuperEqual },
    { 0x2B71, opcode::OP_GetIString },
    { 0x2B72, opcode::OP_EmptyArray },
    { 0x2B73, opcode::OP_Invalid },
    { 0x2B74, opcode::OP_IsDefined },
    { 0x2B75, opcode::OP_ScriptThreadCallPointer },
    { 0x2B76, opcode::OP_SafeSetVariableFieldCached },
    { 0x2B77, opcode::OP_GetUintptr },
    { 0x2B78, opcode::OP_Invalid },
    { 0x2B79, opcode::OP_Invalid },
    { 0x2B7A, opcode::OP_Switch },
    { 0x2B7B, opcode::OP_DevblockBegin },
    { 0x2B7C, opcode::OP_GetNegUnsignedShort },
    { 0x2B7D, opcode::OP_GetGame },
    { 0x2B7E, opcode::OP_GetIString },
    { 0x2B7F, opcode::OP_Invalid },
    { 0x2B80, opcode::OP_GetFloat },
    { 0x2B81, opcode::OP_Invalid },
    { 0x2B82, opcode::OP_Invalid },
    { 0x2B83, opcode::OP_Bit_And },
    { 0x2B84, opcode::OP_Invalid },
    { 0x2B85, opcode::OP_GetHash },
    { 0x2B86, opcode::OP_Invalid },
    { 0x2B87, opcode::OP_ClearArray },
    { 0x2B88, opcode::OP_GetFunction },
    { 0x2B89, opcode::OP_ScriptThreadCall },
    { 0x2B8A, opcode::OP_Invalid },
    { 0x2B8B, opcode::OP_Invalid },
    { 0x2B8C, opcode::OP_ScriptMethodCallPointer },
    { 0x2B8D, opcode::OP_FirstArrayKey },
    { 0x2B8E, opcode::OP_Invalid },
    { 0x2B8F, opcode::OP_GreaterThan },
    { 0x2B90, opcode::OP_ClearFieldVariable },
    { 0x2B91, opcode::OP_Minus },
    { 0x2B92, opcode::OP_Jump },
    { 0x2B93, opcode::OP_GetTime },
    { 0x2B94, opcode::OP_Invalid },
    { 0x2B95, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x2B96, opcode::OP_EvalArrayRef },
    { 0x2B97, opcode::OP_Invalid },
    { 0x2B98, opcode::OP_Equal },
    { 0x2B99, opcode::OP_Invalid },
    { 0x2B9A, opcode::OP_EndOn },
    { 0x2B9B, opcode::OP_Invalid },
    { 0x2B9C, opcode::OP_Invalid },
    { 0x2B9D, opcode::OP_Modulus },
    { 0x2B9E, opcode::OP_Invalid },
    { 0x2B9F, opcode::OP_GetWorld },
    { 0x2BA0, opcode::OP_WaitTill },
    { 0x2BA1, opcode::OP_Invalid },
    { 0x2BA2, opcode::OP_Invalid },
    { 0x2BA3, opcode::OP_Multiply },
    { 0x2BA4, opcode::OP_Invalid },
    { 0x2BA5, opcode::OP_NotEqual },
    { 0x2BA6, opcode::OP_Invalid },
    { 0x2BA7, opcode::OP_Invalid },
    { 0x2BA8, opcode::OP_Invalid },
    { 0x2BA9, opcode::OP_SafeSetVariableFieldCached },
    { 0x2BAA, opcode::OP_GetUndefined },
    { 0x2BAB, opcode::OP_Invalid },
    { 0x2BAC, opcode::OP_EndSwitch },
    { 0x2BAD, opcode::OP_GetUndefined },
    { 0x2BAE, opcode::OP_New },
    { 0x2BAF, opcode::OP_JumpOnTrueExpr },
    { 0x2BB0, opcode::OP_LevelEvalFieldVariable },
    { 0x2BB1, opcode::OP_Bit_Xor },
    { 0x2BB2, opcode::OP_Notify },
    { 0x2BB3, opcode::OP_GetGame },
    { 0x2BB4, opcode::OP_GetFloat },
    { 0x2BB5, opcode::OP_Minus },
    { 0x2BB6, opcode::OP_GetClassesObject },
    { 0x2BB7, opcode::OP_Jump },
    { 0x2BB8, opcode::OP_Invalid },
    { 0x2BB9, opcode::OP_Invalid },
    { 0x2BBA, opcode::OP_Invalid },
    { 0x2BBB, opcode::OP_Invalid },
    { 0x2BBC, opcode::OP_New },
    { 0x2BBD, opcode::OP_EvalArrayRef },
    { 0x2BBE, opcode::OP_ScriptMethodThreadCall },
    { 0x2BBF, opcode::OP_Invalid },
    { 0x2BC0, opcode::OP_Invalid },
    { 0x2BC1, opcode::OP_ProfileStop },
    { 0x2BC2, opcode::OP_GetUintptr },
    { 0x2BC3, opcode::OP_Invalid },
    { 0x2BC4, opcode::OP_ScriptFunctionCallPointer },
    { 0x2BC5, opcode::OP_Invalid },
    { 0x2BC6, opcode::OP_Invalid },
    { 0x2BC7, opcode::OP_GetHash },
    { 0x2BC8, opcode::OP_GetVector },
    { 0x2BC9, opcode::OP_Invalid },
    { 0x2BCA, opcode::OP_Invalid },
    { 0x2BCB, opcode::OP_EvalFieldVariable },
    { 0x2BCC, opcode::OP_DevblockBegin },
    { 0x2BCD, opcode::OP_Invalid },
    { 0x2BCE, opcode::OP_GetZero },
    { 0x2BCF, opcode::OP_Divide },
    { 0x2BD0, opcode::OP_ScriptThreadCallPointer },
    { 0x2BD1, opcode::OP_DecTop },
    { 0x2BD2, opcode::OP_GetVector },
    { 0x2BD3, opcode::OP_Switch },
    { 0x2BD4, opcode::OP_Invalid },
    { 0x2BD5, opcode::OP_ScriptFunctionCallPointer },
    { 0x2BD6, opcode::OP_SafeSetVariableFieldCached },
    { 0x2BD7, opcode::OP_LessThanOrEqualTo },
    { 0x2BD8, opcode::OP_JumpOnTrueExpr },
    { 0x2BD9, opcode::OP_GetWorld },
    { 0x2BDA, opcode::OP_Invalid },
    { 0x2BDB, opcode::OP_Dec },
    { 0x2BDC, opcode::OP_Invalid },
    { 0x2BDD, opcode::OP_Invalid },
    { 0x2BDE, opcode::OP_Invalid },
    { 0x2BDF, opcode::OP_ScriptThreadCallClass },
    { 0x2BE0, opcode::OP_Invalid },
    { 0x2BE1, opcode::OP_ScriptFunctionCallClass },
    { 0x2BE2, opcode::OP_Invalid },
    { 0x2BE3, opcode::OP_GetTime },
    { 0x2BE4, opcode::OP_ScriptMethodCallPointer },
    { 0x2BE5, opcode::OP_DevblockBegin },
    { 0x2BE6, opcode::OP_Jump },
    { 0x2BE7, opcode::OP_Invalid },
    { 0x2BE8, opcode::OP_GetWorldObject },
    { 0x2BE9, opcode::OP_Invalid },
    { 0x2BEA, opcode::OP_Invalid },
    { 0x2BEB, opcode::OP_Invalid },
    { 0x2BEC, opcode::OP_GreaterThan },
    { 0x2BED, opcode::OP_Jump },
    { 0x2BEE, opcode::OP_Invalid },
    { 0x2BEF, opcode::OP_Invalid },
    { 0x2BF0, opcode::OP_JumpOnTrueExpr },
    { 0x2BF1, opcode::OP_Invalid },
    { 0x2BF2, opcode::OP_NextArrayKey },
    { 0x2BF3, opcode::OP_CallBuiltinMethod },
    { 0x2BF4, opcode::OP_GetTime },
    { 0x2BF5, opcode::OP_Invalid },
    { 0x2BF6, opcode::OP_SelfEvalFieldVariable },
    { 0x2BF7, opcode::OP_SizeOf },
    { 0x2BF8, opcode::OP_EvalArrayRef },
    { 0x2BF9, opcode::OP_EndSwitch },
    { 0x2BFA, opcode::OP_Invalid },
    { 0x2BFB, opcode::OP_GetClasses },
    { 0x2BFC, opcode::OP_ScriptMethodCallPointer },
    { 0x2BFD, opcode::OP_Invalid },
    { 0x2BFE, opcode::OP_Vector },
    { 0x2BFF, opcode::OP_LessThanOrEqualTo },
    { 0x2C00, opcode::OP_ClearArray },
    { 0x2C01, opcode::OP_LevelEvalFieldVariable },
    { 0x2C02, opcode::OP_GetAnim },
    { 0x2C03, opcode::OP_Invalid },
    { 0x2C04, opcode::OP_Invalid },
    { 0x2C05, opcode::OP_EvalLocalVariableRefCached },
    { 0x2C06, opcode::OP_Invalid },
    { 0x2C07, opcode::OP_Multiply },
    { 0x2C08, opcode::OP_Invalid },
    { 0x2C09, opcode::OP_Invalid },
    { 0x2C0A, opcode::OP_JumpOnFalse },
    { 0x2C0B, opcode::OP_Invalid },
    { 0x2C0C, opcode::OP_FirstArrayKey },
    { 0x2C0D, opcode::OP_EvalFieldVariable },
    { 0x2C0E, opcode::OP_Invalid },
    { 0x2C0F, opcode::OP_GetFloat },
    { 0x2C10, opcode::OP_Invalid },
    { 0x2C11, opcode::OP_CastBool },
    { 0x2C12, opcode::OP_ShiftRight },
    { 0x2C13, opcode::OP_Bit_Or },
    { 0x2C14, opcode::OP_GetHash },
    { 0x2C15, opcode::OP_DevblockBegin },
    { 0x2C16, opcode::OP_LessThan },
    { 0x2C17, opcode::OP_Invalid },
    { 0x2C18, opcode::OP_Invalid },
    { 0x2C19, opcode::OP_Invalid },
    { 0x2C1A, opcode::OP_Vector },
    { 0x2C1B, opcode::OP_EvalFieldVariable },
    { 0x2C1C, opcode::OP_GetClasses },
    { 0x2C1D, opcode::OP_Invalid },
    { 0x2C1E, opcode::OP_JumpOnTrueExpr },
    { 0x2C1F, opcode::OP_Invalid },
    { 0x2C20, opcode::OP_EvalLocalVariableCached },
    { 0x2C21, opcode::OP_EvalArray },
    { 0x2C22, opcode::OP_GetClassesObject },
    { 0x2C23, opcode::OP_BoolNot },
    { 0x2C24, opcode::OP_Invalid },
    { 0x2C25, opcode::OP_Invalid },
    { 0x2C26, opcode::OP_GetInteger },
    { 0x2C27, opcode::OP_Invalid },
    { 0x2C28, opcode::OP_Invalid },
    { 0x2C29, opcode::OP_ScriptFunctionCall },
    { 0x2C2A, opcode::OP_GetTime },
    { 0x2C2B, opcode::OP_Invalid },
    { 0x2C2C, opcode::OP_CallBuiltinMethod },
    { 0x2C2D, opcode::OP_Plus },
    { 0x2C2E, opcode::OP_Invalid },
    { 0x2C2F, opcode::OP_Bit_Xor },
    { 0x2C30, opcode::OP_Invalid },
    { 0x2C31, opcode::OP_FirstArrayKey },
    { 0x2C32, opcode::OP_Invalid },
    { 0x2C33, opcode::OP_Invalid },
    { 0x2C34, opcode::OP_Invalid },
    { 0x2C35, opcode::OP_EndOn },
    { 0x2C36, opcode::OP_GetNegByte },
    { 0x2C37, opcode::OP_GetGame },
    { 0x2C38, opcode::OP_WaitTillMatch },
    { 0x2C39, opcode::OP_Notify },
    { 0x2C3A, opcode::OP_Invalid },
    { 0x2C3B, opcode::OP_GetInteger },
    { 0x2C3C, opcode::OP_Invalid },
    { 0x2C3D, opcode::OP_ProfileStop },
    { 0x2C3E, opcode::OP_GetInteger },
    { 0x2C3F, opcode::OP_FirstArrayKey },
    { 0x2C40, opcode::OP_Invalid },
    { 0x2C41, opcode::OP_Bit_And },
    { 0x2C42, opcode::OP_Invalid },
    { 0x2C43, opcode::OP_Invalid },
    { 0x2C44, opcode::OP_BoolComplement },
    { 0x2C45, opcode::OP_Invalid },
    { 0x2C46, opcode::OP_Invalid },
    { 0x2C47, opcode::OP_Invalid },
    { 0x2C48, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x2C49, opcode::OP_EndOn },
    { 0x2C4A, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x2C4B, opcode::OP_GreaterThan },
    { 0x2C4C, opcode::OP_Return },
    { 0x2C4D, opcode::OP_Invalid },
    { 0x2C4E, opcode::OP_GetUndefined },
    { 0x2C4F, opcode::OP_GetAPIFunction },
    { 0x2C50, opcode::OP_Invalid },
    { 0x2C51, opcode::OP_Invalid },
    { 0x2C52, opcode::OP_Invalid },
    { 0x2C53, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x2C54, opcode::OP_GetWorld },
    { 0x2C55, opcode::OP_GetClasses },
    { 0x2C56, opcode::OP_WaitTillFrameEnd },
    { 0x2C57, opcode::OP_NotEqual },
    { 0x2C58, opcode::OP_Notify },
    { 0x2C59, opcode::OP_JumpOnTrueExpr },
    { 0x2C5A, opcode::OP_Invalid },
    { 0x2C5B, opcode::OP_LessThanOrEqualTo },
    { 0x2C5C, opcode::OP_Return },
    { 0x2C5D, opcode::OP_Invalid },
    { 0x2C5E, opcode::OP_GetFloat },
    { 0x2C5F, opcode::OP_Equal },
    { 0x2C60, opcode::OP_Invalid },
    { 0x2C61, opcode::OP_GetAPIFunction },
    { 0x2C62, opcode::OP_RealWait },
    { 0x2C63, opcode::OP_GetAnim },
    { 0x2C64, opcode::OP_Switch },
    { 0x2C65, opcode::OP_Invalid },
    { 0x2C66, opcode::OP_Invalid },
    { 0x2C67, opcode::OP_DevblockBegin },
    { 0x2C68, opcode::OP_NotEqual },
    { 0x2C69, opcode::OP_Vector },
    { 0x2C6A, opcode::OP_JumpOnTrueExpr },
    { 0x2C6B, opcode::OP_Invalid },
    { 0x2C6C, opcode::OP_Switch },
    { 0x2C6D, opcode::OP_GetZero },
    { 0x2C6E, opcode::OP_Invalid },
    { 0x2C6F, opcode::OP_Invalid },
    { 0x2C70, opcode::OP_DevblockBegin },
    { 0x2C71, opcode::OP_ScriptMethodThreadCall },
    { 0x2C72, opcode::OP_ScriptMethodCall },
    { 0x2C73, opcode::OP_GetClasses },
    { 0x2C74, opcode::OP_Invalid },
    { 0x2C75, opcode::OP_Invalid },
    { 0x2C76, opcode::OP_LevelEvalFieldVariable },
    { 0x2C77, opcode::OP_ScriptThreadCallPointer },
    { 0x2C78, opcode::OP_Bit_And },
    { 0x2C79, opcode::OP_Invalid },
    { 0x2C7A, opcode::OP_Invalid },
    { 0x2C7B, opcode::OP_GetVector },
    { 0x2C7C, opcode::OP_Invalid },
    { 0x2C7D, opcode::OP_GetSelf },
    { 0x2C7E, opcode::OP_ClearArray },
    { 0x2C7F, opcode::OP_EvalFieldVariable },
    { 0x2C80, opcode::OP_SetVariableField },
    { 0x2C81, opcode::OP_GetString },
    { 0x2C82, opcode::OP_EvalArray },
    { 0x2C83, opcode::OP_SuperNotEqual },
    { 0x2C84, opcode::OP_WaitTillFrameEnd },
    { 0x2C85, opcode::OP_Switch },
    { 0x2C86, opcode::OP_Invalid },
    { 0x2C87, opcode::OP_NextArrayKey },
    { 0x2C88, opcode::OP_SelfEvalFieldVariable },
    { 0x2C89, opcode::OP_Invalid },
    { 0x2C8A, opcode::OP_SuperEqual },
    { 0x2C8B, opcode::OP_BoolNot },
    { 0x2C8C, opcode::OP_GetHash },
    { 0x2C8D, opcode::OP_GreaterThanOrEqualTo },
    { 0x2C8E, opcode::OP_SafeSetVariableFieldCached },
    { 0x2C8F, opcode::OP_SafeCreateLocalVariables },
    { 0x2C90, opcode::OP_EndOn },
    { 0x2C91, opcode::OP_Invalid },
    { 0x2C92, opcode::OP_Minus },
    { 0x2C93, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x2C94, opcode::OP_Invalid },
    { 0x2C95, opcode::OP_EndSwitch },
    { 0x2C96, opcode::OP_Invalid },
    { 0x2C97, opcode::OP_Invalid },
    { 0x2C98, opcode::OP_GetAnimObject },
    { 0x2C99, opcode::OP_Invalid },
    { 0x2C9A, opcode::OP_Invalid },
    { 0x2C9B, opcode::OP_ProfileStart },
    { 0x2C9C, opcode::OP_CallBuiltinMethod },
    { 0x2C9D, opcode::OP_Invalid },
    { 0x2C9E, opcode::OP_JumpOnFalseExpr },
    { 0x2C9F, opcode::OP_GetLevel },
    { 0x2CA0, opcode::OP_GetNegUnsignedShort },
    { 0x2CA1, opcode::OP_Invalid },
    { 0x2CA2, opcode::OP_DecTop },
    { 0x2CA3, opcode::OP_SuperEqual },
    { 0x2CA4, opcode::OP_Invalid },
    { 0x2CA5, opcode::OP_GetSelf },
    { 0x2CA6, opcode::OP_Bit_Xor },
    { 0x2CA7, opcode::OP_Invalid },
    { 0x2CA8, opcode::OP_GetAnimObject },
    { 0x2CA9, opcode::OP_SafeDecTop },
    { 0x2CAA, opcode::OP_VectorScale },
    { 0x2CAB, opcode::OP_Multiply },
    { 0x2CAC, opcode::OP_Multiply },
    { 0x2CAD, opcode::OP_EndOn },
    { 0x2CAE, opcode::OP_Invalid },
    { 0x2CAF, opcode::OP_Bit_Xor },
    { 0x2CB0, opcode::OP_Invalid },
    { 0x2CB1, opcode::OP_GreaterThanOrEqualTo },
    { 0x2CB2, opcode::OP_ScriptThreadCallClass },
    { 0x2CB3, opcode::OP_EvalArrayRef },
    { 0x2CB4, opcode::OP_Invalid },
    { 0x2CB5, opcode::OP_Invalid },
    { 0x2CB6, opcode::OP_Invalid },
    { 0x2CB7, opcode::OP_Bit_And },
    { 0x2CB8, opcode::OP_Return },
    { 0x2CB9, opcode::OP_GetIString },
    { 0x2CBA, opcode::OP_Invalid },
    { 0x2CBB, opcode::OP_Invalid },
    { 0x2CBC, opcode::OP_Invalid },
    { 0x2CBD, opcode::OP_RealWait },
    { 0x2CBE, opcode::OP_GetVector },
    { 0x2CBF, opcode::OP_Invalid },
    { 0x2CC0, opcode::OP_GetGame },
    { 0x2CC1, opcode::OP_Multiply },
    { 0x2CC2, opcode::OP_Invalid },
    { 0x2CC3, opcode::OP_GetLevelObject },
    { 0x2CC4, opcode::OP_Invalid },
    { 0x2CC5, opcode::OP_Dec },
    { 0x2CC6, opcode::OP_Invalid },
    { 0x2CC7, opcode::OP_SelfEvalFieldVariableRef },
    { 0x2CC8, opcode::OP_SuperEqual },
    { 0x2CC9, opcode::OP_DecTop },
    { 0x2CCA, opcode::OP_Invalid },
    { 0x2CCB, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x2CCC, opcode::OP_JumpOnTrue },
    { 0x2CCD, opcode::OP_DevblockBegin },
    { 0x2CCE, opcode::OP_Invalid },
    { 0x2CCF, opcode::OP_EvalLocalVariableCached },
    { 0x2CD0, opcode::OP_Invalid },
    { 0x2CD1, opcode::OP_VectorScale },
    { 0x2CD2, opcode::OP_EvalArray },
    { 0x2CD3, opcode::OP_EvalLocalVariableCached },
    { 0x2CD4, opcode::OP_Invalid },
    { 0x2CD5, opcode::OP_GetGameRef },
    { 0x2CD6, opcode::OP_Invalid },
    { 0x2CD7, opcode::OP_ScriptFunctionCall },
    { 0x2CD8, opcode::OP_Equal },
    { 0x2CD9, opcode::OP_Invalid },
    { 0x2CDA, opcode::OP_ScriptThreadCallClass },
    { 0x2CDB, opcode::OP_Minus },
    { 0x2CDC, opcode::OP_ProfileStop },
    { 0x2CDD, opcode::OP_Invalid },
    { 0x2CDE, opcode::OP_Invalid },
    { 0x2CDF, opcode::OP_GetUnsignedShort },
    { 0x2CE0, opcode::OP_Bit_Xor },
    { 0x2CE1, opcode::OP_GreaterThanOrEqualTo },
    { 0x2CE2, opcode::OP_Jump },
    { 0x2CE3, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x2CE4, opcode::OP_Invalid },
    { 0x2CE5, opcode::OP_GetWorldObject },
    { 0x2CE6, opcode::OP_EvalLocalVariableCached },
    { 0x2CE7, opcode::OP_ClearFieldVariable },
    { 0x2CE8, opcode::OP_Bit_Xor },
    { 0x2CE9, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x2CEA, opcode::OP_ShiftLeft },
    { 0x2CEB, opcode::OP_GetWorld },
    { 0x2CEC, opcode::OP_JumpOnTrue },
    { 0x2CED, opcode::OP_JumpOnFalseExpr },
    { 0x2CEE, opcode::OP_Notify },
    { 0x2CEF, opcode::OP_GetGameRef },
    { 0x2CF0, opcode::OP_CallBuiltinMethod },
    { 0x2CF1, opcode::OP_Invalid },
    { 0x2CF2, opcode::OP_Switch },
    { 0x2CF3, opcode::OP_SuperEqual },
    { 0x2CF4, opcode::OP_Vector },
    { 0x2CF5, opcode::OP_Invalid },
    { 0x2CF6, opcode::OP_GetLevel },
    { 0x2CF7, opcode::OP_GetZero },
    { 0x2CF8, opcode::OP_EvalLocalVariableCached },
    { 0x2CF9, opcode::OP_DevblockBegin },
    { 0x2CFA, opcode::OP_SafeSetVariableFieldCached },
    { 0x2CFB, opcode::OP_Invalid },
    { 0x2CFC, opcode::OP_Invalid },
    { 0x2CFD, opcode::OP_Invalid },
    { 0x2CFE, opcode::OP_GetSelf },
    { 0x2CFF, opcode::OP_VectorConstant },
    { 0x2D00, opcode::OP_Invalid },
    { 0x2D01, opcode::OP_Invalid },
    { 0x2D02, opcode::OP_SafeCreateLocalVariables },
    { 0x2D03, opcode::OP_LevelEvalFieldVariable },
    { 0x2D04, opcode::OP_Invalid },
    { 0x2D05, opcode::OP_ScriptThreadCallClass },
    { 0x2D06, opcode::OP_GetClasses },
    { 0x2D07, opcode::OP_GreaterThan },
    { 0x2D08, opcode::OP_GetNegUnsignedShort },
    { 0x2D09, opcode::OP_Invalid },
    { 0x2D0A, opcode::OP_GetByte },
    { 0x2D0B, opcode::OP_Invalid },
    { 0x2D0C, opcode::OP_GetSelfObject },
    { 0x2D0D, opcode::OP_SelfEvalFieldVariableRef },
    { 0x2D0E, opcode::OP_Invalid },
    { 0x2D0F, opcode::OP_Invalid },
    { 0x2D10, opcode::OP_JumpOnTrueExpr },
    { 0x2D11, opcode::OP_ScriptFunctionCallClass },
    { 0x2D12, opcode::OP_ProfileStop },
    { 0x2D13, opcode::OP_ClearFieldVariable },
    { 0x2D14, opcode::OP_Invalid },
    { 0x2D15, opcode::OP_LessThanOrEqualTo },
    { 0x2D16, opcode::OP_GetAnimObject },
    { 0x2D17, opcode::OP_Invalid },
    { 0x2D18, opcode::OP_Return },
    { 0x2D19, opcode::OP_SuperEqual },
    { 0x2D1A, opcode::OP_ProfileStop },
    { 0x2D1B, opcode::OP_EmptyArray },
    { 0x2D1C, opcode::OP_Invalid },
    { 0x2D1D, opcode::OP_VectorScale },
    { 0x2D1E, opcode::OP_NotEqual },
    { 0x2D1F, opcode::OP_ShiftRight },
    { 0x2D20, opcode::OP_Invalid },
    { 0x2D21, opcode::OP_EvalLocalVariableRefCached },
    { 0x2D22, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x2D23, opcode::OP_Invalid },
    { 0x2D24, opcode::OP_SafeCreateLocalVariables },
    { 0x2D25, opcode::OP_LevelEvalFieldVariableRef },
    { 0x2D26, opcode::OP_JumpOnTrueExpr },
    { 0x2D27, opcode::OP_EvalArray },
    { 0x2D28, opcode::OP_SafeSetVariableFieldCached },
    { 0x2D29, opcode::OP_SafeDecTop },
    { 0x2D2A, opcode::OP_SafeDecTop },
    { 0x2D2B, opcode::OP_Invalid },
    { 0x2D2C, opcode::OP_Invalid },
    { 0x2D2D, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x2D2E, opcode::OP_ShiftRight },
    { 0x2D2F, opcode::OP_Invalid },
    { 0x2D30, opcode::OP_ProfileStart },
    { 0x2D31, opcode::OP_GetUnsignedShort },
    { 0x2D32, opcode::OP_Jump },
    { 0x2D33, opcode::OP_NotEqual },
    { 0x2D34, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x2D35, opcode::OP_Minus },
    { 0x2D36, opcode::OP_ScriptMethodCall },
    { 0x2D37, opcode::OP_EvalLocalVariableCached },
    { 0x2D38, opcode::OP_ClearFieldVariable },
    { 0x2D39, opcode::OP_Invalid },
    { 0x2D3A, opcode::OP_LessThan },
    { 0x2D3B, opcode::OP_Invalid },
    { 0x2D3C, opcode::OP_Invalid },
    { 0x2D3D, opcode::OP_GetVector },
    { 0x2D3E, opcode::OP_NextArrayKey },
    { 0x2D3F, opcode::OP_Invalid },
    { 0x2D40, opcode::OP_Switch },
    { 0x2D41, opcode::OP_Invalid },
    { 0x2D42, opcode::OP_Minus },
    { 0x2D43, opcode::OP_NextArrayKey },
    { 0x2D44, opcode::OP_Minus },
    { 0x2D45, opcode::OP_ProfileStart },
    { 0x2D46, opcode::OP_Invalid },
    { 0x2D47, opcode::OP_Invalid },
    { 0x2D48, opcode::OP_SuperNotEqual },
    { 0x2D49, opcode::OP_EvalArray },
    { 0x2D4A, opcode::OP_ShiftLeft },
    { 0x2D4B, opcode::OP_GetSelfObject },
    { 0x2D4C, opcode::OP_IsDefined },
    { 0x2D4D, opcode::OP_WaitTillFrameEnd },
    { 0x2D4E, opcode::OP_Invalid },
    { 0x2D4F, opcode::OP_Invalid },
    { 0x2D50, opcode::OP_JumpOnTrueExpr },
    { 0x2D51, opcode::OP_CastFieldObject },
    { 0x2D52, opcode::OP_GetHash },
    { 0x2D53, opcode::OP_WaitTillMatch },
    { 0x2D54, opcode::OP_Invalid },
    { 0x2D55, opcode::OP_Invalid },
    { 0x2D56, opcode::OP_ScriptMethodThreadCall },
    { 0x2D57, opcode::OP_ClearArray },
    { 0x2D58, opcode::OP_GetWorldObject },
    { 0x2D59, opcode::OP_LessThanOrEqualTo },
    { 0x2D5A, opcode::OP_FirstArrayKey },
    { 0x2D5B, opcode::OP_Invalid },
    { 0x2D5C, opcode::OP_JumpOnTrueExpr },
    { 0x2D5D, opcode::OP_SuperNotEqual },
    { 0x2D5E, opcode::OP_SetVariableField },
    { 0x2D5F, opcode::OP_LevelEvalFieldVariableRef },
    { 0x2D60, opcode::OP_Return },
    { 0x2D61, opcode::OP_WaitTillFrameEnd },
    { 0x2D62, opcode::OP_Invalid },
    { 0x2D63, opcode::OP_Invalid },
    { 0x2D64, opcode::OP_Invalid },
    { 0x2D65, opcode::OP_Invalid },
    { 0x2D66, opcode::OP_Inc },
    { 0x2D67, opcode::OP_ShiftRight },
    { 0x2D68, opcode::OP_Invalid },
    { 0x2D69, opcode::OP_ShiftLeft },
    { 0x2D6A, opcode::OP_Invalid },
    { 0x2D6B, opcode::OP_ScriptMethodCall },
    { 0x2D6C, opcode::OP_Invalid },
    { 0x2D6D, opcode::OP_BoolComplement },
    { 0x2D6E, opcode::OP_Invalid },
    { 0x2D6F, opcode::OP_ShiftLeft },
    { 0x2D70, opcode::OP_GetAnimObject },
    { 0x2D71, opcode::OP_ScriptThreadCall },
    { 0x2D72, opcode::OP_GetZero },
    { 0x2D73, opcode::OP_SelfEvalFieldVariable },
    { 0x2D74, opcode::OP_Multiply },
    { 0x2D75, opcode::OP_GetGame },
    { 0x2D76, opcode::OP_GetVector },
    { 0x2D77, opcode::OP_ClearFieldVariable },
    { 0x2D78, opcode::OP_ScriptThreadCallClass },
    { 0x2D79, opcode::OP_FirstArrayKey },
    { 0x2D7A, opcode::OP_Invalid },
    { 0x2D7B, opcode::OP_GetSelfObject },
    { 0x2D7C, opcode::OP_GetLevelObject },
    { 0x2D7D, opcode::OP_Wait },
    { 0x2D7E, opcode::OP_DevblockBegin },
    { 0x2D7F, opcode::OP_JumpOnFalse },
    { 0x2D80, opcode::OP_EvalArray },
    { 0x2D81, opcode::OP_CallBuiltinMethod },
    { 0x2D82, opcode::OP_Invalid },
    { 0x2D83, opcode::OP_GetIString },
    { 0x2D84, opcode::OP_Invalid },
    { 0x2D85, opcode::OP_GetAnimation },
    { 0x2D86, opcode::OP_ClearArray },
    { 0x2D87, opcode::OP_Invalid },
    { 0x2D88, opcode::OP_SafeSetVariableFieldCached },
    { 0x2D89, opcode::OP_ClearArray },
    { 0x2D8A, opcode::OP_Bit_Or },
    { 0x2D8B, opcode::OP_Invalid },
    { 0x2D8C, opcode::OP_Invalid },
    { 0x2D8D, opcode::OP_Invalid },
    { 0x2D8E, opcode::OP_Invalid },
    { 0x2D8F, opcode::OP_Invalid },
    { 0x2D90, opcode::OP_LessThanOrEqualTo },
    { 0x2D91, opcode::OP_Invalid },
    { 0x2D92, opcode::OP_GetTime },
    { 0x2D93, opcode::OP_BoolNot },
    { 0x2D94, opcode::OP_Divide },
    { 0x2D95, opcode::OP_GetSelfObject },
    { 0x2D96, opcode::OP_IsDefined },
    { 0x2D97, opcode::OP_EndSwitch },
    { 0x2D98, opcode::OP_Bit_And },
    { 0x2D99, opcode::OP_Invalid },
    { 0x2D9A, opcode::OP_Invalid },
    { 0x2D9B, opcode::OP_GetTime },
    { 0x2D9C, opcode::OP_Invalid },
    { 0x2D9D, opcode::OP_Invalid },
    { 0x2D9E, opcode::OP_GetLevel },
    { 0x2D9F, opcode::OP_JumpOnFalse },
    { 0x2DA0, opcode::OP_VectorConstant },
    { 0x2DA1, opcode::OP_WaitTillMatch },
    { 0x2DA2, opcode::OP_Invalid },
    { 0x2DA3, opcode::OP_ProfileStart },
    { 0x2DA4, opcode::OP_Invalid },
    { 0x2DA5, opcode::OP_Invalid },
    { 0x2DA6, opcode::OP_New },
    { 0x2DA7, opcode::OP_New },
    { 0x2DA8, opcode::OP_Dec },
    { 0x2DA9, opcode::OP_IsDefined },
    { 0x2DAA, opcode::OP_Invalid },
    { 0x2DAB, opcode::OP_CallBuiltinMethod },
    { 0x2DAC, opcode::OP_IsDefined },
    { 0x2DAD, opcode::OP_WaitTillMatch },
    { 0x2DAE, opcode::OP_Wait },
    { 0x2DAF, opcode::OP_Switch },
    { 0x2DB0, opcode::OP_SafeDecTop },
    { 0x2DB1, opcode::OP_Invalid },
    { 0x2DB2, opcode::OP_Invalid },
    { 0x2DB3, opcode::OP_Wait },
    { 0x2DB4, opcode::OP_LessThan },
    { 0x2DB5, opcode::OP_Invalid },
    { 0x2DB6, opcode::OP_CallBuiltinMethod },
    { 0x2DB7, opcode::OP_ScriptMethodCallPointer },
    { 0x2DB8, opcode::OP_EndOn },
    { 0x2DB9, opcode::OP_ScriptThreadCallPointer },
    { 0x2DBA, opcode::OP_SizeOf },
    { 0x2DBB, opcode::OP_Invalid },
    { 0x2DBC, opcode::OP_GetFunction },
    { 0x2DBD, opcode::OP_GreaterThan },
    { 0x2DBE, opcode::OP_EvalLocalVariableCached },
    { 0x2DBF, opcode::OP_Invalid },
    { 0x2DC0, opcode::OP_SafeCreateLocalVariables },
    { 0x2DC1, opcode::OP_Invalid },
    { 0x2DC2, opcode::OP_EmptyArray },
    { 0x2DC3, opcode::OP_ScriptThreadCallPointer },
    { 0x2DC4, opcode::OP_Wait },
    { 0x2DC5, opcode::OP_Invalid },
    { 0x2DC6, opcode::OP_ScriptMethodCall },
    { 0x2DC7, opcode::OP_SafeDecTop },
    { 0x2DC8, opcode::OP_Invalid },
    { 0x2DC9, opcode::OP_Invalid },
    { 0x2DCA, opcode::OP_Invalid },
    { 0x2DCB, opcode::OP_CallBuiltinMethod },
    { 0x2DCC, opcode::OP_VectorScale },
    { 0x2DCD, opcode::OP_GetLevelObject },
    { 0x2DCE, opcode::OP_SizeOf },
    { 0x2DCF, opcode::OP_WaitTill },
    { 0x2DD0, opcode::OP_GetLevel },
    { 0x2DD1, opcode::OP_Bit_Xor },
    { 0x2DD2, opcode::OP_ScriptThreadCallClass },
    { 0x2DD3, opcode::OP_New },
    { 0x2DD4, opcode::OP_SafeDecTop },
    { 0x2DD5, opcode::OP_Invalid },
    { 0x2DD6, opcode::OP_GreaterThanOrEqualTo },
    { 0x2DD7, opcode::OP_Invalid },
    { 0x2DD8, opcode::OP_GetHash },
    { 0x2DD9, opcode::OP_GetString },
    { 0x2DDA, opcode::OP_Invalid },
    { 0x2DDB, opcode::OP_ScriptFunctionCallClass },
    { 0x2DDC, opcode::OP_BoolComplement },
    { 0x2DDD, opcode::OP_Invalid },
    { 0x2DDE, opcode::OP_LessThanOrEqualTo },
    { 0x2DDF, opcode::OP_LevelEvalFieldVariable },
    { 0x2DE0, opcode::OP_SafeCreateLocalVariables },
    { 0x2DE1, opcode::OP_GetWorld },
    { 0x2DE2, opcode::OP_Invalid },
    { 0x2DE3, opcode::OP_GetString },
    { 0x2DE4, opcode::OP_ShiftRight },
    { 0x2DE5, opcode::OP_EvalLocalVariableCached },
    { 0x2DE6, opcode::OP_Bit_Xor },
    { 0x2DE7, opcode::OP_Switch },
    { 0x2DE8, opcode::OP_ScriptThreadCallPointer },
    { 0x2DE9, opcode::OP_GetAnim },
    { 0x2DEA, opcode::OP_GreaterThanOrEqualTo },
    { 0x2DEB, opcode::OP_GetByte },
    { 0x2DEC, opcode::OP_Invalid },
    { 0x2DED, opcode::OP_SafeDecTop },
    { 0x2DEE, opcode::OP_EvalLocalVariableRefCached },
    { 0x2DEF, opcode::OP_GetClasses },
    { 0x2DF0, opcode::OP_Invalid },
    { 0x2DF1, opcode::OP_Invalid },
    { 0x2DF2, opcode::OP_Invalid },
    { 0x2DF3, opcode::OP_Invalid },
    { 0x2DF4, opcode::OP_Invalid },
    { 0x2DF5, opcode::OP_ScriptThreadCallPointer },
    { 0x2DF6, opcode::OP_Invalid },
    { 0x2DF7, opcode::OP_Invalid },
    { 0x2DF8, opcode::OP_GetZero },
    { 0x2DF9, opcode::OP_ProfileStop },
    { 0x2DFA, opcode::OP_LevelEvalFieldVariableRef },
    { 0x2DFB, opcode::OP_Invalid },
    { 0x2DFC, opcode::OP_Invalid },
    { 0x2DFD, opcode::OP_Invalid },
    { 0x2DFE, opcode::OP_WaitTillFrameEnd },
    { 0x2DFF, opcode::OP_Equal },
    { 0x2E00, opcode::OP_GetNegByte },
    { 0x2E01, opcode::OP_ScriptThreadCallClass },
    { 0x2E02, opcode::OP_Invalid },
    { 0x2E03, opcode::OP_Invalid },
    { 0x2E04, opcode::OP_Invalid },
    { 0x2E05, opcode::OP_SuperEqual },
    { 0x2E06, opcode::OP_Jump },
    { 0x2E07, opcode::OP_Notify },
    { 0x2E08, opcode::OP_WaitTillMatch },
    { 0x2E09, opcode::OP_ClearArray },
    { 0x2E0A, opcode::OP_Invalid },
    { 0x2E0B, opcode::OP_Invalid },
    { 0x2E0C, opcode::OP_GetAnimation },
    { 0x2E0D, opcode::OP_GetSelfObject },
    { 0x2E0E, opcode::OP_Invalid },
    { 0x2E0F, opcode::OP_Invalid },
    { 0x2E10, opcode::OP_Bit_Or },
    { 0x2E11, opcode::OP_Invalid },
    { 0x2E12, opcode::OP_GreaterThan },
    { 0x2E13, opcode::OP_Invalid },
    { 0x2E14, opcode::OP_Invalid },
    { 0x2E15, opcode::OP_Invalid },
    { 0x2E16, opcode::OP_Invalid },
    { 0x2E17, opcode::OP_Invalid },
    { 0x2E18, opcode::OP_BoolComplement },
    { 0x2E19, opcode::OP_Invalid },
    { 0x2E1A, opcode::OP_Minus },
    { 0x2E1B, opcode::OP_Invalid },
    { 0x2E1C, opcode::OP_Equal },
    { 0x2E1D, opcode::OP_Invalid },
    { 0x2E1E, opcode::OP_WaitTillFrameEnd },
    { 0x2E1F, opcode::OP_JumpOnTrue },
    { 0x2E20, opcode::OP_Multiply },
    { 0x2E21, opcode::OP_ScriptFunctionCallClass },
    { 0x2E22, opcode::OP_GetUndefined },
    { 0x2E23, opcode::OP_Invalid },
    { 0x2E24, opcode::OP_Invalid },
    { 0x2E25, opcode::OP_ProfileStart },
    { 0x2E26, opcode::OP_SelfEvalFieldVariable },
    { 0x2E27, opcode::OP_ClearFieldVariable },
    { 0x2E28, opcode::OP_Invalid },
    { 0x2E29, opcode::OP_EndOn },
    { 0x2E2A, opcode::OP_Invalid },
    { 0x2E2B, opcode::OP_Invalid },
    { 0x2E2C, opcode::OP_Invalid },
    { 0x2E2D, opcode::OP_Bit_And },
    { 0x2E2E, opcode::OP_ClearFieldVariable },
    { 0x2E2F, opcode::OP_WaitTillMatch },
    { 0x2E30, opcode::OP_GetUintptr },
    { 0x2E31, opcode::OP_JumpOnTrue },
    { 0x2E32, opcode::OP_Notify },
    { 0x2E33, opcode::OP_ClearArray },
    { 0x2E34, opcode::OP_GetFloat },
    { 0x2E35, opcode::OP_GetSelfObject },
    { 0x2E36, opcode::OP_Invalid },
    { 0x2E37, opcode::OP_Invalid },
    { 0x2E38, opcode::OP_GetUintptr },
    { 0x2E39, opcode::OP_ShiftRight },
    { 0x2E3A, opcode::OP_Invalid },
    { 0x2E3B, opcode::OP_GetAnimation },
    { 0x2E3C, opcode::OP_LevelEvalFieldVariableRef },
    { 0x2E3D, opcode::OP_GetHash },
    { 0x2E3E, opcode::OP_Invalid },
    { 0x2E3F, opcode::OP_JumpOnFalse },
    { 0x2E40, opcode::OP_Invalid },
    { 0x2E41, opcode::OP_SafeSetVariableFieldCached },
    { 0x2E42, opcode::OP_ScriptMethodCall },
    { 0x2E43, opcode::OP_GetLevel },
    { 0x2E44, opcode::OP_Invalid },
    { 0x2E45, opcode::OP_Invalid },
    { 0x2E46, opcode::OP_SelfEvalFieldVariableRef },
    { 0x2E47, opcode::OP_Invalid },
    { 0x2E48, opcode::OP_GetLevelObject },
    { 0x2E49, opcode::OP_Invalid },
    { 0x2E4A, opcode::OP_Invalid },
    { 0x2E4B, opcode::OP_Invalid },
    { 0x2E4C, opcode::OP_WaitTillFrameEnd },
    { 0x2E4D, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x2E4E, opcode::OP_JumpOnFalse },
    { 0x2E4F, opcode::OP_Invalid },
    { 0x2E50, opcode::OP_NextArrayKey },
    { 0x2E51, opcode::OP_Invalid },
    { 0x2E52, opcode::OP_NotEqual },
    { 0x2E53, opcode::OP_SuperEqual },
    { 0x2E54, opcode::OP_EndSwitch },
    { 0x2E55, opcode::OP_Invalid },
    { 0x2E56, opcode::OP_NotEqual },
    { 0x2E57, opcode::OP_ScriptFunctionCallPointer },
    { 0x2E58, opcode::OP_BoolNot },
    { 0x2E59, opcode::OP_Invalid },
    { 0x2E5A, opcode::OP_RealWait },
    { 0x2E5B, opcode::OP_ScriptThreadCallClass },
    { 0x2E5C, opcode::OP_Minus },
    { 0x2E5D, opcode::OP_Invalid },
    { 0x2E5E, opcode::OP_NotEqual },
    { 0x2E5F, opcode::OP_EvalFieldVariable },
    { 0x2E60, opcode::OP_GetAnimation },
    { 0x2E61, opcode::OP_NextArrayKey },
    { 0x2E62, opcode::OP_GetWorld },
    { 0x2E63, opcode::OP_GetFloat },
    { 0x2E64, opcode::OP_FirstArrayKey },
    { 0x2E65, opcode::OP_Invalid },
    { 0x2E66, opcode::OP_Plus },
    { 0x2E67, opcode::OP_GetAnim },
    { 0x2E68, opcode::OP_RealWait },
    { 0x2E69, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x2E6A, opcode::OP_GetNegByte },
    { 0x2E6B, opcode::OP_Invalid },
    { 0x2E6C, opcode::OP_Invalid },
    { 0x2E6D, opcode::OP_LevelEvalFieldVariableRef },
    { 0x2E6E, opcode::OP_JumpOnFalse },
    { 0x2E6F, opcode::OP_EvalFieldVariable },
    { 0x2E70, opcode::OP_EvalFieldVariableRef },
    { 0x2E71, opcode::OP_JumpOnFalseExpr },
    { 0x2E72, opcode::OP_Invalid },
    { 0x2E73, opcode::OP_Vector },
    { 0x2E74, opcode::OP_Invalid },
    { 0x2E75, opcode::OP_LevelEvalFieldVariableRef },
    { 0x2E76, opcode::OP_WaitTillMatch },
    { 0x2E77, opcode::OP_Minus },
    { 0x2E78, opcode::OP_Plus },
    { 0x2E79, opcode::OP_GetNegByte },
    { 0x2E7A, opcode::OP_ClearFieldVariable },
    { 0x2E7B, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x2E7C, opcode::OP_Invalid },
    { 0x2E7D, opcode::OP_Invalid },
    { 0x2E7E, opcode::OP_Invalid },
    { 0x2E7F, opcode::OP_Bit_Xor },
    { 0x2E80, opcode::OP_EvalArray },
    { 0x2E81, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x2E82, opcode::OP_Dec },
    { 0x2E83, opcode::OP_GetString },
    { 0x2E84, opcode::OP_Switch },
    { 0x2E85, opcode::OP_Bit_Or },
    { 0x2E86, opcode::OP_Invalid },
    { 0x2E87, opcode::OP_GetUndefined },
    { 0x2E88, opcode::OP_SafeCreateLocalVariables },
    { 0x2E89, opcode::OP_ScriptMethodCall },
    { 0x2E8A, opcode::OP_GetVector },
    { 0x2E8B, opcode::OP_Invalid },
    { 0x2E8C, opcode::OP_GetFunction },
    { 0x2E8D, opcode::OP_GetHash },
    { 0x2E8E, opcode::OP_Invalid },
    { 0x2E8F, opcode::OP_FirstArrayKey },
    { 0x2E90, opcode::OP_RealWait },
    { 0x2E91, opcode::OP_Invalid },
    { 0x2E92, opcode::OP_GetUndefined },
    { 0x2E93, opcode::OP_GetNegUnsignedShort },
    { 0x2E94, opcode::OP_Invalid },
    { 0x2E95, opcode::OP_LessThan },
    { 0x2E96, opcode::OP_EvalLocalVariableRefCached },
    { 0x2E97, opcode::OP_GetAnimObject },
    { 0x2E98, opcode::OP_LessThan },
    { 0x2E99, opcode::OP_BoolComplement },
    { 0x2E9A, opcode::OP_GetString },
    { 0x2E9B, opcode::OP_Invalid },
    { 0x2E9C, opcode::OP_Invalid },
    { 0x2E9D, opcode::OP_ScriptMethodCall },
    { 0x2E9E, opcode::OP_Invalid },
    { 0x2E9F, opcode::OP_LevelEvalFieldVariableRef },
    { 0x2EA0, opcode::OP_GetAnimObject },
    { 0x2EA1, opcode::OP_Modulus },
    { 0x2EA2, opcode::OP_ScriptMethodThreadCall },
    { 0x2EA3, opcode::OP_Invalid },
    { 0x2EA4, opcode::OP_GetLevel },
    { 0x2EA5, opcode::OP_Invalid },
    { 0x2EA6, opcode::OP_EvalLocalVariableRefCached },
    { 0x2EA7, opcode::OP_Invalid },
    { 0x2EA8, opcode::OP_SuperEqual },
    { 0x2EA9, opcode::OP_EvalFieldVariableRef },
    { 0x2EAA, opcode::OP_Invalid },
    { 0x2EAB, opcode::OP_SetVariableField },
    { 0x2EAC, opcode::OP_JumpOnTrue },
    { 0x2EAD, opcode::OP_GetFloat },
    { 0x2EAE, opcode::OP_Invalid },
    { 0x2EAF, opcode::OP_ScriptFunctionCall },
    { 0x2EB0, opcode::OP_Invalid },
    { 0x2EB1, opcode::OP_Invalid },
    { 0x2EB2, opcode::OP_Wait },
    { 0x2EB3, opcode::OP_WaitTill },
    { 0x2EB4, opcode::OP_Invalid },
    { 0x2EB5, opcode::OP_GetString },
    { 0x2EB6, opcode::OP_FirstArrayKey },
    { 0x2EB7, opcode::OP_LevelEvalFieldVariable },
    { 0x2EB8, opcode::OP_SafeSetVariableFieldCached },
    { 0x2EB9, opcode::OP_Invalid },
    { 0x2EBA, opcode::OP_Vector },
    { 0x2EBB, opcode::OP_SafeCreateLocalVariables },
    { 0x2EBC, opcode::OP_New },
    { 0x2EBD, opcode::OP_SafeDecTop },
    { 0x2EBE, opcode::OP_GetUintptr },
    { 0x2EBF, opcode::OP_Multiply },
    { 0x2EC0, opcode::OP_Switch },
    { 0x2EC1, opcode::OP_JumpOnTrueExpr },
    { 0x2EC2, opcode::OP_WaitTillFrameEnd },
    { 0x2EC3, opcode::OP_EvalFieldVariable },
    { 0x2EC4, opcode::OP_Invalid },
    { 0x2EC5, opcode::OP_ClearArray },
    { 0x2EC6, opcode::OP_Wait },
    { 0x2EC7, opcode::OP_Invalid },
    { 0x2EC8, opcode::OP_Invalid },
    { 0x2EC9, opcode::OP_GetAnim },
    { 0x2ECA, opcode::OP_EvalLocalVariableRefCached },
    { 0x2ECB, opcode::OP_Invalid },
    { 0x2ECC, opcode::OP_ShiftRight },
    { 0x2ECD, opcode::OP_SizeOf },
    { 0x2ECE, opcode::OP_Switch },
    { 0x2ECF, opcode::OP_SafeCreateLocalVariables },
    { 0x2ED0, opcode::OP_Invalid },
    { 0x2ED1, opcode::OP_Bit_And },
    { 0x2ED2, opcode::OP_Invalid },
    { 0x2ED3, opcode::OP_Switch },
    { 0x2ED4, opcode::OP_GetUnsignedShort },
    { 0x2ED5, opcode::OP_ScriptMethodCallPointer },
    { 0x2ED6, opcode::OP_ClearFieldVariable },
    { 0x2ED7, opcode::OP_Invalid },
    { 0x2ED8, opcode::OP_Invalid },
    { 0x2ED9, opcode::OP_CastFieldObject },
    { 0x2EDA, opcode::OP_GetUndefined },
    { 0x2EDB, opcode::OP_Invalid },
    { 0x2EDC, opcode::OP_Invalid },
    { 0x2EDD, opcode::OP_DevblockBegin },
    { 0x2EDE, opcode::OP_EndSwitch },
    { 0x2EDF, opcode::OP_Invalid },
    { 0x2EE0, opcode::OP_Minus },
    { 0x2EE1, opcode::OP_Invalid },
    { 0x2EE2, opcode::OP_Invalid },
    { 0x2EE3, opcode::OP_GetNegUnsignedShort },
    { 0x2EE4, opcode::OP_GetWorld },
    { 0x2EE5, opcode::OP_Invalid },
    { 0x2EE6, opcode::OP_WaitTill },
    { 0x2EE7, opcode::OP_GetAPIFunction },
    { 0x2EE8, opcode::OP_GetSelfObject },
    { 0x2EE9, opcode::OP_Wait },
    { 0x2EEA, opcode::OP_Jump },
    { 0x2EEB, opcode::OP_Invalid },
    { 0x2EEC, opcode::OP_GetLevel },
    { 0x2EED, opcode::OP_GetFloat },
    { 0x2EEE, opcode::OP_Invalid },
    { 0x2EEF, opcode::OP_JumpOnTrueExpr },
    { 0x2EF0, opcode::OP_WaitTillMatch },
    { 0x2EF1, opcode::OP_Multiply },
    { 0x2EF2, opcode::OP_ScriptMethodCallPointer },
    { 0x2EF3, opcode::OP_Invalid },
    { 0x2EF4, opcode::OP_GetGameRef },
    { 0x2EF5, opcode::OP_Invalid },
    { 0x2EF6, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x2EF7, opcode::OP_GetWorldObject },
    { 0x2EF8, opcode::OP_ScriptThreadCallPointer },
    { 0x2EF9, opcode::OP_Invalid },
    { 0x2EFA, opcode::OP_Invalid },
    { 0x2EFB, opcode::OP_Invalid },
    { 0x2EFC, opcode::OP_ProfileStop },
    { 0x2EFD, opcode::OP_EvalFieldVariable },
    { 0x2EFE, opcode::OP_New },
    { 0x2EFF, opcode::OP_Invalid },
    { 0x2F00, opcode::OP_NextArrayKey },
    { 0x2F01, opcode::OP_Invalid },
    { 0x2F02, opcode::OP_Invalid },
    { 0x2F03, opcode::OP_GetByte },
    { 0x2F04, opcode::OP_SetVariableField },
    { 0x2F05, opcode::OP_GreaterThan },
    { 0x2F06, opcode::OP_GetGame },
    { 0x2F07, opcode::OP_Invalid },
    { 0x2F08, opcode::OP_WaitTill },
    { 0x2F09, opcode::OP_Invalid },
    { 0x2F0A, opcode::OP_GetNegUnsignedShort },
    { 0x2F0B, opcode::OP_GetGameRef },
    { 0x2F0C, opcode::OP_GetLevelObject },
    { 0x2F0D, opcode::OP_Dec },
    { 0x2F0E, opcode::OP_JumpOnTrue },
    { 0x2F0F, opcode::OP_SizeOf },
    { 0x2F10, opcode::OP_GreaterThanOrEqualTo },
    { 0x2F11, opcode::OP_GetSelfObject },
    { 0x2F12, opcode::OP_Invalid },
    { 0x2F13, opcode::OP_Invalid },
    { 0x2F14, opcode::OP_SafeDecTop },
    { 0x2F15, opcode::OP_GetZero },
    { 0x2F16, opcode::OP_Notify },
    { 0x2F17, opcode::OP_Bit_Or },
    { 0x2F18, opcode::OP_ShiftLeft },
    { 0x2F19, opcode::OP_FirstArrayKey },
    { 0x2F1A, opcode::OP_Invalid },
    { 0x2F1B, opcode::OP_Wait },
    { 0x2F1C, opcode::OP_Return },
    { 0x2F1D, opcode::OP_Invalid },
    { 0x2F1E, opcode::OP_DevblockBegin },
    { 0x2F1F, opcode::OP_SetVariableField },
    { 0x2F20, opcode::OP_ShiftRight },
    { 0x2F21, opcode::OP_GetString },
    { 0x2F22, opcode::OP_Invalid },
    { 0x2F23, opcode::OP_ShiftRight },
    { 0x2F24, opcode::OP_Switch },
    { 0x2F25, opcode::OP_WaitTillMatch },
    { 0x2F26, opcode::OP_Invalid },
    { 0x2F27, opcode::OP_ScriptMethodCall },
    { 0x2F28, opcode::OP_New },
    { 0x2F29, opcode::OP_Invalid },
    { 0x2F2A, opcode::OP_VectorScale },
    { 0x2F2B, opcode::OP_New },
    { 0x2F2C, opcode::OP_EvalLocalVariableCached },
    { 0x2F2D, opcode::OP_Invalid },
    { 0x2F2E, opcode::OP_SetVariableField },
    { 0x2F2F, opcode::OP_Wait },
    { 0x2F30, opcode::OP_Invalid },
    { 0x2F31, opcode::OP_ScriptThreadCall },
    { 0x2F32, opcode::OP_SafeSetVariableFieldCached },
    { 0x2F33, opcode::OP_Invalid },
    { 0x2F34, opcode::OP_ScriptThreadCall },
    { 0x2F35, opcode::OP_GetVector },
    { 0x2F36, opcode::OP_GetFloat },
    { 0x2F37, opcode::OP_Modulus },
    { 0x2F38, opcode::OP_LessThan },
    { 0x2F39, opcode::OP_Invalid },
    { 0x2F3A, opcode::OP_DecTop },
    { 0x2F3B, opcode::OP_Invalid },
    { 0x2F3C, opcode::OP_EmptyArray },
    { 0x2F3D, opcode::OP_Invalid },
    { 0x2F3E, opcode::OP_SuperEqual },
    { 0x2F3F, opcode::OP_EvalArrayRef },
    { 0x2F40, opcode::OP_Invalid },
    { 0x2F41, opcode::OP_GetNegByte },
    { 0x2F42, opcode::OP_JumpOnTrue },
    { 0x2F43, opcode::OP_GetByte },
    { 0x2F44, opcode::OP_New },
    { 0x2F45, opcode::OP_BoolNot },
    { 0x2F46, opcode::OP_Invalid },
    { 0x2F47, opcode::OP_Wait },
    { 0x2F48, opcode::OP_Invalid },
    { 0x2F49, opcode::OP_EndSwitch },
    { 0x2F4A, opcode::OP_GetByte },
    { 0x2F4B, opcode::OP_Jump },
    { 0x2F4C, opcode::OP_Invalid },
    { 0x2F4D, opcode::OP_GetAPIFunction },
    { 0x2F4E, opcode::OP_Invalid },
    { 0x2F4F, opcode::OP_Plus },
    { 0x2F50, opcode::OP_Invalid },
    { 0x2F51, opcode::OP_Invalid },
    { 0x2F52, opcode::OP_SelfEvalFieldVariable },
    { 0x2F53, opcode::OP_Invalid },
    { 0x2F54, opcode::OP_Return },
    { 0x2F55, opcode::OP_Invalid },
    { 0x2F56, opcode::OP_JumpOnFalseExpr },
    { 0x2F57, opcode::OP_GetWorldObject },
    { 0x2F58, opcode::OP_GetAnimation },
    { 0x2F59, opcode::OP_SetVariableField },
    { 0x2F5A, opcode::OP_SelfEvalFieldVariable },
    { 0x2F5B, opcode::OP_Invalid },
    { 0x2F5C, opcode::OP_Bit_Xor },
    { 0x2F5D, opcode::OP_ScriptThreadCall },
    { 0x2F5E, opcode::OP_EmptyArray },
    { 0x2F5F, opcode::OP_GreaterThanOrEqualTo },
    { 0x2F60, opcode::OP_GetLevel },
    { 0x2F61, opcode::OP_WaitTillMatch },
    { 0x2F62, opcode::OP_GetHash },
    { 0x2F63, opcode::OP_Invalid },
    { 0x2F64, opcode::OP_Invalid },
    { 0x2F65, opcode::OP_Invalid },
    { 0x2F66, opcode::OP_EvalArray },
    { 0x2F67, opcode::OP_Invalid },
    { 0x2F68, opcode::OP_FirstArrayKey },
    { 0x2F69, opcode::OP_GetHash },
    { 0x2F6A, opcode::OP_Invalid },
    { 0x2F6B, opcode::OP_GetAPIFunction },
    { 0x2F6C, opcode::OP_RealWait },
    { 0x2F6D, opcode::OP_ScriptMethodCallPointer },
    { 0x2F6E, opcode::OP_GetNegByte },
    { 0x2F6F, opcode::OP_ShiftLeft },
    { 0x2F70, opcode::OP_DevblockBegin },
    { 0x2F71, opcode::OP_Bit_Or },
    { 0x2F72, opcode::OP_CallBuiltinMethod },
    { 0x2F73, opcode::OP_VectorScale },
    { 0x2F74, opcode::OP_Invalid },
    { 0x2F75, opcode::OP_Invalid },
    { 0x2F76, opcode::OP_LessThanOrEqualTo },
    { 0x2F77, opcode::OP_Invalid },
    { 0x2F78, opcode::OP_Invalid },
    { 0x2F79, opcode::OP_Invalid },
    { 0x2F7A, opcode::OP_ScriptMethodThreadCall },
    { 0x2F7B, opcode::OP_EvalLocalVariableCached },
    { 0x2F7C, opcode::OP_Notify },
    { 0x2F7D, opcode::OP_Invalid },
    { 0x2F7E, opcode::OP_VectorConstant },
    { 0x2F7F, opcode::OP_NextArrayKey },
    { 0x2F80, opcode::OP_GetString },
    { 0x2F81, opcode::OP_DecTop },
    { 0x2F82, opcode::OP_Invalid },
    { 0x2F83, opcode::OP_Invalid },
    { 0x2F84, opcode::OP_FirstArrayKey },
    { 0x2F85, opcode::OP_Bit_And },
    { 0x2F86, opcode::OP_Invalid },
    { 0x2F87, opcode::OP_GetTime },
    { 0x2F88, opcode::OP_SizeOf },
    { 0x2F89, opcode::OP_EmptyArray },
    { 0x2F8A, opcode::OP_DecTop },
    { 0x2F8B, opcode::OP_Invalid },
    { 0x2F8C, opcode::OP_GetUnsignedShort },
    { 0x2F8D, opcode::OP_SuperNotEqual },
    { 0x2F8E, opcode::OP_RealWait },
    { 0x2F8F, opcode::OP_LessThanOrEqualTo },
    { 0x2F90, opcode::OP_Invalid },
    { 0x2F91, opcode::OP_Invalid },
    { 0x2F92, opcode::OP_Invalid },
    { 0x2F93, opcode::OP_Invalid },
    { 0x2F94, opcode::OP_Plus },
    { 0x2F95, opcode::OP_Invalid },
    { 0x2F96, opcode::OP_GetAnimObject },
    { 0x2F97, opcode::OP_EndOn },
    { 0x2F98, opcode::OP_JumpOnFalse },
    { 0x2F99, opcode::OP_GetVector },
    { 0x2F9A, opcode::OP_LevelEvalFieldVariableRef },
    { 0x2F9B, opcode::OP_JumpOnFalse },
    { 0x2F9C, opcode::OP_VectorConstant },
    { 0x2F9D, opcode::OP_Invalid },
    { 0x2F9E, opcode::OP_New },
    { 0x2F9F, opcode::OP_Invalid },
    { 0x2FA0, opcode::OP_Bit_Xor },
    { 0x2FA1, opcode::OP_Invalid },
    { 0x2FA2, opcode::OP_Invalid },
    { 0x2FA3, opcode::OP_Invalid },
    { 0x2FA4, opcode::OP_GreaterThan },
    { 0x2FA5, opcode::OP_Invalid },
    { 0x2FA6, opcode::OP_Invalid },
    { 0x2FA7, opcode::OP_Notify },
    { 0x2FA8, opcode::OP_Invalid },
    { 0x2FA9, opcode::OP_EvalArray },
    { 0x2FAA, opcode::OP_Invalid },
    { 0x2FAB, opcode::OP_DecTop },
    { 0x2FAC, opcode::OP_ScriptFunctionCallClass },
    { 0x2FAD, opcode::OP_NextArrayKey },
    { 0x2FAE, opcode::OP_ProfileStop },
    { 0x2FAF, opcode::OP_Divide },
    { 0x2FB0, opcode::OP_Invalid },
    { 0x2FB1, opcode::OP_Modulus },
    { 0x2FB2, opcode::OP_GetIString },
    { 0x2FB3, opcode::OP_Divide },
    { 0x2FB4, opcode::OP_Invalid },
    { 0x2FB5, opcode::OP_EvalFieldVariableRef },
    { 0x2FB6, opcode::OP_ScriptMethodThreadCall },
    { 0x2FB7, opcode::OP_JumpOnFalse },
    { 0x2FB8, opcode::OP_SuperEqual },
    { 0x2FB9, opcode::OP_Invalid },
    { 0x2FBA, opcode::OP_Invalid },
    { 0x2FBB, opcode::OP_Invalid },
    { 0x2FBC, opcode::OP_LevelEvalFieldVariable },
    { 0x2FBD, opcode::OP_GetVector },
    { 0x2FBE, opcode::OP_Invalid },
    { 0x2FBF, opcode::OP_CallBuiltinMethod },
    { 0x2FC0, opcode::OP_ScriptMethodCall },
    { 0x2FC1, opcode::OP_ShiftLeft },
    { 0x2FC2, opcode::OP_LevelEvalFieldVariable },
    { 0x2FC3, opcode::OP_Minus },
    { 0x2FC4, opcode::OP_GetLevelObject },
    { 0x2FC5, opcode::OP_ProfileStop },
    { 0x2FC6, opcode::OP_GetAnim },
    { 0x2FC7, opcode::OP_GetHash },
    { 0x2FC8, opcode::OP_GetUintptr },
    { 0x2FC9, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x2FCA, opcode::OP_Invalid },
    { 0x2FCB, opcode::OP_CastFieldObject },
    { 0x2FCC, opcode::OP_Modulus },
    { 0x2FCD, opcode::OP_GetVector },
    { 0x2FCE, opcode::OP_EndSwitch },
    { 0x2FCF, opcode::OP_Invalid },
    { 0x2FD0, opcode::OP_ScriptThreadCallClass },
    { 0x2FD1, opcode::OP_Notify },
    { 0x2FD2, opcode::OP_Invalid },
    { 0x2FD3, opcode::OP_GetClassesObject },
    { 0x2FD4, opcode::OP_ClearFieldVariable },
    { 0x2FD5, opcode::OP_Invalid },
    { 0x2FD6, opcode::OP_ScriptMethodThreadCall },
    { 0x2FD7, opcode::OP_Return },
    { 0x2FD8, opcode::OP_Jump },
    { 0x2FD9, opcode::OP_EvalArrayRef },
    { 0x2FDA, opcode::OP_Notify },
    { 0x2FDB, opcode::OP_Invalid },
    { 0x2FDC, opcode::OP_Invalid },
    { 0x2FDD, opcode::OP_EvalFieldVariable },
    { 0x2FDE, opcode::OP_Invalid },
    { 0x2FDF, opcode::OP_Invalid },
    { 0x2FE0, opcode::OP_EvalArray },
    { 0x2FE1, opcode::OP_Invalid },
    { 0x2FE2, opcode::OP_Jump },
    { 0x2FE3, opcode::OP_EmptyArray },
    { 0x2FE4, opcode::OP_Bit_Xor },
    { 0x2FE5, opcode::OP_GetAPIFunction },
    { 0x2FE6, opcode::OP_VectorScale },
    { 0x2FE7, opcode::OP_Invalid },
    { 0x2FE8, opcode::OP_Invalid },
    { 0x2FE9, opcode::OP_CastFieldObject },
    { 0x2FEA, opcode::OP_EndSwitch },
    { 0x2FEB, opcode::OP_CallBuiltinMethod },
    { 0x2FEC, opcode::OP_JumpOnTrue },
    { 0x2FED, opcode::OP_Invalid },
    { 0x2FEE, opcode::OP_New },
    { 0x2FEF, opcode::OP_Invalid },
    { 0x2FF0, opcode::OP_New },
    { 0x2FF1, opcode::OP_Invalid },
    { 0x2FF2, opcode::OP_EvalArray },
    { 0x2FF3, opcode::OP_EndOn },
    { 0x2FF4, opcode::OP_GetIString },
    { 0x2FF5, opcode::OP_Wait },
    { 0x2FF6, opcode::OP_Vector },
    { 0x2FF7, opcode::OP_Invalid },
    { 0x2FF8, opcode::OP_GetInteger },
    { 0x2FF9, opcode::OP_NextArrayKey },
    { 0x2FFA, opcode::OP_ScriptMethodThreadCall },
    { 0x2FFB, opcode::OP_GetUintptr },
    { 0x2FFC, opcode::OP_GetUintptr },
    { 0x2FFD, opcode::OP_CastBool },
    { 0x2FFE, opcode::OP_Notify },
    { 0x2FFF, opcode::OP_Invalid },
    { 0x3000, opcode::OP_Invalid },
    { 0x3001, opcode::OP_Invalid },
    { 0x3002, opcode::OP_LevelEvalFieldVariable },
    { 0x3003, opcode::OP_Vector },
    { 0x3004, opcode::OP_Invalid },
    { 0x3005, opcode::OP_Invalid },
    { 0x3006, opcode::OP_JumpOnTrue },
    { 0x3007, opcode::OP_GetNegByte },
    { 0x3008, opcode::OP_Invalid },
    { 0x3009, opcode::OP_EndOn },
    { 0x300A, opcode::OP_GetClasses },
    { 0x300B, opcode::OP_ScriptThreadCall },
    { 0x300C, opcode::OP_GetSelf },
    { 0x300D, opcode::OP_GetFloat },
    { 0x300E, opcode::OP_ClearFieldVariable },
    { 0x300F, opcode::OP_SizeOf },
    { 0x3010, opcode::OP_FirstArrayKey },
    { 0x3011, opcode::OP_GetAnimObject },
    { 0x3012, opcode::OP_Invalid },
    { 0x3013, opcode::OP_Invalid },
    { 0x3014, opcode::OP_ClearFieldVariable },
    { 0x3015, opcode::OP_SelfEvalFieldVariable },
    { 0x3016, opcode::OP_Invalid },
    { 0x3017, opcode::OP_ShiftRight },
    { 0x3018, opcode::OP_Invalid },
    { 0x3019, opcode::OP_Inc },
    { 0x301A, opcode::OP_Invalid },
    { 0x301B, opcode::OP_VectorScale },
    { 0x301C, opcode::OP_Invalid },
    { 0x301D, opcode::OP_Wait },
    { 0x301E, opcode::OP_WaitTill },
    { 0x301F, opcode::OP_GetAnim },
    { 0x3020, opcode::OP_Invalid },
    { 0x3021, opcode::OP_SelfEvalFieldVariable },
    { 0x3022, opcode::OP_Invalid },
    { 0x3023, opcode::OP_Invalid },
    { 0x3024, opcode::OP_FirstArrayKey },
    { 0x3025, opcode::OP_SetVariableField },
    { 0x3026, opcode::OP_EvalLocalVariableRefCached },
    { 0x3027, opcode::OP_GetAnimObject },
    { 0x3028, opcode::OP_ScriptMethodCallPointer },
    { 0x3029, opcode::OP_SafeCreateLocalVariables },
    { 0x302A, opcode::OP_WaitTillMatch },
    { 0x302B, opcode::OP_Notify },
    { 0x302C, opcode::OP_GetWorld },
    { 0x302D, opcode::OP_EmptyArray },
    { 0x302E, opcode::OP_GetGame },
    { 0x302F, opcode::OP_Invalid },
    { 0x3030, opcode::OP_Notify },
    { 0x3031, opcode::OP_Invalid },
    { 0x3032, opcode::OP_Invalid },
    { 0x3033, opcode::OP_Invalid },
    { 0x3034, opcode::OP_SetVariableField },
    { 0x3035, opcode::OP_WaitTill },
    { 0x3036, opcode::OP_WaitTillFrameEnd },
    { 0x3037, opcode::OP_Jump },
    { 0x3038, opcode::OP_GetAPIFunction },
    { 0x3039, opcode::OP_SafeDecTop },
    { 0x303A, opcode::OP_WaitTillMatch },
    { 0x303B, opcode::OP_Invalid },
    { 0x303C, opcode::OP_EvalLocalVariableRefCached },
    { 0x303D, opcode::OP_Invalid },
    { 0x303E, opcode::OP_SuperEqual },
    { 0x303F, opcode::OP_GetString },
    { 0x3040, opcode::OP_Invalid },
    { 0x3041, opcode::OP_EvalFieldVariable },
    { 0x3042, opcode::OP_GetAnimation },
    { 0x3043, opcode::OP_Vector },
    { 0x3044, opcode::OP_Invalid },
    { 0x3045, opcode::OP_Invalid },
    { 0x3046, opcode::OP_GetNegUnsignedShort },
    { 0x3047, opcode::OP_GetString },
    { 0x3048, opcode::OP_JumpOnTrueExpr },
    { 0x3049, opcode::OP_DecTop },
    { 0x304A, opcode::OP_GetSelfObject },
    { 0x304B, opcode::OP_Invalid },
    { 0x304C, opcode::OP_GetZero },
    { 0x304D, opcode::OP_Invalid },
    { 0x304E, opcode::OP_WaitTill },
    { 0x304F, opcode::OP_Bit_Or },
    { 0x3050, opcode::OP_JumpOnTrue },
    { 0x3051, opcode::OP_ScriptFunctionCallPointer },
    { 0x3052, opcode::OP_Wait },
    { 0x3053, opcode::OP_GetClasses },
    { 0x3054, opcode::OP_VectorScale },
    { 0x3055, opcode::OP_Invalid },
    { 0x3056, opcode::OP_WaitTill },
    { 0x3057, opcode::OP_ClearFieldVariable },
    { 0x3058, opcode::OP_CastFieldObject },
    { 0x3059, opcode::OP_GetNegUnsignedShort },
    { 0x305A, opcode::OP_Multiply },
    { 0x305B, opcode::OP_Bit_And },
    { 0x305C, opcode::OP_Invalid },
    { 0x305D, opcode::OP_Invalid },
    { 0x305E, opcode::OP_VectorConstant },
    { 0x305F, opcode::OP_GetFloat },
    { 0x3060, opcode::OP_LessThanOrEqualTo },
    { 0x3061, opcode::OP_Invalid },
    { 0x3062, opcode::OP_Invalid },
    { 0x3063, opcode::OP_GetVector },
    { 0x3064, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x3065, opcode::OP_ScriptMethodThreadCall },
    { 0x3066, opcode::OP_ShiftLeft },
    { 0x3067, opcode::OP_EvalLocalVariableCached },
    { 0x3068, opcode::OP_GetAnimObject },
    { 0x3069, opcode::OP_Invalid },
    { 0x306A, opcode::OP_GetHash },
    { 0x306B, opcode::OP_ProfileStart },
    { 0x306C, opcode::OP_DecTop },
    { 0x306D, opcode::OP_ScriptThreadCallClass },
    { 0x306E, opcode::OP_GetLevel },
    { 0x306F, opcode::OP_Invalid },
    { 0x3070, opcode::OP_LevelEvalFieldVariable },
    { 0x3071, opcode::OP_Invalid },
    { 0x3072, opcode::OP_Invalid },
    { 0x3073, opcode::OP_GetSelfObject },
    { 0x3074, opcode::OP_Invalid },
    { 0x3075, opcode::OP_Invalid },
    { 0x3076, opcode::OP_ScriptMethodCallPointer },
    { 0x3077, opcode::OP_WaitTillFrameEnd },
    { 0x3078, opcode::OP_Invalid },
    { 0x3079, opcode::OP_Return },
    { 0x307A, opcode::OP_DevblockBegin },
    { 0x307B, opcode::OP_LevelEvalFieldVariableRef },
    { 0x307C, opcode::OP_Invalid },
    { 0x307D, opcode::OP_ScriptThreadCallClass },
    { 0x307E, opcode::OP_Invalid },
    { 0x307F, opcode::OP_GetFunction },
    { 0x3080, opcode::OP_GetUndefined },
    { 0x3081, opcode::OP_Invalid },
    { 0x3082, opcode::OP_JumpOnTrueExpr },
    { 0x3083, opcode::OP_GreaterThanOrEqualTo },
    { 0x3084, opcode::OP_WaitTill },
    { 0x3085, opcode::OP_EvalLocalVariableCached },
    { 0x3086, opcode::OP_Switch },
    { 0x3087, opcode::OP_Invalid },
    { 0x3088, opcode::OP_Bit_Or },
    { 0x3089, opcode::OP_LevelEvalFieldVariable },
    { 0x308A, opcode::OP_GetWorld },
    { 0x308B, opcode::OP_SetVariableField },
    { 0x308C, opcode::OP_EvalFieldVariable },
    { 0x308D, opcode::OP_SelfEvalFieldVariable },
    { 0x308E, opcode::OP_ScriptThreadCallClass },
    { 0x308F, opcode::OP_GetUndefined },
    { 0x3090, opcode::OP_GetFunction },
    { 0x3091, opcode::OP_JumpOnTrueExpr },
    { 0x3092, opcode::OP_ScriptThreadCallClass },
    { 0x3093, opcode::OP_ScriptFunctionCallClass },
    { 0x3094, opcode::OP_Modulus },
    { 0x3095, opcode::OP_GreaterThan },
    { 0x3096, opcode::OP_SizeOf },
    { 0x3097, opcode::OP_SafeSetVariableFieldCached },
    { 0x3098, opcode::OP_Bit_Or },
    { 0x3099, opcode::OP_New },
    { 0x309A, opcode::OP_GetAnim },
    { 0x309B, opcode::OP_ScriptFunctionCall },
    { 0x309C, opcode::OP_ShiftLeft },
    { 0x309D, opcode::OP_GetLevelObject },
    { 0x309E, opcode::OP_Invalid },
    { 0x309F, opcode::OP_ScriptFunctionCallPointer },
    { 0x30A0, opcode::OP_JumpOnTrueExpr },
    { 0x30A1, opcode::OP_SafeDecTop },
    { 0x30A2, opcode::OP_Invalid },
    { 0x30A3, opcode::OP_Invalid },
    { 0x30A4, opcode::OP_GetHash },
    { 0x30A5, opcode::OP_JumpOnFalseExpr },
    { 0x30A6, opcode::OP_Plus },
    { 0x30A7, opcode::OP_ScriptThreadCall },
    { 0x30A8, opcode::OP_GetHash },
    { 0x30A9, opcode::OP_EvalLocalVariableCached },
    { 0x30AA, opcode::OP_Invalid },
    { 0x30AB, opcode::OP_SafeDecTop },
    { 0x30AC, opcode::OP_Bit_Or },
    { 0x30AD, opcode::OP_GetVector },
    { 0x30AE, opcode::OP_GetAnimObject },
    { 0x30AF, opcode::OP_SafeDecTop },
    { 0x30B0, opcode::OP_Invalid },
    { 0x30B1, opcode::OP_Invalid },
    { 0x30B2, opcode::OP_SetVariableField },
    { 0x30B3, opcode::OP_GetTime },
    { 0x30B4, opcode::OP_CastFieldObject },
    { 0x30B5, opcode::OP_Plus },
    { 0x30B6, opcode::OP_GetWorld },
    { 0x30B7, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x30B8, opcode::OP_ScriptMethodThreadCall },
    { 0x30B9, opcode::OP_Invalid },
    { 0x30BA, opcode::OP_GreaterThanOrEqualTo },
    { 0x30BB, opcode::OP_EndSwitch },
    { 0x30BC, opcode::OP_JumpOnTrueExpr },
    { 0x30BD, opcode::OP_Invalid },
    { 0x30BE, opcode::OP_Return },
    { 0x30BF, opcode::OP_GetLevelObject },
    { 0x30C0, opcode::OP_Invalid },
    { 0x30C1, opcode::OP_SelfEvalFieldVariableRef },
    { 0x30C2, opcode::OP_Invalid },
    { 0x30C3, opcode::OP_Invalid },
    { 0x30C4, opcode::OP_GreaterThanOrEqualTo },
    { 0x30C5, opcode::OP_Invalid },
    { 0x30C6, opcode::OP_SafeSetVariableFieldCached },
    { 0x30C7, opcode::OP_JumpOnFalse },
    { 0x30C8, opcode::OP_Invalid },
    { 0x30C9, opcode::OP_Invalid },
    { 0x30CA, opcode::OP_GetAnim },
    { 0x30CB, opcode::OP_Invalid },
    { 0x30CC, opcode::OP_Invalid },
    { 0x30CD, opcode::OP_Invalid },
    { 0x30CE, opcode::OP_Invalid },
    { 0x30CF, opcode::OP_Invalid },
    { 0x30D0, opcode::OP_EmptyArray },
    { 0x30D1, opcode::OP_CastFieldObject },
    { 0x30D2, opcode::OP_JumpOnFalse },
    { 0x30D3, opcode::OP_Jump },
    { 0x30D4, opcode::OP_ScriptMethodThreadCall },
    { 0x30D5, opcode::OP_ShiftRight },
    { 0x30D6, opcode::OP_JumpOnFalseExpr },
    { 0x30D7, opcode::OP_Invalid },
    { 0x30D8, opcode::OP_Invalid },
    { 0x30D9, opcode::OP_Invalid },
    { 0x30DA, opcode::OP_SafeDecTop },
    { 0x30DB, opcode::OP_GetHash },
    { 0x30DC, opcode::OP_GetUndefined },
    { 0x30DD, opcode::OP_Invalid },
    { 0x30DE, opcode::OP_Invalid },
    { 0x30DF, opcode::OP_Notify },
    { 0x30E0, opcode::OP_ProfileStart },
    { 0x30E1, opcode::OP_Invalid },
    { 0x30E2, opcode::OP_SizeOf },
    { 0x30E3, opcode::OP_Bit_And },
    { 0x30E4, opcode::OP_GetFloat },
    { 0x30E5, opcode::OP_ClearFieldVariable },
    { 0x30E6, opcode::OP_Invalid },
    { 0x30E7, opcode::OP_GetNegByte },
    { 0x30E8, opcode::OP_GetInteger },
    { 0x30E9, opcode::OP_GetWorld },
    { 0x30EA, opcode::OP_ShiftLeft },
    { 0x30EB, opcode::OP_DevblockBegin },
    { 0x30EC, opcode::OP_VectorScale },
    { 0x30ED, opcode::OP_Invalid },
    { 0x30EE, opcode::OP_GetSelfObject },
    { 0x30EF, opcode::OP_Divide },
    { 0x30F0, opcode::OP_Invalid },
    { 0x30F1, opcode::OP_ScriptThreadCallClass },
    { 0x30F2, opcode::OP_Invalid },
    { 0x30F3, opcode::OP_GetAnimObject },
    { 0x30F4, opcode::OP_NextArrayKey },
    { 0x30F5, opcode::OP_GetSelfObject },
    { 0x30F6, opcode::OP_Modulus },
    { 0x30F7, opcode::OP_GetHash },
    { 0x30F8, opcode::OP_GetGame },
    { 0x30F9, opcode::OP_Multiply },
    { 0x30FA, opcode::OP_GetIString },
    { 0x30FB, opcode::OP_GetUintptr },
    { 0x30FC, opcode::OP_Wait },
    { 0x30FD, opcode::OP_CallBuiltinMethod },
    { 0x30FE, opcode::OP_Invalid },
    { 0x30FF, opcode::OP_ScriptThreadCallClass },
    { 0x3100, opcode::OP_CallBuiltinMethod },
    { 0x3101, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x3102, opcode::OP_Invalid },
    { 0x3103, opcode::OP_GetAnim },
    { 0x3104, opcode::OP_ProfileStop },
    { 0x3105, opcode::OP_GetString },
    { 0x3106, opcode::OP_IsDefined },
    { 0x3107, opcode::OP_Invalid },
    { 0x3108, opcode::OP_Invalid },
    { 0x3109, opcode::OP_RealWait },
    { 0x310A, opcode::OP_JumpOnFalse },
    { 0x310B, opcode::OP_DecTop },
    { 0x310C, opcode::OP_Invalid },
    { 0x310D, opcode::OP_GetHash },
    { 0x310E, opcode::OP_Invalid },
    { 0x310F, opcode::OP_EvalArray },
    { 0x3110, opcode::OP_SuperNotEqual },
    { 0x3111, opcode::OP_JumpOnFalseExpr },
    { 0x3112, opcode::OP_GetAnimObject },
    { 0x3113, opcode::OP_Invalid },
    { 0x3114, opcode::OP_NotEqual },
    { 0x3115, opcode::OP_Invalid },
    { 0x3116, opcode::OP_Invalid },
    { 0x3117, opcode::OP_ScriptThreadCall },
    { 0x3118, opcode::OP_EvalArray },
    { 0x3119, opcode::OP_GetUintptr },
    { 0x311A, opcode::OP_SafeDecTop },
    { 0x311B, opcode::OP_Invalid },
    { 0x311C, opcode::OP_Invalid },
    { 0x311D, opcode::OP_Bit_Xor },
    { 0x311E, opcode::OP_Invalid },
    { 0x311F, opcode::OP_Invalid },
    { 0x3120, opcode::OP_Invalid },
    { 0x3121, opcode::OP_EndSwitch },
    { 0x3122, opcode::OP_Jump },
    { 0x3123, opcode::OP_GetWorld },
    { 0x3124, opcode::OP_Invalid },
    { 0x3125, opcode::OP_JumpOnFalseExpr },
    { 0x3126, opcode::OP_GetWorldObject },
    { 0x3127, opcode::OP_EmptyArray },
    { 0x3128, opcode::OP_Return },
    { 0x3129, opcode::OP_NextArrayKey },
    { 0x312A, opcode::OP_ScriptFunctionCallClass },
    { 0x312B, opcode::OP_WaitTill },
    { 0x312C, opcode::OP_EndSwitch },
    { 0x312D, opcode::OP_Return },
    { 0x312E, opcode::OP_Invalid },
    { 0x312F, opcode::OP_LessThanOrEqualTo },
    { 0x3130, opcode::OP_Return },
    { 0x3131, opcode::OP_JumpOnTrue },
    { 0x3132, opcode::OP_Invalid },
    { 0x3133, opcode::OP_Invalid },
    { 0x3134, opcode::OP_LevelEvalFieldVariable },
    { 0x3135, opcode::OP_GetUnsignedShort },
    { 0x3136, opcode::OP_NextArrayKey },
    { 0x3137, opcode::OP_Invalid },
    { 0x3138, opcode::OP_Invalid },
    { 0x3139, opcode::OP_GetVector },
    { 0x313A, opcode::OP_GetHash },
    { 0x313B, opcode::OP_BoolComplement },
    { 0x313C, opcode::OP_IsDefined },
    { 0x313D, opcode::OP_Divide },
    { 0x313E, opcode::OP_ProfileStart },
    { 0x313F, opcode::OP_DevblockBegin },
    { 0x3140, opcode::OP_GetClasses },
    { 0x3141, opcode::OP_Invalid },
    { 0x3142, opcode::OP_GetVector },
    { 0x3143, opcode::OP_BoolComplement },
    { 0x3144, opcode::OP_Invalid },
    { 0x3145, opcode::OP_GetUnsignedShort },
    { 0x3146, opcode::OP_Invalid },
    { 0x3147, opcode::OP_Invalid },
    { 0x3148, opcode::OP_ProfileStop },
    { 0x3149, opcode::OP_Invalid },
    { 0x314A, opcode::OP_Invalid },
    { 0x314B, opcode::OP_GetUndefined },
    { 0x314C, opcode::OP_ClearFieldVariable },
    { 0x314D, opcode::OP_IsDefined },
    { 0x314E, opcode::OP_Invalid },
    { 0x314F, opcode::OP_Dec },
    { 0x3150, opcode::OP_Invalid },
    { 0x3151, opcode::OP_Invalid },
    { 0x3152, opcode::OP_Multiply },
    { 0x3153, opcode::OP_Vector },
    { 0x3154, opcode::OP_EvalLocalVariableRefCached },
    { 0x3155, opcode::OP_EmptyArray },
    { 0x3156, opcode::OP_BoolNot },
    { 0x3157, opcode::OP_Invalid },
    { 0x3158, opcode::OP_ShiftLeft },
    { 0x3159, opcode::OP_GetWorld },
    { 0x315A, opcode::OP_Invalid },
    { 0x315B, opcode::OP_Jump },
    { 0x315C, opcode::OP_Plus },
    { 0x315D, opcode::OP_JumpOnFalseExpr },
    { 0x315E, opcode::OP_Invalid },
    { 0x315F, opcode::OP_JumpOnFalseExpr },
    { 0x3160, opcode::OP_LessThan },
    { 0x3161, opcode::OP_ScriptThreadCall },
    { 0x3162, opcode::OP_JumpOnTrueExpr },
    { 0x3163, opcode::OP_GetGame },
    { 0x3164, opcode::OP_Bit_Or },
    { 0x3165, opcode::OP_Minus },
    { 0x3166, opcode::OP_Divide },
    { 0x3167, opcode::OP_GetIString },
    { 0x3168, opcode::OP_ScriptFunctionCallPointer },
    { 0x3169, opcode::OP_Invalid },
    { 0x316A, opcode::OP_LevelEvalFieldVariable },
    { 0x316B, opcode::OP_Invalid },
    { 0x316C, opcode::OP_GetSelf },
    { 0x316D, opcode::OP_SetVariableField },
    { 0x316E, opcode::OP_GetGame },
    { 0x316F, opcode::OP_SetVariableField },
    { 0x3170, opcode::OP_Invalid },
    { 0x3171, opcode::OP_Invalid },
    { 0x3172, opcode::OP_JumpOnFalseExpr },
    { 0x3173, opcode::OP_Invalid },
    { 0x3174, opcode::OP_Plus },
    { 0x3175, opcode::OP_GetFloat },
    { 0x3176, opcode::OP_LessThanOrEqualTo },
    { 0x3177, opcode::OP_DevblockBegin },
    { 0x3178, opcode::OP_Invalid },
    { 0x3179, opcode::OP_Jump },
    { 0x317A, opcode::OP_Invalid },
    { 0x317B, opcode::OP_GetAnim },
    { 0x317C, opcode::OP_EvalLocalVariableCached },
    { 0x317D, opcode::OP_Invalid },
    { 0x317E, opcode::OP_Invalid },
    { 0x317F, opcode::OP_Invalid },
    { 0x3180, opcode::OP_WaitTill },
    { 0x3181, opcode::OP_FirstArrayKey },
    { 0x3182, opcode::OP_EvalFieldVariable },
    { 0x3183, opcode::OP_Invalid },
    { 0x3184, opcode::OP_Bit_Xor },
    { 0x3185, opcode::OP_RealWait },
    { 0x3186, opcode::OP_Invalid },
    { 0x3187, opcode::OP_Invalid },
    { 0x3188, opcode::OP_LevelEvalFieldVariableRef },
    { 0x3189, opcode::OP_FirstArrayKey },
    { 0x318A, opcode::OP_Invalid },
    { 0x318B, opcode::OP_EvalFieldVariableRef },
    { 0x318C, opcode::OP_GetAnimObject },
    { 0x318D, opcode::OP_GetIString },
    { 0x318E, opcode::OP_Invalid },
    { 0x318F, opcode::OP_WaitTillFrameEnd },
    { 0x3190, opcode::OP_Invalid },
    { 0x3191, opcode::OP_Invalid },
    { 0x3192, opcode::OP_Wait },
    { 0x3193, opcode::OP_Invalid },
    { 0x3194, opcode::OP_ScriptMethodThreadCall },
    { 0x3195, opcode::OP_Invalid },
    { 0x3196, opcode::OP_SafeCreateLocalVariables },
    { 0x3197, opcode::OP_GetString },
    { 0x3198, opcode::OP_Invalid },
    { 0x3199, opcode::OP_Invalid },
    { 0x319A, opcode::OP_WaitTillFrameEnd },
    { 0x319B, opcode::OP_Invalid },
    { 0x319C, opcode::OP_Notify },
    { 0x319D, opcode::OP_Invalid },
    { 0x319E, opcode::OP_Invalid },
    { 0x319F, opcode::OP_Invalid },
    { 0x31A0, opcode::OP_Invalid },
    { 0x31A1, opcode::OP_ClearFieldVariable },
    { 0x31A2, opcode::OP_SuperNotEqual },
    { 0x31A3, opcode::OP_Invalid },
    { 0x31A4, opcode::OP_ScriptMethodCall },
    { 0x31A5, opcode::OP_Bit_Or },
    { 0x31A6, opcode::OP_GetClasses },
    { 0x31A7, opcode::OP_EvalLocalVariableCached },
    { 0x31A8, opcode::OP_EndOn },
    { 0x31A9, opcode::OP_SizeOf },
    { 0x31AA, opcode::OP_Bit_And },
    { 0x31AB, opcode::OP_VectorScale },
    { 0x31AC, opcode::OP_Invalid },
    { 0x31AD, opcode::OP_Inc },
    { 0x31AE, opcode::OP_Invalid },
    { 0x31AF, opcode::OP_JumpOnFalseExpr },
    { 0x31B0, opcode::OP_LessThan },
    { 0x31B1, opcode::OP_Invalid },
    { 0x31B2, opcode::OP_Invalid },
    { 0x31B3, opcode::OP_GetAPIFunction },
    { 0x31B4, opcode::OP_Switch },
    { 0x31B5, opcode::OP_Return },
    { 0x31B6, opcode::OP_Invalid },
    { 0x31B7, opcode::OP_DevblockBegin },
    { 0x31B8, opcode::OP_CallBuiltinMethod },
    { 0x31B9, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x31BA, opcode::OP_RealWait },
    { 0x31BB, opcode::OP_JumpOnFalseExpr },
    { 0x31BC, opcode::OP_Modulus },
    { 0x31BD, opcode::OP_JumpOnTrue },
    { 0x31BE, opcode::OP_GetWorldObject },
    { 0x31BF, opcode::OP_Invalid },
    { 0x31C0, opcode::OP_Invalid },
    { 0x31C1, opcode::OP_GetFloat },
    { 0x31C2, opcode::OP_JumpOnFalseExpr },
    { 0x31C3, opcode::OP_GetWorldObject },
    { 0x31C4, opcode::OP_VectorScale },
    { 0x31C5, opcode::OP_GetSelf },
    { 0x31C6, opcode::OP_JumpOnFalse },
    { 0x31C7, opcode::OP_Invalid },
    { 0x31C8, opcode::OP_SuperEqual },
    { 0x31C9, opcode::OP_GetUndefined },
    { 0x31CA, opcode::OP_EvalArray },
    { 0x31CB, opcode::OP_Invalid },
    { 0x31CC, opcode::OP_EvalLocalVariableRefCached },
    { 0x31CD, opcode::OP_ShiftRight },
    { 0x31CE, opcode::OP_RealWait },
    { 0x31CF, opcode::OP_FirstArrayKey },
    { 0x31D0, opcode::OP_Invalid },
    { 0x31D1, opcode::OP_ShiftRight },
    { 0x31D2, opcode::OP_NotEqual },
    { 0x31D3, opcode::OP_GreaterThan },
    { 0x31D4, opcode::OP_Return },
    { 0x31D5, opcode::OP_EndSwitch },
    { 0x31D6, opcode::OP_EmptyArray },
    { 0x31D7, opcode::OP_EndOn },
    { 0x31D8, opcode::OP_JumpOnTrue },
    { 0x31D9, opcode::OP_Switch },
    { 0x31DA, opcode::OP_Invalid },
    { 0x31DB, opcode::OP_GetWorldObject },
    { 0x31DC, opcode::OP_GetLevel },
    { 0x31DD, opcode::OP_Invalid },
    { 0x31DE, opcode::OP_ClearArray },
    { 0x31DF, opcode::OP_JumpOnTrue },
    { 0x31E0, opcode::OP_Invalid },
    { 0x31E1, opcode::OP_SafeSetVariableFieldCached },
    { 0x31E2, opcode::OP_NotEqual },
    { 0x31E3, opcode::OP_Invalid },
    { 0x31E4, opcode::OP_GetLevel },
    { 0x31E5, opcode::OP_LessThanOrEqualTo },
    { 0x31E6, opcode::OP_Invalid },
    { 0x31E7, opcode::OP_ScriptFunctionCallClass },
    { 0x31E8, opcode::OP_Invalid },
    { 0x31E9, opcode::OP_Invalid },
    { 0x31EA, opcode::OP_Invalid },
    { 0x31EB, opcode::OP_SafeDecTop },
    { 0x31EC, opcode::OP_SafeDecTop },
    { 0x31ED, opcode::OP_Invalid },
    { 0x31EE, opcode::OP_GetUndefined },
    { 0x31EF, opcode::OP_GetInteger },
    { 0x31F0, opcode::OP_Invalid },
    { 0x31F1, opcode::OP_GetHash },
    { 0x31F2, opcode::OP_Invalid },
    { 0x31F3, opcode::OP_LessThanOrEqualTo },
    { 0x31F4, opcode::OP_Invalid },
    { 0x31F5, opcode::OP_Invalid },
    { 0x31F6, opcode::OP_Invalid },
    { 0x31F7, opcode::OP_Invalid },
    { 0x31F8, opcode::OP_Jump },
    { 0x31F9, opcode::OP_Notify },
    { 0x31FA, opcode::OP_Invalid },
    { 0x31FB, opcode::OP_Invalid },
    { 0x31FC, opcode::OP_Invalid },
    { 0x31FD, opcode::OP_GreaterThanOrEqualTo },
    { 0x31FE, opcode::OP_GetByte },
    { 0x31FF, opcode::OP_NotEqual },
    { 0x3200, opcode::OP_Invalid },
    { 0x3201, opcode::OP_BoolComplement },
    { 0x3202, opcode::OP_Invalid },
    { 0x3203, opcode::OP_Invalid },
    { 0x3204, opcode::OP_GetSelf },
    { 0x3205, opcode::OP_GetIString },
    { 0x3206, opcode::OP_GetTime },
    { 0x3207, opcode::OP_ShiftLeft },
    { 0x3208, opcode::OP_Invalid },
    { 0x3209, opcode::OP_EvalLocalVariableCached },
    { 0x320A, opcode::OP_Notify },
    { 0x320B, opcode::OP_Wait },
    { 0x320C, opcode::OP_Invalid },
    { 0x320D, opcode::OP_Invalid },
    { 0x320E, opcode::OP_Invalid },
    { 0x320F, opcode::OP_CastBool },
    { 0x3210, opcode::OP_Invalid },
    { 0x3211, opcode::OP_Invalid },
    { 0x3212, opcode::OP_ClearFieldVariable },
    { 0x3213, opcode::OP_EvalLocalVariableCached },
    { 0x3214, opcode::OP_Plus },
    { 0x3215, opcode::OP_Invalid },
    { 0x3216, opcode::OP_Invalid },
    { 0x3217, opcode::OP_Notify },
    { 0x3218, opcode::OP_BoolNot },
    { 0x3219, opcode::OP_Invalid },
    { 0x321A, opcode::OP_Invalid },
    { 0x321B, opcode::OP_Invalid },
    { 0x321C, opcode::OP_ScriptMethodThreadCall },
    { 0x321D, opcode::OP_EvalArrayRef },
    { 0x321E, opcode::OP_NextArrayKey },
    { 0x321F, opcode::OP_GetVector },
    { 0x3220, opcode::OP_GreaterThanOrEqualTo },
    { 0x3221, opcode::OP_Invalid },
    { 0x3222, opcode::OP_Invalid },
    { 0x3223, opcode::OP_EvalLocalVariableRefCached },
    { 0x3224, opcode::OP_Invalid },
    { 0x3225, opcode::OP_Invalid },
    { 0x3226, opcode::OP_Invalid },
    { 0x3227, opcode::OP_SafeCreateLocalVariables },
    { 0x3228, opcode::OP_DevblockBegin },
    { 0x3229, opcode::OP_Notify },
    { 0x322A, opcode::OP_EvalLocalVariableRefCached },
    { 0x322B, opcode::OP_GetIString },
    { 0x322C, opcode::OP_GetSelfObject },
    { 0x322D, opcode::OP_ScriptThreadCall },
    { 0x322E, opcode::OP_JumpOnFalse },
    { 0x322F, opcode::OP_Invalid },
    { 0x3230, opcode::OP_Invalid },
    { 0x3231, opcode::OP_Invalid },
    { 0x3232, opcode::OP_Invalid },
    { 0x3233, opcode::OP_Invalid },
    { 0x3234, opcode::OP_GetAnimObject },
    { 0x3235, opcode::OP_Invalid },
    { 0x3236, opcode::OP_Invalid },
    { 0x3237, opcode::OP_Invalid },
    { 0x3238, opcode::OP_Invalid },
    { 0x3239, opcode::OP_EndSwitch },
    { 0x323A, opcode::OP_DecTop },
    { 0x323B, opcode::OP_Inc },
    { 0x323C, opcode::OP_ShiftLeft },
    { 0x323D, opcode::OP_EvalArray },
    { 0x323E, opcode::OP_ScriptFunctionCallClass },
    { 0x323F, opcode::OP_FirstArrayKey },
    { 0x3240, opcode::OP_ShiftLeft },
    { 0x3241, opcode::OP_Bit_Xor },
    { 0x3242, opcode::OP_ShiftRight },
    { 0x3243, opcode::OP_SafeCreateLocalVariables },
    { 0x3244, opcode::OP_GetClasses },
    { 0x3245, opcode::OP_Invalid },
    { 0x3246, opcode::OP_IsDefined },
    { 0x3247, opcode::OP_CastBool },
    { 0x3248, opcode::OP_Invalid },
    { 0x3249, opcode::OP_Bit_Or },
    { 0x324A, opcode::OP_WaitTillMatch },
    { 0x324B, opcode::OP_EndSwitch },
    { 0x324C, opcode::OP_GetAnimObject },
    { 0x324D, opcode::OP_Bit_Or },
    { 0x324E, opcode::OP_GetNegUnsignedShort },
    { 0x324F, opcode::OP_JumpOnTrue },
    { 0x3250, opcode::OP_EvalFieldVariable },
    { 0x3251, opcode::OP_Invalid },
    { 0x3252, opcode::OP_Invalid },
    { 0x3253, opcode::OP_Invalid },
    { 0x3254, opcode::OP_Invalid },
    { 0x3255, opcode::OP_Invalid },
    { 0x3256, opcode::OP_Invalid },
    { 0x3257, opcode::OP_RealWait },
    { 0x3258, opcode::OP_Invalid },
    { 0x3259, opcode::OP_Invalid },
    { 0x325A, opcode::OP_Invalid },
    { 0x325B, opcode::OP_Invalid },
    { 0x325C, opcode::OP_Invalid },
    { 0x325D, opcode::OP_GetWorld },
    { 0x325E, opcode::OP_Invalid },
    { 0x325F, opcode::OP_NextArrayKey },
    { 0x3260, opcode::OP_EmptyArray },
    { 0x3261, opcode::OP_Invalid },
    { 0x3262, opcode::OP_SafeDecTop },
    { 0x3263, opcode::OP_GetAnimObject },
    { 0x3264, opcode::OP_JumpOnFalse },
    { 0x3265, opcode::OP_Invalid },
    { 0x3266, opcode::OP_New },
    { 0x3267, opcode::OP_GetWorldObject },
    { 0x3268, opcode::OP_Invalid },
    { 0x3269, opcode::OP_GreaterThanOrEqualTo },
    { 0x326A, opcode::OP_VectorConstant },
    { 0x326B, opcode::OP_ShiftLeft },
    { 0x326C, opcode::OP_Invalid },
    { 0x326D, opcode::OP_New },
    { 0x326E, opcode::OP_DecTop },
    { 0x326F, opcode::OP_EvalArray },
    { 0x3270, opcode::OP_Invalid },
    { 0x3271, opcode::OP_WaitTillMatch },
    { 0x3272, opcode::OP_GetHash },
    { 0x3273, opcode::OP_Invalid },
    { 0x3274, opcode::OP_ShiftLeft },
    { 0x3275, opcode::OP_ShiftRight },
    { 0x3276, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x3277, opcode::OP_Invalid },
    { 0x3278, opcode::OP_Invalid },
    { 0x3279, opcode::OP_GetSelfObject },
    { 0x327A, opcode::OP_Invalid },
    { 0x327B, opcode::OP_Invalid },
    { 0x327C, opcode::OP_SafeCreateLocalVariables },
    { 0x327D, opcode::OP_GetString },
    { 0x327E, opcode::OP_GetZero },
    { 0x327F, opcode::OP_GetFunction },
    { 0x3280, opcode::OP_WaitTillFrameEnd },
    { 0x3281, opcode::OP_Invalid },
    { 0x3282, opcode::OP_Invalid },
    { 0x3283, opcode::OP_SafeSetVariableFieldCached },
    { 0x3284, opcode::OP_Jump },
    { 0x3285, opcode::OP_BoolNot },
    { 0x3286, opcode::OP_Invalid },
    { 0x3287, opcode::OP_ClearFieldVariable },
    { 0x3288, opcode::OP_Bit_Xor },
    { 0x3289, opcode::OP_EvalFieldVariable },
    { 0x328A, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x328B, opcode::OP_Invalid },
    { 0x328C, opcode::OP_Multiply },
    { 0x328D, opcode::OP_ScriptFunctionCallPointer },
    { 0x328E, opcode::OP_Invalid },
    { 0x328F, opcode::OP_ScriptMethodCall },
    { 0x3290, opcode::OP_Invalid },
    { 0x3291, opcode::OP_GetByte },
    { 0x3292, opcode::OP_Divide },
    { 0x3293, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x3294, opcode::OP_Invalid },
    { 0x3295, opcode::OP_Invalid },
    { 0x3296, opcode::OP_Invalid },
    { 0x3297, opcode::OP_Bit_Or },
    { 0x3298, opcode::OP_Invalid },
    { 0x3299, opcode::OP_SafeSetVariableFieldCached },
    { 0x329A, opcode::OP_Invalid },
    { 0x329B, opcode::OP_ShiftLeft },
    { 0x329C, opcode::OP_GetWorld },
    { 0x329D, opcode::OP_ClearFieldVariable },
    { 0x329E, opcode::OP_SafeSetVariableFieldCached },
    { 0x329F, opcode::OP_Invalid },
    { 0x32A0, opcode::OP_Bit_Xor },
    { 0x32A1, opcode::OP_Invalid },
    { 0x32A2, opcode::OP_ScriptMethodCall },
    { 0x32A3, opcode::OP_DecTop },
    { 0x32A4, opcode::OP_ProfileStop },
    { 0x32A5, opcode::OP_Invalid },
    { 0x32A6, opcode::OP_DevblockBegin },
    { 0x32A7, opcode::OP_JumpOnFalseExpr },
    { 0x32A8, opcode::OP_Invalid },
    { 0x32A9, opcode::OP_Invalid },
    { 0x32AA, opcode::OP_GetUnsignedShort },
    { 0x32AB, opcode::OP_Vector },
    { 0x32AC, opcode::OP_Invalid },
    { 0x32AD, opcode::OP_Invalid },
    { 0x32AE, opcode::OP_ShiftLeft },
    { 0x32AF, opcode::OP_Invalid },
    { 0x32B0, opcode::OP_GetGame },
    { 0x32B1, opcode::OP_Invalid },
    { 0x32B2, opcode::OP_Invalid },
    { 0x32B3, opcode::OP_GetUnsignedShort },
    { 0x32B4, opcode::OP_GetGame },
    { 0x32B5, opcode::OP_SelfEvalFieldVariable },
    { 0x32B6, opcode::OP_SelfEvalFieldVariable },
    { 0x32B7, opcode::OP_Invalid },
    { 0x32B8, opcode::OP_Invalid },
    { 0x32B9, opcode::OP_Invalid },
    { 0x32BA, opcode::OP_GetZero },
    { 0x32BB, opcode::OP_FirstArrayKey },
    { 0x32BC, opcode::OP_ScriptThreadCallPointer },
    { 0x32BD, opcode::OP_GetAnimObject },
    { 0x32BE, opcode::OP_EvalFieldVariable },
    { 0x32BF, opcode::OP_Invalid },
    { 0x32C0, opcode::OP_Bit_And },
    { 0x32C1, opcode::OP_Jump },
    { 0x32C2, opcode::OP_GetAnimObject },
    { 0x32C3, opcode::OP_Invalid },
    { 0x32C4, opcode::OP_CastBool },
    { 0x32C5, opcode::OP_WaitTillMatch },
    { 0x32C6, opcode::OP_Invalid },
    { 0x32C7, opcode::OP_Invalid },
    { 0x32C8, opcode::OP_DevblockBegin },
    { 0x32C9, opcode::OP_Invalid },
    { 0x32CA, opcode::OP_Invalid },
    { 0x32CB, opcode::OP_Invalid },
    { 0x32CC, opcode::OP_Invalid },
    { 0x32CD, opcode::OP_Invalid },
    { 0x32CE, opcode::OP_Invalid },
    { 0x32CF, opcode::OP_ScriptFunctionCallPointer },
    { 0x32D0, opcode::OP_Invalid },
    { 0x32D1, opcode::OP_Invalid },
    { 0x32D2, opcode::OP_CastBool },
    { 0x32D3, opcode::OP_Invalid },
    { 0x32D4, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x32D5, opcode::OP_Invalid },
    { 0x32D6, opcode::OP_ShiftLeft },
    { 0x32D7, opcode::OP_GetUndefined },
    { 0x32D8, opcode::OP_SelfEvalFieldVariableRef },
    { 0x32D9, opcode::OP_Invalid },
    { 0x32DA, opcode::OP_Invalid },
    { 0x32DB, opcode::OP_EvalFieldVariableRef },
    { 0x32DC, opcode::OP_Switch },
    { 0x32DD, opcode::OP_ScriptMethodCall },
    { 0x32DE, opcode::OP_Invalid },
    { 0x32DF, opcode::OP_Invalid },
    { 0x32E0, opcode::OP_VectorScale },
    { 0x32E1, opcode::OP_CallBuiltinMethod },
    { 0x32E2, opcode::OP_Multiply },
    { 0x32E3, opcode::OP_ScriptMethodThreadCall },
    { 0x32E4, opcode::OP_Invalid },
    { 0x32E5, opcode::OP_Modulus },
    { 0x32E6, opcode::OP_WaitTill },
    { 0x32E7, opcode::OP_GetClasses },
    { 0x32E8, opcode::OP_Bit_Xor },
    { 0x32E9, opcode::OP_GetAPIFunction },
    { 0x32EA, opcode::OP_Invalid },
    { 0x32EB, opcode::OP_Invalid },
    { 0x32EC, opcode::OP_Invalid },
    { 0x32ED, opcode::OP_Wait },
    { 0x32EE, opcode::OP_GetUnsignedShort },
    { 0x32EF, opcode::OP_GetFunction },
    { 0x32F0, opcode::OP_GetFloat },
    { 0x32F1, opcode::OP_Invalid },
    { 0x32F2, opcode::OP_ScriptMethodThreadCall },
    { 0x32F3, opcode::OP_Invalid },
    { 0x32F4, opcode::OP_WaitTillMatch },
    { 0x32F5, opcode::OP_Invalid },
    { 0x32F6, opcode::OP_EvalFieldVariable },
    { 0x32F7, opcode::OP_Invalid },
    { 0x32F8, opcode::OP_Bit_Or },
    { 0x32F9, opcode::OP_Multiply },
    { 0x32FA, opcode::OP_ClearArray },
    { 0x32FB, opcode::OP_GetUintptr },
    { 0x32FC, opcode::OP_Invalid },
    { 0x32FD, opcode::OP_EvalArray },
    { 0x32FE, opcode::OP_Invalid },
    { 0x32FF, opcode::OP_EvalFieldVariable },
    { 0x3300, opcode::OP_ShiftRight },
    { 0x3301, opcode::OP_EvalLocalVariableRefCached },
    { 0x3302, opcode::OP_Invalid },
    { 0x3303, opcode::OP_Invalid },
    { 0x3304, opcode::OP_Jump },
    { 0x3305, opcode::OP_GetWorld },
    { 0x3306, opcode::OP_ProfileStart },
    { 0x3307, opcode::OP_Invalid },
    { 0x3308, opcode::OP_SafeCreateLocalVariables },
    { 0x3309, opcode::OP_GetByte },
    { 0x330A, opcode::OP_GetFloat },
    { 0x330B, opcode::OP_SelfEvalFieldVariable },
    { 0x330C, opcode::OP_Notify },
    { 0x330D, opcode::OP_Invalid },
    { 0x330E, opcode::OP_Invalid },
    { 0x330F, opcode::OP_GetClassesObject },
    { 0x3310, opcode::OP_Invalid },
    { 0x3311, opcode::OP_Invalid },
    { 0x3312, opcode::OP_LessThan },
    { 0x3313, opcode::OP_SuperNotEqual },
    { 0x3314, opcode::OP_Invalid },
    { 0x3315, opcode::OP_DecTop },
    { 0x3316, opcode::OP_Invalid },
    { 0x3317, opcode::OP_Bit_Xor },
    { 0x3318, opcode::OP_Invalid },
    { 0x3319, opcode::OP_GetFloat },
    { 0x331A, opcode::OP_Invalid },
    { 0x331B, opcode::OP_CastBool },
    { 0x331C, opcode::OP_Invalid },
    { 0x331D, opcode::OP_JumpOnFalseExpr },
    { 0x331E, opcode::OP_Invalid },
    { 0x331F, opcode::OP_GetAnim },
    { 0x3320, opcode::OP_ShiftRight },
    { 0x3321, opcode::OP_Invalid },
    { 0x3322, opcode::OP_GetWorldObject },
    { 0x3323, opcode::OP_Invalid },
    { 0x3324, opcode::OP_Invalid },
    { 0x3325, opcode::OP_Wait },
    { 0x3326, opcode::OP_Wait },
    { 0x3327, opcode::OP_ClearFieldVariable },
    { 0x3328, opcode::OP_EvalLocalVariableCached },
    { 0x3329, opcode::OP_Invalid },
    { 0x332A, opcode::OP_GetHash },
    { 0x332B, opcode::OP_NextArrayKey },
    { 0x332C, opcode::OP_Invalid },
    { 0x332D, opcode::OP_ClearFieldVariable },
    { 0x332E, opcode::OP_Invalid },
    { 0x332F, opcode::OP_Invalid },
    { 0x3330, opcode::OP_Invalid },
    { 0x3331, opcode::OP_GetUintptr },
    { 0x3332, opcode::OP_Invalid },
    { 0x3333, opcode::OP_GreaterThanOrEqualTo },
    { 0x3334, opcode::OP_Invalid },
    { 0x3335, opcode::OP_Invalid },
    { 0x3336, opcode::OP_Minus },
    { 0x3337, opcode::OP_GetHash },
    { 0x3338, opcode::OP_EndOn },
    { 0x3339, opcode::OP_Invalid },
    { 0x333A, opcode::OP_LevelEvalFieldVariableRef },
    { 0x333B, opcode::OP_Invalid },
    { 0x333C, opcode::OP_GetGameRef },
    { 0x333D, opcode::OP_CastFieldObject },
    { 0x333E, opcode::OP_Invalid },
    { 0x333F, opcode::OP_Invalid },
    { 0x3340, opcode::OP_ClearFieldVariable },
    { 0x3341, opcode::OP_EndOn },
    { 0x3342, opcode::OP_Invalid },
    { 0x3343, opcode::OP_Invalid },
    { 0x3344, opcode::OP_GetClasses },
    { 0x3345, opcode::OP_BoolComplement },
    { 0x3346, opcode::OP_GetFloat },
    { 0x3347, opcode::OP_GreaterThan },
    { 0x3348, opcode::OP_Invalid },
    { 0x3349, opcode::OP_ScriptFunctionCallPointer },
    { 0x334A, opcode::OP_Plus },
    { 0x334B, opcode::OP_JumpOnTrueExpr },
    { 0x334C, opcode::OP_Invalid },
    { 0x334D, opcode::OP_Invalid },
    { 0x334E, opcode::OP_Invalid },
    { 0x334F, opcode::OP_EvalLocalVariableCached },
    { 0x3350, opcode::OP_New },
    { 0x3351, opcode::OP_WaitTillMatch },
    { 0x3352, opcode::OP_SelfEvalFieldVariable },
    { 0x3353, opcode::OP_ScriptFunctionCallPointer },
    { 0x3354, opcode::OP_Invalid },
    { 0x3355, opcode::OP_Invalid },
    { 0x3356, opcode::OP_New },
    { 0x3357, opcode::OP_ScriptThreadCall },
    { 0x3358, opcode::OP_Invalid },
    { 0x3359, opcode::OP_New },
    { 0x335A, opcode::OP_Invalid },
    { 0x335B, opcode::OP_VectorConstant },
    { 0x335C, opcode::OP_SelfEvalFieldVariableRef },
    { 0x335D, opcode::OP_Invalid },
    { 0x335E, opcode::OP_Invalid },
    { 0x335F, opcode::OP_Invalid },
    { 0x3360, opcode::OP_SuperEqual },
    { 0x3361, opcode::OP_Invalid },
    { 0x3362, opcode::OP_Divide },
    { 0x3363, opcode::OP_Invalid },
    { 0x3364, opcode::OP_CastFieldObject },
    { 0x3365, opcode::OP_Multiply },
    { 0x3366, opcode::OP_Invalid },
    { 0x3367, opcode::OP_Invalid },
    { 0x3368, opcode::OP_GetString },
    { 0x3369, opcode::OP_EvalArray },
    { 0x336A, opcode::OP_JumpOnTrueExpr },
    { 0x336B, opcode::OP_SizeOf },
    { 0x336C, opcode::OP_Invalid },
    { 0x336D, opcode::OP_GetSelfObject },
    { 0x336E, opcode::OP_ScriptThreadCallClass },
    { 0x336F, opcode::OP_GetClasses },
    { 0x3370, opcode::OP_GetString },
    { 0x3371, opcode::OP_Invalid },
    { 0x3372, opcode::OP_SafeDecTop },
    { 0x3373, opcode::OP_SafeSetVariableFieldCached },
    { 0x3374, opcode::OP_GetAnimObject },
    { 0x3375, opcode::OP_ShiftRight },
    { 0x3376, opcode::OP_Invalid },
    { 0x3377, opcode::OP_GetUndefined },
    { 0x3378, opcode::OP_BoolComplement },
    { 0x3379, opcode::OP_WaitTillMatch },
    { 0x337A, opcode::OP_GetWorld },
    { 0x337B, opcode::OP_GreaterThan },
    { 0x337C, opcode::OP_RealWait },
    { 0x337D, opcode::OP_Invalid },
    { 0x337E, opcode::OP_Invalid },
    { 0x337F, opcode::OP_GetLevelObject },
    { 0x3380, opcode::OP_Invalid },
    { 0x3381, opcode::OP_Invalid },
    { 0x3382, opcode::OP_Multiply },
    { 0x3383, opcode::OP_Invalid },
    { 0x3384, opcode::OP_Invalid },
    { 0x3385, opcode::OP_Invalid },
    { 0x3386, opcode::OP_Invalid },
    { 0x3387, opcode::OP_Invalid },
    { 0x3388, opcode::OP_Invalid },
    { 0x3389, opcode::OP_Invalid },
    { 0x338A, opcode::OP_Invalid },
    { 0x338B, opcode::OP_ScriptMethodCall },
    { 0x338C, opcode::OP_GetLevelObject },
    { 0x338D, opcode::OP_Invalid },
    { 0x338E, opcode::OP_EvalArrayRef },
    { 0x338F, opcode::OP_Invalid },
    { 0x3390, opcode::OP_ClearArray },
    { 0x3391, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x3392, opcode::OP_EvalLocalVariableRefCached },
    { 0x3393, opcode::OP_GetSelfObject },
    { 0x3394, opcode::OP_Invalid },
    { 0x3395, opcode::OP_GetIString },
    { 0x3396, opcode::OP_ClearArray },
    { 0x3397, opcode::OP_Invalid },
    { 0x3398, opcode::OP_VectorScale },
    { 0x3399, opcode::OP_WaitTill },
    { 0x339A, opcode::OP_SafeCreateLocalVariables },
    { 0x339B, opcode::OP_Invalid },
    { 0x339C, opcode::OP_Invalid },
    { 0x339D, opcode::OP_Dec },
    { 0x339E, opcode::OP_EndSwitch },
    { 0x339F, opcode::OP_Wait },
    { 0x33A0, opcode::OP_Invalid },
    { 0x33A1, opcode::OP_Invalid },
    { 0x33A2, opcode::OP_ScriptThreadCallPointer },
    { 0x33A3, opcode::OP_Invalid },
    { 0x33A4, opcode::OP_GetAnimation },
    { 0x33A5, opcode::OP_GetLevel },
    { 0x33A6, opcode::OP_Invalid },
    { 0x33A7, opcode::OP_ShiftLeft },
    { 0x33A8, opcode::OP_Invalid },
    { 0x33A9, opcode::OP_GetClassesObject },
    { 0x33AA, opcode::OP_Wait },
    { 0x33AB, opcode::OP_Invalid },
    { 0x33AC, opcode::OP_Equal },
    { 0x33AD, opcode::OP_GetLevel },
    { 0x33AE, opcode::OP_Invalid },
    { 0x33AF, opcode::OP_VectorConstant },
    { 0x33B0, opcode::OP_Invalid },
    { 0x33B1, opcode::OP_Modulus },
    { 0x33B2, opcode::OP_GetByte },
    { 0x33B3, opcode::OP_GetNegUnsignedShort },
    { 0x33B4, opcode::OP_SuperEqual },
    { 0x33B5, opcode::OP_Invalid },
    { 0x33B6, opcode::OP_Invalid },
    { 0x33B7, opcode::OP_Invalid },
    { 0x33B8, opcode::OP_Invalid },
    { 0x33B9, opcode::OP_Invalid },
    { 0x33BA, opcode::OP_Invalid },
    { 0x33BB, opcode::OP_Invalid },
    { 0x33BC, opcode::OP_Invalid },
    { 0x33BD, opcode::OP_WaitTillMatch },
    { 0x33BE, opcode::OP_Invalid },
    { 0x33BF, opcode::OP_GetAPIFunction },
    { 0x33C0, opcode::OP_Vector },
    { 0x33C1, opcode::OP_Invalid },
    { 0x33C2, opcode::OP_Invalid },
    { 0x33C3, opcode::OP_Invalid },
    { 0x33C4, opcode::OP_Invalid },
    { 0x33C5, opcode::OP_Switch },
    { 0x33C6, opcode::OP_ScriptFunctionCallPointer },
    { 0x33C7, opcode::OP_RealWait },
    { 0x33C8, opcode::OP_ScriptMethodCallPointer },
    { 0x33C9, opcode::OP_Invalid },
    { 0x33CA, opcode::OP_LessThan },
    { 0x33CB, opcode::OP_Invalid },
    { 0x33CC, opcode::OP_Notify },
    { 0x33CD, opcode::OP_GetHash },
    { 0x33CE, opcode::OP_Invalid },
    { 0x33CF, opcode::OP_LevelEvalFieldVariable },
    { 0x33D0, opcode::OP_Invalid },
    { 0x33D1, opcode::OP_GetIString },
    { 0x33D2, opcode::OP_Invalid },
    { 0x33D3, opcode::OP_Invalid },
    { 0x33D4, opcode::OP_JumpOnTrue },
    { 0x33D5, opcode::OP_Invalid },
    { 0x33D6, opcode::OP_ProfileStart },
    { 0x33D7, opcode::OP_Invalid },
    { 0x33D8, opcode::OP_Invalid },
    { 0x33D9, opcode::OP_GreaterThanOrEqualTo },
    { 0x33DA, opcode::OP_DevblockBegin },
    { 0x33DB, opcode::OP_GetUndefined },
    { 0x33DC, opcode::OP_Invalid },
    { 0x33DD, opcode::OP_Invalid },
    { 0x33DE, opcode::OP_EvalArray },
    { 0x33DF, opcode::OP_Invalid },
    { 0x33E0, opcode::OP_Invalid },
    { 0x33E1, opcode::OP_GetString },
    { 0x33E2, opcode::OP_GetClassesObject },
    { 0x33E3, opcode::OP_GetAnim },
    { 0x33E4, opcode::OP_Invalid },
    { 0x33E5, opcode::OP_SafeCreateLocalVariables },
    { 0x33E6, opcode::OP_Invalid },
    { 0x33E7, opcode::OP_Invalid },
    { 0x33E8, opcode::OP_New },
    { 0x33E9, opcode::OP_GetFloat },
    { 0x33EA, opcode::OP_Invalid },
    { 0x33EB, opcode::OP_GetSelf },
    { 0x33EC, opcode::OP_ScriptFunctionCallPointer },
    { 0x33ED, opcode::OP_Invalid },
    { 0x33EE, opcode::OP_Invalid },
    { 0x33EF, opcode::OP_GetInteger },
    { 0x33F0, opcode::OP_Invalid },
    { 0x33F1, opcode::OP_Invalid },
    { 0x33F2, opcode::OP_ClearFieldVariable },
    { 0x33F3, opcode::OP_Invalid },
    { 0x33F4, opcode::OP_Invalid },
    { 0x33F5, opcode::OP_LessThan },
    { 0x33F6, opcode::OP_GetFloat },
    { 0x33F7, opcode::OP_GetWorld },
    { 0x33F8, opcode::OP_ScriptThreadCallClass },
    { 0x33F9, opcode::OP_New },
    { 0x33FA, opcode::OP_Invalid },
    { 0x33FB, opcode::OP_ClearArray },
    { 0x33FC, opcode::OP_ScriptMethodCall },
    { 0x33FD, opcode::OP_Invalid },
    { 0x33FE, opcode::OP_JumpOnFalseExpr },
    { 0x33FF, opcode::OP_GetFunction },
    { 0x3400, opcode::OP_BoolComplement },
    { 0x3401, opcode::OP_Invalid },
    { 0x3402, opcode::OP_SafeDecTop },
    { 0x3403, opcode::OP_WaitTill },
    { 0x3404, opcode::OP_Invalid },
    { 0x3405, opcode::OP_Invalid },
    { 0x3406, opcode::OP_EndOn },
    { 0x3407, opcode::OP_RealWait },
    { 0x3408, opcode::OP_EvalFieldVariable },
    { 0x3409, opcode::OP_JumpOnFalseExpr },
    { 0x340A, opcode::OP_ClearFieldVariable },
    { 0x340B, opcode::OP_EndOn },
    { 0x340C, opcode::OP_IsDefined },
    { 0x340D, opcode::OP_ScriptMethodCallPointer },
    { 0x340E, opcode::OP_Invalid },
    { 0x340F, opcode::OP_Bit_And },
    { 0x3410, opcode::OP_Invalid },
    { 0x3411, opcode::OP_GetNegUnsignedShort },
    { 0x3412, opcode::OP_CastBool },
    { 0x3413, opcode::OP_Invalid },
    { 0x3414, opcode::OP_Invalid },
    { 0x3415, opcode::OP_Invalid },
    { 0x3416, opcode::OP_Invalid },
    { 0x3417, opcode::OP_Invalid },
    { 0x3418, opcode::OP_ProfileStart },
    { 0x3419, opcode::OP_Invalid },
    { 0x341A, opcode::OP_Invalid },
    { 0x341B, opcode::OP_Plus },
    { 0x341C, opcode::OP_GetZero },
    { 0x341D, opcode::OP_Invalid },
    { 0x341E, opcode::OP_GreaterThanOrEqualTo },
    { 0x341F, opcode::OP_EndSwitch },
    { 0x3420, opcode::OP_Invalid },
    { 0x3421, opcode::OP_Invalid },
    { 0x3422, opcode::OP_Invalid },
    { 0x3423, opcode::OP_GetHash },
    { 0x3424, opcode::OP_Invalid },
    { 0x3425, opcode::OP_Invalid },
    { 0x3426, opcode::OP_IsDefined },
    { 0x3427, opcode::OP_LevelEvalFieldVariableRef },
    { 0x3428, opcode::OP_Invalid },
    { 0x3429, opcode::OP_EvalFieldVariableRef },
    { 0x342A, opcode::OP_GetAnimObject },
    { 0x342B, opcode::OP_Invalid },
    { 0x342C, opcode::OP_JumpOnFalse },
    { 0x342D, opcode::OP_Invalid },
    { 0x342E, opcode::OP_JumpOnTrueExpr },
    { 0x342F, opcode::OP_WaitTillMatch },
    { 0x3430, opcode::OP_ScriptMethodCallPointer },
    { 0x3431, opcode::OP_Invalid },
    { 0x3432, opcode::OP_LevelEvalFieldVariable },
    { 0x3433, opcode::OP_EvalArray },
    { 0x3434, opcode::OP_GetAnimation },
    { 0x3435, opcode::OP_LessThan },
    { 0x3436, opcode::OP_GreaterThan },
    { 0x3437, opcode::OP_Invalid },
    { 0x3438, opcode::OP_EndSwitch },
    { 0x3439, opcode::OP_SuperNotEqual },
    { 0x343A, opcode::OP_WaitTillMatch },
    { 0x343B, opcode::OP_ShiftRight },
    { 0x343C, opcode::OP_NotEqual },
    { 0x343D, opcode::OP_EvalFieldVariable },
    { 0x343E, opcode::OP_GetVector },
    { 0x343F, opcode::OP_ScriptMethodThreadCall },
    { 0x3440, opcode::OP_JumpOnTrue },
    { 0x3441, opcode::OP_GetString },
    { 0x3442, opcode::OP_Invalid },
    { 0x3443, opcode::OP_Invalid },
    { 0x3444, opcode::OP_LessThan },
    { 0x3445, opcode::OP_Invalid },
    { 0x3446, opcode::OP_GetAnimObject },
    { 0x3447, opcode::OP_EvalFieldVariable },
    { 0x3448, opcode::OP_Invalid },
    { 0x3449, opcode::OP_ScriptFunctionCall },
    { 0x344A, opcode::OP_Invalid },
    { 0x344B, opcode::OP_GetGame },
    { 0x344C, opcode::OP_Invalid },
    { 0x344D, opcode::OP_Invalid },
    { 0x344E, opcode::OP_Invalid },
    { 0x344F, opcode::OP_Jump },
    { 0x3450, opcode::OP_Invalid },
    { 0x3451, opcode::OP_Invalid },
    { 0x3452, opcode::OP_Invalid },
    { 0x3453, opcode::OP_Invalid },
    { 0x3454, opcode::OP_Invalid },
    { 0x3455, opcode::OP_Invalid },
    { 0x3456, opcode::OP_GetIString },
    { 0x3457, opcode::OP_Invalid },
    { 0x3458, opcode::OP_GetAPIFunction },
    { 0x3459, opcode::OP_NotEqual },
    { 0x345A, opcode::OP_ScriptMethodCallPointer },
    { 0x345B, opcode::OP_ScriptMethodCall },
    { 0x345C, opcode::OP_SizeOf },
    { 0x345D, opcode::OP_Invalid },
    { 0x345E, opcode::OP_Dec },
    { 0x345F, opcode::OP_Invalid },
    { 0x3460, opcode::OP_CastFieldObject },
    { 0x3461, opcode::OP_GetByte },
    { 0x3462, opcode::OP_DevblockBegin },
    { 0x3463, opcode::OP_VectorConstant },
    { 0x3464, opcode::OP_Vector },
    { 0x3465, opcode::OP_Invalid },
    { 0x3466, opcode::OP_ShiftLeft },
    { 0x3467, opcode::OP_Invalid },
    { 0x3468, opcode::OP_Invalid },
    { 0x3469, opcode::OP_Invalid },
    { 0x346A, opcode::OP_Invalid },
    { 0x346B, opcode::OP_EvalLocalVariableRefCached },
    { 0x346C, opcode::OP_GetVector },
    { 0x346D, opcode::OP_Invalid },
    { 0x346E, opcode::OP_EvalArrayRef },
    { 0x346F, opcode::OP_GetNegUnsignedShort },
    { 0x3470, opcode::OP_CallBuiltinMethod },
    { 0x3471, opcode::OP_Switch },
    { 0x3472, opcode::OP_Wait },
    { 0x3473, opcode::OP_VectorScale },
    { 0x3474, opcode::OP_Plus },
    { 0x3475, opcode::OP_VectorConstant },
    { 0x3476, opcode::OP_Invalid },
    { 0x3477, opcode::OP_GetAnim },
    { 0x3478, opcode::OP_SuperEqual },
    { 0x3479, opcode::OP_Inc },
    { 0x347A, opcode::OP_GetClassesObject },
    { 0x347B, opcode::OP_GetClasses },
    { 0x347C, opcode::OP_GetUintptr },
    { 0x347D, opcode::OP_BoolNot },
    { 0x347E, opcode::OP_GetWorld },
    { 0x347F, opcode::OP_Invalid },
    { 0x3480, opcode::OP_FirstArrayKey },
    { 0x3481, opcode::OP_GetAPIFunction },
    { 0x3482, opcode::OP_Invalid },
    { 0x3483, opcode::OP_Invalid },
    { 0x3484, opcode::OP_Invalid },
    { 0x3485, opcode::OP_Invalid },
    { 0x3486, opcode::OP_Invalid },
    { 0x3487, opcode::OP_NextArrayKey },
    { 0x3488, opcode::OP_GetByte },
    { 0x3489, opcode::OP_LessThan },
    { 0x348A, opcode::OP_Bit_Xor },
    { 0x348B, opcode::OP_GetTime },
    { 0x348C, opcode::OP_Bit_Or },
    { 0x348D, opcode::OP_SafeDecTop },
    { 0x348E, opcode::OP_Invalid },
    { 0x348F, opcode::OP_EvalFieldVariableRef },
    { 0x3490, opcode::OP_GetByte },
    { 0x3491, opcode::OP_New },
    { 0x3492, opcode::OP_NotEqual },
    { 0x3493, opcode::OP_EndSwitch },
    { 0x3494, opcode::OP_Plus },
    { 0x3495, opcode::OP_SuperNotEqual },
    { 0x3496, opcode::OP_GetSelfObject },
    { 0x3497, opcode::OP_GetTime },
    { 0x3498, opcode::OP_Invalid },
    { 0x3499, opcode::OP_Switch },
    { 0x349A, opcode::OP_ScriptFunctionCallPointer },
    { 0x349B, opcode::OP_ScriptMethodCallPointer },
    { 0x349C, opcode::OP_ScriptThreadCallPointer },
    { 0x349D, opcode::OP_Invalid },
    { 0x349E, opcode::OP_JumpOnFalse },
    { 0x349F, opcode::OP_Invalid },
    { 0x34A0, opcode::OP_GetAPIFunction },
    { 0x34A1, opcode::OP_DecTop },
    { 0x34A2, opcode::OP_GetWorld },
    { 0x34A3, opcode::OP_Invalid },
    { 0x34A4, opcode::OP_SafeDecTop },
    { 0x34A5, opcode::OP_LevelEvalFieldVariable },
    { 0x34A6, opcode::OP_EvalArrayRef },
    { 0x34A7, opcode::OP_Equal },
    { 0x34A8, opcode::OP_NotEqual },
    { 0x34A9, opcode::OP_Invalid },
    { 0x34AA, opcode::OP_ScriptFunctionCallClass },
    { 0x34AB, opcode::OP_GetVector },
    { 0x34AC, opcode::OP_Invalid },
    { 0x34AD, opcode::OP_GetHash },
    { 0x34AE, opcode::OP_GetFunction },
    { 0x34AF, opcode::OP_GetAnim },
    { 0x34B0, opcode::OP_Modulus },
    { 0x34B1, opcode::OP_VectorScale },
    { 0x34B2, opcode::OP_EvalLocalVariableRefCached },
    { 0x34B3, opcode::OP_Invalid },
    { 0x34B4, opcode::OP_EndSwitch },
    { 0x34B5, opcode::OP_LessThan },
    { 0x34B6, opcode::OP_Invalid },
    { 0x34B7, opcode::OP_Invalid },
    { 0x34B8, opcode::OP_SuperEqual },
    { 0x34B9, opcode::OP_Invalid },
    { 0x34BA, opcode::OP_GetZero },
    { 0x34BB, opcode::OP_Invalid },
    { 0x34BC, opcode::OP_GetAnim },
    { 0x34BD, opcode::OP_ProfileStart },
    { 0x34BE, opcode::OP_SizeOf },
    { 0x34BF, opcode::OP_Invalid },
    { 0x34C0, opcode::OP_CallBuiltinMethod },
    { 0x34C1, opcode::OP_ShiftLeft },
    { 0x34C2, opcode::OP_Divide },
    { 0x34C3, opcode::OP_VectorScale },
    { 0x34C4, opcode::OP_Invalid },
    { 0x34C5, opcode::OP_New },
    { 0x34C6, opcode::OP_EvalArray },
    { 0x34C7, opcode::OP_Invalid },
    { 0x34C8, opcode::OP_Invalid },
    { 0x34C9, opcode::OP_Invalid },
    { 0x34CA, opcode::OP_Invalid },
    { 0x34CB, opcode::OP_Invalid },
    { 0x34CC, opcode::OP_Invalid },
    { 0x34CD, opcode::OP_Invalid },
    { 0x34CE, opcode::OP_GetGame },
    { 0x34CF, opcode::OP_Invalid },
    { 0x34D0, opcode::OP_ProfileStart },
    { 0x34D1, opcode::OP_Invalid },
    { 0x34D2, opcode::OP_WaitTill },
    { 0x34D3, opcode::OP_JumpOnTrueExpr },
    { 0x34D4, opcode::OP_Invalid },
    { 0x34D5, opcode::OP_Invalid },
    { 0x34D6, opcode::OP_JumpOnFalseExpr },
    { 0x34D7, opcode::OP_GetUintptr },
    { 0x34D8, opcode::OP_SizeOf },
    { 0x34D9, opcode::OP_SuperEqual },
    { 0x34DA, opcode::OP_GetNegUnsignedShort },
    { 0x34DB, opcode::OP_ScriptThreadCallClass },
    { 0x34DC, opcode::OP_GetGame },
    { 0x34DD, opcode::OP_Invalid },
    { 0x34DE, opcode::OP_Invalid },
    { 0x34DF, opcode::OP_Invalid },
    { 0x34E0, opcode::OP_Invalid },
    { 0x34E1, opcode::OP_Invalid },
    { 0x34E2, opcode::OP_Jump },
    { 0x34E3, opcode::OP_RealWait },
    { 0x34E4, opcode::OP_ScriptThreadCall },
    { 0x34E5, opcode::OP_Invalid },
    { 0x34E6, opcode::OP_Invalid },
    { 0x34E7, opcode::OP_EmptyArray },
    { 0x34E8, opcode::OP_Invalid },
    { 0x34E9, opcode::OP_Invalid },
    { 0x34EA, opcode::OP_GetNegByte },
    { 0x34EB, opcode::OP_GetString },
    { 0x34EC, opcode::OP_ShiftLeft },
    { 0x34ED, opcode::OP_WaitTill },
    { 0x34EE, opcode::OP_GetLevel },
    { 0x34EF, opcode::OP_Invalid },
    { 0x34F0, opcode::OP_Invalid },
    { 0x34F1, opcode::OP_Invalid },
    { 0x34F2, opcode::OP_Invalid },
    { 0x34F3, opcode::OP_GreaterThan },
    { 0x34F4, opcode::OP_Invalid },
    { 0x34F5, opcode::OP_Invalid },
    { 0x34F6, opcode::OP_SelfEvalFieldVariableRef },
    { 0x34F7, opcode::OP_Invalid },
    { 0x34F8, opcode::OP_ClearArray },
    { 0x34F9, opcode::OP_GetNegByte },
    { 0x34FA, opcode::OP_Invalid },
    { 0x34FB, opcode::OP_IsDefined },
    { 0x34FC, opcode::OP_Invalid },
    { 0x34FD, opcode::OP_Equal },
    { 0x34FE, opcode::OP_Invalid },
    { 0x34FF, opcode::OP_ShiftLeft },
    { 0x3500, opcode::OP_Invalid },
    { 0x3501, opcode::OP_GetString },
    { 0x3502, opcode::OP_GetVector },
    { 0x3503, opcode::OP_SuperEqual },
    { 0x3504, opcode::OP_Equal },
    { 0x3505, opcode::OP_BoolComplement },
    { 0x3506, opcode::OP_Invalid },
    { 0x3507, opcode::OP_Invalid },
    { 0x3508, opcode::OP_EvalArrayRef },
    { 0x3509, opcode::OP_Invalid },
    { 0x350A, opcode::OP_GetGame },
    { 0x350B, opcode::OP_Invalid },
    { 0x350C, opcode::OP_Switch },
    { 0x350D, opcode::OP_GetAnimObject },
    { 0x350E, opcode::OP_Invalid },
    { 0x350F, opcode::OP_Invalid },
    { 0x3510, opcode::OP_SelfEvalFieldVariable },
    { 0x3511, opcode::OP_GetGameRef },
    { 0x3512, opcode::OP_ShiftLeft },
    { 0x3513, opcode::OP_SuperEqual },
    { 0x3514, opcode::OP_DevblockBegin },
    { 0x3515, opcode::OP_LessThan },
    { 0x3516, opcode::OP_DecTop },
    { 0x3517, opcode::OP_Invalid },
    { 0x3518, opcode::OP_Bit_And },
    { 0x3519, opcode::OP_SizeOf },
    { 0x351A, opcode::OP_NotEqual },
    { 0x351B, opcode::OP_DevblockBegin },
    { 0x351C, opcode::OP_Wait },
    { 0x351D, opcode::OP_Plus },
    { 0x351E, opcode::OP_Invalid },
    { 0x351F, opcode::OP_SafeSetVariableFieldCached },
    { 0x3520, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x3521, opcode::OP_GetGame },
    { 0x3522, opcode::OP_GetFloat },
    { 0x3523, opcode::OP_WaitTill },
    { 0x3524, opcode::OP_Invalid },
    { 0x3525, opcode::OP_Invalid },
    { 0x3526, opcode::OP_ScriptMethodThreadCall },
    { 0x3527, opcode::OP_GetByte },
    { 0x3528, opcode::OP_Divide },
    { 0x3529, opcode::OP_Switch },
    { 0x352A, opcode::OP_Invalid },
    { 0x352B, opcode::OP_Bit_Xor },
    { 0x352C, opcode::OP_Invalid },
    { 0x352D, opcode::OP_EndSwitch },
    { 0x352E, opcode::OP_LessThanOrEqualTo },
    { 0x352F, opcode::OP_GetUintptr },
    { 0x3530, opcode::OP_Invalid },
    { 0x3531, opcode::OP_Bit_Or },
    { 0x3532, opcode::OP_JumpOnTrueExpr },
    { 0x3533, opcode::OP_Invalid },
    { 0x3534, opcode::OP_New },
    { 0x3535, opcode::OP_SelfEvalFieldVariableRef },
    { 0x3536, opcode::OP_Bit_And },
    { 0x3537, opcode::OP_Invalid },
    { 0x3538, opcode::OP_Invalid },
    { 0x3539, opcode::OP_Invalid },
    { 0x353A, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x353B, opcode::OP_Jump },
    { 0x353C, opcode::OP_GetTime },
    { 0x353D, opcode::OP_Notify },
    { 0x353E, opcode::OP_GetWorldObject },
    { 0x353F, opcode::OP_Invalid },
    { 0x3540, opcode::OP_Inc },
    { 0x3541, opcode::OP_Invalid },
    { 0x3542, opcode::OP_EvalFieldVariable },
    { 0x3543, opcode::OP_WaitTillMatch },
    { 0x3544, opcode::OP_Invalid },
    { 0x3545, opcode::OP_Inc },
    { 0x3546, opcode::OP_Invalid },
    { 0x3547, opcode::OP_SelfEvalFieldVariable },
    { 0x3548, opcode::OP_JumpOnTrueExpr },
    { 0x3549, opcode::OP_Invalid },
    { 0x354A, opcode::OP_SizeOf },
    { 0x354B, opcode::OP_ScriptFunctionCallPointer },
    { 0x354C, opcode::OP_Invalid },
    { 0x354D, opcode::OP_Invalid },
    { 0x354E, opcode::OP_EvalFieldVariableRef },
    { 0x354F, opcode::OP_LevelEvalFieldVariable },
    { 0x3550, opcode::OP_EvalArray },
    { 0x3551, opcode::OP_EvalArrayRef },
    { 0x3552, opcode::OP_JumpOnTrue },
    { 0x3553, opcode::OP_SizeOf },
    { 0x3554, opcode::OP_SafeSetVariableFieldCached },
    { 0x3555, opcode::OP_Invalid },
    { 0x3556, opcode::OP_Invalid },
    { 0x3557, opcode::OP_Invalid },
    { 0x3558, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x3559, opcode::OP_GetUintptr },
    { 0x355A, opcode::OP_Invalid },
    { 0x355B, opcode::OP_Invalid },
    { 0x355C, opcode::OP_Invalid },
    { 0x355D, opcode::OP_Invalid },
    { 0x355E, opcode::OP_SelfEvalFieldVariable },
    { 0x355F, opcode::OP_Invalid },
    { 0x3560, opcode::OP_GetUnsignedShort },
    { 0x3561, opcode::OP_Invalid },
    { 0x3562, opcode::OP_ShiftLeft },
    { 0x3563, opcode::OP_LessThanOrEqualTo },
    { 0x3564, opcode::OP_Invalid },
    { 0x3565, opcode::OP_Invalid },
    { 0x3566, opcode::OP_SafeSetVariableFieldCached },
    { 0x3567, opcode::OP_Invalid },
    { 0x3568, opcode::OP_GetUintptr },
    { 0x3569, opcode::OP_GetHash },
    { 0x356A, opcode::OP_ScriptThreadCall },
    { 0x356B, opcode::OP_Invalid },
    { 0x356C, opcode::OP_GetLevel },
    { 0x356D, opcode::OP_DevblockBegin },
    { 0x356E, opcode::OP_EvalArray },
    { 0x356F, opcode::OP_Wait },
    { 0x3570, opcode::OP_Invalid },
    { 0x3571, opcode::OP_Invalid },
    { 0x3572, opcode::OP_GetSelfObject },
    { 0x3573, opcode::OP_Multiply },
    { 0x3574, opcode::OP_SafeDecTop },
    { 0x3575, opcode::OP_Invalid },
    { 0x3576, opcode::OP_ShiftLeft },
    { 0x3577, opcode::OP_GetGameRef },
    { 0x3578, opcode::OP_Invalid },
    { 0x3579, opcode::OP_ScriptThreadCallClass },
    { 0x357A, opcode::OP_EndSwitch },
    { 0x357B, opcode::OP_Invalid },
    { 0x357C, opcode::OP_ScriptThreadCallPointer },
    { 0x357D, opcode::OP_CallBuiltinMethod },
    { 0x357E, opcode::OP_Invalid },
    { 0x357F, opcode::OP_EvalFieldVariable },
    { 0x3580, opcode::OP_EvalLocalVariableRefCached },
    { 0x3581, opcode::OP_EvalFieldVariableRef },
    { 0x3582, opcode::OP_Invalid },
    { 0x3583, opcode::OP_SetVariableField },
    { 0x3584, opcode::OP_Invalid },
    { 0x3585, opcode::OP_LevelEvalFieldVariable },
    { 0x3586, opcode::OP_GetIString },
    { 0x3587, opcode::OP_GreaterThan },
    { 0x3588, opcode::OP_Invalid },
    { 0x3589, opcode::OP_Invalid },
    { 0x358A, opcode::OP_Invalid },
    { 0x358B, opcode::OP_ShiftLeft },
    { 0x358C, opcode::OP_NotEqual },
    { 0x358D, opcode::OP_SuperEqual },
    { 0x358E, opcode::OP_Invalid },
    { 0x358F, opcode::OP_ShiftLeft },
    { 0x3590, opcode::OP_BoolComplement },
    { 0x3591, opcode::OP_ScriptMethodThreadCall },
    { 0x3592, opcode::OP_Invalid },
    { 0x3593, opcode::OP_SelfEvalFieldVariableRef },
    { 0x3594, opcode::OP_GetAPIFunction },
    { 0x3595, opcode::OP_GetWorld },
    { 0x3596, opcode::OP_Jump },
    { 0x3597, opcode::OP_Invalid },
    { 0x3598, opcode::OP_Invalid },
    { 0x3599, opcode::OP_Invalid },
    { 0x359A, opcode::OP_SafeDecTop },
    { 0x359B, opcode::OP_GetNegUnsignedShort },
    { 0x359C, opcode::OP_VectorScale },
    { 0x359D, opcode::OP_Invalid },
    { 0x359E, opcode::OP_GetWorldObject },
    { 0x359F, opcode::OP_EvalLocalVariableCached },
    { 0x35A0, opcode::OP_Invalid },
    { 0x35A1, opcode::OP_Inc },
    { 0x35A2, opcode::OP_ClearArray },
    { 0x35A3, opcode::OP_Modulus },
    { 0x35A4, opcode::OP_Bit_Or },
    { 0x35A5, opcode::OP_GreaterThan },
    { 0x35A6, opcode::OP_Modulus },
    { 0x35A7, opcode::OP_Invalid },
    { 0x35A8, opcode::OP_GetUintptr },
    { 0x35A9, opcode::OP_GetInteger },
    { 0x35AA, opcode::OP_CastBool },
    { 0x35AB, opcode::OP_ScriptMethodCallPointer },
    { 0x35AC, opcode::OP_ScriptMethodThreadCall },
    { 0x35AD, opcode::OP_GetInteger },
    { 0x35AE, opcode::OP_Invalid },
    { 0x35AF, opcode::OP_RealWait },
    { 0x35B0, opcode::OP_Invalid },
    { 0x35B1, opcode::OP_JumpOnFalseExpr },
    { 0x35B2, opcode::OP_ShiftLeft },
    { 0x35B3, opcode::OP_RealWait },
    { 0x35B4, opcode::OP_Divide },
    { 0x35B5, opcode::OP_Invalid },
    { 0x35B6, opcode::OP_New },
    { 0x35B7, opcode::OP_GetFunction },
    { 0x35B8, opcode::OP_Invalid },
    { 0x35B9, opcode::OP_GetAnim },
    { 0x35BA, opcode::OP_Invalid },
    { 0x35BB, opcode::OP_GetWorldObject },
    { 0x35BC, opcode::OP_Invalid },
    { 0x35BD, opcode::OP_ScriptFunctionCallClass },
    { 0x35BE, opcode::OP_GreaterThanOrEqualTo },
    { 0x35BF, opcode::OP_EvalArrayRef },
    { 0x35C0, opcode::OP_Invalid },
    { 0x35C1, opcode::OP_Minus },
    { 0x35C2, opcode::OP_GetAnimation },
    { 0x35C3, opcode::OP_GetUintptr },
    { 0x35C4, opcode::OP_Invalid },
    { 0x35C5, opcode::OP_CastBool },
    { 0x35C6, opcode::OP_ClearFieldVariable },
    { 0x35C7, opcode::OP_Invalid },
    { 0x35C8, opcode::OP_GetWorld },
    { 0x35C9, opcode::OP_GetFloat },
    { 0x35CA, opcode::OP_Invalid },
    { 0x35CB, opcode::OP_GetNegByte },
    { 0x35CC, opcode::OP_NextArrayKey },
    { 0x35CD, opcode::OP_SelfEvalFieldVariable },
    { 0x35CE, opcode::OP_Invalid },
    { 0x35CF, opcode::OP_RealWait },
    { 0x35D0, opcode::OP_Invalid },
    { 0x35D1, opcode::OP_Invalid },
    { 0x35D2, opcode::OP_RealWait },
    { 0x35D3, opcode::OP_LessThanOrEqualTo },
    { 0x35D4, opcode::OP_Invalid },
    { 0x35D5, opcode::OP_Invalid },
    { 0x35D6, opcode::OP_Invalid },
    { 0x35D7, opcode::OP_Invalid },
    { 0x35D8, opcode::OP_Multiply },
    { 0x35D9, opcode::OP_Invalid },
    { 0x35DA, opcode::OP_GetUnsignedShort },
    { 0x35DB, opcode::OP_SizeOf },
    { 0x35DC, opcode::OP_SelfEvalFieldVariable },
    { 0x35DD, opcode::OP_CallBuiltinMethod },
    { 0x35DE, opcode::OP_GetVector },
    { 0x35DF, opcode::OP_Invalid },
    { 0x35E0, opcode::OP_JumpOnFalseExpr },
    { 0x35E1, opcode::OP_GetAnimObject },
    { 0x35E2, opcode::OP_Invalid },
    { 0x35E3, opcode::OP_VectorConstant },
    { 0x35E4, opcode::OP_GetLevel },
    { 0x35E5, opcode::OP_Invalid },
    { 0x35E6, opcode::OP_Invalid },
    { 0x35E7, opcode::OP_NextArrayKey },
    { 0x35E8, opcode::OP_Invalid },
    { 0x35E9, opcode::OP_SizeOf },
    { 0x35EA, opcode::OP_JumpOnFalseExpr },
    { 0x35EB, opcode::OP_Invalid },
    { 0x35EC, opcode::OP_Invalid },
    { 0x35ED, opcode::OP_GetGameRef },
    { 0x35EE, opcode::OP_Invalid },
    { 0x35EF, opcode::OP_SuperNotEqual },
    { 0x35F0, opcode::OP_ShiftLeft },
    { 0x35F1, opcode::OP_Multiply },
    { 0x35F2, opcode::OP_Invalid },
    { 0x35F3, opcode::OP_NextArrayKey },
    { 0x35F4, opcode::OP_WaitTill },
    { 0x35F5, opcode::OP_NextArrayKey },
    { 0x35F6, opcode::OP_DevblockBegin },
    { 0x35F7, opcode::OP_ScriptFunctionCallClass },
    { 0x35F8, opcode::OP_GetIString },
    { 0x35F9, opcode::OP_ScriptMethodThreadCall },
    { 0x35FA, opcode::OP_GetTime },
    { 0x35FB, opcode::OP_SuperNotEqual },
    { 0x35FC, opcode::OP_Invalid },
    { 0x35FD, opcode::OP_GetFunction },
    { 0x35FE, opcode::OP_WaitTillFrameEnd },
    { 0x35FF, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x3600, opcode::OP_ScriptMethodThreadCall },
    { 0x3601, opcode::OP_Invalid },
    { 0x3602, opcode::OP_Invalid },
    { 0x3603, opcode::OP_Invalid },
    { 0x3604, opcode::OP_ShiftRight },
    { 0x3605, opcode::OP_JumpOnTrue },
    { 0x3606, opcode::OP_GetSelf },
    { 0x3607, opcode::OP_Invalid },
    { 0x3608, opcode::OP_Invalid },
    { 0x3609, opcode::OP_ScriptThreadCallClass },
    { 0x360A, opcode::OP_ScriptMethodCall },
    { 0x360B, opcode::OP_Invalid },
    { 0x360C, opcode::OP_SafeDecTop },
    { 0x360D, opcode::OP_GetFunction },
    { 0x360E, opcode::OP_SafeDecTop },
    { 0x360F, opcode::OP_GetClasses },
    { 0x3610, opcode::OP_GetString },
    { 0x3611, opcode::OP_Invalid },
    { 0x3612, opcode::OP_SizeOf },
    { 0x3613, opcode::OP_Switch },
    { 0x3614, opcode::OP_ScriptThreadCallClass },
    { 0x3615, opcode::OP_Bit_And },
    { 0x3616, opcode::OP_NextArrayKey },
    { 0x3617, opcode::OP_GetUintptr },
    { 0x3618, opcode::OP_ShiftLeft },
    { 0x3619, opcode::OP_Invalid },
    { 0x361A, opcode::OP_Invalid },
    { 0x361B, opcode::OP_Multiply },
    { 0x361C, opcode::OP_Invalid },
    { 0x361D, opcode::OP_GetGame },
    { 0x361E, opcode::OP_LessThan },
    { 0x361F, opcode::OP_ClearArray },
    { 0x3620, opcode::OP_WaitTillFrameEnd },
    { 0x3621, opcode::OP_GetString },
    { 0x3622, opcode::OP_Invalid },
    { 0x3623, opcode::OP_Invalid },
    { 0x3624, opcode::OP_GetUndefined },
    { 0x3625, opcode::OP_WaitTillMatch },
    { 0x3626, opcode::OP_ScriptFunctionCall },
    { 0x3627, opcode::OP_WaitTill },
    { 0x3628, opcode::OP_EvalFieldVariable },
    { 0x3629, opcode::OP_Invalid },
    { 0x362A, opcode::OP_Invalid },
    { 0x362B, opcode::OP_ScriptFunctionCallClass },
    { 0x362C, opcode::OP_CallBuiltinMethod },
    { 0x362D, opcode::OP_SafeSetVariableFieldCached },
    { 0x362E, opcode::OP_Invalid },
    { 0x362F, opcode::OP_GetGameRef },
    { 0x3630, opcode::OP_Minus },
    { 0x3631, opcode::OP_GetNegByte },
    { 0x3632, opcode::OP_ScriptFunctionCall },
    { 0x3633, opcode::OP_LessThanOrEqualTo },
    { 0x3634, opcode::OP_Invalid },
    { 0x3635, opcode::OP_ProfileStart },
    { 0x3636, opcode::OP_Multiply },
    { 0x3637, opcode::OP_GetHash },
    { 0x3638, opcode::OP_Invalid },
    { 0x3639, opcode::OP_ClearFieldVariable },
    { 0x363A, opcode::OP_Invalid },
    { 0x363B, opcode::OP_Invalid },
    { 0x363C, opcode::OP_Invalid },
    { 0x363D, opcode::OP_GetZero },
    { 0x363E, opcode::OP_Wait },
    { 0x363F, opcode::OP_GetUintptr },
    { 0x3640, opcode::OP_Invalid },
    { 0x3641, opcode::OP_ProfileStart },
    { 0x3642, opcode::OP_Invalid },
    { 0x3643, opcode::OP_GetLevelObject },
    { 0x3644, opcode::OP_SelfEvalFieldVariable },
    { 0x3645, opcode::OP_EvalArray },
    { 0x3646, opcode::OP_Invalid },
    { 0x3647, opcode::OP_Multiply },
    { 0x3648, opcode::OP_EvalFieldVariableRef },
    { 0x3649, opcode::OP_WaitTill },
    { 0x364A, opcode::OP_SuperNotEqual },
    { 0x364B, opcode::OP_Invalid },
    { 0x364C, opcode::OP_RealWait },
    { 0x364D, opcode::OP_Invalid },
    { 0x364E, opcode::OP_Invalid },
    { 0x364F, opcode::OP_GetAnim },
    { 0x3650, opcode::OP_WaitTillMatch },
    { 0x3651, opcode::OP_GetIString },
    { 0x3652, opcode::OP_Switch },
    { 0x3653, opcode::OP_Multiply },
    { 0x3654, opcode::OP_Invalid },
    { 0x3655, opcode::OP_Invalid },
    { 0x3656, opcode::OP_GetClasses },
    { 0x3657, opcode::OP_Invalid },
    { 0x3658, opcode::OP_EndSwitch },
    { 0x3659, opcode::OP_GetSelfObject },
    { 0x365A, opcode::OP_Invalid },
    { 0x365B, opcode::OP_ScriptFunctionCallClass },
    { 0x365C, opcode::OP_EmptyArray },
    { 0x365D, opcode::OP_SafeDecTop },
    { 0x365E, opcode::OP_SelfEvalFieldVariable },
    { 0x365F, opcode::OP_Plus },
    { 0x3660, opcode::OP_Invalid },
    { 0x3661, opcode::OP_Invalid },
    { 0x3662, opcode::OP_WaitTillFrameEnd },
    { 0x3663, opcode::OP_Invalid },
    { 0x3664, opcode::OP_SelfEvalFieldVariable },
    { 0x3665, opcode::OP_GetAnimObject },
    { 0x3666, opcode::OP_Invalid },
    { 0x3667, opcode::OP_GetFunction },
    { 0x3668, opcode::OP_BoolNot },
    { 0x3669, opcode::OP_GetAnimObject },
    { 0x366A, opcode::OP_GetAnimObject },
    { 0x366B, opcode::OP_ScriptMethodCall },
    { 0x366C, opcode::OP_Invalid },
    { 0x366D, opcode::OP_Invalid },
    { 0x366E, opcode::OP_GetIString },
    { 0x366F, opcode::OP_SafeCreateLocalVariables },
    { 0x3670, opcode::OP_Switch },
    { 0x3671, opcode::OP_GreaterThan },
    { 0x3672, opcode::OP_BoolComplement },
    { 0x3673, opcode::OP_SafeDecTop },
    { 0x3674, opcode::OP_EvalArray },
    { 0x3675, opcode::OP_GetSelfObject },
    { 0x3676, opcode::OP_Invalid },
    { 0x3677, opcode::OP_Invalid },
    { 0x3678, opcode::OP_Invalid },
    { 0x3679, opcode::OP_GetString },
    { 0x367A, opcode::OP_WaitTill },
    { 0x367B, opcode::OP_SizeOf },
    { 0x367C, opcode::OP_SuperEqual },
    { 0x367D, opcode::OP_LevelEvalFieldVariable },
    { 0x367E, opcode::OP_NotEqual },
    { 0x367F, opcode::OP_Bit_And },
    { 0x3680, opcode::OP_ClearFieldVariable },
    { 0x3681, opcode::OP_ScriptFunctionCallClass },
    { 0x3682, opcode::OP_LevelEvalFieldVariable },
    { 0x3683, opcode::OP_CallBuiltinMethod },
    { 0x3684, opcode::OP_Invalid },
    { 0x3685, opcode::OP_GetFloat },
    { 0x3686, opcode::OP_GetWorld },
    { 0x3687, opcode::OP_Invalid },
    { 0x3688, opcode::OP_Invalid },
    { 0x3689, opcode::OP_Invalid },
    { 0x368A, opcode::OP_GetGameRef },
    { 0x368B, opcode::OP_EvalFieldVariableRef },
    { 0x368C, opcode::OP_SafeCreateLocalVariables },
    { 0x368D, opcode::OP_Invalid },
    { 0x368E, opcode::OP_Invalid },
    { 0x368F, opcode::OP_EndSwitch },
    { 0x3690, opcode::OP_Invalid },
    { 0x3691, opcode::OP_Invalid },
    { 0x3692, opcode::OP_Invalid },
    { 0x3693, opcode::OP_LessThan },
    { 0x3694, opcode::OP_Dec },
    { 0x3695, opcode::OP_Invalid },
    { 0x3696, opcode::OP_EvalFieldVariable },
    { 0x3697, opcode::OP_GetTime },
    { 0x3698, opcode::OP_Invalid },
    { 0x3699, opcode::OP_Invalid },
    { 0x369A, opcode::OP_WaitTill },
    { 0x369B, opcode::OP_Invalid },
    { 0x369C, opcode::OP_Invalid },
    { 0x369D, opcode::OP_VectorScale },
    { 0x369E, opcode::OP_Invalid },
    { 0x369F, opcode::OP_JumpOnTrueExpr },
    { 0x36A0, opcode::OP_GetAnim },
    { 0x36A1, opcode::OP_Invalid },
    { 0x36A2, opcode::OP_Invalid },
    { 0x36A3, opcode::OP_Invalid },
    { 0x36A4, opcode::OP_GetHash },
    { 0x36A5, opcode::OP_EvalLocalVariableCached },
    { 0x36A6, opcode::OP_Divide },
    { 0x36A7, opcode::OP_EvalLocalVariableRefCached },
    { 0x36A8, opcode::OP_GetHash },
    { 0x36A9, opcode::OP_GetLevel },
    { 0x36AA, opcode::OP_GetInteger },
    { 0x36AB, opcode::OP_BoolComplement },
    { 0x36AC, opcode::OP_JumpOnFalseExpr },
    { 0x36AD, opcode::OP_Invalid },
    { 0x36AE, opcode::OP_EvalLocalVariableCached },
    { 0x36AF, opcode::OP_Notify },
    { 0x36B0, opcode::OP_LessThanOrEqualTo },
    { 0x36B1, opcode::OP_Invalid },
    { 0x36B2, opcode::OP_Return },
    { 0x36B3, opcode::OP_Minus },
    { 0x36B4, opcode::OP_Jump },
    { 0x36B5, opcode::OP_Invalid },
    { 0x36B6, opcode::OP_Invalid },
    { 0x36B7, opcode::OP_Invalid },
    { 0x36B8, opcode::OP_Invalid },
    { 0x36B9, opcode::OP_Invalid },
    { 0x36BA, opcode::OP_ScriptMethodCall },
    { 0x36BB, opcode::OP_DevblockBegin },
    { 0x36BC, opcode::OP_GetVector },
    { 0x36BD, opcode::OP_Jump },
    { 0x36BE, opcode::OP_Invalid },
    { 0x36BF, opcode::OP_JumpOnFalseExpr },
    { 0x36C0, opcode::OP_Notify },
    { 0x36C1, opcode::OP_Multiply },
    { 0x36C2, opcode::OP_Invalid },
    { 0x36C3, opcode::OP_Invalid },
    { 0x36C4, opcode::OP_JumpOnTrueExpr },
    { 0x36C5, opcode::OP_Invalid },
    { 0x36C6, opcode::OP_Invalid },
    { 0x36C7, opcode::OP_RealWait },
    { 0x36C8, opcode::OP_GetAnimObject },
    { 0x36C9, opcode::OP_Invalid },
    { 0x36CA, opcode::OP_Invalid },
    { 0x36CB, opcode::OP_GetAnim },
    { 0x36CC, opcode::OP_Invalid },
    { 0x36CD, opcode::OP_Modulus },
    { 0x36CE, opcode::OP_Invalid },
    { 0x36CF, opcode::OP_Invalid },
    { 0x36D0, opcode::OP_GetInteger },
    { 0x36D1, opcode::OP_Invalid },
    { 0x36D2, opcode::OP_LessThanOrEqualTo },
    { 0x36D3, opcode::OP_GetZero },
    { 0x36D4, opcode::OP_LevelEvalFieldVariableRef },
    { 0x36D5, opcode::OP_Invalid },
    { 0x36D6, opcode::OP_Plus },
    { 0x36D7, opcode::OP_GetFloat },
    { 0x36D8, opcode::OP_SafeSetVariableFieldCached },
    { 0x36D9, opcode::OP_Invalid },
    { 0x36DA, opcode::OP_Invalid },
    { 0x36DB, opcode::OP_GetClassesObject },
    { 0x36DC, opcode::OP_VectorConstant },
    { 0x36DD, opcode::OP_SuperNotEqual },
    { 0x36DE, opcode::OP_GetUintptr },
    { 0x36DF, opcode::OP_GetUintptr },
    { 0x36E0, opcode::OP_Invalid },
    { 0x36E1, opcode::OP_GetWorld },
    { 0x36E2, opcode::OP_EmptyArray },
    { 0x36E3, opcode::OP_RealWait },
    { 0x36E4, opcode::OP_GetZero },
    { 0x36E5, opcode::OP_Invalid },
    { 0x36E6, opcode::OP_ScriptMethodCallPointer },
    { 0x36E7, opcode::OP_ClearFieldVariable },
    { 0x36E8, opcode::OP_ScriptFunctionCall },
    { 0x36E9, opcode::OP_Divide },
    { 0x36EA, opcode::OP_Invalid },
    { 0x36EB, opcode::OP_Invalid },
    { 0x36EC, opcode::OP_ShiftLeft },
    { 0x36ED, opcode::OP_LevelEvalFieldVariable },
    { 0x36EE, opcode::OP_GetHash },
    { 0x36EF, opcode::OP_GetUndefined },
    { 0x36F0, opcode::OP_Invalid },
    { 0x36F1, opcode::OP_Invalid },
    { 0x36F2, opcode::OP_Invalid },
    { 0x36F3, opcode::OP_Inc },
    { 0x36F4, opcode::OP_GetSelf },
    { 0x36F5, opcode::OP_EvalArrayRef },
    { 0x36F6, opcode::OP_WaitTillFrameEnd },
    { 0x36F7, opcode::OP_Invalid },
    { 0x36F8, opcode::OP_Minus },
    { 0x36F9, opcode::OP_FirstArrayKey },
    { 0x36FA, opcode::OP_GreaterThan },
    { 0x36FB, opcode::OP_Invalid },
    { 0x36FC, opcode::OP_IsDefined },
    { 0x36FD, opcode::OP_GetUnsignedShort },
    { 0x36FE, opcode::OP_NotEqual },
    { 0x36FF, opcode::OP_GetAnimObject },
    { 0x3700, opcode::OP_Invalid },
    { 0x3701, opcode::OP_Invalid },
    { 0x3702, opcode::OP_EmptyArray },
    { 0x3703, opcode::OP_JumpOnFalseExpr },
    { 0x3704, opcode::OP_Switch },
    { 0x3705, opcode::OP_Invalid },
    { 0x3706, opcode::OP_Invalid },
    { 0x3707, opcode::OP_EndSwitch },
    { 0x3708, opcode::OP_VectorConstant },
    { 0x3709, opcode::OP_SizeOf },
    { 0x370A, opcode::OP_Invalid },
    { 0x370B, opcode::OP_LessThanOrEqualTo },
    { 0x370C, opcode::OP_NotEqual },
    { 0x370D, opcode::OP_ShiftRight },
    { 0x370E, opcode::OP_ScriptMethodCall },
    { 0x370F, opcode::OP_GreaterThanOrEqualTo },
    { 0x3710, opcode::OP_Bit_And },
    { 0x3711, opcode::OP_GetUndefined },
    { 0x3712, opcode::OP_WaitTillMatch },
    { 0x3713, opcode::OP_Return },
    { 0x3714, opcode::OP_Invalid },
    { 0x3715, opcode::OP_Invalid },
    { 0x3716, opcode::OP_Invalid },
    { 0x3717, opcode::OP_WaitTill },
    { 0x3718, opcode::OP_WaitTillMatch },
    { 0x3719, opcode::OP_Invalid },
    { 0x371A, opcode::OP_Invalid },
    { 0x371B, opcode::OP_ScriptMethodThreadCall },
    { 0x371C, opcode::OP_GetFloat },
    { 0x371D, opcode::OP_GetHash },
    { 0x371E, opcode::OP_Return },
    { 0x371F, opcode::OP_Invalid },
    { 0x3720, opcode::OP_GetFunction },
    { 0x3721, opcode::OP_Invalid },
    { 0x3722, opcode::OP_Invalid },
    { 0x3723, opcode::OP_GetWorld },
    { 0x3724, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x3725, opcode::OP_BoolNot },
    { 0x3726, opcode::OP_GetUintptr },
    { 0x3727, opcode::OP_Return },
    { 0x3728, opcode::OP_GetVector },
    { 0x3729, opcode::OP_ScriptFunctionCall },
    { 0x372A, opcode::OP_Invalid },
    { 0x372B, opcode::OP_Invalid },
    { 0x372C, opcode::OP_GetUintptr },
    { 0x372D, opcode::OP_Invalid },
    { 0x372E, opcode::OP_Invalid },
    { 0x372F, opcode::OP_Invalid },
    { 0x3730, opcode::OP_GreaterThan },
    { 0x3731, opcode::OP_GetGameRef },
    { 0x3732, opcode::OP_Invalid },
    { 0x3733, opcode::OP_Invalid },
    { 0x3734, opcode::OP_Invalid },
    { 0x3735, opcode::OP_Invalid },
    { 0x3736, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x3737, opcode::OP_Invalid },
    { 0x3738, opcode::OP_Invalid },
    { 0x3739, opcode::OP_Invalid },
    { 0x373A, opcode::OP_Invalid },
    { 0x373B, opcode::OP_WaitTill },
    { 0x373C, opcode::OP_Bit_Or },
    { 0x373D, opcode::OP_RealWait },
    { 0x373E, opcode::OP_Invalid },
    { 0x373F, opcode::OP_Invalid },
    { 0x3740, opcode::OP_GetZero },
    { 0x3741, opcode::OP_Invalid },
    { 0x3742, opcode::OP_SafeCreateLocalVariables },
    { 0x3743, opcode::OP_Bit_Xor },
    { 0x3744, opcode::OP_JumpOnTrueExpr },
    { 0x3745, opcode::OP_GetClassesObject },
    { 0x3746, opcode::OP_Invalid },
    { 0x3747, opcode::OP_ProfileStop },
    { 0x3748, opcode::OP_Notify },
    { 0x3749, opcode::OP_GetGame },
    { 0x374A, opcode::OP_Equal },
    { 0x374B, opcode::OP_Invalid },
    { 0x374C, opcode::OP_GetUnsignedShort },
    { 0x374D, opcode::OP_WaitTillFrameEnd },
    { 0x374E, opcode::OP_Invalid },
    { 0x374F, opcode::OP_Invalid },
    { 0x3750, opcode::OP_BoolNot },
    { 0x3751, opcode::OP_Invalid },
    { 0x3752, opcode::OP_Invalid },
    { 0x3753, opcode::OP_Invalid },
    { 0x3754, opcode::OP_Minus },
    { 0x3755, opcode::OP_Invalid },
    { 0x3756, opcode::OP_Invalid },
    { 0x3757, opcode::OP_GreaterThanOrEqualTo },
    { 0x3758, opcode::OP_Invalid },
    { 0x3759, opcode::OP_Invalid },
    { 0x375A, opcode::OP_GetLevelObject },
    { 0x375B, opcode::OP_Vector },
    { 0x375C, opcode::OP_Bit_And },
    { 0x375D, opcode::OP_GetHash },
    { 0x375E, opcode::OP_Invalid },
    { 0x375F, opcode::OP_Dec },
    { 0x3760, opcode::OP_Invalid },
    { 0x3761, opcode::OP_Invalid },
    { 0x3762, opcode::OP_Invalid },
    { 0x3763, opcode::OP_LessThanOrEqualTo },
    { 0x3764, opcode::OP_Inc },
    { 0x3765, opcode::OP_Invalid },
    { 0x3766, opcode::OP_Bit_And },
    { 0x3767, opcode::OP_CastBool },
    { 0x3768, opcode::OP_Invalid },
    { 0x3769, opcode::OP_Invalid },
    { 0x376A, opcode::OP_Inc },
    { 0x376B, opcode::OP_Invalid },
    { 0x376C, opcode::OP_GetAnimObject },
    { 0x376D, opcode::OP_GetWorldObject },
    { 0x376E, opcode::OP_Invalid },
    { 0x376F, opcode::OP_Invalid },
    { 0x3770, opcode::OP_ClearArray },
    { 0x3771, opcode::OP_Invalid },
    { 0x3772, opcode::OP_Invalid },
    { 0x3773, opcode::OP_ScriptMethodCall },
    { 0x3774, opcode::OP_Invalid },
    { 0x3775, opcode::OP_Invalid },
    { 0x3776, opcode::OP_Bit_And },
    { 0x3777, opcode::OP_Invalid },
    { 0x3778, opcode::OP_Invalid },
    { 0x3779, opcode::OP_Invalid },
    { 0x377A, opcode::OP_VectorScale },
    { 0x377B, opcode::OP_Invalid },
    { 0x377C, opcode::OP_Invalid },
    { 0x377D, opcode::OP_Invalid },
    { 0x377E, opcode::OP_ClearArray },
    { 0x377F, opcode::OP_GetAnimation },
    { 0x3780, opcode::OP_GetIString },
    { 0x3781, opcode::OP_Invalid },
    { 0x3782, opcode::OP_Invalid },
    { 0x3783, opcode::OP_GetFloat },
    { 0x3784, opcode::OP_EvalFieldVariable },
    { 0x3785, opcode::OP_WaitTillMatch },
    { 0x3786, opcode::OP_Invalid },
    { 0x3787, opcode::OP_GetSelfObject },
    { 0x3788, opcode::OP_GetSelf },
    { 0x3789, opcode::OP_Invalid },
    { 0x378A, opcode::OP_SuperEqual },
    { 0x378B, opcode::OP_GetUndefined },
    { 0x378C, opcode::OP_Invalid },
    { 0x378D, opcode::OP_GetGameRef },
    { 0x378E, opcode::OP_Invalid },
    { 0x378F, opcode::OP_Invalid },
    { 0x3790, opcode::OP_Invalid },
    { 0x3791, opcode::OP_GetGame },
    { 0x3792, opcode::OP_ScriptFunctionCallPointer },
    { 0x3793, opcode::OP_Invalid },
    { 0x3794, opcode::OP_NextArrayKey },
    { 0x3795, opcode::OP_EvalArrayRef },
    { 0x3796, opcode::OP_Invalid },
    { 0x3797, opcode::OP_Invalid },
    { 0x3798, opcode::OP_Invalid },
    { 0x3799, opcode::OP_LessThan },
    { 0x379A, opcode::OP_WaitTillMatch },
    { 0x379B, opcode::OP_Invalid },
    { 0x379C, opcode::OP_LevelEvalFieldVariableRef },
    { 0x379D, opcode::OP_SuperNotEqual },
    { 0x379E, opcode::OP_GetUnsignedShort },
    { 0x379F, opcode::OP_Invalid },
    { 0x37A0, opcode::OP_Invalid },
    { 0x37A1, opcode::OP_ScriptFunctionCallPointer },
    { 0x37A2, opcode::OP_Invalid },
    { 0x37A3, opcode::OP_LevelEvalFieldVariableRef },
    { 0x37A4, opcode::OP_RealWait },
    { 0x37A5, opcode::OP_ScriptFunctionCallClass },
    { 0x37A6, opcode::OP_EvalFieldVariable },
    { 0x37A7, opcode::OP_Wait },
    { 0x37A8, opcode::OP_Invalid },
    { 0x37A9, opcode::OP_Invalid },
    { 0x37AA, opcode::OP_Return },
    { 0x37AB, opcode::OP_ScriptFunctionCallClass },
    { 0x37AC, opcode::OP_GetUndefined },
    { 0x37AD, opcode::OP_Invalid },
    { 0x37AE, opcode::OP_Invalid },
    { 0x37AF, opcode::OP_Divide },
    { 0x37B0, opcode::OP_GetClasses },
    { 0x37B1, opcode::OP_Invalid },
    { 0x37B2, opcode::OP_JumpOnTrue },
    { 0x37B3, opcode::OP_CallBuiltinMethod },
    { 0x37B4, opcode::OP_GetSelfObject },
    { 0x37B5, opcode::OP_GetClasses },
    { 0x37B6, opcode::OP_GetUnsignedShort },
    { 0x37B7, opcode::OP_GetLevel },
    { 0x37B8, opcode::OP_SuperEqual },
    { 0x37B9, opcode::OP_Invalid },
    { 0x37BA, opcode::OP_Invalid },
    { 0x37BB, opcode::OP_Divide },
    { 0x37BC, opcode::OP_Invalid },
    { 0x37BD, opcode::OP_GetVector },
    { 0x37BE, opcode::OP_EvalLocalVariableCached },
    { 0x37BF, opcode::OP_Invalid },
    { 0x37C0, opcode::OP_GetUnsignedShort },
    { 0x37C1, opcode::OP_DevblockBegin },
    { 0x37C2, opcode::OP_WaitTill },
    { 0x37C3, opcode::OP_JumpOnTrue },
    { 0x37C4, opcode::OP_Jump },
    { 0x37C5, opcode::OP_GetSelfObject },
    { 0x37C6, opcode::OP_ScriptMethodThreadCall },
    { 0x37C7, opcode::OP_Invalid },
    { 0x37C8, opcode::OP_CastBool },
    { 0x37C9, opcode::OP_Invalid },
    { 0x37CA, opcode::OP_New },
    { 0x37CB, opcode::OP_BoolComplement },
    { 0x37CC, opcode::OP_EvalLocalVariableRefCached },
    { 0x37CD, opcode::OP_FirstArrayKey },
    { 0x37CE, opcode::OP_ScriptThreadCall },
    { 0x37CF, opcode::OP_Bit_Xor },
    { 0x37D0, opcode::OP_WaitTill },
    { 0x37D1, opcode::OP_Invalid },
    { 0x37D2, opcode::OP_JumpOnTrueExpr },
    { 0x37D3, opcode::OP_Minus },
    { 0x37D4, opcode::OP_GetInteger },
    { 0x37D5, opcode::OP_GetUndefined },
    { 0x37D6, opcode::OP_NextArrayKey },
    { 0x37D7, opcode::OP_Invalid },
    { 0x37D8, opcode::OP_Invalid },
    { 0x37D9, opcode::OP_GetFloat },
    { 0x37DA, opcode::OP_FirstArrayKey },
    { 0x37DB, opcode::OP_SelfEvalFieldVariableRef },
    { 0x37DC, opcode::OP_GetTime },
    { 0x37DD, opcode::OP_Invalid },
    { 0x37DE, opcode::OP_ScriptThreadCallClass },
    { 0x37DF, opcode::OP_GetIString },
    { 0x37E0, opcode::OP_Invalid },
    { 0x37E1, opcode::OP_GetLevel },
    { 0x37E2, opcode::OP_Invalid },
    { 0x37E3, opcode::OP_GetTime },
    { 0x37E4, opcode::OP_Invalid },
    { 0x37E5, opcode::OP_Invalid },
    { 0x37E6, opcode::OP_GetAnimObject },
    { 0x37E7, opcode::OP_Bit_And },
    { 0x37E8, opcode::OP_New },
    { 0x37E9, opcode::OP_NotEqual },
    { 0x37EA, opcode::OP_Invalid },
    { 0x37EB, opcode::OP_Plus },
    { 0x37EC, opcode::OP_ScriptFunctionCallPointer },
    { 0x37ED, opcode::OP_GetUnsignedShort },
    { 0x37EE, opcode::OP_Notify },
    { 0x37EF, opcode::OP_ScriptMethodCallPointer },
    { 0x37F0, opcode::OP_EvalArrayRef },
    { 0x37F1, opcode::OP_SizeOf },
    { 0x37F2, opcode::OP_Divide },
    { 0x37F3, opcode::OP_Invalid },
    { 0x37F4, opcode::OP_SafeDecTop },
    { 0x37F5, opcode::OP_GetIString },
    { 0x37F6, opcode::OP_Invalid },
    { 0x37F7, opcode::OP_GetNegUnsignedShort },
    { 0x37F8, opcode::OP_GetHash },
    { 0x37F9, opcode::OP_EndSwitch },
    { 0x37FA, opcode::OP_Invalid },
    { 0x37FB, opcode::OP_GetFunction },
    { 0x37FC, opcode::OP_GetInteger },
    { 0x37FD, opcode::OP_GetNegUnsignedShort },
    { 0x37FE, opcode::OP_Invalid },
    { 0x37FF, opcode::OP_GetUintptr },
    { 0x3800, opcode::OP_GetLevel },
    { 0x3801, opcode::OP_EvalArray },
    { 0x3802, opcode::OP_Invalid },
    { 0x3803, opcode::OP_VectorScale },
    { 0x3804, opcode::OP_Invalid },
    { 0x3805, opcode::OP_GetHash },
    { 0x3806, opcode::OP_Invalid },
    { 0x3807, opcode::OP_JumpOnFalseExpr },
    { 0x3808, opcode::OP_SelfEvalFieldVariable },
    { 0x3809, opcode::OP_Invalid },
    { 0x380A, opcode::OP_GetClasses },
    { 0x380B, opcode::OP_ScriptMethodCall },
    { 0x380C, opcode::OP_GetAnimation },
    { 0x380D, opcode::OP_EndSwitch },
    { 0x380E, opcode::OP_Invalid },
    { 0x380F, opcode::OP_GetLevel },
    { 0x3810, opcode::OP_WaitTillMatch },
    { 0x3811, opcode::OP_EvalFieldVariable },
    { 0x3812, opcode::OP_Invalid },
    { 0x3813, opcode::OP_Invalid },
    { 0x3814, opcode::OP_EvalLocalVariableRefCached },
    { 0x3815, opcode::OP_GetWorldObject },
    { 0x3816, opcode::OP_EndSwitch },
    { 0x3817, opcode::OP_Plus },
    { 0x3818, opcode::OP_NextArrayKey },
    { 0x3819, opcode::OP_GetClassesObject },
    { 0x381A, opcode::OP_ScriptMethodCallPointer },
    { 0x381B, opcode::OP_FirstArrayKey },
    { 0x381C, opcode::OP_ClearArray },
    { 0x381D, opcode::OP_Invalid },
    { 0x381E, opcode::OP_GetUnsignedShort },
    { 0x381F, opcode::OP_GetLevel },
    { 0x3820, opcode::OP_Invalid },
    { 0x3821, opcode::OP_Vector },
    { 0x3822, opcode::OP_Invalid },
    { 0x3823, opcode::OP_Invalid },
    { 0x3824, opcode::OP_CastBool },
    { 0x3825, opcode::OP_Invalid },
    { 0x3826, opcode::OP_Invalid },
    { 0x3827, opcode::OP_Invalid },
    { 0x3828, opcode::OP_Invalid },
    { 0x3829, opcode::OP_Invalid },
    { 0x382A, opcode::OP_Invalid },
    { 0x382B, opcode::OP_Invalid },
    { 0x382C, opcode::OP_New },
    { 0x382D, opcode::OP_Notify },
    { 0x382E, opcode::OP_Invalid },
    { 0x382F, opcode::OP_SuperNotEqual },
    { 0x3830, opcode::OP_Invalid },
    { 0x3831, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x3832, opcode::OP_Invalid },
    { 0x3833, opcode::OP_Switch },
    { 0x3834, opcode::OP_CastBool },
    { 0x3835, opcode::OP_Invalid },
    { 0x3836, opcode::OP_NotEqual },
    { 0x3837, opcode::OP_EvalLocalVariableCached },
    { 0x3838, opcode::OP_Invalid },
    { 0x3839, opcode::OP_RealWait },
    { 0x383A, opcode::OP_GetWorld },
    { 0x383B, opcode::OP_GreaterThan },
    { 0x383C, opcode::OP_Invalid },
    { 0x383D, opcode::OP_NotEqual },
    { 0x383E, opcode::OP_Invalid },
    { 0x383F, opcode::OP_Invalid },
    { 0x3840, opcode::OP_Invalid },
    { 0x3841, opcode::OP_ProfileStart },
    { 0x3842, opcode::OP_Invalid },
    { 0x3843, opcode::OP_Bit_And },
    { 0x3844, opcode::OP_ShiftRight },
    { 0x3845, opcode::OP_SetVariableField },
    { 0x3846, opcode::OP_NextArrayKey },
    { 0x3847, opcode::OP_ScriptThreadCall },
    { 0x3848, opcode::OP_CallBuiltinMethod },
    { 0x3849, opcode::OP_Vector },
    { 0x384A, opcode::OP_Jump },
    { 0x384B, opcode::OP_Invalid },
    { 0x384C, opcode::OP_GetNegByte },
    { 0x384D, opcode::OP_GreaterThanOrEqualTo },
    { 0x384E, opcode::OP_Invalid },
    { 0x384F, opcode::OP_GetVector },
    { 0x3850, opcode::OP_GetWorld },
    { 0x3851, opcode::OP_Invalid },
    { 0x3852, opcode::OP_Invalid },
    { 0x3853, opcode::OP_Invalid },
    { 0x3854, opcode::OP_Invalid },
    { 0x3855, opcode::OP_NextArrayKey },
    { 0x3856, opcode::OP_BoolNot },
    { 0x3857, opcode::OP_LessThanOrEqualTo },
    { 0x3858, opcode::OP_Multiply },
    { 0x3859, opcode::OP_Invalid },
    { 0x385A, opcode::OP_SetVariableField },
    { 0x385B, opcode::OP_SuperEqual },
    { 0x385C, opcode::OP_ClearArray },
    { 0x385D, opcode::OP_DevblockBegin },
    { 0x385E, opcode::OP_GetWorldObject },
    { 0x385F, opcode::OP_EndSwitch },
    { 0x3860, opcode::OP_GetAnimObject },
    { 0x3861, opcode::OP_Invalid },
    { 0x3862, opcode::OP_Bit_Xor },
    { 0x3863, opcode::OP_GetByte },
    { 0x3864, opcode::OP_GetUndefined },
    { 0x3865, opcode::OP_Invalid },
    { 0x3866, opcode::OP_ScriptMethodCallPointer },
    { 0x3867, opcode::OP_SuperEqual },
    { 0x3868, opcode::OP_SelfEvalFieldVariableRef },
    { 0x3869, opcode::OP_Invalid },
    { 0x386A, opcode::OP_NextArrayKey },
    { 0x386B, opcode::OP_Notify },
    { 0x386C, opcode::OP_GreaterThan },
    { 0x386D, opcode::OP_Invalid },
    { 0x386E, opcode::OP_Invalid },
    { 0x386F, opcode::OP_Invalid },
    { 0x3870, opcode::OP_Invalid },
    { 0x3871, opcode::OP_Notify },
    { 0x3872, opcode::OP_Vector },
    { 0x3873, opcode::OP_GetAnim },
    { 0x3874, opcode::OP_Invalid },
    { 0x3875, opcode::OP_SafeSetVariableFieldCached },
    { 0x3876, opcode::OP_SelfEvalFieldVariable },
    { 0x3877, opcode::OP_Invalid },
    { 0x3878, opcode::OP_LevelEvalFieldVariable },
    { 0x3879, opcode::OP_Multiply },
    { 0x387A, opcode::OP_Invalid },
    { 0x387B, opcode::OP_GetFloat },
    { 0x387C, opcode::OP_Bit_Xor },
    { 0x387D, opcode::OP_Invalid },
    { 0x387E, opcode::OP_Invalid },
    { 0x387F, opcode::OP_Invalid },
    { 0x3880, opcode::OP_EvalFieldVariableRef },
    { 0x3881, opcode::OP_GetAnimObject },
    { 0x3882, opcode::OP_FirstArrayKey },
    { 0x3883, opcode::OP_GetString },
    { 0x3884, opcode::OP_SuperNotEqual },
    { 0x3885, opcode::OP_Bit_Xor },
    { 0x3886, opcode::OP_SafeCreateLocalVariables },
    { 0x3887, opcode::OP_Invalid },
    { 0x3888, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x3889, opcode::OP_GetUndefined },
    { 0x388A, opcode::OP_Invalid },
    { 0x388B, opcode::OP_Invalid },
    { 0x388C, opcode::OP_Invalid },
    { 0x388D, opcode::OP_Invalid },
    { 0x388E, opcode::OP_GetTime },
    { 0x388F, opcode::OP_GetIString },
    { 0x3890, opcode::OP_GetUndefined },
    { 0x3891, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x3892, opcode::OP_Invalid },
    { 0x3893, opcode::OP_Notify },
    { 0x3894, opcode::OP_Invalid },
    { 0x3895, opcode::OP_Dec },
    { 0x3896, opcode::OP_Invalid },
    { 0x3897, opcode::OP_New },
    { 0x3898, opcode::OP_GetSelf },
    { 0x3899, opcode::OP_WaitTill },
    { 0x389A, opcode::OP_GetAnimObject },
    { 0x389B, opcode::OP_GetUndefined },
    { 0x389C, opcode::OP_Vector },
    { 0x389D, opcode::OP_ShiftLeft },
    { 0x389E, opcode::OP_GreaterThan },
    { 0x389F, opcode::OP_Invalid },
    { 0x38A0, opcode::OP_GetNegByte },
    { 0x38A1, opcode::OP_GetWorldObject },
    { 0x38A2, opcode::OP_Divide },
    { 0x38A3, opcode::OP_Notify },
    { 0x38A4, opcode::OP_ClearFieldVariable },
    { 0x38A5, opcode::OP_GetClasses },
    { 0x38A6, opcode::OP_ShiftRight },
    { 0x38A7, opcode::OP_RealWait },
    { 0x38A8, opcode::OP_GetWorld },
    { 0x38A9, opcode::OP_GetString },
    { 0x38AA, opcode::OP_Modulus },
    { 0x38AB, opcode::OP_SafeCreateLocalVariables },
    { 0x38AC, opcode::OP_GetAnimation },
    { 0x38AD, opcode::OP_Invalid },
    { 0x38AE, opcode::OP_Invalid },
    { 0x38AF, opcode::OP_GetFunction },
    { 0x38B0, opcode::OP_GetTime },
    { 0x38B1, opcode::OP_Invalid },
    { 0x38B2, opcode::OP_Invalid },
    { 0x38B3, opcode::OP_GetWorld },
    { 0x38B4, opcode::OP_Invalid },
    { 0x38B5, opcode::OP_WaitTillMatch },
    { 0x38B6, opcode::OP_Invalid },
    { 0x38B7, opcode::OP_GreaterThan },
    { 0x38B8, opcode::OP_Invalid },
    { 0x38B9, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x38BA, opcode::OP_Invalid },
    { 0x38BB, opcode::OP_EvalArray },
    { 0x38BC, opcode::OP_GetWorld },
    { 0x38BD, opcode::OP_Notify },
    { 0x38BE, opcode::OP_JumpOnFalseExpr },
    { 0x38BF, opcode::OP_JumpOnTrue },
    { 0x38C0, opcode::OP_GetClasses },
    { 0x38C1, opcode::OP_Invalid },
    { 0x38C2, opcode::OP_EndSwitch },
    { 0x38C3, opcode::OP_DevblockBegin },
    { 0x38C4, opcode::OP_ScriptThreadCall },
    { 0x38C5, opcode::OP_Invalid },
    { 0x38C6, opcode::OP_ScriptThreadCall },
    { 0x38C7, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x38C8, opcode::OP_Invalid },
    { 0x38C9, opcode::OP_LevelEvalFieldVariableRef },
    { 0x38CA, opcode::OP_GreaterThanOrEqualTo },
    { 0x38CB, opcode::OP_Multiply },
    { 0x38CC, opcode::OP_ShiftLeft },
    { 0x38CD, opcode::OP_GetGameRef },
    { 0x38CE, opcode::OP_GetWorld },
    { 0x38CF, opcode::OP_SafeDecTop },
    { 0x38D0, opcode::OP_SetVariableField },
    { 0x38D1, opcode::OP_Invalid },
    { 0x38D2, opcode::OP_SelfEvalFieldVariable },
    { 0x38D3, opcode::OP_Invalid },
    { 0x38D4, opcode::OP_GetTime },
    { 0x38D5, opcode::OP_Invalid },
    { 0x38D6, opcode::OP_ScriptThreadCallClass },
    { 0x38D7, opcode::OP_Invalid },
    { 0x38D8, opcode::OP_WaitTillMatch },
    { 0x38D9, opcode::OP_ShiftRight },
    { 0x38DA, opcode::OP_GetVector },
    { 0x38DB, opcode::OP_SuperEqual },
    { 0x38DC, opcode::OP_NotEqual },
    { 0x38DD, opcode::OP_Invalid },
    { 0x38DE, opcode::OP_GetHash },
    { 0x38DF, opcode::OP_Invalid },
    { 0x38E0, opcode::OP_Invalid },
    { 0x38E1, opcode::OP_GetIString },
    { 0x38E2, opcode::OP_Invalid },
    { 0x38E3, opcode::OP_Invalid },
    { 0x38E4, opcode::OP_Modulus },
    { 0x38E5, opcode::OP_GetVector },
    { 0x38E6, opcode::OP_ShiftRight },
    { 0x38E7, opcode::OP_GetUnsignedShort },
    { 0x38E8, opcode::OP_Invalid },
    { 0x38E9, opcode::OP_EmptyArray },
    { 0x38EA, opcode::OP_Invalid },
    { 0x38EB, opcode::OP_Invalid },
    { 0x38EC, opcode::OP_DevblockBegin },
    { 0x38ED, opcode::OP_Invalid },
    { 0x38EE, opcode::OP_LessThanOrEqualTo },
    { 0x38EF, opcode::OP_Invalid },
    { 0x38F0, opcode::OP_DevblockBegin },
    { 0x38F1, opcode::OP_EvalArrayRef },
    { 0x38F2, opcode::OP_Invalid },
    { 0x38F3, opcode::OP_Invalid },
    { 0x38F4, opcode::OP_Invalid },
    { 0x38F5, opcode::OP_Bit_And },
    { 0x38F6, opcode::OP_GetFloat },
    { 0x38F7, opcode::OP_Divide },
    { 0x38F8, opcode::OP_ScriptFunctionCallClass },
    { 0x38F9, opcode::OP_GetWorld },
    { 0x38FA, opcode::OP_GetWorldObject },
    { 0x38FB, opcode::OP_Invalid },
    { 0x38FC, opcode::OP_Invalid },
    { 0x38FD, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x38FE, opcode::OP_Invalid },
    { 0x38FF, opcode::OP_ClearArray },
    { 0x3900, opcode::OP_Invalid },
    { 0x3901, opcode::OP_GetFunction },
    { 0x3902, opcode::OP_New },
    { 0x3903, opcode::OP_Invalid },
    { 0x3904, opcode::OP_EvalArrayRef },
    { 0x3905, opcode::OP_Bit_Or },
    { 0x3906, opcode::OP_Jump },
    { 0x3907, opcode::OP_Invalid },
    { 0x3908, opcode::OP_JumpOnFalseExpr },
    { 0x3909, opcode::OP_Return },
    { 0x390A, opcode::OP_Invalid },
    { 0x390B, opcode::OP_ScriptMethodThreadCall },
    { 0x390C, opcode::OP_Invalid },
    { 0x390D, opcode::OP_ScriptMethodCallPointer },
    { 0x390E, opcode::OP_WaitTillFrameEnd },
    { 0x390F, opcode::OP_Invalid },
    { 0x3910, opcode::OP_WaitTill },
    { 0x3911, opcode::OP_GetSelfObject },
    { 0x3912, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x3913, opcode::OP_Invalid },
    { 0x3914, opcode::OP_WaitTillFrameEnd },
    { 0x3915, opcode::OP_ShiftRight },
    { 0x3916, opcode::OP_GetFloat },
    { 0x3917, opcode::OP_GetAnim },
    { 0x3918, opcode::OP_ScriptThreadCallClass },
    { 0x3919, opcode::OP_WaitTill },
    { 0x391A, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x391B, opcode::OP_Invalid },
    { 0x391C, opcode::OP_ProfileStart },
    { 0x391D, opcode::OP_GetUnsignedShort },
    { 0x391E, opcode::OP_Invalid },
    { 0x391F, opcode::OP_Invalid },
    { 0x3920, opcode::OP_SelfEvalFieldVariableRef },
    { 0x3921, opcode::OP_GetAnim },
    { 0x3922, opcode::OP_GetNegByte },
    { 0x3923, opcode::OP_Invalid },
    { 0x3924, opcode::OP_JumpOnTrueExpr },
    { 0x3925, opcode::OP_LevelEvalFieldVariable },
    { 0x3926, opcode::OP_GetNegByte },
    { 0x3927, opcode::OP_Invalid },
    { 0x3928, opcode::OP_CallBuiltinMethod },
    { 0x3929, opcode::OP_Invalid },
    { 0x392A, opcode::OP_Invalid },
    { 0x392B, opcode::OP_LevelEvalFieldVariable },
    { 0x392C, opcode::OP_ScriptFunctionCall },
    { 0x392D, opcode::OP_Invalid },
    { 0x392E, opcode::OP_Bit_And },
    { 0x392F, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x3930, opcode::OP_EmptyArray },
    { 0x3931, opcode::OP_Invalid },
    { 0x3932, opcode::OP_ShiftLeft },
    { 0x3933, opcode::OP_Jump },
    { 0x3934, opcode::OP_GetUndefined },
    { 0x3935, opcode::OP_Invalid },
    { 0x3936, opcode::OP_GetAnimObject },
    { 0x3937, opcode::OP_WaitTillMatch },
    { 0x3938, opcode::OP_GetUndefined },
    { 0x3939, opcode::OP_GetIString },
    { 0x393A, opcode::OP_GetUndefined },
    { 0x393B, opcode::OP_Minus },
    { 0x393C, opcode::OP_VectorScale },
    { 0x393D, opcode::OP_GetAnimObject },
    { 0x393E, opcode::OP_Bit_And },
    { 0x393F, opcode::OP_Invalid },
    { 0x3940, opcode::OP_CallBuiltinMethod },
    { 0x3941, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x3942, opcode::OP_GetFloat },
    { 0x3943, opcode::OP_GetGameRef },
    { 0x3944, opcode::OP_EmptyArray },
    { 0x3945, opcode::OP_Invalid },
    { 0x3946, opcode::OP_Invalid },
    { 0x3947, opcode::OP_Invalid },
    { 0x3948, opcode::OP_Invalid },
    { 0x3949, opcode::OP_GetFunction },
    { 0x394A, opcode::OP_Switch },
    { 0x394B, opcode::OP_CallBuiltinMethod },
    { 0x394C, opcode::OP_ShiftLeft },
    { 0x394D, opcode::OP_GetZero },
    { 0x394E, opcode::OP_GetIString },
    { 0x394F, opcode::OP_GetSelfObject },
    { 0x3950, opcode::OP_Invalid },
    { 0x3951, opcode::OP_GetHash },
    { 0x3952, opcode::OP_VectorScale },
    { 0x3953, opcode::OP_Invalid },
    { 0x3954, opcode::OP_Invalid },
    { 0x3955, opcode::OP_GreaterThanOrEqualTo },
    { 0x3956, opcode::OP_Invalid },
    { 0x3957, opcode::OP_GetGame },
    { 0x3958, opcode::OP_Invalid },
    { 0x3959, opcode::OP_Invalid },
    { 0x395A, opcode::OP_VectorScale },
    { 0x395B, opcode::OP_New },
    { 0x395C, opcode::OP_GetWorld },
    { 0x395D, opcode::OP_GetString },
    { 0x395E, opcode::OP_Invalid },
    { 0x395F, opcode::OP_ScriptFunctionCallClass },
    { 0x3960, opcode::OP_JumpOnFalseExpr },
    { 0x3961, opcode::OP_ScriptMethodCallPointer },
    { 0x3962, opcode::OP_Invalid },
    { 0x3963, opcode::OP_GetFunction },
    { 0x3964, opcode::OP_Bit_And },
    { 0x3965, opcode::OP_Invalid },
    { 0x3966, opcode::OP_ClearArray },
    { 0x3967, opcode::OP_Invalid },
    { 0x3968, opcode::OP_Invalid },
    { 0x3969, opcode::OP_ClearArray },
    { 0x396A, opcode::OP_Invalid },
    { 0x396B, opcode::OP_LevelEvalFieldVariableRef },
    { 0x396C, opcode::OP_Invalid },
    { 0x396D, opcode::OP_GetUintptr },
    { 0x396E, opcode::OP_Invalid },
    { 0x396F, opcode::OP_Invalid },
    { 0x3970, opcode::OP_Invalid },
    { 0x3971, opcode::OP_Switch },
    { 0x3972, opcode::OP_Wait },
    { 0x3973, opcode::OP_Invalid },
    { 0x3974, opcode::OP_EndSwitch },
    { 0x3975, opcode::OP_ClearFieldVariable },
    { 0x3976, opcode::OP_WaitTillMatch },
    { 0x3977, opcode::OP_Invalid },
    { 0x3978, opcode::OP_Invalid },
    { 0x3979, opcode::OP_CallBuiltinMethod },
    { 0x397A, opcode::OP_ScriptFunctionCallClass },
    { 0x397B, opcode::OP_Bit_And },
    { 0x397C, opcode::OP_LevelEvalFieldVariableRef },
    { 0x397D, opcode::OP_GetIString },
    { 0x397E, opcode::OP_NotEqual },
    { 0x397F, opcode::OP_Invalid },
    { 0x3980, opcode::OP_JumpOnTrue },
    { 0x3981, opcode::OP_FirstArrayKey },
    { 0x3982, opcode::OP_Invalid },
    { 0x3983, opcode::OP_JumpOnTrue },
    { 0x3984, opcode::OP_CallBuiltinMethod },
    { 0x3985, opcode::OP_EndSwitch },
    { 0x3986, opcode::OP_DevblockBegin },
    { 0x3987, opcode::OP_Invalid },
    { 0x3988, opcode::OP_Invalid },
    { 0x3989, opcode::OP_Invalid },
    { 0x398A, opcode::OP_GetIString },
    { 0x398B, opcode::OP_SetVariableField },
    { 0x398C, opcode::OP_Jump },
    { 0x398D, opcode::OP_NextArrayKey },
    { 0x398E, opcode::OP_WaitTillFrameEnd },
    { 0x398F, opcode::OP_EvalFieldVariableRef },
    { 0x3990, opcode::OP_GreaterThan },
    { 0x3991, opcode::OP_Invalid },
    { 0x3992, opcode::OP_Invalid },
    { 0x3993, opcode::OP_GetVector },
    { 0x3994, opcode::OP_Notify },
    { 0x3995, opcode::OP_Invalid },
    { 0x3996, opcode::OP_Vector },
    { 0x3997, opcode::OP_Invalid },
    { 0x3998, opcode::OP_GetGame },
    { 0x3999, opcode::OP_Invalid },
    { 0x399A, opcode::OP_Invalid },
    { 0x399B, opcode::OP_GetLevel },
    { 0x399C, opcode::OP_GetAnimObject },
    { 0x399D, opcode::OP_Invalid },
    { 0x399E, opcode::OP_GetFloat },
    { 0x399F, opcode::OP_SafeCreateLocalVariables },
    { 0x39A0, opcode::OP_Invalid },
    { 0x39A1, opcode::OP_ProfileStart },
    { 0x39A2, opcode::OP_EvalFieldVariableRef },
    { 0x39A3, opcode::OP_Invalid },
    { 0x39A4, opcode::OP_Invalid },
    { 0x39A5, opcode::OP_DecTop },
    { 0x39A6, opcode::OP_Invalid },
    { 0x39A7, opcode::OP_EvalArrayRef },
    { 0x39A8, opcode::OP_GetIString },
    { 0x39A9, opcode::OP_Bit_And },
    { 0x39AA, opcode::OP_EmptyArray },
    { 0x39AB, opcode::OP_GetWorld },
    { 0x39AC, opcode::OP_LessThan },
    { 0x39AD, opcode::OP_EvalLocalVariableRefCached },
    { 0x39AE, opcode::OP_ClearArray },
    { 0x39AF, opcode::OP_SetVariableField },
    { 0x39B0, opcode::OP_EmptyArray },
    { 0x39B1, opcode::OP_Invalid },
    { 0x39B2, opcode::OP_EvalLocalVariableRefCached },
    { 0x39B3, opcode::OP_VectorScale },
    { 0x39B4, opcode::OP_Invalid },
    { 0x39B5, opcode::OP_EvalArrayRef },
    { 0x39B6, opcode::OP_GetUndefined },
    { 0x39B7, opcode::OP_GetString },
    { 0x39B8, opcode::OP_Invalid },
    { 0x39B9, opcode::OP_FirstArrayKey },
    { 0x39BA, opcode::OP_DevblockBegin },
    { 0x39BB, opcode::OP_Invalid },
    { 0x39BC, opcode::OP_Invalid },
    { 0x39BD, opcode::OP_SelfEvalFieldVariable },
    { 0x39BE, opcode::OP_Invalid },
    { 0x39BF, opcode::OP_GetClasses },
    { 0x39C0, opcode::OP_Invalid },
    { 0x39C1, opcode::OP_Jump },
    { 0x39C2, opcode::OP_Invalid },
    { 0x39C3, opcode::OP_IsDefined },
    { 0x39C4, opcode::OP_SafeCreateLocalVariables },
    { 0x39C5, opcode::OP_CallBuiltinMethod },
    { 0x39C6, opcode::OP_Bit_Or },
    { 0x39C7, opcode::OP_Minus },
    { 0x39C8, opcode::OP_IsDefined },
    { 0x39C9, opcode::OP_Invalid },
    { 0x39CA, opcode::OP_Invalid },
    { 0x39CB, opcode::OP_Multiply },
    { 0x39CC, opcode::OP_GreaterThanOrEqualTo },
    { 0x39CD, opcode::OP_Invalid },
    { 0x39CE, opcode::OP_WaitTillFrameEnd },
    { 0x39CF, opcode::OP_Invalid },
    { 0x39D0, opcode::OP_Divide },
    { 0x39D1, opcode::OP_CastBool },
    { 0x39D2, opcode::OP_Invalid },
    { 0x39D3, opcode::OP_Invalid },
    { 0x39D4, opcode::OP_ScriptThreadCallPointer },
    { 0x39D5, opcode::OP_ScriptFunctionCallClass },
    { 0x39D6, opcode::OP_ScriptMethodCallPointer },
    { 0x39D7, opcode::OP_GetHash },
    { 0x39D8, opcode::OP_GetUintptr },
    { 0x39D9, opcode::OP_Invalid },
    { 0x39DA, opcode::OP_Equal },
    { 0x39DB, opcode::OP_ProfileStart },
    { 0x39DC, opcode::OP_GetSelf },
    { 0x39DD, opcode::OP_GreaterThanOrEqualTo },
    { 0x39DE, opcode::OP_Invalid },
    { 0x39DF, opcode::OP_GetZero },
    { 0x39E0, opcode::OP_GetInteger },
    { 0x39E1, opcode::OP_ClearFieldVariable },
    { 0x39E2, opcode::OP_Invalid },
    { 0x39E3, opcode::OP_EvalLocalVariableRefCached },
    { 0x39E4, opcode::OP_Invalid },
    { 0x39E5, opcode::OP_Switch },
    { 0x39E6, opcode::OP_WaitTillFrameEnd },
    { 0x39E7, opcode::OP_JumpOnFalseExpr },
    { 0x39E8, opcode::OP_SafeDecTop },
    { 0x39E9, opcode::OP_Invalid },
    { 0x39EA, opcode::OP_GetWorld },
    { 0x39EB, opcode::OP_GetInteger },
    { 0x39EC, opcode::OP_GetSelfObject },
    { 0x39ED, opcode::OP_Invalid },
    { 0x39EE, opcode::OP_Invalid },
    { 0x39EF, opcode::OP_Notify },
    { 0x39F0, opcode::OP_ScriptFunctionCallPointer },
    { 0x39F1, opcode::OP_Invalid },
    { 0x39F2, opcode::OP_EvalFieldVariableRef },
    { 0x39F3, opcode::OP_GreaterThan },
    { 0x39F4, opcode::OP_Invalid },
    { 0x39F5, opcode::OP_GetAnimObject },
    { 0x39F6, opcode::OP_GetAnimation },
    { 0x39F7, opcode::OP_Plus },
    { 0x39F8, opcode::OP_Invalid },
    { 0x39F9, opcode::OP_Invalid },
    { 0x39FA, opcode::OP_GetWorldObject },
    { 0x39FB, opcode::OP_Invalid },
    { 0x39FC, opcode::OP_GetClasses },
    { 0x39FD, opcode::OP_Notify },
    { 0x39FE, opcode::OP_NextArrayKey },
    { 0x39FF, opcode::OP_SuperEqual },
    { 0x3A00, opcode::OP_GetNegUnsignedShort },
    { 0x3A01, opcode::OP_Invalid },
    { 0x3A02, opcode::OP_EndOn },
    { 0x3A03, opcode::OP_IsDefined },
    { 0x3A04, opcode::OP_EndSwitch },
    { 0x3A05, opcode::OP_SelfEvalFieldVariableRef },
    { 0x3A06, opcode::OP_Invalid },
    { 0x3A07, opcode::OP_Invalid },
    { 0x3A08, opcode::OP_EmptyArray },
    { 0x3A09, opcode::OP_Invalid },
    { 0x3A0A, opcode::OP_Invalid },
    { 0x3A0B, opcode::OP_LevelEvalFieldVariable },
    { 0x3A0C, opcode::OP_Invalid },
    { 0x3A0D, opcode::OP_GetAnimObject },
    { 0x3A0E, opcode::OP_GetClassesObject },
    { 0x3A0F, opcode::OP_Bit_Or },
    { 0x3A10, opcode::OP_Equal },
    { 0x3A11, opcode::OP_GetUnsignedShort },
    { 0x3A12, opcode::OP_ClearArray },
    { 0x3A13, opcode::OP_GetVector },
    { 0x3A14, opcode::OP_New },
    { 0x3A15, opcode::OP_GetGameRef },
    { 0x3A16, opcode::OP_GetLevelObject },
    { 0x3A17, opcode::OP_SetVariableField },
    { 0x3A18, opcode::OP_Bit_And },
    { 0x3A19, opcode::OP_Invalid },
    { 0x3A1A, opcode::OP_SizeOf },
    { 0x3A1B, opcode::OP_DevblockBegin },
    { 0x3A1C, opcode::OP_BoolNot },
    { 0x3A1D, opcode::OP_Invalid },
    { 0x3A1E, opcode::OP_Divide },
    { 0x3A1F, opcode::OP_GetZero },
    { 0x3A20, opcode::OP_Invalid },
    { 0x3A21, opcode::OP_Invalid },
    { 0x3A22, opcode::OP_ClearFieldVariable },
    { 0x3A23, opcode::OP_EvalFieldVariable },
    { 0x3A24, opcode::OP_Invalid },
    { 0x3A25, opcode::OP_SafeSetVariableFieldCached },
    { 0x3A26, opcode::OP_Minus },
    { 0x3A27, opcode::OP_Bit_Xor },
    { 0x3A28, opcode::OP_JumpOnTrue },
    { 0x3A29, opcode::OP_NextArrayKey },
    { 0x3A2A, opcode::OP_EvalFieldVariableRef },
    { 0x3A2B, opcode::OP_IsDefined },
    { 0x3A2C, opcode::OP_New },
    { 0x3A2D, opcode::OP_GetLevel },
    { 0x3A2E, opcode::OP_ScriptFunctionCallClass },
    { 0x3A2F, opcode::OP_Invalid },
    { 0x3A30, opcode::OP_Inc },
    { 0x3A31, opcode::OP_GetNegByte },
    { 0x3A32, opcode::OP_LessThanOrEqualTo },
    { 0x3A33, opcode::OP_ClearArray },
    { 0x3A34, opcode::OP_New },
    { 0x3A35, opcode::OP_EvalFieldVariable },
    { 0x3A36, opcode::OP_GetUndefined },
    { 0x3A37, opcode::OP_Invalid },
    { 0x3A38, opcode::OP_LevelEvalFieldVariable },
    { 0x3A39, opcode::OP_NextArrayKey },
    { 0x3A3A, opcode::OP_ScriptThreadCallClass },
    { 0x3A3B, opcode::OP_GetUnsignedShort },
    { 0x3A3C, opcode::OP_Invalid },
    { 0x3A3D, opcode::OP_ShiftLeft },
    { 0x3A3E, opcode::OP_Bit_Or },
    { 0x3A3F, opcode::OP_GetGameRef },
    { 0x3A40, opcode::OP_Invalid },
    { 0x3A41, opcode::OP_LessThan },
    { 0x3A42, opcode::OP_BoolComplement },
    { 0x3A43, opcode::OP_Invalid },
    { 0x3A44, opcode::OP_Bit_Or },
    { 0x3A45, opcode::OP_Invalid },
    { 0x3A46, opcode::OP_Invalid },
    { 0x3A47, opcode::OP_Invalid },
    { 0x3A48, opcode::OP_Jump },
    { 0x3A49, opcode::OP_Invalid },
    { 0x3A4A, opcode::OP_Modulus },
    { 0x3A4B, opcode::OP_Invalid },
    { 0x3A4C, opcode::OP_GetWorld },
    { 0x3A4D, opcode::OP_LessThan },
    { 0x3A4E, opcode::OP_GetGameRef },
    { 0x3A4F, opcode::OP_Multiply },
    { 0x3A50, opcode::OP_Invalid },
    { 0x3A51, opcode::OP_WaitTillMatch },
    { 0x3A52, opcode::OP_Invalid },
    { 0x3A53, opcode::OP_Invalid },
    { 0x3A54, opcode::OP_GetWorld },
    { 0x3A55, opcode::OP_Invalid },
    { 0x3A56, opcode::OP_WaitTillMatch },
    { 0x3A57, opcode::OP_Invalid },
    { 0x3A58, opcode::OP_NextArrayKey },
    { 0x3A59, opcode::OP_ScriptThreadCallPointer },
    { 0x3A5A, opcode::OP_Invalid },
    { 0x3A5B, opcode::OP_GetLevel },
    { 0x3A5C, opcode::OP_Invalid },
    { 0x3A5D, opcode::OP_EndSwitch },
    { 0x3A5E, opcode::OP_Invalid },
    { 0x3A5F, opcode::OP_LessThan },
    { 0x3A60, opcode::OP_ProfileStart },
    { 0x3A61, opcode::OP_Invalid },
    { 0x3A62, opcode::OP_EndOn },
    { 0x3A63, opcode::OP_CallBuiltinMethod },
    { 0x3A64, opcode::OP_Jump },
    { 0x3A65, opcode::OP_GetClassesObject },
    { 0x3A66, opcode::OP_Notify },
    { 0x3A67, opcode::OP_WaitTillMatch },
    { 0x3A68, opcode::OP_Invalid },
    { 0x3A69, opcode::OP_Invalid },
    { 0x3A6A, opcode::OP_Invalid },
    { 0x3A6B, opcode::OP_JumpOnTrue },
    { 0x3A6C, opcode::OP_VectorScale },
    { 0x3A6D, opcode::OP_GetIString },
    { 0x3A6E, opcode::OP_Bit_Or },
    { 0x3A6F, opcode::OP_SelfEvalFieldVariable },
    { 0x3A70, opcode::OP_GetAnimObject },
    { 0x3A71, opcode::OP_GetWorld },
    { 0x3A72, opcode::OP_EvalFieldVariable },
    { 0x3A73, opcode::OP_RealWait },
    { 0x3A74, opcode::OP_ScriptFunctionCallPointer },
    { 0x3A75, opcode::OP_Invalid },
    { 0x3A76, opcode::OP_Invalid },
    { 0x3A77, opcode::OP_Invalid },
    { 0x3A78, opcode::OP_Invalid },
    { 0x3A79, opcode::OP_JumpOnFalse },
    { 0x3A7A, opcode::OP_Invalid },
    { 0x3A7B, opcode::OP_SetVariableField },
    { 0x3A7C, opcode::OP_Invalid },
    { 0x3A7D, opcode::OP_Invalid },
    { 0x3A7E, opcode::OP_GetNegUnsignedShort },
    { 0x3A7F, opcode::OP_VectorConstant },
    { 0x3A80, opcode::OP_Wait },
    { 0x3A81, opcode::OP_Inc },
    { 0x3A82, opcode::OP_LessThan },
    { 0x3A83, opcode::OP_GetAPIFunction },
    { 0x3A84, opcode::OP_GetUintptr },
    { 0x3A85, opcode::OP_Invalid },
    { 0x3A86, opcode::OP_GetSelfObject },
    { 0x3A87, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x3A88, opcode::OP_GreaterThan },
    { 0x3A89, opcode::OP_Invalid },
    { 0x3A8A, opcode::OP_Invalid },
    { 0x3A8B, opcode::OP_WaitTillFrameEnd },
    { 0x3A8C, opcode::OP_Invalid },
    { 0x3A8D, opcode::OP_WaitTill },
    { 0x3A8E, opcode::OP_Bit_Xor },
    { 0x3A8F, opcode::OP_Invalid },
    { 0x3A90, opcode::OP_Invalid },
    { 0x3A91, opcode::OP_GetClassesObject },
    { 0x3A92, opcode::OP_Wait },
    { 0x3A93, opcode::OP_WaitTillFrameEnd },
    { 0x3A94, opcode::OP_GetFloat },
    { 0x3A95, opcode::OP_CastBool },
    { 0x3A96, opcode::OP_SafeDecTop },
    { 0x3A97, opcode::OP_Invalid },
    { 0x3A98, opcode::OP_GetVector },
    { 0x3A99, opcode::OP_GetAnimObject },
    { 0x3A9A, opcode::OP_Minus },
    { 0x3A9B, opcode::OP_Invalid },
    { 0x3A9C, opcode::OP_ScriptFunctionCallClass },
    { 0x3A9D, opcode::OP_Invalid },
    { 0x3A9E, opcode::OP_Invalid },
    { 0x3A9F, opcode::OP_JumpOnTrue },
    { 0x3AA0, opcode::OP_Invalid },
    { 0x3AA1, opcode::OP_Invalid },
    { 0x3AA2, opcode::OP_SafeDecTop },
    { 0x3AA3, opcode::OP_SizeOf },
    { 0x3AA4, opcode::OP_Invalid },
    { 0x3AA5, opcode::OP_Invalid },
    { 0x3AA6, opcode::OP_Dec },
    { 0x3AA7, opcode::OP_GetString },
    { 0x3AA8, opcode::OP_EvalFieldVariableRef },
    { 0x3AA9, opcode::OP_SuperNotEqual },
    { 0x3AAA, opcode::OP_Return },
    { 0x3AAB, opcode::OP_Invalid },
    { 0x3AAC, opcode::OP_Invalid },
    { 0x3AAD, opcode::OP_GreaterThan },
    { 0x3AAE, opcode::OP_EmptyArray },
    { 0x3AAF, opcode::OP_Invalid },
    { 0x3AB0, opcode::OP_DevblockBegin },
    { 0x3AB1, opcode::OP_Notify },
    { 0x3AB2, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x3AB3, opcode::OP_GreaterThan },
    { 0x3AB4, opcode::OP_VectorScale },
    { 0x3AB5, opcode::OP_Invalid },
    { 0x3AB6, opcode::OP_Invalid },
    { 0x3AB7, opcode::OP_GetAnimObject },
    { 0x3AB8, opcode::OP_Invalid },
    { 0x3AB9, opcode::OP_ShiftLeft },
    { 0x3ABA, opcode::OP_LessThan },
    { 0x3ABB, opcode::OP_Invalid },
    { 0x3ABC, opcode::OP_Invalid },
    { 0x3ABD, opcode::OP_Invalid },
    { 0x3ABE, opcode::OP_SelfEvalFieldVariable },
    { 0x3ABF, opcode::OP_Invalid },
    { 0x3AC0, opcode::OP_Invalid },
    { 0x3AC1, opcode::OP_GetHash },
    { 0x3AC2, opcode::OP_Plus },
    { 0x3AC3, opcode::OP_ScriptMethodCallPointer },
    { 0x3AC4, opcode::OP_IsDefined },
    { 0x3AC5, opcode::OP_WaitTillFrameEnd },
    { 0x3AC6, opcode::OP_NextArrayKey },
    { 0x3AC7, opcode::OP_Invalid },
    { 0x3AC8, opcode::OP_Bit_Xor },
    { 0x3AC9, opcode::OP_Bit_Xor },
    { 0x3ACA, opcode::OP_ScriptMethodCall },
    { 0x3ACB, opcode::OP_EndOn },
    { 0x3ACC, opcode::OP_Invalid },
    { 0x3ACD, opcode::OP_Invalid },
    { 0x3ACE, opcode::OP_GetSelf },
    { 0x3ACF, opcode::OP_Return },
    { 0x3AD0, opcode::OP_GetUnsignedShort },
    { 0x3AD1, opcode::OP_Minus },
    { 0x3AD2, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x3AD3, opcode::OP_GetZero },
    { 0x3AD4, opcode::OP_SafeDecTop },
    { 0x3AD5, opcode::OP_Invalid },
    { 0x3AD6, opcode::OP_Invalid },
    { 0x3AD7, opcode::OP_GetClassesObject },
    { 0x3AD8, opcode::OP_GetHash },
    { 0x3AD9, opcode::OP_Invalid },
    { 0x3ADA, opcode::OP_Invalid },
    { 0x3ADB, opcode::OP_New },
    { 0x3ADC, opcode::OP_EvalArray },
    { 0x3ADD, opcode::OP_Invalid },
    { 0x3ADE, opcode::OP_GetWorld },
    { 0x3ADF, opcode::OP_EndOn },
    { 0x3AE0, opcode::OP_Jump },
    { 0x3AE1, opcode::OP_Invalid },
    { 0x3AE2, opcode::OP_Return },
    { 0x3AE3, opcode::OP_Plus },
    { 0x3AE4, opcode::OP_Invalid },
    { 0x3AE5, opcode::OP_Invalid },
    { 0x3AE6, opcode::OP_SuperNotEqual },
    { 0x3AE7, opcode::OP_Invalid },
    { 0x3AE8, opcode::OP_WaitTillMatch },
    { 0x3AE9, opcode::OP_NextArrayKey },
    { 0x3AEA, opcode::OP_New },
    { 0x3AEB, opcode::OP_Notify },
    { 0x3AEC, opcode::OP_Invalid },
    { 0x3AED, opcode::OP_Invalid },
    { 0x3AEE, opcode::OP_NotEqual },
    { 0x3AEF, opcode::OP_JumpOnTrue },
    { 0x3AF0, opcode::OP_GetSelfObject },
    { 0x3AF1, opcode::OP_Switch },
    { 0x3AF2, opcode::OP_LevelEvalFieldVariableRef },
    { 0x3AF3, opcode::OP_Invalid },
    { 0x3AF4, opcode::OP_Invalid },
    { 0x3AF5, opcode::OP_ProfileStart },
    { 0x3AF6, opcode::OP_SafeCreateLocalVariables },
    { 0x3AF7, opcode::OP_GetHash },
    { 0x3AF8, opcode::OP_Invalid },
    { 0x3AF9, opcode::OP_GetFloat },
    { 0x3AFA, opcode::OP_Return },
    { 0x3AFB, opcode::OP_ScriptFunctionCallClass },
    { 0x3AFC, opcode::OP_Invalid },
    { 0x3AFD, opcode::OP_Invalid },
    { 0x3AFE, opcode::OP_Invalid },
    { 0x3AFF, opcode::OP_ShiftLeft },
    { 0x3B00, opcode::OP_SizeOf },
    { 0x3B01, opcode::OP_SelfEvalFieldVariableRef },
    { 0x3B02, opcode::OP_LessThanOrEqualTo },
    { 0x3B03, opcode::OP_Invalid },
    { 0x3B04, opcode::OP_Invalid },
    { 0x3B05, opcode::OP_BoolComplement },
    { 0x3B06, opcode::OP_EmptyArray },
    { 0x3B07, opcode::OP_Invalid },
    { 0x3B08, opcode::OP_EvalArray },
    { 0x3B09, opcode::OP_EvalLocalVariableCached },
    { 0x3B0A, opcode::OP_BoolNot },
    { 0x3B0B, opcode::OP_ShiftRight },
    { 0x3B0C, opcode::OP_GetFloat },
    { 0x3B0D, opcode::OP_Invalid },
    { 0x3B0E, opcode::OP_Invalid },
    { 0x3B0F, opcode::OP_LessThanOrEqualTo },
    { 0x3B10, opcode::OP_Modulus },
    { 0x3B11, opcode::OP_GetWorld },
    { 0x3B12, opcode::OP_ScriptMethodCall },
    { 0x3B13, opcode::OP_GetZero },
    { 0x3B14, opcode::OP_Invalid },
    { 0x3B15, opcode::OP_ScriptMethodThreadCall },
    { 0x3B16, opcode::OP_Dec },
    { 0x3B17, opcode::OP_GetVector },
    { 0x3B18, opcode::OP_Equal },
    { 0x3B19, opcode::OP_Invalid },
    { 0x3B1A, opcode::OP_ShiftLeft },
    { 0x3B1B, opcode::OP_ClearArray },
    { 0x3B1C, opcode::OP_LevelEvalFieldVariableRef },
    { 0x3B1D, opcode::OP_GetAnimObject },
    { 0x3B1E, opcode::OP_Invalid },
    { 0x3B1F, opcode::OP_SetVariableField },
    { 0x3B20, opcode::OP_SafeDecTop },
    { 0x3B21, opcode::OP_SelfEvalFieldVariableRef },
    { 0x3B22, opcode::OP_WaitTillFrameEnd },
    { 0x3B23, opcode::OP_EvalArrayRef },
    { 0x3B24, opcode::OP_GetAnim },
    { 0x3B25, opcode::OP_GetClassesObject },
    { 0x3B26, opcode::OP_RealWait },
    { 0x3B27, opcode::OP_GetLevelObject },
    { 0x3B28, opcode::OP_Invalid },
    { 0x3B29, opcode::OP_Invalid },
    { 0x3B2A, opcode::OP_Invalid },
    { 0x3B2B, opcode::OP_Invalid },
    { 0x3B2C, opcode::OP_ScriptMethodCall },
    { 0x3B2D, opcode::OP_GetGame },
    { 0x3B2E, opcode::OP_WaitTill },
    { 0x3B2F, opcode::OP_Notify },
    { 0x3B30, opcode::OP_ClearArray },
    { 0x3B31, opcode::OP_DecTop },
    { 0x3B32, opcode::OP_Invalid },
    { 0x3B33, opcode::OP_JumpOnTrueExpr },
    { 0x3B34, opcode::OP_Plus },
    { 0x3B35, opcode::OP_GetLevelObject },
    { 0x3B36, opcode::OP_ClearFieldVariable },
    { 0x3B37, opcode::OP_ScriptMethodThreadCall },
    { 0x3B38, opcode::OP_GetTime },
    { 0x3B39, opcode::OP_EndSwitch },
    { 0x3B3A, opcode::OP_Invalid },
    { 0x3B3B, opcode::OP_GetLevel },
    { 0x3B3C, opcode::OP_SafeSetVariableFieldCached },
    { 0x3B3D, opcode::OP_WaitTill },
    { 0x3B3E, opcode::OP_Dec },
    { 0x3B3F, opcode::OP_VectorScale },
    { 0x3B40, opcode::OP_JumpOnTrue },
    { 0x3B41, opcode::OP_Invalid },
    { 0x3B42, opcode::OP_GetWorld },
    { 0x3B43, opcode::OP_GetNegUnsignedShort },
    { 0x3B44, opcode::OP_Invalid },
    { 0x3B45, opcode::OP_EvalArray },
    { 0x3B46, opcode::OP_Invalid },
    { 0x3B47, opcode::OP_ScriptThreadCall },
    { 0x3B48, opcode::OP_LevelEvalFieldVariable },
    { 0x3B49, opcode::OP_GetAnim },
    { 0x3B4A, opcode::OP_GetByte },
    { 0x3B4B, opcode::OP_Invalid },
    { 0x3B4C, opcode::OP_GetUndefined },
    { 0x3B4D, opcode::OP_JumpOnTrueExpr },
    { 0x3B4E, opcode::OP_EndSwitch },
    { 0x3B4F, opcode::OP_Invalid },
    { 0x3B50, opcode::OP_Invalid },
    { 0x3B51, opcode::OP_Invalid },
    { 0x3B52, opcode::OP_Return },
    { 0x3B53, opcode::OP_Invalid },
    { 0x3B54, opcode::OP_Invalid },
    { 0x3B55, opcode::OP_Invalid },
    { 0x3B56, opcode::OP_Invalid },
    { 0x3B57, opcode::OP_Invalid },
    { 0x3B58, opcode::OP_Invalid },
    { 0x3B59, opcode::OP_Invalid },
    { 0x3B5A, opcode::OP_GetLevel },
    { 0x3B5B, opcode::OP_GetFunction },
    { 0x3B5C, opcode::OP_LevelEvalFieldVariableRef },
    { 0x3B5D, opcode::OP_ProfileStart },
    { 0x3B5E, opcode::OP_Minus },
    { 0x3B5F, opcode::OP_GetIString },
    { 0x3B60, opcode::OP_Invalid },
    { 0x3B61, opcode::OP_GetAPIFunction },
    { 0x3B62, opcode::OP_Invalid },
    { 0x3B63, opcode::OP_JumpOnTrue },
    { 0x3B64, opcode::OP_FirstArrayKey },
    { 0x3B65, opcode::OP_ProfileStart },
    { 0x3B66, opcode::OP_GetVector },
    { 0x3B67, opcode::OP_GetVector },
    { 0x3B68, opcode::OP_Invalid },
    { 0x3B69, opcode::OP_Invalid },
    { 0x3B6A, opcode::OP_Switch },
    { 0x3B6B, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x3B6C, opcode::OP_Invalid },
    { 0x3B6D, opcode::OP_GetString },
    { 0x3B6E, opcode::OP_SizeOf },
    { 0x3B6F, opcode::OP_EvalLocalVariableRefCached },
    { 0x3B70, opcode::OP_CastFieldObject },
    { 0x3B71, opcode::OP_Invalid },
    { 0x3B72, opcode::OP_SelfEvalFieldVariableRef },
    { 0x3B73, opcode::OP_IsDefined },
    { 0x3B74, opcode::OP_SelfEvalFieldVariableRef },
    { 0x3B75, opcode::OP_GetAnimation },
    { 0x3B76, opcode::OP_GetAnim },
    { 0x3B77, opcode::OP_Invalid },
    { 0x3B78, opcode::OP_Invalid },
    { 0x3B79, opcode::OP_Jump },
    { 0x3B7A, opcode::OP_CastFieldObject },
    { 0x3B7B, opcode::OP_EvalLocalVariableCached },
    { 0x3B7C, opcode::OP_Invalid },
    { 0x3B7D, opcode::OP_GetAnimation },
    { 0x3B7E, opcode::OP_Invalid },
    { 0x3B7F, opcode::OP_GetGame },
    { 0x3B80, opcode::OP_GetInteger },
    { 0x3B81, opcode::OP_Invalid },
    { 0x3B82, opcode::OP_Invalid },
    { 0x3B83, opcode::OP_ClearFieldVariable },
    { 0x3B84, opcode::OP_Invalid },
    { 0x3B85, opcode::OP_Jump },
    { 0x3B86, opcode::OP_EndOn },
    { 0x3B87, opcode::OP_Invalid },
    { 0x3B88, opcode::OP_Invalid },
    { 0x3B89, opcode::OP_Inc },
    { 0x3B8A, opcode::OP_EmptyArray },
    { 0x3B8B, opcode::OP_Invalid },
    { 0x3B8C, opcode::OP_Invalid },
    { 0x3B8D, opcode::OP_ClearFieldVariable },
    { 0x3B8E, opcode::OP_GetSelf },
    { 0x3B8F, opcode::OP_ScriptFunctionCall },
    { 0x3B90, opcode::OP_ShiftRight },
    { 0x3B91, opcode::OP_GetTime },
    { 0x3B92, opcode::OP_SafeSetVariableFieldCached },
    { 0x3B93, opcode::OP_Invalid },
    { 0x3B94, opcode::OP_Invalid },
    { 0x3B95, opcode::OP_SafeSetVariableFieldCached },
    { 0x3B96, opcode::OP_BoolComplement },
    { 0x3B97, opcode::OP_EvalFieldVariable },
    { 0x3B98, opcode::OP_BoolNot },
    { 0x3B99, opcode::OP_Invalid },
    { 0x3B9A, opcode::OP_DevblockBegin },
    { 0x3B9B, opcode::OP_Bit_And },
    { 0x3B9C, opcode::OP_EvalFieldVariable },
    { 0x3B9D, opcode::OP_EndOn },
    { 0x3B9E, opcode::OP_JumpOnFalse },
    { 0x3B9F, opcode::OP_Invalid },
    { 0x3BA0, opcode::OP_JumpOnTrueExpr },
    { 0x3BA1, opcode::OP_GetGameRef },
    { 0x3BA2, opcode::OP_Invalid },
    { 0x3BA3, opcode::OP_Invalid },
    { 0x3BA4, opcode::OP_GetFloat },
    { 0x3BA5, opcode::OP_GetFunction },
    { 0x3BA6, opcode::OP_Invalid },
    { 0x3BA7, opcode::OP_ProfileStop },
    { 0x3BA8, opcode::OP_Invalid },
    { 0x3BA9, opcode::OP_Switch },
    { 0x3BAA, opcode::OP_Invalid },
    { 0x3BAB, opcode::OP_CallBuiltinMethod },
    { 0x3BAC, opcode::OP_Invalid },
    { 0x3BAD, opcode::OP_Invalid },
    { 0x3BAE, opcode::OP_EmptyArray },
    { 0x3BAF, opcode::OP_GetAnimation },
    { 0x3BB0, opcode::OP_JumpOnTrue },
    { 0x3BB1, opcode::OP_ScriptMethodThreadCall },
    { 0x3BB2, opcode::OP_Multiply },
    { 0x3BB3, opcode::OP_Invalid },
    { 0x3BB4, opcode::OP_SafeCreateLocalVariables },
    { 0x3BB5, opcode::OP_Invalid },
    { 0x3BB6, opcode::OP_GetAnimObject },
    { 0x3BB7, opcode::OP_SuperEqual },
    { 0x3BB8, opcode::OP_GetWorldObject },
    { 0x3BB9, opcode::OP_LessThan },
    { 0x3BBA, opcode::OP_Equal },
    { 0x3BBB, opcode::OP_GetLevelObject },
    { 0x3BBC, opcode::OP_CallBuiltinMethod },
    { 0x3BBD, opcode::OP_GetSelfObject },
    { 0x3BBE, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x3BBF, opcode::OP_GetByte },
    { 0x3BC0, opcode::OP_Invalid },
    { 0x3BC1, opcode::OP_Invalid },
    { 0x3BC2, opcode::OP_Invalid },
    { 0x3BC3, opcode::OP_Invalid },
    { 0x3BC4, opcode::OP_Invalid },
    { 0x3BC5, opcode::OP_Invalid },
    { 0x3BC6, opcode::OP_Invalid },
    { 0x3BC7, opcode::OP_Invalid },
    { 0x3BC8, opcode::OP_Invalid },
    { 0x3BC9, opcode::OP_Invalid },
    { 0x3BCA, opcode::OP_ClearFieldVariable },
    { 0x3BCB, opcode::OP_ScriptMethodCallPointer },
    { 0x3BCC, opcode::OP_Minus },
    { 0x3BCD, opcode::OP_CallBuiltinMethod },
    { 0x3BCE, opcode::OP_JumpOnTrue },
    { 0x3BCF, opcode::OP_JumpOnFalse },
    { 0x3BD0, opcode::OP_LevelEvalFieldVariable },
    { 0x3BD1, opcode::OP_GetFloat },
    { 0x3BD2, opcode::OP_Invalid },
    { 0x3BD3, opcode::OP_Invalid },
    { 0x3BD4, opcode::OP_VectorConstant },
    { 0x3BD5, opcode::OP_Invalid },
    { 0x3BD6, opcode::OP_LevelEvalFieldVariable },
    { 0x3BD7, opcode::OP_GetAPIFunction },
    { 0x3BD8, opcode::OP_EmptyArray },
    { 0x3BD9, opcode::OP_SelfEvalFieldVariable },
    { 0x3BDA, opcode::OP_LevelEvalFieldVariable },
    { 0x3BDB, opcode::OP_GetUndefined },
    { 0x3BDC, opcode::OP_GetLevel },
    { 0x3BDD, opcode::OP_GetUndefined },
    { 0x3BDE, opcode::OP_ClearArray },
    { 0x3BDF, opcode::OP_SuperEqual },
    { 0x3BE0, opcode::OP_Invalid },
    { 0x3BE1, opcode::OP_Invalid },
    { 0x3BE2, opcode::OP_Invalid },
    { 0x3BE3, opcode::OP_ShiftLeft },
    { 0x3BE4, opcode::OP_EvalLocalVariableRefCached },
    { 0x3BE5, opcode::OP_GetClassesObject },
    { 0x3BE6, opcode::OP_Invalid },
    { 0x3BE7, opcode::OP_JumpOnTrue },
    { 0x3BE8, opcode::OP_Invalid },
    { 0x3BE9, opcode::OP_GetFloat },
    { 0x3BEA, opcode::OP_GetSelf },
    { 0x3BEB, opcode::OP_EvalArray },
    { 0x3BEC, opcode::OP_Invalid },
    { 0x3BED, opcode::OP_EmptyArray },
    { 0x3BEE, opcode::OP_GetHash },
    { 0x3BEF, opcode::OP_Invalid },
    { 0x3BF0, opcode::OP_JumpOnFalseExpr },
    { 0x3BF1, opcode::OP_Invalid },
    { 0x3BF2, opcode::OP_GetLevel },
    { 0x3BF3, opcode::OP_ScriptThreadCallPointer },
    { 0x3BF4, opcode::OP_Invalid },
    { 0x3BF5, opcode::OP_Invalid },
    { 0x3BF6, opcode::OP_Invalid },
    { 0x3BF7, opcode::OP_Invalid },
    { 0x3BF8, opcode::OP_Invalid },
    { 0x3BF9, opcode::OP_Invalid },
    { 0x3BFA, opcode::OP_Bit_Xor },
    { 0x3BFB, opcode::OP_Invalid },
    { 0x3BFC, opcode::OP_GetAnimation },
    { 0x3BFD, opcode::OP_Invalid },
    { 0x3BFE, opcode::OP_EvalLocalVariableCached },
    { 0x3BFF, opcode::OP_EvalLocalVariableCached },
    { 0x3C00, opcode::OP_Invalid },
    { 0x3C01, opcode::OP_DecTop },
    { 0x3C02, opcode::OP_EvalFieldVariable },
    { 0x3C03, opcode::OP_Invalid },
    { 0x3C04, opcode::OP_GetSelf },
    { 0x3C05, opcode::OP_WaitTill },
    { 0x3C06, opcode::OP_Invalid },
    { 0x3C07, opcode::OP_Invalid },
    { 0x3C08, opcode::OP_Minus },
    { 0x3C09, opcode::OP_ScriptThreadCallClass },
    { 0x3C0A, opcode::OP_Invalid },
    { 0x3C0B, opcode::OP_GetByte },
    { 0x3C0C, opcode::OP_GetVector },
    { 0x3C0D, opcode::OP_Invalid },
    { 0x3C0E, opcode::OP_RealWait },
    { 0x3C0F, opcode::OP_GetAPIFunction },
    { 0x3C10, opcode::OP_Minus },
    { 0x3C11, opcode::OP_Invalid },
    { 0x3C12, opcode::OP_NextArrayKey },
    { 0x3C13, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x3C14, opcode::OP_SelfEvalFieldVariable },
    { 0x3C15, opcode::OP_Invalid },
    { 0x3C16, opcode::OP_Bit_Xor },
    { 0x3C17, opcode::OP_EvalLocalVariableRefCached },
    { 0x3C18, opcode::OP_Invalid },
    { 0x3C19, opcode::OP_ShiftRight },
    { 0x3C1A, opcode::OP_SelfEvalFieldVariable },
    { 0x3C1B, opcode::OP_Invalid },
    { 0x3C1C, opcode::OP_Invalid },
    { 0x3C1D, opcode::OP_Invalid },
    { 0x3C1E, opcode::OP_NextArrayKey },
    { 0x3C1F, opcode::OP_ShiftLeft },
    { 0x3C20, opcode::OP_Invalid },
    { 0x3C21, opcode::OP_Notify },
    { 0x3C22, opcode::OP_JumpOnFalse },
    { 0x3C23, opcode::OP_LessThan },
    { 0x3C24, opcode::OP_EvalArray },
    { 0x3C25, opcode::OP_GetGameRef },
    { 0x3C26, opcode::OP_LevelEvalFieldVariable },
    { 0x3C27, opcode::OP_DecTop },
    { 0x3C28, opcode::OP_GetGame },
    { 0x3C29, opcode::OP_ScriptThreadCallPointer },
    { 0x3C2A, opcode::OP_NextArrayKey },
    { 0x3C2B, opcode::OP_Minus },
    { 0x3C2C, opcode::OP_SafeDecTop },
    { 0x3C2D, opcode::OP_GetUnsignedShort },
    { 0x3C2E, opcode::OP_Switch },
    { 0x3C2F, opcode::OP_Invalid },
    { 0x3C30, opcode::OP_GetString },
    { 0x3C31, opcode::OP_EvalArray },
    { 0x3C32, opcode::OP_GetFloat },
    { 0x3C33, opcode::OP_Switch },
    { 0x3C34, opcode::OP_Switch },
    { 0x3C35, opcode::OP_GetSelf },
    { 0x3C36, opcode::OP_NotEqual },
    { 0x3C37, opcode::OP_Invalid },
    { 0x3C38, opcode::OP_Vector },
    { 0x3C39, opcode::OP_Invalid },
    { 0x3C3A, opcode::OP_Minus },
    { 0x3C3B, opcode::OP_GetNegUnsignedShort },
    { 0x3C3C, opcode::OP_Invalid },
    { 0x3C3D, opcode::OP_GetSelfObject },
    { 0x3C3E, opcode::OP_Invalid },
    { 0x3C3F, opcode::OP_Inc },
    { 0x3C40, opcode::OP_Invalid },
    { 0x3C41, opcode::OP_GetAnim },
    { 0x3C42, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x3C43, opcode::OP_Divide },
    { 0x3C44, opcode::OP_Invalid },
    { 0x3C45, opcode::OP_GetUintptr },
    { 0x3C46, opcode::OP_Invalid },
    { 0x3C47, opcode::OP_EvalFieldVariableRef },
    { 0x3C48, opcode::OP_Invalid },
    { 0x3C49, opcode::OP_ProfileStart },
    { 0x3C4A, opcode::OP_Invalid },
    { 0x3C4B, opcode::OP_GetTime },
    { 0x3C4C, opcode::OP_Invalid },
    { 0x3C4D, opcode::OP_SafeSetVariableFieldCached },
    { 0x3C4E, opcode::OP_SuperNotEqual },
    { 0x3C4F, opcode::OP_GetInteger },
    { 0x3C50, opcode::OP_Invalid },
    { 0x3C51, opcode::OP_Invalid },
    { 0x3C52, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x3C53, opcode::OP_GetLevel },
    { 0x3C54, opcode::OP_Jump },
    { 0x3C55, opcode::OP_GetAnim },
    { 0x3C56, opcode::OP_Invalid },
    { 0x3C57, opcode::OP_Invalid },
    { 0x3C58, opcode::OP_Invalid },
    { 0x3C59, opcode::OP_GetSelfObject },
    { 0x3C5A, opcode::OP_Invalid },
    { 0x3C5B, opcode::OP_GetVector },
    { 0x3C5C, opcode::OP_GetWorldObject },
    { 0x3C5D, opcode::OP_Invalid },
    { 0x3C5E, opcode::OP_GetSelf },
    { 0x3C5F, opcode::OP_New },
    { 0x3C60, opcode::OP_Invalid },
    { 0x3C61, opcode::OP_Bit_Xor },
    { 0x3C62, opcode::OP_Invalid },
    { 0x3C63, opcode::OP_WaitTill },
    { 0x3C64, opcode::OP_BoolNot },
    { 0x3C65, opcode::OP_BoolComplement },
    { 0x3C66, opcode::OP_ScriptFunctionCallClass },
    { 0x3C67, opcode::OP_ScriptThreadCallPointer },
    { 0x3C68, opcode::OP_EmptyArray },
    { 0x3C69, opcode::OP_JumpOnFalseExpr },
    { 0x3C6A, opcode::OP_Notify },
    { 0x3C6B, opcode::OP_FirstArrayKey },
    { 0x3C6C, opcode::OP_Bit_Or },
    { 0x3C6D, opcode::OP_ScriptFunctionCallPointer },
    { 0x3C6E, opcode::OP_Invalid },
    { 0x3C6F, opcode::OP_GetZero },
    { 0x3C70, opcode::OP_EndSwitch },
    { 0x3C71, opcode::OP_Invalid },
    { 0x3C72, opcode::OP_Invalid },
    { 0x3C73, opcode::OP_EndOn },
    { 0x3C74, opcode::OP_VectorScale },
    { 0x3C75, opcode::OP_LevelEvalFieldVariable },
    { 0x3C76, opcode::OP_EvalLocalVariableCached },
    { 0x3C77, opcode::OP_Invalid },
    { 0x3C78, opcode::OP_BoolNot },
    { 0x3C79, opcode::OP_Invalid },
    { 0x3C7A, opcode::OP_GetIString },
    { 0x3C7B, opcode::OP_SizeOf },
    { 0x3C7C, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x3C7D, opcode::OP_Invalid },
    { 0x3C7E, opcode::OP_Invalid },
    { 0x3C7F, opcode::OP_Invalid },
    { 0x3C80, opcode::OP_Invalid },
    { 0x3C81, opcode::OP_LevelEvalFieldVariable },
    { 0x3C82, opcode::OP_Dec },
    { 0x3C83, opcode::OP_Multiply },
    { 0x3C84, opcode::OP_Invalid },
    { 0x3C85, opcode::OP_Invalid },
    { 0x3C86, opcode::OP_ClearFieldVariable },
    { 0x3C87, opcode::OP_WaitTillFrameEnd },
    { 0x3C88, opcode::OP_EvalLocalVariableCached },
    { 0x3C89, opcode::OP_VectorScale },
    { 0x3C8A, opcode::OP_EvalLocalVariableCached },
    { 0x3C8B, opcode::OP_Switch },
    { 0x3C8C, opcode::OP_Invalid },
    { 0x3C8D, opcode::OP_ScriptFunctionCallPointer },
    { 0x3C8E, opcode::OP_JumpOnTrueExpr },
    { 0x3C8F, opcode::OP_SelfEvalFieldVariable },
    { 0x3C90, opcode::OP_ScriptMethodCall },
    { 0x3C91, opcode::OP_Invalid },
    { 0x3C92, opcode::OP_Invalid },
    { 0x3C93, opcode::OP_EvalFieldVariable },
    { 0x3C94, opcode::OP_SafeSetVariableFieldCached },
    { 0x3C95, opcode::OP_Invalid },
    { 0x3C96, opcode::OP_Invalid },
    { 0x3C97, opcode::OP_Invalid },
    { 0x3C98, opcode::OP_JumpOnFalse },
    { 0x3C99, opcode::OP_EvalFieldVariable },
    { 0x3C9A, opcode::OP_LessThanOrEqualTo },
    { 0x3C9B, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x3C9C, opcode::OP_Invalid },
    { 0x3C9D, opcode::OP_Invalid },
    { 0x3C9E, opcode::OP_ScriptFunctionCallClass },
    { 0x3C9F, opcode::OP_Invalid },
    { 0x3CA0, opcode::OP_ClearArray },
    { 0x3CA1, opcode::OP_GetVector },
    { 0x3CA2, opcode::OP_New },
    { 0x3CA3, opcode::OP_Invalid },
    { 0x3CA4, opcode::OP_GetInteger },
    { 0x3CA5, opcode::OP_Invalid },
    { 0x3CA6, opcode::OP_Plus },
    { 0x3CA7, opcode::OP_GetAnim },
    { 0x3CA8, opcode::OP_Invalid },
    { 0x3CA9, opcode::OP_Return },
    { 0x3CAA, opcode::OP_GetIString },
    { 0x3CAB, opcode::OP_Multiply },
    { 0x3CAC, opcode::OP_GetUndefined },
    { 0x3CAD, opcode::OP_WaitTillFrameEnd },
    { 0x3CAE, opcode::OP_SetVariableField },
    { 0x3CAF, opcode::OP_Invalid },
    { 0x3CB0, opcode::OP_ClearFieldVariable },
    { 0x3CB1, opcode::OP_LessThanOrEqualTo },
    { 0x3CB2, opcode::OP_ClearArray },
    { 0x3CB3, opcode::OP_Invalid },
    { 0x3CB4, opcode::OP_Multiply },
    { 0x3CB5, opcode::OP_GetClassesObject },
    { 0x3CB6, opcode::OP_GetTime },
    { 0x3CB7, opcode::OP_Invalid },
    { 0x3CB8, opcode::OP_GetGame },
    { 0x3CB9, opcode::OP_NextArrayKey },
    { 0x3CBA, opcode::OP_GetUnsignedShort },
    { 0x3CBB, opcode::OP_Invalid },
    { 0x3CBC, opcode::OP_GetAnim },
    { 0x3CBD, opcode::OP_Switch },
    { 0x3CBE, opcode::OP_Invalid },
    { 0x3CBF, opcode::OP_GetSelf },
    { 0x3CC0, opcode::OP_ShiftRight },
    { 0x3CC1, opcode::OP_CastFieldObject },
    { 0x3CC2, opcode::OP_Multiply },
    { 0x3CC3, opcode::OP_WaitTillMatch },
    { 0x3CC4, opcode::OP_Invalid },
    { 0x3CC5, opcode::OP_Invalid },
    { 0x3CC6, opcode::OP_Return },
    { 0x3CC7, opcode::OP_Invalid },
    { 0x3CC8, opcode::OP_Multiply },
    { 0x3CC9, opcode::OP_GetUndefined },
    { 0x3CCA, opcode::OP_Modulus },
    { 0x3CCB, opcode::OP_BoolComplement },
    { 0x3CCC, opcode::OP_GetAPIFunction },
    { 0x3CCD, opcode::OP_SafeSetVariableFieldCached },
    { 0x3CCE, opcode::OP_Invalid },
    { 0x3CCF, opcode::OP_GetFloat },
    { 0x3CD0, opcode::OP_GetLevel },
    { 0x3CD1, opcode::OP_EvalLocalVariableRefCached },
    { 0x3CD2, opcode::OP_Invalid },
    { 0x3CD3, opcode::OP_ScriptMethodCallPointer },
    { 0x3CD4, opcode::OP_CastFieldObject },
    { 0x3CD5, opcode::OP_GetWorldObject },
    { 0x3CD6, opcode::OP_Invalid },
    { 0x3CD7, opcode::OP_Invalid },
    { 0x3CD8, opcode::OP_GetAnim },
    { 0x3CD9, opcode::OP_Invalid },
    { 0x3CDA, opcode::OP_Invalid },
    { 0x3CDB, opcode::OP_GreaterThan },
    { 0x3CDC, opcode::OP_GetFunction },
    { 0x3CDD, opcode::OP_Invalid },
    { 0x3CDE, opcode::OP_GetFloat },
    { 0x3CDF, opcode::OP_Invalid },
    { 0x3CE0, opcode::OP_Invalid },
    { 0x3CE1, opcode::OP_ScriptThreadCallClass },
    { 0x3CE2, opcode::OP_EvalLocalVariableRefCached },
    { 0x3CE3, opcode::OP_Invalid },
    { 0x3CE4, opcode::OP_ScriptFunctionCall },
    { 0x3CE5, opcode::OP_GetZero },
    { 0x3CE6, opcode::OP_Invalid },
    { 0x3CE7, opcode::OP_GetSelf },
    { 0x3CE8, opcode::OP_FirstArrayKey },
    { 0x3CE9, opcode::OP_EvalArray },
    { 0x3CEA, opcode::OP_Invalid },
    { 0x3CEB, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x3CEC, opcode::OP_Switch },
    { 0x3CED, opcode::OP_JumpOnFalse },
    { 0x3CEE, opcode::OP_Invalid },
    { 0x3CEF, opcode::OP_Invalid },
    { 0x3CF0, opcode::OP_GetNegUnsignedShort },
    { 0x3CF1, opcode::OP_Invalid },
    { 0x3CF2, opcode::OP_Invalid },
    { 0x3CF3, opcode::OP_WaitTill },
    { 0x3CF4, opcode::OP_Invalid },
    { 0x3CF5, opcode::OP_GetUndefined },
    { 0x3CF6, opcode::OP_RealWait },
    { 0x3CF7, opcode::OP_JumpOnFalseExpr },
    { 0x3CF8, opcode::OP_Invalid },
    { 0x3CF9, opcode::OP_GetSelfObject },
    { 0x3CFA, opcode::OP_ScriptThreadCallClass },
    { 0x3CFB, opcode::OP_Invalid },
    { 0x3CFC, opcode::OP_Invalid },
    { 0x3CFD, opcode::OP_Invalid },
    { 0x3CFE, opcode::OP_ScriptFunctionCall },
    { 0x3CFF, opcode::OP_JumpOnFalse },
    { 0x3D00, opcode::OP_GetWorld },
    { 0x3D01, opcode::OP_Plus },
    { 0x3D02, opcode::OP_Invalid },
    { 0x3D03, opcode::OP_SelfEvalFieldVariableRef },
    { 0x3D04, opcode::OP_ScriptThreadCallClass },
    { 0x3D05, opcode::OP_GetIString },
    { 0x3D06, opcode::OP_JumpOnTrueExpr },
    { 0x3D07, opcode::OP_GetClassesObject },
    { 0x3D08, opcode::OP_Minus },
    { 0x3D09, opcode::OP_Invalid },
    { 0x3D0A, opcode::OP_GetNegUnsignedShort },
    { 0x3D0B, opcode::OP_Invalid },
    { 0x3D0C, opcode::OP_Invalid },
    { 0x3D0D, opcode::OP_ClearArray },
    { 0x3D0E, opcode::OP_GetGame },
    { 0x3D0F, opcode::OP_GreaterThanOrEqualTo },
    { 0x3D10, opcode::OP_EvalArray },
    { 0x3D11, opcode::OP_BoolComplement },
    { 0x3D12, opcode::OP_Bit_Xor },
    { 0x3D13, opcode::OP_WaitTill },
    { 0x3D14, opcode::OP_Invalid },
    { 0x3D15, opcode::OP_ProfileStart },
    { 0x3D16, opcode::OP_EvalFieldVariableRef },
    { 0x3D17, opcode::OP_Invalid },
    { 0x3D18, opcode::OP_BoolNot },
    { 0x3D19, opcode::OP_GetHash },
    { 0x3D1A, opcode::OP_Invalid },
    { 0x3D1B, opcode::OP_GetLevelObject },
    { 0x3D1C, opcode::OP_ProfileStart },
    { 0x3D1D, opcode::OP_Invalid },
    { 0x3D1E, opcode::OP_GetNegUnsignedShort },
    { 0x3D1F, opcode::OP_FirstArrayKey },
    { 0x3D20, opcode::OP_Invalid },
    { 0x3D21, opcode::OP_RealWait },
    { 0x3D22, opcode::OP_Invalid },
    { 0x3D23, opcode::OP_GetFloat },
    { 0x3D24, opcode::OP_SetVariableField },
    { 0x3D25, opcode::OP_Invalid },
    { 0x3D26, opcode::OP_JumpOnTrue },
    { 0x3D27, opcode::OP_Invalid },
    { 0x3D28, opcode::OP_Invalid },
    { 0x3D29, opcode::OP_Wait },
    { 0x3D2A, opcode::OP_EvalArray },
    { 0x3D2B, opcode::OP_GetClassesObject },
    { 0x3D2C, opcode::OP_WaitTillMatch },
    { 0x3D2D, opcode::OP_New },
    { 0x3D2E, opcode::OP_Invalid },
    { 0x3D2F, opcode::OP_EvalArray },
    { 0x3D30, opcode::OP_NotEqual },
    { 0x3D31, opcode::OP_Invalid },
    { 0x3D32, opcode::OP_NotEqual },
    { 0x3D33, opcode::OP_Invalid },
    { 0x3D34, opcode::OP_Invalid },
    { 0x3D35, opcode::OP_Invalid },
    { 0x3D36, opcode::OP_GetUintptr },
    { 0x3D37, opcode::OP_ClearArray },
    { 0x3D38, opcode::OP_Invalid },
    { 0x3D39, opcode::OP_LessThan },
    { 0x3D3A, opcode::OP_Invalid },
    { 0x3D3B, opcode::OP_Invalid },
    { 0x3D3C, opcode::OP_GreaterThan },
    { 0x3D3D, opcode::OP_GetString },
    { 0x3D3E, opcode::OP_BoolComplement },
    { 0x3D3F, opcode::OP_DevblockBegin },
    { 0x3D40, opcode::OP_GetSelfObject },
    { 0x3D41, opcode::OP_Return },
    { 0x3D42, opcode::OP_ScriptThreadCallClass },
    { 0x3D43, opcode::OP_Plus },
    { 0x3D44, opcode::OP_GetLevel },
    { 0x3D45, opcode::OP_Invalid },
    { 0x3D46, opcode::OP_Invalid },
    { 0x3D47, opcode::OP_Invalid },
    { 0x3D48, opcode::OP_Invalid },
    { 0x3D49, opcode::OP_Invalid },
    { 0x3D4A, opcode::OP_GetFloat },
    { 0x3D4B, opcode::OP_ShiftRight },
    { 0x3D4C, opcode::OP_Bit_Xor },
    { 0x3D4D, opcode::OP_GetHash },
    { 0x3D4E, opcode::OP_SafeDecTop },
    { 0x3D4F, opcode::OP_Invalid },
    { 0x3D50, opcode::OP_LevelEvalFieldVariableRef },
    { 0x3D51, opcode::OP_SizeOf },
    { 0x3D52, opcode::OP_Switch },
    { 0x3D53, opcode::OP_ShiftLeft },
    { 0x3D54, opcode::OP_Dec },
    { 0x3D55, opcode::OP_EvalLocalVariableCached },
    { 0x3D56, opcode::OP_Invalid },
    { 0x3D57, opcode::OP_Invalid },
    { 0x3D58, opcode::OP_EvalLocalVariableRefCached },
    { 0x3D59, opcode::OP_DevblockBegin },
    { 0x3D5A, opcode::OP_Inc },
    { 0x3D5B, opcode::OP_GetSelfObject },
    { 0x3D5C, opcode::OP_Invalid },
    { 0x3D5D, opcode::OP_Invalid },
    { 0x3D5E, opcode::OP_LevelEvalFieldVariable },
    { 0x3D5F, opcode::OP_GetZero },
    { 0x3D60, opcode::OP_New },
    { 0x3D61, opcode::OP_SelfEvalFieldVariable },
    { 0x3D62, opcode::OP_GetWorldObject },
    { 0x3D63, opcode::OP_Invalid },
    { 0x3D64, opcode::OP_Invalid },
    { 0x3D65, opcode::OP_GetGameRef },
    { 0x3D66, opcode::OP_SizeOf },
    { 0x3D67, opcode::OP_GetUndefined },
    { 0x3D68, opcode::OP_Invalid },
    { 0x3D69, opcode::OP_Invalid },
    { 0x3D6A, opcode::OP_Invalid },
    { 0x3D6B, opcode::OP_Minus },
    { 0x3D6C, opcode::OP_GetAnimation },
    { 0x3D6D, opcode::OP_GetSelfObject },
    { 0x3D6E, opcode::OP_Invalid },
    { 0x3D6F, opcode::OP_Invalid },
    { 0x3D70, opcode::OP_ScriptMethodThreadCall },
    { 0x3D71, opcode::OP_SafeSetVariableFieldCached },
    { 0x3D72, opcode::OP_Invalid },
    { 0x3D73, opcode::OP_Invalid },
    { 0x3D74, opcode::OP_JumpOnFalseExpr },
    { 0x3D75, opcode::OP_Invalid },
    { 0x3D76, opcode::OP_Invalid },
    { 0x3D77, opcode::OP_ScriptMethodThreadCall },
    { 0x3D78, opcode::OP_Invalid },
    { 0x3D79, opcode::OP_Invalid },
    { 0x3D7A, opcode::OP_LessThan },
    { 0x3D7B, opcode::OP_GetLevelObject },
    { 0x3D7C, opcode::OP_ClearFieldVariable },
    { 0x3D7D, opcode::OP_Invalid },
    { 0x3D7E, opcode::OP_Invalid },
    { 0x3D7F, opcode::OP_Invalid },
    { 0x3D80, opcode::OP_GetClasses },
    { 0x3D81, opcode::OP_Wait },
    { 0x3D82, opcode::OP_JumpOnTrue },
    { 0x3D83, opcode::OP_DecTop },
    { 0x3D84, opcode::OP_GetUndefined },
    { 0x3D85, opcode::OP_Dec },
    { 0x3D86, opcode::OP_Invalid },
    { 0x3D87, opcode::OP_GetWorldObject },
    { 0x3D88, opcode::OP_SafeSetWaittillVariableFieldCached },
    { 0x3D89, opcode::OP_SafeSetVariableFieldCached },
    { 0x3D8A, opcode::OP_Invalid },
    { 0x3D8B, opcode::OP_WaitTillFrameEnd },
    { 0x3D8C, opcode::OP_DevblockBegin },
    { 0x3D8D, opcode::OP_SuperEqual },
    { 0x3D8E, opcode::OP_ScriptFunctionCallPointer },
    { 0x3D8F, opcode::OP_CastFieldObject },
    { 0x3D90, opcode::OP_SuperEqual },
    { 0x3D91, opcode::OP_GetVector },
    { 0x3D92, opcode::OP_SizeOf },
    { 0x3D93, opcode::OP_Invalid },
    { 0x3D94, opcode::OP_GetString },
    { 0x3D95, opcode::OP_Invalid },
    { 0x3D96, opcode::OP_Invalid },
    { 0x3D97, opcode::OP_Wait },
    { 0x3D98, opcode::OP_Invalid },
    { 0x3D99, opcode::OP_EvalFieldVariable },
    { 0x3D9A, opcode::OP_Invalid },
    { 0x3D9B, opcode::OP_Plus },
    { 0x3D9C, opcode::OP_Invalid },
    { 0x3D9D, opcode::OP_BoolComplement },
    { 0x3D9E, opcode::OP_GetZero },
    { 0x3D9F, opcode::OP_Invalid },
    { 0x3DA0, opcode::OP_EndSwitch },
    { 0x3DA1, opcode::OP_GetClasses },
    { 0x3DA2, opcode::OP_Invalid },
    { 0x3DA3, opcode::OP_Invalid },
    { 0x3DA4, opcode::OP_Invalid },
    { 0x3DA5, opcode::OP_SafeDecTop },
    { 0x3DA6, opcode::OP_DevblockBegin },
    { 0x3DA7, opcode::OP_GetString },
    { 0x3DA8, opcode::OP_Invalid },
    { 0x3DA9, opcode::OP_JumpOnTrue },
    { 0x3DAA, opcode::OP_GetTime },
    { 0x3DAB, opcode::OP_Switch },
    { 0x3DAC, opcode::OP_ScriptThreadCallClass },
    { 0x3DAD, opcode::OP_Invalid },
    { 0x3DAE, opcode::OP_SafeDecTop },
    { 0x3DAF, opcode::OP_Invalid },
    { 0x3DB0, opcode::OP_Plus },
    { 0x3DB1, opcode::OP_GetVector },
    { 0x3DB2, opcode::OP_GetAnim },
    { 0x3DB3, opcode::OP_ShiftRight },
    { 0x3DB4, opcode::OP_GetAnimObject },
    { 0x3DB5, opcode::OP_EvalFieldVariableRef },
    { 0x3DB6, opcode::OP_WaitTill },
    { 0x3DB7, opcode::OP_Invalid },
    { 0x3DB8, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x3DB9, opcode::OP_Invalid },
    { 0x3DBA, opcode::OP_SafeSetVariableFieldCached },
    { 0x3DBB, opcode::OP_Invalid },
    { 0x3DBC, opcode::OP_EndOn },
    { 0x3DBD, opcode::OP_GetGame },
    { 0x3DBE, opcode::OP_Invalid },
    { 0x3DBF, opcode::OP_Invalid },
    { 0x3DC0, opcode::OP_Invalid },
    { 0x3DC1, opcode::OP_EvalLocalVariableRefCached },
    { 0x3DC2, opcode::OP_SafeDecTop },
    { 0x3DC3, opcode::OP_Invalid },
    { 0x3DC4, opcode::OP_GetString },
    { 0x3DC5, opcode::OP_GetClassesObject },
    { 0x3DC6, opcode::OP_GetLevelObject },
    { 0x3DC7, opcode::OP_Invalid },
    { 0x3DC8, opcode::OP_ScriptMethodThreadCall },
    { 0x3DC9, opcode::OP_FirstArrayKey },
    { 0x3DCA, opcode::OP_Invalid },
    { 0x3DCB, opcode::OP_Invalid },
    { 0x3DCC, opcode::OP_Invalid },
    { 0x3DCD, opcode::OP_Invalid },
    { 0x3DCE, opcode::OP_Invalid },
    { 0x3DCF, opcode::OP_EvalLocalVariableCached },
    { 0x3DD0, opcode::OP_SelfEvalFieldVariable },
    { 0x3DD1, opcode::OP_SetVariableField },
    { 0x3DD2, opcode::OP_Invalid },
    { 0x3DD3, opcode::OP_EvalArray },
    { 0x3DD4, opcode::OP_EndOn },
    { 0x3DD5, opcode::OP_GetClassesObject },
    { 0x3DD6, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x3DD7, opcode::OP_Invalid },
    { 0x3DD8, opcode::OP_GetUintptr },
    { 0x3DD9, opcode::OP_GetAnim },
    { 0x3DDA, opcode::OP_EvalFieldVariable },
    { 0x3DDB, opcode::OP_ProfileStart },
    { 0x3DDC, opcode::OP_ClearFieldVariable },
    { 0x3DDD, opcode::OP_LevelEvalFieldVariable },
    { 0x3DDE, opcode::OP_DevblockBegin },
    { 0x3DDF, opcode::OP_GetLevel },
    { 0x3DE0, opcode::OP_GetUintptr },
    { 0x3DE1, opcode::OP_Invalid },
    { 0x3DE2, opcode::OP_SafeSetVariableFieldCached },
    { 0x3DE3, opcode::OP_Invalid },
    { 0x3DE4, opcode::OP_LevelEvalFieldVariable },
    { 0x3DE5, opcode::OP_ShiftRight },
    { 0x3DE6, opcode::OP_SelfEvalFieldVariableRef },
    { 0x3DE7, opcode::OP_WaitTillMatch },
    { 0x3DE8, opcode::OP_GetAPIFunction },
    { 0x3DE9, opcode::OP_JumpOnFalseExpr },
    { 0x3DEA, opcode::OP_Invalid },
    { 0x3DEB, opcode::OP_Notify },
    { 0x3DEC, opcode::OP_SetVariableField },
    { 0x3DED, opcode::OP_Invalid },
    { 0x3DEE, opcode::OP_Wait },
    { 0x3DEF, opcode::OP_LevelEvalFieldVariable },
    { 0x3DF0, opcode::OP_Invalid },
    { 0x3DF1, opcode::OP_WaitTillFrameEnd },
    { 0x3DF2, opcode::OP_GreaterThanOrEqualTo },
    { 0x3DF3, opcode::OP_NotEqual },
    { 0x3DF4, opcode::OP_Invalid },
    { 0x3DF5, opcode::OP_GetUndefined },
    { 0x3DF6, opcode::OP_GetGameRef },
    { 0x3DF7, opcode::OP_SelfEvalFieldVariable },
    { 0x3DF8, opcode::OP_JumpOnTrueExpr },
    { 0x3DF9, opcode::OP_Jump },
    { 0x3DFA, opcode::OP_Invalid },
    { 0x3DFB, opcode::OP_Divide },
    { 0x3DFC, opcode::OP_EvalLocalVariableRefCached },
    { 0x3DFD, opcode::OP_JumpOnTrueExpr },
    { 0x3DFE, opcode::OP_EvalFieldVariableRef },
    { 0x3DFF, opcode::OP_Wait },
    { 0x3E00, opcode::OP_Invalid },
    { 0x3E01, opcode::OP_WaitTillFrameEnd },
    { 0x3E02, opcode::OP_Invalid },
    { 0x3E03, opcode::OP_Jump },
    { 0x3E04, opcode::OP_GetHash },
    { 0x3E05, opcode::OP_Invalid },
    { 0x3E06, opcode::OP_Dec },
    { 0x3E07, opcode::OP_DevblockBegin },
    { 0x3E08, opcode::OP_GetWorldObject },
    { 0x3E09, opcode::OP_GetUndefined },
    { 0x3E0A, opcode::OP_Inc },
    { 0x3E0B, opcode::OP_Invalid },
    { 0x3E0C, opcode::OP_Invalid },
    { 0x3E0D, opcode::OP_Invalid },
    { 0x3E0E, opcode::OP_Invalid },
    { 0x3E0F, opcode::OP_Invalid },
    { 0x3E10, opcode::OP_Invalid },
    { 0x3E11, opcode::OP_SafeSetVariableFieldCached },
    { 0x3E12, opcode::OP_VectorScale },
    { 0x3E13, opcode::OP_Notify },
    { 0x3E14, opcode::OP_GetGameRef },
    { 0x3E15, opcode::OP_ScriptThreadCallClass },
    { 0x3E16, opcode::OP_Invalid },
    { 0x3E17, opcode::OP_JumpOnTrue },
    { 0x3E18, opcode::OP_SuperEqual },
    { 0x3E19, opcode::OP_GetAnim },
    { 0x3E1A, opcode::OP_Invalid },
    { 0x3E1B, opcode::OP_Invalid },
    { 0x3E1C, opcode::OP_ClearArray },
    { 0x3E1D, opcode::OP_Invalid },
    { 0x3E1E, opcode::OP_Invalid },
    { 0x3E1F, opcode::OP_Invalid },
    { 0x3E20, opcode::OP_SuperEqual },
    { 0x3E21, opcode::OP_Invalid },
    { 0x3E22, opcode::OP_GetByte },
    { 0x3E23, opcode::OP_GetWorld },
    { 0x3E24, opcode::OP_Modulus },
    { 0x3E25, opcode::OP_Invalid },
    { 0x3E26, opcode::OP_Invalid },
    { 0x3E27, opcode::OP_GreaterThanOrEqualTo },
    { 0x3E28, opcode::OP_DecTop },
    { 0x3E29, opcode::OP_GetSelf },
    { 0x3E2A, opcode::OP_Invalid },
    { 0x3E2B, opcode::OP_Multiply },
    { 0x3E2C, opcode::OP_Minus },
    { 0x3E2D, opcode::OP_Invalid },
    { 0x3E2E, opcode::OP_SafeDecTop },
    { 0x3E2F, opcode::OP_Invalid },
    { 0x3E30, opcode::OP_Invalid },
    { 0x3E31, opcode::OP_Invalid },
    { 0x3E32, opcode::OP_GetFloat },
    { 0x3E33, opcode::OP_Divide },
    { 0x3E34, opcode::OP_BoolComplement },
    { 0x3E35, opcode::OP_Invalid },
    { 0x3E36, opcode::OP_IsDefined },
    { 0x3E37, opcode::OP_Bit_And },
    { 0x3E38, opcode::OP_DecTop },
    { 0x3E39, opcode::OP_EvalArray },
    { 0x3E3A, opcode::OP_GetSelf },
    { 0x3E3B, opcode::OP_WaitTillFrameEnd },
    { 0x3E3C, opcode::OP_Invalid },
    { 0x3E3D, opcode::OP_ScriptMethodCall },
    { 0x3E3E, opcode::OP_Invalid },
    { 0x3E3F, opcode::OP_EvalFieldVariable },
    { 0x3E40, opcode::OP_Invalid },
    { 0x3E41, opcode::OP_Invalid },
    { 0x3E42, opcode::OP_Invalid },
    { 0x3E43, opcode::OP_ScriptMethodCall },
    { 0x3E44, opcode::OP_ScriptFunctionCallClass },
    { 0x3E45, opcode::OP_GetUnsignedShort },
    { 0x3E46, opcode::OP_Invalid },
    { 0x3E47, opcode::OP_ProfileStart },
    { 0x3E48, opcode::OP_Invalid },
    { 0x3E49, opcode::OP_GetByte },
    { 0x3E4A, opcode::OP_Invalid },
    { 0x3E4B, opcode::OP_Invalid },
    { 0x3E4C, opcode::OP_Invalid },
    { 0x3E4D, opcode::OP_WaitTillFrameEnd },
    { 0x3E4E, opcode::OP_EvalFieldVariableRef },
    { 0x3E4F, opcode::OP_RealWait },
    { 0x3E50, opcode::OP_Invalid },
    { 0x3E51, opcode::OP_Invalid },
    { 0x3E52, opcode::OP_BoolNot },
    { 0x3E53, opcode::OP_WaitTill },
    { 0x3E54, opcode::OP_Plus },
    { 0x3E55, opcode::OP_Invalid },
    { 0x3E56, opcode::OP_Invalid },
    { 0x3E57, opcode::OP_Plus },
    { 0x3E58, opcode::OP_Invalid },
    { 0x3E59, opcode::OP_Invalid },
    { 0x3E5A, opcode::OP_Invalid },
    { 0x3E5B, opcode::OP_NextArrayKey },
    { 0x3E5C, opcode::OP_EvalFieldVariableRef },
    { 0x3E5D, opcode::OP_GetByte },
    { 0x3E5E, opcode::OP_Jump },
    { 0x3E5F, opcode::OP_ClearArray },
    { 0x3E60, opcode::OP_Invalid },
    { 0x3E61, opcode::OP_ClearFieldVariable },
    { 0x3E62, opcode::OP_Invalid },
    { 0x3E63, opcode::OP_Invalid },
    { 0x3E64, opcode::OP_New },
    { 0x3E65, opcode::OP_JumpOnFalseExpr },
    { 0x3E66, opcode::OP_Invalid },
    { 0x3E67, opcode::OP_Invalid },
    { 0x3E68, opcode::OP_Invalid },
    { 0x3E69, opcode::OP_ScriptThreadCallPointer },
    { 0x3E6A, opcode::OP_GetLevelObject },
    { 0x3E6B, opcode::OP_SizeOf },
    { 0x3E6C, opcode::OP_Invalid },
    { 0x3E6D, opcode::OP_Invalid },
    { 0x3E6E, opcode::OP_Invalid },
    { 0x3E6F, opcode::OP_GetString },
    { 0x3E70, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x3E71, opcode::OP_Invalid },
    { 0x3E72, opcode::OP_Invalid },
    { 0x3E73, opcode::OP_Multiply },
    { 0x3E74, opcode::OP_Invalid },
    { 0x3E75, opcode::OP_SetVariableField },
    { 0x3E76, opcode::OP_JumpOnTrueExpr },
    { 0x3E77, opcode::OP_Invalid },
    { 0x3E78, opcode::OP_Invalid },
    { 0x3E79, opcode::OP_VectorScale },
    { 0x3E7A, opcode::OP_Invalid },
    { 0x3E7B, opcode::OP_GetSelfObject },
    { 0x3E7C, opcode::OP_ScriptThreadCallPointer },
    { 0x3E7D, opcode::OP_Invalid },
    { 0x3E7E, opcode::OP_SafeCreateLocalVariables },
    { 0x3E7F, opcode::OP_Invalid },
    { 0x3E80, opcode::OP_Invalid },
    { 0x3E81, opcode::OP_ScriptMethodCall },
    { 0x3E82, opcode::OP_Invalid },
    { 0x3E83, opcode::OP_FirstArrayKey },
    { 0x3E84, opcode::OP_ScriptMethodThreadCall },
    { 0x3E85, opcode::OP_Invalid },
    { 0x3E86, opcode::OP_ScriptMethodThreadCall },
    { 0x3E87, opcode::OP_SizeOf },
    { 0x3E88, opcode::OP_JumpOnTrueExpr },
    { 0x3E89, opcode::OP_GetTime },
    { 0x3E8A, opcode::OP_Switch },
    { 0x3E8B, opcode::OP_EmptyArray },
    { 0x3E8C, opcode::OP_CastFieldObject },
    { 0x3E8D, opcode::OP_GetFloat },
    { 0x3E8E, opcode::OP_WaitTillFrameEnd },
    { 0x3E8F, opcode::OP_Invalid },
    { 0x3E90, opcode::OP_Invalid },
    { 0x3E91, opcode::OP_GetHash },
    { 0x3E92, opcode::OP_Invalid },
    { 0x3E93, opcode::OP_Inc },
    { 0x3E94, opcode::OP_Invalid },
    { 0x3E95, opcode::OP_Invalid },
    { 0x3E96, opcode::OP_GreaterThan },
    { 0x3E97, opcode::OP_EmptyArray },
    { 0x3E98, opcode::OP_EndSwitch },
    { 0x3E99, opcode::OP_GetSelfObject },
    { 0x3E9A, opcode::OP_Multiply },
    { 0x3E9B, opcode::OP_Invalid },
    { 0x3E9C, opcode::OP_NextArrayKey },
    { 0x3E9D, opcode::OP_GetUintptr },
    { 0x3E9E, opcode::OP_Invalid },
    { 0x3E9F, opcode::OP_Invalid },
    { 0x3EA0, opcode::OP_NotEqual },
    { 0x3EA1, opcode::OP_Jump },
    { 0x3EA2, opcode::OP_GetWorld },
    { 0x3EA3, opcode::OP_JumpOnFalseExpr },
    { 0x3EA4, opcode::OP_RealWait },
    { 0x3EA5, opcode::OP_JumpOnFalse },
    { 0x3EA6, opcode::OP_Invalid },
    { 0x3EA7, opcode::OP_BoolNot },
    { 0x3EA8, opcode::OP_Invalid },
    { 0x3EA9, opcode::OP_Multiply },
    { 0x3EAA, opcode::OP_Plus },
    { 0x3EAB, opcode::OP_EndOn },
    { 0x3EAC, opcode::OP_EvalFieldVariable },
    { 0x3EAD, opcode::OP_JumpOnFalse },
    { 0x3EAE, opcode::OP_CallBuiltinMethod },
    { 0x3EAF, opcode::OP_Invalid },
    { 0x3EB0, opcode::OP_Invalid },
    { 0x3EB1, opcode::OP_Invalid },
    { 0x3EB2, opcode::OP_SuperEqual },
    { 0x3EB3, opcode::OP_Minus },
    { 0x3EB4, opcode::OP_Invalid },
    { 0x3EB5, opcode::OP_EvalLocalVariableRefCached },
    { 0x3EB6, opcode::OP_Equal },
    { 0x3EB7, opcode::OP_GetHash },
    { 0x3EB8, opcode::OP_EvalArray },
    { 0x3EB9, opcode::OP_EvalLocalVariableCached },
    { 0x3EBA, opcode::OP_Invalid },
    { 0x3EBB, opcode::OP_GetUintptr },
    { 0x3EBC, opcode::OP_SafeCreateLocalVariables },
    { 0x3EBD, opcode::OP_Invalid },
    { 0x3EBE, opcode::OP_Invalid },
    { 0x3EBF, opcode::OP_BoolNot },
    { 0x3EC0, opcode::OP_Invalid },
    { 0x3EC1, opcode::OP_Dec },
    { 0x3EC2, opcode::OP_RealWait },
    { 0x3EC3, opcode::OP_SafeDecTop },
    { 0x3EC4, opcode::OP_ProfileStart },
    { 0x3EC5, opcode::OP_SafeSetVariableFieldCached },
    { 0x3EC6, opcode::OP_GetByte },
    { 0x3EC7, opcode::OP_SafeDecTop },
    { 0x3EC8, opcode::OP_Invalid },
    { 0x3EC9, opcode::OP_Invalid },
    { 0x3ECA, opcode::OP_GetInteger },
    { 0x3ECB, opcode::OP_Invalid },
    { 0x3ECC, opcode::OP_Invalid },
    { 0x3ECD, opcode::OP_ScriptThreadCallPointer },
    { 0x3ECE, opcode::OP_WaitTill },
    { 0x3ECF, opcode::OP_EvalLocalVariableCached },
    { 0x3ED0, opcode::OP_Invalid },
    { 0x3ED1, opcode::OP_Multiply },
    { 0x3ED2, opcode::OP_BoolComplement },
    { 0x3ED3, opcode::OP_EvalArray },
    { 0x3ED4, opcode::OP_LevelEvalFieldVariable },
    { 0x3ED5, opcode::OP_Invalid },
    { 0x3ED6, opcode::OP_CastBool },
    { 0x3ED7, opcode::OP_Invalid },
    { 0x3ED8, opcode::OP_Invalid },
    { 0x3ED9, opcode::OP_GetString },
    { 0x3EDA, opcode::OP_Invalid },
    { 0x3EDB, opcode::OP_ProfileStop },
    { 0x3EDC, opcode::OP_Invalid },
    { 0x3EDD, opcode::OP_SuperEqual },
    { 0x3EDE, opcode::OP_WaitTillFrameEnd },
    { 0x3EDF, opcode::OP_EvalLocalVariableRefCached },
    { 0x3EE0, opcode::OP_SizeOf },
    { 0x3EE1, opcode::OP_Inc },
    { 0x3EE2, opcode::OP_Invalid },
    { 0x3EE3, opcode::OP_Invalid },
    { 0x3EE4, opcode::OP_Invalid },
    { 0x3EE5, opcode::OP_Invalid },
    { 0x3EE6, opcode::OP_GetGameRef },
    { 0x3EE7, opcode::OP_Jump },
    { 0x3EE8, opcode::OP_Switch },
    { 0x3EE9, opcode::OP_DevblockBegin },
    { 0x3EEA, opcode::OP_GetNegByte },
    { 0x3EEB, opcode::OP_Invalid },
    { 0x3EEC, opcode::OP_GetClasses },
    { 0x3EED, opcode::OP_EmptyArray },
    { 0x3EEE, opcode::OP_Invalid },
    { 0x3EEF, opcode::OP_SuperNotEqual },
    { 0x3EF0, opcode::OP_ShiftRight },
    { 0x3EF1, opcode::OP_ScriptFunctionCallClass },
    { 0x3EF2, opcode::OP_VectorConstant },
    { 0x3EF3, opcode::OP_Invalid },
    { 0x3EF4, opcode::OP_ShiftLeft },
    { 0x3EF5, opcode::OP_LevelEvalFieldVariable },
    { 0x3EF6, opcode::OP_SizeOf },
    { 0x3EF7, opcode::OP_Invalid },
    { 0x3EF8, opcode::OP_Invalid },
    { 0x3EF9, opcode::OP_EndSwitch },
    { 0x3EFA, opcode::OP_Invalid },
    { 0x3EFB, opcode::OP_BoolNot },
    { 0x3EFC, opcode::OP_GetClasses },
    { 0x3EFD, opcode::OP_GetGame },
    { 0x3EFE, opcode::OP_Invalid },
    { 0x3EFF, opcode::OP_Invalid },
    { 0x3F00, opcode::OP_Invalid },
    { 0x3F01, opcode::OP_Invalid },
    { 0x3F02, opcode::OP_SelfEvalFieldVariable },
    { 0x3F03, opcode::OP_ScriptThreadCall },
    { 0x3F04, opcode::OP_Invalid },
    { 0x3F05, opcode::OP_Invalid },
    { 0x3F06, opcode::OP_GetFunction },
    { 0x3F07, opcode::OP_ScriptFunctionCallPointer },
    { 0x3F08, opcode::OP_Invalid },
    { 0x3F09, opcode::OP_Invalid },
    { 0x3F0A, opcode::OP_SuperNotEqual },
    { 0x3F0B, opcode::OP_GetNegUnsignedShort },
    { 0x3F0C, opcode::OP_JumpOnFalse },
    { 0x3F0D, opcode::OP_EvalFieldVariable },
    { 0x3F0E, opcode::OP_Bit_Xor },
    { 0x3F0F, opcode::OP_CastBool },
    { 0x3F10, opcode::OP_ClearArray },
    { 0x3F11, opcode::OP_GetAnim },
    { 0x3F12, opcode::OP_Invalid },
    { 0x3F13, opcode::OP_GetUndefined },
    { 0x3F14, opcode::OP_Invalid },
    { 0x3F15, opcode::OP_GetWorldObject },
    { 0x3F16, opcode::OP_SelfEvalFieldVariableRef },
    { 0x3F17, opcode::OP_SelfEvalFieldVariableRef },
    { 0x3F18, opcode::OP_ScriptMethodThreadCall },
    { 0x3F19, opcode::OP_Invalid },
    { 0x3F1A, opcode::OP_New },
    { 0x3F1B, opcode::OP_GetWorldObject },
    { 0x3F1C, opcode::OP_New },
    { 0x3F1D, opcode::OP_Invalid },
    { 0x3F1E, opcode::OP_Invalid },
    { 0x3F1F, opcode::OP_ClearArray },
    { 0x3F20, opcode::OP_Invalid },
    { 0x3F21, opcode::OP_GetGame },
    { 0x3F22, opcode::OP_Invalid },
    { 0x3F23, opcode::OP_ScriptMethodCallPointer },
    { 0x3F24, opcode::OP_GetSelfObject },
    { 0x3F25, opcode::OP_ClearFieldVariable },
    { 0x3F26, opcode::OP_Invalid },
    { 0x3F27, opcode::OP_GetLevel },
    { 0x3F28, opcode::OP_Return },
    { 0x3F29, opcode::OP_Invalid },
    { 0x3F2A, opcode::OP_Invalid },
    { 0x3F2B, opcode::OP_GetSelf },
    { 0x3F2C, opcode::OP_Invalid },
    { 0x3F2D, opcode::OP_New },
    { 0x3F2E, opcode::OP_DevblockBegin },
    { 0x3F2F, opcode::OP_GetSelfObject },
    { 0x3F30, opcode::OP_NextArrayKey },
    { 0x3F31, opcode::OP_Invalid },
    { 0x3F32, opcode::OP_WaitTillFrameEnd },
    { 0x3F33, opcode::OP_ScriptMethodCallPointer },
    { 0x3F34, opcode::OP_GetFunction },
    { 0x3F35, opcode::OP_GetAnimObject },
    { 0x3F36, opcode::OP_Invalid },
    { 0x3F37, opcode::OP_Invalid },
    { 0x3F38, opcode::OP_EvalLocalVariableRefCached },
    { 0x3F39, opcode::OP_Plus },
    { 0x3F3A, opcode::OP_Invalid },
    { 0x3F3B, opcode::OP_Invalid },
    { 0x3F3C, opcode::OP_Invalid },
    { 0x3F3D, opcode::OP_LevelEvalFieldVariableRef },
    { 0x3F3E, opcode::OP_Invalid },
    { 0x3F3F, opcode::OP_Switch },
    { 0x3F40, opcode::OP_WaitTillMatch },
    { 0x3F41, opcode::OP_RealWait },
    { 0x3F42, opcode::OP_Invalid },
    { 0x3F43, opcode::OP_EvalArrayRef },
    { 0x3F44, opcode::OP_GetZero },
    { 0x3F45, opcode::OP_Invalid },
    { 0x3F46, opcode::OP_Bit_And },
    { 0x3F47, opcode::OP_VectorConstant },
    { 0x3F48, opcode::OP_WaitTill },
    { 0x3F49, opcode::OP_Invalid },
    { 0x3F4A, opcode::OP_RealWait },
    { 0x3F4B, opcode::OP_Invalid },
    { 0x3F4C, opcode::OP_Wait },
    { 0x3F4D, opcode::OP_Invalid },
    { 0x3F4E, opcode::OP_ScriptMethodCallPointer },
    { 0x3F4F, opcode::OP_ClearFieldVariable },
    { 0x3F50, opcode::OP_LevelEvalFieldVariable },
    { 0x3F51, opcode::OP_Invalid },
    { 0x3F52, opcode::OP_Modulus },
    { 0x3F53, opcode::OP_Invalid },
    { 0x3F54, opcode::OP_EvalArrayRef },
    { 0x3F55, opcode::OP_NotEqual },
    { 0x3F56, opcode::OP_GetUnsignedShort },
    { 0x3F57, opcode::OP_Invalid },
    { 0x3F58, opcode::OP_Switch },
    { 0x3F59, opcode::OP_Invalid },
    { 0x3F5A, opcode::OP_ProfileStop },
    { 0x3F5B, opcode::OP_GetAnimObject },
    { 0x3F5C, opcode::OP_GetWorldObject },
    { 0x3F5D, opcode::OP_Invalid },
    { 0x3F5E, opcode::OP_EmptyArray },
    { 0x3F5F, opcode::OP_Invalid },
    { 0x3F60, opcode::OP_VectorScale },
    { 0x3F61, opcode::OP_JumpOnFalse },
    { 0x3F62, opcode::OP_Wait },
    { 0x3F63, opcode::OP_Invalid },
    { 0x3F64, opcode::OP_WaitTillMatch },
    { 0x3F65, opcode::OP_Invalid },
    { 0x3F66, opcode::OP_ShiftLeft },
    { 0x3F67, opcode::OP_ScriptMethodCallPointer },
    { 0x3F68, opcode::OP_Invalid },
    { 0x3F69, opcode::OP_WaitTillFrameEnd },
    { 0x3F6A, opcode::OP_Invalid },
    { 0x3F6B, opcode::OP_GetNegUnsignedShort },
    { 0x3F6C, opcode::OP_CallBuiltinMethod },
    { 0x3F6D, opcode::OP_Invalid },
    { 0x3F6E, opcode::OP_GetAnimObject },
    { 0x3F6F, opcode::OP_Invalid },
    { 0x3F70, opcode::OP_Invalid },
    { 0x3F71, opcode::OP_Return },
    { 0x3F72, opcode::OP_CastFieldObject },
    { 0x3F73, opcode::OP_ScriptFunctionCallPointer },
    { 0x3F74, opcode::OP_LevelEvalFieldVariable },
    { 0x3F75, opcode::OP_Invalid },
    { 0x3F76, opcode::OP_BoolComplement },
    { 0x3F77, opcode::OP_CastFieldObject },
    { 0x3F78, opcode::OP_GetSelf },
    { 0x3F79, opcode::OP_ClearArray },
    { 0x3F7A, opcode::OP_EndSwitch },
    { 0x3F7B, opcode::OP_GetIString },
    { 0x3F7C, opcode::OP_GreaterThanOrEqualTo },
    { 0x3F7D, opcode::OP_Modulus },
    { 0x3F7E, opcode::OP_Invalid },
    { 0x3F7F, opcode::OP_Inc },
    { 0x3F80, opcode::OP_SetVariableField },
    { 0x3F81, opcode::OP_Invalid },
    { 0x3F82, opcode::OP_GetUnsignedShort },
    { 0x3F83, opcode::OP_Invalid },
    { 0x3F84, opcode::OP_ShiftLeft },
    { 0x3F85, opcode::OP_EvalFieldVariableRef },
    { 0x3F86, opcode::OP_GetByte },
    { 0x3F87, opcode::OP_VectorConstant },
    { 0x3F88, opcode::OP_EmptyArray },
    { 0x3F89, opcode::OP_Invalid },
    { 0x3F8A, opcode::OP_GetWorld },
    { 0x3F8B, opcode::OP_Invalid },
    { 0x3F8C, opcode::OP_Invalid },
    { 0x3F8D, opcode::OP_JumpOnFalse },
    { 0x3F8E, opcode::OP_Invalid },
    { 0x3F8F, opcode::OP_WaitTill },
    { 0x3F90, opcode::OP_GetVector },
    { 0x3F91, opcode::OP_GetAnim },
    { 0x3F92, opcode::OP_ShiftLeft },
    { 0x3F93, opcode::OP_VectorScale },
    { 0x3F94, opcode::OP_SelfEvalFieldVariable },
    { 0x3F95, opcode::OP_Invalid },
    { 0x3F96, opcode::OP_WaitTill },
    { 0x3F97, opcode::OP_EndOn },
    { 0x3F98, opcode::OP_EvalLocalVariableRefCached },
    { 0x3F99, opcode::OP_ClearFieldVariable },
    { 0x3F9A, opcode::OP_Invalid },
    { 0x3F9B, opcode::OP_EvalLocalVariableRefCached },
    { 0x3F9C, opcode::OP_GetUnsignedShort },
    { 0x3F9D, opcode::OP_Invalid },
    { 0x3F9E, opcode::OP_Invalid },
    { 0x3F9F, opcode::OP_ShiftLeft },
    { 0x3FA0, opcode::OP_Invalid },
    { 0x3FA1, opcode::OP_NotEqual },
    { 0x3FA2, opcode::OP_EvalLocalVariableRefCached },
    { 0x3FA3, opcode::OP_Invalid },
    { 0x3FA4, opcode::OP_Invalid },
    { 0x3FA5, opcode::OP_LessThanOrEqualTo },
    { 0x3FA6, opcode::OP_GetVector },
    { 0x3FA7, opcode::OP_NextArrayKey },
    { 0x3FA8, opcode::OP_LessThan },
    { 0x3FA9, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x3FAA, opcode::OP_GetVector },
    { 0x3FAB, opcode::OP_Equal },
    { 0x3FAC, opcode::OP_GreaterThanOrEqualTo },
    { 0x3FAD, opcode::OP_Invalid },
    { 0x3FAE, opcode::OP_GetIString },
    { 0x3FAF, opcode::OP_Invalid },
    { 0x3FB0, opcode::OP_Bit_Xor },
    { 0x3FB1, opcode::OP_SelfEvalFieldVariable },
    { 0x3FB2, opcode::OP_EvalArrayRef },
    { 0x3FB3, opcode::OP_ScriptFunctionCallClass },
    { 0x3FB4, opcode::OP_Invalid },
    { 0x3FB5, opcode::OP_SafeDecTop },
    { 0x3FB6, opcode::OP_EvalArray },
    { 0x3FB7, opcode::OP_Invalid },
    { 0x3FB8, opcode::OP_Invalid },
    { 0x3FB9, opcode::OP_NextArrayKey },
    { 0x3FBA, opcode::OP_JumpOnTrue },
    { 0x3FBB, opcode::OP_BoolNot },
    { 0x3FBC, opcode::OP_Invalid },
    { 0x3FBD, opcode::OP_Invalid },
    { 0x3FBE, opcode::OP_Vector },
    { 0x3FBF, opcode::OP_Invalid },
    { 0x3FC0, opcode::OP_ShiftRight },
    { 0x3FC1, opcode::OP_Invalid },
    { 0x3FC2, opcode::OP_Bit_Xor },
    { 0x3FC3, opcode::OP_GetClasses },
    { 0x3FC4, opcode::OP_Invalid },
    { 0x3FC5, opcode::OP_EvalLocalVariableCached },
    { 0x3FC6, opcode::OP_SizeOf },
    { 0x3FC7, opcode::OP_EmptyArray },
    { 0x3FC8, opcode::OP_WaitTill },
    { 0x3FC9, opcode::OP_SelfEvalFieldVariableRef },
    { 0x3FCA, opcode::OP_GetAnimObject },
    { 0x3FCB, opcode::OP_FirstArrayKey },
    { 0x3FCC, opcode::OP_Switch },
    { 0x3FCD, opcode::OP_ScriptMethodThreadCallPointer },
    { 0x3FCE, opcode::OP_ShiftLeft },
    { 0x3FCF, opcode::OP_Invalid },
    { 0x3FD0, opcode::OP_GetNegUnsignedShort },
    { 0x3FD1, opcode::OP_Invalid },
    { 0x3FD2, opcode::OP_Invalid },
    { 0x3FD3, opcode::OP_CastBool },
    { 0x3FD4, opcode::OP_GetUintptr },
    { 0x3FD5, opcode::OP_ScriptMethodThreadCall },
    { 0x3FD6, opcode::OP_GetIString },
    { 0x3FD7, opcode::OP_GetLevel },
    { 0x3FD8, opcode::OP_FirstArrayKey },
    { 0x3FD9, opcode::OP_Modulus },
    { 0x3FDA, opcode::OP_GetSelfObject },
    { 0x3FDB, opcode::OP_Invalid },
    { 0x3FDC, opcode::OP_NotEqual },
    { 0x3FDD, opcode::OP_GetByte },
    { 0x3FDE, opcode::OP_Invalid },
    { 0x3FDF, opcode::OP_ShiftRight },
    { 0x3FE0, opcode::OP_Invalid },
    { 0x3FE1, opcode::OP_GetWorldObject },
    { 0x3FE2, opcode::OP_Invalid },
    { 0x3FE3, opcode::OP_Invalid },
    { 0x3FE4, opcode::OP_ScriptThreadCallClass },
    { 0x3FE5, opcode::OP_ProfileStart },
    { 0x3FE6, opcode::OP_GreaterThan },
    { 0x3FE7, opcode::OP_JumpOnFalseExpr },
    { 0x3FE8, opcode::OP_Invalid },
    { 0x3FE9, opcode::OP_GetAnim },
    { 0x3FEA, opcode::OP_Invalid },
    { 0x3FEB, opcode::OP_GetClasses },
    { 0x3FEC, opcode::OP_New },
    { 0x3FED, opcode::OP_Invalid },
    { 0x3FEE, opcode::OP_ScriptThreadCallClass },
    { 0x3FEF, opcode::OP_GetSelfObject },
    { 0x3FF0, opcode::OP_GetClasses },
    { 0x3FF1, opcode::OP_Invalid },
    { 0x3FF2, opcode::OP_LessThanOrEqualTo },
    { 0x3FF3, opcode::OP_Invalid },
    { 0x3FF4, opcode::OP_GetUnsignedShort },
    { 0x3FF5, opcode::OP_GetHash },
    { 0x3FF6, opcode::OP_Minus },
    { 0x3FF7, opcode::OP_IsDefined },
    { 0x3FF8, opcode::OP_LessThanOrEqualTo },
    { 0x3FF9, opcode::OP_Invalid },
    { 0x3FFA, opcode::OP_Invalid },
    { 0x3FFB, opcode::OP_Invalid },
    { 0x3FFC, opcode::OP_Invalid },
    { 0x3FFD, opcode::OP_GetVector },
    { 0x3FFE, opcode::OP_GetWorld },
    { 0x3FFF, opcode::OP_EmptyArray },
}};

} // namespace xsk::arc::t7
