// Copyright 2024 xensik. All rights reserved.
//
// Use of this source code is governed by a GNU GPLv3 license
// that can be found in the LICENSE file.

#include "xsk/gsc/engine/iw8.hpp"

namespace xsk::gsc::iw8
{

extern std::array<std::pair<u32, char const*>, token_count> const token_list
{{
    { 0x0000, "" },
    { 0x0001, "pl#" },
    { 0x0002, "-" },
    { 0x0003, "radius`" },
    { 0x0004, "note:" },
    { 0x0005, "scripts/aitypes/bt_util" },
    { 0x0006, "scripts/asm/asm" },
    { 0x0007, "scripts/code/ai" },
    { 0x0008, "scripts/code/delete" },
    { 0x0009, "scripts/code/struct" },
    { 0x000A, "scripts/common/interactive" },
    { 0x000B, "scripts/common/scriptable" },
    { 0x000C, "scripts/common/ui" },
    { 0x000D, "scripts/cp/dedicated" },
    { 0x000E, "scripts/mp/callbacksetup" },
    { 0x000F, "scripts/mp/dedicated" },
    { 0x0010, "scripts/mp/weapons" },
    { 0x0011, "scripts/mp/agents/agent_common" },
    { 0x0012, "scripts/mp/agents/agents" },
    { 0x0013, "scripts/mp/agents/scriptedagents" },
    { 0x0014, "scripts/mp/bots/bots" },
    { 0x0015, "scripts/mp/agents/alien/agents" },
    { 0x0016, "_" },
    { 0x0017, "_custom" },
    { 0x0018, "_process_native_script" },
    { 0x0019, "accumulate" },
    { 0x001A, "accuracy" },
    { 0x001B, "actionslot1" },
    { 0x001C, "actionslot2" },
    { 0x001D, "actionslot3" },
    { 0x001E, "actionslot4" },
    { 0x001F, "actionslot5" },
    { 0x0020, "actionslot6" },
    { 0x0021, "actionslot7" },
    { 0x0022, "activator" },
    { 0x0023, "active" },
    { 0x0024, "activevisionset" },
    { 0x0025, "activevisionsetduration" },
    { 0x0026, "adrenaline" },
    { 0x0027, "agent" },
    { 0x0028, "agenthealth" },
    { 0x0029, "agentname" },
    { 0x002A, "agentteam" },
    { 0x002B, "aggressivemode" },
    { 0x002C, "aiSpread" },
    { 0x002D, "ai_event" },
    { 0x002E, "aifusetime" },
    { 0x002F, "aim_highest_bone" },
    { 0x0030, "aim_vis_bone" },
    { 0x0031, "aimyawspeed" },
    { 0x0032, "alert" },
    { 0x0033, "alertlevel" },
    { 0x0034, "alertlevelint" },
    { 0x0035, "alien" },
    { 0x0036, "alignx" },
    { 0x0037, "aligny" },
    { 0x0038, "all" },
    { 0x0039, "allies" },
    { 0x003A, "allowcrouch" },
    { 0x003B, "allowdeath" },
    { 0x003C, "allowjump" },
    { 0x003D, "allowladders" },
    { 0x003E, "allowpain" },
    { 0x003F, "allowpain_internal" },
    { 0x0040, "allowprone" },
    { 0x0041, "allowspeedupwhencombathot" },
    { 0x0042, "allowstrafe" },
    { 0x0043, "alpha" },
    { 0x0044, "alternateinventory" },
    { 0x0045, "alternateweapons" },
    { 0x0046, "altmode" },
    { 0x0047, "always" },
    { 0x0048, "ambient" },
    { 0x0049, "ambush" },
    { 0x004A, "ambush_nodes_only" },
    { 0x004B, "amount" },
    { 0x004C, "angle_deltas" },
    { 0x004D, "angledelta" },
    { 0x004E, "angleindex" },
    { 0x004F, "anglelerprate" },
    { 0x0050, "angles" },
    { 0x0051, "angles_offset" },
    { 0x0052, "anim_angle_delta" },
    { 0x0053, "anim_deltas" },
    { 0x0054, "anim_pose" },
    { 0x0055, "anim_will_finish" },
    { 0x0056, "anims" },
    { 0x0057, "animscript" },
    { 0x0058, "animscriptedactive" },
    { 0x0059, "archived" },
    { 0x005A, "archivetime" },
    { 0x005B, "archiveusepotg" },
    { 0x005C, "arrivalfailed" },
    { 0x005D, "arriving" },
    { 0x005E, "asleep" },
    { 0x005F, "asm_ephemeral_events" },
    { 0x0060, "asm_events" },
    { 0x0061, "asm_getfunction" },
    { 0x0062, "asm_getgenerichandler" },
    { 0x0063, "asm_getparams" },
    { 0x0064, "aspectratio" },
    { 0x0065, "assists" },
    { 0x0066, "attachments" },
    { 0x0067, "attachmentvarindices" },
    { 0x0068, "attachtag" },
    { 0x0069, "attacker" },
    { 0x006A, "attackeraccuracy" },
    { 0x006B, "attackercount" },
    { 0x006C, "auto_ai" },
    { 0x006D, "auto_change" },
    { 0x006E, "auto_nonai" },
    { 0x006F, "axis" },
    { 0x0070, "back" },
    { 0x0071, "back_left" },
    { 0x0072, "back_low" },
    { 0x0073, "back_mid" },
    { 0x0074, "back_right" },
    { 0x0075, "back_up" },
    { 0x0076, "backpiece" },
    { 0x0077, "backpiecevarindex" },
    { 0x0078, "bad_guys" },
    { 0x0079, "bad_path" },
    { 0x007A, "badpath" },
    { 0x007B, "badplaceawareness" },
    { 0x007C, "baimedataimtarget" },
    { 0x007D, "basearchetype" },
    { 0x007E, "basename" },
    { 0x007F, "begin" },
    { 0x0080, "begin_custom_anim" },
    { 0x0081, "begin_firing" },
    { 0x0082, "begin_firing_left" },
    { 0x0083, "bfire" },
    { 0x0084, "bgrenadeavoid" },
    { 0x0085, "bgrenadereturnthrow" },
    { 0x0086, "birthtime" },
    { 0x0087, "bisincombat" },
    { 0x0088, "blade_hide" },
    { 0x0089, "blade_show" },
    { 0x008A, "blindfire" },
    { 0x008B, "blockfriendlies" },
    { 0x008C, "blurradius" },
    { 0x008D, "body_animate_jnt" },
    { 0x008E, "bodyindex" },
    { 0x008F, "bottomarc" },
    { 0x0090, "boundingoverwatchenabled" },
    { 0x0091, "boxsizex" },
    { 0x0092, "boxsizey" },
    { 0x0093, "breload" },
    { 0x0094, "bt_createinstance" },
    { 0x0095, "bt_createtasktree" },
    { 0x0096, "bt_eventlistener" },
    { 0x0097, "bt_finalizebehavior" },
    { 0x0098, "bt_finalizeregistrar" },
    { 0x0099, "bt_getchildtaskid" },
    { 0x009A, "bt_getdemeanor" },
    { 0x009B, "bt_getfunction" },
    { 0x009C, "bt_gettaskfuncargs" },
    { 0x009D, "bt_init" },
    { 0x009E, "bt_initactions" },
    { 0x009F, "bt_initnodetypes" },
    { 0x00A0, "bt_initroot" },
    { 0x00A1, "bt_istreeregistered" },
    { 0x00A2, "bt_nativecopyaction" },
    { 0x00A3, "bt_nativecopybehavior" },
    { 0x00A4, "bt_nativeexecaction" },
    { 0x00A5, "bt_nativefinalizeregistrar" },
    { 0x00A6, "bt_nativeistreeregistered" },
    { 0x00A7, "bt_nativeregisteraction" },
    { 0x00A8, "bt_nativeregisterbehavior" },
    { 0x00A9, "bt_nativeregisterbehaviortotree" },
    { 0x00AA, "bt_nativeregistertree" },
    { 0x00AB, "bt_nativesetregistrar" },
    { 0x00AC, "bt_nativetick" },
    { 0x00AD, "bt_negateresult" },
    { 0x00AE, "bt_registeraction" },
    { 0x00AF, "bt_registerbehavior" },
    { 0x00B0, "bt_registerbehaviortotree" },
    { 0x00B1, "bt_registerprefabtaskids" },
    { 0x00B2, "bt_registertaskargs" },
    { 0x00B3, "bt_registertree" },
    { 0x00B4, "bt_setregistrar" },
    { 0x00B5, "bt_terminateprevrunningaction" },
    { 0x00B6, "bt_tick" },
    { 0x00B7, "btgoalheight" },
    { 0x00B8, "btgoalradius" },
    { 0x00B9, "buildpathextradata" },
    { 0x00BA, "bullet_hitshield" },
    { 0x00BB, "bullethit" },
    { 0x00BC, "bulletsinclip" },
    { 0x00BD, "bulletwhizby" },
    { 0x00BE, "burstcount" },
    { 0x00BF, "busebackwardstrafespace" },
    { 0x00C0, "call_vote" },
    { 0x00C1, "callsign" },
    { 0x00C2, "camo" },
    { 0x00C3, "canacquirenearbytacvisenemies" },
    { 0x00C4, "cancel_location" },
    { 0x00C5, "canclimbladders" },
    { 0x00C6, "candrop" },
    { 0x00C7, "capsule_halfheight" },
    { 0x00C8, "capsule_midpoint_height" },
    { 0x00C9, "capsule_radius" },
    { 0x00CA, "cautiouslookaheaddist" },
    { 0x00CB, "cautiousnavigation" },
    { 0x00CC, "chainfallback" },
    { 0x00CD, "chainnode" },
    { 0x00CE, "changearchetype" },
    { 0x00CF, "characterid" },
    { 0x00D0, "chest" },
    { 0x00D1, "civilian" },
    { 0x00D2, "civiliannameplate" },
    { 0x00D3, "clantag" },
    { 0x00D4, "classname" },
    { 0x00D5, "clipdistance" },
    { 0x00D6, "clipsize" },
    { 0x00D7, "code_classname" },
    { 0x00D8, "code_damageradius" },
    { 0x00D9, "code_move" },
    { 0x00DA, "code_move_slide" },
    { 0x00DB, "codecallback_agentadded" },
    { 0x00DC, "codecallback_agentdamaged" },
    { 0x00DD, "codecallback_agentfinishweaponchange" },
    { 0x00DE, "codecallback_agentimpaled" },
    { 0x00DF, "codecallback_agentkilled" },
    { 0x00E0, "codecallback_getprojectilespeedscale" },
    { 0x00E1, "codecallback_hostmigration" },
    { 0x00E2, "codecallback_leaderdialog" },
    { 0x00E3, "codecallback_omnvarschanged" },
    { 0x00E4, "codecallback_playeractive" },
    { 0x00E5, "codecallback_playerconnect" },
    { 0x00E6, "codecallback_playerdamage" },
    { 0x00E7, "codecallback_playerdisconnect" },
    { 0x00E8, "codecallback_playerfinishweaponchange" },
    { 0x00E9, "codecallback_playerimpaled" },
    { 0x00EA, "codecallback_playerkilled" },
    { 0x00EB, "codecallback_playerlaststand" },
    { 0x00EC, "codecallback_playermigrated" },
    { 0x00ED, "codecallback_playerspawned" },
    { 0x00EE, "codecallback_spawnpointcritscore" },
    { 0x00EF, "codecallback_spawnpointscore" },
    { 0x00F0, "codecallback_spawnpointsprecalc" },
    { 0x00F1, "codecallback_startgametype" },
    { 0x00F2, "codecallback_vehicledamage" },
    { 0x00F3, "color" },
    { 0x00F4, "color_blind_toggled" },
    { 0x00F5, "combat" },
    { 0x00F6, "combatmode" },
    { 0x00F7, "compositemodel" },
    { 0x00F8, "confirm_location" },
    { 0x00F9, "consecutiveKills" },
    { 0x00FA, "console" },
    { 0x00FB, "constrained" },
    { 0x00FC, "contact" },
    { 0x00FD, "convergencetime" },
    { 0x00FE, "count" },
    { 0x00FF, "cover" },
    { 0x0100, "cover_approach" },
    { 0x0101, "coverexposetype" },
    { 0x0102, "covernode" },
    { 0x0103, "coversearchinterval" },
    { 0x0104, "coversearchintervalafterfailure" },
    { 0x0105, "coverselectoroverride" },
    { 0x0106, "coverstarttime" },
    { 0x0107, "coverstate" },
    { 0x0108, "createstruct" },
    { 0x0109, "criticalbulletdamagedist" },
    { 0x010A, "crouch" },
    { 0x010B, "croucharrivaltype" },
    { 0x010C, "crouchblendratio" },
    { 0x010D, "current" },
    { 0x010E, "currentpose" },
    { 0x010F, "currentprimaryweapon" },
    { 0x0110, "currentweapon" },
    { 0x0111, "cursorhint" },
    { 0x0112, "custom_attach_00" },
    { 0x0113, "custom_attach_01" },
    { 0x0114, "custom_attach_02" },
    { 0x0115, "custom_attach_03" },
    { 0x0116, "custom_attach_04" },
    { 0x0117, "custom_attach_05" },
    { 0x0118, "custom_attach_06" },
    { 0x0119, "custom_attach_07" },
    { 0x011A, "custom_attach_08" },
    { 0x011B, "custom_attach_09" },
    { 0x011C, "custom_attach_10" },
    { 0x011D, "custom_attach_11" },
    { 0x011E, "custom_attach_12" },
    { 0x011F, "custom_attach_13" },
    { 0x0120, "custom_attach_14" },
    { 0x0121, "custom_attach_15" },
    { 0x0122, "damage" },
    { 0x0123, "damage_notdone" },
    { 0x0124, "damagedir" },
    { 0x0125, "damagelocation" },
    { 0x0126, "damagemod" },
    { 0x0127, "damagemultiplier" },
    { 0x0128, "damageradius" },
    { 0x0129, "damageshield" },
    { 0x012A, "damagetaken" },
    { 0x012B, "damageweapon" },
    { 0x012C, "damageyaw" },
    { 0x012D, "dangerreactduration" },
    { 0x012E, "dead" },
    { 0x012F, "death" },
    { 0x0130, "death_timer_length" },
    { 0x0131, "deathinvulnerabletime" },
    { 0x0132, "deathplant" },
    { 0x0133, "deaths" },
    { 0x0134, "deathshield" },
    { 0x0135, "defaultcoverselector" },
    { 0x0136, "delayeddeath" },
    { 0x0137, "deployedlmgnode" },
    { 0x0138, "desiredangle" },
    { 0x0139, "desiredstance" },
    { 0x013A, "destructible_type" },
    { 0x013B, "detonate" },
    { 0x013C, "diequietly" },
    { 0x013D, "diffusefraction" },
    { 0x013E, "direct" },
    { 0x013F, "direction" },
    { 0x0140, "disableautolookat" },
    { 0x0141, "disabledeathorient" },
    { 0x0142, "disablepistol" },
    { 0x0143, "disableplayeradsloscheck" },
    { 0x0144, "disablereload" },
    { 0x0145, "disablereloadwhilemoving" },
    { 0x0146, "disablerunngun" },
    { 0x0147, "disablesniperbehaviors" },
    { 0x0148, "dlight" },
    { 0x0149, "dmg" },
    { 0x014A, "doavoidanceblocking" },
    { 0x014B, "dodamagetoall" },
    { 0x014C, "dodangerreact" },
    { 0x014D, "doffar" },
    { 0x014E, "dofnear" },
    { 0x014F, "dog" },
    { 0x0150, "doghandler" },
    { 0x0151, "doingambush" },
    { 0x0152, "done" },
    { 0x0153, "dontattackme" },
    { 0x0154, "dontavoidplayer" },
    { 0x0155, "dontevershoot" },
    { 0x0156, "dontshootwhilemoving" },
    { 0x0157, "dosharpturnspeedscaling" },
    { 0x0158, "down" },
    { 0x0159, "downaimlimit" },
    { 0x015A, "drawoncompass" },
    { 0x015B, "droppedlmg" },
    { 0x015C, "dropweapon" },
    { 0x015D, "eftarc" },
    { 0x015E, "empty" },
    { 0x015F, "empty_offhand" },
    { 0x0160, "enable" },
    { 0x0161, "enablehudlighting" },
    { 0x0162, "enableshadows" },
    { 0x0163, "end_firing" },
    { 0x0164, "end_firing_left" },
    { 0x0165, "end_script" },
    { 0x0166, "enemy" },
    { 0x0167, "enemy_sighted" },
    { 0x0168, "enemy_sighted_lost" },
    { 0x0169, "enemy_visible" },
    { 0x016A, "enemyselector" },
    { 0x016B, "engagemaxdist" },
    { 0x016C, "engagemaxfalloffdist" },
    { 0x016D, "engagemindist" },
    { 0x016E, "engageminfalloffdist" },
    { 0x016F, "entity" },
    { 0x0170, "entity_used" },
    { 0x0171, "equip_deploy_failed" },
    { 0x0172, "equip_deploy_succeeded" },
    { 0x0173, "equippedweapons" },
    { 0x0174, "exclusive" },
    { 0x0175, "exclusiveinventory" },
    { 0x0176, "explode" },
    { 0x0177, "exposedduration" },
    { 0x0178, "extra" },
    { 0x0179, "extrascore0" },
    { 0x017A, "extrascore1" },
    { 0x017B, "extrascore2" },
    { 0x017C, "extrascore3" },
    { 0x017D, "extravarindex" },
    { 0x017E, "face_angle" },
    { 0x017F, "face_angle_3d" },
    { 0x0180, "face_angle_abs" },
    { 0x0181, "face_angle_rel" },
    { 0x0182, "face_current" },
    { 0x0183, "face_current_angles" },
    { 0x0184, "face_default" },
    { 0x0185, "face_direction" },
    { 0x0186, "face_enemy" },
    { 0x0187, "face_enemy_or_motion" },
    { 0x0188, "face_goal" },
    { 0x0189, "face_motion" },
    { 0x018A, "face_point" },
    { 0x018B, "facemotion" },
    { 0x018C, "failed" },
    { 0x018D, "falling" },
    { 0x018E, "falloff" },
    { 0x018F, "falloffstart" },
    { 0x0190, "fast_radar" },
    { 0x0191, "favoriteenemy" },
    { 0x0192, "finalaccuracy" },
    { 0x0193, "finalangles" },
    { 0x0194, "firetime" },
    { 0x0195, "first_person" },
    { 0x0196, "fixednode" },
    { 0x0197, "fixednodesaferadius" },
    { 0x0198, "flags" },
    { 0x0199, "flash" },
    { 0x019A, "flashbang" },
    { 0x019B, "follow" },
    { 0x019C, "followmax" },
    { 0x019D, "followmin" },
    { 0x019E, "font" },
    { 0x019F, "fontscale" },
    { 0x01A0, "footstepdetectdist" },
    { 0x01A1, "footstepdetectdistsprint" },
    { 0x01A2, "footstepdetectdistwalk" },
    { 0x01A3, "forcenextpathfindimmediate" },
    { 0x01A4, "forceragdollimmediate" },
    { 0x01A5, "forcesidearm" },
    { 0x01A6, "forcespectatorclient" },
    { 0x01A7, "forcestrafe" },
    { 0x01A8, "forcestrafefacingpos" },
    { 0x01A9, "foreground" },
    { 0x01AA, "forward" },
    { 0x01AB, "fov" },
    { 0x01AC, "fovcosine" },
    { 0x01AD, "fovcosinebusy" },
    { 0x01AE, "fovcosineperiph" },
    { 0x01AF, "fovcosineperiphmaxdistsq" },
    { 0x01B0, "fovcosinez" },
    { 0x01B1, "fovforward" },
    { 0x01B2, "fovground" },
    { 0x01B3, "fraction" },
    { 0x01B4, "frag" },
    { 0x01B5, "frameduration" },
    { 0x01B6, "free" },
    { 0x01B7, "free_expendable" },
    { 0x01B8, "freecamera" },
    { 0x01B9, "freelook" },
    { 0x01BA, "front_left" },
    { 0x01BB, "front_right" },
    { 0x01BC, "frontlinedir" },
    { 0x01BD, "frontlineenabled" },
    { 0x01BE, "frontlinepos" },
    { 0x01BF, "frontlineused" },
    { 0x01C0, "frontpiece" },
    { 0x01C1, "frontpiecevarindex" },
    { 0x01C2, "frontshieldanglecos" },
    { 0x01C3, "fusetime" },
    { 0x01C4, "game_extrainfo" },
    { 0x01C5, "generatenavmesh" },
    { 0x01C6, "glass_destroyed" },
    { 0x01C7, "glowalpha" },
    { 0x01C8, "glowcolor" },
    { 0x01C9, "goal" },
    { 0x01CA, "goal_changed" },
    { 0x01CB, "goal_reached" },
    { 0x01CC, "goal_yaw" },
    { 0x01CD, "goalheight" },
    { 0x01CE, "goalnode" },
    { 0x01CF, "goalpos" },
    { 0x01D0, "goalradius" },
    { 0x01D1, "gravity" },
    { 0x01D2, "grenade" },
    { 0x01D3, "grenade_fire" },
    { 0x01D4, "grenade_pullback" },
    { 0x01D5, "grenadeammo" },
    { 0x01D6, "grenadeawareness" },
    { 0x01D7, "grenadedanger" },
    { 0x01D8, "grenadereturnthrowchance" },
    { 0x01D9, "grenadeweapon" },
    { 0x01DA, "groundEntChanged" },
    { 0x01DB, "groundtype" },
    { 0x01DC, "gun_ads" },
    { 0x01DD, "gun_silencer" },
    { 0x01DE, "gunblockedbywall" },
    { 0x01DF, "gundiscipline" },
    { 0x01E0, "gunposeoverride" },
    { 0x01E1, "gunposeoverride_internal" },
    { 0x01E2, "gunshot" },
    { 0x01E3, "gunshot_teammate" },
    { 0x01E4, "hasalternate" },
    { 0x01E5, "hasradar" },
    { 0x01E6, "headindex" },
    { 0x01E7, "health" },
    { 0x01E8, "heavyweapons" },
    { 0x01E9, "height" },
    { 0x01EA, "hidein3rdperson" },
    { 0x01EB, "hidewhendead" },
    { 0x01EC, "hidewhenindemo" },
    { 0x01ED, "hidewheninmenu" },
    { 0x01EE, "high_priority" },
    { 0x01EF, "highlyawareradius" },
    { 0x01F0, "highpriorityweapon" },
    { 0x01F1, "hindlegstraceoffset" },
    { 0x01F2, "hintstring" },
    { 0x01F3, "hit_by_missile" },
    { 0x01F4, "horzalign" },
    { 0x01F5, "host_sucks_end_game" },
    { 0x01F6, "human" },
    { 0x01F7, "ignoreall" },
    { 0x01F8, "ignoreclosefoliage" },
    { 0x01F9, "ignoreexplosionevents" },
    { 0x01FA, "ignoreforfixednodesafecheck" },
    { 0x01FB, "ignoreme" },
    { 0x01FC, "ignoreplayersuppressionlines" },
    { 0x01FD, "ignorerandombulletdamage" },
    { 0x01FE, "ignoresuppression" },
    { 0x01FF, "ignoretriggers" },
    { 0x0200, "index" },
    { 0x0201, "infinite_energy" },
    { 0x0202, "info_notnull" },
    { 0x0203, "info_player_start" },
    { 0x0204, "init" },
    { 0x0205, "initstructs" },
    { 0x0206, "insolid" },
    { 0x0207, "intensity" },
    { 0x0208, "interactable" },
    { 0x0209, "interactive" },
    { 0x020A, "intermission" },
    { 0x020B, "interval" },
    { 0x020C, "intightquarters" },
    { 0x020D, "inventorytype" },
    { 0x020E, "invisible" },
    { 0x020F, "ironsight_off" },
    { 0x0210, "ironsight_on" },
    { 0x0211, "isalternate" },
    { 0x0212, "isauto" },
    { 0x0213, "isbeam" },
    { 0x0214, "isbolt" },
    { 0x0215, "ismelee" },
    { 0x0216, "isradarblocked" },
    { 0x0217, "issemiauto" },
    { 0x0218, "issuspendedvehicle" },
    { 0x0219, "item" },
    { 0x021A, "iteminventory" },
    { 0x021B, "j_eyeball_le" },
    { 0x021C, "j_eyeball_ri" },
    { 0x021D, "j_head" },
    { 0x021E, "j_left_elbow" },
    { 0x021F, "j_left_hand" },
    { 0x0220, "j_left_shoulder" },
    { 0x0221, "j_mainroot" },
    { 0x0222, "j_neck" },
    { 0x0223, "j_spine4" },
    { 0x0224, "j_spinelower" },
    { 0x0225, "j_spineupper" },
    { 0x0226, "jumpcost" },
    { 0x0227, "jumping" },
    { 0x0228, "keepclaimednode" },
    { 0x0229, "keepclaimednodeifvalid" },
    { 0x022A, "keepnodeduringscriptedanim" },
    { 0x022B, "key1" },
    { 0x022C, "key2" },
    { 0x022D, "killanimscript" },
    { 0x022E, "killcamentity" },
    { 0x022F, "killcamentitylookat" },
    { 0x0230, "kills" },
    { 0x0231, "known_event" },
    { 0x0232, "label" },
    { 0x0233, "ladder_down" },
    { 0x0234, "ladder_up" },
    { 0x0235, "land" },
    { 0x0236, "lastattacker" },
    { 0x0237, "lastenemysightpos" },
    { 0x0238, "laststand" },
    { 0x0239, "ledge" },
    { 0x023A, "left" },
    { 0x023B, "leftaimlimit" },
    { 0x023C, "leftarc" },
    { 0x023D, "lerpduration" },
    { 0x023E, "light" },
    { 0x023F, "lightmap" },
    { 0x0240, "lmaplookup" },
    { 0x0241, "lockorientation" },
    { 0x0242, "lod" },
    { 0x0243, "look" },
    { 0x0244, "lookahead" },
    { 0x0245, "lookaheaddir" },
    { 0x0246, "lookaheaddist" },
    { 0x0247, "lookforward" },
    { 0x0248, "lookposition" },
    { 0x0249, "lookright" },
    { 0x024A, "looktarget" },
    { 0x024B, "lookup" },
    { 0x024C, "low_priority" },
    { 0x024D, "lowresbackground" },
    { 0x024E, "lui_notify_callback" },
    { 0x024F, "luinotifyserver" },
    { 0x0250, "mag_eject" },
    { 0x0251, "mag_eject_left" },
    { 0x0252, "magazine" },
    { 0x0253, "magazinevarindex" },
    { 0x0254, "main" },
    { 0x0255, "makecorpse" },
    { 0x0256, "manual" },
    { 0x0257, "manual_ai" },
    { 0x0258, "manual_change" },
    { 0x0259, "mapentlookup" },
    { 0x025A, "material" },
    { 0x025B, "max_time" },
    { 0x025C, "maxammo" },
    { 0x025D, "maxdamage" },
    { 0x025E, "maxfaceenemydist" },
    { 0x025F, "maxfaceenemydistslow" },
    { 0x0260, "maxfacenewenemydist" },
    { 0x0261, "maxhealth" },
    { 0x0262, "maxrange" },
    { 0x0263, "maxrunngunangle" },
    { 0x0264, "maxsightdistsqrd" },
    { 0x0265, "maxvisibledist" },
    { 0x0266, "meleeattackdist" },
    { 0x0267, "meleechargedist" },
    { 0x0268, "meleechargedistvsplayer" },
    { 0x0269, "meleemaxzdiff" },
    { 0x026A, "meleerequested" },
    { 0x026B, "meleerequestedcharge" },
    { 0x026C, "meleeweapons" },
    { 0x026D, "menuresponse" },
    { 0x026E, "middle_left" },
    { 0x026F, "middle_right" },
    { 0x0270, "min_energy" },
    { 0x0271, "min_time" },
    { 0x0272, "mincornerspeedscalingmultiplier" },
    { 0x0273, "mindamage" },
    { 0x0274, "minpaindamage" },
    { 0x0275, "minusedistsq" },
    { 0x0276, "missile_fire" },
    { 0x0277, "missile_stuck" },
    { 0x0278, "mod_crush" },
    { 0x0279, "mod_explosive" },
    { 0x027A, "mod_explosive_bullet" },
    { 0x027B, "mod_falling" },
    { 0x027C, "mod_fire" },
    { 0x027D, "mod_fire_bullet" },
    { 0x027E, "mod_grenade" },
    { 0x027F, "mod_grenade_splash" },
    { 0x0280, "mod_head_shot" },
    { 0x0281, "mod_impact" },
    { 0x0282, "mod_melee" },
    { 0x0283, "mod_melee_alien" },
    { 0x0284, "mod_melee_dog" },
    { 0x0285, "mod_pistol_bullet" },
    { 0x0286, "mod_projectile" },
    { 0x0287, "mod_projectile_splash" },
    { 0x0288, "mod_rifle_bullet" },
    { 0x0289, "mod_suicide" },
    { 0x028A, "mod_trigger_hurt" },
    { 0x028B, "mod_unknown" },
    { 0x028C, "model" },
    { 0x028D, "modelname" },
    { 0x028E, "modifier" },
    { 0x028F, "modifiervarindex" },
    { 0x0290, "movedelta" },
    { 0x0291, "movedone" },
    { 0x0292, "movemode" },
    { 0x0293, "movetype" },
    { 0x0294, "muzzle" },
    { 0x0295, "muzzlevarindex" },
    { 0x0296, "name" },
    { 0x0297, "navvolume_ignoreglass" },
    { 0x0298, "navvolume_worldonly" },
    { 0x0299, "near_goal" },
    { 0x029A, "nearz" },
    { 0x029B, "neutral" },
    { 0x029C, "neutralsenses" },
    { 0x029D, "never" },
    { 0x029E, "newenemyreaction" },
    { 0x029F, "newenemyreactiondistsq" },
    { 0x02A0, "newenemyreactiontime" },
    { 0x02A1, "nextlookforcovertime" },
    { 0x02A2, "night_vision_off" },
    { 0x02A3, "night_vision_on" },
    { 0x02A4, "no_cover" },
    { 0x02A5, "no_gravity" },
    { 0x02A6, "noattackeraccuracymod" },
    { 0x02A7, "noclip" },
    { 0x02A8, "node" },
    { 0x02A9, "node_bad" },
    { 0x02AA, "node_out_of_range" },
    { 0x02AB, "node_relinquished" },
    { 0x02AC, "nododgemove" },
    { 0x02AD, "nogravity" },
    { 0x02AE, "nogrenadereturnthrow" },
    { 0x02AF, "noncombat" },
    { 0x02B0, "none" },
    { 0x02B1, "nophysics" },
    { 0x02B2, "normal" },
    { 0x02B3, "normal_radar" },
    { 0x02B4, "northyaw" },
    { 0x02B5, "notarget" },
    { 0x02B6, "notinsolid" },
    { 0x02B7, "obstacle" },
    { 0x02B8, "offhand" },
    { 0x02B9, "offhand_end" },
    { 0x02BA, "offhandinventory" },
    { 0x02BB, "offhandweapon" },
    { 0x02BC, "offsetx" },
    { 0x02BD, "offsety" },
    { 0x02BE, "ondeactivate" },
    { 0x02BF, "onenterstate" },
    { 0x02C0, "only_sky" },
    { 0x02C1, "onlygoodnearestnodes" },
    { 0x02C2, "onlytakedamagefromplayer" },
    { 0x02C3, "oriented" },
    { 0x02C4, "orientto_complete" },
    { 0x02C5, "origin" },
    { 0x02C6, "origin_offset" },
    { 0x02C7, "other" },
    { 0x02C8, "others" },
    { 0x02C9, "othervarindices" },
    { 0x02CA, "over" },
    { 0x02CB, "override" },
    { 0x02CC, "overridevarindex" },
    { 0x02CD, "owner" },
    { 0x02CE, "pacifist" },
    { 0x02CF, "pacifistwait" },
    { 0x02D0, "pain" },
    { 0x02D1, "parentangles" },
    { 0x02D2, "parentindex" },
    { 0x02D3, "parentname" },
    { 0x02D4, "parentpos" },
    { 0x02D5, "partname" },
    { 0x02D6, "path_blocked" },
    { 0x02D7, "path_changed" },
    { 0x02D8, "path_dir_change" },
    { 0x02D9, "path_enemy" },
    { 0x02DA, "path_need_dodge" },
    { 0x02DB, "path_set" },
    { 0x02DC, "pathenemyfightdist" },
    { 0x02DD, "pathenemylookahead" },
    { 0x02DE, "pathgoalpos" },
    { 0x02DF, "pathpending" },
    { 0x02E0, "pathrandompercent" },
    { 0x02E1, "pathsmoothmultiplier" },
    { 0x02E2, "pc" },
    { 0x02E3, "pelvis" },
    { 0x02E4, "pers" },
    { 0x02E5, "physics_finished" },
    { 0x02E6, "pickup" },
    { 0x02E7, "pistol" },
    { 0x02E8, "pitchconvergencetime" },
    { 0x02E9, "plane_waypoint" },
    { 0x02EA, "player" },
    { 0x02EB, "playerSpread" },
    { 0x02EC, "player_pushed" },
    { 0x02ED, "playercardbackground" },
    { 0x02EE, "playercardpatch" },
    { 0x02EF, "playercardpatchbacking" },
    { 0x02F0, "playercontrol" },
    { 0x02F1, "playing" },
    { 0x02F2, "point" },
    { 0x02F3, "position" },
    { 0x02F4, "postsharpturnlookaheaddist" },
    { 0x02F5, "precache" },
    { 0x02F6, "predicted_projectile_impact" },
    { 0x02F7, "predictedfacemotion" },
    { 0x02F8, "preferreddrop" },
    { 0x02F9, "prevanimdelta" },
    { 0x02FA, "prevcovernode" },
    { 0x02FB, "previous" },
    { 0x02FC, "prevnode" },
    { 0x02FD, "prevscript" },
    { 0x02FE, "primary" },
    { 0x02FF, "primaryinventory" },
    { 0x0300, "primaryoffhand" },
    { 0x0301, "primaryweapon" },
    { 0x0302, "primaryweapons" },
    { 0x0303, "projectile_impact" },
    { 0x0304, "projectile_ping" },
    { 0x0305, "prone" },
    { 0x0306, "proneok" },
    { 0x0307, "providecoveringfire" },
    { 0x0308, "ps4" },
    { 0x0309, "psoffsettime" },
    { 0x030A, "pushable" },
    { 0x030B, "radarmode" },
    { 0x030C, "radarshowenemydirection" },
    { 0x030D, "radarstrength" },
    { 0x030E, "radius" },
    { 0x030F, "ragdoll_early_result" },
    { 0x0310, "reached_end_node" },
    { 0x0311, "reached_wait_node" },
    { 0x0312, "reached_wait_speed" },
    { 0x0313, "reacquiresteptime" },
    { 0x0314, "readonly" },
    { 0x0315, "reargrip" },
    { 0x0316, "reargripvarindex" },
    { 0x0317, "receiver" },
    { 0x0318, "receivervarindex" },
    { 0x0319, "reflection_clear_color" },
    { 0x031A, "relativedir" },
    { 0x031B, "reload" },
    { 0x031C, "reload_start" },
    { 0x031D, "remainexposedendtime" },
    { 0x031E, "rendertotexture" },
    { 0x031F, "repeatcoverfindiffailed" },
    { 0x0320, "requestarrivalnotify" },
    { 0x0321, "requestdifferentcover" },
    { 0x0322, "requestedgoalpos" },
    { 0x0323, "result" },
    { 0x0324, "reticle" },
    { 0x0325, "return_pitch" },
    { 0x0326, "reverse" },
    { 0x0327, "right" },
    { 0x0328, "rightaimlimit" },
    { 0x0329, "rightarc" },
    { 0x032A, "rigindex" },
    { 0x032B, "riotshield_damaged" },
    { 0x032C, "rocket" },
    { 0x032D, "rocketammo" },
    { 0x032E, "rotatedone" },
    { 0x032F, "rotation" },
    { 0x0330, "run" },
    { 0x0331, "runcost" },
    { 0x0332, "runngun" },
    { 0x0333, "runnguntime" },
    { 0x0334, "runpassthroughtype" },
    { 0x0335, "runto_arrived" },
    { 0x0336, "safetochangescript" },
    { 0x0337, "scalex" },
    { 0x0338, "scaley" },
    { 0x0339, "scavenger" },
    { 0x033A, "scavengerinventory" },
    { 0x033B, "scope" },
    { 0x033C, "scope_ads" },
    { 0x033D, "scope_cap" },
    { 0x033E, "scope_center" },
    { 0x033F, "scope_top" },
    { 0x0340, "scopevarindex" },
    { 0x0341, "score" },
    { 0x0342, "script" },
    { 0x0343, "script_brushmodel" },
    { 0x0344, "script_damage" },
    { 0x0345, "script_delay" },
    { 0x0346, "script_delete" },
    { 0x0347, "script_earthquake" },
    { 0x0348, "script_envonly" },
    { 0x0349, "script_exploder" },
    { 0x034A, "script_linkname" },
    { 0x034B, "script_linkto" },
    { 0x034C, "script_model" },
    { 0x034D, "script_noteworthy" },
    { 0x034E, "script_origin" },
    { 0x034F, "script_parent" },
    { 0x0350, "script_parentname" },
    { 0x0351, "script_pushable" },
    { 0x0352, "script_radius" },
    { 0x0353, "script_rumble" },
    { 0x0354, "script_trace" },
    { 0x0355, "script_vehicle" },
    { 0x0356, "script_vehicle_collision" },
    { 0x0357, "script_vehicle_collmap" },
    { 0x0358, "script_vehicle_corpse" },
    { 0x0359, "script_visionset" },
    { 0x035A, "script_zone" },
    { 0x035B, "scriptable" },
    { 0x035C, "scriptable_initialize" },
    { 0x035D, "scriptable_notify_callback" },
    { 0x035E, "scriptable_touched" },
    { 0x035F, "scriptable_post_initialize" },
    { 0x0360, "scriptable_used" },
    { 0x0361, "scriptbundlename" },
    { 0x0362, "scriptedarrivalent" },
    { 0x0363, "scriptgoalpos" },
    { 0x0364, "search_end" },
    { 0x0365, "secondaryoffhand" },
    { 0x0366, "secondaryweapon" },
    { 0x0367, "sentry" },
    { 0x0368, "sentry_offline" },
    { 0x0369, "sessionstate" },
    { 0x036A, "sessionteam" },
    { 0x036B, "shapeindex" },
    { 0x036C, "sharpturnforceusevelocity" },
    { 0x036D, "sharpturnlookaheaddist" },
    { 0x036E, "sharpturnnotifydist" },
    { 0x036F, "sharpturntooclosetodestdist" },
    { 0x0370, "shoot_firstshot" },
    { 0x0371, "shootparams_bconvergeontarget" },
    { 0x0372, "shootparams_burstcount" },
    { 0x0373, "shootparams_buseentinshootcalc" },
    { 0x0374, "shootparams_ent" },
    { 0x0375, "shootparams_fastburst" },
    { 0x0376, "shootparams_numburstsleft" },
    { 0x0377, "shootparams_objective" },
    { 0x0378, "shootparams_pos" },
    { 0x0379, "shootparams_readid" },
    { 0x037A, "shootparams_shotsperburst" },
    { 0x037B, "shootparams_starttime" },
    { 0x037C, "shootparams_style" },
    { 0x037D, "shootparams_taskid" },
    { 0x037E, "shootparams_valid" },
    { 0x037F, "shootparams_writeid" },
    { 0x0380, "shootstyleoverride" },
    { 0x0381, "shouldinitiallyattackfromexposed" },
    { 0x0382, "showinkillcam" },
    { 0x0383, "shufflenode" },
    { 0x0384, "sidearm" },
    { 0x0385, "sightlatency" },
    { 0x0386, "silenced_shot" },
    { 0x0387, "slidevelocity" },
    { 0x0388, "slowmo_active" },
    { 0x0389, "slowmo_passive" },
    { 0x038A, "smartfacingpos" },
    { 0x038B, "smoke" },
    { 0x038C, "snd_channelvolprio_holdbreath" },
    { 0x038D, "snd_channelvolprio_pain" },
    { 0x038E, "snd_channelvolprio_shellshock" },
    { 0x038F, "snd_enveffectsprio_level" },
    { 0x0390, "snd_enveffectsprio_shellshock" },
    { 0x0391, "sort" },
    { 0x0392, "sound_blend" },
    { 0x0393, "sound_transient_soundbanks" },
    { 0x0394, "space" },
    { 0x0395, "spaceship_accel" },
    { 0x0396, "spaceship_boosting" },
    { 0x0397, "spaceship_mode" },
    { 0x0398, "spaceship_rotaccel" },
    { 0x0399, "spaceship_rotvel" },
    { 0x039A, "spaceship_vel" },
    { 0x039B, "spawned" },
    { 0x039C, "spawner" },
    { 0x039D, "spawnflags" },
    { 0x039E, "spectatekillcam" },
    { 0x039F, "spectating_cycle" },
    { 0x03A0, "spectator" },
    { 0x03A1, "speed" },
    { 0x03A2, "speedscalemult" },
    { 0x03A3, "splatter" },
    { 0x03A4, "splinenode_angles" },
    { 0x03A5, "splinenode_corridor_height" },
    { 0x03A6, "splinenode_corridor_width" },
    { 0x03A7, "splinenode_label" },
    { 0x03A8, "splinenode_speed" },
    { 0x03A9, "splinenode_string" },
    { 0x03AA, "splinenode_tension" },
    { 0x03AB, "splinenode_throttle" },
    { 0x03AC, "splittime" },
    { 0x03AD, "sprint_begin" },
    { 0x03AE, "sprint_end" },
    { 0x03AF, "squadmovementallowed" },
    { 0x03B0, "squadnumber" },
    { 0x03B1, "squareaspectratio" },
    { 0x03B2, "stairsstate" },
    { 0x03B3, "stand" },
    { 0x03B4, "start_blend" },
    { 0x03B5, "start_move" },
    { 0x03B6, "start_ragdoll" },
    { 0x03B7, "startammo" },
    { 0x03B8, "startpos" },
    { 0x03B9, "statelocked" },
    { 0x03BA, "statusicon" },
    { 0x03BB, "stealth" },
    { 0x03BC, "stickerslot0" },
    { 0x03BD, "stickerslot1" },
    { 0x03BE, "stickerslot2" },
    { 0x03BF, "stickerslot3" },
    { 0x03C0, "stop" },
    { 0x03C1, "stop_soon" },
    { 0x03C2, "stopanim" },
    { 0x03C3, "stopanimdistsq" },
    { 0x03C4, "stopsoonnotifydist" },
    { 0x03C5, "subpartname" },
    { 0x03C6, "subpartstate" },
    { 0x03C7, "suncolor" },
    { 0x03C8, "sundirection" },
    { 0x03C9, "sunlight" },
    { 0x03CA, "superMeterProgress" },
    { 0x03CB, "suppression" },
    { 0x03CC, "suppressionTime" },
    { 0x03CD, "suppression_end" },
    { 0x03CE, "suppressiondecrement" },
    { 0x03CF, "suppressionduration" },
    { 0x03D0, "suppressionmeter" },
    { 0x03D1, "suppressionstarttime" },
    { 0x03D2, "suppressionwait" },
    { 0x03D3, "surfacetype" },
    { 0x03D4, "surprisedbymedistsq" },
    { 0x03D5, "suspendvehicle" },
    { 0x03D6, "swimmer" },
    { 0x03D7, "syncedmeleetarget" },
    { 0x03D8, "tag" },
    { 0x03D9, "tag_aim" },
    { 0x03DA, "tag_aim_animated" },
    { 0x03DB, "tag_aim_pivot" },
    { 0x03DC, "tag_barrel" },
    { 0x03DD, "tag_blade_off" },
    { 0x03DE, "tag_body" },
    { 0x03DF, "tag_brass" },
    { 0x03E0, "tag_butt" },
    { 0x03E1, "tag_cambone" },
    { 0x03E2, "tag_camera" },
    { 0x03E3, "tag_charge_fx01" },
    { 0x03E4, "tag_charge_fx02" },
    { 0x03E5, "tag_charge_fx03" },
    { 0x03E6, "tag_charge_fx04" },
    { 0x03E7, "tag_charge_fx05" },
    { 0x03E8, "tag_charge_fx06" },
    { 0x03E9, "tag_charge_fx07" },
    { 0x03EA, "tag_charge_fx08" },
    { 0x03EB, "tag_charge_fx09" },
    { 0x03EC, "tag_charge_fx10" },
    { 0x03ED, "tag_charge_fx11" },
    { 0x03EE, "tag_charge_fx12" },
    { 0x03EF, "tag_charge_fx13" },
    { 0x03F0, "tag_charge_fx14" },
    { 0x03F1, "tag_charge_fx15" },
    { 0x03F2, "tag_charge_fx16" },
    { 0x03F3, "tag_clip" },
    { 0x03F4, "tag_detach" },
    { 0x03F5, "tag_engine_left" },
    { 0x03F6, "tag_engine_right" },
    { 0x03F7, "tag_eotech_reticle" },
    { 0x03F8, "tag_eye" },
    { 0x03F9, "tag_flash" },
    { 0x03FA, "tag_flash_2" },
    { 0x03FB, "tag_flash_silenced" },
    { 0x03FC, "tag_fx" },
    { 0x03FD, "tag_gasmask" },
    { 0x03FE, "tag_gasmask2" },
    { 0x03FF, "tag_glass_ads" },
    { 0x0400, "tag_glass_ads2" },
    { 0x0401, "tag_glass_hip" },
    { 0x0402, "tag_glass_hip2" },
    { 0x0403, "tag_ik_loc_le" },
    { 0x0404, "tag_ik_loc_le_foregrip" },
    { 0x0405, "tag_ik_loc_le_launcher" },
    { 0x0406, "tag_ik_loc_le_shotgun" },
    { 0x0407, "tag_inhand" },
    { 0x0408, "tag_knife_fx" },
    { 0x0409, "tag_laser" },
    { 0x040A, "tag_launcher" },
    { 0x040B, "tag_magnifier_eotech_reticle" },
    { 0x040C, "tag_motion_tracker_bl" },
    { 0x040D, "tag_motion_tracker_br" },
    { 0x040E, "tag_motion_tracker_fx" },
    { 0x040F, "tag_motion_tracker_tl" },
    { 0x0410, "tag_origin" },
    { 0x0411, "tag_player" },
    { 0x0412, "tag_popout" },
    { 0x0413, "tag_reticle_acog" },
    { 0x0414, "tag_reticle_hamr" },
    { 0x0415, "tag_reticle_on" },
    { 0x0416, "tag_reticle_red_dot" },
    { 0x0417, "tag_reticle_reflex" },
    { 0x0418, "tag_reticle_tavor_scope" },
    { 0x0419, "tag_reticle_thermal_scope" },
    { 0x041A, "tag_shield_back" },
    { 0x041B, "tag_shotgun" },
    { 0x041C, "tag_show_alt" },
    { 0x041D, "tag_stowed_back" },
    { 0x041E, "tag_stowed_hip_rear" },
    { 0x041F, "tag_sync" },
    { 0x0420, "tag_turret" },
    { 0x0421, "tag_turret_base" },
    { 0x0422, "tag_weapon" },
    { 0x0423, "tag_weapon_chest" },
    { 0x0424, "tag_weapon_left" },
    { 0x0425, "tag_weapon_right" },
    { 0x0426, "tag_wheel_back_left" },
    { 0x0427, "tag_wheel_back_right" },
    { 0x0428, "tag_wheel_front_left" },
    { 0x0429, "tag_wheel_front_right" },
    { 0x042A, "tag_wheel_middle_left" },
    { 0x042B, "tag_wheel_middle_right" },
    { 0x042C, "tagname" },
    { 0x042D, "takedamage" },
    { 0x042E, "target" },
    { 0x042F, "target_script_trigger" },
    { 0x0430, "targetname" },
    { 0x0431, "team" },
    { 0x0432, "team3" },
    { 0x0433, "teammode_axisallies" },
    { 0x0434, "teammode_ffa" },
    { 0x0435, "teammovewaittime" },
    { 0x0436, "thermal" },
    { 0x0437, "thermalbodymaterial" },
    { 0x0438, "third_person" },
    { 0x0439, "threatbias" },
    { 0x043A, "threatbiasgroup" },
    { 0x043B, "threatsight" },
    { 0x043C, "threatsightdistmax" },
    { 0x043D, "threatsightdistmin" },
    { 0x043E, "threatsightratemax" },
    { 0x043F, "threatsightratemin" },
    { 0x0440, "threshold" },
    { 0x0441, "throwbackweapon" },
    { 0x0442, "throwingknife" },
    { 0x0443, "timemodified" },
    { 0x0444, "top" },
    { 0x0445, "toparc" },
    { 0x0446, "totalscore" },
    { 0x0447, "touch" },
    { 0x0448, "touching_platform" },
    { 0x0449, "trackmoverup" },
    { 0x044A, "transient_entity" },
    { 0x044B, "transients_synced" },
    { 0x044C, "traverse_complete" },
    { 0x044D, "traverse_soon" },
    { 0x044E, "traversecost" },
    { 0x044F, "traversesoonnotifydist" },
    { 0x0450, "trigger" },
    { 0x0451, "trigger_damage" },
    { 0x0452, "trigger_use" },
    { 0x0453, "trigger_use_touch" },
    { 0x0454, "triggervarindex" },
    { 0x0455, "truck_cam" },
    { 0x0456, "turningpoint" },
    { 0x0457, "turnrate" },
    { 0x0458, "turnthreshold" },
    { 0x0459, "turret_deactivate" },
    { 0x045A, "turret_fire" },
    { 0x045B, "turret_no_vis" },
    { 0x045C, "turret_not_on_target" },
    { 0x045D, "turret_on_target" },
    { 0x045E, "turret_on_vistarget" },
    { 0x045F, "turret_pitch_clamped" },
    { 0x0460, "turret_rotate_stopped" },
    { 0x0461, "turret_yaw_clamped" },
    { 0x0462, "turretinvulnerability" },
    { 0x0463, "turretownerchange" },
    { 0x0464, "turretstatechange" },
    { 0x0465, "type" },
    { 0x0466, "underbarrel" },
    { 0x0467, "underbarrelvarindex" },
    { 0x0468, "unittype" },
    { 0x0469, "unresolved_collision" },
    { 0x046A, "unsafe" },
    { 0x046B, "unusable" },
    { 0x046C, "up" },
    { 0x046D, "upaimlimit" },
    { 0x046E, "useable" },
    { 0x046F, "useanimgoalweight" },
    { 0x0470, "usechokepoints" },
    { 0x0471, "usecommand" },
    { 0x0472, "usepriority" },
    { 0x0473, "usestrictreacquiresightshoot" },
    { 0x0474, "usingnavmesh" },
    { 0x0475, "variantid" },
    { 0x0476, "veh_boatbounce" },
    { 0x0477, "veh_brake" },
    { 0x0478, "veh_collision" },
    { 0x0479, "veh_jolt" },
    { 0x047A, "veh_landed" },
    { 0x047B, "veh_leftground" },
    { 0x047C, "veh_origin" },
    { 0x047D, "veh_pathdir" },
    { 0x047E, "veh_pathspeed" },
    { 0x047F, "veh_pathtype" },
    { 0x0480, "veh_predictedcollision" },
    { 0x0481, "veh_speed" },
    { 0x0482, "veh_throttle" },
    { 0x0483, "veh_topspeed" },
    { 0x0484, "veh_transmission" },
    { 0x0485, "vehicle_dismount" },
    { 0x0486, "vehicle_mount" },
    { 0x0487, "vehicletype" },
    { 0x0488, "velocity" },
    { 0x0489, "vertalign" },
    { 0x048A, "view_jostle" },
    { 0x048B, "visionsetmissilecam" },
    { 0x048C, "visionsetmissilecamduration" },
    { 0x048D, "visionsetnaked" },
    { 0x048E, "visionsetnakedduration" },
    { 0x048F, "visionsetnight" },
    { 0x0490, "visionsetnightduration" },
    { 0x0491, "visionsetpain" },
    { 0x0492, "visionsetpainduration" },
    { 0x0493, "visionsetthermal" },
    { 0x0494, "visionsetthermalduration" },
    { 0x0495, "visor_down" },
    { 0x0496, "visual" },
    { 0x0497, "visualvarindex" },
    { 0x0498, "vote" },
    { 0x0499, "wait" },
    { 0x049A, "wakeupvehicle" },
    { 0x049B, "walk" },
    { 0x049C, "walkdist" },
    { 0x049D, "walkdistfacingmotion" },
    { 0x049E, "waypoint_reached" },
    { 0x049F, "weapon" },
    { 0x04A0, "weapon_change" },
    { 0x04A1, "weapon_dropped" },
    { 0x04A2, "weapon_fired" },
    { 0x04A3, "weapon_switch_started" },
    { 0x04A4, "weapon_taken" },
    { 0x04A5, "weaponchange" },
    { 0x04A6, "weaponinfo" },
    { 0x04A7, "weaponname" },
    { 0x04A8, "weaponrail_on" },
    { 0x04A9, "weaponrequest" },
    { 0x04AA, "weights" },
    { 0x04AB, "width" },
    { 0x04AC, "world" },
    { 0x04AD, "worldspawn" },
    { 0x04AE, "x" },
    { 0x04AF, "xb3" },
    { 0x04B0, "xuid" },
    { 0x04B1, "y" },
    { 0x04B2, "yawconvergencetime" },
    { 0x04B3, "z" },
    { 0x04B4, "zonly_physics" },
    { 0x04B5, "aiasm/civilian_mp" },
    { 0x04B6, "aiasm/civilian_sp" },
    { 0x04B7, "aiasm/corner_cover_lean_shoot_mp" },
    { 0x04B8, "aiasm/corner_cover_lean_shoot_sp" },
    { 0x04B9, "aiasm/dog_sp" },
    { 0x04BA, "aiasm/gesture_mp" },
    { 0x04BB, "aiasm/gesture_sp" },
    { 0x04BC, "aiasm/playerasm_mp" },
    { 0x04BD, "aiasm/playerasm_sp" },
    { 0x04BE, "aiasm/playerasm_sub_mp" },
    { 0x04BF, "aiasm/playerasm_sub_sp" },
    { 0x04C0, "aiasm/playerasm_void_mp" },
    { 0x04C1, "aiasm/playerasm_void_sp" },
    { 0x04C2, "aiasm/shoot_mp" },
    { 0x04C3, "aiasm/shoot_sp" },
    { 0x04C4, "aiasm/soldier_mp" },
    { 0x04C5, "aiasm/soldier_sp" },
    { 0x04C6, "aiasm/suicidebomber_mp" },
    { 0x04C7, "aiasm/suicidebomber_sp" },
    { 0x04C8, "behaviortree/civilian" },
    { 0x04C9, "behaviortree/civilian_agent" },
    { 0x04CA, "behaviortree/dog" },
    { 0x04CB, "behaviortree/enemy_combatant" },
    { 0x04CC, "behaviortree/juggernaut" },
    { 0x04CD, "behaviortree/juggernaut_agent" },
    { 0x04CE, "behaviortree/soldier_agent" },
    { 0x04CF, "behaviortree/suicidebomber" },
    { 0x04D0, "behaviortree/suicidebomber_agent" },
    { 0x04D1, "character/alq_syrkistan_female_scarf_purple" },
    { 0x04D2, "character/alq_syrkistan_female_scarf_red" },
    { 0x04D3, "character/character_al_qatala_desert_ar" },
    { 0x04D4, "character/character_al_qatala_desert_ar_2" },
    { 0x04D5, "character/character_al_qatala_desert_ar_3" },
    { 0x04D6, "character/character_al_qatala_desert_ar_4" },
    { 0x04D7, "character/character_al_qatala_desert_cqc" },
    { 0x04D8, "character/character_al_qatala_desert_lmg" },
    { 0x04D9, "character/character_al_qatala_trials" },
    { 0x04DA, "character/character_al_qatala_urban_a6_variant" },
    { 0x04DB, "character/character_al_qatala_urban_ar_variant" },
    { 0x04DC, "character/character_al_qatala_urban_bomber" },
    { 0x04DD, "character/character_al_qatala_urban_civ_1" },
    { 0x04DE, "character/character_al_qatala_urban_civ_2" },
    { 0x04DF, "character/character_al_qatala_urban_civ_3" },
    { 0x04E0, "character/character_al_qatala_urban_civ_4" },
    { 0x04E1, "character/character_al_qatala_urban_civ_5" },
    { 0x04E2, "character/character_al_qatala_urban_civ_6" },
    { 0x04E3, "character/character_al_qatala_urban_civ_7" },
    { 0x04E4, "character/character_al_qatala_urban_civ_8" },
    { 0x04E5, "character/character_al_qatala_urban_civ_9" },
    { 0x04E6, "character/character_al_qatala_urban_cqb_variant" },
    { 0x04E7, "character/character_al_qatala_urban_lmg_variant" },
    { 0x04E8, "character/character_ally_so15_1" },
    { 0x04E9, "character/character_ally_so15_2" },
    { 0x04EA, "character/character_ally_so15_3" },
    { 0x04EB, "character/character_barkov_captive" },
    { 0x04EC, "character/character_civ_male_rus_clerical_1" },
    { 0x04ED, "character/character_civ_male_rus_clerical_2" },
    { 0x04EE, "character/character_civ_male_rus_clerical_3" },
    { 0x04EF, "character/character_civ_russian_police_officer" },
    { 0x04F0, "character/character_civilian_me_female" },
    { 0x04F1, "character/character_civilian_me_female_cp" },
    { 0x04F2, "character/character_civilian_me_female_embassy" },
    { 0x04F3, "character/character_civilian_me_female_embassy_mom" },
    { 0x04F4, "character/character_civilian_me_female_veil" },
    { 0x04F5, "character/character_civilian_me_female_wrap" },
    { 0x04F6, "character/character_civilian_me_male" },
    { 0x04F7, "character/character_civilian_me_male_cinderblock_a" },
    { 0x04F8, "character/character_civilian_me_male_cinderblock_b" },
    { 0x04F9, "character/character_civilian_me_male_cinderblock_c" },
    { 0x04FA, "character/character_civilian_me_male_cinderblock_d" },
    { 0x04FB, "character/character_civilian_me_male_cp" },
    { 0x04FC, "character/character_civilian_me_male_dist" },
    { 0x04FD, "character/character_civilian_me_male_embassy" },
    { 0x04FE, "character/character_civilian_me_male_embassy_dad" },
    { 0x04FF, "character/character_civilian_me_male_veil" },
    { 0x0500, "character/character_civilian_syrkistan_boy_1_1" },
    { 0x0501, "character/character_civilian_syrkistan_boy_2_1" },
    { 0x0502, "character/character_civilian_syrkistan_boy_3_1" },
    { 0x0503, "character/character_civilian_syrkistan_boy_4_1" },
    { 0x0504, "character/character_civilian_syrkistan_boy_5_1" },
    { 0x0505, "character/character_civilian_syrkistan_boy_6_1" },
    { 0x0506, "character/character_cp_al_qatala_desert_ar" },
    { 0x0507, "character/character_cp_al_qatala_desert_ar_2" },
    { 0x0508, "character/character_cp_al_qatala_desert_ar_3" },
    { 0x0509, "character/character_cp_al_qatala_desert_ar_4" },
    { 0x050A, "character/character_cp_al_qatala_desert_cqc" },
    { 0x050B, "character/character_cp_al_qatala_desert_dmr" },
    { 0x050C, "character/character_cp_al_qatala_desert_lmg" },
    { 0x050D, "character/character_eastern_yegor_1_1" },
    { 0x050E, "character/character_hero_alex_desert" },
    { 0x050F, "character/character_hero_alex_urban" },
    { 0x0510, "character/character_hero_farah_disguised" },
    { 0x0511, "character/character_hero_farah_disguised_soldier" },
    { 0x0512, "character/character_hero_griggs_desert" },
    { 0x0513, "character/character_hero_hadir_prisoner" },
    { 0x0514, "character/character_hero_hadir_pw" },
    { 0x0515, "character/character_hero_hadir_urban" },
    { 0x0516, "character/character_hero_hadir_young" },
    { 0x0517, "character/character_hero_kyle_desert" },
    { 0x0518, "character/character_hero_kyle_so15" },
    { 0x0519, "character/character_hero_kyle_undercover" },
    { 0x051A, "character/character_hero_kyle_urban" },
    { 0x051B, "character/character_hero_kyle_woodland" },
    { 0x051C, "character/character_hero_kyle_woodland_nvg" },
    { 0x051D, "character/character_hero_nikolai_lab" },
    { 0x051E, "character/character_hero_nikolai_st_petersburg" },
    { 0x051F, "character/character_hero_price_desert" },
    { 0x0520, "character/character_hero_price_undercover" },
    { 0x0521, "character/character_hero_price_urban" },
    { 0x0522, "character/character_hero_price_urban_nvg" },
    { 0x0523, "character/character_hero_price_woodland" },
    { 0x0524, "character/character_hero_price_woodland_nvg" },
    { 0x0525, "character/character_hero_price_young" },
    { 0x0526, "character/character_hero_tarik" },
    { 0x0527, "character/character_iw8_al_qatala_desert_1" },
    { 0x0528, "character/character_iw8_al_qatala_desert_2" },
    { 0x0529, "character/character_iw8_al_qatala_desert_2_rpg_helmet" },
    { 0x052A, "character/character_iw8_al_qatala_desert_3" },
    { 0x052B, "character/character_iw8_al_qatala_desert_4" },
    { 0x052C, "character/character_iw8_al_qatala_desert_5" },
    { 0x052D, "character/character_iw8_al_qatala_desert_6" },
    { 0x052E, "character/character_iw8_al_qatala_desert_7" },
    { 0x052F, "character/character_iw8_al_qatala_desert_8" },
    { 0x0530, "character/character_iw8_al_qatala_desert_9" },
    { 0x0531, "character/character_iw8_al_qatala_desert_9_rpg" },
    { 0x0532, "character/character_iw8_al_qatala_urban_01" },
    { 0x0533, "character/character_iw8_al_qatala_urban_02" },
    { 0x0534, "character/character_iw8_al_qatala_urban_03" },
    { 0x0535, "character/character_iw8_al_qatala_urban_04" },
    { 0x0536, "character/character_iw8_al_qatala_urban_05" },
    { 0x0537, "character/character_iw8_al_qatala_urban_06" },
    { 0x0538, "character/character_iw8_al_qatala_urban_07" },
    { 0x0539, "character/character_iw8_al_qatala_urban_08_long_jacket" },
    { 0x053A, "character/character_iw8_al_qatala_urban_bombvest" },
    { 0x053B, "character/character_iw8_al_qatala_urban_female_01" },
    { 0x053C, "character/character_iw8_al_qatala_urban_female_02" },
    { 0x053D, "character/character_iw8_al_qatala_urban_female_03" },
    { 0x053E, "character/character_iw8_al_qatala_urban_female_04" },
    { 0x053F, "character/character_iw8_al_qatala_urban_female_05" },
    { 0x0540, "character/character_iw8_al_qatala_urban_female_06" },
    { 0x0541, "character/character_iw8_russian_army_1" },
    { 0x0542, "character/character_iw8_russian_army_1_safehouse" },
    { 0x0543, "character/character_iw8_russian_army_1_safehouse_finale" },
    { 0x0544, "character/character_iw8_russian_army_2_hood" },
    { 0x0545, "character/character_iw8_russian_army_2_hood_safehouse" },
    { 0x0546, "character/character_iw8_russian_army_2_hood_safehouse_finale" },
    { 0x0547, "character/character_iw8_russian_army_ar_1_balaclava" },
    { 0x0548, "character/character_iw8_russian_army_ar_1_gasmask" },
    { 0x0549, "character/character_iw8_russian_army_ar_1_gasmask_only" },
    { 0x054A, "character/character_iw8_russian_army_ar_2_balaclava" },
    { 0x054B, "character/character_iw8_russian_army_ar_2_gasmask" },
    { 0x054C, "character/character_iw8_russian_army_ar_2_gasmask_only" },
    { 0x054D, "character/character_iw8_russian_army_ar_3_gasmask_only" },
    { 0x054E, "character/character_iw8_russian_army_ar_4_gasmask" },
    { 0x054F, "character/character_iw8_russian_army_ar_4_gasmask_only" },
    { 0x0550, "character/character_iw8_russian_army_ar_5_gasmask" },
    { 0x0551, "character/character_iw8_russian_army_ar_5_gasmask_only" },
    { 0x0552, "character/character_iw8_russian_army_ar_6_gasmask_only" },
    { 0x0553, "character/character_iw8_russian_weapon_smugglers_1" },
    { 0x0554, "character/character_iw8_russian_weapon_smugglers_2" },
    { 0x0555, "character/character_iw8_russian_weapon_smugglers_3" },
    { 0x0556, "character/character_iw8_russian_weapon_smugglers_4" },
    { 0x0557, "character/character_iw8_russian_weapon_smugglers_5" },
    { 0x0558, "character/character_iw8_russian_weapon_smugglers_burned_1" },
    { 0x0559, "character/character_iw8_sla_rebel_female_1_1" },
    { 0x055A, "character/character_iw8_sla_rebel_female_2_1" },
    { 0x055B, "character/character_iw8_sla_rebel_female_3_1" },
    { 0x055C, "character/character_iw8_sla_rebel_female_4_1" },
    { 0x055D, "character/character_iw8_sla_rebel_female_5_1" },
    { 0x055E, "character/character_iw8_sla_rebel_female_6_1" },
    { 0x055F, "character/character_iw8_sla_rebels_female_prisoner_1" },
    { 0x0560, "character/character_iw8_sla_rebels_female_prisoner_2" },
    { 0x0561, "character/character_iw8_sla_rebels_female_prisoner_3" },
    { 0x0562, "character/character_iw8_sla_rebels_female_prisoner_4" },
    { 0x0563, "character/character_iw8_sla_rebels_female_prisoner_5" },
    { 0x0564, "character/character_london_police_hivis" },
    { 0x0565, "character/character_opforce_juggernaut" },
    { 0x0566, "character/character_opforce_juggernaut_cp" },
    { 0x0567, "character/character_rus_pilot_helicopter" },
    { 0x0568, "character/character_russian_boss_hometown" },
    { 0x0569, "character/character_russian_boss_hometown_cp" },
    { 0x056A, "character/character_russian_suits" },
    { 0x056B, "character/character_sas_pilot_helicopter" },
    { 0x056C, "character/character_sas_pilot_helicopter_cp" },
    { 0x056D, "character/character_sas_urban_ar" },
    { 0x056E, "character/character_sas_urban_ar_1" },
    { 0x056F, "character/character_sas_urban_ar_2" },
    { 0x0570, "character/character_sas_urban_ar_3" },
    { 0x0571, "character/character_sas_urban_ar_4" },
    { 0x0572, "character/character_sas_urban_cqc" },
    { 0x0573, "character/character_sas_urban_dmr" },
    { 0x0574, "character/character_sas_urban_nvg_ar" },
    { 0x0575, "character/character_sas_urban_nvg_dmr" },
    { 0x0576, "character/character_sas_woodland_nvg" },
    { 0x0577, "character/character_sla_rebels_male_ar" },
    { 0x0578, "character/character_sla_rebels_male_ar_2_1" },
    { 0x0579, "character/character_sla_rebels_male_cqb" },
    { 0x057A, "character/character_sla_rebels_male_cqb_2_1" },
    { 0x057B, "character/character_sla_rebels_male_dmr" },
    { 0x057C, "character/character_sla_rebels_male_dmr_2_1" },
    { 0x057D, "character/character_sla_rebels_male_lmg" },
    { 0x057E, "character/character_sla_rebels_male_lmg_2_1" },
    { 0x057F, "character/character_spetsnaz_ar" },
    { 0x0580, "character/character_spetsnaz_ar_cp" },
    { 0x0581, "character/character_spetsnaz_ar_nvg" },
    { 0x0582, "character/character_spetsnaz_ar_nvg_fixed" },
    { 0x0583, "character/character_spetsnaz_cqc" },
    { 0x0584, "character/character_spetsnaz_cqc_cp" },
    { 0x0585, "character/character_spetsnaz_cqc_nvg" },
    { 0x0586, "character/character_spetsnaz_dmr_cp" },
    { 0x0587, "character/character_spetsnaz_gasmask_ar" },
    { 0x0588, "character/character_spetsnaz_gasmask_cqc" },
    { 0x0589, "character/character_spetsnaz_gasmask_lmg" },
    { 0x058A, "character/character_spetsnaz_gasmask_nohelmet_ar" },
    { 0x058B, "character/character_spetsnaz_gasmask_nohelmet_cqc" },
    { 0x058C, "character/character_spetsnaz_gasmask_nohelmet_lmg" },
    { 0x058D, "character/character_spetsnaz_lmg" },
    { 0x058E, "character/character_spetsnaz_lmg_cp" },
    { 0x058F, "character/character_usmc_ar" },
    { 0x0590, "character/character_usmc_basic_ar_1" },
    { 0x0591, "character/character_usmc_basic_ar_1_tape" },
    { 0x0592, "character/character_usmc_basic_ar_2" },
    { 0x0593, "character/character_usmc_basic_ar_3" },
    { 0x0594, "character/character_usmc_basic_ar_3_tape" },
    { 0x0595, "character/character_usmc_basic_ar_4" },
    { 0x0596, "character/character_usmc_basic_ar_4_tape" },
    { 0x0597, "character/character_usmc_basic_lmg" },
    { 0x0598, "character/character_usmc_raiders_ar_1" },
    { 0x0599, "character/character_usmc_raiders_ar_2" },
    { 0x059A, "character/character_usmc_raiders_ar_3" },
    { 0x059B, "character/character_usmc_raiders_ar_4" },
    { 0x059C, "character/character_usmc_raiders_ar_5" },
    { 0x059D, "character/character_villain_barkov_old" },
    { 0x059E, "character/character_villain_enforcer_st_petersburg" },
    { 0x059F, "character/character_villain_wolf" },
    { 0x05A0, "character/character_villain_wolf_bombvest" },
    { 0x05A1, "character/civ_al_qatala_urban_civ_female" },
    { 0x05A2, "character/civ_al_qatala_urban_civ_female_bluetop" },
    { 0x05A3, "character/civ_al_qatala_urban_civ_female_turquoise" },
    { 0x05A4, "character/civ_al_qatala_urban_civ_female_whitetop" },
    { 0x05A5, "character/civ_child_interrogation" },
    { 0x05A6, "character/civ_embassy_ambassador_assistant" },
    { 0x05A7, "character/civ_embassy_office_worker_female_1_1" },
    { 0x05A8, "character/civ_embassy_office_worker_female_1_1_smallhead" },
    { 0x05A9, "character/civ_embassy_office_worker_female_1_2" },
    { 0x05AA, "character/civ_embassy_office_worker_female_2_1" },
    { 0x05AB, "character/civ_embassy_office_worker_female_2_2" },
    { 0x05AC, "character/civ_embassy_office_worker_male_1_1" },
    { 0x05AD, "character/civ_embassy_office_worker_male_1_2" },
    { 0x05AE, "character/civ_embassy_office_worker_male_1_3" },
    { 0x05AF, "character/civ_embassy_office_worker_male_2_1" },
    { 0x05B0, "character/civ_embassy_office_worker_male_2_2" },
    { 0x05B1, "character/civ_embassy_office_worker_male_2_3" },
    { 0x05B2, "character/civ_embassy_office_worker_male_2_4" },
    { 0x05B3, "character/civ_female_interrogation" },
    { 0x05B4, "character/civ_london_female_02_skintone_dark" },
    { 0x05B5, "character/civ_london_female_02_skintone_light" },
    { 0x05B6, "character/civ_london_female_02_skintone_med" },
    { 0x05B7, "character/civ_london_female_03_skintone_dark" },
    { 0x05B8, "character/civ_london_female_03_skintone_light" },
    { 0x05B9, "character/civ_london_female_03_skintone_med" },
    { 0x05BA, "character/civ_london_female_skintone_light" },
    { 0x05BB, "character/civ_london_female_skintone_light_anim_safe" },
    { 0x05BC, "character/civ_london_female_skintone_med" },
    { 0x05BD, "character/civ_london_female_skintone_med_anim_safe" },
    { 0x05BE, "character/civ_london_male_embassy_adam" },
    { 0x05BF, "character/civ_london_male_embassy_ambassador" },
    { 0x05C0, "character/civ_london_male_skintone_light" },
    { 0x05C1, "character/civ_london_male_skintone_med" },
    { 0x05C2, "character/civ_russian_female" },
    { 0x05C3, "character/civ_russian_male" },
    { 0x05C4, "character/civ_russian_male_cp" },
    { 0x05C5, "character/civ_syrkistan_female_nurse_mask" },
    { 0x05C6, "character/civ_syrkistan_female_nurse_nomask" },
    { 0x05C7, "character/civ_syrkistan_female_scarf_dress_blue" },
    { 0x05C8, "character/civ_syrkistan_female_scarf_dress_orange" },
    { 0x05C9, "character/civ_syrkistan_female_scarf_dress_pink" },
    { 0x05CA, "character/civ_syrkistan_female_scarf_green" },
    { 0x05CB, "character/civ_syrkistan_female_scarf_long_blue" },
    { 0x05CC, "character/civ_syrkistan_female_scarf_long_brown" },
    { 0x05CD, "character/civ_syrkistan_girl_1_1" },
    { 0x05CE, "character/civ_syrkistan_girl_2_1" },
    { 0x05CF, "character/civ_syrkistan_girl_3_1" },
    { 0x05D0, "character/civ_syrkistan_girl_4_1" },
    { 0x05D1, "character/civ_syrkistan_girl_5_1" },
    { 0x05D2, "character/civ_syrkistan_girl_6_1" },
    { 0x05D3, "character/civ_syrkistan_girl_7_1" },
    { 0x05D4, "character/civ_syrkistan_male_doctor_mask" },
    { 0x05D5, "character/civ_syrkistan_male_doctor_nomask" },
    { 0x05D6, "character/civ_uk_female_coat_blue" },
    { 0x05D7, "character/civ_western_cold_boy" },
    { 0x05D8, "character/civ_western_cold_girl" },
    { 0x05D9, "character/hero_xo_farah_variant" },
    { 0x05DA, "character/test_character_alq_embassy" },
    { 0x05DB, "character/test_character_civ_female_rus_clerical" },
    { 0x05DC, "character/test_character_civ_male_london_01" },
    { 0x05DD, "character/test_character_civ_male_rus_clerical" },
    { 0x05DE, "character/test_character_cp_crew_male_vest_picc_01" },
    { 0x05DF, "character/test_character_crew_male_vest_picc_01" },
    { 0x05E0, "character/test_character_dog" },
    { 0x05E1, "character/test_character_farah_father" },
    { 0x05E2, "xmodelalias/alias_hero_stpetersburg_nikilai_body" },
    { 0x05E3, "xmodelalias/bodies_al_qatala_desert_01" },
    { 0x05E4, "xmodelalias/bodies_al_qatala_desert_02" },
    { 0x05E5, "xmodelalias/bodies_al_qatala_desert_03" },
    { 0x05E6, "xmodelalias/bodies_al_qatala_desert_07" },
    { 0x05E7, "xmodelalias/bodies_al_qatala_desert_09" },
    { 0x05E8, "xmodelalias/bodies_al_qatala_urban_a6_variant" },
    { 0x05E9, "xmodelalias/bodies_al_qatala_urban_ar" },
    { 0x05EA, "xmodelalias/bodies_al_qatala_urban_ar_variant" },
    { 0x05EB, "xmodelalias/bodies_al_qatala_urban_bomber" },
    { 0x05EC, "xmodelalias/bodies_al_qatala_urban_cqb_variant" },
    { 0x05ED, "xmodelalias/bodies_al_qatala_urban_lmg_variant" },
    { 0x05EE, "xmodelalias/bodies_civ_al_qatala_urban_female" },
    { 0x05EF, "xmodelalias/bodies_civ_russian_police_officer" },
    { 0x05F0, "xmodelalias/bodies_civ_western_cold_boy" },
    { 0x05F1, "xmodelalias/bodies_civ_western_cold_girl" },
    { 0x05F2, "xmodelalias/bodies_sas_urban_ar" },
    { 0x05F3, "xmodelalias/bodies_sas_urban_cqc" },
    { 0x05F4, "xmodelalias/bodies_sas_urban_dmr" },
    { 0x05F5, "xmodelalias/bodies_sas_woodland_ar" },
    { 0x05F6, "xmodelalias/bodies_spetsnaz_ar" },
    { 0x05F7, "xmodelalias/civ_russian_male_body_1" },
    { 0x05F8, "xmodelalias/civ_russian_male_head_1" },
    { 0x05F9, "xmodelalias/civilian_london_female_body_02_skintone_dark" },
    { 0x05FA, "xmodelalias/civilian_london_female_body_02_skintone_light" },
    { 0x05FB, "xmodelalias/civilian_london_female_body_02_skintone_med" },
    { 0x05FC, "xmodelalias/civilian_london_female_body_skintone_01" },
    { 0x05FD, "xmodelalias/civilian_london_female_body_skintone_01_anim_safe" },
    { 0x05FE, "xmodelalias/civilian_london_female_body_skintone_med" },
    { 0x05FF, "xmodelalias/civilian_london_female_body_skintone_med_anim_safe" },
    { 0x0600, "xmodelalias/civilian_london_female_head_skintone_light" },
    { 0x0601, "xmodelalias/civilian_london_female_head_skintone_med" },
    { 0x0602, "xmodelalias/civilian_london_female_heads_skintone_dark" },
    { 0x0603, "xmodelalias/civilian_london_female_heads_skintone_dark_nohair" },
    { 0x0604, "xmodelalias/civilian_london_female_heads_skintone_light" },
    { 0x0605, "xmodelalias/civilian_london_female_heads_skintone_light_nohair" },
    { 0x0606, "xmodelalias/civilian_london_female_heads_skintone_med" },
    { 0x0607, "xmodelalias/civilian_london_female_heads_skintone_med_nohair" },
    { 0x0608, "xmodelalias/civilian_london_male_body_skintone_light" },
    { 0x0609, "xmodelalias/civilian_london_male_body_skintone_med" },
    { 0x060A, "xmodelalias/civilian_me_female_bodies" },
    { 0x060B, "xmodelalias/civilian_me_female_embassy_bodies" },
    { 0x060C, "xmodelalias/civilian_me_female_heads" },
    { 0x060D, "xmodelalias/civilian_me_female_veil_bodies" },
    { 0x060E, "xmodelalias/civilian_me_female_wrap_bodies" },
    { 0x060F, "xmodelalias/civilian_me_female_wrap_heads" },
    { 0x0610, "xmodelalias/civilian_me_male_veil_bodies" },
    { 0x0611, "xmodelalias/civilian_me_male_veil_heads" },
    { 0x0612, "xmodelalias/civilian_russian_female_body" },
    { 0x0613, "xmodelalias/civilian_russian_female_head" },
    { 0x0614, "xmodelalias/civilian_syrkistan_female_head" },
    { 0x0615, "xmodelalias/civilian_syrkistan_female_head_no_hair" },
    { 0x0616, "xmodelalias/civilian_syrkistan_male_body" },
    { 0x0617, "xmodelalias/civilian_syrkistan_male_body_dist" },
    { 0x0618, "xmodelalias/civilian_syrkistan_male_body_embassy" },
    { 0x0619, "xmodelalias/civilian_syrkistan_male_head" },
    { 0x061A, "xmodelalias/civilian_uk_male_heads_skintone_light" },
    { 0x061B, "xmodelalias/civilian_uk_male_heads_skintone_med" },
    { 0x061C, "xmodelalias/hats_civ_russian_police_officer" },
    { 0x061D, "xmodelalias/heads_al_qatala_desert" },
    { 0x061E, "xmodelalias/heads_al_qatala_desert_03" },
    { 0x061F, "xmodelalias/heads_al_qatala_desert_08" },
    { 0x0620, "xmodelalias/heads_al_qatala_desert_bomber" },
    { 0x0621, "xmodelalias/heads_al_qatala_urban_04" },
    { 0x0622, "xmodelalias/heads_al_qatala_urban_05" },
    { 0x0623, "xmodelalias/heads_al_qatala_urban_06" },
    { 0x0624, "xmodelalias/heads_al_qatala_urban_ar_variant" },
    { 0x0625, "xmodelalias/heads_civ_al_qatala_urban_female" },
    { 0x0626, "xmodelalias/heads_civ_russian_police_officer" },
    { 0x0627, "xmodelalias/heads_civ_western_cold_boy" },
    { 0x0628, "xmodelalias/heads_civ_western_cold_girl" },
    { 0x0629, "xmodelalias/heads_london_police" },
    { 0x062A, "xmodelalias/heads_sas_urban" },
    { 0x062B, "xmodelalias/heads_sas_urban_nvg" },
    { 0x062C, "xmodelalias/heads_sas_woodland_nvg" },
    { 0x062D, "xmodelalias/heads_usmc_male" },
    { 0x062E, "xmodelalias/russian_army_ar_1_hats_gasmask" },
    { 0x062F, "xmodelalias/russian_army_ar_2_hats_gasmask" },
    { 0x0630, "xmodelalias/russian_army_ar_4_hats_gasmask" },
    { 0x0631, "xmodelalias/russian_army_ar_5_hats_gasmask" },
    { 0x0632, "xmodelalias/russian_army_bodies_1" },
    { 0x0633, "xmodelalias/russian_army_bodies_1_light" },
    { 0x0634, "xmodelalias/russian_army_bodies_2" },
    { 0x0635, "xmodelalias/russian_army_bodies_2_light" },
    { 0x0636, "xmodelalias/russian_army_hats" },
    { 0x0637, "xmodelalias/russian_army_hats_safehouse" },
    { 0x0638, "xmodelalias/russian_army_heads" },
    { 0x0639, "xmodelalias/russian_army_heads_gasmask" },
    { 0x063A, "xmodelalias/russian_army_heads_safehouse" },
    { 0x063B, "xmodelalias/test_alias_civ_london_male_1_body" },
    { 0x063C, "xmodelalias/test_enemy_picc_heads" },
    { 0x063D, "scripts/aitypes/alert" },
    { 0x063E, "scripts/aitypes/assets" },
    { 0x063F, "scripts/aitypes/bt_action_api" },
    { 0x0640, "scripts/aitypes/bt_state_api" },
    { 0x0641, "scripts/aitypes/c12api" },
    { 0x0642, "scripts/aitypes/combat" },
    { 0x0643, "scripts/aitypes/combat_mp" },
    { 0x0644, "scripts/aitypes/combat_sp" },
    { 0x0645, "scripts/aitypes/common" },
    { 0x0646, "scripts/aitypes/cover" },
    { 0x0647, "scripts/aitypes/dismember" },
    { 0x0648, "scripts/aitypes/grenade_response" },
    { 0x0649, "scripts/aitypes/melee" },
    { 0x064A, "scripts/aitypes/melee_sp" },
    { 0x064B, "scripts/aitypes/patrol" },
    { 0x064C, "scripts/aitypes/robot_dismember" },
    { 0x064D, "scripts/aitypes/squad" },
    { 0x064E, "scripts/aitypes/squad_movement" },
    { 0x064F, "scripts/aitypes/stealth" },
    { 0x0650, "scripts/aitypes/throwgrenade" },
    { 0x0651, "scripts/aitypes/vehicle" },
    { 0x0652, "scripts/aitypes/weapon" },
    { 0x0653, "scripts/asm/asm_bb" },
    { 0x0654, "scripts/asm/asm_mp" },
    { 0x0655, "scripts/asm/asm_sp" },
    { 0x0656, "scripts/asm/gesture" },
    { 0x0657, "scripts/asm/track" },
    { 0x0658, "scripts/asm/traverse" },
    { 0x0659, "scripts/code/ai_shooting" },
    { 0x065A, "scripts/code/character" },
    { 0x065B, "scripts/common/ai" },
    { 0x065C, "scripts/common/anim" },
    { 0x065D, "scripts/common/basic_wind" },
    { 0x065E, "scripts/common/bcs_location_trigs" },
    { 0x065F, "scripts/common/create_cover_nodes" },
    { 0x0660, "scripts/common/createfx" },
    { 0x0661, "scripts/common/createfxmenu" },
    { 0x0662, "scripts/common/csplines" },
    { 0x0663, "scripts/common/debug_graycard" },
    { 0x0664, "scripts/common/debug_reflection" },
    { 0x0665, "scripts/common/elevator" },
    { 0x0666, "scripts/common/exploder" },
    { 0x0667, "scripts/common/fx" },
    { 0x0668, "scripts/common/gameskill" },
    { 0x0669, "scripts/common/input_allow" },
    { 0x066A, "scripts/common/lbravo_ai_infil" },
    { 0x066B, "scripts/common/mocap_ar" },
    { 0x066C, "scripts/common/notetrack" },
    { 0x066D, "scripts/common/painter" },
    { 0x066E, "scripts/common/rockable_vehicles" },
    { 0x066F, "scripts/common/screens" },
    { 0x0670, "scripts/common/turret" },
    { 0x0671, "scripts/common/utility" },
    { 0x0672, "scripts/common/vehicle" },
    { 0x0673, "scripts/common/vehicle_aianim" },
    { 0x0674, "scripts/common/vehicle_build" },
    { 0x0675, "scripts/common/vehicle_code" },
    { 0x0676, "scripts/common/vehicle_lights" },
    { 0x0677, "scripts/common/vehicle_paths" },
    { 0x0678, "scripts/common/vehicle_treadfx" },
    { 0x0679, "scripts/cp/coop_createfx" },
    { 0x067A, "scripts/cp/coop_escort" },
    { 0x067B, "scripts/cp/coop_fx" },
    { 0x067C, "scripts/cp/coop_personal_ents" },
    { 0x067D, "scripts/cp/coop_priority_queue" },
    { 0x067E, "scripts/cp/coop_stealth" },
    { 0x067F, "scripts/cp/coop_super" },
    { 0x0680, "scripts/cp/cp_accessories" },
    { 0x0681, "scripts/cp/cp_achievement" },
    { 0x0682, "scripts/cp/cp_adrenaline_crate" },
    { 0x0683, "scripts/cp/cp_agent_damage" },
    { 0x0684, "scripts/cp/cp_agent_patrol" },
    { 0x0685, "scripts/cp/cp_agent_utils" },
    { 0x0686, "scripts/cp/cp_ai_spawn_anim_skits" },
    { 0x0687, "scripts/cp/cp_aiparachute" },
    { 0x0688, "scripts/cp/cp_aitype_structs_enemy_alq" },
    { 0x0689, "scripts/cp/cp_ammo_crate" },
    { 0x068A, "scripts/cp/cp_analytics" },
    { 0x068B, "scripts/cp/cp_anim" },
    { 0x068C, "scripts/cp/cp_armor" },
    { 0x068D, "scripts/cp/cp_armor_crate" },
    { 0x068E, "scripts/cp/cp_battlechatter" },
    { 0x068F, "scripts/cp/cp_battlechatter_ai" },
    { 0x0690, "scripts/cp/cp_breach_c4" },
    { 0x0691, "scripts/cp/cp_c4" },
    { 0x0692, "scripts/cp/cp_claymore" },
    { 0x0693, "scripts/cp/cp_compass" },
    { 0x0694, "scripts/cp/cp_computerscreen" },
    { 0x0695, "scripts/cp/cp_convoy_manager" },
    { 0x0696, "scripts/cp/cp_convoy_manager_code" },
    { 0x0697, "scripts/cp/cp_core_gamescore" },
    { 0x0698, "scripts/cp/cp_create_script_utility" },
    { 0x0699, "scripts/cp/cp_damage" },
    { 0x069A, "scripts/cp/cp_damagefeedback" },
    { 0x069B, "scripts/cp/cp_debug" },
    { 0x069C, "scripts/cp/cp_deployablebox" },
    { 0x069D, "scripts/cp/cp_destruction" },
    { 0x069E, "scripts/cp/cp_dev_hud" },
    { 0x069F, "scripts/cp/cp_dialogue" },
    { 0x06A0, "scripts/cp/cp_disguise" },
    { 0x06A1, "scripts/cp/cp_door" },
    { 0x06A2, "scripts/cp/cp_drone_strike" },
    { 0x06A3, "scripts/cp/cp_electricswitch" },
    { 0x06A4, "scripts/cp/cp_elevator" },
    { 0x06A5, "scripts/cp/cp_endgame" },
    { 0x06A6, "scripts/cp/cp_equipment" },
    { 0x06A7, "scripts/cp/cp_escalation" },
    { 0x06A8, "scripts/cp/cp_flares" },
    { 0x06A9, "scripts/cp/cp_gamescore" },
    { 0x06AA, "scripts/cp/cp_gameskill" },
    { 0x06AB, "scripts/cp/cp_globallogic" },
    { 0x06AC, "scripts/cp/cp_globalthreat" },
    { 0x06AD, "scripts/cp/cp_grenade_crate" },
    { 0x06AE, "scripts/cp/cp_hacking" },
    { 0x06AF, "scripts/cp/cp_hostage" },
    { 0x06B0, "scripts/cp/cp_hostmigration" },
    { 0x06B1, "scripts/cp/cp_hud_message" },
    { 0x06B2, "scripts/cp/cp_hud_util" },
    { 0x06B3, "scripts/cp/cp_infilexfil" },
    { 0x06B4, "scripts/cp/cp_interaction" },
    { 0x06B5, "scripts/cp/cp_juggernaut" },
    { 0x06B6, "scripts/cp/cp_kidnapper" },
    { 0x06B7, "scripts/cp/cp_ladder" },
    { 0x06B8, "scripts/cp/cp_laststand" },
    { 0x06B9, "scripts/cp/cp_loadout" },
    { 0x06BA, "scripts/cp/cp_mapselect" },
    { 0x06BB, "scripts/cp/cp_merits" },
    { 0x06BC, "scripts/cp/cp_modular_spawning" },
    { 0x06BD, "scripts/cp/cp_movers" },
    { 0x06BE, "scripts/cp/cp_munitions" },
    { 0x06BF, "scripts/cp/cp_music_and_dialog" },
    { 0x06C0, "scripts/cp/cp_objective_mechanics" },
    { 0x06C1, "scripts/cp/cp_objectives" },
    { 0x06C2, "scripts/cp/cp_objectives_events" },
    { 0x06C3, "scripts/cp/cp_outline" },
    { 0x06C4, "scripts/cp/cp_outline_utility" },
    { 0x06C5, "scripts/cp/cp_outofbounds" },
    { 0x06C6, "scripts/cp/cp_persistence" },
    { 0x06C7, "scripts/cp/cp_pickup_hostage" },
    { 0x06C8, "scripts/cp/cp_player_battlechatter" },
    { 0x06C9, "scripts/cp/cp_playerchatter" },
    { 0x06CA, "scripts/cp/cp_powers" },
    { 0x06CB, "scripts/cp/cp_puzzles_core" },
    { 0x06CC, "scripts/cp/cp_quest" },
    { 0x06CD, "scripts/cp/cp_relics" },
    { 0x06CE, "scripts/cp/cp_remote_tank" },
    { 0x06CF, "scripts/cp/cp_reward" },
    { 0x06D0, "scripts/cp/cp_scriptable_states" },
    { 0x06D1, "scripts/cp/cp_skits" },
    { 0x06D2, "scripts/cp/cp_smg_prototype" },
    { 0x06D3, "scripts/cp/cp_snakecam" },
    { 0x06D4, "scripts/cp/cp_spawn_factor" },
    { 0x06D5, "scripts/cp/cp_spawner_scoring" },
    { 0x06D6, "scripts/cp/cp_spawning" },
    { 0x06D7, "scripts/cp/cp_spawning_util" },
    { 0x06D8, "scripts/cp/cp_squadmanager" },
    { 0x06D9, "scripts/cp/cp_stealth_zombie" },
    { 0x06DA, "scripts/cp/cp_strike_debug" },
    { 0x06DB, "scripts/cp/cp_traversalassist" },
    { 0x06DC, "scripts/cp/cp_trigger_spawn" },
    { 0x06DD, "scripts/cp/cp_turret" },
    { 0x06DE, "scripts/cp/cp_vehicle_structs" },
    { 0x06DF, "scripts/cp/cp_vehicle_turretdrone" },
    { 0x06E0, "scripts/cp/cp_vehicles" },
    { 0x06E1, "scripts/cp/cp_vip" },
    { 0x06E2, "scripts/cp/cp_visionsets" },
    { 0x06E3, "scripts/cp/cp_vo" },
    { 0x06E4, "scripts/cp/cp_wall_buys" },
    { 0x06E5, "scripts/cp/cp_wave_spawning" },
    { 0x06E6, "scripts/cp/cp_weapon" },
    { 0x06E7, "scripts/cp/cp_weapon_autosentry" },
    { 0x06E8, "scripts/cp/cp_weapon_upgrade" },
    { 0x06E9, "scripts/cp/cp_weaponrank" },
    { 0x06EA, "scripts/cp/cp_weapons" },
    { 0x06EB, "scripts/cp/crafting_system" },
    { 0x06EC, "scripts/cp/emp_debuff_cp" },
    { 0x06ED, "scripts/cp/gestures_cp" },
    { 0x06EE, "scripts/cp/init_cp_mp" },
    { 0x06EF, "scripts/cp/loot_system" },
    { 0x06F0, "scripts/cp/pingcallout_cp" },
    { 0x06F1, "scripts/cp/raid_utility" },
    { 0x06F2, "scripts/cp/scriptable" },
    { 0x06F3, "scripts/cp/tripwire_cp" },
    { 0x06F4, "scripts/cp/utility" },
    { 0x06F5, "scripts/cp/vehicle" },
    { 0x06F6, "scripts/cp_mp/anim_scene" },
    { 0x06F7, "scripts/cp_mp/auto_ascender" },
    { 0x06F8, "scripts/cp_mp/emp_debuff" },
    { 0x06F9, "scripts/cp_mp/ent_manager" },
    { 0x06FA, "scripts/cp_mp/entityheadicons" },
    { 0x06FB, "scripts/cp_mp/execution" },
    { 0x06FC, "scripts/cp_mp/frontendutils" },
    { 0x06FD, "scripts/cp_mp/gasmask" },
    { 0x06FE, "scripts/cp_mp/gestures" },
    { 0x06FF, "scripts/cp_mp/hostmigration" },
    { 0x0700, "scripts/cp_mp/mortar_launcher" },
    { 0x0701, "scripts/cp_mp/outofrange" },
    { 0x0702, "scripts/cp_mp/parachute" },
    { 0x0703, "scripts/cp_mp/pet_watch" },
    { 0x0704, "scripts/cp_mp/pingcallout" },
    { 0x0705, "scripts/cp_mp/powershud" },
    { 0x0706, "scripts/cp_mp/targetmarkergroups" },
    { 0x0707, "scripts/cp_mp/tripwire" },
    { 0x0708, "scripts/engine/dev" },
    { 0x0709, "scripts/engine/flags" },
    { 0x070A, "scripts/engine/math" },
    { 0x070B, "scripts/engine/scriptable" },
    { 0x070C, "scripts/engine/scriptable_door" },
    { 0x070D, "scripts/engine/trace" },
    { 0x070E, "scripts/engine/utility" },
    { 0x070F, "scripts/models/interactive_utility" },
    { 0x0710, "scripts/mp/accessories" },
    { 0x0711, "scripts/mp/accolades" },
    { 0x0712, "scripts/mp/analyticslog" },
    { 0x0713, "scripts/mp/anim" },
    { 0x0714, "scripts/mp/animatedmodels" },
    { 0x0715, "scripts/mp/animation_suite" },
    { 0x0716, "scripts/mp/arbitrary_up" },
    { 0x0717, "scripts/mp/areas" },
    { 0x0718, "scripts/mp/art" },
    { 0x0719, "scripts/mp/audio" },
    { 0x071A, "scripts/mp/awards" },
    { 0x071B, "scripts/mp/battlechatter_mp" },
    { 0x071C, "scripts/mp/battlechatter_trigs" },
    { 0x071D, "scripts/mp/bounty" },
    { 0x071E, "scripts/mp/broshot" },
    { 0x071F, "scripts/mp/broshot_utilities" },
    { 0x0720, "scripts/mp/callouts" },
    { 0x0721, "scripts/mp/challengefunctions" },
    { 0x0722, "scripts/mp/challenges" },
    { 0x0723, "scripts/mp/class" },
    { 0x0724, "scripts/mp/clientmatchdata" },
    { 0x0725, "scripts/mp/codcasterclientmatchdata" },
    { 0x0726, "scripts/mp/compass" },
    { 0x0727, "scripts/mp/cranked" },
    { 0x0728, "scripts/mp/createfx" },
    { 0x0729, "scripts/mp/damage" },
    { 0x072A, "scripts/mp/damagefeedback" },
    { 0x072B, "scripts/mp/deathicons" },
    { 0x072C, "scripts/mp/destructables" },
    { 0x072D, "scripts/mp/destructible" },
    { 0x072E, "scripts/mp/dev" },
    { 0x072F, "scripts/mp/door" },
    { 0x0730, "scripts/mp/emp_debuff_mp" },
    { 0x0731, "scripts/mp/equipment" },
    { 0x0732, "scripts/mp/equipment_interact" },
    { 0x0733, "scripts/mp/events" },
    { 0x0734, "scripts/mp/execution_mp" },
    { 0x0735, "scripts/mp/final_killcam" },
    { 0x0736, "scripts/mp/flags" },
    { 0x0737, "scripts/mp/flashpoint" },
    { 0x0738, "scripts/mp/friendicons" },
    { 0x0739, "scripts/mp/fx" },
    { 0x073A, "scripts/mp/gamelogic" },
    { 0x073B, "scripts/mp/gameobjects" },
    { 0x073C, "scripts/mp/gamescore" },
    { 0x073D, "scripts/mp/gestures_mp" },
    { 0x073E, "scripts/mp/global_fx" },
    { 0x073F, "scripts/mp/global_fx_code" },
    { 0x0740, "scripts/mp/globalentities" },
    { 0x0741, "scripts/mp/globallogic" },
    { 0x0742, "scripts/mp/healthoverlay" },
    { 0x0743, "scripts/mp/heavyarmor" },
    { 0x0744, "scripts/mp/hostmigration" },
    { 0x0745, "scripts/mp/hud" },
    { 0x0746, "scripts/mp/hud_message" },
    { 0x0747, "scripts/mp/hud_util" },
    { 0x0748, "scripts/mp/init_cp_mp" },
    { 0x0749, "scripts/mp/javelin" },
    { 0x074A, "scripts/mp/juggernaut" },
    { 0x074B, "scripts/mp/killcam" },
    { 0x074C, "scripts/mp/laststand" },
    { 0x074D, "scripts/mp/launcher_target_lead" },
    { 0x074E, "scripts/mp/lightarmor" },
    { 0x074F, "scripts/mp/lightbar" },
    { 0x0750, "scripts/mp/load" },
    { 0x0751, "scripts/mp/loot" },
    { 0x0752, "scripts/mp/matchdata" },
    { 0x0753, "scripts/mp/matchrecording" },
    { 0x0754, "scripts/mp/matchstats" },
    { 0x0755, "scripts/mp/menus" },
    { 0x0756, "scripts/mp/minefields" },
    { 0x0757, "scripts/mp/missilelauncher" },
    { 0x0758, "scripts/mp/motiondetectors" },
    { 0x0759, "scripts/mp/movers" },
    { 0x075A, "scripts/mp/mp_agent" },
    { 0x075B, "scripts/mp/music_and_dialog" },
    { 0x075C, "scripts/mp/objidpoolmanager" },
    { 0x075D, "scripts/mp/objpoints" },
    { 0x075E, "scripts/mp/outline" },
    { 0x075F, "scripts/mp/outofbounds" },
    { 0x0760, "scripts/mp/passives" },
    { 0x0761, "scripts/mp/persistence" },
    { 0x0762, "scripts/mp/pingcallout_mp" },
    { 0x0763, "scripts/mp/playeractions" },
    { 0x0764, "scripts/mp/playercards" },
    { 0x0765, "scripts/mp/playerlogic" },
    { 0x0766, "scripts/mp/playerstats" },
    { 0x0767, "scripts/mp/playerstats_interface" },
    { 0x0768, "scripts/mp/potg" },
    { 0x0769, "scripts/mp/potg_events" },
    { 0x076A, "scripts/mp/radiation" },
    { 0x076B, "scripts/mp/rally_point" },
    { 0x076C, "scripts/mp/rangefinder" },
    { 0x076D, "scripts/mp/rank" },
    { 0x076E, "scripts/mp/riotshield" },
    { 0x076F, "scripts/mp/scoreboard" },
    { 0x0770, "scripts/mp/screenshotcity" },
    { 0x0771, "scripts/mp/scriptable" },
    { 0x0772, "scripts/mp/secrethunt" },
    { 0x0773, "scripts/mp/sentientpoolmanager" },
    { 0x0774, "scripts/mp/serversettings" },
    { 0x0775, "scripts/mp/shellshock" },
    { 0x0776, "scripts/mp/spawncamera" },
    { 0x0777, "scripts/mp/spawnfactor" },
    { 0x0778, "scripts/mp/spawnlogic" },
    { 0x0779, "scripts/mp/spawnscoring" },
    { 0x077A, "scripts/mp/spawnselection" },
    { 0x077B, "scripts/mp/spectating" },
    { 0x077C, "scripts/mp/supers" },
    { 0x077D, "scripts/mp/tac_ops_map" },
    { 0x077E, "scripts/mp/teamrevive" },
    { 0x077F, "scripts/mp/teams" },
    { 0x0780, "scripts/mp/turret" },
    { 0x0781, "scripts/mp/tweakables" },
    { 0x0782, "scripts/mp/validation" },
    { 0x0783, "scripts/mp/weaponrank" },
    { 0x0784, "scripts/mp/whizby" },
    { 0x0785, "scripts/smartobjects/stealth_exposed_fire_up" },
    { 0x0786, "scripts/smartobjects/stealth_knock_off_30" },
    { 0x0787, "scripts/smartobjects/stealth_knock_off_36" },
    { 0x0788, "scripts/smartobjects/stealth_lean_table_30" },
    { 0x0789, "scripts/smartobjects/stealth_lean_table_36" },
    { 0x078A, "scripts/smartobjects/stealth_lean_table_l_30" },
    { 0x078B, "scripts/smartobjects/stealth_lean_table_l_36" },
    { 0x078C, "scripts/smartobjects/stealth_lean_table_r_30" },
    { 0x078D, "scripts/smartobjects/stealth_lean_table_r_36" },
    { 0x078E, "scripts/smartobjects/stealth_lean_wall_l" },
    { 0x078F, "scripts/smartobjects/stealth_lean_wall_r" },
    { 0x0790, "scripts/smartobjects/stealth_look_around" },
    { 0x0791, "scripts/smartobjects/stealth_look_down" },
    { 0x0792, "scripts/smartobjects/stealth_look_high" },
    { 0x0793, "scripts/smartobjects/stealth_look_over" },
    { 0x0794, "scripts/smartobjects/stealth_look_under_10" },
    { 0x0795, "scripts/smartobjects/stealth_look_under_30" },
    { 0x0796, "scripts/smartobjects/stealth_look_up" },
    { 0x0797, "scripts/smartobjects/stealth_rage_bash" },
    { 0x0798, "scripts/smartobjects/stealth_rage_bash_l" },
    { 0x0799, "scripts/smartobjects/stealth_rage_bash_r" },
    { 0x079A, "scripts/smartobjects/stealth_rage_kick" },
    { 0x079B, "scripts/smartobjects/stealth_rage_kick_l" },
    { 0x079C, "scripts/smartobjects/stealth_rage_kick_r" },
    { 0x079D, "scripts/smartobjects/stealth_rage_punch" },
    { 0x079E, "scripts/smartobjects/utility" },
    { 0x079F, "scripts/sp/analytics" },
    { 0x07A0, "scripts/sp/anim" },
    { 0x07A1, "scripts/sp/anim_notetrack" },
    { 0x07A2, "scripts/sp/art" },
    { 0x07A3, "scripts/sp/audio" },
    { 0x07A4, "scripts/sp/autosave" },
    { 0x07A5, "scripts/sp/colors" },
    { 0x07A6, "scripts/sp/compass" },
    { 0x07A7, "scripts/sp/createfx" },
    { 0x07A8, "scripts/sp/credits" },
    { 0x07A9, "scripts/sp/damagefeedback" },
    { 0x07AA, "scripts/sp/debug" },
    { 0x07AB, "scripts/sp/debug_menu" },
    { 0x07AC, "scripts/sp/debug_spawnai" },
    { 0x07AD, "scripts/sp/door" },
    { 0x07AE, "scripts/sp/door_ai" },
    { 0x07AF, "scripts/sp/door_internal" },
    { 0x07B0, "scripts/sp/door_scriptable" },
    { 0x07B1, "scripts/sp/drone" },
    { 0x07B2, "scripts/sp/drone_ai" },
    { 0x07B3, "scripts/sp/drone_base" },
    { 0x07B4, "scripts/sp/drone_civilian" },
    { 0x07B5, "scripts/sp/endmission" },
    { 0x07B6, "scripts/sp/fakeactor" },
    { 0x07B7, "scripts/sp/fakeactor_node" },
    { 0x07B8, "scripts/sp/flags" },
    { 0x07B9, "scripts/sp/footsteps" },
    { 0x07BA, "scripts/sp/friendlyfire" },
    { 0x07BB, "scripts/sp/gamer_profile" },
    { 0x07BC, "scripts/sp/gameskill" },
    { 0x07BD, "scripts/sp/geo_mover" },
    { 0x07BE, "scripts/sp/gibbing" },
    { 0x07BF, "scripts/sp/glass" },
    { 0x07C0, "scripts/sp/global_fx" },
    { 0x07C1, "scripts/sp/global_fx_code" },
    { 0x07C2, "scripts/sp/helicopter_ai" },
    { 0x07C3, "scripts/sp/helicopter_globals" },
    { 0x07C4, "scripts/sp/hud" },
    { 0x07C5, "scripts/sp/hud_util" },
    { 0x07C6, "scripts/sp/idles" },
    { 0x07C7, "scripts/sp/intelligence" },
    { 0x07C8, "scripts/sp/interaction" },
    { 0x07C9, "scripts/sp/interaction_manager" },
    { 0x07CA, "scripts/sp/introscreen" },
    { 0x07CB, "scripts/sp/lights" },
    { 0x07CC, "scripts/sp/load" },
    { 0x07CD, "scripts/sp/load_code" },
    { 0x07CE, "scripts/sp/loot" },
    { 0x07CF, "scripts/sp/mg_penetration" },
    { 0x07D0, "scripts/sp/mgturret" },
    { 0x07D1, "scripts/sp/names" },
    { 0x07D2, "scripts/sp/outline" },
    { 0x07D3, "scripts/sp/patrol" },
    { 0x07D4, "scripts/sp/pausemenu" },
    { 0x07D5, "scripts/sp/pip_util" },
    { 0x07D6, "scripts/sp/player" },
    { 0x07D7, "scripts/sp/player_death" },
    { 0x07D8, "scripts/sp/player_rig" },
    { 0x07D9, "scripts/sp/player_stats" },
    { 0x07DA, "scripts/sp/script_items" },
    { 0x07DB, "scripts/sp/scriptable" },
    { 0x07DC, "scripts/sp/scripted_weapon_assignment" },
    { 0x07DD, "scripts/sp/scriptedsniper" },
    { 0x07DE, "scripts/sp/slowmo_init" },
    { 0x07DF, "scripts/sp/spawner" },
    { 0x07E0, "scripts/sp/stairtrain" },
    { 0x07E1, "scripts/sp/starts" },
    { 0x07E2, "scripts/sp/statemachine" },
    { 0x07E3, "scripts/sp/stayahead" },
    { 0x07E4, "scripts/sp/stinger" },
    { 0x07E5, "scripts/sp/traffic_system" },
    { 0x07E6, "scripts/sp/treadfx" },
    { 0x07E7, "scripts/sp/trigger" },
    { 0x07E8, "scripts/sp/utility" },
    { 0x07E9, "scripts/sp/vehicle" },
    { 0x07EA, "scripts/sp/vehicle_aianim" },
    { 0x07EB, "scripts/sp/vehicle_build" },
    { 0x07EC, "scripts/sp/vehicle_code" },
    { 0x07ED, "scripts/sp/vehicle_heavy_destruction" },
    { 0x07EE, "scripts/sp/vehicle_interact" },
    { 0x07EF, "scripts/sp/vehicle_lights" },
    { 0x07F0, "scripts/sp/vehicle_paths" },
    { 0x07F1, "scripts/sp/vehicle_treads" },
    { 0x07F2, "scripts/sp/vision" },
    { 0x07F3, "scripts/stealth/callbacks" },
    { 0x07F4, "scripts/stealth/clear_regions" },
    { 0x07F5, "scripts/stealth/corpse" },
    { 0x07F6, "scripts/stealth/debug" },
    { 0x07F7, "scripts/stealth/enemy" },
    { 0x07F8, "scripts/stealth/event" },
    { 0x07F9, "scripts/stealth/friendly" },
    { 0x07FA, "scripts/stealth/group" },
    { 0x07FB, "scripts/stealth/init" },
    { 0x07FC, "scripts/stealth/manager" },
    { 0x07FD, "scripts/stealth/neutral" },
    { 0x07FE, "scripts/stealth/player" },
    { 0x07FF, "scripts/stealth/threat_sight" },
    { 0x0800, "scripts/stealth/utility" },
    { 0x0801, "scripts/unittest/call" },
    { 0x0802, "scripts/unittest/cond" },
    { 0x0803, "scripts/unittest/error" },
    { 0x0804, "scripts/unittest/loop" },
    { 0x0805, "scripts/unittest/ops" },
    { 0x0806, "scripts/unittest/patch" },
    { 0x0807, "scripts/unittest/patch_far" },
    { 0x0808, "scripts/unittest/patch_new" },
    { 0x0809, "scripts/unittest/switch" },
    { 0x080A, "scripts/unittest/threads" },
    { 0x080B, "scripts/unittest/unittest" },
    { 0x080C, "scripts/unittest/util" },
    { 0x080D, "scripts/unittest/variables" },
    { 0x080E, "scripts/vehicle/apache" },
    { 0x080F, "scripts/vehicle/asierra" },
    { 0x0810, "scripts/vehicle/attack_heli" },
    { 0x0811, "scripts/vehicle/blima" },
    { 0x0812, "scripts/vehicle/blima_ground" },
    { 0x0813, "scripts/vehicle/bromeo" },
    { 0x0814, "scripts/vehicle/decho" },
    { 0x0815, "scripts/vehicle/drone_improvised" },
    { 0x0816, "scripts/vehicle/empty" },
    { 0x0817, "scripts/vehicle/empty_heli" },
    { 0x0818, "scripts/vehicle/empty_nocollision" },
    { 0x0819, "scripts/vehicle/empty_turret" },
    { 0x081A, "scripts/vehicle/lbravo" },
    { 0x081B, "scripts/vehicle/london_cab" },
    { 0x081C, "scripts/vehicle/mindia8" },
    { 0x081D, "scripts/vehicle/mindia8_jugg" },
    { 0x081E, "scripts/vehicle/mkilo23" },
    { 0x081F, "scripts/vehicle/mkilo23_ai_infil" },
    { 0x0820, "scripts/vehicle/palfa" },
    { 0x0821, "scripts/vehicle/pindia" },
    { 0x0822, "scripts/vehicle/ralfa" },
    { 0x0823, "scripts/vehicle/secho" },
    { 0x0824, "scripts/vehicle/skilo" },
    { 0x0825, "scripts/vehicle/stango" },
    { 0x0826, "scripts/vehicle/suniform25" },
    { 0x0827, "scripts/vehicle/techo" },
    { 0x0828, "scripts/vehicle/tromeo" },
    { 0x0829, "scripts/vehicle/umike" },
    { 0x082A, "scripts/vehicle/vehicle_common" },
    { 0x082B, "scripts/vehicle/victor40" },
    { 0x082C, "scripts/vehicle/vindia" },
    { 0x082D, "scripts/vehicle/walfa" },
    { 0x082E, "scripts/vehicle/zuniform" },
    { 0x082F, "scripts/aitypes/dog/combat" },
    { 0x0830, "scripts/aitypes/human/civilian_logic" },
    { 0x0831, "scripts/aitypes/juggernaut/behaviors" },
    { 0x0832, "scripts/aitypes/soldier/agent_setup" },
    { 0x0833, "scripts/aitypes/suicidebomber/combat" },
    { 0x0834, "scripts/aitypes/suicidebomber/setup_agent" },
    { 0x0835, "scripts/asm/civilian/script_funcs" },
    { 0x0836, "scripts/asm/dog/move" },
    { 0x0837, "scripts/asm/gesture/script_funcs" },
    { 0x0838, "scripts/asm/juggernaut/juggernaut" },
    { 0x0839, "scripts/asm/seeker/melee" },
    { 0x083A, "scripts/asm/shared/utility" },
    { 0x083B, "scripts/asm/shoot/script_funcs" },
    { 0x083C, "scripts/asm/soldier/arrival" },
    { 0x083D, "scripts/asm/soldier/cover" },
    { 0x083E, "scripts/asm/soldier/custom" },
    { 0x083F, "scripts/asm/soldier/death" },
    { 0x0840, "scripts/asm/soldier/grenade_response" },
    { 0x0841, "scripts/asm/soldier/interactable" },
    { 0x0842, "scripts/asm/soldier/lmg" },
    { 0x0843, "scripts/asm/soldier/long_death" },
    { 0x0844, "scripts/asm/soldier/melee" },
    { 0x0845, "scripts/asm/soldier/move" },
    { 0x0846, "scripts/asm/soldier/pain" },
    { 0x0847, "scripts/asm/soldier/patrol" },
    { 0x0848, "scripts/asm/soldier/patrol_idle" },
    { 0x0849, "scripts/asm/soldier/script_funcs" },
    { 0x084A, "scripts/asm/soldier/smartobject" },
    { 0x084B, "scripts/asm/soldier/throwgrenade" },
    { 0x084C, "scripts/asm/soldier/traverse" },
    { 0x084D, "scripts/asm/soldier/vehicle" },
    { 0x084E, "scripts/asm/suicidebomber/suicidebomber" },
    { 0x084F, "scripts/cp/agents/gametype_cp_strike" },
    { 0x0850, "scripts/cp/agents/gametype_cp_survival" },
    { 0x0851, "scripts/cp/agents/gametype_cp_wave_survival" },
    { 0x0852, "scripts/cp/agents/soldier_agent_spec" },
    { 0x0853, "scripts/cp/bomb_defusal/coop_bomb_defusal" },
    { 0x0854, "scripts/cp/classes/cp_class_progression" },
    { 0x0855, "scripts/cp/crate_drops/cp_crate_drops" },
    { 0x0856, "scripts/cp/crate_drops/cp_crate_drops_cs" },
    { 0x0857, "scripts/cp/drone/scout_drone" },
    { 0x0858, "scripts/cp/drone/utility" },
    { 0x0859, "scripts/cp/equipment/cp_at_mine" },
    { 0x085A, "scripts/cp/equipment/cp_gas_grenade" },
    { 0x085B, "scripts/cp/equipment/cp_javelin" },
    { 0x085C, "scripts/cp/equipment/cp_snapshot_grenade" },
    { 0x085D, "scripts/cp/equipment/cp_stinger" },
    { 0x085E, "scripts/cp/equipment/cp_thermite" },
    { 0x085F, "scripts/cp/equipment/cp_trophy_system" },
    { 0x0860, "scripts/cp/equipment/nvg" },
    { 0x0861, "scripts/cp/equipment/throwing_knife_cp" },
    { 0x0862, "scripts/cp/extraction/cp_extraction" },
    { 0x0863, "scripts/cp/factions/faction_progression" },
    { 0x0864, "scripts/cp/helicopter/cp_helicopter" },
    { 0x0865, "scripts/cp/infilexfil/blima_exfil" },
    { 0x0866, "scripts/cp/infilexfil/cp_fulton" },
    { 0x0867, "scripts/cp/infilexfil/infilexfil" },
    { 0x0868, "scripts/cp/infilexfil/lbravo_infil_cp" },
    { 0x0869, "scripts/cp/intel/cp_intel" },
    { 0x086A, "scripts/cp/inventory/cp_ac130" },
    { 0x086B, "scripts/cp/inventory/cp_target_marker" },
    { 0x086C, "scripts/cp/killstreaks/airdrop_cp" },
    { 0x086D, "scripts/cp/killstreaks/airdrop_multiple_cp" },
    { 0x086E, "scripts/cp/killstreaks/airstrike_cp" },
    { 0x086F, "scripts/cp/killstreaks/chopper_gunner_cp" },
    { 0x0870, "scripts/cp/killstreaks/chopper_support_cp" },
    { 0x0871, "scripts/cp/killstreaks/cruise_predator_cp" },
    { 0x0872, "scripts/cp/killstreaks/emp_drone_cp" },
    { 0x0873, "scripts/cp/killstreaks/emp_drone_targeted_cp" },
    { 0x0874, "scripts/cp/killstreaks/gunship_cp" },
    { 0x0875, "scripts/cp/killstreaks/helper_drone_cp" },
    { 0x0876, "scripts/cp/killstreaks/init_cp" },
    { 0x0877, "scripts/cp/killstreaks/juggernaut_cp" },
    { 0x0878, "scripts/cp/killstreaks/manual_turret_cp" },
    { 0x0879, "scripts/cp/killstreaks/sentry_gun_cp" },
    { 0x087A, "scripts/cp/killstreaks/toma_strike_cp" },
    { 0x087B, "scripts/cp/killstreaks/uav_cp" },
    { 0x087C, "scripts/cp/killstreaks/white_phosphorus_cp" },
    { 0x087D, "scripts/cp/perks/cp_perk_utility" },
    { 0x087E, "scripts/cp/perks/cp_perks" },
    { 0x087F, "scripts/cp/perks/cp_prestige" },
    { 0x0880, "scripts/cp/powers/coop_molotov" },
    { 0x0881, "scripts/cp/powers/cp_tactical_cover" },
    { 0x0882, "scripts/cp/pvpe/pvpe" },
    { 0x0883, "scripts/cp/pvpve/pvpve" },
    { 0x0884, "scripts/cp/radio_tower/cp_radio_tower" },
    { 0x0885, "scripts/cp/respawn/cp_ac130_respawn" },
    { 0x0886, "scripts/cp/respawn/cp_respawn" },
    { 0x0887, "scripts/cp/survival/survival_loadout" },
    { 0x0888, "scripts/cp/utility/disconnect_event_aggregator" },
    { 0x0889, "scripts/cp/utility/entity" },
    { 0x088A, "scripts/cp/utility/game_utility_cp" },
    { 0x088B, "scripts/cp/utility/join_team_aggregator" },
    { 0x088C, "scripts/cp/utility/lui_game_event_aggregator" },
    { 0x088D, "scripts/cp/utility/player" },
    { 0x088E, "scripts/cp/utility/player_frame_update_aggregator" },
    { 0x088F, "scripts/cp/utility/player_utility_cp" },
    { 0x0890, "scripts/cp/utility/spawn_event_aggregator" },
    { 0x0891, "scripts/cp/vehicle_push/coop_vehicle_push" },
    { 0x0892, "scripts/cp/vehicle_race/coop_vehicle_race" },
    { 0x0893, "scripts/cp/vehicles/apc_rus_cp" },
    { 0x0894, "scripts/cp/vehicles/atv_cp" },
    { 0x0895, "scripts/cp/vehicles/big_bird_cp" },
    { 0x0896, "scripts/cp/vehicles/cargo_truck_cp" },
    { 0x0897, "scripts/cp/vehicles/cop_car_cp" },
    { 0x0898, "scripts/cp/vehicles/cp_heli_trip" },
    { 0x0899, "scripts/cp/vehicles/cp_helicopter_mi8" },
    { 0x089A, "scripts/cp/vehicles/damage_cp" },
    { 0x089B, "scripts/cp/vehicles/hoopty_cp" },
    { 0x089C, "scripts/cp/vehicles/hoopty_truck_cp" },
    { 0x089D, "scripts/cp/vehicles/jeep_cp" },
    { 0x089E, "scripts/cp/vehicles/large_transport_cp" },
    { 0x089F, "scripts/cp/vehicles/light_tank_cp" },
    { 0x08A0, "scripts/cp/vehicles/little_bird_cp" },
    { 0x08A1, "scripts/cp/vehicles/med_transport_cp" },
    { 0x08A2, "scripts/cp/vehicles/pickup_truck_cp" },
    { 0x08A3, "scripts/cp/vehicles/tac_rover_cp" },
    { 0x08A4, "scripts/cp/vehicles/technical_cp" },
    { 0x08A5, "scripts/cp/vehicles/van_cp" },
    { 0x08A6, "scripts/cp/vehicles/vehicle_cp" },
    { 0x08A7, "scripts/cp/vehicles/vehicle_interact_cp" },
    { 0x08A8, "scripts/cp/vehicles/vehicle_occupancy_cp" },
    { 0x08A9, "scripts/cp/vehicles/vehicle_oob_cp" },
    { 0x08AA, "scripts/cp/vehicles/vehicle_spawn_cp" },
    { 0x08AB, "scripts/cp/zombies/cp_consumables" },
    { 0x08AC, "scripts/cp/zombies/zombieclientmatchdata" },
    { 0x08AD, "scripts/cp_mp/agents/agent_init" },
    { 0x08AE, "scripts/cp_mp/equipment/throwing_knife" },
    { 0x08AF, "scripts/cp_mp/killstreaks/airdrop" },
    { 0x08B0, "scripts/cp_mp/killstreaks/airdrop_multiple" },
    { 0x08B1, "scripts/cp_mp/killstreaks/airstrike" },
    { 0x08B2, "scripts/cp_mp/killstreaks/chopper_gunner" },
    { 0x08B3, "scripts/cp_mp/killstreaks/chopper_support" },
    { 0x08B4, "scripts/cp_mp/killstreaks/cruise_predator" },
    { 0x08B5, "scripts/cp_mp/killstreaks/emp_drone" },
    { 0x08B6, "scripts/cp_mp/killstreaks/emp_drone_targeted" },
    { 0x08B7, "scripts/cp_mp/killstreaks/gunship" },
    { 0x08B8, "scripts/cp_mp/killstreaks/helper_drone" },
    { 0x08B9, "scripts/cp_mp/killstreaks/init" },
    { 0x08BA, "scripts/cp_mp/killstreaks/juggernaut" },
    { 0x08BB, "scripts/cp_mp/killstreaks/killstreakdeploy" },
    { 0x08BC, "scripts/cp_mp/killstreaks/manual_turret" },
    { 0x08BD, "scripts/cp_mp/killstreaks/sentry_gun" },
    { 0x08BE, "scripts/cp_mp/killstreaks/toma_strike" },
    { 0x08BF, "scripts/cp_mp/killstreaks/uav" },
    { 0x08C0, "scripts/cp_mp/killstreaks/white_phosphorus" },
    { 0x08C1, "scripts/cp_mp/utility/damage_utility" },
    { 0x08C2, "scripts/cp_mp/utility/debug_utility" },
    { 0x08C3, "scripts/cp_mp/utility/dialog_utility" },
    { 0x08C4, "scripts/cp_mp/utility/game_utility" },
    { 0x08C5, "scripts/cp_mp/utility/inventory_utility" },
    { 0x08C6, "scripts/cp_mp/utility/killstreak_utility" },
    { 0x08C7, "scripts/cp_mp/utility/player_utility" },
    { 0x08C8, "scripts/cp_mp/utility/script_utility" },
    { 0x08C9, "scripts/cp_mp/utility/shellshock_utility" },
    { 0x08CA, "scripts/cp_mp/utility/vehicle_omnvar_utility" },
    { 0x08CB, "scripts/cp_mp/utility/weapon_utility" },
    { 0x08CC, "scripts/cp_mp/vehicles/apc_rus" },
    { 0x08CD, "scripts/cp_mp/vehicles/atv" },
    { 0x08CE, "scripts/cp_mp/vehicles/big_bird" },
    { 0x08CF, "scripts/cp_mp/vehicles/cargo_truck" },
    { 0x08D0, "scripts/cp_mp/vehicles/cop_car" },
    { 0x08D1, "scripts/cp_mp/vehicles/hoopty" },
    { 0x08D2, "scripts/cp_mp/vehicles/hoopty_truck" },
    { 0x08D3, "scripts/cp_mp/vehicles/jeep" },
    { 0x08D4, "scripts/cp_mp/vehicles/large_transport" },
    { 0x08D5, "scripts/cp_mp/vehicles/light_tank" },
    { 0x08D6, "scripts/cp_mp/vehicles/little_bird" },
    { 0x08D7, "scripts/cp_mp/vehicles/med_transport" },
    { 0x08D8, "scripts/cp_mp/vehicles/pickup_truck" },
    { 0x08D9, "scripts/cp_mp/vehicles/tac_rover" },
    { 0x08DA, "scripts/cp_mp/vehicles/technical" },
    { 0x08DB, "scripts/cp_mp/vehicles/van" },
    { 0x08DC, "scripts/cp_mp/vehicles/vehicle" },
    { 0x08DD, "scripts/cp_mp/vehicles/vehicle_damage" },
    { 0x08DE, "scripts/cp_mp/vehicles/vehicle_dlog" },
    { 0x08DF, "scripts/cp_mp/vehicles/vehicle_interact" },
    { 0x08E0, "scripts/cp_mp/vehicles/vehicle_mines" },
    { 0x08E1, "scripts/cp_mp/vehicles/vehicle_occupancy" },
    { 0x08E2, "scripts/cp_mp/vehicles/vehicle_spawn" },
    { 0x08E3, "scripts/cp_mp/vehicles/vehicle_tracking" },
    { 0x08E4, "scripts/engine/sp/objectives" },
    { 0x08E5, "scripts/engine/sp/utility" },
    { 0x08E6, "scripts/engine/sp/utility_code" },
    { 0x08E7, "scripts/game/sp/door" },
    { 0x08E8, "scripts/game/sp/load" },
    { 0x08E9, "scripts/game/sp/outline" },
    { 0x08EA, "scripts/game/sp/player" },
    { 0x08EB, "scripts/game/sp/trigger" },
    { 0x08EC, "scripts/mp/agents/agent_utility" },
    { 0x08ED, "scripts/mp/archetypes/archassault" },
    { 0x08EE, "scripts/mp/archetypes/archcommon" },
    { 0x08EF, "scripts/mp/arm_objectives/arm_obj_capture" },
    { 0x08F0, "scripts/mp/arm_objectives/arm_obj_nuke" },
    { 0x08F1, "scripts/mp/bots/bots_killstreaks" },
    { 0x08F2, "scripts/mp/bots/bots_killstreaks_remote_vehicle" },
    { 0x08F3, "scripts/mp/bots/bots_loadout" },
    { 0x08F4, "scripts/mp/bots/bots_personality" },
    { 0x08F5, "scripts/mp/bots/bots_sentry" },
    { 0x08F6, "scripts/mp/bots/bots_strategy" },
    { 0x08F7, "scripts/mp/bots/bots_util" },
    { 0x08F8, "scripts/mp/cinematic_replays/cinematic_replays" },
    { 0x08F9, "scripts/mp/equipment/adrenaline" },
    { 0x08FA, "scripts/mp/equipment/advanced_supply_drop" },
    { 0x08FB, "scripts/mp/equipment/ammo_box" },
    { 0x08FC, "scripts/mp/equipment/armor_plate" },
    { 0x08FD, "scripts/mp/equipment/at_mine" },
    { 0x08FE, "scripts/mp/equipment/bandage" },
    { 0x08FF, "scripts/mp/equipment/c4" },
    { 0x0900, "scripts/mp/equipment/claymore" },
    { 0x0901, "scripts/mp/equipment/concussion_grenade" },
    { 0x0902, "scripts/mp/equipment/decoy_grenade" },
    { 0x0903, "scripts/mp/equipment/emp_grenade" },
    { 0x0904, "scripts/mp/equipment/flash_grenade" },
    { 0x0905, "scripts/mp/equipment/gas_grenade" },
    { 0x0906, "scripts/mp/equipment/hb_sensor" },
    { 0x0907, "scripts/mp/equipment/molotov" },
    { 0x0908, "scripts/mp/equipment/nvg" },
    { 0x0909, "scripts/mp/equipment/snapshot_grenade" },
    { 0x090A, "scripts/mp/equipment/support_box" },
    { 0x090B, "scripts/mp/equipment/tac_insert" },
    { 0x090C, "scripts/mp/equipment/tactical_cover" },
    { 0x090D, "scripts/mp/equipment/thermite" },
    { 0x090E, "scripts/mp/equipment/throwing_knife_mp" },
    { 0x090F, "scripts/mp/equipment/trophy_system" },
    { 0x0910, "scripts/mp/equipment/weapon_drop" },
    { 0x0911, "scripts/mp/equipment/wristrocket" },
    { 0x0912, "scripts/mp/infilexfil/infilexfil" },
    { 0x0913, "scripts/mp/infilexfil/lbravo_infil" },
    { 0x0914, "scripts/mp/infilexfil/mi8_infil" },
    { 0x0915, "scripts/mp/infilexfil/rappel_hackney_infil" },
    { 0x0916, "scripts/mp/infilexfil/tango72_infil" },
    { 0x0917, "scripts/mp/infilexfil/umike_infil" },
    { 0x0918, "scripts/mp/infilexfil/van_hackney_infil" },
    { 0x0919, "scripts/mp/infilexfil/vindia_infil" },
    { 0x091A, "scripts/mp/killstreaks/agent_killstreak" },
    { 0x091B, "scripts/mp/killstreaks/airdrop_mp" },
    { 0x091C, "scripts/mp/killstreaks/airdrop_multiple_mp" },
    { 0x091D, "scripts/mp/killstreaks/airstrike_mp" },
    { 0x091E, "scripts/mp/killstreaks/autosentry" },
    { 0x091F, "scripts/mp/killstreaks/chill_common" },
    { 0x0920, "scripts/mp/killstreaks/chopper_gunner_mp" },
    { 0x0921, "scripts/mp/killstreaks/chopper_support_mp" },
    { 0x0922, "scripts/mp/killstreaks/cruise_predator_mp" },
    { 0x0923, "scripts/mp/killstreaks/death_switch" },
    { 0x0924, "scripts/mp/killstreaks/deployablebox" },
    { 0x0925, "scripts/mp/killstreaks/deployablebox_vest" },
    { 0x0926, "scripts/mp/killstreaks/dronehive" },
    { 0x0927, "scripts/mp/killstreaks/emp" },
    { 0x0928, "scripts/mp/killstreaks/emp_drone_mp" },
    { 0x0929, "scripts/mp/killstreaks/emp_drone_targeted_mp" },
    { 0x092A, "scripts/mp/killstreaks/flares" },
    { 0x092B, "scripts/mp/killstreaks/gunship_mp" },
    { 0x092C, "scripts/mp/killstreaks/helicopter" },
    { 0x092D, "scripts/mp/killstreaks/helicopter_pilot" },
    { 0x092E, "scripts/mp/killstreaks/helper_drone" },
    { 0x092F, "scripts/mp/killstreaks/helper_drone_mp" },
    { 0x0930, "scripts/mp/killstreaks/hover_jet" },
    { 0x0931, "scripts/mp/killstreaks/init_mp" },
    { 0x0932, "scripts/mp/killstreaks/jackal" },
    { 0x0933, "scripts/mp/killstreaks/juggernaut_mp" },
    { 0x0934, "scripts/mp/killstreaks/killstreaks" },
    { 0x0935, "scripts/mp/killstreaks/manual_turret_mp" },
    { 0x0936, "scripts/mp/killstreaks/mapselect" },
    { 0x0937, "scripts/mp/killstreaks/nuke" },
    { 0x0938, "scripts/mp/killstreaks/placeable" },
    { 0x0939, "scripts/mp/killstreaks/plane" },
    { 0x093A, "scripts/mp/killstreaks/proxyagent" },
    { 0x093B, "scripts/mp/killstreaks/remotemissile" },
    { 0x093C, "scripts/mp/killstreaks/remotetank" },
    { 0x093D, "scripts/mp/killstreaks/remoteturret" },
    { 0x093E, "scripts/mp/killstreaks/remoteuav" },
    { 0x093F, "scripts/mp/killstreaks/sentry_gun_mp" },
    { 0x0940, "scripts/mp/killstreaks/target_marker" },
    { 0x0941, "scripts/mp/killstreaks/throwback_marker" },
    { 0x0942, "scripts/mp/killstreaks/toma_strike_mp" },
    { 0x0943, "scripts/mp/killstreaks/uav_mp" },
    { 0x0944, "scripts/mp/killstreaks/white_phosphorus_mp" },
    { 0x0945, "scripts/mp/perks/headgear" },
    { 0x0946, "scripts/mp/perks/perk_equipmentping" },
    { 0x0947, "scripts/mp/perks/perk_mark_targets" },
    { 0x0948, "scripts/mp/perks/perkfunctions" },
    { 0x0949, "scripts/mp/perks/perkpackage" },
    { 0x094A, "scripts/mp/perks/perks" },
    { 0x094B, "scripts/mp/perks/weaponpassives" },
    { 0x094C, "scripts/mp/supers/laststand_heal" },
    { 0x094D, "scripts/mp/supers/spawnbeacon" },
    { 0x094E, "scripts/mp/supers/super_deadsilence" },
    { 0x094F, "scripts/mp/supers/super_stoppingpower" },
    { 0x0950, "scripts/mp/tac_ops/hostage_utility" },
    { 0x0951, "scripts/mp/tac_ops/hvt_utility" },
    { 0x0952, "scripts/mp/tac_ops/radio_utility" },
    { 0x0953, "scripts/mp/tac_ops/roles_utility" },
    { 0x0954, "scripts/mp/trials/mp_trials_patches" },
    { 0x0955, "scripts/mp/trials/mp_trl_cleararea" },
    { 0x0956, "scripts/mp/trials/mp_trl_destroy" },
    { 0x0957, "scripts/mp/utility/damage" },
    { 0x0958, "scripts/mp/utility/debug" },
    { 0x0959, "scripts/mp/utility/dialog" },
    { 0x095A, "scripts/mp/utility/disconnect_event_aggregator" },
    { 0x095B, "scripts/mp/utility/dvars" },
    { 0x095C, "scripts/mp/utility/entity" },
    { 0x095D, "scripts/mp/utility/equipment" },
    { 0x095E, "scripts/mp/utility/game" },
    { 0x095F, "scripts/mp/utility/game_utility_mp" },
    { 0x0960, "scripts/mp/utility/infilexfil" },
    { 0x0961, "scripts/mp/utility/inventory" },
    { 0x0962, "scripts/mp/utility/join_squad_aggregator" },
    { 0x0963, "scripts/mp/utility/join_team_aggregator" },
    { 0x0964, "scripts/mp/utility/killstreak" },
    { 0x0965, "scripts/mp/utility/lower_message" },
    { 0x0966, "scripts/mp/utility/lui_game_event_aggregator" },
    { 0x0967, "scripts/mp/utility/outline" },
    { 0x0968, "scripts/mp/utility/perk" },
    { 0x0969, "scripts/mp/utility/player" },
    { 0x096A, "scripts/mp/utility/player_frame_update_aggregator" },
    { 0x096B, "scripts/mp/utility/points" },
    { 0x096C, "scripts/mp/utility/print" },
    { 0x096D, "scripts/mp/utility/script" },
    { 0x096E, "scripts/mp/utility/sound" },
    { 0x096F, "scripts/mp/utility/spawn_event_aggregator" },
    { 0x0970, "scripts/mp/utility/stats" },
    { 0x0971, "scripts/mp/utility/teams" },
    { 0x0972, "scripts/mp/utility/trigger" },
    { 0x0973, "scripts/mp/utility/usability" },
    { 0x0974, "scripts/mp/utility/weapon" },
    { 0x0975, "scripts/mp/vehicles/apc_rus_mp" },
    { 0x0976, "scripts/mp/vehicles/atv_mp" },
    { 0x0977, "scripts/mp/vehicles/big_bird_mp" },
    { 0x0978, "scripts/mp/vehicles/cargo_truck_mp" },
    { 0x0979, "scripts/mp/vehicles/cop_car_mp" },
    { 0x097A, "scripts/mp/vehicles/damage" },
    { 0x097B, "scripts/mp/vehicles/hoopty_mp" },
    { 0x097C, "scripts/mp/vehicles/hoopty_truck_mp" },
    { 0x097D, "scripts/mp/vehicles/jeep_mp" },
    { 0x097E, "scripts/mp/vehicles/large_transport_mp" },
    { 0x097F, "scripts/mp/vehicles/light_tank_mp" },
    { 0x0980, "scripts/mp/vehicles/little_bird_mp" },
    { 0x0981, "scripts/mp/vehicles/med_transport_mp" },
    { 0x0982, "scripts/mp/vehicles/pickup_truck_mp" },
    { 0x0983, "scripts/mp/vehicles/tac_rover_mp" },
    { 0x0984, "scripts/mp/vehicles/technical_mp" },
    { 0x0985, "scripts/mp/vehicles/van_mp" },
    { 0x0986, "scripts/mp/vehicles/vehicle_interact_mp" },
    { 0x0987, "scripts/mp/vehicles/vehicle_mines_mp" },
    { 0x0988, "scripts/mp/vehicles/vehicle_mp" },
    { 0x0989, "scripts/mp/vehicles/vehicle_occupancy_mp" },
    { 0x098A, "scripts/mp/vehicles/vehicle_oob_mp" },
    { 0x098B, "scripts/mp/vehicles/vehicle_spawn_mp" },
    { 0x098C, "scripts/sp/destructibles/barrel_common" },
    { 0x098D, "scripts/sp/destructibles/destructible_vehicle" },
    { 0x098E, "scripts/sp/destructibles/oil_barrel" },
    { 0x098F, "scripts/sp/destructibles/red_barrel" },
    { 0x0990, "scripts/sp/destructibles/water_barrel" },
    { 0x0991, "scripts/sp/equipment/c4" },
    { 0x0992, "scripts/sp/equipment/flash" },
    { 0x0993, "scripts/sp/equipment/frag" },
    { 0x0994, "scripts/sp/equipment/green_beam" },
    { 0x0995, "scripts/sp/equipment/ied" },
    { 0x0996, "scripts/sp/equipment/incendiarylauncher" },
    { 0x0997, "scripts/sp/equipment/molotov" },
    { 0x0998, "scripts/sp/equipment/noisemaker" },
    { 0x0999, "scripts/sp/equipment/offhands" },
    { 0x099A, "scripts/sp/equipment/pipebomb" },
    { 0x099B, "scripts/sp/equipment/semtex" },
    { 0x099C, "scripts/sp/equipment/signal" },
    { 0x099D, "scripts/sp/equipment/smoke" },
    { 0x099E, "scripts/sp/equipment/teargas" },
    { 0x099F, "scripts/sp/equipment/throwingknife" },
    { 0x09A0, "scripts/sp/equipment/tripwire" },
    { 0x09A1, "scripts/sp/interactables/dynolight" },
    { 0x09A2, "scripts/sp/nvg/nvg_ai" },
    { 0x09A3, "scripts/sp/nvg/nvg_player" },
    { 0x09A4, "scripts/sp/player/ally_equipment" },
    { 0x09A5, "scripts/sp/player/ballistics" },
    { 0x09A6, "scripts/sp/player/bullet_feedback" },
    { 0x09A7, "scripts/sp/player/context_melee" },
    { 0x09A8, "scripts/sp/player/cursor_hint" },
    { 0x09A9, "scripts/sp/player/flare" },
    { 0x09AA, "scripts/sp/player/gestures" },
    { 0x09AB, "scripts/sp/player/offhand_box" },
    { 0x09AC, "scripts/sp/player/playerchatter" },
    { 0x09AD, "scripts/sp/player/teenagefarah" },
    { 0x09AE, "scripts/sp/player/youngfarrah" },
    { 0x09AF, "scripts/sp/stealth/idle_sitting" },
    { 0x09B0, "scripts/sp/stealth/manager" },
    { 0x09B1, "scripts/sp/stealth/player" },
    { 0x09B2, "scripts/sp/stealth/tagging" },
    { 0x09B3, "scripts/sp/stealth/utility" },
    { 0x09B4, "scripts/asm/shared/mp/utility" },
    { 0x09B5, "scripts/asm/shared/sp/utility" },
    { 0x09B6, "scripts/asm/soldier/mp/gesture_script_funcs" },
    { 0x09B7, "scripts/asm/soldier/mp/script_funcs" },
    { 0x09B8, "scripts/asm/soldier/sp/melee" },
    { 0x09B9, "scripts/asm/soldier/sp/script_funcs" },
    { 0x09BA, "scripts/game/sp/stealth/manager" },
    { 0x09BB, "scripts/mp/agents/juggernaut/juggernaut_agent" },
    { 0x09BC, "scripts/mp/agents/soldier/soldier_agent" },
    { 0x09BD, "scripts/mp/agents/suicidebomber/suicidebomber_agent" },
    { 0x09BE, "__smangles" },
    { 0x09BF, "__smid" },
    { 0x09C0, "__smname" },
    { 0x09C1, "__smorigin" },
    { 0x09C2, "__smuid" },
    { 0x09C3, "_add_objective" },
    { 0x09C4, "_add_z" },
    { 0x09C5, "_ai_delete" },
    { 0x09C6, "_ai_gesture_head_additives" },
    { 0x09C7, "_ai_group" },
    { 0x09C8, "_ai_head_weight_blend_in" },
    { 0x09C9, "_ai_health" },
    { 0x09CA, "_ai_torso_weight_blend_in" },
    { 0x09CB, "_alarmmonitorinternal" },
    { 0x09CC, "_allowbattleslide" },
    { 0x09CD, "_ambush_rpg_after_spawn" },
    { 0x09CE, "_ambush_squad_func" },
    { 0x09CF, "_anim_scene_actor_end_interrupt_think" },
    { 0x09D0, "_anim_scene_ender_think" },
    { 0x09D1, "_anim_scene_force_end_think" },
    { 0x09D2, "_anim_scene_internal" },
    { 0x09D3, "_anim_scene_internal_blend_in" },
    { 0x09D4, "_anim_scene_internal_end" },
    { 0x09D5, "_anim_scene_internal_finish_blend" },
    { 0x09D6, "_anim_scene_internal_get_anim_duration" },
    { 0x09D7, "_anim_scene_internal_start_anims" },
    { 0x09D8, "_anim_scene_interrupt_think" },
    { 0x09D9, "_animactive" },
    { 0x09DA, "_anime" },
    { 0x09DB, "_animmode" },
    { 0x09DC, "_animname" },
    { 0x09DD, "_ar_callout_tracker" },
    { 0x09DE, "_array_wait" },
    { 0x09DF, "_arraytostring" },
    { 0x09E0, "_assignthinkoffset" },
    { 0x09E1, "_audio_random_array_dict" },
    { 0x09E2, "_autosave_game_now" },
    { 0x09E3, "_autosave_stealthcheck" },
    { 0x09E4, "_baseeffect" },
    { 0x09E5, "_baseeffectenemy" },
    { 0x09E6, "_baseeffectfriendly" },
    { 0x09E7, "_battlechatter" },
    { 0x09E8, "_beginlocationselection" },
    { 0x09E9, "_blackboard" },
    { 0x09EA, "_box_setactivehelper" },
    { 0x09EB, "_br_circle_expected_players" },
    { 0x09EC, "_br_circle_min_lerp_time" },
    { 0x09ED, "_br_circles_dist" },
    { 0x09EE, "_branalytics_header" },
    { 0x09EF, "_btactions" },
    { 0x09F0, "_buildweaponcustom" },
    { 0x09F1, "_bullet_trace" },
    { 0x09F2, "_bullet_trace_passed" },
    { 0x09F3, "_checkforregister" },
    { 0x09F4, "_circledurationforplayer" },
    { 0x09F5, "_clearalltextafterhudelem" },
    { 0x09F6, "_clearexecution" },
    { 0x09F7, "_clearperks" },
    { 0x09F8, "_clearregisters" },
    { 0x09F9, "_color" },
    { 0x09FA, "_color_friendly_spawners" },
    { 0x09FB, "_colors_go_line" },
    { 0x09FC, "_completebet" },
    { 0x09FD, "_create_tagging_highlight" },
    { 0x09FE, "_createfx" },
    { 0x09FF, "_createheadicon" },
    { 0x0A00, "_createnavobstacle" },
    { 0x0A01, "_csm_bound_center" },
    { 0x0A02, "_csm_bound_halfsize" },
    { 0x0A03, "_custom_anim" },
    { 0x0A04, "_custom_anim_loop" },
    { 0x0A05, "_custom_anim_thread" },
    { 0x0A06, "_defaultnotetrackhandler" },
    { 0x0A07, "_defusesetup" },
    { 0x0A08, "_delete_ents" },
    { 0x0A09, "_deletevehicle" },
    { 0x0A0A, "_deployhacktablet" },
    { 0x0A0B, "_destroyheadicon" },
    { 0x0A0C, "_destroynavobstacle" },
    { 0x0A0D, "_detachall" },
    { 0x0A0E, "_disable_hudoutline_on_ent" },
    { 0x0A0F, "_disableequipdeployvfx" },
    { 0x0A10, "_disableignoreme" },
    { 0x0A11, "_domflageffect" },
    { 0x0A12, "_domflagpulseeffect" },
    { 0x0A13, "_draw_arrow" },
    { 0x0A14, "_effect" },
    { 0x0A15, "_effect_keys" },
    { 0x0A16, "_effects" },
    { 0x0A17, "_emp_grenade_apply_player" },
    { 0x0A18, "_emp_grenade_end_early" },
    { 0x0A19, "_enable_hudoutline_on_channel_ents" },
    { 0x0A1A, "_enable_hudoutline_on_ent" },
    { 0x0A1B, "_enablecollisionnotifies" },
    { 0x0A1C, "_enableequipdeployvfx" },
    { 0x0A1D, "_enableignoreme" },
    { 0x0A1E, "_end_heli_spawn_group" },
    { 0x0A1F, "_end_reinforcements" },
    { 0x0A20, "_end_spawn_group" },
    { 0x0A21, "_end_tagging_highlighting" },
    { 0x0A22, "_findexisitingquestlocale" },
    { 0x0A23, "_findnewdomflagoriginplaced" },
    { 0x0A24, "_findnewdomflagoriginrandom" },
    { 0x0A25, "_findunobstructedfiringpointhelper" },
    { 0x0A26, "_fire" },
    { 0x0A27, "_first_frame_anim" },
    { 0x0A28, "_flag_wait_trigger" },
    { 0x0A29, "_flageffect" },
    { 0x0A2A, "_flagradiuseffect" },
    { 0x0A2B, "_freeze_until_phototaken" },
    { 0x0A2C, "_freezecontrols" },
    { 0x0A2D, "_freezelookcontrols" },
    { 0x0A2E, "_fx" },
    { 0x0A2F, "_genericsearcharea" },
    { 0x0A30, "_get_sorted_list_of_channel_plus_child_channels" },
    { 0x0A31, "_getlocation" },
    { 0x0A32, "_getphysicspointaboutnavmesh" },
    { 0x0A33, "_getplayerscore" },
    { 0x0A34, "_getradarstrength" },
    { 0x0A35, "_getrandomspawnstructs" },
    { 0x0A36, "_getteamscore" },
    { 0x0A37, "_getvehiclespawnerarray" },
    { 0x0A38, "_givebrsuper" },
    { 0x0A39, "_giveexecution" },
    { 0x0A3A, "_giveweapon" },
    { 0x0A3B, "_global_fx_ents" },
    { 0x0A3C, "_hacksetup" },
    { 0x0A3D, "_hardpointeffect" },
    { 0x0A3E, "_hasperk" },
    { 0x0A3F, "_heapgreaterthan" },
    { 0x0A40, "_heapify" },
    { 0x0A41, "_heapleftchild" },
    { 0x0A42, "_heaplessthan" },
    { 0x0A43, "_heapparent" },
    { 0x0A44, "_heaprightchild" },
    { 0x0A45, "_hidefromplayer" },
    { 0x0A46, "_hint_stick_get_config_suffix" },
    { 0x0A47, "_hint_stick_update_breakfunc" },
    { 0x0A48, "_hint_stick_update_string" },
    { 0x0A49, "_hudoutlineenableforclient" },
    { 0x0A4A, "_hudoutlineenableforclients" },
    { 0x0A4B, "_hudoutlineviewmodeldisable" },
    { 0x0A4C, "_hudoutlineviewmodelenable" },
    { 0x0A4D, "_init_door_internal" },
    { 0x0A4E, "_initmanagerquestthread" },
    { 0x0A4F, "_initpic" },
    { 0x0A50, "_intel_dismiss_button_listener" },
    { 0x0A51, "_intel_waypoint_button_listener" },
    { 0x0A52, "_interactive" },
    { 0x0A53, "_interactmonitor" },
    { 0x0A54, "_is_godmode" },
    { 0x0A55, "_is_looking_at_range" },
    { 0x0A56, "_isalive" },
    { 0x0A57, "_isquestthreaded" },
    { 0x0A58, "_issuspendedvehicle" },
    { 0x0A59, "_kill_fx_play_direction" },
    { 0x0A5A, "_lastanime" },
    { 0x0A5B, "_lastanimtime" },
    { 0x0A5C, "_launchgrenade" },
    { 0x0A5D, "_launchsinglenuke" },
    { 0x0A5E, "_leaderafterspawnfunc" },
    { 0x0A5F, "_linkto" },
    { 0x0A60, "_loadstarted" },
    { 0x0A61, "_magicbullet" },
    { 0x0A62, "_mainturretoff" },
    { 0x0A63, "_mainturreton" },
    { 0x0A64, "_makekioskpurchase" },
    { 0x0A65, "_managenukeexplosionvisionset" },
    { 0x0A66, "_max_script_health" },
    { 0x0A67, "_mgoff" },
    { 0x0A68, "_mgon" },
    { 0x0A69, "_missing_fx" },
    { 0x0A6A, "_mobilearmorychooseclass" },
    { 0x0A6B, "_mobilearmoryendusethink" },
    { 0x0A6C, "_mobilearmorymanageminimapicon" },
    { 0x0A6D, "_mobilearmoryusethink" },
    { 0x0A6E, "_newhudelem" },
    { 0x0A6F, "_notetrackfx" },
    { 0x0A70, "_objective_addlocation" },
    { 0x0A71, "_objective_delete" },
    { 0x0A72, "_objective_getindexforname" },
    { 0x0A73, "_objective_getnextfreelocationindex" },
    { 0x0A74, "_objective_getnextfreeobjectiveindex" },
    { 0x0A75, "_objective_initindexforname" },
    { 0x0A76, "_objective_validatename" },
    { 0x0A77, "_ondeathordisconnectinternal" },
    { 0x0A78, "_onenteractivestate" },
    { 0x0A79, "_onenterchargingstate" },
    { 0x0A7A, "_onentercooldownstate" },
    { 0x0A7B, "_onenterdefaultstate" },
    { 0x0A7C, "_onenterscanningstate" },
    { 0x0A7D, "_onexitactivestate" },
    { 0x0A7E, "_onexitchargingstate" },
    { 0x0A7F, "_onexitdefaultstate" },
    { 0x0A80, "_onexitscanningstate" },
    { 0x0A81, "_ontabletpulledout" },
    { 0x0A82, "_ontabletputaway" },
    { 0x0A83, "_open_door" },
    { 0x0A84, "_parsepurchaseitemtables" },
    { 0x0A85, "_picknextcirclecenter" },
    { 0x0A86, "_play_interaction_anim_vo_note" },
    { 0x0A87, "_play_player_dialogue" },
    { 0x0A88, "_player_allowed_stances" },
    { 0x0A89, "_playerrespawntext" },
    { 0x0A8A, "_playradioecho" },
    { 0x0A8B, "_playsound" },
    { 0x0A8C, "_poistateupdate" },
    { 0x0A8D, "_precache" },
    { 0x0A8E, "_precomputedlosdatatest" },
    { 0x0A8F, "_primarylightcount" },
    { 0x0A90, "_processusethink" },
    { 0x0A91, "_questinstancesactive" },
    { 0x0A92, "_questmanagerthread" },
    { 0x0A93, "_questthreadsactive" },
    { 0x0A94, "_radiusdamage" },
    { 0x0A95, "_redefine_interaction_radius_cleanup" },
    { 0x0A96, "_registerquestcategory" },
    { 0x0A97, "_registerquestfunc" },
    { 0x0A98, "_remove_tagging_highlight_on_death" },
    { 0x0A99, "_removecashstateforplayer" },
    { 0x0A9A, "_removemanagerquestthread" },
    { 0x0A9B, "_resetenableignoreme" },
    { 0x0A9C, "_rpg_skit_after_spawn" },
    { 0x0A9D, "_runaddquestinstance" },
    { 0x0A9E, "_runaddquestthread" },
    { 0x0A9F, "_runcheckiflocaleisavailable" },
    { 0x0AA0, "_runclearquestvars" },
    { 0x0AA1, "_runcooldownphase" },
    { 0x0AA2, "_runcreatequestlocale" },
    { 0x0AA3, "_runfindsearcharea" },
    { 0x0AA4, "_runinitquesttype" },
    { 0x0AA5, "_runinitquestvars" },
    { 0x0AA6, "_runpurchasemenu" },
    { 0x0AA7, "_runquestthink" },
    { 0x0AA8, "_runquestthinkfunctions" },
    { 0x0AA9, "_runremovequestinstance" },
    { 0x0AAA, "_runremovequestthread" },
    { 0x0AAB, "_satellitetruckactivate" },
    { 0x0AAC, "_satellitetruckendusethink" },
    { 0x0AAD, "_satellitetruckmanageminimapicon" },
    { 0x0AAE, "_satellitetruckstartsound" },
    { 0x0AAF, "_satellitetruckusethink" },
    { 0x0AB0, "_schedulenukes" },
    { 0x0AB1, "_screenshakeonposition" },
    { 0x0AB2, "_scriptnoteworthycheck" },
    { 0x0AB3, "_set_node_relative_anim_actor" },
    { 0x0AB4, "_setactionslot" },
    { 0x0AB5, "_setdof_internal" },
    { 0x0AB6, "_setdomencountericoninfo" },
    { 0x0AB7, "_setdomflagiconinfo" },
    { 0x0AB8, "_setdomquesticoninfo" },
    { 0x0AB9, "_setextraperks" },
    { 0x0ABA, "_setgoalpos" },
    { 0x0ABB, "_setperk" },
    { 0x0ABC, "_setperkinternal" },
    { 0x0ABD, "_setplayerscore" },
    { 0x0ABE, "_setsuit" },
    { 0x0ABF, "_setteamradarstrength" },
    { 0x0AC0, "_setteamscore" },
    { 0x0AC1, "_settext" },
    { 0x0AC2, "_setuppiccontrols" },
    { 0x0AC3, "_setvehgoalpos" },
    { 0x0AC4, "_setvehgoalpos_wrap" },
    { 0x0AC5, "_setvehgoalposadheretomesh" },
    { 0x0AC6, "_setvisibiilityomnvarforkillstreak" },
    { 0x0AC7, "_shellshock" },
    { 0x0AC8, "_simple_interaction_prop_clear" },
    { 0x0AC9, "_simple_interaction_prop_random_anim" },
    { 0x0ACA, "_simple_interaction_prop_start" },
    { 0x0ACB, "_snd_doppler_main" },
    { 0x0ACC, "_snd_get_velocity" },
    { 0x0ACD, "_spawner_mg42_think" },
    { 0x0ACE, "_spawnhelicopter" },
    { 0x0ACF, "_spawnpiccontrols" },
    { 0x0AD0, "_spawnpois" },
    { 0x0AD1, "_spawnsoldier" },
    { 0x0AD2, "_spawnvehicle" },
    { 0x0AD3, "_startragdoll" },
    { 0x0AD4, "_startsoldierpatrol" },
    { 0x0AD5, "_startusethink" },
    { 0x0AD6, "_stealth" },
    { 0x0AD7, "_stopshellshock" },
    { 0x0AD8, "_suicide" },
    { 0x0AD9, "_suspendvehicle" },
    { 0x0ADA, "_switchtoweapon" },
    { 0x0ADB, "_switchtoweaponimmediate" },
    { 0x0ADC, "_tag_entity" },
    { 0x0ADD, "_takeweapon" },
    { 0x0ADE, "_takeweaponsexceptlist" },
    { 0x0ADF, "_timeout" },
    { 0x0AE0, "_timeoutpiccontrols" },
    { 0x0AE1, "_togglecellphoneallows" },
    { 0x0AE2, "_toggletabletallows" },
    { 0x0AE3, "_turretoffshared" },
    { 0x0AE4, "_turretonshared" },
    { 0x0AE5, "_unlink" },
    { 0x0AE6, "_unsetextraperks" },
    { 0x0AE7, "_unsetperk" },
    { 0x0AE8, "_unsetperkinternal" },
    { 0x0AE9, "_update_emp_scramble" },
    { 0x0AEA, "_update_spawn_data_on_death" },
    { 0x0AEB, "_updatechopperseatplayerusable" },
    { 0x0AEC, "_updatechopperseatteamusable" },
    { 0x0AED, "_updateenemyusable" },
    { 0x0AEE, "_updatehackomnvars" },
    { 0x0AEF, "_updatehackprogressomnvar" },
    { 0x0AF0, "_updateiconowner" },
    { 0x0AF1, "_updatematchtimerhudinternal" },
    { 0x0AF2, "_updatereviveplayerusable" },
    { 0x0AF3, "_updatereviveteamusable" },
    { 0x0AF4, "_updateteamusable" },
    { 0x0AF5, "_updateuseobjs" },
    { 0x0AF6, "_useperkenabled" },
    { 0x0AF7, "_validateattacker" },
    { 0x0AF8, "_validateplayer" },
    { 0x0AF9, "_validateplayerfilter" },
    { 0x0AFA, "_validatevictim" },
    { 0x0AFB, "_vehicle_landvehicle" },
    { 0x0AFC, "_vehicle_paths" },
    { 0x0AFD, "_vehicle_resume_named" },
    { 0x0AFE, "_vehicle_stop_named" },
    { 0x0AFF, "_vehicle_unload" },
    { 0x0B00, "_visionsetnaked" },
    { 0x0B01, "_visionsetnakedforplayer" },
    { 0x0B02, "_visionunsetnakedforplayer" },
    { 0x0B03, "_waittill_dead_notify_done" },
    { 0x0B04, "_waittill_trigger" },
    { 0x0B05, "_waittillplayerdoneskydivingac130timeout" },
    { 0x0B06, "_waituntilinteractfinished" },
    { 0x0B07, "_wakeupvehicle" },
    { 0x0B08, "_watch_for_flight_over_origin" },
    { 0x0B09, "_watchforjuggstop" },
    { 0x0B0A, "_watchforstopambient6waves" },
    { 0x0B0B, "_watchforstopwaves" },
    { 0x0B0C, "_watchforwalkstopwaves" },
    { 0x0B0D, "_watchnavobstacle" },
    { 0x0B0E, "_watchpiccontroltimeout" },
    { 0x0B0F, "_watchpiccontroluse" },
    { 0x0B10, "_weapons" },
    { 0x0B11, "_whizbyfxent" },
    { 0x0B12, "a" },
    { 0x0B13, "a10_airstrike_fx" },
    { 0x0B14, "a10_flyby" },
    { 0x0B15, "a10_play_contrail" },
    { 0x0B16, "aa_status" },
    { 0x0B17, "aarawardcount" },
    { 0x0B18, "aarawards" },
    { 0x0B19, "aarpriority" },
    { 0x0B1A, "abh_used" },
    { 0x0B1B, "ability_invulnerable" },
    { 0x0B1C, "abort" },
    { 0x0B1D, "abort_count" },
    { 0x0B1E, "abort_wait_any_func_array" },
    { 0x0B1F, "aborted" },
    { 0x0B20, "abortextractpickup" },
    { 0x0B21, "abortlevel" },
    { 0x0B22, "abortmonitoredweaponswitch" },
    { 0x0B23, "abortreliableweaponswitch" },
    { 0x0B24, "abortshufflecleanup" },
    { 0x0B25, "above_pain_breathing_sfx_threshold" },
    { 0x0B26, "abs_int" },
    { 0x0B27, "absangleclamp180" },
    { 0x0B28, "absyawtoangles" },
    { 0x0B29, "absyawtoenemy" },
    { 0x0B2A, "absyawtoenemy2d" },
    { 0x0B2B, "absyawtoorigin" },
    { 0x0B2C, "ac130" },
    { 0x0B2D, "ac130_activate_function" },
    { 0x0B2E, "ac130_attachgunner" },
    { 0x0B2F, "ac130_cloudsfx" },
    { 0x0B30, "ac130_crash" },
    { 0x0B31, "ac130_getfiretime" },
    { 0x0B32, "ac130_gunship" },
    { 0x0B33, "ac130_leave" },
    { 0x0B34, "ac130_location" },
    { 0x0B35, "ac130_magnitude" },
    { 0x0B36, "ac130_monitormanualplayerexit" },
    { 0x0B37, "ac130_paratrooper_veh" },
    { 0x0B38, "ac130_playflares" },
    { 0x0B39, "ac130_playfocalfx" },
    { 0x0B3A, "ac130_playpilotfx" },
    { 0x0B3B, "ac130_removeplane" },
    { 0x0B3C, "ac130_returnplayer" },
    { 0x0B3D, "ac130_spawn" },
    { 0x0B3E, "ac130_speed" },
    { 0x0B3F, "ac130_startuse" },
    { 0x0B40, "ac130_track105mmmissile" },
    { 0x0B41, "ac130_updateaimingcoords" },
    { 0x0B42, "ac130_updateoverlaycoords" },
    { 0x0B43, "ac130_updateplanemodelcoords" },
    { 0x0B44, "ac130_updateplayerpositioncoords" },
    { 0x0B45, "ac130_waitforweaponreloadtime" },
    { 0x0B46, "ac130_waittilldestination" },
    { 0x0B47, "ac130_watch105mmexplosion" },
    { 0x0B48, "ac130_watchchangeweapons" },
    { 0x0B49, "ac130_watchdamage" },
    { 0x0B4A, "ac130_watchowner" },
    { 0x0B4B, "ac130_watchtimeout" },
    { 0x0B4C, "ac130_watchweaponfired" },
    { 0x0B4D, "ac130_watchweaponimpact" },
    { 0x0B4E, "ac130_weaponreload" },
    { 0x0B4F, "ac130activatefunc" },
    { 0x0B50, "ac130handlemovement" },
    { 0x0B51, "ac130height" },
    { 0x0B52, "ac130heightoffset" },
    { 0x0B53, "ac130inuse" },
    { 0x0B54, "ac130linkandspin" },
    { 0x0B55, "ac130linker" },
    { 0x0B56, "ac130player" },
    { 0x0B57, "ac130queue" },
    { 0x0B58, "ac130s" },
    { 0x0B59, "ac130setupanim" },
    { 0x0B5A, "ac130shellshock" },
    { 0x0B5B, "accel" },
    { 0x0B5C, "acceptablemeleefraction" },
    { 0x0B5D, "accessories" },
    { 0x0B5E, "accessoryattachment" },
    { 0x0B5F, "accessorydata" },
    { 0x0B60, "accessoryfullweapon" },
    { 0x0B61, "accessoryinfo" },
    { 0x0B62, "accessoryinfobyindex" },
    { 0x0B63, "accessorylogic" },
    { 0x0B64, "accessoryweaponbyindex" },
    { 0x0B65, "accolades" },
    { 0x0B66, "accumulatedtime" },
    { 0x0B67, "accuracy_shots_fired" },
    { 0x0B68, "accuracy_shots_on_target" },
    { 0x0B69, "accuracy_think" },
    { 0x0B6A, "accuracygrowthmultiplier" },
    { 0x0B6B, "accuracystationarymod" },
    { 0x0B6C, "aces" },
    { 0x0B6D, "achievement" },
    { 0x0B6E, "achievement_completed" },
    { 0x0B6F, "achievement_death_tracker" },
    { 0x0B70, "achievement_list" },
    { 0x0B71, "achievement_pistol_enemies" },
    { 0x0B72, "achievement_registration_func" },
    { 0x0B73, "achievement_watcher" },
    { 0x0B74, "acievement_monitor" },
    { 0x0B75, "acquire_alley_bodyguard" },
    { 0x0B76, "acquire_alley_fence_guy" },
    { 0x0B77, "acquire_autosave_before_cafe" },
    { 0x0B78, "acquire_birds_fly" },
    { 0x0B79, "acquire_butcher_over_fence_fallback" },
    { 0x0B7A, "acquire_catchup" },
    { 0x0B7B, "acquire_containment" },
    { 0x0B7C, "acquire_door_handler" },
    { 0x0B7D, "acquire_enemy_handler" },
    { 0x0B7E, "acquire_enforcer_handler" },
    { 0x0B7F, "acquire_init" },
    { 0x0B80, "acquire_main" },
    { 0x0B81, "acquire_player_anim" },
    { 0x0B82, "acquire_price_handler" },
    { 0x0B83, "acquire_pursuit_timer_handler" },
    { 0x0B84, "acquire_restore_user_fov" },
    { 0x0B85, "acquire_sniper_laser" },
    { 0x0B86, "acquire_start" },
    { 0x0B87, "acquire_stp_main" },
    { 0x0B88, "acquirecannontarget" },
    { 0x0B89, "acquireturrettarget" },
    { 0x0B8A, "acript_attackeraccuracy" },
    { 0x0B8B, "across_delta" },
    { 0x0B8C, "across_delta_local" },
    { 0x0B8D, "action" },
    { 0x0B8E, "action_thread" },
    { 0x0B8F, "actioncancellation" },
    { 0x0B90, "actioncount" },
    { 0x0B91, "actionendtime" },
    { 0x0B92, "actionfn" },
    { 0x0B93, "actionglobals" },
    { 0x0B94, "actionmap" },
    { 0x0B95, "actionmapfuncs" },
    { 0x0B96, "actions" },
    { 0x0B97, "actionsets" },
    { 0x0B98, "actionslotoverride" },
    { 0x0B99, "actionslotoverridecallback" },
    { 0x0B9A, "actionslotoverrideremove" },
    { 0x0B9B, "actionslotweapon" },
    { 0x0B9C, "actionstarttime" },
    { 0x0B9D, "actionstates" },
    { 0x0B9E, "activate_ac130_on_player" },
    { 0x0B9F, "activate_adrenaline" },
    { 0x0BA0, "activate_adrenaline_boost" },
    { 0x0BA1, "activate_apache_on_player" },
    { 0x0BA2, "activate_auto_revive_crate" },
    { 0x0BA3, "activate_blackbox_interaction" },
    { 0x0BA4, "activate_bomb_for_pick_up" },
    { 0x0BA5, "activate_bomb_interactions" },
    { 0x0BA6, "activate_clientside_exploder" },
    { 0x0BA7, "activate_cloak" },
    { 0x0BA8, "activate_cluster_strike" },
    { 0x0BA9, "activate_color_code_internal" },
    { 0x0BAA, "activate_color_trigger" },
    { 0x0BAB, "activate_colortrig_on_aigroup_death" },
    { 0x0BAC, "activate_colortrig_on_death" },
    { 0x0BAD, "activate_colortrig_safe" },
    { 0x0BAE, "activate_drone_mode_on_player" },
    { 0x0BAF, "activate_emp_drone" },
    { 0x0BB0, "activate_enemy_turret" },
    { 0x0BB1, "activate_enemy_turret_when_reach_it" },
    { 0x0BB2, "activate_exploder" },
    { 0x0BB3, "activate_exploders_in_volume" },
    { 0x0BB4, "activate_extraction" },
    { 0x0BB5, "activate_extraction_flare" },
    { 0x0BB6, "activate_grenade_object" },
    { 0x0BB7, "activate_group_fulton_interact" },
    { 0x0BB8, "activate_individual_exploder" },
    { 0x0BB9, "activate_individual_exploder_proc" },
    { 0x0BBA, "activate_infinite_ammo" },
    { 0x0BBB, "activate_instant_revive" },
    { 0x0BBC, "activate_interactives_in_volume" },
    { 0x0BBD, "activate_inv_cooldown" },
    { 0x0BBE, "activate_invulnerability" },
    { 0x0BBF, "activate_jugg_suit" },
    { 0x0BC0, "activate_ks_on_use" },
    { 0x0BC1, "activate_laser_on_ambush_sniper" },
    { 0x0BC2, "activate_linked_ied_spawners" },
    { 0x0BC3, "activate_mark_enemies" },
    { 0x0BC4, "activate_mh_trigger" },
    { 0x0BC5, "activate_mortar" },
    { 0x0BC6, "activate_mortar_enemy" },
    { 0x0BC7, "activate_mortar_when_reach_path_end" },
    { 0x0BC8, "activate_nerf" },
    { 0x0BC9, "activate_object" },
    { 0x0BCA, "activate_radar" },
    { 0x0BCB, "activate_radius_distance_trigger_markers" },
    { 0x0BCC, "activate_respawn_flare" },
    { 0x0BCD, "activate_right_street_trigger" },
    { 0x0BCE, "activate_rpgs_on_use" },
    { 0x0BCF, "activate_scavenger" },
    { 0x0BD0, "activate_sentry_turret" },
    { 0x0BD1, "activate_sledge_lookin_dialogue" },
    { 0x0BD2, "activate_sniper" },
    { 0x0BD3, "activate_team_armor_buff" },
    { 0x0BD4, "activate_team_auto_revive" },
    { 0x0BD5, "activate_team_stopping_power" },
    { 0x0BD6, "activate_thermite_launcher" },
    { 0x0BD7, "activate_toma_strike" },
    { 0x0BD8, "activate_trig_when_vol_clear" },
    { 0x0BD9, "activate_trigger" },
    { 0x0BDA, "activate_trigger_process" },
    { 0x0BDB, "activate_trigger_with_noteworthy" },
    { 0x0BDC, "activate_trigger_with_targetname" },
    { 0x0BDD, "activate_twister_homing" },
    { 0x0BDE, "activate_uav" },
    { 0x0BDF, "activate_vehicle_progress_marker" },
    { 0x0BE0, "activateagent" },
    { 0x0BE1, "activateaxeblood" },
    { 0x0BE2, "activatecallback" },
    { 0x0BE3, "activatecrate" },
    { 0x0BE4, "activatecratefirsttime" },
    { 0x0BE5, "activatecratephysics" },
    { 0x0BE6, "activated" },
    { 0x0BE7, "activated_color_trigger" },
    { 0x0BE8, "activated_nerfs" },
    { 0x0BE9, "activated_relics" },
    { 0x0BEA, "activateendzone" },
    { 0x0BEB, "activateimmediately" },
    { 0x0BEC, "activatejugg" },
    { 0x0BED, "activatejuggcrate" },
    { 0x0BEE, "activatelifepackboost" },
    { 0x0BEF, "activatenewjuggcrate" },
    { 0x0BF0, "activatenewjuggernaut" },
    { 0x0BF1, "activatepenalty" },
    { 0x0BF2, "activatepenaltyalt" },
    { 0x0BF3, "activatepower" },
    { 0x0BF4, "activatespawns" },
    { 0x0BF5, "activatespawnset" },
    { 0x0BF6, "activatestring" },
    { 0x0BF7, "activatesuper" },
    { 0x0BF8, "activatetime" },
    { 0x0BF9, "activatezombiestealth" },
    { 0x0BFA, "activatezone" },
    { 0x0BFB, "activation_func" },
    { 0x0BFC, "activation_radius_sq" },
    { 0x0BFD, "activationarms1" },
    { 0x0BFE, "activationarms2" },
    { 0x0BFF, "activationarms3" },
    { 0x0C00, "activationarms4" },
    { 0x0C01, "activationcalltraininteract" },
    { 0x0C02, "activationcommslaptop" },
    { 0x0C03, "activationdelay" },
    { 0x0C04, "activationdelaystarttime" },
    { 0x0C05, "activationmoraleslaptop" },
    { 0x0C06, "activationmoralessignal" },
    { 0x0C07, "activationnuke" },
    { 0x0C08, "activationstiminteract" },
    { 0x0C09, "activationtmtylinterrogate" },
    { 0x0C0A, "active_cam_id" },
    { 0x0C0B, "active_camera" },
    { 0x0C0C, "active_feed" },
    { 0x0C0D, "active_jackals" },
    { 0x0C0E, "active_level" },
    { 0x0C0F, "active_loot_spots" },
    { 0x0C10, "active_objectives_string" },
    { 0x0C11, "active_player_respawn_locs" },
    { 0x0C12, "active_scene_data" },
    { 0x0C13, "active_section" },
    { 0x0C14, "active_sense_funcs" },
    { 0x0C15, "active_spawn_module_structs" },
    { 0x0C16, "active_spawn_modules" },
    { 0x0C17, "active_spawn_volumes" },
    { 0x0C18, "active_volume_check" },
    { 0x0C19, "activeadvanceduavs" },
    { 0x0C1A, "activebreadcrumbs" },
    { 0x0C1B, "activeconfigs" },
    { 0x0C1C, "activecontextualwalltraversals" },
    { 0x0C1D, "activecount" },
    { 0x0C1E, "activecounteruavs" },
    { 0x0C1F, "activeextractions" },
    { 0x0C20, "activeextractors" },
    { 0x0C21, "activegesturenotify" },
    { 0x0C22, "activegrenadetimer" },
    { 0x0C23, "activeheadicons" },
    { 0x0C24, "activehostagecount" },
    { 0x0C25, "activehvts" },
    { 0x0C26, "activeid" },
    { 0x0C27, "activejuggcrates" },
    { 0x0C28, "activejuggernauts" },
    { 0x0C29, "activekillstreaklistcontains" },
    { 0x0C2A, "activekillstreaks" },
    { 0x0C2B, "activelocations" },
    { 0x0C2C, "activemission" },
    { 0x0C2D, "activenodes" },
    { 0x0C2E, "activeoutlines" },
    { 0x0C2F, "activeplayers" },
    { 0x0C30, "activeplayerstreak" },
    { 0x0C31, "activequarrydefense" },
    { 0x0C32, "activequests" },
    { 0x0C33, "activescreeneffectoverlays" },
    { 0x0C34, "activescriptfactors" },
    { 0x0C35, "activesentientcount" },
    { 0x0C36, "activesentients" },
    { 0x0C37, "activespawncontext" },
    { 0x0C38, "activespawnlogic" },
    { 0x0C39, "activespawnsets" },
    { 0x0C3A, "activesupertrophies" },
    { 0x0C3B, "activetablets" },
    { 0x0C3C, "activetargetmarkergroups" },
    { 0x0C3D, "activetimeseconds" },
    { 0x0C3E, "activetvs" },
    { 0x0C3F, "activeuavs" },
    { 0x0C40, "activevehicles" },
    { 0x0C41, "activevisionsetlist" },
    { 0x0C42, "activewpfires" },
    { 0x0C43, "activewpflares" },
    { 0x0C44, "activewpinnerzones" },
    { 0x0C45, "activewpzones" },
    { 0x0C46, "activezone" },
    { 0x0C47, "actor" },
    { 0x0C48, "actor_animloop" },
    { 0x0C49, "actor_die_when_shot" },
    { 0x0C4A, "actor_interactive_think" },
    { 0x0C4B, "actor_is3d" },
    { 0x0C4C, "actor_isspace" },
    { 0x0C4D, "actor_normal_think" },
    { 0x0C4E, "actor1" },
    { 0x0C4F, "actor2" },
    { 0x0C50, "actorloop" },
    { 0x0C51, "actorloopthink" },
    { 0x0C52, "actorplayer" },
    { 0x0C53, "actors" },
    { 0x0C54, "actorthink" },
    { 0x0C55, "actorthinkanim" },
    { 0x0C56, "actorthinkpath" },
    { 0x0C57, "actualhealth" },
    { 0x0C58, "adaptive" },
    { 0x0C59, "adaptive_density" },
    { 0x0C5A, "adaptive_expected_players_max" },
    { 0x0C5B, "add" },
    { 0x0C5C, "add_abort" },
    { 0x0C5D, "add_active_sense_function" },
    { 0x0C5E, "add_actor_to_manager" },
    { 0x0C5F, "add_actor_tointeractionmanager" },
    { 0x0C60, "add_additional_parts" },
    { 0x0C61, "add_additional_parts_func" },
    { 0x0C62, "add_agents_to_game" },
    { 0x0C63, "add_ai_air_infil" },
    { 0x0C64, "add_ai_ground_infil" },
    { 0x0C65, "add_ai_to_marked_critical_enemy_ai_list" },
    { 0x0C66, "add_ai_to_marked_enemy_ai_list" },
    { 0x0C67, "add_aitype_spawner_override" },
    { 0x0C68, "add_ammo_if_needed" },
    { 0x0C69, "add_and_select_entity" },
    { 0x0C6A, "add_and_watch_group" },
    { 0x0C6B, "add_animation" },
    { 0x0C6C, "add_animents" },
    { 0x0C6D, "add_animsound" },
    { 0x0C6E, "add_announce_debounce" },
    { 0x0C6F, "add_attachment_to_weapon" },
    { 0x0C70, "add_bcs_location_mapping" },
    { 0x0C71, "add_beacon_effect" },
    { 0x0C72, "add_button" },
    { 0x0C73, "add_call" },
    { 0x0C74, "add_cleanup_ent" },
    { 0x0C75, "add_clip" },
    { 0x0C76, "add_command_to_action_tracker" },
    { 0x0C77, "add_condition" },
    { 0x0C78, "add_context_sensitive_dialog" },
    { 0x0C79, "add_context_sensitive_timeout" },
    { 0x0C7A, "add_contextualwalltraversal_array" },
    { 0x0C7B, "add_convoy_to_level" },
    { 0x0C7C, "add_cortex_charge_func" },
    { 0x0C7D, "add_cover_node" },
    { 0x0C7E, "add_crafted_item_to_dpad" },
    { 0x0C7F, "add_damage_function" },
    { 0x0C80, "add_debugdvar_func" },
    { 0x0C81, "add_demo_button_combo" },
    { 0x0C82, "add_destructible" },
    { 0x0C83, "add_destructible_array" },
    { 0x0C84, "add_dialogue_line" },
    { 0x0C85, "add_dialogue_line_alex" },
    { 0x0C86, "add_dialogue_line_aq" },
    { 0x0C87, "add_dialogue_line_aq_soldier" },
    { 0x0C88, "add_dialogue_line_butcher" },
    { 0x0C89, "add_dialogue_line_butcher_son" },
    { 0x0C8A, "add_dialogue_line_butcher_wife" },
    { 0x0C8B, "add_dialogue_line_civ_ambusher" },
    { 0x0C8C, "add_dialogue_line_civilian" },
    { 0x0C8D, "add_dialogue_line_convoy_apc" },
    { 0x0C8E, "add_dialogue_line_griggs" },
    { 0x0C8F, "add_dialogue_line_heli_pilot" },
    { 0x0C90, "add_dialogue_line_hms" },
    { 0x0C91, "add_dialogue_line_kyle" },
    { 0x0C92, "add_dialogue_line_marine" },
    { 0x0C93, "add_dialogue_line_nikolai" },
    { 0x0C94, "add_dialogue_line_police" },
    { 0x0C95, "add_dialogue_line_price" },
    { 0x0C96, "add_dialogue_line_radio" },
    { 0x0C97, "add_dialogue_line_wolf" },
    { 0x0C98, "add_dialogue_line_yegor" },
    { 0x0C99, "add_door_speed_modifiers" },
    { 0x0C9A, "add_dynamicladder" },
    { 0x0C9B, "add_dynolight" },
    { 0x0C9C, "add_earthquake" },
    { 0x0C9D, "add_emp_ent" },
    { 0x0C9E, "add_encounter_start_condition" },
    { 0x0C9F, "add_encounter_start_function" },
    { 0x0CA0, "add_endon" },
    { 0x0CA1, "add_exploder" },
    { 0x0CA2, "add_extra_autosave_check" },
    { 0x0CA3, "add_extrahuds" },
    { 0x0CA4, "add_fake_silencer_to_new_weapons" },
    { 0x0CA5, "add_frame_event" },
    { 0x0CA6, "add_func" },
    { 0x0CA7, "add_fx" },
    { 0x0CA8, "add_global_spawn_function" },
    { 0x0CA9, "add_grenadier_anchor" },
    { 0x0CAA, "add_gunner_turret" },
    { 0x0CAB, "add_hint_string" },
    { 0x0CAC, "add_humanoid_agent" },
    { 0x0CAD, "add_init_script" },
    { 0x0CAE, "add_interaction_structs_to_interaction_arrays" },
    { 0x0CAF, "add_item_to_outline_watcher" },
    { 0x0CB0, "add_item_to_priority_queue" },
    { 0x0CB1, "add_item_to_priority_queue_internal" },
    { 0x0CB2, "add_kb_button" },
    { 0x0CB3, "add_key" },
    { 0x0CB4, "add_launcher_xmags" },
    { 0x0CB5, "add_linkedents" },
    { 0x0CB6, "add_location_start_condition" },
    { 0x0CB7, "add_marine_to_color_array" },
    { 0x0CB8, "add_menu" },
    { 0x0CB9, "add_menu_child" },
    { 0x0CBA, "add_menuent" },
    { 0x0CBB, "add_menuoptions" },
    { 0x0CBC, "add_missing_nodes" },
    { 0x0CBD, "add_name" },
    { 0x0CBE, "add_name_from_table" },
    { 0x0CBF, "add_names" },
    { 0x0CC0, "add_no_game_starts" },
    { 0x0CC1, "add_node_to_global_arrays" },
    { 0x0CC2, "add_noself_call" },
    { 0x0CC3, "add_notetrack_and_get_index" },
    { 0x0CC4, "add_notetrack_array" },
    { 0x0CC5, "add_objective" },
    { 0x0CC6, "add_option_to_selected_entities" },
    { 0x0CC7, "add_path_node" },
    { 0x0CC8, "add_pathpoints" },
    { 0x0CC9, "add_player_to_threatbias_group" },
    { 0x0CCA, "add_pushent" },
    { 0x0CCB, "add_random_killspawner_to_spawngroup" },
    { 0x0CCC, "add_reactive_fx" },
    { 0x0CCD, "add_reverb" },
    { 0x0CCE, "add_rider_to_decho_dirty" },
    { 0x0CCF, "add_rider_to_decho_rebel" },
    { 0x0CD0, "add_say_on_closest_ally_to_chatter" },
    { 0x0CD1, "add_scripted_movement_arrivefuncs" },
    { 0x0CD2, "add_selectable" },
    { 0x0CD3, "add_skill_point_to_skill" },
    { 0x0CD4, "add_smartobject_point" },
    { 0x0CD5, "add_smartobject_type" },
    { 0x0CD6, "add_space_to_string" },
    { 0x0CD7, "add_spammodel" },
    { 0x0CD8, "add_spawn_function" },
    { 0x0CD9, "add_spawn_scoring_poi" },
    { 0x0CDA, "add_spawn_skit" },
    { 0x0CDB, "add_spawner_to_color_spawner_array" },
    { 0x0CDC, "add_spawners_to_passive_wave_spawning" },
    { 0x0CDD, "add_start" },
    { 0x0CDE, "add_start_assert" },
    { 0x0CDF, "add_start_construct" },
    { 0x0CE0, "add_state" },
    { 0x0CE1, "add_state_ent" },
    { 0x0CE2, "add_targetname_kvps" },
    { 0x0CE3, "add_to_ambient_sound_queue" },
    { 0x0CE4, "add_to_ambush_vehicle_array" },
    { 0x0CE5, "add_to_ambush_vehicles_ahead_player_vehicle_array" },
    { 0x0CE6, "add_to_ambush_vehicles_behind_player_vehicle_array" },
    { 0x0CE7, "add_to_animsound" },
    { 0x0CE8, "add_to_blocker_vehicles_array" },
    { 0x0CE9, "add_to_bot_damage_targets" },
    { 0x0CEA, "add_to_bot_use_targets" },
    { 0x0CEB, "add_to_characters_array" },
    { 0x0CEC, "add_to_chatter" },
    { 0x0CED, "add_to_convoy_structs" },
    { 0x0CEE, "add_to_cruise_missile_list" },
    { 0x0CEF, "add_to_current_interaction_list" },
    { 0x0CF0, "add_to_current_interaction_list_for_player" },
    { 0x0CF1, "add_to_dialogue" },
    { 0x0CF2, "add_to_dialogue_generic" },
    { 0x0CF3, "add_to_friendly_convoy_list" },
    { 0x0CF4, "add_to_grenade_cache" },
    { 0x0CF5, "add_to_hack_attackers_list" },
    { 0x0CF6, "add_to_hvt_bodyguard_vehicles_array" },
    { 0x0CF7, "add_to_identified_ieds_list" },
    { 0x0CF8, "add_to_interrupt_vo" },
    { 0x0CF9, "add_to_kick_queue" },
    { 0x0CFA, "add_to_kill_off_list" },
    { 0x0CFB, "add_to_lightbar_stack" },
    { 0x0CFC, "add_to_list_of_current_chain_idx" },
    { 0x0CFD, "add_to_module_vehicles_list" },
    { 0x0CFE, "add_to_nag_vo" },
    { 0x0CFF, "add_to_notify_queue" },
    { 0x0D00, "add_to_player_dialogue" },
    { 0x0D01, "add_to_player_revive_icon_list" },
    { 0x0D02, "add_to_players_as_passenger_list" },
    { 0x0D03, "add_to_players_being_revived" },
    { 0x0D04, "add_to_players_cannot_see_vehicle_icon_list" },
    { 0x0D05, "add_to_queue_at_priority" },
    { 0x0D06, "add_to_radio" },
    { 0x0D07, "add_to_revive_icon_ent_icon_list" },
    { 0x0D08, "add_to_revive_icon_entity_list" },
    { 0x0D09, "add_to_spawner_flags" },
    { 0x0D0A, "add_to_spawngroup" },
    { 0x0D0B, "add_to_special_lockon_target_list" },
    { 0x0D0C, "add_to_unidentified_ieds_list" },
    { 0x0D0D, "add_to_vehicle_queue" },
    { 0x0D0E, "add_to_vehicle_repair_interaction_list" },
    { 0x0D0F, "add_to_vehicle_travel_array" },
    { 0x0D10, "add_to_vo_queue" },
    { 0x0D11, "add_to_vo_system" },
    { 0x0D12, "add_to_vo_system_internal" },
    { 0x0D13, "add_to_weapon_array" },
    { 0x0D14, "add_to_weapons_status" },
    { 0x0D15, "add_tokens_to_trigger_flags" },
    { 0x0D16, "add_traversalassist" },
    { 0x0D17, "add_traversalassist_array" },
    { 0x0D18, "add_trigger_func_thread" },
    { 0x0D19, "add_trigger_function" },
    { 0x0D1A, "add_turret" },
    { 0x0D1B, "add_universal_button" },
    { 0x0D1C, "add_veh_anim" },
    { 0x0D1D, "add_visionset_to_stack" },
    { 0x0D1E, "add_vo_line" },
    { 0x0D1F, "add_vo_line_linked" },
    { 0x0D20, "add_vo_line_scaled" },
    { 0x0D21, "add_vo_notify" },
    { 0x0D22, "add_vo_rule" },
    { 0x0D23, "add_vo_rules_all" },
    { 0x0D24, "add_vo_rules_any" },
    { 0x0D25, "add_vo_wait" },
    { 0x0D26, "add_volume_to_global_arrays" },
    { 0x0D27, "add_volumes_to_array" },
    { 0x0D28, "add_wait" },
    { 0x0D29, "add_wait_asserter" },
    { 0x0D2A, "add_weak_spot_on_hvt_vehicle" },
    { 0x0D2B, "add_weapon" },
    { 0x0D2C, "add_welding_alias" },
    { 0x0D2D, "add_wheel_tag" },
    { 0x0D2E, "add_z" },
    { 0x0D2F, "addaction" },
    { 0x0D30, "addactioncovermealiasex" },
    { 0x0D31, "addactivecounteruav" },
    { 0x0D32, "addactiveuav" },
    { 0x0D33, "addaieventlistener_func" },
    { 0x0D34, "addairexplosion" },
    { 0x0D35, "addallowedthreatcallout" },
    { 0x0D36, "addanimation" },
    { 0x0D37, "addarmcratedata" },
    { 0x0D38, "addattachmenttoweapon" },
    { 0x0D39, "addattacker" },
    { 0x0D3A, "addattackerkillstreak" },
    { 0x0D3B, "addawardtoaarlist" },
    { 0x0D3C, "addbots" },
    { 0x0D3D, "addboxtolevelarray" },
    { 0x0D3E, "addboxtoownerarray" },
    { 0x0D3F, "addcalloutresponseevent" },
    { 0x0D40, "addcheckfirealias" },
    { 0x0D41, "addchild" },
    { 0x0D42, "addclassstructtocache" },
    { 0x0D43, "addconcatdirectionalias" },
    { 0x0D44, "addconcattargetalias" },
    { 0x0D45, "addcustombc" },
    { 0x0D46, "addcustombcstealthalias" },
    { 0x0D47, "adddamagemodifier" },
    { 0x0D48, "adddamagetaken" },
    { 0x0D49, "adddeathicon" },
    { 0x0D4A, "adddynamicspawnarea" },
    { 0x0D4B, "added_lines" },
    { 0x0D4C, "addedtowave" },
    { 0x0D4D, "addenemydeathicon" },
    { 0x0D4E, "addentrytodevgui" },
    { 0x0D4F, "addentrytodevgui_internal" },
    { 0x0D50, "addeventplaybcs" },
    { 0x0D51, "addexecutioncharge" },
    { 0x0D52, "addfunc" },
    { 0x0D53, "addglobalrankxpmultiplier" },
    { 0x0D54, "addglobalspawnarea" },
    { 0x0D55, "addglobalweaponrankxpmultiplier" },
    { 0x0D56, "addgrenadethrowanimoffset" },
    { 0x0D57, "addheadicon" },
    { 0x0D58, "addhealthback" },
    { 0x0D59, "addheavyarmor" },
    { 0x0D5A, "addhelidroppingcratetolist" },
    { 0x0D5B, "addhostileburstalias" },
    { 0x0D5C, "addhudincoming_attacker" },
    { 0x0D5D, "addhvtheadicons" },
    { 0x0D5E, "addincominghelperdrone" },
    { 0x0D5F, "addincominghelperdroneifpossible" },
    { 0x0D60, "addinformalias" },
    { 0x0D61, "addinformevent" },
    { 0x0D62, "addinformreloadingaliasex" },
    { 0x0D63, "addinitexploders" },
    { 0x0D64, "addinitialattachmentsprimary" },
    { 0x0D65, "addinitialattachmentssecondary" },
    { 0x0D66, "addinstancetodomflag" },
    { 0x0D67, "additional_corpse" },
    { 0x0D68, "additional_false_positive_dots_needed" },
    { 0x0D69, "additional_laststand_weapon_exclusion" },
    { 0x0D6A, "additional_tactical_logic_func" },
    { 0x0D6B, "additionalassets" },
    { 0x0D6C, "additionalents" },
    { 0x0D6D, "additionalsighttraceentities" },
    { 0x0D6E, "additive_anim" },
    { 0x0D6F, "additive_branch" },
    { 0x0D70, "additive_pain" },
    { 0x0D71, "additivedamagemodifierignorefuncs" },
    { 0x0D72, "additivedamagemodifiers" },
    { 0x0D73, "addkillcharge" },
    { 0x0D74, "addkillstreakcharge" },
    { 0x0D75, "addkillstreakcratedata" },
    { 0x0D76, "addkillstreakstoqueue" },
    { 0x0D77, "addlevel" },
    { 0x0D78, "addlevelstoexperience" },
    { 0x0D79, "addloadingplayer" },
    { 0x0D7A, "addloadingplayerdisconnectwatch" },
    { 0x0D7B, "addlocationresponsealias" },
    { 0x0D7C, "addlockedon" },
    { 0x0D7D, "addloopinganimation" },
    { 0x0D7E, "addlowermessage" },
    { 0x0D7F, "addmarkpoints" },
    { 0x0D80, "addmodeltoplayer" },
    { 0x0D81, "addmovecombataliasex" },
    { 0x0D82, "addmovenoncombataliasex" },
    { 0x0D83, "addnamealias" },
    { 0x0D84, "addnamealiasex" },
    { 0x0D85, "addnotetrack_animsound" },
    { 0x0D86, "addnotetrack_attach" },
    { 0x0D87, "addnotetrack_attach_gun" },
    { 0x0D88, "addnotetrack_customfunction" },
    { 0x0D89, "addnotetrack_detach" },
    { 0x0D8A, "addnotetrack_detach_gun" },
    { 0x0D8B, "addnotetrack_dialogue" },
    { 0x0D8C, "addnotetrack_flag" },
    { 0x0D8D, "addnotetrack_flag_clear" },
    { 0x0D8E, "addnotetrack_mayhemend" },
    { 0x0D8F, "addnotetrack_mayhemstart" },
    { 0x0D90, "addnotetrack_notify" },
    { 0x0D91, "addnotetrack_playerdialogue" },
    { 0x0D92, "addnotetrack_playersound" },
    { 0x0D93, "addnotetrack_sound" },
    { 0x0D94, "addnotetrack_startfxontag" },
    { 0x0D95, "addnotetrack_stopfxontag" },
    { 0x0D96, "addnotetrack_swapparttoefx" },
    { 0x0D97, "addnotetrack_tracepartforefx" },
    { 0x0D98, "addnukecharge" },
    { 0x0D99, "addobjectivescorecharge" },
    { 0x0D9A, "addofficertosquad" },
    { 0x0D9B, "addonstart_animsound" },
    { 0x0D9C, "addoption" },
    { 0x0D9D, "addorderalias" },
    { 0x0D9E, "addorderevent" },
    { 0x0D9F, "addoutlineoccluder" },
    { 0x0DA0, "addoverheadicon" },
    { 0x0DA1, "addoverridearchetypepriority" },
    { 0x0DA2, "addplantingcharge" },
    { 0x0DA3, "addplayernamealias" },
    { 0x0DA4, "addplayertolevelarrays" },
    { 0x0DA5, "addplayertosquad" },
    { 0x0DA6, "addplayertoteam" },
    { 0x0DA7, "addpossiblethreatcallout" },
    { 0x0DA8, "addprereq" },
    { 0x0DA9, "addprintlinetext" },
    { 0x0DAA, "addquestinstance" },
    { 0x0DAB, "addrankalias" },
    { 0x0DAC, "addrankxpmultiplier" },
    { 0x0DAD, "addreactionalias" },
    { 0x0DAE, "addreactionevent" },
    { 0x0DAF, "addrecentattacker" },
    { 0x0DB0, "addrecentdamage" },
    { 0x0DB1, "addrespawntoken" },
    { 0x0DB2, "addresponsealias" },
    { 0x0DB3, "addresponseevent" },
    { 0x0DB4, "addresponseevent_internal" },
    { 0x0DB5, "addscavengercliptoweapon" },
    { 0x0DB6, "addselected" },
    { 0x0DB7, "addsmartobjectanim" },
    { 0x0DB8, "addsmartobjectanim_internal" },
    { 0x0DB9, "addsmartobjectarrivalanims" },
    { 0x0DBA, "addsmartobjectdeathanim" },
    { 0x0DBB, "addsmartobjectexitanims" },
    { 0x0DBC, "addsmartobjectintroanim" },
    { 0x0DBD, "addsmartobjectoutroanim" },
    { 0x0DBE, "addsmartobjectpainanim" },
    { 0x0DBF, "addsmartobjectreactanim" },
    { 0x0DC0, "addspawnareaonspawn" },
    { 0x0DC1, "addspawnareatoconfig" },
    { 0x0DC2, "addspawndangerzone" },
    { 0x0DC3, "addspawnpoints" },
    { 0x0DC4, "addspawnviewer" },
    { 0x0DC5, "addspeaker" },
    { 0x0DC6, "addstackcount" },
    { 0x0DC7, "addstartspawnpoints" },
    { 0x0DC8, "addstealthalias" },
    { 0x0DC9, "addstealthevent" },
    { 0x0DCA, "addsurvivorattachmentsprimary" },
    { 0x0DCB, "addsurvivorattachmentssecondary" },
    { 0x0DCC, "addtakingfirealias" },
    { 0x0DCD, "addtarget" },
    { 0x0DCE, "addtargetmarkergroup" },
    { 0x0DCF, "addtauntalias" },
    { 0x0DD0, "addteamrankxpmultiplier" },
    { 0x0DD1, "addtestclients" },
    { 0x0DD2, "addthinker" },
    { 0x0DD3, "addthreatalias" },
    { 0x0DD4, "addthreatcalloutalias" },
    { 0x0DD5, "addthreatcalloutecho" },
    { 0x0DD6, "addthreatcalloutlandmarkalias" },
    { 0x0DD7, "addthreatcalloutlocationalias" },
    { 0x0DD8, "addthreatcalloutqa_nextline" },
    { 0x0DD9, "addthreatcalloutresponsealias" },
    { 0x0DDA, "addthreatdistancealias" },
    { 0x0DDB, "addthreatelevationalias" },
    { 0x0DDC, "addthreatevent" },
    { 0x0DDD, "addthreatexposedalias" },
    { 0x0DDE, "addthreatobviousalias" },
    { 0x0DDF, "addtime" },
    { 0x0DE0, "addtoactivekillstreaklist" },
    { 0x0DE1, "addtoairstrikelist" },
    { 0x0DE2, "addtoalivecount" },
    { 0x0DE3, "addtoassaultdronelist" },
    { 0x0DE4, "addtocarrylist" },
    { 0x0DE5, "addtocharactersarray" },
    { 0x0DE6, "addtogamemodestat" },
    { 0x0DE7, "addtogroup" },
    { 0x0DE8, "addtohelilist" },
    { 0x0DE9, "addtointensitybuffer" },
    { 0x0DEA, "addtointeractionslistbynoteworthy" },
    { 0x0DEB, "addtolists" },
    { 0x0DEC, "addtolittlebirdlist" },
    { 0x0DED, "addtolivescount" },
    { 0x0DEE, "addtomatchstat" },
    { 0x0DEF, "addtoparticipantsarray" },
    { 0x0DF0, "addtopatrolexclusion" },
    { 0x0DF1, "addtopersonalinteractionlist" },
    { 0x0DF2, "addtopkillstreakcharge" },
    { 0x0DF3, "addtoplayerkillstreaklist" },
    { 0x0DF4, "addtoplayerstat" },
    { 0x0DF5, "addtoplayerstat_internal" },
    { 0x0DF6, "addtoplayerstatbuffered" },
    { 0x0DF7, "addtopod" },
    { 0x0DF8, "addtoprojectilelist" },
    { 0x0DF9, "addtoremotekillstreaklist" },
    { 0x0DFA, "addtosquad" },
    { 0x0DFB, "addtostatgroup" },
    { 0x0DFC, "addtostructarray" },
    { 0x0DFD, "addtosupportdronelist" },
    { 0x0DFE, "addtosystem" },
    { 0x0DFF, "addtotacopsmap" },
    { 0x0E00, "addtoteam" },
    { 0x0E01, "addtoteamcount" },
    { 0x0E02, "addtoteamlives" },
    { 0x0E03, "addtotraplist" },
    { 0x0E04, "addtoturretlist" },
    { 0x0E05, "addtouavlist" },
    { 0x0E06, "addtougvlist" },
    { 0x0E07, "addtowavespawner" },
    { 0x0E08, "addtriggerdeathicon" },
    { 0x0E09, "addttlosoverride" },
    { 0x0E0A, "addturret" },
    { 0x0E0B, "adduavmodel" },
    { 0x0E0C, "addvaluetocardmeter" },
    { 0x0E0D, "addvehiclealias" },
    { 0x0E0E, "addvehicleevent" },
    { 0x0E0F, "addwatchchargewin" },
    { 0x0E10, "addwatchchargewintop3" },
    { 0x0E11, "addweaponrankxpmultiplier" },
    { 0x0E12, "adjacent_volumes" },
    { 0x0E13, "adjust_ai_pistol_accuracy" },
    { 0x0E14, "adjust_allowed_civilian_deaths" },
    { 0x0E15, "adjust_angles_to_player" },
    { 0x0E16, "adjust_clip_ammo_from_stock" },
    { 0x0E17, "adjust_cursor_hint_side" },
    { 0x0E18, "adjust_damage_to_vehicle" },
    { 0x0E19, "adjust_entcounthud_pos" },
    { 0x0E1A, "adjust_entity_count_hud_color" },
    { 0x0E1B, "adjust_for_stance" },
    { 0x0E1C, "adjust_move_speed_while_crouched" },
    { 0x0E1D, "adjust_move_speed_while_sliding" },
    { 0x0E1E, "adjust_reaper_camera_zoom_level" },
    { 0x0E1F, "adjust_target_circle_fov_and_radius" },
    { 0x0E20, "adjust_vector_field" },
    { 0x0E21, "adjust_vehicle_speed_on_center_dist" },
    { 0x0E22, "adjust_vehicle_speed_on_player_dist" },
    { 0x0E23, "adjustbulletstokill" },
    { 0x0E24, "adjustedstarttime" },
    { 0x0E25, "adjustmodelvis" },
    { 0x0E26, "adjustmovespeed" },
    { 0x0E27, "adjustposforvisibility" },
    { 0x0E28, "adjustroundendtimer" },
    { 0x0E29, "adr_boost" },
    { 0x0E2A, "adrenaline_crate_init" },
    { 0x0E2B, "adrenaline_missionondeaththink" },
    { 0x0E2C, "adrenaline_missiononuse" },
    { 0x0E2D, "adrenaline_removeondamage" },
    { 0x0E2E, "adrenaline_removeongameend" },
    { 0x0E2F, "adrenaline_removeonplayernotifies" },
    { 0x0E30, "adrenaline_shot" },
    { 0x0E31, "adrenalinebox_canusedeployable" },
    { 0x0E32, "adrenalinebox_onusedeployable" },
    { 0x0E33, "adrenalinepoweractive" },
    { 0x0E34, "adsbreathhold" },
    { 0x0E35, "adsfire" },
    { 0x0E36, "adshint" },
    { 0x0E37, "adsraisedelaytimer" },
    { 0x0E38, "adstime" },
    { 0x0E39, "adsviewbobhack" },
    { 0x0E3A, "adult_fail_watcher" },
    { 0x0E3B, "advance_animatedfarahenemydeathanimationlogic" },
    { 0x0E3C, "advance_down_the_bridge" },
    { 0x0E3D, "advance_down_the_bridge_via_struct" },
    { 0x0E3E, "advance_down_the_bridge_via_volume" },
    { 0x0E3F, "advance_enemiesconversationlogic" },
    { 0x0E40, "advance_enemyshootalertalllogic" },
    { 0x0E41, "advance_farahenemybreakoutlogic" },
    { 0x0E42, "advance_getenemies" },
    { 0x0E43, "advance_main" },
    { 0x0E44, "advance_regardless_of_numbers" },
    { 0x0E45, "advance_scenefarahenemydamagelogic" },
    { 0x0E46, "advance_scenefarahenemyreactlogic" },
    { 0x0E47, "advance_scenefarahscaleanimratehack" },
    { 0x0E48, "advance_scenefarahtakedownfinishlogic" },
    { 0x0E49, "advance_scenefarahtakedownlogic" },
    { 0x0E4A, "advance_scenelogic" },
    { 0x0E4B, "advance_sceneplayerenemyreactdamagelogic" },
    { 0x0E4C, "advance_sceneplayerenemyreactlogic" },
    { 0x0E4D, "advance_spawnfarahenemy" },
    { 0x0E4E, "advance_spawnplayerenemies" },
    { 0x0E4F, "advance_start" },
    { 0x0E50, "advance_tank_bullet_pings" },
    { 0x0E51, "advance_through_struct_path" },
    { 0x0E52, "advance_watchallenemydeathslogic" },
    { 0x0E53, "advance_watchenemydeathslogic" },
    { 0x0E54, "advancebombcase" },
    { 0x0E55, "advanced_supply_drop_marker_used" },
    { 0x0E56, "advanceduavrig" },
    { 0x0E57, "advancetoenemygroup" },
    { 0x0E58, "advancetoenemygroupmax" },
    { 0x0E59, "advancetoenemyinterval" },
    { 0x0E5A, "advradarviewtime" },
    { 0x0E5B, "aerial_danger_exists_for" },
    { 0x0E5C, "aerial_vehicle_allowed" },
    { 0x0E5D, "affectedbylockon" },
    { 0x0E5E, "aftermath_ambience" },
    { 0x0E5F, "agent_anims" },
    { 0x0E60, "agent_available_to_spawn_time" },
    { 0x0E61, "agent_damage_finished" },
    { 0x0E62, "agent_definition" },
    { 0x0E63, "agent_exit_heli" },
    { 0x0E64, "agent_funcs" },
    { 0x0E65, "agent_gameparticipant" },
    { 0x0E66, "agent_go_to_pos" },
    { 0x0E67, "agent_handledamagefeedback" },
    { 0x0E68, "agent_height" },
    { 0x0E69, "agent_init" },
    { 0x0E6A, "agent_init_anims" },
    { 0x0E6B, "agent_killed_queue" },
    { 0x0E6C, "agent_monitor_death" },
    { 0x0E6D, "agent_move_and_take_cover" },
    { 0x0E6E, "agent_onuse" },
    { 0x0E6F, "agent_player_air_think" },
    { 0x0E70, "agent_player_bhd_think" },
    { 0x0E71, "agent_player_blitz_think" },
    { 0x0E72, "agent_player_conf_think" },
    { 0x0E73, "agent_player_dom_think" },
    { 0x0E74, "agent_player_mugger_think" },
    { 0x0E75, "agent_player_sam_think" },
    { 0x0E76, "agent_player_sd_think" },
    { 0x0E77, "agent_player_wmd_think" },
    { 0x0E78, "agent_put_on_heli" },
    { 0x0E79, "agent_radius" },
    { 0x0E7A, "agent_recycle_interval" },
    { 0x0E7B, "agent_spawnai" },
    { 0x0E7C, "agent_squadmember_air_think" },
    { 0x0E7D, "agent_squadmember_bhd_think" },
    { 0x0E7E, "agent_squadmember_blitz_think" },
    { 0x0E7F, "agent_squadmember_conf_think" },
    { 0x0E80, "agent_squadmember_dom_think" },
    { 0x0E81, "agent_squadmember_mugger_think" },
    { 0x0E82, "agent_squadmember_sam_think" },
    { 0x0E83, "agent_squadmember_wmd_think" },
    { 0x0E84, "agent_teamparticipant" },
    { 0x0E85, "agent_type" },
    { 0x0E86, "agent_use_door_spawner" },
    { 0x0E87, "agentarray" },
    { 0x0E88, "agentcantbeignored" },
    { 0x0E89, "agentdamagefeedback" },
    { 0x0E8A, "agentfunc" },
    { 0x0E8B, "agentisfnfimmune" },
    { 0x0E8C, "agentisinstakillimmune" },
    { 0x0E8D, "agentisspecialzombie" },
    { 0x0E8E, "agentmodeltable" },
    { 0x0E8F, "agentmodeltabledata" },
    { 0x0E90, "agents" },
    { 0x0E91, "agentskilled" },
    { 0x0E92, "agentteamarray" },
    { 0x0E93, "agentvalidateattacker" },
    { 0x0E94, "aggregateweaponkills" },
    { 0x0E95, "aggressive" },
    { 0x0E96, "aggressiveblindfire" },
    { 0x0E97, "aggressivelowcover_dist" },
    { 0x0E98, "aggressivelowcovermode" },
    { 0x0E99, "ahdmode" },
    { 0x0E9A, "ahead_of_player" },
    { 0x0E9B, "ahmadzai_wh02_model" },
    { 0x0E9C, "ai" },
    { 0x0E9D, "ai_3d_sighting_model" },
    { 0x0E9E, "ai_ac130_firedata" },
    { 0x0E9F, "ai_after_animation" },
    { 0x0EA0, "ai_anim" },
    { 0x0EA1, "ai_anim_first_frame" },
    { 0x0EA2, "ai_anim_start" },
    { 0x0EA3, "ai_attachhat" },
    { 0x0EA4, "ai_attachhead" },
    { 0x0EA5, "ai_burn_death_scream" },
    { 0x0EA6, "ai_can_lookat" },
    { 0x0EA7, "ai_cancel_gesture" },
    { 0x0EA8, "ai_cellphone_cleanup" },
    { 0x0EA9, "ai_classname_in_level" },
    { 0x0EAA, "ai_cleanup_watcher" },
    { 0x0EAB, "ai_clear_all_navigation" },
    { 0x0EAC, "ai_counter" },
    { 0x0EAD, "ai_create_weapon_stow" },
    { 0x0EAE, "ai_custom_gesture" },
    { 0x0EAF, "ai_damage_think" },
    { 0x0EB0, "ai_death_func" },
    { 0x0EB1, "ai_deathflag" },
    { 0x0EB2, "ai_delete_when_out_of_sight" },
    { 0x0EB3, "ai_detachall" },
    { 0x0EB4, "ai_detachhat" },
    { 0x0EB5, "ai_dieondamageduringanimation" },
    { 0x0EB6, "ai_dieondamageduringanimationnotifylogic" },
    { 0x0EB7, "ai_display_dmg" },
    { 0x0EB8, "ai_dogfightbarklogic" },
    { 0x0EB9, "ai_dogforcebark" },
    { 0x0EBA, "ai_dogforcegrowl" },
    { 0x0EBB, "ai_dont_glow_in_thermal" },
    { 0x0EBC, "ai_door_anim" },
    { 0x0EBD, "ai_door_spawn_anims" },
    { 0x0EBE, "ai_drop_func" },
    { 0x0EBF, "ai_drop_info" },
    { 0x0EC0, "ai_endguardlogic" },
    { 0x0EC1, "ai_endguardproximitylogic" },
    { 0x0EC2, "ai_endpathlogic" },
    { 0x0EC3, "ai_enter_laststand" },
    { 0x0EC4, "ai_enter_vehicle" },
    { 0x0EC5, "ai_extendedtacgraph" },
    { 0x0EC6, "ai_finish_gesture" },
    { 0x0EC7, "ai_fire_suppression_logic" },
    { 0x0EC8, "ai_fire_suppression_postspawn" },
    { 0x0EC9, "ai_follow_player_ai_color_manager" },
    { 0x0ECA, "ai_frontline_behavior" },
    { 0x0ECB, "ai_frontline_initial_behavior" },
    { 0x0ECC, "ai_gas_mask" },
    { 0x0ECD, "ai_gesture_blink_loop" },
    { 0x0ECE, "ai_gesture_directional_custom" },
    { 0x0ECF, "ai_gesture_eyes_leftright" },
    { 0x0ED0, "ai_gesture_eyes_lookat" },
    { 0x0ED1, "ai_gesture_eyes_stop" },
    { 0x0ED2, "ai_gesture_eyes_updown" },
    { 0x0ED3, "ai_gesture_head_leftright" },
    { 0x0ED4, "ai_gesture_head_leftright_c6" },
    { 0x0ED5, "ai_gesture_head_updown" },
    { 0x0ED6, "ai_gesture_head_updown_c6" },
    { 0x0ED7, "ai_gesture_lookat" },
    { 0x0ED8, "ai_gesture_lookat_natural" },
    { 0x0ED9, "ai_gesture_lookat_torso" },
    { 0x0EDA, "ai_gesture_lookat_weight_down" },
    { 0x0EDB, "ai_gesture_lookat_weight_up" },
    { 0x0EDC, "ai_gesture_point" },
    { 0x0EDD, "ai_gesture_requested" },
    { 0x0EDE, "ai_gesture_simple" },
    { 0x0EDF, "ai_gesture_single_blink" },
    { 0x0EE0, "ai_gesture_stop" },
    { 0x0EE1, "ai_gesture_stop_c6" },
    { 0x0EE2, "ai_gesture_torso_leftright" },
    { 0x0EE3, "ai_gesture_torso_stop" },
    { 0x0EE4, "ai_gesture_update_eyes_lookat" },
    { 0x0EE5, "ai_gesture_update_lookat" },
    { 0x0EE6, "ai_gestures" },
    { 0x0EE7, "ai_get_closest_point" },
    { 0x0EE8, "ai_getaliveaiarray" },
    { 0x0EE9, "ai_getanimationfinalangles" },
    { 0x0EEA, "ai_getanimationfinalorigin" },
    { 0x0EEB, "ai_getanimationoriginattime" },
    { 0x0EEC, "ai_getanimationoriginattimeoverframe" },
    { 0x0EED, "ai_getanimationstartangles" },
    { 0x0EEE, "ai_getanimationstartorigin" },
    { 0x0EEF, "ai_getstance" },
    { 0x0EF0, "ai_going_to_alarm" },
    { 0x0EF1, "ai_ground_veh_spawn" },
    { 0x0EF2, "ai_gunpose_ads" },
    { 0x0EF3, "ai_gunpose_reset" },
    { 0x0EF4, "ai_in_antigrav_should_rerise" },
    { 0x0EF5, "ai_in_position" },
    { 0x0EF6, "ai_infil_type" },
    { 0x0EF7, "ai_init" },
    { 0x0EF8, "ai_instantlyremovefromvehicle" },
    { 0x0EF9, "ai_is_shooting" },
    { 0x0EFA, "ai_isalive" },
    { 0x0EFB, "ai_iscivilian" },
    { 0x0EFC, "ai_isdog" },
    { 0x0EFD, "ai_isfemale" },
    { 0x0EFE, "ai_isguard" },
    { 0x0EFF, "ai_isridingvehicle" },
    { 0x0F00, "ai_isvehicledriver" },
    { 0x0F01, "ai_killondamage" },
    { 0x0F02, "ai_laser_always_on" },
    { 0x0F03, "ai_lasers" },
    { 0x0F04, "ai_last_weapon_fire_time" },
    { 0x0F05, "ai_lbravo_spawn" },
    { 0x0F06, "ai_lookat_hold" },
    { 0x0F07, "ai_lookat_release" },
    { 0x0F08, "ai_masks" },
    { 0x0F09, "ai_mindia8_jugg_spawn" },
    { 0x0F0A, "ai_mode" },
    { 0x0F0B, "ai_monitor_doors" },
    { 0x0F0C, "ai_move_away" },
    { 0x0F0D, "ai_movealongpath" },
    { 0x0F0E, "ai_movealongpathcleanupobjectivelogic" },
    { 0x0F0F, "ai_movealongpathplayerproximityfocushintlogic" },
    { 0x0F10, "ai_movealongpathplayerproximitylogic" },
    { 0x0F11, "ai_movement_control" },
    { 0x0F12, "ai_notehandler_cellphone" },
    { 0x0F13, "ai_notehandler_smoking" },
    { 0x0F14, "ai_notetrack_loop" },
    { 0x0F15, "ai_number" },
    { 0x0F16, "ai_nvg_down" },
    { 0x0F17, "ai_nvg_player_update" },
    { 0x0F18, "ai_nvg_up" },
    { 0x0F19, "ai_open_try_animated" },
    { 0x0F1A, "ai_pathdebugenabled" },
    { 0x0F1B, "ai_pathdoesnodehaveaistop" },
    { 0x0F1C, "ai_pathgetnextnodesarray" },
    { 0x0F1D, "ai_pathplayerfollowaispeedscaling" },
    { 0x0F1E, "ai_picks_destination" },
    { 0x0F1F, "ai_playsound" },
    { 0x0F20, "ai_point_gesture_requested" },
    { 0x0F21, "ai_push_residence" },
    { 0x0F22, "ai_ragdoll_immediate" },
    { 0x0F23, "ai_ragdolldeathondamage" },
    { 0x0F24, "ai_removesidearm" },
    { 0x0F25, "ai_request_gesture" },
    { 0x0F26, "ai_request_gesture_internal" },
    { 0x0F27, "ai_resetstances" },
    { 0x0F28, "ai_rpg_behavior" },
    { 0x0F29, "ai_saftey_nets" },
    { 0x0F2A, "ai_setaimassist" },
    { 0x0F2B, "ai_setallowmelee" },
    { 0x0F2C, "ai_sethackedname" },
    { 0x0F2D, "ai_setlookatentity" },
    { 0x0F2E, "ai_setname" },
    { 0x0F2F, "ai_setnoarmordrop" },
    { 0x0F30, "ai_sets_goal" },
    { 0x0F31, "ai_sets_goal_with_delay" },
    { 0x0F32, "ai_shoot" },
    { 0x0F33, "ai_should_be_added" },
    { 0x0F34, "ai_should_follow_check" },
    { 0x0F35, "ai_show_shadows_in_compound" },
    { 0x0F36, "ai_sight_brushes" },
    { 0x0F37, "ai_sight_monitor" },
    { 0x0F38, "ai_slice_settings" },
    { 0x0F39, "ai_smoking_blowsmoke" },
    { 0x0F3A, "ai_smoking_cleanup" },
    { 0x0F3B, "ai_spawn_door_interal" },
    { 0x0F3C, "ai_spawn_func" },
    { 0x0F3D, "ai_spawn_vehicle_func" },
    { 0x0F3E, "ai_spawned" },
    { 0x0F3F, "ai_stance_init" },
    { 0x0F40, "ai_stance_thread" },
    { 0x0F41, "ai_stumbling" },
    { 0x0F42, "ai_takecoveratnearestnodeinarray" },
    { 0x0F43, "ai_takecoveratnodes" },
    { 0x0F44, "ai_trace" },
    { 0x0F45, "ai_trace_get_all_results" },
    { 0x0F46, "ai_trace_passed" },
    { 0x0F47, "ai_try_open_door" },
    { 0x0F48, "ai_turnoff_alarm" },
    { 0x0F49, "ai_turnon_alarm" },
    { 0x0F4A, "ai_turret_shoot" },
    { 0x0F4B, "ai_update" },
    { 0x0F4C, "ai_use_scripted_navigation" },
    { 0x0F4D, "ai_used_think" },
    { 0x0F4E, "ai_wait_go" },
    { 0x0F4F, "ai_waittillinstance" },
    { 0x0F50, "ai_weapon_override" },
    { 0x0F51, "aiac130inprogress" },
    { 0x0F52, "aiairchief" },
    { 0x0F53, "aiairstrikeinprogress" },
    { 0x0F54, "aianimcheck" },
    { 0x0F55, "aianims" },
    { 0x0F56, "aianimthread" },
    { 0x0F57, "aibackpackmodel" },
    { 0x0F58, "aibashmonitor" },
    { 0x0F59, "aibashproxcheck" },
    { 0x0F5A, "aibattlechatterloop" },
    { 0x0F5B, "aicanseeplayer" },
    { 0x0F5C, "aicount" },
    { 0x0F5D, "aidamageradius" },
    { 0x0F5E, "aideathenemy" },
    { 0x0F5F, "aideatheventthread" },
    { 0x0F60, "aideathfriendly" },
    { 0x0F61, "aideaths" },
    { 0x0F62, "aidisplacewaiter" },
    { 0x0F63, "aidoorchief" },
    { 0x0F64, "aievent_funcs" },
    { 0x0F65, "aifolloworderwaiter" },
    { 0x0F66, "aigibfunction" },
    { 0x0F67, "aigrenadedangerwaiter" },
    { 0x0F68, "aigrenadetypecheck" },
    { 0x0F69, "aigroup_create" },
    { 0x0F6A, "aigroup_decrement" },
    { 0x0F6B, "aigroup_soldierthink" },
    { 0x0F6C, "aigroup_spawnerdeath" },
    { 0x0F6D, "aigroup_spawnerempty" },
    { 0x0F6E, "aigroup_spawnerthink" },
    { 0x0F6F, "aihasweapon" },
    { 0x0F70, "aihostileburstloop" },
    { 0x0F71, "aiinformweaponwaiter" },
    { 0x0F72, "aikilleventthread" },
    { 0x0F73, "aikillradius" },
    { 0x0F74, "aim_2" },
    { 0x0F75, "aim_2_default" },
    { 0x0F76, "aim_4" },
    { 0x0F77, "aim_4_default" },
    { 0x0F78, "aim_5" },
    { 0x0F79, "aim_6" },
    { 0x0F7A, "aim_6_default" },
    { 0x0F7B, "aim_8" },
    { 0x0F7C, "aim_8_default" },
    { 0x0F7D, "aim_animnode" },
    { 0x0F7E, "aim_animprefix" },
    { 0x0F7F, "aim_assist" },
    { 0x0F80, "aim_at" },
    { 0x0F81, "aim_at_laser_off" },
    { 0x0F82, "aim_at_laser_on" },
    { 0x0F83, "aim_laser" },
    { 0x0F84, "aim_pos" },
    { 0x0F85, "aim_search_around" },
    { 0x0F86, "aim_search_spline" },
    { 0x0F87, "aim_status" },
    { 0x0F88, "aim_target" },
    { 0x0F89, "aim_target_offset" },
    { 0x0F8A, "aim_think" },
    { 0x0F8B, "aim_turret_at_ambush_point_or_visible_enemy" },
    { 0x0F8C, "aim_weights" },
    { 0x0F8D, "aimchange_oldturnrate" },
    { 0x0F8E, "aimchangeorientation" },
    { 0x0F8F, "aimedataimtarget" },
    { 0x0F90, "aimedsomewhatatenemy" },
    { 0x0F91, "aiment" },
    { 0x0F92, "aimgroup" },
    { 0x0F93, "aimingdown" },
    { 0x0F94, "aimlimitstatemappings" },
    { 0x0F95, "aimpitchdifftolerance" },
    { 0x0F96, "aimspeedmultiplier" },
    { 0x0F97, "aimspeedoverride" },
    { 0x0F98, "aimstarttime" },
    { 0x0F99, "aimtarget" },
    { 0x0F9A, "aimtargetoriginalposition" },
    { 0x0F9B, "aimweight" },
    { 0x0F9C, "aimweight_end" },
    { 0x0F9D, "aimweight_start" },
    { 0x0F9E, "aimweight_t" },
    { 0x0F9F, "aimweight_transframes" },
    { 0x0FA0, "aimyawdiffclosedistsq" },
    { 0x0FA1, "aimyawdiffclosetolerance" },
    { 0x0FA2, "aimyawdifffartolerance" },
    { 0x0FA3, "ainame" },
    { 0x0FA4, "ainameandrankwaiter" },
    { 0x0FA5, "aiopener" },
    { 0x0FA6, "air_doors" },
    { 0x0FA7, "air_raid_active" },
    { 0x0FA8, "air_raid_team_called" },
    { 0x0FA9, "air_reference" },
    { 0x0FAA, "air_start_nodes" },
    { 0x0FAB, "air_veh_spawner" },
    { 0x0FAC, "air_vehicles_distant" },
    { 0x0FAD, "air_vehicles_distant_intro_skipped" },
    { 0x0FAE, "airank" },
    { 0x0FAF, "aircraft_wash" },
    { 0x0FB0, "aircraft_wash_thread" },
    { 0x0FB1, "airdrop_airdropmultipledropcrates" },
    { 0x0FB2, "airdrop_airdropmultipleinit" },
    { 0x0FB3, "airdrop_allowactionset" },
    { 0x0FB4, "airdrop_awardkillstreak" },
    { 0x0FB5, "airdrop_botiskillstreaksupported" },
    { 0x0FB6, "airdrop_br_forcegiveweapon" },
    { 0x0FB7, "airdrop_br_givedropbagloadout" },
    { 0x0FB8, "airdrop_capturelootcachecallback" },
    { 0x0FB9, "airdrop_getgamemodespecificcratedata" },
    { 0x0FBA, "airdrop_gettargetmarker" },
    { 0x0FBB, "airdrop_handlemovingplatforms" },
    { 0x0FBC, "airdrop_iskillstreakblockedforbots" },
    { 0x0FBD, "airdrop_light_tank" },
    { 0x0FBE, "airdrop_makeitemfromcrate" },
    { 0x0FBF, "airdrop_makeitemsfromcrate" },
    { 0x0FC0, "airdrop_makeweaponfromcrate" },
    { 0x0FC1, "airdrop_multiple_ac130firstframe" },
    { 0x0FC2, "airdrop_multiple_ac130handledamage" },
    { 0x0FC3, "airdrop_multiple_ac130handlefataldamage" },
    { 0x0FC4, "airdrop_multiple_addac130tolist" },
    { 0x0FC5, "airdrop_multiple_createac130" },
    { 0x0FC6, "airdrop_multiple_deleteac130" },
    { 0x0FC7, "airdrop_multiple_destroyac130" },
    { 0x0FC8, "airdrop_multiple_dropcrates" },
    { 0x0FC9, "airdrop_multiple_getcratedropcaststart" },
    { 0x0FCA, "airdrop_multiple_getdropheight" },
    { 0x0FCB, "airdrop_multiple_init" },
    { 0x0FCC, "airdrop_multiple_initanimations" },
    { 0x0FCD, "airdrop_multiple_monitordamage" },
    { 0x0FCE, "airdrop_multiple_removeac130fromlist" },
    { 0x0FCF, "airdrop_multiple_watchdropcrates" },
    { 0x0FD0, "airdrop_multiple_watchdropcratesend" },
    { 0x0FD1, "airdrop_multiple_watchdropcratesinternal" },
    { 0x0FD2, "airdrop_new_loadout_near_player" },
    { 0x0FD3, "airdrop_outlinedisable" },
    { 0x0FD4, "airdrop_registeractionset" },
    { 0x0FD5, "airdrop_registercrateforcleanup" },
    { 0x0FD6, "airdrop_registerscoreinfo" },
    { 0x0FD7, "airdrop_requests" },
    { 0x0FD8, "airdrop_showerrormessage" },
    { 0x0FD9, "airdrop_showkillstreaksplash" },
    { 0x0FDA, "airdrop_stophandlingmovingplatforms" },
    { 0x0FDB, "airdrop_trigger_watcher" },
    { 0x0FDC, "airdrop_unresolvedcollisionnearestnode" },
    { 0x0FDD, "airdrop_updateuiprogress" },
    { 0x0FDE, "airdrop_watchplayerweapon" },
    { 0x0FDF, "airdroplocations" },
    { 0x0FE0, "airdropmarkeractivate" },
    { 0x0FE1, "airdropmarkerfired" },
    { 0x0FE2, "airdropmarkerswitchended" },
    { 0x0FE3, "airdropmarkertaken" },
    { 0x0FE4, "airdroptype" },
    { 0x0FE5, "airdropvisualmarkeractivate" },
    { 0x0FE6, "airdropvisualmarkerfired" },
    { 0x0FE7, "airfield_mortar_1" },
    { 0x0FE8, "airfield_mortar_2" },
    { 0x0FE9, "airfield_obj_func" },
    { 0x0FEA, "airfield_plant_spots" },
    { 0x0FEB, "airfield_player_tanks" },
    { 0x0FEC, "airlookatent" },
    { 0x0FED, "airpathidx" },
    { 0x0FEE, "airpathnodes" },
    { 0x0FEF, "airplane_list" },
    { 0x0FF0, "airport_ecounterstart" },
    { 0x0FF1, "airport_enemy_setup" },
    { 0x0FF2, "airport_gate_open" },
    { 0x0FF3, "airport_gate_trigger" },
    { 0x0FF4, "airport_spawners_trigger" },
    { 0x0FF5, "airportcombat_getallycovernodes" },
    { 0x0FF6, "airstrike_addspawndangerzone" },
    { 0x0FF7, "airstrike_delayplayscriptable" },
    { 0x0FF8, "airstrike_earthquake" },
    { 0x0FF9, "airstrike_getmapselectpoint" },
    { 0x0FFA, "airstrike_getownerlookatpos" },
    { 0x0FFB, "airstrike_handleflyoutfxdeath" },
    { 0x0FFC, "airstrike_killcammove" },
    { 0x0FFD, "airstrike_munitionused" },
    { 0x0FFE, "airstrike_playapproachfx" },
    { 0x0FFF, "airstrike_playflybyfx" },
    { 0x1000, "airstrike_playflyfx" },
    { 0x1001, "airstrike_playflyoutfx" },
    { 0x1002, "airstrike_playplaneattackfx" },
    { 0x1003, "airstrike_removemarker" },
    { 0x1004, "airstrike_setmarkerobjective" },
    { 0x1005, "airstrike_showerrormessage" },
    { 0x1006, "airstrike_startmapselectsequence" },
    { 0x1007, "airstrike_updatemarkerpos" },
    { 0x1008, "airstrike_watchdeployended" },
    { 0x1009, "airstrike_watchforads" },
    { 0x100A, "airstrike_watchkills" },
    { 0x100B, "airstrike_watchkillscount" },
    { 0x100C, "airstrike_watchkillstimeout" },
    { 0x100D, "airstrike_watchplayerweapon" },
    { 0x100E, "airstrikeinprogress" },
    { 0x100F, "airstrikekillcount" },
    { 0x1010, "airstrikemodels" },
    { 0x1011, "airstrikesettings" },
    { 0x1012, "aispread" },
    { 0x1013, "aistate" },
    { 0x1014, "aisuppressai" },
    { 0x1015, "aithreadthreader" },
    { 0x1016, "aitoplayerdistancesq" },
    { 0x1017, "aiturnnotifies" },
    { 0x1018, "aiturretcantarget" },
    { 0x1019, "aiturretgettarget" },
    { 0x101A, "aiturretshoottarget" },
    { 0x101B, "aiturretthink" },
    { 0x101C, "aitype" },
    { 0x101D, "aitype_check" },
    { 0x101E, "aitype_override" },
    { 0x101F, "aitype_override_cumulative_weight" },
    { 0x1020, "aitype_override_weights" },
    { 0x1021, "aitypeinitfuncs" },
    { 0x1022, "aitypes" },
    { 0x1023, "aiupdateanimstate" },
    { 0x1024, "aiupdatecombat" },
    { 0x1025, "aiupdatesuppressed" },
    { 0x1026, "aiusingturret" },
    { 0x1027, "aivehiclekillwaiter" },
    { 0x1028, "aivehiclewaiter" },
    { 0x1029, "aiweapon" },
    { 0x102A, "ajar" },
    { 0x102B, "ajar_opener" },
    { 0x102C, "ajara_opener" },
    { 0x102D, "ajarmonitor" },
    { 0x102E, "ak_shoot_timer" },
    { 0x102F, "ak_weapon_user" },
    { 0x1030, "ak_weapon_user_no_sidearm" },
    { 0x1031, "akimbo_prop" },
    { 0x1032, "akproxies" },
    { 0x1033, "alameer_wh04_model" },
    { 0x1034, "alarm_audio" },
    { 0x1035, "alarm_box" },
    { 0x1036, "alarm_box_player_interaction" },
    { 0x1037, "alarm_box_structs" },
    { 0x1038, "alarm_car_debug" },
    { 0x1039, "alarm_car_watch_damage" },
    { 0x103A, "alarm_cars_init" },
    { 0x103B, "alarm_fx_off" },
    { 0x103C, "alarm_fx_on" },
    { 0x103D, "alarm_on" },
    { 0x103E, "alarm_sound" },
    { 0x103F, "alarm_sound_off" },
    { 0x1040, "alarm_sound_off_encounter_end" },
    { 0x1041, "alarm_sound_on" },
    { 0x1042, "alarmbox2_logic" },
    { 0x1043, "alarmcars" },
    { 0x1044, "alarmdamage" },
    { 0x1045, "alarmdoor" },
    { 0x1046, "alarmeddoors" },
    { 0x1047, "alarmmonitor" },
    { 0x1048, "alarmprompts" },
    { 0x1049, "alarmstillplaying" },
    { 0x104A, "albedoblendfactor" },
    { 0x104B, "albedoblendmode" },
    { 0x104C, "alert_all_nearby_enemies" },
    { 0x104D, "alert_debug_display" },
    { 0x104E, "alert_delay_distance_time" },
    { 0x104F, "alert_enemy_soldiers" },
    { 0x1050, "alert_icon" },
    { 0x1051, "alert_levels_exe" },
    { 0x1052, "alert_levels_int" },
    { 0x1053, "alert_when_see_player" },
    { 0x1054, "alerted" },
    { 0x1055, "alerted_hunt_mode" },
    { 0x1056, "alertedanimationname" },
    { 0x1057, "alertedhuntmode" },
    { 0x1058, "alertgroup" },
    { 0x1059, "alertgroupnames" },
    { 0x105A, "alertlevel_init_map" },
    { 0x105B, "alertlevel_normal" },
    { 0x105C, "alertlevel_script_to_exe" },
    { 0x105D, "alertlevelscript" },
    { 0x105E, "alertnearbyenemiesafterdelay" },
    { 0x105F, "alertnearbyloop" },
    { 0x1060, "alertzombie" },
    { 0x1061, "alex" },
    { 0x1062, "alex_ai" },
    { 0x1063, "alex_call_out_runner" },
    { 0x1064, "alex_dialog_struct" },
    { 0x1065, "alex_face_swap" },
    { 0x1066, "alex_loadout" },
    { 0x1067, "alex_loadout_final" },
    { 0x1068, "alex_setup" },
    { 0x1069, "alex_speaking_stairwell_secure_speaking" },
    { 0x106A, "alex_weapons_config" },
    { 0x106B, "alex_wm" },
    { 0x106C, "alias" },
    { 0x106D, "alias_2d_version_exists" },
    { 0x106E, "alias_from_distance" },
    { 0x106F, "alias_group_exists" },
    { 0x1070, "alias_groups" },
    { 0x1071, "aliases" },
    { 0x1072, "aliasname" },
    { 0x1073, "aliaspain" },
    { 0x1074, "alien_fire_off" },
    { 0x1075, "alien_fire_on" },
    { 0x1076, "alien_health_per_player_init" },
    { 0x1077, "alien_health_per_player_scalar" },
    { 0x1078, "alien_loadout" },
    { 0x1079, "alien_mode_feature" },
    { 0x107A, "alien_mode_has" },
    { 0x107B, "alien_perks" },
    { 0x107C, "alien_scripted" },
    { 0x107D, "aliensnarecount" },
    { 0x107E, "aliensnarespeedscalar" },
    { 0x107F, "alive" },
    { 0x1080, "alive_monitor" },
    { 0x1081, "alive_support_vehicles" },
    { 0x1082, "aliveplayers" },
    { 0x1083, "alivestates" },
    { 0x1084, "all_ai_vehicle_infils" },
    { 0x1085, "all_air_vehicle_spawn_points" },
    { 0x1086, "all_alive_players_in_chopper" },
    { 0x1087, "all_available_pents" },
    { 0x1088, "all_convoys" },
    { 0x1089, "all_dom_flags" },
    { 0x108A, "all_heli_ents" },
    { 0x108B, "all_interaction_structs" },
    { 0x108C, "all_lights_off" },
    { 0x108D, "all_magic_weapons" },
    { 0x108E, "all_marines" },
    { 0x108F, "all_node_positions" },
    { 0x1090, "all_perk_list" },
    { 0x1091, "all_players_fulton" },
    { 0x1092, "all_repairs_are_done" },
    { 0x1093, "all_search_areas" },
    { 0x1094, "all_secure_check" },
    { 0x1095, "all_spawn_locations" },
    { 0x1096, "all_spawned_vehicles" },
    { 0x1097, "allaliveplayersplunder" },
    { 0x1098, "allencounters" },
    { 0x1099, "alley" },
    { 0x109A, "alley_anim_node" },
    { 0x109B, "alley_approach_garage" },
    { 0x109C, "alley_attack" },
    { 0x109D, "alley_bldg_door_handler" },
    { 0x109E, "alley_car_alarm_setup" },
    { 0x109F, "alley_catchup" },
    { 0x10A0, "alley_children_vo" },
    { 0x10A1, "alley_containment" },
    { 0x10A2, "alley_ctbuddy_anim" },
    { 0x10A3, "alley_cutter_at_gate" },
    { 0x10A4, "alley_enter" },
    { 0x10A5, "alley_entry_event" },
    { 0x10A6, "alley_fallback_handler" },
    { 0x10A7, "alley_farah" },
    { 0x10A8, "alley_farah_aim" },
    { 0x10A9, "alley_gate_open" },
    { 0x10AA, "alley_grab_anim_node" },
    { 0x10AB, "alley_grab_guy_model" },
    { 0x10AC, "alley_grab_mask_line" },
    { 0x10AD, "alley_grab_mask_model" },
    { 0x10AE, "alley_guy_cleanup" },
    { 0x10AF, "alley_heli_crash" },
    { 0x10B0, "alley_heli_crash_lgt_1" },
    { 0x10B1, "alley_heli_crash_lgt_2" },
    { 0x10B2, "alley_ignore_player_clear" },
    { 0x10B3, "alley_ignore_player_enable" },
    { 0x10B4, "alley_jumpers" },
    { 0x10B5, "alley_life_door" },
    { 0x10B6, "alley_life_kids" },
    { 0x10B7, "alley_life_kids_animate_then_delete" },
    { 0x10B8, "alley_life_kids_door" },
    { 0x10B9, "alley_life_kids_player_distance_listener" },
    { 0x10BA, "alley_life_kids_player_firing_listener" },
    { 0x10BB, "alley_life_kids_player_within_distance" },
    { 0x10BC, "alley_life_tv" },
    { 0x10BD, "alley_life_tv_player_firing_listener" },
    { 0x10BE, "alley_life_tv_player_looking_listener" },
    { 0x10BF, "alley_looped_anims" },
    { 0x10C0, "alley_main" },
    { 0x10C1, "alley_marine_ignore_handler" },
    { 0x10C2, "alley_place_truck_start" },
    { 0x10C3, "alley_price" },
    { 0x10C4, "alley_price_anim" },
    { 0x10C5, "alley_price_arrival_aim" },
    { 0x10C6, "alley_price_at_gate" },
    { 0x10C7, "alley_price_life_door_aim" },
    { 0x10C8, "alley_push_up_scripted_dialogue" },
    { 0x10C9, "alley_runners" },
    { 0x10CA, "alley_setup" },
    { 0x10CB, "alley_smoke_handler" },
    { 0x10CC, "alley_soccer_screens" },
    { 0x10CD, "alley_start" },
    { 0x10CE, "alley_start_vo" },
    { 0x10CF, "alley_stealth_aq_alert" },
    { 0x10D0, "alley_stealth_aq_create_badplace_in_combat" },
    { 0x10D1, "alley_stealth_aq_create_badplace_on_death" },
    { 0x10D2, "alley_stealth_aq_prox_check" },
    { 0x10D3, "alley_stealth_aq_setup" },
    { 0x10D4, "alley_stealth_background_enemy_handler" },
    { 0x10D5, "alley_stealth_bar_entrance_door_handler" },
    { 0x10D6, "alley_stealth_catchup" },
    { 0x10D7, "alley_stealth_check_for_player_kill" },
    { 0x10D8, "alley_stealth_check_if_player_shoots" },
    { 0x10D9, "alley_stealth_check_if_player_unholsters" },
    { 0x10DA, "alley_stealth_check_player" },
    { 0x10DB, "alley_stealth_door_hint_handler" },
    { 0x10DC, "alley_stealth_draw_weapon_check" },
    { 0x10DD, "alley_stealth_enemies" },
    { 0x10DE, "alley_stealth_grabbed_enemy_handler" },
    { 0x10DF, "alley_stealth_main" },
    { 0x10E0, "alley_stealth_monitor_door_bash" },
    { 0x10E1, "alley_stealth_player_fail" },
    { 0x10E2, "alley_stealth_player_fail_handler" },
    { 0x10E3, "alley_stealth_player_movement" },
    { 0x10E4, "alley_stealth_pre_price_ambush_notify" },
    { 0x10E5, "alley_stealth_price_adjust_ff_penalty" },
    { 0x10E6, "alley_stealth_price_alert_end_door_idle" },
    { 0x10E7, "alley_stealth_price_check_player" },
    { 0x10E8, "alley_stealth_price_clean_house" },
    { 0x10E9, "alley_stealth_price_combat" },
    { 0x10EA, "alley_stealth_price_from_start_point" },
    { 0x10EB, "alley_stealth_price_post_at_door" },
    { 0x10EC, "alley_stealth_price_setup" },
    { 0x10ED, "alley_stealth_price_takedown_fire" },
    { 0x10EE, "alley_stealth_remove_dead_bodies" },
    { 0x10EF, "alley_stealth_reset_enemy_alert_level" },
    { 0x10F0, "alley_stealth_stakeout_exit_door_handler" },
    { 0x10F1, "alley_stealth_start" },
    { 0x10F2, "alley_stealth_start_delayed" },
    { 0x10F3, "alley_stealth_start_function" },
    { 0x10F4, "alley_stealth_stp_main" },
    { 0x10F5, "alley_track_player_smoke_grenade" },
    { 0x10F6, "alley_triggers_monitor" },
    { 0x10F7, "alley_wolf_escort" },
    { 0x10F8, "alley_wolf_escort_animate_then_idle" },
    { 0x10F9, "alley_wrong_way_spotted" },
    { 0x10FA, "alleys_vig_init" },
    { 0x10FB, "alleytruckdropoff" },
    { 0x10FC, "allfobs" },
    { 0x10FD, "allies_approach" },
    { 0x10FE, "allies_are_close" },
    { 0x10FF, "allies_explosion_bullet_shield" },
    { 0x1100, "allies_fallback_thread" },
    { 0x1101, "allies_groundfloor_melee_clear_handler" },
    { 0x1102, "allies_hold_fire" },
    { 0x1103, "allies_in_danger" },
    { 0x1104, "allies_juggernaut_flee" },
    { 0x1105, "allies_juggernaut_setup" },
    { 0x1106, "allies_juggernaut_spawn" },
    { 0x1107, "allies_molotov_toggle" },
    { 0x1108, "allies_move_away" },
    { 0x1109, "allies_move_through_bunker" },
    { 0x110A, "allies_move_through_exterior" },
    { 0x110B, "allies_move_through_factory" },
    { 0x110C, "allies_move_to_trucks" },
    { 0x110D, "allies_nvg_on" },
    { 0x110E, "allies_push_stairwell_early" },
    { 0x110F, "allies_respawn" },
    { 0x1110, "allies_same_color" },
    { 0x1111, "allies_to_combat" },
    { 0x1112, "allies_to_cqb" },
    { 0x1113, "alliesaverage" },
    { 0x1114, "alliescapturing" },
    { 0x1115, "allieschopper" },
    { 0x1116, "alliesfrontlinevec" },
    { 0x1117, "allieshealth" },
    { 0x1118, "allieshqloc" },
    { 0x1119, "allieshqname" },
    { 0x111A, "alliesmaxhealth" },
    { 0x111B, "alliesprevflagcount" },
    { 0x111C, "alliesspawnareas" },
    { 0x111D, "alliessquadleader" },
    { 0x111E, "alliesstartspawn" },
    { 0x111F, "allieszone" },
    { 0x1120, "alllocations" },
    { 0x1121, "allow_action_slot_weapon" },
    { 0x1122, "allow_add" },
    { 0x1123, "allow_ads" },
    { 0x1124, "allow_airdrop_internal" },
    { 0x1125, "allow_antigrav_float" },
    { 0x1126, "allow_armor" },
    { 0x1127, "allow_array" },
    { 0x1128, "allow_audio_hints" },
    { 0x1129, "allow_autoreload" },
    { 0x112A, "allow_backstabbers" },
    { 0x112B, "allow_breach_charge" },
    { 0x112C, "allow_carry" },
    { 0x112D, "allow_cg_drawcrosshair" },
    { 0x112E, "allow_change_stance" },
    { 0x112F, "allow_cinematic_motion" },
    { 0x1130, "allow_cough_gesture" },
    { 0x1131, "allow_crate_use" },
    { 0x1132, "allow_crouch" },
    { 0x1133, "allow_death" },
    { 0x1134, "allow_despawn_all_hostages" },
    { 0x1135, "allow_dodge" },
    { 0x1136, "allow_doublejump" },
    { 0x1137, "allow_driver_exit" },
    { 0x1138, "allow_dvar_infammo" },
    { 0x1139, "allow_emp" },
    { 0x113A, "allow_emp_player" },
    { 0x113B, "allow_equipment" },
    { 0x113C, "allow_equipment_slot" },
    { 0x113D, "allow_execution_attack" },
    { 0x113E, "allow_execution_victim" },
    { 0x113F, "allow_fire" },
    { 0x1140, "allow_flashed" },
    { 0x1141, "allow_force_player_exit" },
    { 0x1142, "allow_funcs" },
    { 0x1143, "allow_gesture" },
    { 0x1144, "allow_gesture_reactions" },
    { 0x1145, "allow_hands" },
    { 0x1146, "allow_health_regen" },
    { 0x1147, "allow_hvt_stealing_by_ai" },
    { 0x1148, "allow_infil_after_full_or_timeout" },
    { 0x1149, "allow_init" },
    { 0x114A, "allow_input_internal" },
    { 0x114B, "allow_interactions" },
    { 0x114C, "allow_jammer_takedamage" },
    { 0x114D, "allow_jog" },
    { 0x114E, "allow_jump" },
    { 0x114F, "allow_killstreaks" },
    { 0x1150, "allow_ladder_placement" },
    { 0x1151, "allow_lean" },
    { 0x1152, "allow_lookpeek" },
    { 0x1153, "allow_mantle" },
    { 0x1154, "allow_melee" },
    { 0x1155, "allow_mount_side" },
    { 0x1156, "allow_mount_top" },
    { 0x1157, "allow_movement" },
    { 0x1158, "allow_munitions" },
    { 0x1159, "allow_nvg" },
    { 0x115A, "allow_offhand_primary_weapons" },
    { 0x115B, "allow_offhand_secondary_weapons" },
    { 0x115C, "allow_offhand_shield_weapons" },
    { 0x115D, "allow_offhand_weapons" },
    { 0x115E, "allow_one_hit_melee_victim" },
    { 0x115F, "allow_picking_up_hvts" },
    { 0x1160, "allow_player_ignore_me" },
    { 0x1161, "allow_player_interactions" },
    { 0x1162, "allow_player_mantles" },
    { 0x1163, "allow_player_teleport" },
    { 0x1164, "allow_player_weapon_info" },
    { 0x1165, "allow_players_exfil" },
    { 0x1166, "allow_players_to_restart" },
    { 0x1167, "allow_prone" },
    { 0x1168, "allow_random_killers" },
    { 0x1169, "allow_recruiting_juggernauts" },
    { 0x116A, "allow_recruiting_nearby_soldiers" },
    { 0x116B, "allow_register_set" },
    { 0x116C, "allow_reload" },
    { 0x116D, "allow_routing_to_any_vehicles" },
    { 0x116E, "allow_routing_to_backup_support_vehicles" },
    { 0x116F, "allow_routing_to_backup_vehicles" },
    { 0x1170, "allow_routing_to_end" },
    { 0x1171, "allow_script_weapon_switch" },
    { 0x1172, "allow_secondary_offhand_weapons" },
    { 0x1173, "allow_set" },
    { 0x1174, "allow_sets" },
    { 0x1175, "allow_shellshock" },
    { 0x1176, "allow_slide" },
    { 0x1177, "allow_soldiers_attempt_take_target" },
    { 0x1178, "allow_sprint" },
    { 0x1179, "allow_stand" },
    { 0x117A, "allow_stealing_from_player_car" },
    { 0x117B, "allow_stick_kill" },
    { 0x117C, "allow_stunned" },
    { 0x117D, "allow_super" },
    { 0x117E, "allow_supers" },
    { 0x117F, "allow_to_get_to_corpse" },
    { 0x1180, "allow_unload_on_path" },
    { 0x1181, "allow_usability" },
    { 0x1182, "allow_vehicle_use" },
    { 0x1183, "allow_wallrun" },
    { 0x1184, "allow_weapon" },
    { 0x1185, "allow_weapon_first_raise_anims" },
    { 0x1186, "allow_weapon_mp" },
    { 0x1187, "allow_weapon_mp_init" },
    { 0x1188, "allow_weapon_pickup" },
    { 0x1189, "allow_weapon_scanning" },
    { 0x118A, "allow_weapon_switch" },
    { 0x118B, "allow_weapon_switch_clip" },
    { 0x118C, "allowable_double_attachments" },
    { 0x118D, "allowactionset" },
    { 0x118E, "allowairexit" },
    { 0x118F, "allowallyblindfire" },
    { 0x1190, "allowantigrav" },
    { 0x1191, "allowcapture" },
    { 0x1192, "allowcarry" },
    { 0x1193, "allowclasschoice" },
    { 0x1194, "allowclasschoicefunc" },
    { 0x1195, "allowdamageflash" },
    { 0x1196, "allowdeath_just_ragdoll" },
    { 0x1197, "allowed_aitypes" },
    { 0x1198, "allowed_elite" },
    { 0x1199, "allowed_enemy_types" },
    { 0x119A, "allowed_heavy" },
    { 0x119B, "allowed_light" },
    { 0x119C, "allowed_to_exit" },
    { 0x119D, "allowed_to_spawn_agent" },
    { 0x119E, "allowedcallouts" },
    { 0x119F, "allowedintrigger" },
    { 0x11A0, "allowedspawnareas" },
    { 0x11A1, "allowedwhileplanting" },
    { 0x11A2, "allowedwhilereviving" },
    { 0x11A3, "allowempdamage" },
    { 0x11A4, "allowenemyspectate" },
    { 0x11A5, "allowfauxdeath" },
    { 0x11A6, "allowfreespectate" },
    { 0x11A7, "allowgrenadedamage" },
    { 0x11A8, "allowhide" },
    { 0x11A9, "allowhvtspawn" },
    { 0x11AA, "allowinteractivecombat" },
    { 0x11AB, "allowkillstreaks" },
    { 0x11AC, "allowlatecomers" },
    { 0x11AD, "allowlmgarrival" },
    { 0x11AE, "allowmeleedamage" },
    { 0x11AF, "allowmonitoreddamage" },
    { 0x11B0, "allownoisemakerpickups" },
    { 0x11B1, "allowpartialrepairs" },
    { 0x11B2, "allowperks" },
    { 0x11B3, "allowplayerheadtracking" },
    { 0x11B4, "allowplayertobreach" },
    { 0x11B5, "allowprematchdamage" },
    { 0x11B6, "allowprematchlook" },
    { 0x11B7, "allowrefund" },
    { 0x11B8, "allowreviveweapons" },
    { 0x11B9, "allowridekillstreakplayerexit" },
    { 0x11BA, "allowrunninggesture" },
    { 0x11BB, "allows" },
    { 0x11BC, "allowselfrevive" },
    { 0x11BD, "allowshellshockondamage" },
    { 0x11BE, "allowshoot" },
    { 0x11BF, "allowspawnlocation" },
    { 0x11C0, "allowsupers" },
    { 0x11C1, "allowsuperweaponstow" },
    { 0x11C2, "allowtacopsmapprematch" },
    { 0x11C3, "allowteamassignment" },
    { 0x11C4, "allowtelefrag" },
    { 0x11C5, "allowturn45" },
    { 0x11C6, "allowuse" },
    { 0x11C7, "allowvehicledamage" },
    { 0x11C8, "allowweaponcache" },
    { 0x11C9, "allowweapons" },
    { 0x11CA, "allowweaponsforsentry" },
    { 0x11CB, "allparts" },
    { 0x11CC, "allpieces" },
    { 0x11CD, "allplayershaveassetsloaded" },
    { 0x11CE, "allprisoners" },
    { 0x11CF, "allspatrolpoints" },
    { 0x11D0, "allteamnamelist" },
    { 0x11D1, "allteamstied" },
    { 0x11D2, "alltrackedplayers" },
    { 0x11D3, "allweapons" },
    { 0x11D4, "ally" },
    { 0x11D5, "ally_01_mortar" },
    { 0x11D6, "ally_02_mortar" },
    { 0x11D7, "ally_03" },
    { 0x11D8, "ally_04" },
    { 0x11D9, "ally_05" },
    { 0x11DA, "ally_06" },
    { 0x11DB, "ally_anim_reach_after_delay" },
    { 0x11DC, "ally_armory_02_guards" },
    { 0x11DD, "ally_armory_guards" },
    { 0x11DE, "ally_burstshoot_enemy" },
    { 0x11DF, "ally_burstshoot_pos" },
    { 0x11E0, "ally_death" },
    { 0x11E1, "ally_drone_attack" },
    { 0x11E2, "ally_equipment_backpack" },
    { 0x11E3, "ally_equipment_backpack_icon" },
    { 0x11E4, "ally_equipment_backpack_interact" },
    { 0x11E5, "ally_equipment_force_ping" },
    { 0x11E6, "ally_equipment_init" },
    { 0x11E7, "ally_equipment_remove" },
    { 0x11E8, "ally_equipment_think" },
    { 0x11E9, "ally_equipment_watcher" },
    { 0x11EA, "ally_fob_movement" },
    { 0x11EB, "ally_go_to_and_wait" },
    { 0x11EC, "ally_groups" },
    { 0x11ED, "ally_increase_equipment" },
    { 0x11EE, "ally_move_with_purpose" },
    { 0x11EF, "ally_movement_containers" },
    { 0x11F0, "ally_nodes_init" },
    { 0x11F1, "ally_nodes_interact" },
    { 0x11F2, "ally_nodes_interact_recall" },
    { 0x11F3, "ally_nodes_interact_remove" },
    { 0x11F4, "ally_pep_talk_breakout" },
    { 0x11F5, "ally_rpg_guy" },
    { 0x11F6, "ally_search_array" },
    { 0x11F7, "ally_shoot_enemy" },
    { 0x11F8, "ally_shoot_pos" },
    { 0x11F9, "ally_start_at_end" },
    { 0x11FA, "ally_town_movement" },
    { 0x11FB, "ally_town_movement_bink" },
    { 0x11FC, "ally_track_and_kill" },
    { 0x11FD, "ally_track_and_kill_noteworthy" },
    { 0x11FE, "ally_tracking_enemy" },
    { 0x11FF, "ally_turn_on_player" },
    { 0x1200, "ally_vo" },
    { 0x1201, "ally_volume" },
    { 0x1202, "allyaveragedist" },
    { 0x1203, "allydrones" },
    { 0x1204, "allymarines" },
    { 0x1205, "allyonuse" },
    { 0x1206, "allytargets" },
    { 0x1207, "allzpatrolpoints" },
    { 0x1208, "alpha_ai_array_handler" },
    { 0x1209, "alpha_and_bravo_team" },
    { 0x120A, "alpha_moveup_post_breach" },
    { 0x120B, "alpha_team" },
    { 0x120C, "alpha_team_enter" },
    { 0x120D, "alpha_trailers" },
    { 0x120E, "alpha1" },
    { 0x120F, "alpha1_final_scene" },
    { 0x1210, "alpha1_gas_search" },
    { 0x1211, "alpha1_move_into_warehouse" },
    { 0x1212, "alpha1_move_to_chem_truck" },
    { 0x1213, "alpha1_wait_for_player" },
    { 0x1214, "alpha2" },
    { 0x1215, "alpha3" },
    { 0x1216, "alpha4" },
    { 0x1217, "alpha5" },
    { 0x1218, "alpha5_b1_girl_is_dead" },
    { 0x1219, "alpha5_b1_girl_secure" },
    { 0x121A, "alpha5_secure" },
    { 0x121B, "alpha6" },
    { 0x121C, "alphaagents" },
    { 0x121D, "alphaai" },
    { 0x121E, "alphabetize" },
    { 0x121F, "already_being_cut" },
    { 0x1220, "already_dead" },
    { 0x1221, "already_ran_function" },
    { 0x1222, "already_used" },
    { 0x1223, "alreadyaddedtoalivecount" },
    { 0x1224, "alreadyfindingpoi" },
    { 0x1225, "alreadyhit" },
    { 0x1226, "alreadytouchingtrigger" },
    { 0x1227, "alt_mode_passive" },
    { 0x1228, "alt_mode_weapons_allowed" },
    { 0x1229, "alt_node" },
    { 0x122A, "alt_rig" },
    { 0x122B, "altclipammo" },
    { 0x122C, "altdeath" },
    { 0x122D, "altdirectionalbloodoverlay" },
    { 0x122E, "altdisplayindex" },
    { 0x122F, "alternates" },
    { 0x1230, "altgunnerturret" },
    { 0x1231, "altstockammo" },
    { 0x1232, "always_attempt_killoff" },
    { 0x1233, "always_on_exploders" },
    { 0x1234, "always_pain" },
    { 0x1235, "always_sprint" },
    { 0x1236, "always_win_melee" },
    { 0x1237, "alwaysdrawfriendlynames" },
    { 0x1238, "alwaysgamemodeclass" },
    { 0x1239, "alwaysrunforward" },
    { 0x123A, "alwaysshowicon" },
    { 0x123B, "alwaysshowminimap" },
    { 0x123C, "alwaysshowsplash" },
    { 0x123D, "alwaysstalemate" },
    { 0x123E, "alwaysusestartspawns" },
    { 0x123F, "am_i_alive" },
    { 0x1240, "amb_info_updater" },
    { 0x1241, "ambassador_rock" },
    { 0x1242, "ambience_inner" },
    { 0x1243, "ambience_outer" },
    { 0x1244, "ambient_candidates" },
    { 0x1245, "ambient_combat_popo" },
    { 0x1246, "ambient_explosion" },
    { 0x1247, "ambient_fighting" },
    { 0x1248, "ambient_fighting_monitor_player" },
    { 0x1249, "ambient_garage_welding" },
    { 0x124A, "ambient_garage_welding_light" },
    { 0x124B, "ambient_house_enter_explosions" },
    { 0x124C, "ambient_idle_anim_node" },
    { 0x124D, "ambient_idle_scenes" },
    { 0x124E, "ambient_player_stop" },
    { 0x124F, "ambient_player_thread" },
    { 0x1250, "ambient_popo_spawn_func" },
    { 0x1251, "ambient_sound_queue" },
    { 0x1252, "ambient_spawning_paused" },
    { 0x1253, "ambientgroupinit" },
    { 0x1254, "ambientgroups" },
    { 0x1255, "ambo_anim_hack" },
    { 0x1256, "ambo_badplaces" },
    { 0x1257, "ambo_caught_logic" },
    { 0x1258, "ambo_direct_hint_check" },
    { 0x1259, "ambo_last_frame" },
    { 0x125A, "ambo_locate_hint_check" },
    { 0x125B, "ambulance" },
    { 0x125C, "ambulancedefibrillator" },
    { 0x125D, "ambulancedelayreuse" },
    { 0x125E, "ambulancedisable" },
    { 0x125F, "ambulancedisabletoteam" },
    { 0x1260, "ambulancedosiren" },
    { 0x1261, "ambulanceenabletoteam" },
    { 0x1262, "ambulancehidefromplayer" },
    { 0x1263, "ambulancelights" },
    { 0x1264, "ambulancemakeunsabletoall" },
    { 0x1265, "ambulancemakeunusabletoplayer" },
    { 0x1266, "ambulancemakeusable" },
    { 0x1267, "ambulancemakeusabletoplayer" },
    { 0x1268, "ambulancesetup" },
    { 0x1269, "ambulanceshowtoplayer" },
    { 0x126A, "ambulancethink" },
    { 0x126B, "ambush_1f_vo" },
    { 0x126C, "ambush_2f_postspawn" },
    { 0x126D, "ambush_allieslogic" },
    { 0x126E, "ambush_dialoguelogic" },
    { 0x126F, "ambush_duration" },
    { 0x1270, "ambush_end" },
    { 0x1271, "ambush_enemieslogic" },
    { 0x1272, "ambush_enemyballistickillcalloutlogic" },
    { 0x1273, "ambush_enemybarrelkillcalloutlogic" },
    { 0x1274, "ambush_enemylogic" },
    { 0x1275, "ambush_entrances" },
    { 0x1276, "ambush_getallynodes" },
    { 0x1277, "ambush_getenemiesgoalvolume" },
    { 0x1278, "ambush_getenemycovernodes" },
    { 0x1279, "ambush_getied" },
    { 0x127A, "ambush_getlocationvolumes" },
    { 0x127B, "ambush_getvolumelines" },
    { 0x127C, "ambush_guy_think" },
    { 0x127D, "ambush_halon_gas_control" },
    { 0x127E, "ambush_iedlogic" },
    { 0x127F, "ambush_instructionsdialoguelogic" },
    { 0x1280, "ambush_is_looking_forward" },
    { 0x1281, "ambush_is_looking_left" },
    { 0x1282, "ambush_lighting_change" },
    { 0x1283, "ambush_locationcalloutlogic" },
    { 0x1284, "ambush_main" },
    { 0x1285, "ambush_rpg_after_spawn" },
    { 0x1286, "ambush_rpg_monitor" },
    { 0x1287, "ambush_save" },
    { 0x1288, "ambush_sniper" },
    { 0x1289, "ambush_sniper_fire" },
    { 0x128A, "ambush_sniper_mover_clean_up" },
    { 0x128B, "ambush_sniper_sequence" },
    { 0x128C, "ambush_sniper_think" },
    { 0x128D, "ambush_spawnenemies" },
    { 0x128E, "ambush_spawning_think" },
    { 0x128F, "ambush_squad_func" },
    { 0x1290, "ambush_start" },
    { 0x1291, "ambush_suicide_bomber_think" },
    { 0x1292, "ambush_tele_lower_postspawn" },
    { 0x1293, "ambush_tele_upper_postspawn" },
    { 0x1294, "ambush_teleport_to_cover" },
    { 0x1295, "ambush_teleport_to_struct" },
    { 0x1296, "ambush_trap_ent" },
    { 0x1297, "ambush_triggeried" },
    { 0x1298, "ambush_vehicle_death_monitor" },
    { 0x1299, "ambush_vehicle_id" },
    { 0x129A, "ambush_vehicle_should_slow_down" },
    { 0x129B, "ambush_vehicle_speed_manager" },
    { 0x129C, "ambush_vehicle_speed_think" },
    { 0x129D, "ambush_vehicle_think" },
    { 0x129E, "ambush_vehicle_unload" },
    { 0x129F, "ambush_vehicle_unload_when_player_vehicle_break_down" },
    { 0x12A0, "ambush_vehicles" },
    { 0x12A1, "ambush_vehicles_ahead_player_vehicle" },
    { 0x12A2, "ambush_vehicles_behind_player_vehicle" },
    { 0x12A3, "ambush_yaw" },
    { 0x12A4, "ambush1_cleanup" },
    { 0x12A5, "ambush1_emergency_lights_on" },
    { 0x12A6, "ambush1_lights_off" },
    { 0x12A7, "ambush1_lights_on" },
    { 0x12A8, "ambush1_logic" },
    { 0x12A9, "ambusher_can_be_shot" },
    { 0x12AA, "ammo" },
    { 0x12AB, "ammo_autorefill" },
    { 0x12AC, "ammo_box_lids" },
    { 0x12AD, "ammo_count" },
    { 0x12AE, "ammo_crate_init" },
    { 0x12AF, "ammo_round_up" },
    { 0x12B0, "ammobox_addboxweapon" },
    { 0x12B1, "ammobox_addheadicon" },
    { 0x12B2, "ammobox_bulletdamagetohits" },
    { 0x12B3, "ammobox_clearbufferedweapon" },
    { 0x12B4, "ammobox_delete" },
    { 0x12B5, "ammobox_destroy" },
    { 0x12B6, "ammobox_empapplied" },
    { 0x12B7, "ammobox_explode" },
    { 0x12B8, "ammobox_explosivedamagetohits" },
    { 0x12B9, "ammobox_fullrefill" },
    { 0x12BA, "ammobox_getbufferedplayerdata" },
    { 0x12BB, "ammobox_getbufferedweapon" },
    { 0x12BC, "ammobox_getrandomweapon" },
    { 0x12BD, "ammobox_givepointsfordeath" },
    { 0x12BE, "ammobox_givexpforuse" },
    { 0x12BF, "ammobox_handledamage" },
    { 0x12C0, "ammobox_handlefataldamage" },
    { 0x12C1, "ammobox_handlemovingplatforms" },
    { 0x12C2, "ammobox_init" },
    { 0x12C3, "ammobox_internalpreloadweapons" },
    { 0x12C4, "ammobox_isvalidrandomweapon" },
    { 0x12C5, "ammobox_makedamageable" },
    { 0x12C6, "ammobox_makeunusable" },
    { 0x12C7, "ammobox_makeusable" },
    { 0x12C8, "ammobox_objective_icon" },
    { 0x12C9, "ammobox_onmovingplatformdeath" },
    { 0x12CA, "ammobox_onplayeruse" },
    { 0x12CB, "ammobox_playercanuse" },
    { 0x12CC, "ammobox_preloadweapons" },
    { 0x12CD, "ammobox_removeheadicon" },
    { 0x12CE, "ammobox_removeowneroutline" },
    { 0x12CF, "ammobox_settled" },
    { 0x12D0, "ammobox_think" },
    { 0x12D1, "ammobox_unset" },
    { 0x12D2, "ammobox_updateplayersused" },
    { 0x12D3, "ammobox_updateplayerusevisibility" },
    { 0x12D4, "ammobox_usedcallback" },
    { 0x12D5, "ammobox_watchallplayeruse" },
    { 0x12D6, "ammobox_watchdisownedtimeout" },
    { 0x12D7, "ammobox_watchdisownedtimeoutinternal" },
    { 0x12D8, "ammobox_watchplayeruse" },
    { 0x12D9, "ammobox_watchplayeruseinternal" },
    { 0x12DA, "ammoboxes_init" },
    { 0x12DB, "ammoboxweapons" },
    { 0x12DC, "ammocheatinterval" },
    { 0x12DD, "ammocheattime" },
    { 0x12DE, "ammocount" },
    { 0x12DF, "ammodisabling_impair" },
    { 0x12E0, "ammodisabling_impairend" },
    { 0x12E1, "ammodisabling_run" },
    { 0x12E2, "ammoidmap" },
    { 0x12E3, "ammoincompatibleweaponslist" },
    { 0x12E4, "ammoitems" },
    { 0x12E5, "ammomax" },
    { 0x12E6, "ammorestock_playeruse" },
    { 0x12E7, "ammorestock_think" },
    { 0x12E8, "ammorestock_usecooldowncheck" },
    { 0x12E9, "ammorestocklocs" },
    { 0x12EA, "ammotrigger" },
    { 0x12EB, "ammount" },
    { 0x12EC, "amortizationstep" },
    { 0x12ED, "amortize" },
    { 0x12EE, "amortizeyawtraces" },
    { 0x12EF, "amount_to_compromise" },
    { 0x12F0, "amount_to_compromise_left" },
    { 0x12F1, "analytics" },
    { 0x12F2, "analytics_event" },
    { 0x12F3, "analytics_event_upload" },
    { 0x12F4, "analytics_fake_start_point" },
    { 0x12F5, "analytics_getmaxspawneventsforcurrentmode" },
    { 0x12F6, "analytics_kleenex_update" },
    { 0x12F7, "analytics_kleenex_upload" },
    { 0x12F8, "analytics_obj_failed" },
    { 0x12F9, "analytics_skip_start_point" },
    { 0x12FA, "analytics_storage" },
    { 0x12FB, "analytics_tracking_player_mount" },
    { 0x12FC, "analytics_upload_during_nextmission" },
    { 0x12FD, "analyticsactive" },
    { 0x12FE, "analyticsdoesspawndataexist" },
    { 0x12FF, "analyticsendgame" },
    { 0x1300, "analyticsinitspawndata" },
    { 0x1301, "analyticslog" },
    { 0x1302, "analyticslogenabled" },
    { 0x1303, "analyticslogid" },
    { 0x1304, "analyticslogtype" },
    { 0x1305, "analyticssend_shouldsenddata" },
    { 0x1306, "analyticssend_spawnfactors" },
    { 0x1307, "analyticssend_spawnplayerdetails" },
    { 0x1308, "analyticssend_spawntype" },
    { 0x1309, "analyticsspawnlogenabled" },
    { 0x130A, "analyticsstorespawndata" },
    { 0x130B, "analyticsthread" },
    { 0x130C, "anchor" },
    { 0x130D, "anchordir" },
    { 0x130E, "anchorentity" },
    { 0x130F, "anchorrt" },
    { 0x1310, "angle" },
    { 0x1311, "angle_diff" },
    { 0x1312, "angle_lerp" },
    { 0x1313, "angle_offset" },
    { 0x1314, "angle_ref" },
    { 0x1315, "anglealongpath" },
    { 0x1316, "anglebetweenvectors" },
    { 0x1317, "anglebetweenvectorsrounded" },
    { 0x1318, "anglebetweenvectorssigned" },
    { 0x1319, "anglebetweenvectorsunit" },
    { 0x131A, "anglediffwalkandtalk" },
    { 0x131B, "anglemortar" },
    { 0x131C, "angleoffset" },
    { 0x131D, "angles_debug" },
    { 0x131E, "anglesclamp180" },
    { 0x131F, "anglesclamp180_lerp" },
    { 0x1320, "anim_addmodel" },
    { 0x1321, "anim_aim" },
    { 0x1322, "anim_aim_and_reload" },
    { 0x1323, "anim_aim_end" },
    { 0x1324, "anim_aim_internal" },
    { 0x1325, "anim_aim_shoot" },
    { 0x1326, "anim_animationendnotify" },
    { 0x1327, "anim_array" },
    { 0x1328, "anim_at_entity" },
    { 0x1329, "anim_at_self" },
    { 0x132A, "anim_blend_time_override" },
    { 0x132B, "anim_block_in_cleanup_internal" },
    { 0x132C, "anim_block_in_internal" },
    { 0x132D, "anim_block_in_single" },
    { 0x132E, "anim_block_in_solo" },
    { 0x132F, "anim_branch" },
    { 0x1330, "anim_changes_pushplayer" },
    { 0x1331, "anim_check_loop" },
    { 0x1332, "anim_collision_check" },
    { 0x1333, "anim_custom_animmode" },
    { 0x1334, "anim_custom_animmode_loop" },
    { 0x1335, "anim_custom_animmode_loop_solo" },
    { 0x1336, "anim_custom_animmode_on_guy" },
    { 0x1337, "anim_custom_animmode_solo" },
    { 0x1338, "anim_deathnotify" },
    { 0x1339, "anim_dialogueendnotify" },
    { 0x133A, "anim_disablepain" },
    { 0x133B, "anim_dontpushplayer" },
    { 0x133C, "anim_door" },
    { 0x133D, "anim_door_then_loop" },
    { 0x133E, "anim_door_then_loop_stopper" },
    { 0x133F, "anim_earlyinit" },
    { 0x1340, "anim_end_early" },
    { 0x1341, "anim_ent_debug" },
    { 0x1342, "anim_facialanim" },
    { 0x1343, "anim_facialendnotify" },
    { 0x1344, "anim_facialfiller" },
    { 0x1345, "anim_first_frame" },
    { 0x1346, "anim_first_frame_door" },
    { 0x1347, "anim_first_frame_on_guy" },
    { 0x1348, "anim_first_frame_solo" },
    { 0x1349, "anim_fulton_ac130_scene" },
    { 0x134A, "anim_fulton_backpack_scene" },
    { 0x134B, "anim_fulton_balloon_show" },
    { 0x134C, "anim_fulton_exfil_player_scene" },
    { 0x134D, "anim_fulton_hostage_player_scene" },
    { 0x134E, "anim_fulton_linkedent_scene" },
    { 0x134F, "anim_gate_truck_lights" },
    { 0x1350, "anim_generic" },
    { 0x1351, "anim_generic_custom_animmode" },
    { 0x1352, "anim_generic_custom_animmode_loop" },
    { 0x1353, "anim_generic_first_frame" },
    { 0x1354, "anim_generic_gravity" },
    { 0x1355, "anim_generic_loop" },
    { 0x1356, "anim_generic_queue" },
    { 0x1357, "anim_generic_reach" },
    { 0x1358, "anim_generic_reach_and_arrive" },
    { 0x1359, "anim_generic_run" },
    { 0x135A, "anim_generic_teleport" },
    { 0x135B, "anim_get_goal_time" },
    { 0x135C, "anim_getrootfunc" },
    { 0x135D, "anim_gun_react" },
    { 0x135E, "anim_gun_react_and_idle" },
    { 0x135F, "anim_gunhand" },
    { 0x1360, "anim_guninhand" },
    { 0x1361, "anim_handle_notetrack" },
    { 0x1362, "anim_hold_last_frame_solo" },
    { 0x1363, "anim_hostage_fulton_start" },
    { 0x1364, "anim_hostage_idle" },
    { 0x1365, "anim_hostage_notetrack_handler" },
    { 0x1366, "anim_hostage_wait_release" },
    { 0x1367, "anim_info" },
    { 0x1368, "anim_init" },
    { 0x1369, "anim_init_exfil_fulton" },
    { 0x136A, "anim_init_hostage" },
    { 0x136B, "anim_init_trafficking" },
    { 0x136C, "anim_init_truck" },
    { 0x136D, "anim_is_death" },
    { 0x136E, "anim_last_frame_door" },
    { 0x136F, "anim_last_frame_solo" },
    { 0x1370, "anim_lerp_from_player_pos" },
    { 0x1371, "anim_link_tag_model" },
    { 0x1372, "anim_long_death" },
    { 0x1373, "anim_long_death_relative" },
    { 0x1374, "anim_loop" },
    { 0x1375, "anim_loop_door" },
    { 0x1376, "anim_loop_door_stop" },
    { 0x1377, "anim_loop_packet" },
    { 0x1378, "anim_loop_packet_solo" },
    { 0x1379, "anim_loop_solo" },
    { 0x137A, "anim_loop_solo_with_nags" },
    { 0x137B, "anim_loop_with_props" },
    { 0x137C, "anim_model" },
    { 0x137D, "anim_moveto" },
    { 0x137E, "anim_name" },
    { 0x137F, "anim_node" },
    { 0x1380, "anim_origin" },
    { 0x1381, "anim_player" },
    { 0x1382, "anim_player_internal" },
    { 0x1383, "anim_player_solo" },
    { 0x1384, "anim_playsound_func" },
    { 0x1385, "anim_playvm_func" },
    { 0x1386, "anim_playvo_func" },
    { 0x1387, "anim_pos" },
    { 0x1388, "anim_prop_models" },
    { 0x1389, "anim_pushplayer" },
    { 0x138A, "anim_rate_watcher" },
    { 0x138B, "anim_reach" },
    { 0x138C, "anim_reach_and_approach" },
    { 0x138D, "anim_reach_and_approach_node_solo" },
    { 0x138E, "anim_reach_and_approach_solo" },
    { 0x138F, "anim_reach_and_arrive" },
    { 0x1390, "anim_reach_and_idle" },
    { 0x1391, "anim_reach_and_idle_solo" },
    { 0x1392, "anim_reach_and_loop_solo" },
    { 0x1393, "anim_reach_and_plant" },
    { 0x1394, "anim_reach_and_plant_and_arrive" },
    { 0x1395, "anim_reach_arrive_idle" },
    { 0x1396, "anim_reach_cleanup_solo" },
    { 0x1397, "anim_reach_failsafe" },
    { 0x1398, "anim_reach_failsafe_go" },
    { 0x1399, "anim_reach_idle" },
    { 0x139A, "anim_reach_safe" },
    { 0x139B, "anim_reach_solo" },
    { 0x139C, "anim_reach_solo_skip_check" },
    { 0x139D, "anim_reach_solo_skip_offscreen" },
    { 0x139E, "anim_reach_together" },
    { 0x139F, "anim_reach_watcher" },
    { 0x13A0, "anim_reach_with_funcs" },
    { 0x13A1, "anim_react" },
    { 0x13A2, "anim_react_add_to_alertgroup" },
    { 0x13A3, "anim_react_ai_events" },
    { 0x13A4, "anim_react_alertgroup_msg" },
    { 0x13A5, "anim_react_damage" },
    { 0x13A6, "anim_react_data" },
    { 0x13A7, "anim_react_death" },
    { 0x13A8, "anim_react_event" },
    { 0x13A9, "anim_react_new" },
    { 0x13AA, "anim_react_radius" },
    { 0x13AB, "anim_react_skip_stopanimscripted" },
    { 0x13AC, "anim_react_thread" },
    { 0x13AD, "anim_react_wait_thread" },
    { 0x13AE, "anim_react_waittill" },
    { 0x13AF, "anim_relative" },
    { 0x13B0, "anim_removemodel" },
    { 0x13B1, "anim_scene" },
    { 0x13B2, "anim_scene_create_actor" },
    { 0x13B3, "anim_scene_loop" },
    { 0x13B4, "anim_scene_set_actor_interruptable" },
    { 0x13B5, "anim_scene_stop" },
    { 0x13B6, "anim_scene_stop_actor" },
    { 0x13B7, "anim_scriptable" },
    { 0x13B8, "anim_self_set_time" },
    { 0x13B9, "anim_sequence" },
    { 0x13BA, "anim_sequential_counter" },
    { 0x13BB, "anim_set_rate" },
    { 0x13BC, "anim_set_rate_internal" },
    { 0x13BD, "anim_set_rate_single" },
    { 0x13BE, "anim_set_time" },
    { 0x13BF, "anim_set_time_solo" },
    { 0x13C0, "anim_single" },
    { 0x13C1, "anim_single_and_idle" },
    { 0x13C2, "anim_single_and_loop" },
    { 0x13C3, "anim_single_and_loop_solo" },
    { 0x13C4, "anim_single_failsafe" },
    { 0x13C5, "anim_single_failsafeonguy" },
    { 0x13C6, "anim_single_gravity" },
    { 0x13C7, "anim_single_internal" },
    { 0x13C8, "anim_single_queue" },
    { 0x13C9, "anim_single_run" },
    { 0x13CA, "anim_single_solo" },
    { 0x13CB, "anim_single_solo_end_notify" },
    { 0x13CC, "anim_single_solo_run" },
    { 0x13CD, "anim_single_solo_scriptable" },
    { 0x13CE, "anim_single_then_last" },
    { 0x13CF, "anim_single_then_loop" },
    { 0x13D0, "anim_single_then_loop_ent" },
    { 0x13D1, "anim_single_then_loop_solo" },
    { 0x13D2, "anim_single_with_props" },
    { 0x13D3, "anim_smartdialog_func" },
    { 0x13D4, "anim_spawn_generic_model" },
    { 0x13D5, "anim_spawn_model" },
    { 0x13D6, "anim_spawn_tag_model" },
    { 0x13D7, "anim_spawner_teleport" },
    { 0x13D8, "anim_start_at_groundpos" },
    { 0x13D9, "anim_start_delay" },
    { 0x13DA, "anim_start_pct" },
    { 0x13DB, "anim_start_pos" },
    { 0x13DC, "anim_start_pos_solo" },
    { 0x13DD, "anim_stopanimscripted" },
    { 0x13DE, "anim_struct" },
    { 0x13DF, "anim_structs" },
    { 0x13E0, "anim_teleport" },
    { 0x13E1, "anim_teleport_solo" },
    { 0x13E2, "anim_test" },
    { 0x13E3, "anim_then_last_frame_and_kill" },
    { 0x13E4, "anim_then_loop" },
    { 0x13E5, "anim_then_loop_solo" },
    { 0x13E6, "anim_then_loopender_thread" },
    { 0x13E7, "anim_time" },
    { 0x13E8, "anim_touch_react_and_idle" },
    { 0x13E9, "anim_trafficking_play_scene_informant" },
    { 0x13EA, "anim_trafficking_play_scene_soldier" },
    { 0x13EB, "anim_trafficking_soldier_play" },
    { 0x13EC, "anim_wait_for_ent_flag" },
    { 0x13ED, "anim_wait_func" },
    { 0x13EE, "anim_weapon_for_player" },
    { 0x13EF, "anim_weight" },
    { 0x13F0, "animalias" },
    { 0x13F1, "animang" },
    { 0x13F2, "animarchetype" },
    { 0x13F3, "animarms" },
    { 0x13F4, "animarray" },
    { 0x13F5, "animarrayanyexist" },
    { 0x13F6, "animarraypickrandom" },
    { 0x13F7, "animate_2f_extras" },
    { 0x13F8, "animate_drive_idle" },
    { 0x13F9, "animate_guys" },
    { 0x13FA, "animated_passanger_logic" },
    { 0x13FB, "animated_prop" },
    { 0x13FC, "animated_van_scene" },
    { 0x13FD, "animatedmask" },
    { 0x13FE, "animatemodel" },
    { 0x13FF, "animatemoveintoplace" },
    { 0x1400, "animatescreeneffect" },
    { 0x1401, "animation" },
    { 0x1402, "animation_exists" },
    { 0x1403, "animation_getloopanimationentity" },
    { 0x1404, "animation_idle" },
    { 0x1405, "animation_loop" },
    { 0x1406, "animation_notifyonnotetrack" },
    { 0x1407, "animation_reach" },
    { 0x1408, "animation_reachintofirstframe" },
    { 0x1409, "animation_reachtoidle" },
    { 0x140A, "animation_reachtosingle" },
    { 0x140B, "animation_reachtosingleintoidle" },
    { 0x140C, "animation_reachtosingleintolastframe" },
    { 0x140D, "animation_reachtosingleintoloop" },
    { 0x140E, "animation_single" },
    { 0x140F, "animation_single_then_loop" },
    { 0x1410, "animation_singleintoidle" },
    { 0x1411, "animation_singleintoidleproc" },
    { 0x1412, "animation_singleintolastframe" },
    { 0x1413, "animation_singleintolastframeproc" },
    { 0x1414, "animation_singleintoloop" },
    { 0x1415, "animation_singleintoloopproc" },
    { 0x1416, "animation_stoploop" },
    { 0x1417, "animation_stopreach" },
    { 0x1418, "animation_waittillend" },
    { 0x1419, "animation_waittillnotetrack" },
    { 0x141A, "animationarchetype" },
    { 0x141B, "animationorigin" },
    { 0x141C, "animationsuite" },
    { 0x141D, "animcustomender" },
    { 0x141E, "animdroptime" },
    { 0x141F, "animduration" },
    { 0x1420, "anime" },
    { 0x1421, "animendtime" },
    { 0x1422, "animents" },
    { 0x1423, "animeshotdir" },
    { 0x1424, "animflagnameindex" },
    { 0x1425, "animfrac_min" },
    { 0x1426, "animgenericcustomanimmode" },
    { 0x1427, "animhasfacialoverride" },
    { 0x1428, "animindex" },
    { 0x1429, "animlength" },
    { 0x142A, "animlist" },
    { 0x142B, "animloop_headlook" },
    { 0x142C, "animname" },
    { 0x142D, "animname_incrementer" },
    { 0x142E, "animnode" },
    { 0x142F, "animnodes" },
    { 0x1430, "animontag" },
    { 0x1431, "animontag_ragdoll_death" },
    { 0x1432, "animontag_ragdoll_death_fall" },
    { 0x1433, "animorg" },
    { 0x1434, "animoverrides" },
    { 0x1435, "animplaybackrate" },
    { 0x1436, "animpriority" },
    { 0x1437, "animratefrac" },
    { 0x1438, "animreactpain" },
    { 0x1439, "animreactrelative" },
    { 0x143A, "animrig" },
    { 0x143B, "animrope" },
    { 0x143C, "animropethrow" },
    { 0x143D, "animscriptdonotetracksthread" },
    { 0x143E, "animscriptedaction" },
    { 0x143F, "animscriptedaction_cleanup" },
    { 0x1440, "animscriptedaction_terminate" },
    { 0x1441, "animscriptedcleanup" },
    { 0x1442, "animscriptedstartup" },
    { 0x1443, "animscriptmp" },
    { 0x1444, "animscriptmp_internal" },
    { 0x1445, "animscriptmp_loop_internal" },
    { 0x1446, "animscriptmp_single_internal" },
    { 0x1447, "animscriptmp_watchcancel" },
    { 0x1448, "animsdirectionalhit" },
    { 0x1449, "animsdirectionalscrub" },
    { 0x144A, "animselector" },
    { 0x144B, "animselectorfeaturetable" },
    { 0x144C, "animsequence" },
    { 0x144D, "animset" },
    { 0x144E, "animsets" },
    { 0x144F, "animsound_aliases" },
    { 0x1450, "animsound_exists" },
    { 0x1451, "animsound_hudlimit" },
    { 0x1452, "animsound_start_tracker" },
    { 0x1453, "animsound_start_tracker_loop" },
    { 0x1454, "animsound_tagged" },
    { 0x1455, "animsound_tracker" },
    { 0x1456, "animsounds" },
    { 0x1457, "animsriptedactioncivilian_terminate" },
    { 0x1458, "animstatename" },
    { 0x1459, "animstoptrailtime" },
    { 0x145A, "animstruct" },
    { 0x145B, "animsuite_getparentobject" },
    { 0x145C, "animsuite_linkchildrentoparentobject" },
    { 0x145D, "animsuite_playthreadedsound" },
    { 0x145E, "animsuite_rotation" },
    { 0x145F, "animsuite_rotation_continuous" },
    { 0x1460, "animsuite_rotation_pingpong" },
    { 0x1461, "animsuite_translation" },
    { 0x1462, "animsuite_translation_once" },
    { 0x1463, "animsuite_translation_pingpong" },
    { 0x1464, "animtag" },
    { 0x1465, "animtree" },
    { 0x1466, "animunhidetime" },
    { 0x1467, "animweapon" },
    { 0x1468, "announce_spotted_acknowledge" },
    { 0x1469, "announceinfilwinner" },
    { 0x146A, "announcer_vo_playing" },
    { 0x146B, "antepenultimate_struct" },
    { 0x146C, "antigrav" },
    { 0x146D, "antigrav_clear_float_ai_override" },
    { 0x146E, "antigrav_disable_nav_obstacle_for_team" },
    { 0x146F, "antigrav_float_ai_override" },
    { 0x1470, "antigrav_float_time_done" },
    { 0x1471, "antigravgrenstate" },
    { 0x1472, "antigravtag" },
    { 0x1473, "antithreat" },
    { 0x1474, "any_ai_around_player" },
    { 0x1475, "any_alive" },
    { 0x1476, "any_button_hit" },
    { 0x1477, "any_groups_in_combat" },
    { 0x1478, "any_ied_left_unidentified_in_zone" },
    { 0x1479, "any_input" },
    { 0x147A, "any_player_nearby" },
    { 0x147B, "any_player_under_bridge" },
    { 0x147C, "any_player_within_range" },
    { 0x147D, "any_soldiers_nearby" },
    { 0x147E, "any_vehicle_within_range" },
    { 0x147F, "anyambulancesavailable" },
    { 0x1480, "anyarmdismembered" },
    { 0x1481, "anylegdismembered" },
    { 0x1482, "anyone_can_see" },
    { 0x1483, "anyone_has_known_player_since_time" },
    { 0x1484, "anyone_in_combat" },
    { 0x1485, "anyone_in_hunt" },
    { 0x1486, "anyplayersinkillcam" },
    { 0x1487, "aoe_instant_revive" },
    { 0x1488, "aon_loadouts" },
    { 0x1489, "aonallperks" },
    { 0x148A, "aonperkkillcount" },
    { 0x148B, "aonrules" },
    { 0x148C, "ap" },
    { 0x148D, "ap_bpg_md" },
    { 0x148E, "ap_bpg_scene" },
    { 0x148F, "ap_breach" },
    { 0x1490, "ap_cctv" },
    { 0x1491, "ap_combat_intro" },
    { 0x1492, "ap_gar_meetup" },
    { 0x1493, "ap_gate_overrun" },
    { 0x1494, "ap_infil_crash" },
    { 0x1495, "ap_offices_chaos" },
    { 0x1496, "ap_overlook_reveal" },
    { 0x1497, "ap_patrol" },
    { 0x1498, "ap_power_lever" },
    { 0x1499, "ap_residence" },
    { 0x149A, "ap_saferoom" },
    { 0x149B, "ap_stairwell_door" },
    { 0x149C, "ap_stairwell_door_nag_vo" },
    { 0x149D, "ap_truck_office" },
    { 0x149E, "ap_wolf_escort" },
    { 0x149F, "apache_activate_function" },
    { 0x14A0, "apache_damage_vision" },
    { 0x14A1, "apache_damage_watcher" },
    { 0x14A2, "apache_death_watcher" },
    { 0x14A3, "apache_dof_watcher" },
    { 0x14A4, "apache_fire_vo" },
    { 0x14A5, "apache_freefall" },
    { 0x14A6, "apache_hints" },
    { 0x14A7, "apache_killconfirm_vo" },
    { 0x14A8, "apache_missile_fire_vo" },
    { 0x14A9, "apache_modify_damage" },
    { 0x14AA, "apache_reloading_vo" },
    { 0x14AB, "apache_start_moving_nags" },
    { 0x14AC, "apache_thermalshellshock" },
    { 0x14AD, "apache_vehiclekillconfirm_vo" },
    { 0x14AE, "apachee_pilot" },
    { 0x14AF, "apachepoints" },
    { 0x14B0, "apartment_catchup" },
    { 0x14B1, "apartment_check_if_grenade_explodes_in_apt" },
    { 0x14B2, "apartment_check_if_grenade_goes_out_window" },
    { 0x14B3, "apartment_check_if_grenade_kills_civilian" },
    { 0x14B4, "apartment_containment" },
    { 0x14B5, "apartment_dead_bodies" },
    { 0x14B6, "apartment_destruction_grenade_effects" },
    { 0x14B7, "apartment_dying_crawl_civ" },
    { 0x14B8, "apartment_dying_crawl_civ_kill" },
    { 0x14B9, "apartment_enforcer_enter_apt" },
    { 0x14BA, "apartment_enforcer_glass_break" },
    { 0x14BB, "apartment_enforcer_grenade" },
    { 0x14BC, "apartment_enforcer_grenade_throw" },
    { 0x14BD, "apartment_enforcer_movement_handler" },
    { 0x14BE, "apartment_grenade_door_handler" },
    { 0x14BF, "apartment_handsup_civ" },
    { 0x14C0, "apartment_handsup_civ_mb" },
    { 0x14C1, "apartment_init" },
    { 0x14C2, "apartment_main" },
    { 0x14C3, "apartment_player_grenade_effects" },
    { 0x14C4, "apartment_price_handler" },
    { 0x14C5, "apartment_pursuit_timer_handler" },
    { 0x14C6, "apartment_start" },
    { 0x14C7, "apartment_stp_main" },
    { 0x14C8, "apartment_toggle_containment" },
    { 0x14C9, "apc" },
    { 0x14CA, "apc_1_sound_ent" },
    { 0x14CB, "apc_attack_target_until_closer_threat" },
    { 0x14CC, "apc_bravo_sounds_start" },
    { 0x14CD, "apc_cleanup_handler" },
    { 0x14CE, "apc_destroyed" },
    { 0x14CF, "apc_disable_turret" },
    { 0x14D0, "apc_exit_cops_sequence" },
    { 0x14D1, "apc_exit_counter" },
    { 0x14D2, "apc_exit_sequence" },
    { 0x14D3, "apc_exit_thread" },
    { 0x14D4, "apc_exit_vo" },
    { 0x14D5, "apc_fire_main_cannon" },
    { 0x14D6, "apc_hurttarget" },
    { 0x14D7, "apc_intro_sounds_start" },
    { 0x14D8, "apc_intro_vo" },
    { 0x14D9, "apc_lerp_fov" },
    { 0x14DA, "apc_main" },
    { 0x14DB, "apc_player_detector_monitor" },
    { 0x14DC, "apc_player_detector_volume_handler" },
    { 0x14DD, "apc_rus_cp_create" },
    { 0x14DE, "apc_rus_cp_createfromstructs" },
    { 0x14DF, "apc_rus_cp_delete" },
    { 0x14E0, "apc_rus_cp_getspawnstructscallback" },
    { 0x14E1, "apc_rus_cp_init" },
    { 0x14E2, "apc_rus_cp_initlate" },
    { 0x14E3, "apc_rus_cp_initspawning" },
    { 0x14E4, "apc_rus_cp_ondeathrespawncallback" },
    { 0x14E5, "apc_rus_cp_spawncallback" },
    { 0x14E6, "apc_rus_cp_waitandspawn" },
    { 0x14E7, "apc_rus_create" },
    { 0x14E8, "apc_rus_createturret" },
    { 0x14E9, "apc_rus_deathcallback" },
    { 0x14EA, "apc_rus_deletenextframe" },
    { 0x14EB, "apc_rus_enterend" },
    { 0x14EC, "apc_rus_enterendinternal" },
    { 0x14ED, "apc_rus_enterstart" },
    { 0x14EE, "apc_rus_exitend" },
    { 0x14EF, "apc_rus_exitendinternal" },
    { 0x14F0, "apc_rus_explode" },
    { 0x14F1, "apc_rus_getspawnstructscallback" },
    { 0x14F2, "apc_rus_init" },
    { 0x14F3, "apc_rus_initfx" },
    { 0x14F4, "apc_rus_initinteract" },
    { 0x14F5, "apc_rus_initlate" },
    { 0x14F6, "apc_rus_initoccupancy" },
    { 0x14F7, "apc_rus_initspawning" },
    { 0x14F8, "apc_rus_monitor" },
    { 0x14F9, "apc_rus_mp_create" },
    { 0x14FA, "apc_rus_mp_delete" },
    { 0x14FB, "apc_rus_mp_getspawnstructscallback" },
    { 0x14FC, "apc_rus_mp_init" },
    { 0x14FD, "apc_rus_mp_initmines" },
    { 0x14FE, "apc_rus_mp_initspawning" },
    { 0x14FF, "apc_rus_mp_ondeathrespawncallback" },
    { 0x1500, "apc_rus_mp_spawncallback" },
    { 0x1501, "apc_rus_mp_waitandspawn" },
    { 0x1502, "apc_rus_premoddamagecallback" },
    { 0x1503, "apc_rus_updatechassisanglesui" },
    { 0x1504, "apc_rus_updateomnvarsonseatenter" },
    { 0x1505, "apc_shoot_logic" },
    { 0x1506, "apc_should_attack_player" },
    { 0x1507, "apc_start" },
    { 0x1508, "apc_target_updater" },
    { 0x1509, "apc_turret_behavior" },
    { 0x150A, "apc_turret_scanning_behavior" },
    { 0x150B, "apcsrus" },
    { 0x150C, "apcstart" },
    { 0x150D, "apcstop" },
    { 0x150E, "apcwid" },
    { 0x150F, "aperturespeed" },
    { 0x1510, "apex_delta" },
    { 0x1511, "apex_delta_local" },
    { 0x1512, "aplanted" },
    { 0x1513, "apply_and_remove_attention_flag" },
    { 0x1514, "apply_apc_soldier_settings" },
    { 0x1515, "apply_crit_effects" },
    { 0x1516, "apply_difficulty_settings" },
    { 0x1517, "apply_difficulty_settings_shared" },
    { 0x1518, "apply_emp" },
    { 0x1519, "apply_emp_struct" },
    { 0x151A, "apply_friendly_fire_damage_modifier" },
    { 0x151B, "apply_func_to_all_in_group" },
    { 0x151C, "apply_juggernaut_part_damage" },
    { 0x151D, "apply_option_to_selected_fx" },
    { 0x151E, "apply_reverb" },
    { 0x151F, "apply_truck_dmg" },
    { 0x1520, "applyaccoladestructtoplayerpers" },
    { 0x1521, "applyarchetype" },
    { 0x1522, "applybombcarrierclass" },
    { 0x1523, "applybombstoplayers" },
    { 0x1524, "applycaptureprogress" },
    { 0x1525, "applycaptureprogressanduseupdate" },
    { 0x1526, "applyconcussion" },
    { 0x1527, "applyempshellshock" },
    { 0x1528, "applyempshellshockvisionset" },
    { 0x1529, "applyflagcarrierclass" },
    { 0x152A, "applyflash" },
    { 0x152B, "applyflashfromdamage" },
    { 0x152C, "applyfovpresentation" },
    { 0x152D, "applygamemodecallout" },
    { 0x152E, "applygasdamageovertime" },
    { 0x152F, "applygaseffect" },
    { 0x1530, "applyinteractteam" },
    { 0x1531, "applykillstreakplayeroutline" },
    { 0x1532, "applymapenableonspawn" },
    { 0x1533, "applymapvisionset" },
    { 0x1534, "applynvgforrevive" },
    { 0x1535, "applyoffset" },
    { 0x1536, "applyoutlinecalloutsource" },
    { 0x1537, "applyparentstructvalues" },
    { 0x1538, "applyperkomnvars" },
    { 0x1539, "applyplayercontrolonconnect" },
    { 0x153A, "applyradiusdamageasmelee" },
    { 0x153B, "applyshrapnelfx" },
    { 0x153C, "applyshrapnelfxinternal" },
    { 0x153D, "applyshutdownonspawn" },
    { 0x153E, "applyspawnprotection" },
    { 0x153F, "applystoppingpower" },
    { 0x1540, "applystunresistence" },
    { 0x1541, "applythermal" },
    { 0x1542, "applytimervisibleteam" },
    { 0x1543, "applyuavshellshock" },
    { 0x1544, "applyuavshellshockvisionset" },
    { 0x1545, "applyweaponchange" },
    { 0x1546, "applyweaponsonicstun" },
    { 0x1547, "applyzombiescriptablestate" },
    { 0x1548, "apprehension_init" },
    { 0x1549, "apprehension_interaction" },
    { 0x154A, "approach_1f_civ_vo" },
    { 0x154B, "approach_building_wait" },
    { 0x154C, "approach_fd_and_idle" },
    { 0x154D, "approach_types" },
    { 0x154E, "approachdir" },
    { 0x154F, "approx_location" },
    { 0x1550, "apt_grenade" },
    { 0x1551, "apt_hallway_door_setup" },
    { 0x1552, "aptenforcerfakefire" },
    { 0x1553, "aptenforcergrenade" },
    { 0x1554, "aptstairblockers" },
    { 0x1555, "aq_boy_1" },
    { 0x1556, "aq_chatter" },
    { 0x1557, "aq_enforcer" },
    { 0x1558, "aq_enforcer_entourage" },
    { 0x1559, "aq_female_1" },
    { 0x155A, "aq_hall_blind_corner_shooter" },
    { 0x155B, "aq_hall_cover_move" },
    { 0x155C, "aq_hospital_hall_left_flank_ambusher" },
    { 0x155D, "aq_hospital_hall_left_side" },
    { 0x155E, "aq_hospital_hall_right_side" },
    { 0x155F, "aq_hospital_stairwell" },
    { 0x1560, "aq_hudenabled" },
    { 0x1561, "aq_hunter_bounty_hud" },
    { 0x1562, "aq_hunter_target_hud" },
    { 0x1563, "aq_initquest" },
    { 0x1564, "aq_killer_tag_taken" },
    { 0x1565, "aq_lobby_breach_spawners" },
    { 0x1566, "aq_override_ar_lasersight" },
    { 0x1567, "aq_override_pistol_silenced" },
    { 0x1568, "aq_playerdied" },
    { 0x1569, "aq_questthink" },
    { 0x156A, "aq_questthink_circleposition" },
    { 0x156B, "aq_questthink_objectivevisibility" },
    { 0x156C, "aq_removequestinstance" },
    { 0x156D, "aq_removequestthread" },
    { 0x156E, "aq_run_behind_truck" },
    { 0x156F, "aq_soldier_1" },
    { 0x1570, "aq_soldier_2" },
    { 0x1571, "aq_soldier_3" },
    { 0x1572, "aq_soldier_dialog_struct" },
    { 0x1573, "aq_target_hud" },
    { 0x1574, "aq_technical_1_sound" },
    { 0x1575, "aq_technical_2_sound" },
    { 0x1576, "aq_technical_spawners" },
    { 0x1577, "aq_technical_unload_watcher" },
    { 0x1578, "aq1" },
    { 0x1579, "aquireplayertime" },
    { 0x157A, "ar_callout_ent" },
    { 0x157B, "arbitraryuptriggers" },
    { 0x157C, "arbitraryuptriggersstructs" },
    { 0x157D, "arbitraryuptriggerstruct" },
    { 0x157E, "arcade_games_progress" },
    { 0x157F, "arcade_last_stand_power_func" },
    { 0x1580, "archetype" },
    { 0x1581, "archetype_exists" },
    { 0x1582, "archetype_selection_monitor" },
    { 0x1583, "archetypeexists" },
    { 0x1584, "archetypeids" },
    { 0x1585, "archetypeoverridepriorities" },
    { 0x1586, "archetypeoverrides" },
    { 0x1587, "archetypepriority" },
    { 0x1588, "archetypes" },
    { 0x1589, "archivecurrentgamestate" },
    { 0x158A, "archiveplaybackcleanup" },
    { 0x158B, "archiverequesthelper" },
    { 0x158C, "arclimits" },
    { 0x158D, "are_all_players_nearby" },
    { 0x158E, "are_all_players_on_watchtower" },
    { 0x158F, "are_any_consumables_active" },
    { 0x1590, "are_enemies_nearby" },
    { 0x1591, "are_part_of_same_landmark" },
    { 0x1592, "are_weapons_free" },
    { 0x1593, "area" },
    { 0x1594, "area_gone_hot_think" },
    { 0x1595, "area_marker_add" },
    { 0x1596, "area_marker_remove" },
    { 0x1597, "areacounter" },
    { 0x1598, "areaidmap" },
    { 0x1599, "areallmerittierscomplete" },
    { 0x159A, "areatriggers" },
    { 0x159B, "arefieldupgradesallowed" },
    { 0x159C, "arefriendliesnear" },
    { 0x159D, "areinteractionsenabled" },
    { 0x159E, "arekillcamsenabled" },
    { 0x159F, "arekillstreaksallowed" },
    { 0x15A0, "arekillstreaksequipped" },
    { 0x15A1, "arematchstatsenabled" },
    { 0x15A2, "arena" },
    { 0x15A3, "arena_endgame" },
    { 0x15A4, "arena_loadouts" },
    { 0x15A5, "arenadamage" },
    { 0x15A6, "arenaflag" },
    { 0x15A7, "arenaflag_oncontested" },
    { 0x15A8, "arenaflag_onuse" },
    { 0x15A9, "arenaflag_onusebegin" },
    { 0x15AA, "arenaflag_onuseend" },
    { 0x15AB, "arenaflag_onuseupdate" },
    { 0x15AC, "arenaintroalliesplayers" },
    { 0x15AD, "arenaintroaxisplayers" },
    { 0x15AE, "arenaloadouts" },
    { 0x15AF, "arenaloadouts_getweapongroup" },
    { 0x15B0, "arenaloadouts_removeclass" },
    { 0x15B1, "arenaloadouts_select" },
    { 0x15B2, "arenamap" },
    { 0x15B3, "arenaplayers" },
    { 0x15B4, "arenas" },
    { 0x15B5, "arenaspawncounter" },
    { 0x15B6, "arenaweapont1" },
    { 0x15B7, "arenaweapont2" },
    { 0x15B8, "arenaweapont3" },
    { 0x15B9, "arenaweapont4" },
    { 0x15BA, "arenaweapont5" },
    { 0x15BB, "arenaweapont6" },
    { 0x15BC, "arenaweapont7" },
    { 0x15BD, "arenaweapont8" },
    { 0x15BE, "arenextpathsinsafebounds" },
    { 0x15BF, "areplayersnearspawnarea" },
    { 0x15C0, "areplayerstatsenabled" },
    { 0x15C1, "areplayerstatsreadonly" },
    { 0x15C2, "arespawnviewersvalid" },
    { 0x15C3, "aretagsenabled" },
    { 0x15C4, "aretrucksvalid" },
    { 0x15C5, "arevehiclesenabled" },
    { 0x15C6, "arm" },
    { 0x15C7, "arm_initoutofbounds" },
    { 0x15C8, "arm_leaderdialogonplayer_internal" },
    { 0x15C9, "arm_player" },
    { 0x15CA, "arm_playstatusdialog" },
    { 0x15CB, "arm_playstatusdialogonplayer" },
    { 0x15CC, "armageddon_hint_displayed" },
    { 0x15CD, "armcapturestrings" },
    { 0x15CE, "armcrateactivatecallback" },
    { 0x15CF, "armcratecapturecallback" },
    { 0x15D0, "armdefconlevels" },
    { 0x15D1, "armen" },
    { 0x15D2, "armexfilcount" },
    { 0x15D3, "armingdelay" },
    { 0x15D4, "armnuketimer" },
    { 0x15D5, "armor" },
    { 0x15D6, "armor_achievementlogic" },
    { 0x15D7, "armor_audiologic" },
    { 0x15D8, "armor_clearvehiclessmokegrenades" },
    { 0x15D9, "armor_crate_init" },
    { 0x15DA, "armor_dialogicfeedbacklogic" },
    { 0x15DB, "armor_dialoguelogic" },
    { 0x15DC, "armor_disabled_vfx_loop" },
    { 0x15DD, "armor_getvehicles" },
    { 0x15DE, "armor_main" },
    { 0x15DF, "armor_meter_monitor" },
    { 0x15E0, "armor_notifylevelonvehicleendpath" },
    { 0x15E1, "armor_objectivelogic" },
    { 0x15E2, "armor_resistance_to_type" },
    { 0x15E3, "armor_spawnvehicles" },
    { 0x15E4, "armor_start" },
    { 0x15E5, "armor_vehicleenemieslogic" },
    { 0x15E6, "armor_vehicleinitialsmokegrenadeslogic" },
    { 0x15E7, "armor_vehiclelogic" },
    { 0x15E8, "armor_vehiclespottedlogic" },
    { 0x15E9, "armor_vehiclespottedspeedlogic" },
    { 0x15EA, "armor_vehiclesstoppedautosave" },
    { 0x15EB, "armor_vehicletireaudiologic" },
    { 0x15EC, "armor_vest_hint_func" },
    { 0x15ED, "armoramount" },
    { 0x15EE, "armorbox_canusedeployable" },
    { 0x15EF, "armorbox_onusedeployable" },
    { 0x15F0, "armorbreak" },
    { 0x15F1, "armorbroke" },
    { 0x15F2, "armorcancelnotifywait" },
    { 0x15F3, "armordamagehints" },
    { 0x15F4, "armordamagetohealthratiomax" },
    { 0x15F5, "armordamagetohealthratiomin" },
    { 0x15F6, "armordistanceratio" },
    { 0x15F7, "armordroptimer" },
    { 0x15F8, "armorhealth" },
    { 0x15F9, "armorhealthratio" },
    { 0x15FA, "armorinit" },
    { 0x15FB, "armorinventoryratio" },
    { 0x15FC, "armormaxprobability" },
    { 0x15FD, "armormitigation" },
    { 0x15FE, "armormod" },
    { 0x15FF, "armornoui" },
    { 0x1600, "armoronweaponswitchlongpress" },
    { 0x1601, "armorpiercingmod" },
    { 0x1602, "armorpiercingmodks" },
    { 0x1603, "armorplateinsertion" },
    { 0x1604, "armorplates" },
    { 0x1605, "armorprotectsdamagetype" },
    { 0x1606, "armorratio" },
    { 0x1607, "armorratiohealthregenthreshold" },
    { 0x1608, "armorratioinverse" },
    { 0x1609, "armortoggleui" },
    { 0x160A, "armorvest_clearbroke" },
    { 0x160B, "armorvest_clearhit" },
    { 0x160C, "armorvest_setbroke" },
    { 0x160D, "armorvest_sethit" },
    { 0x160E, "armorvest_wasbroke" },
    { 0x160F, "armorvest_washit" },
    { 0x1610, "armorvestbulletdelta" },
    { 0x1611, "armorvestcancelblendcontrols" },
    { 0x1612, "armory_01" },
    { 0x1613, "armory_01_anim_start" },
    { 0x1614, "armory_01_catchup" },
    { 0x1615, "armory_01_main" },
    { 0x1616, "armory_01_nag" },
    { 0x1617, "armory_01_start" },
    { 0x1618, "armory_02" },
    { 0x1619, "armory_02_door" },
    { 0x161A, "armory_02_guards_vo" },
    { 0x161B, "armory_02_main" },
    { 0x161C, "armory_02_start" },
    { 0x161D, "armory_guard_breakout" },
    { 0x161E, "armory_guard_death_watcher" },
    { 0x161F, "armory_guards_anims" },
    { 0x1620, "armory_guards_ignored" },
    { 0x1621, "armory_lights" },
    { 0x1622, "armorykioskpurchaseallowed" },
    { 0x1623, "armorykioskused" },
    { 0x1624, "arms_race_spawn_music" },
    { 0x1625, "armtime" },
    { 0x1626, "armweights" },
    { 0x1627, "array" },
    { 0x1628, "array_add" },
    { 0x1629, "array_add_safe" },
    { 0x162A, "array_add_size_limited" },
    { 0x162B, "array_any_wait" },
    { 0x162C, "array_any_wait_match" },
    { 0x162D, "array_any_wait_match_proc" },
    { 0x162E, "array_any_wait_proc" },
    { 0x162F, "array_any_wait_return" },
    { 0x1630, "array_any_wait_return_proc" },
    { 0x1631, "array_any_wait_timeout" },
    { 0x1632, "array_any_wait_timeout_proc" },
    { 0x1633, "array_average" },
    { 0x1634, "array_call" },
    { 0x1635, "array_check_for_dupes" },
    { 0x1636, "array_combine" },
    { 0x1637, "array_combine_multiple" },
    { 0x1638, "array_combine_non_integer_indices" },
    { 0x1639, "array_combine_unique" },
    { 0x163A, "array_combine_unique_keys" },
    { 0x163B, "array_compare" },
    { 0x163C, "array_contains" },
    { 0x163D, "array_contains_key" },
    { 0x163E, "array_deck_shuffle" },
    { 0x163F, "array_delete" },
    { 0x1640, "array_delete_evenly" },
    { 0x1641, "array_difference" },
    { 0x1642, "array_divide" },
    { 0x1643, "array_ent_flag_wait" },
    { 0x1644, "array_ent_flag_wait_proc" },
    { 0x1645, "array_exclude" },
    { 0x1646, "array_find" },
    { 0x1647, "array_get_first_item" },
    { 0x1648, "array_handling" },
    { 0x1649, "array_hardfail" },
    { 0x164A, "array_index_by_classname" },
    { 0x164B, "array_index_by_parameters" },
    { 0x164C, "array_index_by_script_index" },
    { 0x164D, "array_insert" },
    { 0x164E, "array_intersection" },
    { 0x164F, "array_kill" },
    { 0x1650, "array_levelcall" },
    { 0x1651, "array_levelthread" },
    { 0x1652, "array_merge" },
    { 0x1653, "array_notify" },
    { 0x1654, "array_of_torrent_points" },
    { 0x1655, "array_randomize" },
    { 0x1656, "array_randomize_objects" },
    { 0x1657, "array_remove" },
    { 0x1658, "array_remove_array" },
    { 0x1659, "array_remove_dupes" },
    { 0x165A, "array_remove_duplicates" },
    { 0x165B, "array_remove_first" },
    { 0x165C, "array_remove_index" },
    { 0x165D, "array_remove_keep_index" },
    { 0x165E, "array_remove_key" },
    { 0x165F, "array_remove_key_array" },
    { 0x1660, "array_remove_nokeys" },
    { 0x1661, "array_removedead" },
    { 0x1662, "array_removedead_keepkeys" },
    { 0x1663, "array_removedead_or_dying" },
    { 0x1664, "array_removedeadandai" },
    { 0x1665, "array_removedeaddyingorundefined" },
    { 0x1666, "array_removedeadvehicles" },
    { 0x1667, "array_removeundefined" },
    { 0x1668, "array_reverse" },
    { 0x1669, "array_rotate" },
    { 0x166A, "array_slice" },
    { 0x166B, "array_sort_by_handler" },
    { 0x166C, "array_sort_with_func" },
    { 0x166D, "array_sortbyarray" },
    { 0x166E, "array_sortbyscriptindex" },
    { 0x166F, "array_sortbysorter" },
    { 0x1670, "array_spawn" },
    { 0x1671, "array_spawn_function" },
    { 0x1672, "array_spawn_function_aigroup" },
    { 0x1673, "array_spawn_function_noteworthy" },
    { 0x1674, "array_spawn_function_targetname" },
    { 0x1675, "array_spawn_noteworthy" },
    { 0x1676, "array_spawn_targetname" },
    { 0x1677, "array_sum" },
    { 0x1678, "array_thread" },
    { 0x1679, "array_thread_amortized" },
    { 0x167A, "array_thread_mod_delayed" },
    { 0x167B, "array_thread_safe" },
    { 0x167C, "array_to_vector" },
    { 0x167D, "array_wait" },
    { 0x167E, "array_wait_match" },
    { 0x167F, "array_wait_match_proc" },
    { 0x1680, "array_wait_proc" },
    { 0x1681, "array_wait_timeout_proc" },
    { 0x1682, "array_waitlogic1" },
    { 0x1683, "array_waitlogic2" },
    { 0x1684, "array_waittill_ballisticdeath" },
    { 0x1685, "array_waittill_ballisticdeath_proc" },
    { 0x1686, "arrays_of_colorcoded_ai" },
    { 0x1687, "arrays_of_colorcoded_nodes" },
    { 0x1688, "arrays_of_colorcoded_spawners" },
    { 0x1689, "arrays_of_colorcoded_volumes" },
    { 0x168A, "arrays_of_colorforced_ai" },
    { 0x168B, "arrest_lerpend" },
    { 0x168C, "arrest_lerpstart" },
    { 0x168D, "arrest_main" },
    { 0x168E, "arrest_scene" },
    { 0x168F, "arrest_start" },
    { 0x1690, "arrival_animmode" },
    { 0x1691, "arrival_done" },
    { 0x1692, "arrival_hadir_pickup_rifle" },
    { 0x1693, "arrival_hadir_pistol_holster" },
    { 0x1694, "arrivalangles" },
    { 0x1695, "arrivalasmstatename" },
    { 0x1696, "arrivalcount" },
    { 0x1697, "arrivaldata" },
    { 0x1698, "arrivaldesiredspeed" },
    { 0x1699, "arrivaldistsq" },
    { 0x169A, "arrivalendstance" },
    { 0x169B, "arrivalhack_emptywait" },
    { 0x169C, "arrivaloptionalprefix" },
    { 0x169D, "arrivalspeed" },
    { 0x169E, "arrivalspeedtarget" },
    { 0x169F, "arrivalstance" },
    { 0x16A0, "arrivalstate" },
    { 0x16A1, "arrivalstates" },
    { 0x16A2, "arrivalstopfired" },
    { 0x16A3, "arrivalterminate_patrol" },
    { 0x16A4, "arrivalterminatewait" },
    { 0x16A5, "arrivalusefootdown" },
    { 0x16A6, "arrivalxanim" },
    { 0x16A7, "arrive_at_exfil_location" },
    { 0x16A8, "arriveatvehicle_terminate" },
    { 0x16A9, "arrived_at_goal" },
    { 0x16AA, "arrived_at_patrol_exit" },
    { 0x16AB, "arrow_debug" },
    { 0x16AC, "art_catchup" },
    { 0x16AD, "art_main" },
    { 0x16AE, "art_start" },
    { 0x16AF, "artillery_earthquake" },
    { 0x16B0, "ascenddeathlistener" },
    { 0x16B1, "ascender" },
    { 0x16B2, "ascenderscriptableused" },
    { 0x16B3, "ascenderuse" },
    { 0x16B4, "ascendstarts" },
    { 0x16B5, "ascendstructend" },
    { 0x16B6, "ascendstructout" },
    { 0x16B7, "ascendstructs" },
    { 0x16B8, "asm" },
    { 0x16B9, "asm_addephemeraleventtowatchlist" },
    { 0x16BA, "asm_animcustom" },
    { 0x16BB, "asm_animcustom_endanimscript" },
    { 0x16BC, "asm_animhasfacialoverride" },
    { 0x16BD, "asm_animscripted" },
    { 0x16BE, "asm_checktransitions" },
    { 0x16BF, "asm_chooseanim" },
    { 0x16C0, "asm_cleanupaimknobs" },
    { 0x16C1, "asm_cleanupaimknobsonterminate" },
    { 0x16C2, "asm_cleanupaimknobswithdelay" },
    { 0x16C3, "asm_clearallephemeralevents" },
    { 0x16C4, "asm_cleardemeanoranimoverride" },
    { 0x16C5, "asm_clearevents" },
    { 0x16C6, "asm_clearfacialanim" },
    { 0x16C7, "asm_clearfingerposes" },
    { 0x16C8, "asm_clearikfingeranim" },
    { 0x16C9, "asm_clearvisoranim" },
    { 0x16CA, "asm_currentstatehasflag" },
    { 0x16CB, "asm_donotetracks" },
    { 0x16CC, "asm_donotetracksfortime" },
    { 0x16CD, "asm_donotetracksfortime_helper" },
    { 0x16CE, "asm_donotetrackssingleloop" },
    { 0x16CF, "asm_donotetrackssingleloop_waiter" },
    { 0x16D0, "asm_donotetrackswithinterceptor" },
    { 0x16D1, "asm_donotetrackswithtimeout" },
    { 0x16D2, "asm_donotetrackswithtimeout_helper" },
    { 0x16D3, "asm_dosinglenotetrack" },
    { 0x16D4, "asm_ephemeral_event_watchlist" },
    { 0x16D5, "asm_ephemeraleventfired" },
    { 0x16D6, "asm_eventfired" },
    { 0x16D7, "asm_eventfiredrecently" },
    { 0x16D8, "asm_fireephemeralevent" },
    { 0x16D9, "asm_fireevent" },
    { 0x16DA, "asm_fireevent_internal" },
    { 0x16DB, "asm_generichandler" },
    { 0x16DC, "asm_getaimlimitset" },
    { 0x16DD, "asm_getallanimindicesforalias" },
    { 0x16DE, "asm_getallanimsforalias" },
    { 0x16DF, "asm_getallanimsforstate" },
    { 0x16E0, "asm_getanim" },
    { 0x16E1, "asm_getanimindex" },
    { 0x16E2, "asm_getbodyknob" },
    { 0x16E3, "asm_getcurrentstate" },
    { 0x16E4, "asm_getcurrentstatename" },
    { 0x16E5, "asm_getdemeanor" },
    { 0x16E6, "asm_getdemeanoranimoverride" },
    { 0x16E7, "asm_getephemeraleventdata" },
    { 0x16E8, "asm_geteventdata" },
    { 0x16E9, "asm_geteventtime" },
    { 0x16EA, "asm_getfacialknob" },
    { 0x16EB, "asm_getheadlookknobifexists" },
    { 0x16EC, "asm_getinnerrootknob" },
    { 0x16ED, "asm_getmoveplaybackrate" },
    { 0x16EE, "asm_getnotehandler" },
    { 0x16EF, "asm_getrandomalias" },
    { 0x16F0, "asm_getrandomanim" },
    { 0x16F1, "asm_getroot" },
    { 0x16F2, "asm_getxanim" },
    { 0x16F3, "asm_globalinit" },
    { 0x16F4, "asm_handlenewnotetracks" },
    { 0x16F5, "asm_handlenotetracks" },
    { 0x16F6, "asm_hasalias" },
    { 0x16F7, "asm_hasdemeanoranimoverride" },
    { 0x16F8, "asm_hasknobs" },
    { 0x16F9, "asm_hasstatesp" },
    { 0x16FA, "asm_ikfingeranim" },
    { 0x16FB, "asm_init" },
    { 0x16FC, "asm_init_blackboard" },
    { 0x16FD, "asm_initfingerposes" },
    { 0x16FE, "asm_iscrawlmelee" },
    { 0x16FF, "asm_isfrantic" },
    { 0x1700, "asm_isweaponoverride" },
    { 0x1701, "asm_lookupanimfromalias" },
    { 0x1702, "asm_lookupanimfromaliasifexists" },
    { 0x1703, "asm_lookupdirectionalfootanim" },
    { 0x1704, "asm_lookuprandomalias" },
    { 0x1705, "asm_loopanimstate" },
    { 0x1706, "asm_playadditiveanimloopstate" },
    { 0x1707, "asm_playadditiveanimloopstate_helper" },
    { 0x1708, "asm_playadditiveanimloopstate_mp" },
    { 0x1709, "asm_playadditiveanimloopstate_sp" },
    { 0x170A, "asm_playanimstate" },
    { 0x170B, "asm_playanimstateindex" },
    { 0x170C, "asm_playanimstatenotransition" },
    { 0x170D, "asm_playanimstateuntilnotetrack" },
    { 0x170E, "asm_playanimstatewithnotetrackinterceptor" },
    { 0x170F, "asm_playfacialanim" },
    { 0x1710, "asm_playfacialanim_sp" },
    { 0x1711, "asm_playfacialanimfromnotetrack" },
    { 0x1712, "asm_playfacialaniminternal" },
    { 0x1713, "asm_playfacialanimsingleframedeath" },
    { 0x1714, "asm_playikfingeranim" },
    { 0x1715, "asm_playvisorraise" },
    { 0x1716, "asm_powerdown" },
    { 0x1717, "asm_powerup" },
    { 0x1718, "asm_register" },
    { 0x1719, "asm_restorefacialanim" },
    { 0x171A, "asm_setaimlimits" },
    { 0x171B, "asm_setcrawlmelee" },
    { 0x171C, "asm_setdemeanoranimoverride" },
    { 0x171D, "asm_setmoveplaybackrate" },
    { 0x171E, "asm_setoverrideparams" },
    { 0x171F, "asm_setstate" },
    { 0x1720, "asm_setstateaimlimits" },
    { 0x1721, "asm_settransitionanimmode" },
    { 0x1722, "asm_settransitionanimmode_legacy" },
    { 0x1723, "asm_settransitionanimmode_transition" },
    { 0x1724, "asm_settransitionorientmode" },
    { 0x1725, "asm_settransitionorientmode_legacy" },
    { 0x1726, "asm_settransitionorientmode_transition" },
    { 0x1727, "asm_setupaim" },
    { 0x1728, "asm_setupaim_sp" },
    { 0x1729, "asm_setupgesture" },
    { 0x172A, "asm_shoulddeathtransition" },
    { 0x172B, "asm_shouldpowerdown" },
    { 0x172C, "asm_stopanimcustom" },
    { 0x172D, "asm_stopanimscripted" },
    { 0x172E, "asm_terminateandreplace" },
    { 0x172F, "asm_tick" },
    { 0x1730, "asm_tryhandledeathstatechangenotetrack" },
    { 0x1731, "asm_trynvgmodelswap" },
    { 0x1732, "asm_updatefrantic" },
    { 0x1733, "asm_waitforaimnotetrack" },
    { 0x1734, "asmasset" },
    { 0x1735, "asmfuncs" },
    { 0x1736, "asmname" },
    { 0x1737, "asmparams" },
    { 0x1738, "ass" },
    { 0x1739, "assaigned" },
    { 0x173A, "assassinate_dialogueenemydeathslogic" },
    { 0x173B, "assassinate_dialogueinstructionslogic" },
    { 0x173C, "assassinate_dialoguelogic" },
    { 0x173D, "assassinate_dialoguemisslogic" },
    { 0x173E, "assassinate_dialoguetruck" },
    { 0x173F, "assassinate_dogslogic" },
    { 0x1740, "assassinate_drawweaponhintlogic" },
    { 0x1741, "assassinate_driverdeathlogic" },
    { 0x1742, "assassinate_enemiesdeathlogic" },
    { 0x1743, "assassinate_enemiesdialoguelogic" },
    { 0x1744, "assassinate_enemieslogic" },
    { 0x1745, "assassinate_enemybinocularslogic" },
    { 0x1746, "assassinate_enemylogic" },
    { 0x1747, "assassinate_enemyreactlogic" },
    { 0x1748, "assassinate_farahkillremainingenemieslogic" },
    { 0x1749, "assassinate_farahlogic" },
    { 0x174A, "assassinate_flankfarahnaglogic" },
    { 0x174B, "assassinate_getanimationstruct" },
    { 0x174C, "assassinate_getbehindtrucktrigger" },
    { 0x174D, "assassinate_getcrawlcovernodes" },
    { 0x174E, "assassinate_getdrawweaponhinttrigger" },
    { 0x174F, "assassinate_getenemies" },
    { 0x1750, "assassinate_getplayerflanktrigger" },
    { 0x1751, "assassinate_getspawners" },
    { 0x1752, "assassinate_getvehicle" },
    { 0x1753, "assassinate_interiorscenelogic" },
    { 0x1754, "assassinate_main" },
    { 0x1755, "assassinate_playeralertsenemies" },
    { 0x1756, "assassinate_sfxlogic" },
    { 0x1757, "assassinate_spawnenemiesinvehicle" },
    { 0x1758, "assassinate_spawnvehicle" },
    { 0x1759, "assassinate_start" },
    { 0x175A, "assault_enemieslogic" },
    { 0x175B, "assault_enemymagicmolotovgrenadelogic" },
    { 0x175C, "assault_getextraenemyspawners" },
    { 0x175D, "assault_main" },
    { 0x175E, "assault_start" },
    { 0x175F, "assault_vehicle" },
    { 0x1760, "assault_vehicle_sound" },
    { 0x1761, "assault_vehicle_spawner" },
    { 0x1762, "assault_weapons_array" },
    { 0x1763, "assaultdrones" },
    { 0x1764, "assaultspawns" },
    { 0x1765, "assert_existance_of_anim" },
    { 0x1766, "assert_if_identical_origins" },
    { 0x1767, "assetname" },
    { 0x1768, "assetoverridename" },
    { 0x1769, "assetref" },
    { 0x176A, "assign_agent_func" },
    { 0x176B, "assign_animals_tree" },
    { 0x176C, "assign_animtree" },
    { 0x176D, "assign_animtree_based_on_subclass" },
    { 0x176E, "assign_animtree_based_on_unittype" },
    { 0x176F, "assign_bed_civ_index" },
    { 0x1770, "assign_c12_animtree" },
    { 0x1771, "assign_c6_animtree" },
    { 0x1772, "assign_c8_animtree" },
    { 0x1773, "assign_door_ents" },
    { 0x1774, "assign_drone_tree" },
    { 0x1775, "assign_event_location" },
    { 0x1776, "assign_fx_to_trigger" },
    { 0x1777, "assign_generic_human_tree" },
    { 0x1778, "assign_heli_positions" },
    { 0x1779, "assign_highest_full_slot_to_active" },
    { 0x177A, "assign_human_animtree" },
    { 0x177B, "assign_model" },
    { 0x177C, "assign_more_vehicle_unload_groups" },
    { 0x177D, "assign_npcid" },
    { 0x177E, "assign_player_team" },
    { 0x177F, "assign_pvpe_team_and_slot_number" },
    { 0x1780, "assign_random_bed_civ_index" },
    { 0x1781, "assign_scripted_movement" },
    { 0x1782, "assign_soldier_spec" },
    { 0x1783, "assign_spawner" },
    { 0x1784, "assign_spawnpoints_to_parent_structs" },
    { 0x1785, "assign_trigger_on_player_spawned" },
    { 0x1786, "assign_unique_id" },
    { 0x1787, "assign_vehicle_interaction" },
    { 0x1788, "assign_weapons_to_structs" },
    { 0x1789, "assign_window" },
    { 0x178A, "assignchevrons" },
    { 0x178B, "assigned" },
    { 0x178C, "assigned_pos" },
    { 0x178D, "assigngamemodecallout" },
    { 0x178E, "assigngoalpos" },
    { 0x178F, "assignhelitoexfilpoint" },
    { 0x1790, "assigninteractteam" },
    { 0x1791, "assignlevelstoturrets" },
    { 0x1792, "assignlootpassivetoweapon" },
    { 0x1793, "assignpersonalmodelents" },
    { 0x1794, "assignrandomspawnselection" },
    { 0x1795, "assignspectatortofollowplayer" },
    { 0x1796, "assignspectatortospectateplayer" },
    { 0x1797, "assignteamspawns" },
    { 0x1798, "assigntimervisibleteam" },
    { 0x1799, "assignvehicleminimumsforvolume" },
    { 0x179A, "assist_onbeginuse" },
    { 0x179B, "assist_onenduse" },
    { 0x179C, "assistedsuicide" },
    { 0x179D, "assists_disabled" },
    { 0x179E, "assisttouchlist" },
    { 0x179F, "associate_lead_with_player" },
    { 0x17A0, "associate_turret_settings_from_type" },
    { 0x17A1, "associated_player" },
    { 0x17A2, "associated_table" },
    { 0x17A3, "associatedteams" },
    { 0x17A4, "at_extract" },
    { 0x17A5, "at_least_goal" },
    { 0x17A6, "at_mine_cleanup_danger_icon_ent" },
    { 0x17A7, "at_mine_create_player_trigger" },
    { 0x17A8, "at_mine_damage_manually" },
    { 0x17A9, "at_mine_damage_vehicle_manually" },
    { 0x17AA, "at_mine_delete" },
    { 0x17AB, "at_mine_destroy" },
    { 0x17AC, "at_mine_empapplied" },
    { 0x17AD, "at_mine_explode_from_notify" },
    { 0x17AE, "at_mine_explode_from_player_trigger" },
    { 0x17AF, "at_mine_explode_from_vehicle_trigger" },
    { 0x17B0, "at_mine_explode_from_vehicle_trigger_internal" },
    { 0x17B1, "at_mine_init" },
    { 0x17B2, "at_mine_modified_damage" },
    { 0x17B3, "at_mine_onownerchanged" },
    { 0x17B4, "at_mine_plant" },
    { 0x17B5, "at_mine_player_trigger" },
    { 0x17B6, "at_mine_test" },
    { 0x17B7, "at_mine_update_danger_zone" },
    { 0x17B8, "at_mine_use" },
    { 0x17B9, "at_mine_vehicle_trigger" },
    { 0x17BA, "at_mine_watch_detonate" },
    { 0x17BB, "at_mine_watch_emp" },
    { 0x17BC, "at_mine_watch_flight" },
    { 0x17BD, "at_mine_watch_flight_effects" },
    { 0x17BE, "at_mine_watch_flight_mover" },
    { 0x17BF, "at_mine_watch_game_end" },
    { 0x17C0, "at_mine_watch_player_trigger" },
    { 0x17C1, "at_mine_watch_trigger" },
    { 0x17C2, "at_mine_watch_vehicle_trigger" },
    { 0x17C3, "atbase" },
    { 0x17C4, "atbrinkofdeath" },
    { 0x17C5, "atconcealmentnode" },
    { 0x17C6, "atk_bomber" },
    { 0x17C7, "atk_bomber_no_path_to_bomb_count" },
    { 0x17C8, "atk_bomber_update" },
    { 0x17C9, "atm_amount_deposited" },
    { 0x17CA, "atm_transaction_amount" },
    { 0x17CB, "atmines" },
    { 0x17CC, "atmosphere" },
    { 0x17CD, "atmosphere_enable" },
    { 0x17CE, "atmotypes" },
    { 0x17CF, "atr_node" },
    { 0x17D0, "atrest" },
    { 0x17D1, "attach_and_detach_phone" },
    { 0x17D2, "attach_barrels_to_truck" },
    { 0x17D3, "attach_chains_to_chair" },
    { 0x17D4, "attach_chair" },
    { 0x17D5, "attach_entity" },
    { 0x17D6, "attach_hvt_to_vehicle" },
    { 0x17D7, "attach_icon" },
    { 0x17D8, "attach_keycard_left" },
    { 0x17D9, "attach_keycard_right" },
    { 0x17DA, "attach_model_override" },
    { 0x17DB, "attach_player_knife" },
    { 0x17DC, "attach_player_to_heli" },
    { 0x17DD, "attach_player_to_rig" },
    { 0x17DE, "attach_price_halligan" },
    { 0x17DF, "attach_props" },
    { 0x17E0, "attach_shackles_to_rig" },
    { 0x17E1, "attach_sidearm" },
    { 0x17E2, "attach_smuggler_loot" },
    { 0x17E3, "attach_vehicle" },
    { 0x17E4, "attach_vehicle_and_gopath" },
    { 0x17E5, "attachcustomtoidmap" },
    { 0x17E6, "attachdefaults" },
    { 0x17E7, "attachdefaulttoidmap" },
    { 0x17E8, "attached" },
    { 0x17E9, "attached_barrels" },
    { 0x17EA, "attached_drones" },
    { 0x17EB, "attached_pents" },
    { 0x17EC, "attachedguys" },
    { 0x17ED, "attachedmodels" },
    { 0x17EE, "attachedpath" },
    { 0x17EF, "attachedusemodel" },
    { 0x17F0, "attachedweaponmodels" },
    { 0x17F1, "attachextratoidmap" },
    { 0x17F2, "attachflag" },
    { 0x17F3, "attachflashlight" },
    { 0x17F4, "attachgrenademodel" },
    { 0x17F5, "attachhat" },
    { 0x17F6, "attachhead" },
    { 0x17F7, "attachmentammonamehack" },
    { 0x17F8, "attachmentcheck" },
    { 0x17F9, "attachmentdata" },
    { 0x17FA, "attachmentextralist" },
    { 0x17FB, "attachmentgroup" },
    { 0x17FC, "attachmentinitialprimary" },
    { 0x17FD, "attachmentinitialsecondary" },
    { 0x17FE, "attachmentinitialsecondarytwo" },
    { 0x17FF, "attachmentiscosmetic" },
    { 0x1800, "attachmentisdefault" },
    { 0x1801, "attachmentismod" },
    { 0x1802, "attachmentlogsstats" },
    { 0x1803, "attachmentmap" },
    { 0x1804, "attachmentmap_attachtoperk" },
    { 0x1805, "attachmentmap_basetounique" },
    { 0x1806, "attachmentmap_conflicts" },
    { 0x1807, "attachmentmap_extratovariantid" },
    { 0x1808, "attachmentmap_tobase" },
    { 0x1809, "attachmentmap_toextra" },
    { 0x180A, "attachmentmap_tounique" },
    { 0x180B, "attachmentmap_uniquetobase" },
    { 0x180C, "attachmentmap_uniquetoextra" },
    { 0x180D, "attachmentperkmap" },
    { 0x180E, "attachmentref" },
    { 0x180F, "attachmentroll" },
    { 0x1810, "attachmentrollcount" },
    { 0x1811, "attachmentscompatible" },
    { 0x1812, "attachmentsconflict" },
    { 0x1813, "attachmentsfilterforstats" },
    { 0x1814, "attachmentsurvivorprimary" },
    { 0x1815, "attachmentsurvivorsecondary" },
    { 0x1816, "attachmentsurvivorsecondarytwo" },
    { 0x1817, "attachmissiles" },
    { 0x1818, "attachobj" },
    { 0x1819, "attachobjecttocarrier" },
    { 0x181A, "attachraritymap" },
    { 0x181B, "attachtoughenuparmor" },
    { 0x181C, "attachweapon" },
    { 0x181D, "attack_behavior" },
    { 0x181E, "attack_bolt" },
    { 0x181F, "attack_damage_trigger" },
    { 0x1820, "attack_heli_cleanup" },
    { 0x1821, "attack_heli_fx" },
    { 0x1822, "attack_heli_safe_volumes" },
    { 0x1823, "attack_sequence" },
    { 0x1824, "attack_spot" },
    { 0x1825, "attack_turns" },
    { 0x1826, "attackarrow" },
    { 0x1827, "attackbuttondebounce" },
    { 0x1828, "attacker_damage" },
    { 0x1829, "attacker_isonmyteam" },
    { 0x182A, "attacker_troop_isonmyteam" },
    { 0x182B, "attacker_velocity_lerp" },
    { 0x182C, "attackerdata" },
    { 0x182D, "attackerendzone" },
    { 0x182E, "attackerent" },
    { 0x182F, "attackerentnum" },
    { 0x1830, "attackerinremotekillstreak" },
    { 0x1831, "attackerishittingteam" },
    { 0x1832, "attackerloadoutperks" },
    { 0x1833, "attackernum" },
    { 0x1834, "attackerposition" },
    { 0x1835, "attackers" },
    { 0x1836, "attackerslockedon" },
    { 0x1837, "attackertable" },
    { 0x1838, "attackerteam" },
    { 0x1839, "attackgroundtarget" },
    { 0x183A, "attackheli" },
    { 0x183B, "attackheliaiburstsize" },
    { 0x183C, "attackheliexcluders" },
    { 0x183D, "attackhelifov" },
    { 0x183E, "attackheligraceperiod" },
    { 0x183F, "attackhelikillsai" },
    { 0x1840, "attackhelimemory" },
    { 0x1841, "attackhelimovetime" },
    { 0x1842, "attackheliplayerbreak" },
    { 0x1843, "attackhelirange" },
    { 0x1844, "attackhelitargetreaquire" },
    { 0x1845, "attackhelitimeout" },
    { 0x1846, "attackingtarget" },
    { 0x1847, "attacklasedtarget" },
    { 0x1848, "attempt_ai_air_infil_cooldown" },
    { 0x1849, "attempt_ai_ground_infil_cooldown" },
    { 0x184A, "attempt_end_sequence" },
    { 0x184B, "attempt_new_pulse_set" },
    { 0x184C, "attempt_take_stunstick" },
    { 0x184D, "attempt_throttle" },
    { 0x184E, "attempt_to_give_info" },
    { 0x184F, "attempt_to_join_squad" },
    { 0x1850, "attempt_to_walk_around" },
    { 0x1851, "attempting_teleport" },
    { 0x1852, "attempttier" },
    { 0x1853, "attic" },
    { 0x1854, "attic_attach_clacker" },
    { 0x1855, "attic_bink_start" },
    { 0x1856, "attic_death_dialogue" },
    { 0x1857, "attic_detach_laptop" },
    { 0x1858, "attic_door_triggered" },
    { 0x1859, "attic_enemy" },
    { 0x185A, "attic_enemy_anim" },
    { 0x185B, "attic_enemy_death" },
    { 0x185C, "attic_enemy_death_vo" },
    { 0x185D, "attic_enemy_early_death" },
    { 0x185E, "attic_enemy_smartdialog" },
    { 0x185F, "attic_final_player_deathanim" },
    { 0x1860, "attic_fov_notetrack" },
    { 0x1861, "attic_main" },
    { 0x1862, "attic_open_door" },
    { 0x1863, "attic_player_can_shoot" },
    { 0x1864, "attic_player_sees_enemy" },
    { 0x1865, "attic_price_anim" },
    { 0x1866, "attic_price_shoot" },
    { 0x1867, "attic_price_stairtrain" },
    { 0x1868, "attic_room" },
    { 0x1869, "attic_start" },
    { 0x186A, "attic_swap_door" },
    { 0x186B, "attic_swap_door2" },
    { 0x186C, "attic_trigger_damage_thread" },
    { 0x186D, "attic_use_deathanim" },
    { 0x186E, "attic_use_final_deathanim" },
    { 0x186F, "attic_use_ragdoll" },
    { 0x1870, "attract_agent_to_alarm" },
    { 0x1871, "attract_agent_to_bomb_plant" },
    { 0x1872, "attract_agent_to_mortar" },
    { 0x1873, "attract_an_agent" },
    { 0x1874, "attract_range" },
    { 0x1875, "attract_strength" },
    { 0x1876, "attracting" },
    { 0x1877, "attractor" },
    { 0x1878, "attractor2" },
    { 0x1879, "atv_collide_death" },
    { 0x187A, "atv_cp_create" },
    { 0x187B, "atv_cp_createfromstructs" },
    { 0x187C, "atv_cp_delete" },
    { 0x187D, "atv_cp_getspawnstructscallback" },
    { 0x187E, "atv_cp_init" },
    { 0x187F, "atv_cp_initlate" },
    { 0x1880, "atv_cp_initspawning" },
    { 0x1881, "atv_cp_ondeathrespawncallback" },
    { 0x1882, "atv_cp_spawncallback" },
    { 0x1883, "atv_cp_waitandspawn" },
    { 0x1884, "atv_create" },
    { 0x1885, "atv_death_launchslide" },
    { 0x1886, "atv_deathcallback" },
    { 0x1887, "atv_decide_shoot" },
    { 0x1888, "atv_decide_shoot_internal" },
    { 0x1889, "atv_deletenextframe" },
    { 0x188A, "atv_do_event" },
    { 0x188B, "atv_enterend" },
    { 0x188C, "atv_enterendinternal" },
    { 0x188D, "atv_exitend" },
    { 0x188E, "atv_exitendinternal" },
    { 0x188F, "atv_explode" },
    { 0x1890, "atv_get_death_anim" },
    { 0x1891, "atv_getoff" },
    { 0x1892, "atv_geton" },
    { 0x1893, "atv_getspawnstructscallback" },
    { 0x1894, "atv_handle_events" },
    { 0x1895, "atv_init" },
    { 0x1896, "atv_initfx" },
    { 0x1897, "atv_initinteract" },
    { 0x1898, "atv_initlate" },
    { 0x1899, "atv_initoccupancy" },
    { 0x189A, "atv_initspawning" },
    { 0x189B, "atv_loop_driver" },
    { 0x189C, "atv_loop_driver_shooting" },
    { 0x189D, "atv_mp_create" },
    { 0x189E, "atv_mp_delete" },
    { 0x189F, "atv_mp_getspawnstructscallback" },
    { 0x18A0, "atv_mp_init" },
    { 0x18A1, "atv_mp_initmines" },
    { 0x18A2, "atv_mp_initspawning" },
    { 0x18A3, "atv_mp_ondeathrespawncallback" },
    { 0x18A4, "atv_mp_spawncallback" },
    { 0x18A5, "atv_mp_waitandspawn" },
    { 0x18A6, "atv_normal_death" },
    { 0x18A7, "atv_reload" },
    { 0x18A8, "atv_reload_internal" },
    { 0x18A9, "atv_setanim_common" },
    { 0x18AA, "atv_setanim_driver" },
    { 0x18AB, "atv_shoot" },
    { 0x18AC, "atv_start_shooting" },
    { 0x18AD, "atv_stop_shooting" },
    { 0x18AE, "atv_trackshootentorpos_driver" },
    { 0x18AF, "atv_waitfor_end" },
    { 0x18B0, "atv_waitfor_start_aim" },
    { 0x18B1, "atv_waitfor_start_lean" },
    { 0x18B2, "atvs" },
    { 0x18B3, "atvshootbehavior" },
    { 0x18B4, "aud_car_door_opened" },
    { 0x18B5, "aud_smoke_grenade_loop" },
    { 0x18B6, "audio" },
    { 0x18B7, "audio_aq_in_other_room_banging" },
    { 0x18B8, "audio_aq_run_behind_truck" },
    { 0x18B9, "audio_aq_run_behind_truck_one_shots" },
    { 0x18BA, "audio_big_truck_turn_on_idle" },
    { 0x18BB, "audio_bink_fadein_ambient" },
    { 0x18BC, "audio_bink_fadeout_ambient" },
    { 0x18BD, "audio_bink_transition_ambient" },
    { 0x18BE, "audio_bpg_entrance_alarm_loop_start" },
    { 0x18BF, "audio_carried_music_russians" },
    { 0x18C0, "audio_cctv_mix" },
    { 0x18C1, "audio_cctv_mix_clear" },
    { 0x18C2, "audio_chopper_struggling" },
    { 0x18C3, "audio_clear_audio_zone_heli" },
    { 0x18C4, "audio_compile_umbra" },
    { 0x18C5, "audio_convoy_flyby" },
    { 0x18C6, "audio_convoy_sierra_1" },
    { 0x18C7, "audio_convoy_sierra_2" },
    { 0x18C8, "audio_convoy_tango" },
    { 0x18C9, "audio_credits_done_rolling" },
    { 0x18CA, "audio_credits_start_rolling" },
    { 0x18CB, "audio_crowd_angry_outside" },
    { 0x18CC, "audio_crowd_cheer_at_end_of_infil_crash" },
    { 0x18CD, "audio_defend_4_perimeter_zone_state" },
    { 0x18CE, "audio_defend_4_zone_state" },
    { 0x18CF, "audio_defend_5_zone_state" },
    { 0x18D0, "audio_defend_6_zone_state" },
    { 0x18D1, "audio_dist_shootings" },
    { 0x18D2, "audio_dist_shootings_one_shot_executions" },
    { 0x18D3, "audio_distant_gas_death_scream_handler" },
    { 0x18D4, "audio_distant_gas_death_screams_01" },
    { 0x18D5, "audio_distant_gas_death_screams_02" },
    { 0x18D6, "audio_distant_gas_death_screams_03" },
    { 0x18D7, "audio_door_clip_thread" },
    { 0x18D8, "audio_door_close" },
    { 0x18D9, "audio_door_damage_thread" },
    { 0x18DA, "audio_door_interaction_wait" },
    { 0x18DB, "audio_door_open" },
    { 0x18DC, "audio_door_set_state" },
    { 0x18DD, "audio_door_slam_shut" },
    { 0x18DE, "audio_door_sound_clip_init" },
    { 0x18DF, "audio_fade_out_ending_mix" },
    { 0x18E0, "audio_fade_out_over_bink" },
    { 0x18E1, "audio_farrah_cpapa_ads_handler" },
    { 0x18E2, "audio_final_shot_start" },
    { 0x18E3, "audio_finale_cockpit_shot" },
    { 0x18E4, "audio_finale_heli_start" },
    { 0x18E5, "audio_find_script_vehicles" },
    { 0x18E6, "audio_front_door_dog_sfx" },
    { 0x18E7, "audio_garage_door_roll_up" },
    { 0x18E8, "audio_gas_canister_smoke_atmos" },
    { 0x18E9, "audio_gassed_music" },
    { 0x18EA, "audio_grenade_warning" },
    { 0x18EB, "audio_helmet_transition_helmet_off_no_filter_change" },
    { 0x18EC, "audio_helmet_transition_helmet_off_release_scripted_filter" },
    { 0x18ED, "audio_helmet_transition_helmet_on_visor_down_w_lma" },
    { 0x18EE, "audio_helmet_transition_helmet_on_visor_up_no_lma" },
    { 0x18EF, "audio_helmet_transition_visor_down_w_lma" },
    { 0x18F0, "audio_helmet_transition_visor_up" },
    { 0x18F1, "audio_hometown_truck_kid_loaded_gate" },
    { 0x18F2, "audio_hometown_truck_kid_loaded_idle" },
    { 0x18F3, "audio_hometown_truck_kid_loaded_leaving" },
    { 0x18F4, "audio_house_boss_enter_music" },
    { 0x18F5, "audio_house_enter_music" },
    { 0x18F6, "audio_infil_crowd" },
    { 0x18F7, "audio_intro_mix" },
    { 0x18F8, "audio_intro_mix_change" },
    { 0x18F9, "audio_jeep1_idle" },
    { 0x18FA, "audio_jeep2_idle" },
    { 0x18FB, "audio_loop_state" },
    { 0x18FC, "audio_main_siren_handler" },
    { 0x18FD, "audio_mix_bomb_explo" },
    { 0x18FE, "audio_mix_fade_out_end_of_level" },
    { 0x18FF, "audio_mix_move1" },
    { 0x1900, "audio_mix_move2" },
    { 0x1901, "audio_mix_move3" },
    { 0x1902, "audio_mix_move4" },
    { 0x1903, "audio_music_house_post_stab" },
    { 0x1904, "audio_music_intro" },
    { 0x1905, "audio_music_stab" },
    { 0x1906, "audio_music_stab_kill_brute" },
    { 0x1907, "audio_music_start_st_pete" },
    { 0x1908, "audio_music_stop_music_delay" },
    { 0x1909, "audio_music_streets_fade_out" },
    { 0x190A, "audio_music_streets_grab_player" },
    { 0x190B, "audio_music_transition_to_alley" },
    { 0x190C, "audio_notify_change_mix" },
    { 0x190D, "audio_office_alarm_loop_start" },
    { 0x190E, "audio_pipes_bomb_plant_start" },
    { 0x190F, "audio_play_bullet_impacts_around_player" },
    { 0x1910, "audio_poppies_mix_change" },
    { 0x1911, "audio_post_gas" },
    { 0x1912, "audio_post_truck_office_alarm_loop_start" },
    { 0x1913, "audio_python_open_filter" },
    { 0x1914, "audio_residence_door_close" },
    { 0x1915, "audio_residence_door_open" },
    { 0x1916, "audio_shed_truck_idle_monitor" },
    { 0x1917, "audio_start_air_raid_siren" },
    { 0x1918, "audio_start_car_siren_01" },
    { 0x1919, "audio_start_car_siren_02" },
    { 0x191A, "audio_start_car_siren_03" },
    { 0x191B, "audio_start_car_siren_handler" },
    { 0x191C, "audio_start_pre_impact_group_walla" },
    { 0x191D, "audio_start_ramp_emitters" },
    { 0x191E, "audio_start_stairwell_car_scene" },
    { 0x191F, "audio_stp_intro_amb" },
    { 0x1920, "audio_thread_lever" },
    { 0x1921, "audio_toggle_door_propagation" },
    { 0x1922, "audio_train_front_car_low_groan_handler" },
    { 0x1923, "audio_train_front_car_mtl_screech_handler" },
    { 0x1924, "audio_train_mid_car_low_groan_handler" },
    { 0x1925, "audio_train_mid_car_mtl_screech_handler" },
    { 0x1926, "audio_train_rear_car_low_groan_handler" },
    { 0x1927, "audio_train_rear_car_mtl_screech_handler" },
    { 0x1928, "audio_truck_door_interaction_check" },
    { 0x1929, "audio_truck_exit" },
    { 0x192A, "audio_truck_passby_ext" },
    { 0x192B, "audio_truck3_wake_up_and_away" },
    { 0x192C, "audio_vehicle_print3d_monitor" },
    { 0x192D, "audio_wait_until_player_close_enough_to_obj" },
    { 0x192E, "audio_wolf_outro_room_mix" },
    { 0x192F, "audio_wp_explosions" },
    { 0x1930, "audio_wp_sizzle" },
    { 0x1931, "audio_zd30_dog_kill_handler" },
    { 0x1932, "audio_zd30_intro_lbird_bravo_heli" },
    { 0x1933, "audio_zd30_intro_lbird_plr_heli" },
    { 0x1934, "audio_zd30_intro_lbird_plr_heli_kill_entities" },
    { 0x1935, "audio_zd30_transition_to_tunnels" },
    { 0x1936, "audio_zones" },
    { 0x1937, "audioportalent" },
    { 0x1938, "audiostate" },
    { 0x1939, "audiotoggler" },
    { 0x193A, "auraquickswap_bestowaura" },
    { 0x193B, "auraquickswap_run" },
    { 0x193C, "auto" },
    { 0x193D, "auto_adjust" },
    { 0x193E, "auto_adjust_data_add" },
    { 0x193F, "auto_adjust_data_get" },
    { 0x1940, "auto_adjust_data_reset" },
    { 0x1941, "auto_adjust_data_set" },
    { 0x1942, "auto_adjust_debug" },
    { 0x1943, "auto_adjust_debug_update" },
    { 0x1944, "auto_adjust_debuglite" },
    { 0x1945, "auto_adjust_difficult_get" },
    { 0x1946, "auto_adjust_difficulty" },
    { 0x1947, "auto_adjust_init" },
    { 0x1948, "auto_adjust_lerp_setting" },
    { 0x1949, "auto_adjust_playerdied" },
    { 0x194A, "auto_adjust_save_committed" },
    { 0x194B, "auto_adjust_set_table" },
    { 0x194C, "auto_adjust_thread" },
    { 0x194D, "auto_alarm_turnoff" },
    { 0x194E, "auto_mg42_target" },
    { 0x194F, "auto_mgturretlink" },
    { 0x1950, "auto_write_to_map" },
    { 0x1951, "autoassign" },
    { 0x1952, "autoattachtoplayer" },
    { 0x1953, "autoclosemonitor" },
    { 0x1954, "autodestructactivated" },
    { 0x1955, "autodestructdamagepercent" },
    { 0x1956, "autogenfunc_0" },
    { 0x1957, "autogenfunc_1" },
    { 0x1958, "autogenfunc_10" },
    { 0x1959, "autogenfunc_2" },
    { 0x195A, "autogenfunc_3" },
    { 0x195B, "autogenfunc_4" },
    { 0x195C, "autogenfunc_5" },
    { 0x195D, "autogenfunc_6" },
    { 0x195E, "autogenfunc_7" },
    { 0x195F, "autogenfunc_8" },
    { 0x1960, "autogenfunc_9" },
    { 0x1961, "automated_respawn_available" },
    { 0x1962, "automated_respawn_delay" },
    { 0x1963, "automated_respawn_delay_skip" },
    { 0x1964, "automated_respawn_func" },
    { 0x1965, "automated_respawn_sequence" },
    { 0x1966, "automaticignitehint" },
    { 0x1967, "autopickupplunder" },
    { 0x1968, "autoresettime" },
    { 0x1969, "autorespawntime" },
    { 0x196A, "autosave" },
    { 0x196B, "autosave_after_shellshock" },
    { 0x196C, "autosave_block_in_drone" },
    { 0x196D, "autosave_by_name" },
    { 0x196E, "autosave_by_name_silent" },
    { 0x196F, "autosave_by_name_thread" },
    { 0x1970, "autosave_check_override" },
    { 0x1971, "autosave_hudfail_destroy" },
    { 0x1972, "autosave_hudfail_update" },
    { 0x1973, "autosave_hudprint" },
    { 0x1974, "autosave_loop" },
    { 0x1975, "autosave_now" },
    { 0x1976, "autosave_now_silent" },
    { 0x1977, "autosave_now_trigger" },
    { 0x1978, "autosave_or_timeout" },
    { 0x1979, "autosave_or_timeout_silent" },
    { 0x197A, "autosave_proximity_check" },
    { 0x197B, "autosave_proximity_threat_func" },
    { 0x197C, "autosave_proximity_threat_func_hometown" },
    { 0x197D, "autosave_setup_hometown" },
    { 0x197E, "autosave_stealth" },
    { 0x197F, "autosave_stealth_silent" },
    { 0x1980, "autosave_tactical" },
    { 0x1981, "autosave_tactical_grenade_check" },
    { 0x1982, "autosave_tactical_grenade_check_dieout" },
    { 0x1983, "autosave_tactical_grenade_check_wait_throw" },
    { 0x1984, "autosave_tactical_nade_flag_clear" },
    { 0x1985, "autosave_tactical_player_nades" },
    { 0x1986, "autosave_tactical_proc" },
    { 0x1987, "autosave_tactical_setup" },
    { 0x1988, "autosave_think" },
    { 0x1989, "autosave_threat_check_enabled" },
    { 0x198A, "autosave_try_once" },
    { 0x198B, "autosaveammocheck" },
    { 0x198C, "autosavecheck" },
    { 0x198D, "autosavecheck_not_picky" },
    { 0x198E, "autosavefriendlyfirecheck" },
    { 0x198F, "autosavehealthcheck" },
    { 0x1990, "autosaveplayercheck" },
    { 0x1991, "autosaveprint" },
    { 0x1992, "autosaveprint_hometown" },
    { 0x1993, "autosavethreatcheck" },
    { 0x1994, "autosavethreatcheck_hometown" },
    { 0x1995, "autosentry_hint_displayed" },
    { 0x1996, "autoshootanimrate" },
    { 0x1997, "autoshuffle" },
    { 0x1998, "autospotadswatcher" },
    { 0x1999, "autospotdeathwatcher" },
    { 0x199A, "autostructural" },
    { 0x199B, "autotarget" },
    { 0x199C, "available" },
    { 0x199D, "available_ai_vehicle_air_infils" },
    { 0x199E, "available_ai_vehicle_ground_infils" },
    { 0x199F, "available_id_for_bomb_detonator" },
    { 0x19A0, "available_ingredient_slots" },
    { 0x19A1, "available_on_start" },
    { 0x19A2, "available_player_characters" },
    { 0x19A3, "availablefunc" },
    { 0x19A4, "availableomnvars" },
    { 0x19A5, "availablepositions" },
    { 0x19A6, "availableseatid" },
    { 0x19A7, "availablespawnlocations" },
    { 0x19A8, "availableteam" },
    { 0x19A9, "avengedplayer" },
    { 0x19AA, "average_mag" },
    { 0x19AB, "average_velo" },
    { 0x19AC, "average_velocity" },
    { 0x19AD, "averagealliesz" },
    { 0x19AE, "avoid_other_helicopters" },
    { 0x19AF, "avoid_players_vision" },
    { 0x19B0, "avoid_recently_used_spawns" },
    { 0x19B1, "avoidbradleys" },
    { 0x19B2, "avoidcarepackages" },
    { 0x19B3, "avoidcloseenemies" },
    { 0x19B4, "avoidclosestenemy" },
    { 0x19B5, "avoidclosestenemybydistance" },
    { 0x19B6, "avoidclosetokothzone" },
    { 0x19B7, "avoidcornervisibleenemies" },
    { 0x19B8, "avoidenemiesbydistance" },
    { 0x19B9, "avoidenemyinfluence" },
    { 0x19BA, "avoidenemyspawn" },
    { 0x19BB, "avoidfullvisibleenemies" },
    { 0x19BC, "avoidgrenades" },
    { 0x19BD, "avoidkillstreakonspawntimer" },
    { 0x19BE, "avoidlastattackerlocation" },
    { 0x19BF, "avoidlastdeathlocation" },
    { 0x19C0, "avoidmines" },
    { 0x19C1, "avoidrecentlyusedbyanyone" },
    { 0x19C2, "avoidrecentlyusedbyenemies" },
    { 0x19C3, "avoidrugbyoffsides" },
    { 0x19C4, "avoidsamespawn" },
    { 0x19C5, "avoidshorttimetoenemysight" },
    { 0x19C6, "avoidshorttimetojumpingenemysight" },
    { 0x19C7, "avoidtelefrag" },
    { 0x19C8, "avoidveryshorttimetojumpingenemysight" },
    { 0x19C9, "awaitingdropgunnotetrack" },
    { 0x19CA, "awaitingpent" },
    { 0x19CB, "award_intel" },
    { 0x19CC, "awardbuffdebuffassists" },
    { 0x19CD, "awardcapturepoints" },
    { 0x19CE, "awardgenericmedals" },
    { 0x19CF, "awardhqpoints" },
    { 0x19D0, "awardkillstreak" },
    { 0x19D1, "awardkillstreakfromstruct" },
    { 0x19D2, "awardqueue" },
    { 0x19D3, "awards" },
    { 0x19D4, "awardsthislife" },
    { 0x19D5, "awardsuperlottery" },
    { 0x19D6, "awarenessadjustment" },
    { 0x19D7, "awarenessaudiopulse" },
    { 0x19D8, "awarenessmonitorstance" },
    { 0x19D9, "awarenessqueryrate" },
    { 0x19DA, "awarenessradius" },
    { 0x19DB, "axe_damage" },
    { 0x19DC, "axe_damage_cone" },
    { 0x19DD, "axe_hint_display" },
    { 0x19DE, "axedetachfromcorpse" },
    { 0x19DF, "axeswingnum" },
    { 0x19E0, "axis_attacked_think" },
    { 0x19E1, "axis_debug" },
    { 0x19E2, "axis_grenade_toggle" },
    { 0x19E3, "axis_shoot_think" },
    { 0x19E4, "axis_stealth_cqb_think" },
    { 0x19E5, "axis_stealth_filter" },
    { 0x19E6, "axis_stealth_spawnfunc" },
    { 0x19E7, "axis_toggle_flashlight_fx_at_dist" },
    { 0x19E8, "axisadjuststarttime" },
    { 0x19E9, "axisaverage" },
    { 0x19EA, "axiscapturing" },
    { 0x19EB, "axischopper" },
    { 0x19EC, "axisfrontlinevec" },
    { 0x19ED, "axishealth" },
    { 0x19EE, "axishqloc" },
    { 0x19EF, "axishqname" },
    { 0x19F0, "axismaxhealth" },
    { 0x19F1, "axismode" },
    { 0x19F2, "axisnoise" },
    { 0x19F3, "axisprevflagcount" },
    { 0x19F4, "axisspawnareas" },
    { 0x19F5, "axissquadleader" },
    { 0x19F6, "axisstartspawn" },
    { 0x19F7, "axiswinondeath" },
    { 0x19F8, "axiszone" },
    { 0x19F9, "ayah" },
    { 0x19FA, "azadeh" },
    { 0x19FB, "azadeh_brought_in" },
    { 0x19FC, "b" },
    { 0x19FD, "b_ac130decoytracked" },
    { 0x19FE, "b_cleared_for_drop" },
    { 0x19FF, "b_in_vehicle" },
    { 0x1A00, "b_mg_on_player" },
    { 0x1A01, "b_murderhole_suppression_tutorialized" },
    { 0x1A02, "b_player_exposed" },
    { 0x1A03, "b_should_get_hit" },
    { 0x1A04, "b_smoke" },
    { 0x1A05, "b_suppressed" },
    { 0x1A06, "b_switching_targets" },
    { 0x1A07, "b1_alpha5_action" },
    { 0x1A08, "b1_alpha5_lookat" },
    { 0x1A09, "b1_alpha5_vo" },
    { 0x1A0A, "b1_alpha6_action" },
    { 0x1A0B, "b1_alpha6_lookat" },
    { 0x1A0C, "b1_alpha6_vo" },
    { 0x1A0D, "b1_back_room_approach_vo" },
    { 0x1A0E, "b1_back_room_vo" },
    { 0x1A0F, "b1_breach_intro" },
    { 0x1A10, "b1_child" },
    { 0x1A11, "b1_child_action" },
    { 0x1A12, "b1_child_fail" },
    { 0x1A13, "b1_child_reaction_vo" },
    { 0x1A14, "b1_clear_vo" },
    { 0x1A15, "b1_door_nag" },
    { 0x1A16, "b1_door_quick_open" },
    { 0x1A17, "b1_door_runner" },
    { 0x1A18, "b1_door_setup" },
    { 0x1A19, "b1_flashbang_watcher" },
    { 0x1A1A, "b1_girl_action" },
    { 0x1A1B, "b1_girl_ads_watcher" },
    { 0x1A1C, "b1_girl_damage_watcher" },
    { 0x1A1D, "b1_girl_in_position" },
    { 0x1A1E, "b1_guy" },
    { 0x1A1F, "b1_guy_setup" },
    { 0x1A20, "b1_intro_death_watcher" },
    { 0x1A21, "b1_intro_guy" },
    { 0x1A22, "b1_mom_action" },
    { 0x1A23, "b1_mom_child_nag" },
    { 0x1A24, "b1_mom_damage_tracker" },
    { 0x1A25, "b1_mom_flashed" },
    { 0x1A26, "b1_mom_setup" },
    { 0x1A27, "b1_mom_swap_death" },
    { 0x1A28, "b1_mom_vo" },
    { 0x1A29, "b1_moveup_alpha6" },
    { 0x1A2A, "b1_open_door" },
    { 0x1A2B, "b1_runner" },
    { 0x1A2C, "b1_runner_action" },
    { 0x1A2D, "b1_runner_watcher" },
    { 0x1A2E, "b1_setup" },
    { 0x1A2F, "b1_sledge_intro" },
    { 0x1A30, "ba_countdown_start" },
    { 0x1A31, "ba_destroy_tanks_start" },
    { 0x1A32, "ba_end_sequence" },
    { 0x1A33, "ba_escape_debug_start" },
    { 0x1A34, "ba_escape_start" },
    { 0x1A35, "ba_escape_start_tank" },
    { 0x1A36, "ba_mnu_start" },
    { 0x1A37, "ba_router" },
    { 0x1A38, "ba_router_start" },
    { 0x1A39, "ba_searcarea_debug_start" },
    { 0x1A3A, "ba_searchareas_start" },
    { 0x1A3B, "ba_shiprecieve_start" },
    { 0x1A3C, "ba_steal_tank_start" },
    { 0x1A3D, "ba_tower_start" },
    { 0x1A3E, "babort" },
    { 0x1A3F, "baby" },
    { 0x1A40, "baby_blend_idle" },
    { 0x1A41, "baby_cry" },
    { 0x1A42, "baby_cry_hard" },
    { 0x1A43, "baby_death" },
    { 0x1A44, "baby_door_ondamage" },
    { 0x1A45, "baby_idle_relative" },
    { 0x1A46, "baby_mobile_stay_active" },
    { 0x1A47, "baby_mom" },
    { 0x1A48, "baby_mom_add_collision_head" },
    { 0x1A49, "baby_mom_anim" },
    { 0x1A4A, "baby_mom_anim_get" },
    { 0x1A4B, "baby_mom_anim_random" },
    { 0x1A4C, "baby_mom_clear_damageshield" },
    { 0x1A4D, "baby_mom_death_cleanup" },
    { 0x1A4E, "baby_mom_death_dialogue" },
    { 0x1A4F, "baby_mom_death_react" },
    { 0x1A50, "baby_mom_dialog" },
    { 0x1A51, "baby_mom_idle_react" },
    { 0x1A52, "baby_mom_is_ads" },
    { 0x1A53, "baby_mom_normal_death" },
    { 0x1A54, "baby_mom_ondamage" },
    { 0x1A55, "baby_mom_playdeath" },
    { 0x1A56, "baby_mom_prior_dialog" },
    { 0x1A57, "baby_mom_prior_dialog_internal" },
    { 0x1A58, "baby_mom_remove_death" },
    { 0x1A59, "baby_mom_stand_death" },
    { 0x1A5A, "baby_mom_use_move_death" },
    { 0x1A5B, "baby_mom_vo" },
    { 0x1A5C, "baby_pickup_by_allyanim" },
    { 0x1A5D, "baby_pickup_early_time_adjust" },
    { 0x1A5E, "baby_room" },
    { 0x1A5F, "baby_room_unlink_baby" },
    { 0x1A60, "babycry_hard_start" },
    { 0x1A61, "back_alley_autosave" },
    { 0x1A62, "back_backroom_player_standing_handler" },
    { 0x1A63, "back_bedroom_enemy" },
    { 0x1A64, "back_bedroom_enemy_death" },
    { 0x1A65, "back_enemy_watcher" },
    { 0x1A66, "back_line_enemies_attack_logic" },
    { 0x1A67, "back_line_enemy_attack_logic" },
    { 0x1A68, "back_on_roof_nag" },
    { 0x1A69, "back_street_drive" },
    { 0x1A6A, "back_street_traffic_drive" },
    { 0x1A6B, "back_suicide_truck_speed_manager" },
    { 0x1A6C, "back_trig" },
    { 0x1A6D, "backdoor_enter_count" },
    { 0x1A6E, "backdoor_enter_done" },
    { 0x1A6F, "backdoor_enter_hurry" },
    { 0x1A70, "backdoor_entry" },
    { 0x1A71, "backdoor_entry_thread" },
    { 0x1A72, "backdoor_freeze" },
    { 0x1A73, "backdoor_freeze_nag" },
    { 0x1A74, "backdoor_freeze_rate_thread" },
    { 0x1A75, "backdoor_freeze_thread" },
    { 0x1A76, "backdoor_lastguy_nag" },
    { 0x1A77, "backextents" },
    { 0x1A78, "backfillhvts" },
    { 0x1A79, "backfunction" },
    { 0x1A7A, "background_civ_vo" },
    { 0x1A7B, "background_civs" },
    { 0x1A7C, "background_fakeciv_idle" },
    { 0x1A7D, "background_fakeciv_loop" },
    { 0x1A7E, "background_fakeciv_scatter" },
    { 0x1A7F, "background_fakeciv_setup" },
    { 0x1A80, "background_fakecivs" },
    { 0x1A81, "background_guard_not_reachable_spawn_func" },
    { 0x1A82, "background_guard_spawn_func" },
    { 0x1A83, "background_heli_turret_cleanup" },
    { 0x1A84, "background_marine_handler" },
    { 0x1A85, "background_outside_murderhouse_allies_cleanup" },
    { 0x1A86, "background_scatter_fake" },
    { 0x1A87, "background_scatter_runto" },
    { 0x1A88, "background_vehicle_parking_lot_right_sound" },
    { 0x1A89, "background_window_scene" },
    { 0x1A8A, "backgroundguards" },
    { 0x1A8B, "backoffset" },
    { 0x1A8C, "backpack_delayshow" },
    { 0x1A8D, "backpoint" },
    { 0x1A8E, "backroom_check_if_player_jumps" },
    { 0x1A8F, "backroom_check_if_player_shoots" },
    { 0x1A90, "backroom_pre_combat_handler" },
    { 0x1A91, "backroom_price_follow_player" },
    { 0x1A92, "backstabber_stage" },
    { 0x1A93, "backstabber_update" },
    { 0x1A94, "backtracking_2f_nag" },
    { 0x1A95, "backup" },
    { 0x1A96, "backup_called_already" },
    { 0x1A97, "backup_deposit_names" },
    { 0x1A98, "backup_enemyvehiclescriptablelogic" },
    { 0x1A99, "backup_getanimationstruct" },
    { 0x1A9A, "backup_getenemyvehicle" },
    { 0x1A9B, "backup_getenemyvehiclespawner" },
    { 0x1A9C, "backup_guy_think" },
    { 0x1A9D, "backup_main" },
    { 0x1A9E, "backup_nodes" },
    { 0x1A9F, "backup_soldiers" },
    { 0x1AA0, "backup_spawned" },
    { 0x1AA1, "backup_spawnenemyvehicle" },
    { 0x1AA2, "backup_start" },
    { 0x1AA3, "backup_technical_check_passed" },
    { 0x1AA4, "backup_vehicleenemylogic" },
    { 0x1AA5, "backup_vehiclelogic" },
    { 0x1AA6, "backup_vehiclesfxlogic" },
    { 0x1AA7, "backup_vehiclewallalogic" },
    { 0x1AA8, "backuphead" },
    { 0x1AA9, "backupsuit" },
    { 0x1AAA, "backuptime" },
    { 0x1AAB, "backyard" },
    { 0x1AAC, "backyard_alley_move_solo" },
    { 0x1AAD, "backyard_alley_move_thread" },
    { 0x1AAE, "backyard_ally_counter" },
    { 0x1AAF, "backyard_backup_move" },
    { 0x1AB0, "backyard_catchup" },
    { 0x1AB1, "backyard_cut_gate" },
    { 0x1AB2, "backyard_door_open" },
    { 0x1AB3, "backyard_door_open_rotate" },
    { 0x1AB4, "backyard_door_setup" },
    { 0x1AB5, "backyard_fail_damage_thread" },
    { 0x1AB6, "backyard_fail_onexplode" },
    { 0x1AB7, "backyard_fail_thread" },
    { 0x1AB8, "backyard_force_fail" },
    { 0x1AB9, "backyard_free_move" },
    { 0x1ABA, "backyard_freeze_counter" },
    { 0x1ABB, "backyard_freeze_townhouse" },
    { 0x1ABC, "backyard_intro" },
    { 0x1ABD, "backyard_intro_anim" },
    { 0x1ABE, "backyard_intro_main" },
    { 0x1ABF, "backyard_intro_start" },
    { 0x1AC0, "backyard_lock_physics" },
    { 0x1AC1, "backyard_main" },
    { 0x1AC2, "backyard_move" },
    { 0x1AC3, "backyard_move_counter" },
    { 0x1AC4, "backyard_move_rate_thread" },
    { 0x1AC5, "backyard_move_thread" },
    { 0x1AC6, "backyard_player_safe_demeanor_thread" },
    { 0x1AC7, "backyard_setup" },
    { 0x1AC8, "backyard_start" },
    { 0x1AC9, "bad_ak_monitor" },
    { 0x1ACA, "bad_obstacle_id" },
    { 0x1ACB, "bad_place_remover" },
    { 0x1ACC, "baddies" },
    { 0x1ACD, "baddies_die" },
    { 0x1ACE, "badplace" },
    { 0x1ACF, "badplace_cylinder_func" },
    { 0x1AD0, "badplace_delete_func" },
    { 0x1AD1, "badplace_id" },
    { 0x1AD2, "badplace_manager" },
    { 0x1AD3, "badplaceavoid" },
    { 0x1AD4, "badplaceavoidstarttime" },
    { 0x1AD5, "badplaceint" },
    { 0x1AD6, "badplaces" },
    { 0x1AD7, "badplaceterminate" },
    { 0x1AD8, "badspawnreason" },
    { 0x1AD9, "badzone" },
    { 0x1ADA, "balanceteams" },
    { 0x1ADB, "balcony_3f_door" },
    { 0x1ADC, "balcony_damage_watcher" },
    { 0x1ADD, "balcony_enemy" },
    { 0x1ADE, "balcony_enemy_2f_action" },
    { 0x1ADF, "balcony_force_open_door" },
    { 0x1AE0, "balcony_hostage_anims_price" },
    { 0x1AE1, "balcony_hostage_dof" },
    { 0x1AE2, "balcony_hostage_intro_catchup" },
    { 0x1AE3, "balcony_hostage_intro_main" },
    { 0x1AE4, "balcony_hostage_intro_start" },
    { 0x1AE5, "balcony_marine_advancing" },
    { 0x1AE6, "balcony_sees_player" },
    { 0x1AE7, "balcony_vol_1" },
    { 0x1AE8, "balcony_watcher" },
    { 0x1AE9, "balconydeathnode" },
    { 0x1AEA, "ball" },
    { 0x1AEB, "ball_add_start" },
    { 0x1AEC, "ball_assign_start" },
    { 0x1AED, "ball_bot_attacker_limit_for_team" },
    { 0x1AEE, "ball_bot_defender_limit_for_team" },
    { 0x1AEF, "ball_can_pickup" },
    { 0x1AF0, "ball_carried" },
    { 0x1AF1, "ball_carrier_cleanup" },
    { 0x1AF2, "ball_carrier_touched_goal" },
    { 0x1AF3, "ball_check_assist" },
    { 0x1AF4, "ball_check_pass_kill_pickup" },
    { 0x1AF5, "ball_clear_contents" },
    { 0x1AF6, "ball_connect_watch" },
    { 0x1AF7, "ball_create_ball_starts" },
    { 0x1AF8, "ball_create_killcam_ent" },
    { 0x1AF9, "ball_create_team_goal" },
    { 0x1AFA, "ball_default_origins" },
    { 0x1AFB, "ball_dont_interpolate" },
    { 0x1AFC, "ball_download_fx" },
    { 0x1AFD, "ball_download_wait" },
    { 0x1AFE, "ball_drop_on_ability" },
    { 0x1AFF, "ball_find_ground" },
    { 0x1B00, "ball_fx_active" },
    { 0x1B01, "ball_fx_start" },
    { 0x1B02, "ball_fx_start_player" },
    { 0x1B03, "ball_fx_stop" },
    { 0x1B04, "ball_get_num_players_on_team" },
    { 0x1B05, "ball_get_path_dist" },
    { 0x1B06, "ball_get_view_team" },
    { 0x1B07, "ball_give_score" },
    { 0x1B08, "ball_goal_can_use" },
    { 0x1B09, "ball_goal_contested" },
    { 0x1B0A, "ball_goal_fx" },
    { 0x1B0B, "ball_goal_fx_for_player" },
    { 0x1B0C, "ball_goal_uncontested" },
    { 0x1B0D, "ball_goal_useobject" },
    { 0x1B0E, "ball_goals" },
    { 0x1B0F, "ball_impact_sounds" },
    { 0x1B10, "ball_in_goal" },
    { 0x1B11, "ball_init_map_min_max" },
    { 0x1B12, "ball_location_hud" },
    { 0x1B13, "ball_maxs" },
    { 0x1B14, "ball_mins" },
    { 0x1B15, "ball_on_connect" },
    { 0x1B16, "ball_on_host_migration" },
    { 0x1B17, "ball_on_pickup" },
    { 0x1B18, "ball_on_projectile_death" },
    { 0x1B19, "ball_on_projectile_hit_client" },
    { 0x1B1A, "ball_on_reset" },
    { 0x1B1B, "ball_overridemovingplatformdeath" },
    { 0x1B1C, "ball_pass_or_shoot" },
    { 0x1B1D, "ball_pass_or_throw_active" },
    { 0x1B1E, "ball_pass_projectile" },
    { 0x1B1F, "ball_pass_touch_goal" },
    { 0x1B20, "ball_pass_watch" },
    { 0x1B21, "ball_physics_bad_trigger_at_rest" },
    { 0x1B22, "ball_physics_bad_trigger_watch" },
    { 0x1B23, "ball_physics_fake_bounce" },
    { 0x1B24, "ball_physics_launch" },
    { 0x1B25, "ball_physics_launch_drop" },
    { 0x1B26, "ball_physics_out_of_level" },
    { 0x1B27, "ball_physics_timeout" },
    { 0x1B28, "ball_physics_touch_cant_pickup_player" },
    { 0x1B29, "ball_physics_touch_goal" },
    { 0x1B2A, "ball_play_fx_joined_team" },
    { 0x1B2B, "ball_play_local_team_sound" },
    { 0x1B2C, "ball_play_score_fx" },
    { 0x1B2D, "ball_player_on_connect" },
    { 0x1B2E, "ball_restore_contents" },
    { 0x1B2F, "ball_return_home" },
    { 0x1B30, "ball_score_event" },
    { 0x1B31, "ball_score_sound" },
    { 0x1B32, "ball_set_dropped" },
    { 0x1B33, "ball_set_role" },
    { 0x1B34, "ball_shoot_watch" },
    { 0x1B35, "ball_spawn" },
    { 0x1B36, "ball_starts" },
    { 0x1B37, "ball_touch_goal_watch" },
    { 0x1B38, "ball_touched_goal" },
    { 0x1B39, "ball_track_pass_lifetime" },
    { 0x1B3A, "ball_track_pass_velocity" },
    { 0x1B3B, "ball_track_target" },
    { 0x1B3C, "ball_triggers" },
    { 0x1B3D, "ball_waypoint_contest" },
    { 0x1B3E, "ball_waypoint_download" },
    { 0x1B3F, "ball_waypoint_held" },
    { 0x1B40, "ball_waypoint_neutral" },
    { 0x1B41, "ball_waypoint_reset" },
    { 0x1B42, "ball_waypoint_upload" },
    { 0x1B43, "ball_weapon_change_watch" },
    { 0x1B44, "ballactivationdelay" },
    { 0x1B45, "ballallowedtriggers" },
    { 0x1B46, "ballbases" },
    { 0x1B47, "balldrones" },
    { 0x1B48, "balldropdelay" },
    { 0x1B49, "ballendtime" },
    { 0x1B4A, "ballindex" },
    { 0x1B4B, "ballisticdontpenetrate" },
    { 0x1B4C, "ballistics" },
    { 0x1B4D, "ballistics_aiignoreballisticsweaponpain" },
    { 0x1B4E, "ballistics_bulletfiremonitor" },
    { 0x1B4F, "ballistics_createbullet" },
    { 0x1B50, "ballistics_delaybulletshow" },
    { 0x1B51, "ballistics_delaybulletvfx" },
    { 0x1B52, "ballistics_deletebullet" },
    { 0x1B53, "ballistics_doesbullettrajectoryhitentity" },
    { 0x1B54, "ballistics_impactvfxentitylogic" },
    { 0x1B55, "ballistics_impactvfxentityparentlogic" },
    { 0x1B56, "ballistics_killai" },
    { 0x1B57, "ballistics_playerholdingballisticsweapon" },
    { 0x1B58, "ballistics_rotateflags" },
    { 0x1B59, "ballistics_shoulddamageai" },
    { 0x1B5A, "ballistics_shouldkillai" },
    { 0x1B5B, "ballistics_wasaidamagedbyplayerballisticsweapon" },
    { 0x1B5C, "ballistics_wasainotdamagedbyplayerballisticsweapon" },
    { 0x1B5D, "balloon_hint_displayed" },
    { 0x1B5E, "ballowfinish" },
    { 0x1B5F, "ballowsecondaries" },
    { 0x1B60, "ballpassdist" },
    { 0x1B61, "ballphysicscontentoverride" },
    { 0x1B62, "ballpickupscorefrozen" },
    { 0x1B63, "ballreset" },
    { 0x1B64, "ballruntimer" },
    { 0x1B65, "balls" },
    { 0x1B66, "balltime" },
    { 0x1B67, "balltimerpaused" },
    { 0x1B68, "balltimerstopped" },
    { 0x1B69, "balltimerwait" },
    { 0x1B6A, "balltraceradius" },
    { 0x1B6B, "ballweapon" },
    { 0x1B6C, "balocked" },
    { 0x1B6D, "balwayscoverexposed" },
    { 0x1B6E, "bandageactive" },
    { 0x1B6F, "bandageheal" },
    { 0x1B70, "bang_bangs" },
    { 0x1B71, "bank_alarm_sfx" },
    { 0x1B72, "bank_ecounterstart" },
    { 0x1B73, "bank_elevator" },
    { 0x1B74, "bank_getspawneraitype" },
    { 0x1B75, "bank_hvt" },
    { 0x1B76, "bank_hvt_cig" },
    { 0x1B77, "bank_hvt_jugg" },
    { 0x1B78, "bank_hvt_usb" },
    { 0x1B79, "bank_roof_doors_clip" },
    { 0x1B7A, "bank_stair_doors" },
    { 0x1B7B, "bank_stair_doors_clip" },
    { 0x1B7C, "bankalltriggers" },
    { 0x1B7D, "bankcapturetime" },
    { 0x1B7E, "bankdisable" },
    { 0x1B7F, "bankdisabletags" },
    { 0x1B80, "bankdisabletime" },
    { 0x1B81, "banklights" },
    { 0x1B82, "bankplayerentering" },
    { 0x1B83, "bankplayerexiting" },
    { 0x1B84, "bankplunder" },
    { 0x1B85, "bankplunderdeposited" },
    { 0x1B86, "bankplunderongameended" },
    { 0x1B87, "bankrate" },
    { 0x1B88, "banktags" },
    { 0x1B89, "bankthink" },
    { 0x1B8A, "banktime" },
    { 0x1B8B, "bankturnoffalarm" },
    { 0x1B8C, "bankturnonalarm" },
    { 0x1B8D, "bar" },
    { 0x1B8E, "bar_ai_combat_behavior" },
    { 0x1B8F, "bar_alley_entrance_door_interacted" },
    { 0x1B90, "bar_animate_door" },
    { 0x1B91, "bar_back_aq_anim" },
    { 0x1B92, "bar_backroom_catchup" },
    { 0x1B93, "bar_backroom_main" },
    { 0x1B94, "bar_backroom_player_kill" },
    { 0x1B95, "bar_backroom_player_speed_handler" },
    { 0x1B96, "bar_backroom_start" },
    { 0x1B97, "bar_backroom_stp_main" },
    { 0x1B98, "bar_containment" },
    { 0x1B99, "bar_enforcer_second_handler" },
    { 0x1B9A, "bar_enforcer_third_handler" },
    { 0x1B9B, "bar_init" },
    { 0x1B9C, "bar_interior_exit_door_handler" },
    { 0x1B9D, "bar_pooltable_aq_anim" },
    { 0x1B9E, "bar_price_handler" },
    { 0x1B9F, "bar_right_aq_anim" },
    { 0x1BA0, "bar_rotate_door" },
    { 0x1BA1, "bar_shootout_ai_dead_check" },
    { 0x1BA2, "bar_shootout_aq" },
    { 0x1BA3, "bar_shootout_aq_fallback" },
    { 0x1BA4, "bar_shootout_aq_regular" },
    { 0x1BA5, "bar_shootout_aq_retreater" },
    { 0x1BA6, "bar_shootout_catchup" },
    { 0x1BA7, "bar_shootout_door_bash_monitor" },
    { 0x1BA8, "bar_shootout_door_close" },
    { 0x1BA9, "bar_shootout_door_handler" },
    { 0x1BAA, "bar_shootout_door_sight_trace_monitor" },
    { 0x1BAB, "bar_shootout_enemies" },
    { 0x1BAC, "bar_shootout_enemy_shot_earlier" },
    { 0x1BAD, "bar_shootout_enforcer_impulse" },
    { 0x1BAE, "bar_shootout_exit_alley_door_handler" },
    { 0x1BAF, "bar_shootout_handler" },
    { 0x1BB0, "bar_shootout_main" },
    { 0x1BB1, "bar_shootout_player_hiding" },
    { 0x1BB2, "bar_shootout_player_kill" },
    { 0x1BB3, "bar_shootout_price_advance" },
    { 0x1BB4, "bar_shootout_price_pain_handler" },
    { 0x1BB5, "bar_shootout_retreat_enemy_handler" },
    { 0x1BB6, "bar_shootout_send_retreater_to_goal" },
    { 0x1BB7, "bar_shootout_special_mb" },
    { 0x1BB8, "bar_shootout_start" },
    { 0x1BB9, "bar_shootout_stp_main" },
    { 0x1BBA, "bar_street_ai_combat_behavior" },
    { 0x1BBB, "bar_street_aq_death_check" },
    { 0x1BBC, "bar_street_aq_door" },
    { 0x1BBD, "bar_street_aq_door_extra" },
    { 0x1BBE, "bar_street_aq_handler" },
    { 0x1BBF, "bar_street_aq_hangback" },
    { 0x1BC0, "bar_street_catchup" },
    { 0x1BC1, "bar_street_civ_shot_squib" },
    { 0x1BC2, "bar_street_combat_handler" },
    { 0x1BC3, "bar_street_containment" },
    { 0x1BC4, "bar_street_dead_bodies" },
    { 0x1BC5, "bar_street_enforcer_flee" },
    { 0x1BC6, "bar_street_enforcer_mb" },
    { 0x1BC7, "bar_street_enforcer_spawn" },
    { 0x1BC8, "bar_street_extra_car" },
    { 0x1BC9, "bar_street_fleeing_civs_vignettes" },
    { 0x1BCA, "bar_street_garbage_bag_blood" },
    { 0x1BCB, "bar_street_garbage_bag_place" },
    { 0x1BCC, "bar_street_mag_bullet" },
    { 0x1BCD, "bar_street_main" },
    { 0x1BCE, "bar_street_player_kill" },
    { 0x1BCF, "bar_street_price_advance" },
    { 0x1BD0, "bar_street_price_handler" },
    { 0x1BD1, "bar_street_price_intro_gopath" },
    { 0x1BD2, "bar_street_price_wait" },
    { 0x1BD3, "bar_street_start" },
    { 0x1BD4, "bar_street_stp_main" },
    { 0x1BD5, "bar_street_swap_corpses_with_trash" },
    { 0x1BD6, "bar_street_timer_handler" },
    { 0x1BD7, "bar_street_turn_car_alarms_off" },
    { 0x1BD8, "barcov_pain" },
    { 0x1BD9, "barkouterradiussq" },
    { 0x1BDA, "barkov" },
    { 0x1BDB, "barkov_charged_player_vo" },
    { 0x1BDC, "barkov_check_for_melee_range" },
    { 0x1BDD, "barkov_choke_scene" },
    { 0x1BDE, "barkov_choke_takedown_anims" },
    { 0x1BDF, "barkov_crawl_anim" },
    { 0x1BE0, "barkov_crawl_anim_shot" },
    { 0x1BE1, "barkov_crawl_scene" },
    { 0x1BE2, "barkov_damage" },
    { 0x1BE3, "barkov_damage_ending" },
    { 0x1BE4, "barkov_damage_ending_setup" },
    { 0x1BE5, "barkov_damage_notifies" },
    { 0x1BE6, "barkov_damaged_during_anim" },
    { 0x1BE7, "barkov_death" },
    { 0x1BE8, "barkov_dialog_interrupt" },
    { 0x1BE9, "barkov_dof" },
    { 0x1BEA, "barkov_final_anim_and_cleanup" },
    { 0x1BEB, "barkov_firing_loop" },
    { 0x1BEC, "barkov_gun_path" },
    { 0x1BED, "barkov_has_no_head" },
    { 0x1BEE, "barkov_idle_vo" },
    { 0x1BEF, "barkov_in_player_sight" },
    { 0x1BF0, "barkov_is_armed" },
    { 0x1BF1, "barkov_kick_dialog" },
    { 0x1BF2, "barkov_kick_out_scene" },
    { 0x1BF3, "barkov_kickoff_anim" },
    { 0x1BF4, "barkov_kills_player" },
    { 0x1BF5, "barkov_lookback_scene_start" },
    { 0x1BF6, "barkov_mayhem_end" },
    { 0x1BF7, "barkov_melee_path" },
    { 0x1BF8, "barkov_melee_setup" },
    { 0x1BF9, "barkov_move_to_corner" },
    { 0x1BFA, "barkov_orders_turn_to_face" },
    { 0x1BFB, "barkov_pain" },
    { 0x1BFC, "barkov_perform_partial_shock" },
    { 0x1BFD, "barkov_perform_shock" },
    { 0x1BFE, "barkov_play_anime_into_idle" },
    { 0x1BFF, "barkov_play_chained_anime_into_idle" },
    { 0x1C00, "barkov_play_idle" },
    { 0x1C01, "barkov_play_response" },
    { 0x1C02, "barkov_return_ready_next_anim" },
    { 0x1C03, "barkov_shooting_path" },
    { 0x1C04, "barkov_shoots" },
    { 0x1C05, "barkov_shot_dialog" },
    { 0x1C06, "barkov_shot_dialog_internal" },
    { 0x1C07, "barkov_shot_loop" },
    { 0x1C08, "barkov_spawn_func" },
    { 0x1C09, "barkov_stab_dialog" },
    { 0x1C0A, "barkov_stab_loop" },
    { 0x1C0B, "barkov_stab_post_melee" },
    { 0x1C0C, "barkov_start_choke_effect" },
    { 0x1C0D, "barkov_start_escort" },
    { 0x1C0E, "barkov_struggle_setup" },
    { 0x1C0F, "barkov_swap_to_blendshape" },
    { 0x1C10, "barkov_tell_face_wall" },
    { 0x1C11, "barkov_watcher_attack" },
    { 0x1C12, "barkov_wind_change" },
    { 0x1C13, "barkov_within_melee_range" },
    { 0x1C14, "barkovchopper" },
    { 0x1C15, "barkovfakebodies" },
    { 0x1C16, "barkovmaxmeleedistsq" },
    { 0x1C17, "barkovmodel" },
    { 0x1C18, "barkovreloading" },
    { 0x1C19, "barkovspeakerlineindex" },
    { 0x1C1A, "barkradiussq" },
    { 0x1C1B, "barracks_civ" },
    { 0x1C1C, "barrel_animate_player" },
    { 0x1C1D, "barrel_block_gesture" },
    { 0x1C1E, "barrel_cancel_animate_player" },
    { 0x1C1F, "barrel_cleanup" },
    { 0x1C20, "barrel_collect_chance" },
    { 0x1C21, "barrel_debug" },
    { 0x1C22, "barrel_early_exit" },
    { 0x1C23, "barrel_freeze" },
    { 0x1C24, "barrel_fulton" },
    { 0x1C25, "barrel_fusetimer" },
    { 0x1C26, "barrel_handle_cancellation" },
    { 0x1C27, "barrel_health" },
    { 0x1C28, "barrel_launch" },
    { 0x1C29, "barrel_nav_obstruction" },
    { 0x1C2A, "barrel_one_hit_kill" },
    { 0x1C2B, "barrel_player" },
    { 0x1C2C, "barrel_reaction_gesture" },
    { 0x1C2D, "barrel_setup" },
    { 0x1C2E, "barrel_setup_anims" },
    { 0x1C2F, "barrel_thread_setup" },
    { 0x1C30, "barrel_unfreeze" },
    { 0x1C31, "barrel_wind_to_above_truck" },
    { 0x1C32, "barrelbarrel_damage_thread" },
    { 0x1C33, "barrels" },
    { 0x1C34, "barrels_on_death" },
    { 0x1C35, "barrelscan_animactor" },
    { 0x1C36, "barrelscan_animscene" },
    { 0x1C37, "barrelshouldexplode" },
    { 0x1C38, "barricade_player_crushed_monitor" },
    { 0x1C39, "barrier" },
    { 0x1C3A, "barrier_deathfunc" },
    { 0x1C3B, "barrier_destroy" },
    { 0x1C3C, "barrier_dmgfunc" },
    { 0x1C3D, "barrier_explode" },
    { 0x1C3E, "barriermonitordamage" },
    { 0x1C3F, "barriermonitordeath" },
    { 0x1C40, "bars_out" },
    { 0x1C41, "base" },
    { 0x1C42, "base_accuracy" },
    { 0x1C43, "base_anim" },
    { 0x1C44, "base_anime" },
    { 0x1C45, "base_button_text" },
    { 0x1C46, "base_explosion_test" },
    { 0x1C47, "base_setupvfx" },
    { 0x1C48, "base_speed" },
    { 0x1C49, "base_speedscale" },
    { 0x1C4A, "base_tank_ai_speed" },
    { 0x1C4B, "base_weapon" },
    { 0x1C4C, "baseaccuracy" },
    { 0x1C4D, "basealias" },
    { 0x1C4E, "basealpha" },
    { 0x1C4F, "baseangle" },
    { 0x1C50, "baseangles" },
    { 0x1C51, "basecam" },
    { 0x1C52, "baseeffectforward" },
    { 0x1C53, "baseeffectpos" },
    { 0x1C54, "basefontscale" },
    { 0x1C55, "basefusetimers" },
    { 0x1C56, "basefxid" },
    { 0x1C57, "baseheight" },
    { 0x1C58, "baseignorerandombulletdamage" },
    { 0x1C59, "baseintensity" },
    { 0x1C5A, "basekilloutlineid" },
    { 0x1C5B, "basement" },
    { 0x1C5C, "basement_aq" },
    { 0x1C5D, "basement_bodies" },
    { 0x1C5E, "basement_catchup" },
    { 0x1C5F, "basement_ceiling_guy" },
    { 0x1C60, "basement_ceiling_guy_flashlight" },
    { 0x1C61, "basement_ceiling_ignoreme_think" },
    { 0x1C62, "basement_check_crowguy_death" },
    { 0x1C63, "basement_collapse_crawl_vo" },
    { 0x1C64, "basement_collapse_crawl_vo_structs" },
    { 0x1C65, "basement_collapse_crawl_vo_structs_debug" },
    { 0x1C66, "basement_collapse_lights_on" },
    { 0x1C67, "basement_collapse_lights_out" },
    { 0x1C68, "basement_collapse_objective_update" },
    { 0x1C69, "basement_coward" },
    { 0x1C6A, "basement_door_enter" },
    { 0x1C6B, "basement_door_guy" },
    { 0x1C6C, "basement_door_surprise_guy" },
    { 0x1C6D, "basement_enemy_flare_throw" },
    { 0x1C6E, "basement_enemy_sfx" },
    { 0x1C6F, "basement_enemy_vo" },
    { 0x1C70, "basement_env_fx" },
    { 0x1C71, "basement_falling_rocks_thingy" },
    { 0x1C72, "basement_farah_lights_out_and_tripwire_hint_vo" },
    { 0x1C73, "basement_final_guy" },
    { 0x1C74, "basement_first_blast_behavior" },
    { 0x1C75, "basement_first_blast_cancel" },
    { 0x1C76, "basement_first_cell_guy" },
    { 0x1C77, "basement_first_cell_guy_canned_once" },
    { 0x1C78, "basement_footsteps" },
    { 0x1C79, "basement_guard_combat_stealth_filter" },
    { 0x1C7A, "basement_guard_combat_think" },
    { 0x1C7B, "basement_guard_death_func" },
    { 0x1C7C, "basement_guard_has_lost_enemy" },
    { 0x1C7D, "basement_guard_pre_combat_stealth_filter" },
    { 0x1C7E, "basement_guard_pre_stealth_filter" },
    { 0x1C7F, "basement_guard_spawn_func" },
    { 0x1C80, "basement_guard_stealth_filter" },
    { 0x1C81, "basement_guards" },
    { 0x1C82, "basement_guy" },
    { 0x1C83, "basement_guy_wake_by_trigger" },
    { 0x1C84, "basement_intro_add_fov_scale_factor_override" },
    { 0x1C85, "basement_intro_farah" },
    { 0x1C86, "basement_intro_player_speed_management" },
    { 0x1C87, "basement_intro_scene" },
    { 0x1C88, "basement_intro_skip_think" },
    { 0x1C89, "basement_intro_vo" },
    { 0x1C8A, "basement_jump_start" },
    { 0x1C8B, "basement_left_flank_camper" },
    { 0x1C8C, "basement_left_flank_camper_long_death_think" },
    { 0x1C8D, "basement_light_models" },
    { 0x1C8E, "basement_lights" },
    { 0x1C8F, "basement_lights_out" },
    { 0x1C90, "basement_live_grenade_monitor" },
    { 0x1C91, "basement_main" },
    { 0x1C92, "basement_override_price_demeanor" },
    { 0x1C93, "basement_paul_revere_behavior" },
    { 0x1C94, "basement_paul_revere_scene" },
    { 0x1C95, "basement_player_rush_handler" },
    { 0x1C96, "basement_price" },
    { 0x1C97, "basement_price_vo" },
    { 0x1C98, "basement_right_flank_runner" },
    { 0x1C99, "basement_right_flank_surprise" },
    { 0x1C9A, "basement_runner" },
    { 0x1C9B, "basement_runners" },
    { 0x1C9C, "basement_setup" },
    { 0x1C9D, "basement_sneak_1" },
    { 0x1C9E, "basement_sneak_1_animated" },
    { 0x1C9F, "basement_sneak_1_backup" },
    { 0x1CA0, "basement_sneak_1_backup_spawn" },
    { 0x1CA1, "basement_special_magic_flash" },
    { 0x1CA2, "basement_special_magic_molotov" },
    { 0x1CA3, "basement_special_magic_molotov_exploder_cleanup" },
    { 0x1CA4, "basement_sr_crowbar" },
    { 0x1CA5, "basement_sr_crowguy" },
    { 0x1CA6, "basement_sr_last_stand" },
    { 0x1CA7, "basement_start" },
    { 0x1CA8, "basement_stealth_catchup" },
    { 0x1CA9, "basement_stealth_eventdists" },
    { 0x1CAA, "basement_stealth_flags" },
    { 0x1CAB, "basement_stealth_main" },
    { 0x1CAC, "basement_stealth_melee_counter_monitor" },
    { 0x1CAD, "basement_stealth_stairwell_cleanup" },
    { 0x1CAE, "basement_stealth_start" },
    { 0x1CAF, "basement_triggered_vo" },
    { 0x1CB0, "basement_tunnel" },
    { 0x1CB1, "basement_tunnel_catchup" },
    { 0x1CB2, "basement_tunnel_dof" },
    { 0x1CB3, "basement_tunnel_start" },
    { 0x1CB4, "basement_vo" },
    { 0x1CB5, "basement_vo_another_tripwire" },
    { 0x1CB6, "basement_vo_farah_followup" },
    { 0x1CB7, "basement_vo_player" },
    { 0x1CB8, "basement_vo_player_play" },
    { 0x1CB9, "basement_vo_whisper" },
    { 0x1CBA, "basement_whisper_lights_scene" },
    { 0x1CBB, "basementguards" },
    { 0x1CBC, "baseorigin" },
    { 0x1CBD, "baseplate_dialogue_struct" },
    { 0x1CBE, "basepoints" },
    { 0x1CBF, "baseraidalblur" },
    { 0x1CC0, "baseraritymap" },
    { 0x1CC1, "basescore" },
    { 0x1CC2, "basetacopstimelimit" },
    { 0x1CC3, "basetime" },
    { 0x1CC4, "baseweapon" },
    { 0x1CC5, "basewidth" },
    { 0x1CC6, "bash_debug" },
    { 0x1CC7, "bash_door_isplayerclose" },
    { 0x1CC8, "bash_manager" },
    { 0x1CC9, "bash_monitor" },
    { 0x1CCA, "bash_opening" },
    { 0x1CCB, "bashblocked" },
    { 0x1CCC, "bashed" },
    { 0x1CCD, "bashed_full" },
    { 0x1CCE, "bashed_locked_door" },
    { 0x1CCF, "bashed_locked_door_sfx" },
    { 0x1CD0, "bashedsfx" },
    { 0x1CD1, "basher_count" },
    { 0x1CD2, "bashmonitor" },
    { 0x1CD3, "bashopen" },
    { 0x1CD4, "bashpresentation" },
    { 0x1CD5, "bashproxcheck" },
    { 0x1CD6, "bashscale" },
    { 0x1CD7, "bashtime" },
    { 0x1CD8, "basketballhighscore" },
    { 0x1CD9, "bathroom_2f_guy_breathing" },
    { 0x1CDA, "bathroom_damage_func" },
    { 0x1CDB, "bathroom_door" },
    { 0x1CDC, "bathroom_enemy" },
    { 0x1CDD, "bathroom_enemy_audio" },
    { 0x1CDE, "bathroom_enemy_audio_close" },
    { 0x1CDF, "bathroom_enemy_death" },
    { 0x1CE0, "bathroom_enemy_death_func" },
    { 0x1CE1, "bathroom_enemy_react" },
    { 0x1CE2, "bathroom_enemy_react_anim" },
    { 0x1CE3, "bathroom_flash_think" },
    { 0x1CE4, "bathroom_inner_trigger" },
    { 0x1CE5, "bathroom_nade_think" },
    { 0x1CE6, "bathroom_sfx" },
    { 0x1CE7, "bathroom_stop_deathanim" },
    { 0x1CE8, "bathroom_trigger_damage_ondamage" },
    { 0x1CE9, "bathroom_trigger_damage_onflashbang" },
    { 0x1CEA, "bathroom_trigger_think" },
    { 0x1CEB, "battery" },
    { 0x1CEC, "battle_chatter_armory_01" },
    { 0x1CED, "battlecenter" },
    { 0x1CEE, "battlechatter" },
    { 0x1CEF, "battlechatter_addvehicle" },
    { 0x1CF0, "battlechatter_alias" },
    { 0x1CF1, "battlechatter_anim_active" },
    { 0x1CF2, "battlechatter_canprint" },
    { 0x1CF3, "battlechatter_canprintdump" },
    { 0x1CF4, "battlechatter_canprintscreen" },
    { 0x1CF5, "battlechatter_commander_off" },
    { 0x1CF6, "battlechatter_commander_on" },
    { 0x1CF7, "battlechatter_debugprint" },
    { 0x1CF8, "battlechatter_dist_check" },
    { 0x1CF9, "battlechatter_draw_arrow" },
    { 0x1CFA, "battlechatter_filter_internal" },
    { 0x1CFB, "battlechatter_filter_off" },
    { 0x1CFC, "battlechatter_filter_on" },
    { 0x1CFD, "battlechatter_friendlyfire_force" },
    { 0x1CFE, "battlechatter_line_ok" },
    { 0x1CFF, "battlechatter_off" },
    { 0x1D00, "battlechatter_off_spawn_func" },
    { 0x1D01, "battlechatter_on" },
    { 0x1D02, "battlechatter_on_thread" },
    { 0x1D03, "battlechatter_otn_off" },
    { 0x1D04, "battlechatter_otn_on" },
    { 0x1D05, "battlechatter_print" },
    { 0x1D06, "battlechatter_printdump" },
    { 0x1D07, "battlechatter_printdumpline" },
    { 0x1D08, "battlechatter_printerror" },
    { 0x1D09, "battlechatter_printscreen" },
    { 0x1D0A, "battlechatter_printscreenadd" },
    { 0x1D0B, "battlechatter_printwarning" },
    { 0x1D0C, "battlechatter_probability" },
    { 0x1D0D, "battlechatter_radioecho_off" },
    { 0x1D0E, "battlechatter_radioecho_on" },
    { 0x1D0F, "battlechatter_removed" },
    { 0x1D10, "battlechatter_saytimescaled" },
    { 0x1D11, "battlechatter_target" },
    { 0x1D12, "battlechatterallowed" },
    { 0x1D13, "battlechattercustom" },
    { 0x1D14, "battlechatterenabled" },
    { 0x1D15, "battlechatterintensitybuffer" },
    { 0x1D16, "battleslid" },
    { 0x1D17, "battleslideshield" },
    { 0x1D18, "battleslideshield_break" },
    { 0x1D19, "battleslideshield_breakfx" },
    { 0x1D1A, "battleslideshield_damagedfx" },
    { 0x1D1B, "battleslideshield_killondeathdisconnectunset" },
    { 0x1D1C, "battleslideshield_killonjumpfall" },
    { 0x1D1D, "battleslideshield_killonsprint" },
    { 0x1D1E, "battleslideshield_killontime" },
    { 0x1D1F, "battleslideshield_lower" },
    { 0x1D20, "battleslideshield_lowerfx" },
    { 0x1D21, "battleslideshield_loweronleavearea" },
    { 0x1D22, "battleslideshield_lowerontime" },
    { 0x1D23, "battleslideshield_monitor" },
    { 0x1D24, "battleslideshield_monitorhealth" },
    { 0x1D25, "battleslideshield_raise" },
    { 0x1D26, "battleslideshield_raisefx" },
    { 0x1D27, "battleslideshield_unlink" },
    { 0x1D28, "battleslideshield_unlinkonstop" },
    { 0x1D29, "bautonomouscombat" },
    { 0x1D2A, "bb_canplaygesture" },
    { 0x1D2B, "bb_canrodeo" },
    { 0x1D2C, "bb_civilianrequestspeed" },
    { 0x1D2D, "bb_claimshootparams" },
    { 0x1D2E, "bb_clearanimscripted" },
    { 0x1D2F, "bb_clearmeleechargerequest" },
    { 0x1D30, "bb_clearmeleerequest" },
    { 0x1D31, "bb_clearmeleerequestcomplete" },
    { 0x1D32, "bb_clearmeleetarget" },
    { 0x1D33, "bb_clearmoverequest" },
    { 0x1D34, "bb_clearplaysmartobject" },
    { 0x1D35, "bb_clearrodeorequest" },
    { 0x1D36, "bb_clearshootparams" },
    { 0x1D37, "bb_clearsmartobject" },
    { 0x1D38, "bb_clearweaponrequest" },
    { 0x1D39, "bb_dismemberedpart" },
    { 0x1D3A, "bb_firerequested" },
    { 0x1D3B, "bb_getcivilianstate" },
    { 0x1D3C, "bb_getcivilianstatetime" },
    { 0x1D3D, "bb_getcovernode" },
    { 0x1D3E, "bb_gethaywire" },
    { 0x1D3F, "bb_getmeleechargetarget" },
    { 0x1D40, "bb_getmeleechargetargetpos" },
    { 0x1D41, "bb_getmeleetarget" },
    { 0x1D42, "bb_getmissingleg" },
    { 0x1D43, "bb_getprefixstring" },
    { 0x1D44, "bb_getrequestedcoverexposetype" },
    { 0x1D45, "bb_getrequestedcovermultiswitchnodetype" },
    { 0x1D46, "bb_getrequestedcoverstate" },
    { 0x1D47, "bb_getrequestedsmartobject" },
    { 0x1D48, "bb_getrequestedstance" },
    { 0x1D49, "bb_getrequestedturret" },
    { 0x1D4A, "bb_getrequestedweapon" },
    { 0x1D4B, "bb_getrequestedwhizby" },
    { 0x1D4C, "bb_getthrowgrenadetarget" },
    { 0x1D4D, "bb_hadcovernode" },
    { 0x1D4E, "bb_hasshufflenode" },
    { 0x1D4F, "bb_isanimscripted" },
    { 0x1D50, "bb_iscovermultiswitchrequested" },
    { 0x1D51, "bb_iscrawlmelee" },
    { 0x1D52, "bb_isfrantic" },
    { 0x1D53, "bb_ishaywire" },
    { 0x1D54, "bb_isheadless" },
    { 0x1D55, "bb_isinbadcrouchspot" },
    { 0x1D56, "bb_isincombat" },
    { 0x1D57, "bb_ismissingaleg" },
    { 0x1D58, "bb_ispartdismembered" },
    { 0x1D59, "bb_isrequestedstance_refresh" },
    { 0x1D5A, "bb_isrequestedstanceanddemeanor" },
    { 0x1D5B, "bb_isrodeorequested" },
    { 0x1D5C, "bb_issameshootparamsent" },
    { 0x1D5D, "bb_isselfdestruct" },
    { 0x1D5E, "bb_isshort" },
    { 0x1D5F, "bb_isweaponclass" },
    { 0x1D60, "bb_iswhizbyrequested" },
    { 0x1D61, "bb_meleechargeaborted" },
    { 0x1D62, "bb_meleechargerequested" },
    { 0x1D63, "bb_meleecomplete" },
    { 0x1D64, "bb_meleeinprogress" },
    { 0x1D65, "bb_meleerequested" },
    { 0x1D66, "bb_meleerequestinvalid" },
    { 0x1D67, "bb_moverequested" },
    { 0x1D68, "bb_movetyperequested" },
    { 0x1D69, "bb_newshootparams" },
    { 0x1D6A, "bb_playsmartobjectrequested" },
    { 0x1D6B, "bb_recovery" },
    { 0x1D6C, "bb_reloadrequested" },
    { 0x1D6D, "bb_requestcoverblindfire" },
    { 0x1D6E, "bb_requestcoverexposetype" },
    { 0x1D6F, "bb_requestcovermultiswitch" },
    { 0x1D70, "bb_requestcoverstate" },
    { 0x1D71, "bb_requestfire" },
    { 0x1D72, "bb_requestgrenadereturnthrow" },
    { 0x1D73, "bb_requestmelee" },
    { 0x1D74, "bb_requestmeleecharge" },
    { 0x1D75, "bb_requestmove" },
    { 0x1D76, "bb_requestmovetype" },
    { 0x1D77, "bb_requestplaysmartobject" },
    { 0x1D78, "bb_requestreload" },
    { 0x1D79, "bb_requestsmartobject" },
    { 0x1D7A, "bb_requeststance" },
    { 0x1D7B, "bb_requestthrowgrenade" },
    { 0x1D7C, "bb_requestturret" },
    { 0x1D7D, "bb_requestturretpose" },
    { 0x1D7E, "bb_requestweapon" },
    { 0x1D7F, "bb_requestwhizby" },
    { 0x1D80, "bb_resetcovermultiswitch" },
    { 0x1D81, "bb_selfdestructnow" },
    { 0x1D82, "bb_setanimscripted" },
    { 0x1D83, "bb_setcanrodeo" },
    { 0x1D84, "bb_setcivilianstate" },
    { 0x1D85, "bb_setcovernode" },
    { 0x1D86, "bb_setcrawlmelee" },
    { 0x1D87, "bb_sethaywire" },
    { 0x1D88, "bb_setheadless" },
    { 0x1D89, "bb_setisinbadcrouchspot" },
    { 0x1D8A, "bb_setisincombat" },
    { 0x1D8B, "bb_setmeleetarget" },
    { 0x1D8C, "bb_setrodeorequest" },
    { 0x1D8D, "bb_setselfdestruct" },
    { 0x1D8E, "bb_setshootparams" },
    { 0x1D8F, "bb_setshort" },
    { 0x1D90, "bb_shootparams_empty" },
    { 0x1D91, "bb_shootparams_idsmatch" },
    { 0x1D92, "bb_shootparamsvalid" },
    { 0x1D93, "bb_shoulddroprocketlauncher" },
    { 0x1D94, "bb_shouldselfdestructnow" },
    { 0x1D95, "bb_shouldwildfire" },
    { 0x1D96, "bb_smartobjectrequested" },
    { 0x1D97, "bb_think" },
    { 0x1D98, "bb_throwgrenaderequested" },
    { 0x1D99, "bb_timer" },
    { 0x1D9A, "bb_updateshootparams" },
    { 0x1D9B, "bb_updateshootparams_pos" },
    { 0x1D9C, "bb_updateshootparams_posandent" },
    { 0x1D9D, "bb_wantstostrafe" },
    { 0x1D9E, "bb_waspartjustdismembered" },
    { 0x1D9F, "bb_werepartsdismemberedinorder" },
    { 0x1DA0, "bbadcrouchspot" },
    { 0x1DA1, "bbark" },
    { 0x1DA2, "bblocked" },
    { 0x1DA3, "bc_event_override" },
    { 0x1DA4, "bc_looktarget" },
    { 0x1DA5, "bc_prefix" },
    { 0x1DA6, "bcallingreinforcements" },
    { 0x1DA7, "bcansee" },
    { 0x1DA8, "bccallsign" },
    { 0x1DA9, "bccansee" },
    { 0x1DAA, "bccountryid" },
    { 0x1DAB, "bccreatemouth" },
    { 0x1DAC, "bccustomconvo" },
    { 0x1DAD, "bcdisabled" },
    { 0x1DAE, "bcdrawobjects" },
    { 0x1DAF, "bcfrequency" },
    { 0x1DB0, "bcgetclaimednode" },
    { 0x1DB1, "bcharge" },
    { 0x1DB2, "bchargecomplete" },
    { 0x1DB3, "bchecklosttarget" },
    { 0x1DB4, "bcinfo" },
    { 0x1DB5, "bcinfolastsaytimes" },
    { 0x1DB6, "bcinfoqueued" },
    { 0x1DB7, "bcisgrenade" },
    { 0x1DB8, "bcisincombat" },
    { 0x1DB9, "bcisrpg" },
    { 0x1DBA, "bcissniper" },
    { 0x1DBB, "bclocked" },
    { 0x1DBC, "bcname" },
    { 0x1DBD, "bcnameid" },
    { 0x1DBE, "bcorner" },
    { 0x1DBF, "bcoverhasbeenblown" },
    { 0x1DC0, "bcprint_info" },
    { 0x1DC1, "bcprintfailprefix" },
    { 0x1DC2, "bcprintwarnprefix" },
    { 0x1DC3, "bcrank" },
    { 0x1DC4, "bcs_enabled" },
    { 0x1DC5, "bcs_frequencyscalar" },
    { 0x1DC6, "bcs_jackal" },
    { 0x1DC7, "bcs_lastcontactdelay" },
    { 0x1DC8, "bcs_location_mappings" },
    { 0x1DC9, "bcs_location_trigger_mapping" },
    { 0x1DCA, "bcs_location_trigs_init" },
    { 0x1DCB, "bcs_locations" },
    { 0x1DCC, "bcs_maxstealthdistsqrdfromplayer" },
    { 0x1DCD, "bcs_maxtalkingdistsqrdfromplayer" },
    { 0x1DCE, "bcs_maxthreatdistsqrdfromplayer" },
    { 0x1DCF, "bcs_scripted_dialog_clear" },
    { 0x1DD0, "bcs_scripted_dialogue_start" },
    { 0x1DD1, "bcs_setup_chatter_toggle_array" },
    { 0x1DD2, "bcs_setup_countryids" },
    { 0x1DD3, "bcs_setup_flavorburst_toggle_array" },
    { 0x1DD4, "bcs_setup_playernameids" },
    { 0x1DD5, "bcs_setup_teams_array" },
    { 0x1DD6, "bcs_setup_voice" },
    { 0x1DD7, "bcs_stealthhuntthink" },
    { 0x1DD8, "bcs_threatresettime" },
    { 0x1DD9, "bcs_trigs_assign_aliases" },
    { 0x1DDA, "bcscooldown" },
    { 0x1DDB, "bcsdebugwaiter" },
    { 0x1DDC, "bcsenabled" },
    { 0x1DDD, "bcsounds" },
    { 0x1DDE, "bctable" },
    { 0x1DDF, "bctable_addfile" },
    { 0x1DE0, "bctable_categorykey" },
    { 0x1DE1, "bctable_exists" },
    { 0x1DE2, "bctable_pickaliasset" },
    { 0x1DE3, "bctable_setfiles" },
    { 0x1DE4, "bctabledeck" },
    { 0x1DE5, "bctablelast" },
    { 0x1DE6, "bctracking" },
    { 0x1DE7, "bdisabledefaultfacialanims" },
    { 0x1DE8, "bdlocked" },
    { 0x1DE9, "bdocoverblownreaction" },
    { 0x1DEA, "bdoingbloodsmear" },
    { 0x1DEB, "bdonotreact" },
    { 0x1DEC, "bdpaddown" },
    { 0x1DED, "bdpadleft" },
    { 0x1DEE, "bdpadright" },
    { 0x1DEF, "bdpadup" },
    { 0x1DF0, "bdyingbackidleandshootsetup" },
    { 0x1DF1, "beacon_fuse" },
    { 0x1DF2, "beam_fail_cooldown" },
    { 0x1DF3, "beam_in_hand" },
    { 0x1DF4, "beam_nag_lines" },
    { 0x1DF5, "beam_nags" },
    { 0x1DF6, "beam_weapon_check" },
    { 0x1DF7, "becomehvt" },
    { 0x1DF8, "bed_civ_2f_action" },
    { 0x1DF9, "bed_civ_ads_monitor" },
    { 0x1DFA, "bed_civ_cleanup_monitor" },
    { 0x1DFB, "bed_civ_death_monitor" },
    { 0x1DFC, "bed_civ_flinch_monitor" },
    { 0x1DFD, "bed_civ_handsup_complete_monitor" },
    { 0x1DFE, "bed_civ_handsup_trigger" },
    { 0x1DFF, "bed_civ_init" },
    { 0x1E00, "bed_civ_state_handsup" },
    { 0x1E01, "bed_civ_state_handsup_flinch" },
    { 0x1E02, "bed_civ_state_laying" },
    { 0x1E03, "bed_civ_state_laying_flinch" },
    { 0x1E04, "bed_civ_state_laying_responsive" },
    { 0x1E05, "bed_civ_state_laying_unresponsive" },
    { 0x1E06, "bed_civs_init" },
    { 0x1E07, "bed_enemy_2f_action" },
    { 0x1E08, "bed_enemy_flash_watcher" },
    { 0x1E09, "bed_enemy_watcher" },
    { 0x1E0A, "bed_guy" },
    { 0x1E0B, "bed_guy_blood_pool" },
    { 0x1E0C, "bed_guy_deathanim" },
    { 0x1E0D, "bed_guy_dropgun" },
    { 0x1E0E, "bed_guy_flash" },
    { 0x1E0F, "bed_guy_sight_thread" },
    { 0x1E10, "bed_guy_target" },
    { 0x1E11, "bedciv" },
    { 0x1E12, "bedroom_2f_woman_breathing" },
    { 0x1E13, "bedroom_3f_death" },
    { 0x1E14, "bedroom_3f_door" },
    { 0x1E15, "bedroom_girl_stunned" },
    { 0x1E16, "bedroom_girl_watcher" },
    { 0x1E17, "beeper_loop" },
    { 0x1E18, "beeper_monitor" },
    { 0x1E19, "beffectlooping" },
    { 0x1E1A, "beforestairanim" },
    { 0x1E1B, "begin_anim_reach" },
    { 0x1E1C, "begin_attack_heli_behavior" },
    { 0x1E1D, "begin_fsm" },
    { 0x1E1E, "begin_searching_for_landing_loc" },
    { 0x1E1F, "begin_wave_spawning" },
    { 0x1E20, "beginarchiveplayback" },
    { 0x1E21, "beginbrc130playeraniminfilsequence" },
    { 0x1E22, "beginc4tracking" },
    { 0x1E23, "beginclasschoice" },
    { 0x1E24, "begincustomevent" },
    { 0x1E25, "begindeployableviamarker" },
    { 0x1E26, "beginevasivemaneuvers" },
    { 0x1E27, "begingrenadetracking" },
    { 0x1E28, "beginjackal" },
    { 0x1E29, "beginjackalescort" },
    { 0x1E2A, "beginlittlebird" },
    { 0x1E2B, "beginnewfight" },
    { 0x1E2C, "beginningoflevelsave" },
    { 0x1E2D, "beginningoflevelsave_thread" },
    { 0x1E2E, "beginningoflevelsavedelay" },
    { 0x1E2F, "beginsliding" },
    { 0x1E30, "beginslidinglegacy" },
    { 0x1E31, "beginsuperuse" },
    { 0x1E32, "beginteamchoice" },
    { 0x1E33, "beginuse" },
    { 0x1E34, "beginusefunc" },
    { 0x1E35, "beginusegas" },
    { 0x1E36, "beginusesupplypack" },
    { 0x1E37, "behavior" },
    { 0x1E38, "behaviortreeasset" },
    { 0x1E39, "behind_hadir" },
    { 0x1E3A, "behinddoors" },
    { 0x1E3B, "being_hunted_by_kidnapper" },
    { 0x1E3C, "being_intercepted" },
    { 0x1E3D, "being_revived" },
    { 0x1E3E, "being_used" },
    { 0x1E3F, "beingmarked" },
    { 0x1E40, "beingpushed" },
    { 0x1E41, "beingrallyrespawned" },
    { 0x1E42, "beingrevived" },
    { 0x1E43, "beingshoved" },
    { 0x1E44, "bellycrawl" },
    { 0x1E45, "belowcriticalhealththreshold" },
    { 0x1E46, "benemyinlowcover" },
    { 0x1E47, "berserk" },
    { 0x1E48, "best_target" },
    { 0x1E49, "bestairtarget" },
    { 0x1E4A, "bestgroundtarget" },
    { 0x1E4B, "bestlifetimekillstreak" },
    { 0x1E4C, "bestpatrolpoint" },
    { 0x1E4D, "bestscorestats" },
    { 0x1E4E, "bestspawnflag" },
    { 0x1E4F, "besttarget" },
    { 0x1E50, "bestwall" },
    { 0x1E51, "betchangefail" },
    { 0x1E52, "bets" },
    { 0x1E53, "betting" },
    { 0x1E54, "bettingopen" },
    { 0x1E55, "between_regen_wait" },
    { 0x1E56, "bexaminerequested" },
    { 0x1E57, "bfacade" },
    { 0x1E58, "bfacesomedecentdirectionwhenidle" },
    { 0x1E59, "bflashlight" },
    { 0x1E5A, "bforceaim" },
    { 0x1E5B, "bforcespawn" },
    { 0x1E5C, "bfs_assigned" },
    { 0x1E5D, "bfs_cooldown" },
    { 0x1E5E, "bfs_distance" },
    { 0x1E5F, "bfs_score" },
    { 0x1E60, "bfs_visited" },
    { 0x1E61, "bg" },
    { 0x1E62, "bg_2d" },
    { 0x1E63, "bg_aa_fire_tracer_fx" },
    { 0x1E64, "bg_aa_trigger_tracer_fx" },
    { 0x1E65, "bg_cars" },
    { 0x1E66, "bg_retreat_slaughter_magic_bullets" },
    { 0x1E67, "bg_scene_post_vo" },
    { 0x1E68, "bgameover" },
    { 0x1E69, "bgivensentry" },
    { 0x1E6A, "bgrowl" },
    { 0x1E6B, "bhascovernode" },
    { 0x1E6C, "bhasgunwhileriding" },
    { 0x1E6D, "bhaslasertag" },
    { 0x1E6E, "bhaslos" },
    { 0x1E6F, "bhasthighholster" },
    { 0x1E70, "bhitbyvehicle" },
    { 0x1E71, "bhunkering" },
    { 0x1E72, "bidlecurious" },
    { 0x1E73, "big_boom" },
    { 0x1E74, "big_door_l" },
    { 0x1E75, "big_door_r" },
    { 0x1E76, "big_doors_are_open" },
    { 0x1E77, "bignoretargetflee" },
    { 0x1E78, "bignoretimeout" },
    { 0x1E79, "binary" },
    { 0x1E7A, "binc130" },
    { 0x1E7B, "bindactionscripts" },
    { 0x1E7C, "binfullbodypain" },
    { 0x1E7D, "binited" },
    { 0x1E7E, "binitialhunt" },
    { 0x1E7F, "binitialinvestigate" },
    { 0x1E80, "bink" },
    { 0x1E81, "bink_chopper_behavior" },
    { 0x1E82, "bink_choppers" },
    { 0x1E83, "bink_hc" },
    { 0x1E84, "bink_intro_catchup" },
    { 0x1E85, "bink_intro_main" },
    { 0x1E86, "bink_intro_start" },
    { 0x1E87, "bink_main" },
    { 0x1E88, "bink_pip" },
    { 0x1E89, "bink_speech" },
    { 0x1E8A, "bink_speech_main" },
    { 0x1E8B, "bink_start" },
    { 0x1E8C, "bink_technical" },
    { 0x1E8D, "bink_town_allies" },
    { 0x1E8E, "bink_transition_music" },
    { 0x1E8F, "binkstopper" },
    { 0x1E90, "binocs" },
    { 0x1E91, "binoculars" },
    { 0x1E92, "binprogress" },
    { 0x1E93, "binseat" },
    { 0x1E94, "binvehicle" },
    { 0x1E95, "binvestigatelookaround" },
    { 0x1E96, "binvestigateoutofrange" },
    { 0x1E97, "birth_time" },
    { 0x1E98, "bisgunner" },
    { 0x1E99, "bit_1" },
    { 0x1E9A, "bit_2" },
    { 0x1E9B, "bit_3" },
    { 0x1E9C, "bit_position" },
    { 0x1E9D, "black_screen" },
    { 0x1E9E, "blackbox_count" },
    { 0x1E9F, "blackbox_data_type" },
    { 0x1EA0, "blackbox_event_run" },
    { 0x1EA1, "blackfade" },
    { 0x1EA2, "blackout" },
    { 0x1EA3, "blackout_delay" },
    { 0x1EA4, "blackoverlay" },
    { 0x1EA5, "blank" },
    { 0x1EA6, "blank_func" },
    { 0x1EA7, "blank_score_component_init" },
    { 0x1EA8, "blankfunc" },
    { 0x1EA9, "blankline" },
    { 0x1EAA, "blankmodulefunc" },
    { 0x1EAB, "blankobjectivefunc" },
    { 0x1EAC, "blastshieldclamp" },
    { 0x1EAD, "blastshieldmod" },
    { 0x1EAE, "blastshieldusetracker" },
    { 0x1EAF, "bledout" },
    { 0x1EB0, "bleedoutspawnentityoverride" },
    { 0x1EB1, "bleedoutthink" },
    { 0x1EB2, "blend_down_in_progress" },
    { 0x1EB3, "blend_in_time" },
    { 0x1EB4, "blend_movespeedscale" },
    { 0x1EB5, "blend_movespeedscale_default" },
    { 0x1EB6, "blend_movespeedscale_percent" },
    { 0x1EB7, "blend_partial_in" },
    { 0x1EB8, "blend_partial_out" },
    { 0x1EB9, "blend_player_to_arms" },
    { 0x1EBA, "blend_sun_intensity_over_distance_trigger" },
    { 0x1EBB, "blend_to_ai" },
    { 0x1EBC, "blend_up_in_progress" },
    { 0x1EBD, "blendanimsbyspeed" },
    { 0x1EBE, "blenddelete" },
    { 0x1EBF, "blended_anim" },
    { 0x1EC0, "blended_anim_solo" },
    { 0x1EC1, "blended_interaction_tracecheck" },
    { 0x1EC2, "blended_loop_anim" },
    { 0x1EC3, "blended_loop_cleanup" },
    { 0x1EC4, "blended_loop_solo" },
    { 0x1EC5, "blendshape_disable" },
    { 0x1EC6, "blendshape_enable" },
    { 0x1EC7, "blendshape_get_modelname" },
    { 0x1EC8, "blendspacerndm" },
    { 0x1EC9, "blendtoai" },
    { 0x1ECA, "blendviewoffsetinternal" },
    { 0x1ECB, "blima" },
    { 0x1ECC, "blima_cam_shake_bump" },
    { 0x1ECD, "blima_cam_shake_low" },
    { 0x1ECE, "blima_chief_play_sound_func" },
    { 0x1ECF, "blima_clean_up" },
    { 0x1ED0, "blima_commander_play_sound_func" },
    { 0x1ED1, "blima_delete" },
    { 0x1ED2, "blima_door_slam" },
    { 0x1ED3, "blima_engine_sound" },
    { 0x1ED4, "blima_engine_sound_death_watch" },
    { 0x1ED5, "blima_engine_sound_done_watch" },
    { 0x1ED6, "blima_rumble_ground" },
    { 0x1ED7, "blima_rumble_rope" },
    { 0x1ED8, "blima_spawn_pilot" },
    { 0x1ED9, "blind" },
    { 0x1EDA, "blind_fire" },
    { 0x1EDB, "blinddurations" },
    { 0x1EDC, "blindeyerecipients" },
    { 0x1EDD, "blindid" },
    { 0x1EDE, "blindparts" },
    { 0x1EDF, "blindplayers" },
    { 0x1EE0, "blindstates" },
    { 0x1EE1, "blink_beacon" },
    { 0x1EE2, "blink_tire_outline" },
    { 0x1EE3, "blinkinglightfx" },
    { 0x1EE4, "blinkinglighttag" },
    { 0x1EE5, "blinkloc" },
    { 0x1EE6, "block_for_mantle" },
    { 0x1EE7, "block_for_push" },
    { 0x1EE8, "block_while_alive" },
    { 0x1EE9, "block_while_enemy_count" },
    { 0x1EEA, "blockade_bomb_defusal_success_func" },
    { 0x1EEB, "blockade_gates" },
    { 0x1EEC, "blockade_gates_are_closing" },
    { 0x1EED, "blockade_gates_are_opening" },
    { 0x1EEE, "blockade_landmine" },
    { 0x1EEF, "blockade_mindia_unload_func" },
    { 0x1EF0, "blockade_vindia_unload_func" },
    { 0x1EF1, "blockarea" },
    { 0x1EF2, "blockedbywall" },
    { 0x1EF3, "blockedwaittillgrouptimerdone" },
    { 0x1EF4, "blockentsinarea" },
    { 0x1EF5, "blocker_vehicle_death_monitor" },
    { 0x1EF6, "blocker_vehicle_spawn_trigger_think" },
    { 0x1EF7, "blocker_vehicle_spawned_monitor" },
    { 0x1EF8, "blocker_vehicle_think" },
    { 0x1EF9, "blocker_vehicles" },
    { 0x1EFA, "blocking_ratio" },
    { 0x1EFB, "blockingpain" },
    { 0x1EFC, "blockkillstreakforbots" },
    { 0x1EFD, "blocknukekills" },
    { 0x1EFE, "blocknumber" },
    { 0x1EFF, "blockperkfunction" },
    { 0x1F00, "blockplayeruav" },
    { 0x1F01, "blockpuzzleactivation" },
    { 0x1F02, "blockpuzzlehint" },
    { 0x1F03, "blockpuzzleinit" },
    { 0x1F04, "blocks" },
    { 0x1F05, "blocks_binary_sequence" },
    { 0x1F06, "blocksize" },
    { 0x1F07, "blockswaploadouts" },
    { 0x1F08, "blockupdatewalldata" },
    { 0x1F09, "blockviewmodelanim" },
    { 0x1F0A, "blockweapondrops" },
    { 0x1F0B, "blood_camo_222" },
    { 0x1F0C, "blood_camo_84" },
    { 0x1F0D, "blood_pool" },
    { 0x1F0E, "blood_pool_mom" },
    { 0x1F0F, "blood_smear" },
    { 0x1F10, "bloodcamokillcount" },
    { 0x1F11, "bloodeffect" },
    { 0x1F12, "bloodmeleeeffect" },
    { 0x1F13, "bloodoverlay" },
    { 0x1F14, "bloodsplat" },
    { 0x1F15, "blowout" },
    { 0x1F16, "blowout_goalradius_on_pathend" },
    { 0x1F17, "blue_marines_move_to_hospital" },
    { 0x1F18, "blue_wire" },
    { 0x1F19, "blueprintref" },
    { 0x1F1A, "blur_burst" },
    { 0x1F1B, "bmoving" },
    { 0x1F1C, "bnaturaldeath" },
    { 0x1F1D, "bnoanimunload" },
    { 0x1F1E, "board_chopper" },
    { 0x1F1F, "board_getallydronestartnodes" },
    { 0x1F20, "boat_vehicle" },
    { 0x1F21, "boatbob" },
    { 0x1F22, "boatfx" },
    { 0x1F23, "boatwobble" },
    { 0x1F24, "body" },
    { 0x1F25, "body_damage_watcher" },
    { 0x1F26, "body_drag_door_bodies_think" },
    { 0x1F27, "body_drag_door_door_think" },
    { 0x1F28, "body_drag_door_scene" },
    { 0x1F29, "body_drag_door_scene_think" },
    { 0x1F2A, "body_drag_dumpster_bodies_think" },
    { 0x1F2B, "body_drag_dumpster_scene" },
    { 0x1F2C, "body_drag_dumpster_scene_think" },
    { 0x1F2D, "body_model" },
    { 0x1F2E, "body_poke_scene" },
    { 0x1F2F, "body_poke_scene_think" },
    { 0x1F30, "body_poker_think" },
    { 0x1F31, "body1" },
    { 0x1F32, "body1_dropped" },
    { 0x1F33, "body2" },
    { 0x1F34, "body2_dropped" },
    { 0x1F35, "bodyarmorhp" },
    { 0x1F36, "bodyclip" },
    { 0x1F37, "bodydouble" },
    { 0x1F38, "bodyguard_radius" },
    { 0x1F39, "bodyguard_vehicle_death_monitor" },
    { 0x1F3A, "bodyguard_vehicle_id" },
    { 0x1F3B, "bodyguard_vehicle_spawn_trigger_think" },
    { 0x1F3C, "bodyguard_vehicle_spawned_monitor" },
    { 0x1F3D, "bodyguard_vehicle_think" },
    { 0x1F3E, "bodymodel" },
    { 0x1F3F, "bodymodelname" },
    { 0x1F40, "bodyonly_guy_damage_monitor" },
    { 0x1F41, "bodyonly_guy_setup" },
    { 0x1F42, "bodyonly_hostage_dmg_monitor" },
    { 0x1F43, "bodyonlyspawn" },
    { 0x1F44, "bolt_destroy" },
    { 0x1F45, "boltcutters" },
    { 0x1F46, "bomb" },
    { 0x1F47, "bomb_anim_think" },
    { 0x1F48, "bomb_beeps" },
    { 0x1F49, "bomb_countdown" },
    { 0x1F4A, "bomb_defusal_success_func" },
    { 0x1F4B, "bomb_defused_end_player_clean_up" },
    { 0x1F4C, "bomb_defuser" },
    { 0x1F4D, "bomb_defuser_update" },
    { 0x1F4E, "bomb_detonator_control_think" },
    { 0x1F4F, "bomb_detonator_fill_percent" },
    { 0x1F50, "bomb_detonator_id" },
    { 0x1F51, "bomb_detonator_pressed_color" },
    { 0x1F52, "bomb_detonator_pressed_id" },
    { 0x1F53, "bomb_detonator_timer_bar_think" },
    { 0x1F54, "bomb_detonator_wire_color_change_think" },
    { 0x1F55, "bomb_exploded" },
    { 0x1F56, "bomb_explodes" },
    { 0x1F57, "bomb_for_pick_up" },
    { 0x1F58, "bomb_for_pick_up_use_monitor" },
    { 0x1F59, "bomb_fuse_think" },
    { 0x1F5A, "bomb_guardian_damage_watcher_internal" },
    { 0x1F5B, "bomb_guardian_death_watcher_internal" },
    { 0x1F5C, "bomb_guardian_is_killed" },
    { 0x1F5D, "bomb_guardian_watcher" },
    { 0x1F5E, "bomb_id" },
    { 0x1F5F, "bomb_id_index_chosen" },
    { 0x1F60, "bomb_id_index_chosen_sorted" },
    { 0x1F61, "bomb_id_marker" },
    { 0x1F62, "bomb_id_marker_tag_origin" },
    { 0x1F63, "bomb_is_loaded" },
    { 0x1F64, "bomb_model" },
    { 0x1F65, "bomb_model_as_use_entity" },
    { 0x1F66, "bomb_plant_cinematic_settings" },
    { 0x1F67, "bomb_plant_dialog" },
    { 0x1F68, "bomb_plant_scene" },
    { 0x1F69, "bomb_plant_think" },
    { 0x1F6A, "bomb_planted_think" },
    { 0x1F6B, "bomb_play_and_remove" },
    { 0x1F6C, "bomb_pre_exp_music" },
    { 0x1F6D, "bomb_pre_exp_sfx_wait" },
    { 0x1F6E, "bomb_room_check_if_enforcer_clear" },
    { 0x1F6F, "bomb_room_enemies_handler" },
    { 0x1F70, "bomb_room_enemy_anim_new" },
    { 0x1F71, "bomb_room_front_enemies" },
    { 0x1F72, "bomb_room_price_advance" },
    { 0x1F73, "bomb_room_set_enemy_model" },
    { 0x1F74, "bomb_room_spawn_extra_guy" },
    { 0x1F75, "bomb_type" },
    { 0x1F76, "bomb_use_activate" },
    { 0x1F77, "bomb_wire_cut_color" },
    { 0x1F78, "bomb_wire_cut_id" },
    { 0x1F79, "bomb_zone_assaulting" },
    { 0x1F7A, "bombardment_aq_behavior" },
    { 0x1F7B, "bombardment_aq_hit_monitor" },
    { 0x1F7C, "bombardment_aq_run_to_cover_monitor" },
    { 0x1F7D, "bombardment_aq_window_target_player_manager" },
    { 0x1F7E, "bombardment_window_air_bullet_spawners" },
    { 0x1F7F, "bombardment_window_ground_bullet_spawners" },
    { 0x1F80, "bombardment_window_ground_bullet_targets" },
    { 0x1F81, "bombardment_window_kills" },
    { 0x1F82, "bombdefused" },
    { 0x1F83, "bombdefusetrig" },
    { 0x1F84, "bombdroploc" },
    { 0x1F85, "bomber_agentinitonkilled" },
    { 0x1F86, "bomber_checktarget" },
    { 0x1F87, "bomber_detonation" },
    { 0x1F88, "bomber_finishpainhead" },
    { 0x1F89, "bomber_gettarget" },
    { 0x1F8A, "bomber_init" },
    { 0x1F8B, "bomber_monitor_no_path" },
    { 0x1F8C, "bomber_move" },
    { 0x1F8D, "bomber_moveinit" },
    { 0x1F8E, "bomber_moveterminate" },
    { 0x1F8F, "bomber_set_detonation_dist_squared" },
    { 0x1F90, "bomber_set_target" },
    { 0x1F91, "bomber_shouldmove" },
    { 0x1F92, "bomber_shouldraisearm" },
    { 0x1F93, "bomber_terminate" },
    { 0x1F94, "bomber_updateeveryframe" },
    { 0x1F95, "bomber_wait_for_bomb_reset" },
    { 0x1F96, "bomber_wait_for_death" },
    { 0x1F97, "bombercanexplodebehindtarget" },
    { 0x1F98, "bomberdisablemovebehavior" },
    { 0x1F99, "bomberexplodeangle" },
    { 0x1F9A, "bomberexplodedistance" },
    { 0x1F9B, "bomberignoresecondarytargets" },
    { 0x1F9C, "bomberlookatdistance" },
    { 0x1F9D, "bomberlookattarget" },
    { 0x1F9E, "bomberlookattargettime" },
    { 0x1F9F, "bomberplayerseesme" },
    { 0x1FA0, "bomberraisearm" },
    { 0x1FA1, "bomberraisearmdistsquared" },
    { 0x1FA2, "bomberraisearmtime" },
    { 0x1FA3, "bombersecondaryexplodedistance" },
    { 0x1FA4, "bombertarget" },
    { 0x1FA5, "bomberusegrenade" },
    { 0x1FA6, "bombexploded" },
    { 0x1FA7, "bombexplodedcount" },
    { 0x1FA8, "bombhandler" },
    { 0x1FA9, "bombnode" },
    { 0x1FAA, "bombowner" },
    { 0x1FAB, "bombplant_encounterstart" },
    { 0x1FAC, "bombplanted" },
    { 0x1FAD, "bombplanted_music" },
    { 0x1FAE, "bombplantedteam" },
    { 0x1FAF, "bombplantedtime" },
    { 0x1FB0, "bombplantent" },
    { 0x1FB1, "bombplantweapon" },
    { 0x1FB2, "bombpuzzle_debug" },
    { 0x1FB3, "bombpuzzle_debug_print3d" },
    { 0x1FB4, "bombpuzzle_lookat_wire" },
    { 0x1FB5, "bombpuzzle_setup" },
    { 0x1FB6, "bombpuzzle_setup_bombvest" },
    { 0x1FB7, "bombpuzzle_setup_briefcase" },
    { 0x1FB8, "bombpuzzle_setup_individual" },
    { 0x1FB9, "bombpuzzle_setup_wire" },
    { 0x1FBA, "bombpuzzle_think" },
    { 0x1FBB, "bombpuzzle_watch_for_defuse" },
    { 0x1FBC, "bombpuzzle_wire_cut_debug" },
    { 0x1FBD, "bombpuzzles" },
    { 0x1FBE, "bombradialunfill" },
    { 0x1FBF, "bombresettimer" },
    { 0x1FC0, "bombrespawnangles" },
    { 0x1FC1, "bombrespawnpoint" },
    { 0x1FC2, "bombs" },
    { 0x1FC3, "bombs_explode" },
    { 0x1FC4, "bombs_for_coop_bomb_defusal" },
    { 0x1FC5, "bombsitewatcher" },
    { 0x1FC6, "bombsplanted" },
    { 0x1FC7, "bombsquadmodel" },
    { 0x1FC8, "bombstrip" },
    { 0x1FC9, "bombtablet" },
    { 0x1FCA, "bombtimer" },
    { 0x1FCB, "bombtimerwait" },
    { 0x1FCC, "bombvest_character" },
    { 0x1FCD, "bombzone_awardgenericbombzonemedals" },
    { 0x1FCE, "bombzone_holdtimer" },
    { 0x1FCF, "bombzone_num_picked" },
    { 0x1FD0, "bombzone_onactivateobjective" },
    { 0x1FD1, "bombzone_onbeginuse" },
    { 0x1FD2, "bombzone_onbombplanted" },
    { 0x1FD3, "bombzone_oncantuse" },
    { 0x1FD4, "bombzone_ondisableobjective" },
    { 0x1FD5, "bombzone_onenableobjective" },
    { 0x1FD6, "bombzone_onenduse" },
    { 0x1FD7, "bombzone_onusedefuseobject" },
    { 0x1FD8, "bombzone_onuseplantobject" },
    { 0x1FD9, "bombzone_setupbombcase" },
    { 0x1FDA, "bombzone_warningklaxon" },
    { 0x1FDB, "bombzonegoal" },
    { 0x1FDC, "bombzones" },
    { 0x1FDD, "bone" },
    { 0x1FDE, "boneyard_fire_at_targets" },
    { 0x1FDF, "boneyard_style_heli_missile_attack" },
    { 0x1FE0, "boneyard_style_heli_missile_attack_linked" },
    { 0x1FE1, "bonusscore" },
    { 0x1FE2, "bonusscorefunc" },
    { 0x1FE3, "bonustime" },
    { 0x1FE4, "bonustimemax" },
    { 0x1FE5, "bonustype" },
    { 0x1FE6, "bookcase_anim_speed" },
    { 0x1FE7, "bookcase_beating_timing" },
    { 0x1FE8, "bookcase_break_out" },
    { 0x1FE9, "bool_to_string" },
    { 0x1FEA, "boombox_hint_displayed" },
    { 0x1FEB, "boomtrackplayerdeath" },
    { 0x1FEC, "boomtrackplayers" },
    { 0x1FED, "boost_door" },
    { 0x1FEE, "boost_moment_dof" },
    { 0x1FEF, "boostspeed" },
    { 0x1FF0, "boosttrigger" },
    { 0x1FF1, "boosttriggerthink" },
    { 0x1FF2, "bored" },
    { 0x1FF3, "boredofcoverinterval" },
    { 0x1FF4, "boredomrate" },
    { 0x1FF5, "boredstart" },
    { 0x1FF6, "borienttoplayeryrot" },
    { 0x1FF7, "borigininvestigated" },
    { 0x1FF8, "borigininvolume" },
    { 0x1FF9, "boss_blocker" },
    { 0x1FFA, "boss_chopper" },
    { 0x1FFB, "boss_chopper_chu_behavior" },
    { 0x1FFC, "boss_chopper_damage_watcher" },
    { 0x1FFD, "boss_chopper_mg_attack" },
    { 0x1FFE, "boss_chopper_rockets" },
    { 0x1FFF, "boss_current_room" },
    { 0x2000, "boss_death_func" },
    { 0x2001, "boss_efforts_getting_stabbed" },
    { 0x2002, "boss_enemy_watcher" },
    { 0x2003, "boss_enter_anim_done" },
    { 0x2004, "boss_enter_anim_monitor" },
    { 0x2005, "boss_fight_intro" },
    { 0x2006, "boss_final_struggle_catch_lines" },
    { 0x2007, "boss_heli_weapons_create" },
    { 0x2008, "boss_kill_sling_model" },
    { 0x2009, "boss_mg_50cal" },
    { 0x200A, "boss_pilot_death_watcher" },
    { 0x200B, "boss_round_updates" },
    { 0x200C, "boss_shoot_player_model" },
    { 0x200D, "boss_skip_fight_intro" },
    { 0x200E, "boss_skip_fight_overlay" },
    { 0x200F, "boss_stab_player_model" },
    { 0x2010, "boss_stabbed" },
    { 0x2011, "boss_stabbed_amount" },
    { 0x2012, "boss_stream_pos" },
    { 0x2013, "boss_struggle_anim_node" },
    { 0x2014, "boss_struggle_anim_node_safe" },
    { 0x2015, "boss_struggle_light_fill" },
    { 0x2016, "boss_struggle_light_key" },
    { 0x2017, "boss_struggle_lights_node" },
    { 0x2018, "boss_struggle_player_model" },
    { 0x2019, "boss_struggle_vo" },
    { 0x201A, "boss_turn_on_hadir_hit" },
    { 0x201B, "boss_turns_on_hadir_anim" },
    { 0x201C, "boss_vo" },
    { 0x201D, "bot" },
    { 0x201E, "bot_3d_sighting_model" },
    { 0x201F, "bot_3d_sighting_model_thread" },
    { 0x2020, "bot_abort_tactical_goal" },
    { 0x2021, "bot_add_ambush_time_delayed" },
    { 0x2022, "bot_add_missing_nodes" },
    { 0x2023, "bot_add_scavenger_bag" },
    { 0x2024, "bot_add_to_bot_damage_targets" },
    { 0x2025, "bot_add_to_bot_level_targets" },
    { 0x2026, "bot_add_to_bot_use_targets" },
    { 0x2027, "bot_air_think" },
    { 0x2028, "bot_allow_to_capture_flag" },
    { 0x2029, "bot_allowed_to_3_cap" },
    { 0x202A, "bot_allowed_to_switch_teams" },
    { 0x202B, "bot_allowed_to_use_killstreaks" },
    { 0x202C, "bot_ambush_end" },
    { 0x202D, "bot_arm_think" },
    { 0x202E, "bot_assign_personality_functions" },
    { 0x202F, "bot_attachment_reticle" },
    { 0x2030, "bot_attachmenttable" },
    { 0x2031, "bot_attacker_limit_for_team" },
    { 0x2032, "bot_balance_personality" },
    { 0x2033, "bot_ball_ai_director_update" },
    { 0x2034, "bot_ball_think" },
    { 0x2035, "bot_bhd_think" },
    { 0x2036, "bot_blitz_think" },
    { 0x2037, "bot_body_is_dead" },
    { 0x2038, "bot_bots_enabled_or_added" },
    { 0x2039, "bot_br_think" },
    { 0x203A, "bot_cache_entrances" },
    { 0x203B, "bot_cache_entrances_to_bombzones" },
    { 0x203C, "bot_cache_entrances_to_flags_or_radios" },
    { 0x203D, "bot_cache_entrances_to_gametype_array" },
    { 0x203E, "bot_cache_flag_distances" },
    { 0x203F, "bot_camotable" },
    { 0x2040, "bot_camp_tag" },
    { 0x2041, "bot_camp_zone" },
    { 0x2042, "bot_camping" },
    { 0x2043, "bot_can_change_stance_while_watching_nodes" },
    { 0x2044, "bot_can_join_team" },
    { 0x2045, "bot_can_revive" },
    { 0x2046, "bot_can_use_aa_launcher" },
    { 0x2047, "bot_can_use_air_superiority" },
    { 0x2048, "bot_can_use_ball_drone" },
    { 0x2049, "bot_can_use_box_by_type" },
    { 0x204A, "bot_can_use_emp" },
    { 0x204B, "bot_can_use_killstreak" },
    { 0x204C, "bot_can_use_point_in_defend" },
    { 0x204D, "bot_capture_point" },
    { 0x204E, "bot_capture_zone" },
    { 0x204F, "bot_capture_zone_get_furthest_distance" },
    { 0x2050, "bot_check_tag_above_head" },
    { 0x2051, "bot_check_team_is_using_position" },
    { 0x2052, "bot_choose_difficulty_for_default" },
    { 0x2053, "bot_choose_flag" },
    { 0x2054, "bot_chosen_difficulty" },
    { 0x2055, "bot_class" },
    { 0x2056, "bot_client_counts" },
    { 0x2057, "bot_cm_human_picked" },
    { 0x2058, "bot_cm_spawned_bots" },
    { 0x2059, "bot_cm_waited_players_time" },
    { 0x205A, "bot_combine_tag_seen_arrays" },
    { 0x205B, "bot_conf_think" },
    { 0x205C, "bot_connect_monitor" },
    { 0x205D, "bot_connect_monitor_multiteam" },
    { 0x205E, "bot_control_heli" },
    { 0x205F, "bot_control_heli_main_move_loop" },
    { 0x2060, "bot_control_heli_pilot" },
    { 0x2061, "bot_control_heli_sniper" },
    { 0x2062, "bot_control_odin" },
    { 0x2063, "bot_control_odin_assault" },
    { 0x2064, "bot_control_odin_support" },
    { 0x2065, "bot_control_switchblade_cluster" },
    { 0x2066, "bot_control_vanguard" },
    { 0x2067, "bot_cranked_think" },
    { 0x2068, "bot_crate_valid" },
    { 0x2069, "bot_ctf_think" },
    { 0x206A, "bot_cyber_think" },
    { 0x206B, "bot_damage_callback" },
    { 0x206C, "bot_dark_volumes" },
    { 0x206D, "bot_default_sd_role_behavior" },
    { 0x206E, "bot_defcon_think" },
    { 0x206F, "bot_defend_get_precalc_entrances_for_current_area" },
    { 0x2070, "bot_defend_get_random_entrance_point_for_current_area" },
    { 0x2071, "bot_defend_player_guarding" },
    { 0x2072, "bot_defend_requires_center" },
    { 0x2073, "bot_defend_stop" },
    { 0x2074, "bot_defend_think" },
    { 0x2075, "bot_defender_limit_for_team" },
    { 0x2076, "bot_defending" },
    { 0x2077, "bot_defending_center" },
    { 0x2078, "bot_defending_nodes" },
    { 0x2079, "bot_defending_override_origin_node" },
    { 0x207A, "bot_defending_radius" },
    { 0x207B, "bot_defending_trigger" },
    { 0x207C, "bot_defending_type" },
    { 0x207D, "bot_defending_zone_id" },
    { 0x207E, "bot_demolition_think" },
    { 0x207F, "bot_difficulty_defaults" },
    { 0x2080, "bot_disable_tactical_goals" },
    { 0x2081, "bot_dm_think" },
    { 0x2082, "bot_do_doublejump" },
    { 0x2083, "bot_dom_debug_should_capture_all" },
    { 0x2084, "bot_dom_debug_should_protect_all" },
    { 0x2085, "bot_dom_get_node_chance" },
    { 0x2086, "bot_dom_leader_dialog" },
    { 0x2087, "bot_dom_override_flag_targets" },
    { 0x2088, "bot_dom_think" },
    { 0x2089, "bot_draw_circle" },
    { 0x208A, "bot_draw_cylinder" },
    { 0x208B, "bot_draw_cylinder_think" },
    { 0x208C, "bot_drop" },
    { 0x208D, "bot_enable_tactical_goals" },
    { 0x208E, "bot_end_control_on_respawn" },
    { 0x208F, "bot_end_control_on_vehicle_death" },
    { 0x2090, "bot_end_control_watcher" },
    { 0x2091, "bot_end_odin_watcher" },
    { 0x2092, "bot_ent_is_anonymous_mine" },
    { 0x2093, "bot_fallback_personality" },
    { 0x2094, "bot_fallback_weapon" },
    { 0x2095, "bot_filter_ambush_inuse" },
    { 0x2096, "bot_filter_ambush_vicinity" },
    { 0x2097, "bot_find_ambush_entrances" },
    { 0x2098, "bot_find_best_tag_from_array" },
    { 0x2099, "bot_find_closest_tag" },
    { 0x209A, "bot_find_defend_node_func" },
    { 0x209B, "bot_find_node_that_protects_point" },
    { 0x209C, "bot_find_node_to_capture_point" },
    { 0x209D, "bot_find_node_to_capture_zone" },
    { 0x209E, "bot_find_node_to_guard_player" },
    { 0x209F, "bot_find_node_to_protect_zone" },
    { 0x20A0, "bot_find_random_midpoint" },
    { 0x20A1, "bot_find_visible_tags" },
    { 0x20A2, "bot_find_visible_tags_mugger" },
    { 0x20A3, "bot_fixup_bombzone_issues" },
    { 0x20A4, "bot_flag_trigger" },
    { 0x20A5, "bot_flag_trigger_clear" },
    { 0x20A6, "bot_force_stance_for_time" },
    { 0x20A7, "bot_front_think" },
    { 0x20A8, "bot_funcs" },
    { 0x20A9, "bot_gametype_chooses_class" },
    { 0x20AA, "bot_gametype_chooses_team" },
    { 0x20AB, "bot_gametype_precaching_done" },
    { 0x20AC, "bot_get_all_possible_flags" },
    { 0x20AD, "bot_get_ambush_trap_item" },
    { 0x20AE, "bot_get_available_ball" },
    { 0x20AF, "bot_get_ball_carrier" },
    { 0x20B0, "bot_get_client_limit" },
    { 0x20B1, "bot_get_enemy_team" },
    { 0x20B2, "bot_get_entrances_for_stance_and_index" },
    { 0x20B3, "bot_get_grenade_ammo" },
    { 0x20B4, "bot_get_grenade_for_purpose" },
    { 0x20B5, "bot_get_heli_goal_dist_sq" },
    { 0x20B6, "bot_get_heli_slowdown_dist_sq" },
    { 0x20B7, "bot_get_host_team" },
    { 0x20B8, "bot_get_human_picked_team" },
    { 0x20B9, "bot_get_known_attacker" },
    { 0x20BA, "bot_get_low_on_ammo" },
    { 0x20BB, "bot_get_max_players_on_team" },
    { 0x20BC, "bot_get_nodes_in_cone" },
    { 0x20BD, "bot_get_player_team" },
    { 0x20BE, "bot_get_rank_xp" },
    { 0x20BF, "bot_get_string_index_for_integer" },
    { 0x20C0, "bot_get_team_limit" },
    { 0x20C1, "bot_get_teammates_currently_defending_point" },
    { 0x20C2, "bot_get_teammates_currently_defending_zone" },
    { 0x20C3, "bot_get_teammates_in_radius" },
    { 0x20C4, "bot_get_total_gun_ammo" },
    { 0x20C5, "bot_get_valid_nodes_in_trigger" },
    { 0x20C6, "bot_get_zones_within_dist" },
    { 0x20C7, "bot_get_zones_within_dist_recurs" },
    { 0x20C8, "bot_goal_can_override" },
    { 0x20C9, "bot_goto_zone" },
    { 0x20CA, "bot_grenade_matches_purpose" },
    { 0x20CB, "bot_grind_extra_think" },
    { 0x20CC, "bot_grind_think" },
    { 0x20CD, "bot_grnd_think" },
    { 0x20CE, "bot_guard_player" },
    { 0x20CF, "bot_gun_think" },
    { 0x20D0, "bot_handle_no_valid_defense_node" },
    { 0x20D1, "bot_handle_stance_for_look" },
    { 0x20D2, "bot_hardpoint_ai_director_update" },
    { 0x20D3, "bot_hardpoint_think" },
    { 0x20D4, "bot_has_tactical_goal" },
    { 0x20D5, "bot_headquarters_think" },
    { 0x20D6, "bot_heli_find_unvisited_nodes" },
    { 0x20D7, "bot_heli_nodes" },
    { 0x20D8, "bot_heli_pilot_traceoffset" },
    { 0x20D9, "bot_hvt_think" },
    { 0x20DA, "bot_ignore_precalc_paths" },
    { 0x20DB, "bot_in_combat" },
    { 0x20DC, "bot_infect_ai_director_update" },
    { 0x20DD, "bot_infect_angle_too_steep_for_knife_throw" },
    { 0x20DE, "bot_infect_find_node_can_see_ent" },
    { 0x20DF, "bot_infect_retrieve_knife" },
    { 0x20E0, "bot_infect_think" },
    { 0x20E1, "bot_initialized_remote_vehicles" },
    { 0x20E2, "bot_interaction_type" },
    { 0x20E3, "bot_invalid_attachment_combos" },
    { 0x20E4, "bot_is_bodyguarding" },
    { 0x20E5, "bot_is_capturing" },
    { 0x20E6, "bot_is_capturing_flag" },
    { 0x20E7, "bot_is_defending" },
    { 0x20E8, "bot_is_defending_point" },
    { 0x20E9, "bot_is_guarding_player" },
    { 0x20EA, "bot_is_killstreak_supported" },
    { 0x20EB, "bot_is_patrolling" },
    { 0x20EC, "bot_is_protecting" },
    { 0x20ED, "bot_is_protecting_flag" },
    { 0x20EE, "bot_is_ready_to_spawn" },
    { 0x20EF, "bot_is_remote_or_linked" },
    { 0x20F0, "bot_is_tag_visible" },
    { 0x20F1, "bot_israndom" },
    { 0x20F2, "bot_jump_for_tag" },
    { 0x20F3, "bot_killstreak_choose_loc_enemies" },
    { 0x20F4, "bot_killstreak_drop" },
    { 0x20F5, "bot_killstreak_drop_anywhere" },
    { 0x20F6, "bot_killstreak_drop_hidden" },
    { 0x20F7, "bot_killstreak_drop_outside" },
    { 0x20F8, "bot_killstreak_get_all_outside_allies" },
    { 0x20F9, "bot_killstreak_get_all_outside_enemies" },
    { 0x20FA, "bot_killstreak_get_outside_players" },
    { 0x20FB, "bot_killstreak_get_zone_allies_outside" },
    { 0x20FC, "bot_killstreak_get_zone_enemies_outside" },
    { 0x20FD, "bot_killstreak_is_valid_internal" },
    { 0x20FE, "bot_killstreak_is_valid_single" },
    { 0x20FF, "bot_killstreak_never_use" },
    { 0x2100, "bot_killstreak_remote_control" },
    { 0x2101, "bot_killstreak_sentry" },
    { 0x2102, "bot_killstreak_setup" },
    { 0x2103, "bot_killstreak_simple_use" },
    { 0x2104, "bot_killstreak_valid_for_specific_streaktype" },
    { 0x2105, "bot_killstreak_vanguard_start" },
    { 0x2106, "bot_know_enemies_on_start" },
    { 0x2107, "bot_ks_funcs" },
    { 0x2108, "bot_ks_heli_offset" },
    { 0x2109, "bot_last_team_ally" },
    { 0x210A, "bot_last_team_enemy" },
    { 0x210B, "bot_lava_think" },
    { 0x210C, "bot_leader_dialog" },
    { 0x210D, "bot_light_volumes" },
    { 0x210E, "bot_loadout_choose_fallback_primary" },
    { 0x210F, "bot_loadout_choose_from_attachmenttable" },
    { 0x2110, "bot_loadout_choose_from_camotable" },
    { 0x2111, "bot_loadout_choose_from_default_class" },
    { 0x2112, "bot_loadout_choose_from_perktable" },
    { 0x2113, "bot_loadout_choose_from_set" },
    { 0x2114, "bot_loadout_choose_from_statstable" },
    { 0x2115, "bot_loadout_choose_values" },
    { 0x2116, "bot_loadout_class_callback" },
    { 0x2117, "bot_loadout_fields" },
    { 0x2118, "bot_loadout_get_archetype" },
    { 0x2119, "bot_loadout_get_difficulty" },
    { 0x211A, "bot_loadout_item_allowed" },
    { 0x211B, "bot_loadout_make_index" },
    { 0x211C, "bot_loadout_perk_slots" },
    { 0x211D, "bot_loadout_pick" },
    { 0x211E, "bot_loadout_set" },
    { 0x211F, "bot_loadout_setup_perks" },
    { 0x2120, "bot_loadout_valid_choice" },
    { 0x2121, "bot_loadouts_initialized" },
    { 0x2122, "bot_lui_convert_team_to_int" },
    { 0x2123, "bot_make_entity_sentient" },
    { 0x2124, "bot_map_center" },
    { 0x2125, "bot_map_max_x" },
    { 0x2126, "bot_map_max_y" },
    { 0x2127, "bot_map_max_z" },
    { 0x2128, "bot_map_min_x" },
    { 0x2129, "bot_map_min_y" },
    { 0x212A, "bot_map_min_z" },
    { 0x212B, "bot_max_players_on_team" },
    { 0x212C, "bot_melee_tactical_insertion_check" },
    { 0x212D, "bot_memory_goal" },
    { 0x212E, "bot_memory_goal_time" },
    { 0x212F, "bot_monitor_enemy_camp_spots" },
    { 0x2130, "bot_monitor_team_limits" },
    { 0x2131, "bot_monitor_watch_entrances_at_goal" },
    { 0x2132, "bot_monitor_watch_entrances_bodyguard" },
    { 0x2133, "bot_monitor_watch_entrances_camp" },
    { 0x2134, "bot_mtmc_think" },
    { 0x2135, "bot_mugger_loadout_modify" },
    { 0x2136, "bot_mugger_think" },
    { 0x2137, "bot_new_tactical_goal" },
    { 0x2138, "bot_nodes" },
    { 0x2139, "bot_notify_streak_used" },
    { 0x213A, "bot_odin_find_target_for_airdrop" },
    { 0x213B, "bot_odin_find_target_for_rods" },
    { 0x213C, "bot_odin_get_closest_visible_outside_player" },
    { 0x213D, "bot_odin_get_high_priority_smoke_locations" },
    { 0x213E, "bot_odin_get_num_valid_care_packages" },
    { 0x213F, "bot_odin_get_player_target_point" },
    { 0x2140, "bot_odin_get_visible_outside_players" },
    { 0x2141, "bot_odin_should_airdrop_at_marker" },
    { 0x2142, "bot_odin_should_drop_smoke_at_marker" },
    { 0x2143, "bot_odin_should_fire_flash_at_marker" },
    { 0x2144, "bot_odin_should_fire_rod_at_marker" },
    { 0x2145, "bot_odin_time_to_move" },
    { 0x2146, "bot_odin_try_airdrop" },
    { 0x2147, "bot_odin_try_flash" },
    { 0x2148, "bot_odin_try_rods" },
    { 0x2149, "bot_odin_try_smoke" },
    { 0x214A, "bot_odin_try_spawn_juggernaut" },
    { 0x214B, "bot_out_of_ammo" },
    { 0x214C, "bot_out_of_combat_time" },
    { 0x214D, "bot_patrol_area" },
    { 0x214E, "bot_payload_think" },
    { 0x214F, "bot_perk_cost" },
    { 0x2150, "bot_perktable" },
    { 0x2151, "bot_perktable_groups" },
    { 0x2152, "bot_perktypes" },
    { 0x2153, "bot_pers_init" },
    { 0x2154, "bot_pers_update" },
    { 0x2155, "bot_personality" },
    { 0x2156, "bot_personality_list" },
    { 0x2157, "bot_personality_type" },
    { 0x2158, "bot_personality_types_desired" },
    { 0x2159, "bot_pick_personality_from_weapon" },
    { 0x215A, "bot_pick_random_point_from_set" },
    { 0x215B, "bot_pick_random_point_in_radius" },
    { 0x215C, "bot_picking_up" },
    { 0x215D, "bot_pickup_weapon" },
    { 0x215E, "bot_pill_think" },
    { 0x215F, "bot_player_spawned" },
    { 0x2160, "bot_point_is_on_pathgrid" },
    { 0x2161, "bot_post_teleport" },
    { 0x2162, "bot_post_use_ammo_crate" },
    { 0x2163, "bot_post_use_box_of_type" },
    { 0x2164, "bot_pre_use_ammo_crate" },
    { 0x2165, "bot_pre_use_box_of_type" },
    { 0x2166, "bot_prematchdonetime" },
    { 0x2167, "bot_protect_point" },
    { 0x2168, "bot_protect_zone" },
    { 0x2169, "bot_queued_process" },
    { 0x216A, "bot_queued_process_level_thread" },
    { 0x216B, "bot_queued_process_level_thread_active" },
    { 0x216C, "bot_queued_process_queue" },
    { 0x216D, "bot_random_path" },
    { 0x216E, "bot_random_path_default" },
    { 0x216F, "bot_random_path_function" },
    { 0x2170, "bot_random_ranks_for_difficulty" },
    { 0x2171, "bot_rank_weapon_class" },
    { 0x2172, "bot_recent_point_of_interest" },
    { 0x2173, "bot_register_killstreak_func" },
    { 0x2174, "bot_remove_from_bot_level_targets" },
    { 0x2175, "bot_remove_invalid_tags" },
    { 0x2176, "bot_respawn_launcher_name" },
    { 0x2177, "bot_restart_think_threads" },
    { 0x2178, "bot_rnd_prestige" },
    { 0x2179, "bot_rnd_rank" },
    { 0x217A, "bot_sam_think" },
    { 0x217B, "bot_scavenger_bags" },
    { 0x217C, "bot_sd_ai_director_update" },
    { 0x217D, "bot_sd_override_zone_targets" },
    { 0x217E, "bot_sd_start" },
    { 0x217F, "bot_sd_think" },
    { 0x2180, "bot_seek_dropped_weapon" },
    { 0x2181, "bot_send_cancel_notify" },
    { 0x2182, "bot_send_place_notify" },
    { 0x2183, "bot_sentry_activate" },
    { 0x2184, "bot_sentry_add_goal" },
    { 0x2185, "bot_sentry_cancel" },
    { 0x2186, "bot_sentry_cancel_failsafe" },
    { 0x2187, "bot_sentry_carried_obj" },
    { 0x2188, "bot_sentry_choose_placement" },
    { 0x2189, "bot_sentry_choose_target" },
    { 0x218A, "bot_sentry_ensure_exit" },
    { 0x218B, "bot_sentry_force_cancel" },
    { 0x218C, "bot_sentry_path_start" },
    { 0x218D, "bot_sentry_path_thread" },
    { 0x218E, "bot_sentry_should_abort" },
    { 0x218F, "bot_set_ambush_trap" },
    { 0x2190, "bot_set_ambush_trap_wait_fire" },
    { 0x2191, "bot_set_bombzone_bottargets" },
    { 0x2192, "bot_set_difficulty" },
    { 0x2193, "bot_set_loadout_class" },
    { 0x2194, "bot_set_objective_bottargets" },
    { 0x2195, "bot_set_personality" },
    { 0x2196, "bot_set_role" },
    { 0x2197, "bot_set_role_delayed" },
    { 0x2198, "bot_setup_bombzone_bottargets" },
    { 0x2199, "bot_setup_bot_targets" },
    { 0x219A, "bot_setup_callback_class" },
    { 0x219B, "bot_setup_loadout_callback" },
    { 0x219C, "bot_setup_objective_bottargets" },
    { 0x219D, "bot_setup_radio_bottargets" },
    { 0x219E, "bot_should_defend" },
    { 0x219F, "bot_should_defend_flag" },
    { 0x21A0, "bot_should_do_killcam" },
    { 0x21A1, "bot_should_melee_level_damage_target" },
    { 0x21A2, "bot_should_pickup_weapons" },
    { 0x21A3, "bot_should_pickup_weapons_infect" },
    { 0x21A4, "bot_should_use_ammo_crate" },
    { 0x21A5, "bot_should_use_ballistic_vest_crate" },
    { 0x21A6, "bot_should_use_grenade_crate" },
    { 0x21A7, "bot_should_use_juicebox_crate" },
    { 0x21A8, "bot_should_use_scavenger_bag" },
    { 0x21A9, "bot_should_use_support_crate" },
    { 0x21AA, "bot_siege_manager_think" },
    { 0x21AB, "bot_siege_think" },
    { 0x21AC, "bot_smoke_sight_clip_large" },
    { 0x21AD, "bot_spawned_before" },
    { 0x21AE, "bot_squad_lookup" },
    { 0x21AF, "bot_squad_lookup_enemy" },
    { 0x21B0, "bot_squad_lookup_private" },
    { 0x21B1, "bot_squad_lookup_ranked" },
    { 0x21B2, "bot_squadmember_lookup" },
    { 0x21B3, "bot_sr_think" },
    { 0x21B4, "bot_start_aa_launcher_tracking" },
    { 0x21B5, "bot_start_know_enemy" },
    { 0x21B6, "bot_start_known_by_enemy" },
    { 0x21B7, "bot_supported_killstreaks" },
    { 0x21B8, "bot_switch_to_killstreak_weapon" },
    { 0x21B9, "bot_tac_ops_think" },
    { 0x21BA, "bot_tag_allowable_jump_height" },
    { 0x21BB, "bot_tag_obj_radius" },
    { 0x21BC, "bot_target" },
    { 0x21BD, "bot_target_is_flag" },
    { 0x21BE, "bot_targets" },
    { 0x21BF, "bot_team" },
    { 0x21C0, "bot_think" },
    { 0x21C1, "bot_think_crate" },
    { 0x21C2, "bot_think_crate_blocking_path" },
    { 0x21C3, "bot_think_dynamic_doors" },
    { 0x21C4, "bot_think_gametype" },
    { 0x21C5, "bot_think_killstreak" },
    { 0x21C6, "bot_think_level_actions" },
    { 0x21C7, "bot_think_nvg" },
    { 0x21C8, "bot_think_revive" },
    { 0x21C9, "bot_think_seek_dropped_weapons" },
    { 0x21CA, "bot_think_tactical_goals" },
    { 0x21CB, "bot_think_watch_aerial_killstreak" },
    { 0x21CC, "bot_think_watch_enemy" },
    { 0x21CD, "bot_throw_ball" },
    { 0x21CE, "bot_tjugg_think" },
    { 0x21CF, "bot_to_hstg_think" },
    { 0x21D0, "bot_triggers" },
    { 0x21D1, "bot_try_trap_follower" },
    { 0x21D2, "bot_update_camp_assassin" },
    { 0x21D3, "bot_usebutton_wait" },
    { 0x21D4, "bot_valid_camp_assassin" },
    { 0x21D5, "bot_validate_perk" },
    { 0x21D6, "bot_validate_reticle" },
    { 0x21D7, "bot_validate_weapon" },
    { 0x21D8, "bot_vanguard_find_unvisited_nodes" },
    { 0x21D9, "bot_vanguard_height_trace_size" },
    { 0x21DA, "bot_variables_initialized" },
    { 0x21DB, "bot_vectors_are_equal" },
    { 0x21DC, "bot_vip_think" },
    { 0x21DD, "bot_visited_times" },
    { 0x21DE, "bot_wait_for_event_flag_swap" },
    { 0x21DF, "bot_waittill_bots_enabled" },
    { 0x21E0, "bot_waittill_goal_or_fail" },
    { 0x21E1, "bot_waittill_out_of_combat_or_time" },
    { 0x21E2, "bot_waittill_using_vehicle" },
    { 0x21E3, "bot_war_think" },
    { 0x21E4, "bot_watch_entrances_delayed" },
    { 0x21E5, "bot_watch_for_death" },
    { 0x21E6, "bot_watch_for_killstreak_use" },
    { 0x21E7, "bot_watch_manual_detonate" },
    { 0x21E8, "bot_watch_new_tags" },
    { 0x21E9, "bot_watch_nodes" },
    { 0x21EA, "bot_weap_personality" },
    { 0x21EB, "bot_weap_statstable" },
    { 0x21EC, "bot_weapon_is_better_class" },
    { 0x21ED, "bot_wmd_think" },
    { 0x21EE, "botarchetype" },
    { 0x21EF, "botarchetypes" },
    { 0x21F0, "botblockedkillstreaks" },
    { 0x21F1, "botharmsdismembered" },
    { 0x21F2, "bothlegsdismembered" },
    { 0x21F3, "botlastloadout" },
    { 0x21F4, "botlastloadoutdifficulty" },
    { 0x21F5, "botlastloadoutpersonality" },
    { 0x21F6, "botloadoutfavoritecamo" },
    { 0x21F7, "botloadoutsets" },
    { 0x21F8, "botloadouttemplates" },
    { 0x21F9, "botopenmonitor" },
    { 0x21FA, "botoperatorref" },
    { 0x21FB, "botoperatorteam" },
    { 0x21FC, "botpickuphack" },
    { 0x21FD, "bots" },
    { 0x21FE, "bots_attacking_wanted" },
    { 0x21FF, "bots_defending_wanted" },
    { 0x2200, "bots_disable_team_switching" },
    { 0x2201, "bots_exist" },
    { 0x2202, "bots_gametype_handles_class_choice" },
    { 0x2203, "bots_gametype_handles_team_choice" },
    { 0x2204, "bots_gametype_initialized" },
    { 0x2205, "bots_ignore_team_balance" },
    { 0x2206, "bots_init" },
    { 0x2207, "bots_notify_on_disconnect" },
    { 0x2208, "bots_notify_on_spawn" },
    { 0x2209, "bots_remove_from_array_on_notify" },
    { 0x220A, "bots_update_difficulty" },
    { 0x220B, "bots_used" },
    { 0x220C, "botsenabled" },
    { 0x220D, "botskinid" },
    { 0x220E, "bottarget" },
    { 0x220F, "bottargets" },
    { 0x2210, "bottomextents" },
    { 0x2211, "bouncelight" },
    { 0x2212, "bounty_index" },
    { 0x2213, "bountycollect" },
    { 0x2214, "bountyconvert" },
    { 0x2215, "bountyincreasestreak" },
    { 0x2216, "bountyinit" },
    { 0x2217, "bountypoints" },
    { 0x2218, "bountystreak" },
    { 0x2219, "box" },
    { 0x221A, "box_activate_func" },
    { 0x221B, "box_addboxforplayer" },
    { 0x221C, "box_agentconnected" },
    { 0x221D, "box_angles" },
    { 0x221E, "box_center" },
    { 0x221F, "box_createinteraction" },
    { 0x2220, "box_debug" },
    { 0x2221, "box_disabled" },
    { 0x2222, "box_disableplayeruse" },
    { 0x2223, "box_enableplayeruse" },
    { 0x2224, "box_handledamage" },
    { 0x2225, "box_handledeath" },
    { 0x2226, "box_handledeathdamage" },
    { 0x2227, "box_handleownerdisconnect" },
    { 0x2228, "box_hint_func" },
    { 0x2229, "box_leave" },
    { 0x222A, "box_modelteamupdater" },
    { 0x222B, "box_modifydamage" },
    { 0x222C, "box_playerconnected" },
    { 0x222D, "box_playerjoinedteam" },
    { 0x222E, "box_setactive" },
    { 0x222F, "box_seticon" },
    { 0x2230, "box_setinactive" },
    { 0x2231, "box_timeout" },
    { 0x2232, "box_waittill_player_spawn_and_add_box" },
    { 0x2233, "box_watchownerstatus" },
    { 0x2234, "box_x" },
    { 0x2235, "box_x_min" },
    { 0x2236, "box_y" },
    { 0x2237, "box_y_min" },
    { 0x2238, "box_z" },
    { 0x2239, "box_z_min" },
    { 0x223A, "boxcapturethink" },
    { 0x223B, "boxes" },
    { 0x223C, "boxiconid" },
    { 0x223D, "boxmodel" },
    { 0x223E, "boxparams" },
    { 0x223F, "boxsettings" },
    { 0x2240, "boxthink" },
    { 0x2241, "boxtouchonly" },
    { 0x2242, "boxtype" },
    { 0x2243, "bp" },
    { 0x2244, "bp_glass_combat_catchup" },
    { 0x2245, "bp_glass_combat_enemies" },
    { 0x2246, "bp_glass_combat_main" },
    { 0x2247, "bp_glass_combat_start" },
    { 0x2248, "bp_glass_combat_wave" },
    { 0x2249, "bp_glass_hint_flash" },
    { 0x224A, "bp_glass_metal_detectors_catchup" },
    { 0x224B, "bp_glass_metal_detectors_main" },
    { 0x224C, "bp_glass_metal_detectors_start" },
    { 0x224D, "bp_glass_price_vo" },
    { 0x224E, "bp_glass_scene_catchup" },
    { 0x224F, "bp_glass_scene_main" },
    { 0x2250, "bp_glass_scene_start" },
    { 0x2251, "bp_glass_vo" },
    { 0x2252, "bpaused" },
    { 0x2253, "bpg_car_fire_light" },
    { 0x2254, "bpg_closers" },
    { 0x2255, "bpg_combat" },
    { 0x2256, "bpg_combat_price" },
    { 0x2257, "bpg_combat_wait_autosave" },
    { 0x2258, "bpg_combat_window_exterior_light_on_and_off" },
    { 0x2259, "bpg_first_wave_enemy" },
    { 0x225A, "bpg_individual_civ_flee" },
    { 0x225B, "bpg_md_aq" },
    { 0x225C, "bpg_md_aq_first_wave" },
    { 0x225D, "bpg_md_aq_stack_up_at_door" },
    { 0x225E, "bpg_md_cowering_civ" },
    { 0x225F, "bpg_md_door" },
    { 0x2260, "bpg_md_door_civ" },
    { 0x2261, "bpg_md_first_wave_objects" },
    { 0x2262, "bpg_md_nag" },
    { 0x2263, "bpg_md_one_off_table" },
    { 0x2264, "bpg_md_price" },
    { 0x2265, "bpg_md_screens" },
    { 0x2266, "bpg_md_table" },
    { 0x2267, "bpg_metal_detectors" },
    { 0x2268, "bpg_scene" },
    { 0x2269, "bpg_scene_aq" },
    { 0x226A, "bpg_scene_aq_basher" },
    { 0x226B, "bpg_scene_aq_basher_crowbar" },
    { 0x226C, "bpg_scene_chair_1" },
    { 0x226D, "bpg_scene_chair_2" },
    { 0x226E, "bpg_scene_chair_3" },
    { 0x226F, "bpg_scene_check_door_interact" },
    { 0x2270, "bpg_scene_civ_escape" },
    { 0x2271, "bpg_scene_civ_escape_count" },
    { 0x2272, "bpg_scene_civ_otherside" },
    { 0x2273, "bpg_scene_civ_otherside_count" },
    { 0x2274, "bpg_scene_civ_vo" },
    { 0x2275, "bpg_scene_enforcer" },
    { 0x2276, "bpg_scene_escape_idle_nag_vo" },
    { 0x2277, "bpg_scene_exit" },
    { 0x2278, "bpg_scene_handle_exit_doors" },
    { 0x2279, "bpg_scene_key_civ" },
    { 0x227A, "bpg_scene_marine" },
    { 0x227B, "bpg_scene_marine_spawn" },
    { 0x227C, "bpg_scene_mother" },
    { 0x227D, "bpg_scene_player_interact" },
    { 0x227E, "bpg_scene_player_interact_aq_enforcer_entourage" },
    { 0x227F, "bpg_scene_player_interact_death" },
    { 0x2280, "bpg_scene_player_interact_struggle" },
    { 0x2281, "bpg_scene_pre_vo" },
    { 0x2282, "bpg_scene_price" },
    { 0x2283, "bpg_scene_price_push_door" },
    { 0x2284, "bpg_scene_price_vo_nag" },
    { 0x2285, "bpg_window_break_through" },
    { 0x2286, "bpgc_conf_aq" },
    { 0x2287, "bpgc_conf_civ" },
    { 0x2288, "bpgc_conf_object" },
    { 0x2289, "bpgc_conference_room" },
    { 0x228A, "bpgc_halligan_breakout_vo" },
    { 0x228B, "bpgc_halligan_scene_vo" },
    { 0x228C, "bpgc_hostage" },
    { 0x228D, "bpgc_hostage_aq" },
    { 0x228E, "bpgc_hostage_bullet_shield" },
    { 0x228F, "bpgc_hostage_char" },
    { 0x2290, "bpgc_hostage_check_damage" },
    { 0x2291, "bpgc_hostage_civ" },
    { 0x2292, "bpgc_hostage_entrance" },
    { 0x2293, "bpgc_interrogation" },
    { 0x2294, "bpgc_interrogation_aq" },
    { 0x2295, "bpgc_interrogation_check_speed_up" },
    { 0x2296, "bpgc_interrogation_civ" },
    { 0x2297, "bpgc_price_halligan_pre_gesture" },
    { 0x2298, "bpgc_price_halligan_scene" },
    { 0x2299, "bpgc_price_halligan_scene_aq_death" },
    { 0x229A, "bpgc_price_halligan_scene_check_player_tries_door" },
    { 0x229B, "bplanted" },
    { 0x229C, "bplayerrevivingteammate" },
    { 0x229D, "bplayingspecificstealthsound" },
    { 0x229E, "bplaysmartobject" },
    { 0x229F, "bpm" },
    { 0x22A0, "bposedstyle" },
    { 0x22A1, "bpossiblefail" },
    { 0x22A2, "bpowerdown" },
    { 0x22A3, "bpowereddown" },
    { 0x22A4, "bpreragdolled" },
    { 0x22A5, "br_ac130" },
    { 0x22A6, "br_allguns" },
    { 0x22A7, "br_ammo" },
    { 0x22A8, "br_ammo_clipsize" },
    { 0x22A9, "br_ammo_give_type" },
    { 0x22AA, "br_ammo_init" },
    { 0x22AB, "br_ammo_max" },
    { 0x22AC, "br_ammo_omnvars" },
    { 0x22AD, "br_ammo_player_clear" },
    { 0x22AE, "br_ammo_player_hud_monitor" },
    { 0x22AF, "br_ammo_player_hud_update_ammotype" },
    { 0x22B0, "br_ammo_player_init" },
    { 0x22B1, "br_ammo_player_reload_watch" },
    { 0x22B2, "br_ammo_take_type" },
    { 0x22B3, "br_ammo_type_for_weapon" },
    { 0x22B4, "br_ammo_type_player_full" },
    { 0x22B5, "br_ammo_types" },
    { 0x22B6, "br_ammo_update_from_weapons" },
    { 0x22B7, "br_ammo_update_weapons" },
    { 0x22B8, "br_armorhealth" },
    { 0x22B9, "br_armorlevel" },
    { 0x22BA, "br_armory_kiosk" },
    { 0x22BB, "br_armory_kiosk_enabled" },
    { 0x22BC, "br_assignedplayertofollow" },
    { 0x22BD, "br_assignedplayertospectate" },
    { 0x22BE, "br_assignedteamtofollow" },
    { 0x22BF, "br_bank_alarm_enabled" },
    { 0x22C0, "br_cash_count" },
    { 0x22C1, "br_cash_time" },
    { 0x22C2, "br_circle" },
    { 0x22C3, "br_circle_disabled" },
    { 0x22C4, "br_circlecenteroverrides" },
    { 0x22C5, "br_circleclosetimes" },
    { 0x22C6, "br_circledelaytimes" },
    { 0x22C7, "br_circledynamicvfx" },
    { 0x22C8, "br_circleinnervfx" },
    { 0x22C9, "br_circleminimapradii" },
    { 0x22CA, "br_circleradii" },
    { 0x22CB, "br_circlestaticvfx" },
    { 0x22CC, "br_cleanups" },
    { 0x22CD, "br_convoytrucks" },
    { 0x22CE, "br_corners" },
    { 0x22CF, "br_crateguns" },
    { 0x22D0, "br_crateitems" },
    { 0x22D1, "br_currentcalloutzone" },
    { 0x22D2, "br_deadcountdownhud" },
    { 0x22D3, "br_debugsolotest" },
    { 0x22D4, "br_depots" },
    { 0x22D5, "br_drop_bags_enabled" },
    { 0x22D6, "br_dropinventoryfordropbagloadout" },
    { 0x22D7, "br_dropoffsets" },
    { 0x22D8, "br_droppedloot" },
    { 0x22D9, "br_equipcount" },
    { 0x22DA, "br_equipname" },
    { 0x22DB, "br_equipnametoscriptable" },
    { 0x22DC, "br_fallaccel" },
    { 0x22DD, "br_finalcircleoverride" },
    { 0x22DE, "br_forcegivecustompickupitem" },
    { 0x22DF, "br_forcegivecustomweapon" },
    { 0x22E0, "br_forcegiveweapon" },
    { 0x22E1, "br_getrandomkillstreakreward" },
    { 0x22E2, "br_getrewardicon" },
    { 0x22E3, "br_getweaponstartingclipammo" },
    { 0x22E4, "br_givedropbagloadout" },
    { 0x22E5, "br_gulagammo" },
    { 0x22E6, "br_gulaggun" },
    { 0x22E7, "br_gulagguncurrent" },
    { 0x22E8, "br_gulagguns" },
    { 0x22E9, "br_gulagoffhands" },
    { 0x22EA, "br_gulagpickups" },
    { 0x22EB, "br_guncount" },
    { 0x22EC, "br_helicopters" },
    { 0x22ED, "br_helmethealth" },
    { 0x22EE, "br_helmetlevel" },
    { 0x22EF, "br_helosmax" },
    { 0x22F0, "br_helospawns" },
    { 0x22F1, "br_infil_type" },
    { 0x22F2, "br_infillocationselectionhandlers" },
    { 0x22F3, "br_infils_disabled" },
    { 0x22F4, "br_infilstarted" },
    { 0x22F5, "br_inventory_slots" },
    { 0x22F6, "br_itemrow" },
    { 0x22F7, "br_itemtype" },
    { 0x22F8, "br_justpickedup" },
    { 0x22F9, "br_killstreakreference" },
    { 0x22FA, "br_killstreaktoscriptable" },
    { 0x22FB, "br_lastincirclenotifytime" },
    { 0x22FC, "br_lastscenecheck" },
    { 0x22FD, "br_lastweaponchange" },
    { 0x22FE, "br_leaderbystreak" },
    { 0x22FF, "br_leftspawn" },
    { 0x2300, "br_level" },
    { 0x2301, "br_loadouts" },
    { 0x2302, "br_lootguns" },
    { 0x2303, "br_lootiteminfo" },
    { 0x2304, "br_mapbounds" },
    { 0x2305, "br_mapcenter" },
    { 0x2306, "br_mapsize" },
    { 0x2307, "br_matchstarted" },
    { 0x2308, "br_maxarmorhealth" },
    { 0x2309, "br_mobile_armory_enabled" },
    { 0x230A, "br_mobilearmories" },
    { 0x230B, "br_objectiveindex" },
    { 0x230C, "br_orbitcam" },
    { 0x230D, "br_perk_points_enabled" },
    { 0x230E, "br_perkpoints" },
    { 0x230F, "br_perks" },
    { 0x2310, "br_pickupconflicts" },
    { 0x2311, "br_pickupdenyalreadyhaveks" },
    { 0x2312, "br_pickupdenyalreadyhavetoken" },
    { 0x2313, "br_pickupdenyalreadyhaveweapon" },
    { 0x2314, "br_pickupdenyammonoroom" },
    { 0x2315, "br_pickupdenyarmornotbetter" },
    { 0x2316, "br_pickupdenyequipnoroom" },
    { 0x2317, "br_pickupnomorerespawn" },
    { 0x2318, "br_pickups" },
    { 0x2319, "br_pickupsfx" },
    { 0x231A, "br_picspawns" },
    { 0x231B, "br_playersdowned" },
    { 0x231C, "br_playersusingsonar" },
    { 0x231D, "br_plunder" },
    { 0x231E, "br_plunder_enabled" },
    { 0x231F, "br_plunder_ents" },
    { 0x2320, "br_plunder_lobby" },
    { 0x2321, "br_plunder_sites" },
    { 0x2322, "br_plunderers" },
    { 0x2323, "br_prematchffa" },
    { 0x2324, "br_prematchloot" },
    { 0x2325, "br_prematchlootparts" },
    { 0x2326, "br_prematchstarted" },
    { 0x2327, "br_quests_enabled" },
    { 0x2328, "br_queststashlocations" },
    { 0x2329, "br_respawn_enabled" },
    { 0x232A, "br_respawn_loadout" },
    { 0x232B, "br_respawnambulances" },
    { 0x232C, "br_respawned" },
    { 0x232D, "br_safecirclereset" },
    { 0x232E, "br_satellite_truck_enabled" },
    { 0x232F, "br_satellitetruck" },
    { 0x2330, "br_sonartickrates" },
    { 0x2331, "br_spawndensepois" },
    { 0x2332, "br_spawndistanceratio" },
    { 0x2333, "br_spawnpois" },
    { 0x2334, "br_spawns" },
    { 0x2335, "br_spawnsemidensepois" },
    { 0x2336, "br_spawnsparsepois" },
    { 0x2337, "br_spectatorinitialized" },
    { 0x2338, "br_squadindex" },
    { 0x2339, "br_superreference" },
    { 0x233A, "br_supportedguns" },
    { 0x233B, "br_supporteditems" },
    { 0x233C, "br_throwables" },
    { 0x233D, "br_totalvehiclesmax" },
    { 0x233E, "br_totalvehiclesspawned" },
    { 0x233F, "br_truck" },
    { 0x2340, "br_usables" },
    { 0x2341, "br_usespawnclosets" },
    { 0x2342, "br_vehicleallspawns" },
    { 0x2343, "br_vehiclealwaysspawns" },
    { 0x2344, "br_vehtargetnametoref" },
    { 0x2345, "br_vieworigin" },
    { 0x2346, "br_weaponsbygroup" },
    { 0x2347, "br_weaponsprimary" },
    { 0x2348, "br_weaponssecondary" },
    { 0x2349, "br_weapontoscriptable" },
    { 0x234A, "br_weaponweights" },
    { 0x234B, "br_weaponweighttotal" },
    { 0x234C, "bradley" },
    { 0x234D, "bradley_handlefataltacopsdamage" },
    { 0x234E, "bradley_handletacopsdamage" },
    { 0x234F, "bradley_onfirecamera" },
    { 0x2350, "bradley_onfireshocknearplayers" },
    { 0x2351, "bradley_ref_sphere" },
    { 0x2352, "bradley_restorehealth" },
    { 0x2353, "bradley_turretdustkickup" },
    { 0x2354, "bradley_vehicledestroy" },
    { 0x2355, "bradleybeginuse" },
    { 0x2356, "bradleydamagewatcher" },
    { 0x2357, "bradleymodeloverride" },
    { 0x2358, "branalytics_deployallowed" },
    { 0x2359, "branalytics_deployland" },
    { 0x235A, "branalytics_deploytriggered" },
    { 0x235B, "branalytics_down" },
    { 0x235C, "branalytics_equipmentuse" },
    { 0x235D, "branalytics_lootdrop" },
    { 0x235E, "branalytics_lootpickup" },
    { 0x235F, "branalytics_revive" },
    { 0x2360, "branches" },
    { 0x2361, "bravo_3_toggle_laser" },
    { 0x2362, "bravo_ai_array_handler" },
    { 0x2363, "bravo_driver" },
    { 0x2364, "bravo_gate_open" },
    { 0x2365, "bravo_gate_vo" },
    { 0x2366, "bravo_gate_vo_open" },
    { 0x2367, "bravo_midway_anims" },
    { 0x2368, "bravo_team" },
    { 0x2369, "bravo1" },
    { 0x236A, "bravo1_2f_idle" },
    { 0x236B, "bravo1_3f_ending" },
    { 0x236C, "bravo1_3f_return_fire" },
    { 0x236D, "bravo1_3f_shot_at_vo" },
    { 0x236E, "bravo1_enters_3f_room" },
    { 0x236F, "bravo1_gas_search" },
    { 0x2370, "bravo1_idle" },
    { 0x2371, "bravo1_move_into_warehouse" },
    { 0x2372, "bravo1_street_movement" },
    { 0x2373, "bravo2" },
    { 0x2374, "bravo2_gas_search" },
    { 0x2375, "bravo2_idle" },
    { 0x2376, "bravo2_move_into_warehouse" },
    { 0x2377, "bravo2_tape" },
    { 0x2378, "bravo2_truck_convoy" },
    { 0x2379, "bravo3" },
    { 0x237A, "bravo3_approach_and_mask_up" },
    { 0x237B, "bravo3_final_scene" },
    { 0x237C, "bravo3_gas_search" },
    { 0x237D, "bravo3_head_to_convoy" },
    { 0x237E, "bravo3_move_into_warehouse" },
    { 0x237F, "bravo3_vo" },
    { 0x2380, "bravo4" },
    { 0x2381, "bravo4_3_door_enter" },
    { 0x2382, "bravo4_4_open_baby_door" },
    { 0x2383, "bravo4_4_try_early_mom_death" },
    { 0x2384, "bravo4_4_use_death_react" },
    { 0x2385, "bravo4_4_use_stand_death_react" },
    { 0x2386, "bravo4_frontdoor_enter" },
    { 0x2387, "bravo4_movements" },
    { 0x2388, "bravo5" },
    { 0x2389, "bravo5_anim_check" },
    { 0x238A, "bravo5_in_door" },
    { 0x238B, "bravo6" },
    { 0x238C, "bravo7" },
    { 0x238D, "bravoagents" },
    { 0x238E, "bravoai" },
    { 0x238F, "brbroadcastplayercardsplash" },
    { 0x2390, "brchooselaststandweapon" },
    { 0x2391, "brcircleextract" },
    { 0x2392, "brcleanuptime" },
    { 0x2393, "brcrateactivatecallback" },
    { 0x2394, "brcratecapturecallback" },
    { 0x2395, "brdpadcallback" },
    { 0x2396, "breach_anims" },
    { 0x2397, "breach_anims_jumpto" },
    { 0x2398, "breach_bomb_detach" },
    { 0x2399, "breach_door_scene" },
    { 0x239A, "breach_doors" },
    { 0x239B, "breach_explosion_fx" },
    { 0x239C, "breach_gate" },
    { 0x239D, "breach_gate_nag" },
    { 0x239E, "breach_good_vo" },
    { 0x239F, "breach_hint_func" },
    { 0x23A0, "breach_into_courtyard" },
    { 0x23A1, "breach_trigger_time" },
    { 0x23A2, "breach_use_func" },
    { 0x23A3, "breachanimlength" },
    { 0x23A4, "breachdoor" },
    { 0x23A5, "breached" },
    { 0x23A6, "breached_gate_catchup" },
    { 0x23A7, "breached_gate_start" },
    { 0x23A8, "breachernum" },
    { 0x23A9, "breachindex" },
    { 0x23AA, "breaching" },
    { 0x23AB, "breachmonitor" },
    { 0x23AC, "breachpoints" },
    { 0x23AD, "breachusetriggers" },
    { 0x23AE, "breacting" },
    { 0x23AF, "bread_crumbs" },
    { 0x23B0, "breadcrumb_objective" },
    { 0x23B1, "breadycomplete" },
    { 0x23B2, "break_catchup" },
    { 0x23B3, "break_cover_after_breached" },
    { 0x23B4, "break_door" },
    { 0x23B5, "break_final_catchup" },
    { 0x23B6, "break_final_main" },
    { 0x23B7, "break_final_main_wegame" },
    { 0x23B8, "break_final_start" },
    { 0x23B9, "break_flags" },
    { 0x23BA, "break_glass" },
    { 0x23BB, "break_glass_on_traverse" },
    { 0x23BC, "break_intro_main" },
    { 0x23BD, "break_lock" },
    { 0x23BE, "break_orders_catchup" },
    { 0x23BF, "break_orders_main" },
    { 0x23C0, "break_orders_start" },
    { 0x23C1, "break_out_of_disguise_loop" },
    { 0x23C2, "break_pc_on_damage" },
    { 0x23C3, "break_player_out_of_anim" },
    { 0x23C4, "break_precache" },
    { 0x23C5, "break_setup" },
    { 0x23C6, "break_start" },
    { 0x23C7, "break_stealth_for_anyone_near" },
    { 0x23C8, "break_waterboard_catchup" },
    { 0x23C9, "break_waterboard_main" },
    { 0x23CA, "break_waterboard_start" },
    { 0x23CB, "breakanimref" },
    { 0x23CC, "breakanswer1" },
    { 0x23CD, "breakanswer2" },
    { 0x23CE, "breakanswer3" },
    { 0x23CF, "breakanswer4" },
    { 0x23D0, "breakgasmask" },
    { 0x23D1, "breakhelmet" },
    { 0x23D2, "breakout" },
    { 0x23D3, "breakout_to_color" },
    { 0x23D4, "breakout_wait" },
    { 0x23D5, "breakuserangesqr" },
    { 0x23D6, "breath_fade_delay" },
    { 0x23D7, "breath_fx_thread" },
    { 0x23D8, "breathdeck" },
    { 0x23D9, "breathingmanager" },
    { 0x23DA, "breathingstoptime" },
    { 0x23DB, "breathlevel" },
    { 0x23DC, "breathloopdeck" },
    { 0x23DD, "breathoverlay" },
    { 0x23DE, "breathranouttime" },
    { 0x23DF, "breaths" },
    { 0x23E0, "breathviewoffsets_accell" },
    { 0x23E1, "breathviewoffsets_accellcycle" },
    { 0x23E2, "breathviewoffsetslogic" },
    { 0x23E3, "brendgame" },
    { 0x23E4, "brick_hint" },
    { 0x23E5, "bridge_blocker_1" },
    { 0x23E6, "bridge_blocker_2" },
    { 0x23E7, "bridge_blocker_friendlies_spawn" },
    { 0x23E8, "bridge_blockers_delete" },
    { 0x23E9, "bridge_catchup" },
    { 0x23EA, "bridge_crawlers" },
    { 0x23EB, "bridge_guy_setup" },
    { 0x23EC, "bridge_guys_die" },
    { 0x23ED, "bridge_main" },
    { 0x23EE, "bridge_overseer_handler" },
    { 0x23EF, "bridge_stair_up_combat_think" },
    { 0x23F0, "bridge_stair_up_enemy" },
    { 0x23F1, "bridge_start" },
    { 0x23F2, "bridge_start_struct_index" },
    { 0x23F3, "bridge_tank_shoots" },
    { 0x23F4, "bridgedompoint_onuse" },
    { 0x23F5, "bridgeobjectiveindex" },
    { 0x23F6, "brief_color_disable" },
    { 0x23F7, "brinit" },
    { 0x23F8, "brkillstreak" },
    { 0x23F9, "brkillstreakhudicon" },
    { 0x23FA, "brkillstreakhudlabel" },
    { 0x23FB, "brlatespawnplayer" },
    { 0x23FC, "brleaderdialog" },
    { 0x23FD, "brloadoutcrateactivatecallback" },
    { 0x23FE, "brloadoutcratecapturecallback" },
    { 0x23FF, "brloadouts" },
    { 0x2400, "brlootcache" },
    { 0x2401, "brlootcache_init" },
    { 0x2402, "brloottablename" },
    { 0x2403, "brmapselectionafk" },
    { 0x2404, "brmodifyplayerdamage" },
    { 0x2405, "bro" },
    { 0x2406, "broadcast_armor" },
    { 0x2407, "broadcast_role" },
    { 0x2408, "broadcast_status" },
    { 0x2409, "brodeodisabled" },
    { 0x240A, "brodeohintdisabled" },
    { 0x240B, "brokearmorvest" },
    { 0x240C, "brokehelmet" },
    { 0x240D, "broken_pos" },
    { 0x240E, "bronzescore" },
    { 0x240F, "bronzetime" },
    { 0x2410, "broshotepictauntprops" },
    { 0x2411, "broshotepictauntsubprops" },
    { 0x2412, "broshotfirstcamblends" },
    { 0x2413, "broshotintrodone" },
    { 0x2414, "broshotrunning" },
    { 0x2415, "broshottauntqueue" },
    { 0x2416, "broshotwinnersgoodguys" },
    { 0x2417, "brouteforward" },
    { 0x2418, "brpickupsusecallback" },
    { 0x2419, "brplayerhudoutlinedelayedhide" },
    { 0x241A, "brprematchaddkill" },
    { 0x241B, "brprematchclearkills" },
    { 0x241C, "brush_delete" },
    { 0x241D, "brush_show" },
    { 0x241E, "brush_shown" },
    { 0x241F, "brush_throw" },
    { 0x2420, "brushmodel" },
    { 0x2421, "brutefirstspawn" },
    { 0x2422, "brvehicleonprematchstarted" },
    { 0x2423, "brvehiclesinit" },
    { 0x2424, "brvehiclesonstartgametype" },
    { 0x2425, "brvehiclespawnvolreset" },
    { 0x2426, "brvehiclesreset" },
    { 0x2427, "brvehspawnvols" },
    { 0x2428, "brwasinlaststand" },
    { 0x2429, "bshockactive" },
    { 0x242A, "bshootidle" },
    { 0x242B, "bshouldattemptdive" },
    { 0x242C, "bshouldoccupantsbeignored" },
    { 0x242D, "bshouldstop" },
    { 0x242E, "bskipplantsequence" },
    { 0x242F, "bskipstartcoverarrival" },
    { 0x2430, "bsmstate" },
    { 0x2431, "bsoldier" },
    { 0x2432, "bsoundlooping" },
    { 0x2433, "bspawningviaac130" },
    { 0x2434, "bstarted" },
    { 0x2435, "bstayincombatoncealerted" },
    { 0x2436, "bstrafeenabled" },
    { 0x2437, "bt" },
    { 0x2438, "bt_escaping" },
    { 0x2439, "bt_event_combat" },
    { 0x243A, "bt_event_cover_blown" },
    { 0x243B, "bt_event_handler_severity" },
    { 0x243C, "bt_event_investigate" },
    { 0x243D, "bt_set_stealth_state" },
    { 0x243E, "bt_terminateandreplace" },
    { 0x243F, "btargetlastknown" },
    { 0x2440, "bteleported" },
    { 0x2441, "btestclient" },
    { 0x2442, "bthrowgrenade" },
    { 0x2443, "btm" },
    { 0x2444, "btmextraprimaryspawnpoints" },
    { 0x2445, "btmflagobject" },
    { 0x2446, "btmjuggcrate" },
    { 0x2447, "btmjugginfo" },
    { 0x2448, "btraversing" },
    { 0x2449, "btreeorient" },
    { 0x244A, "btstate_addsubstate" },
    { 0x244B, "btstate_clearsubstates" },
    { 0x244C, "btstate_endcurrentsubstate" },
    { 0x244D, "btstate_endstates" },
    { 0x244E, "btstate_getcurrentsubstate" },
    { 0x244F, "btstate_getsubstate" },
    { 0x2450, "btstate_setupstate" },
    { 0x2451, "btstate_tickstates" },
    { 0x2452, "btstate_transitionstate" },
    { 0x2453, "bucket" },
    { 0x2454, "bucket_terminator" },
    { 0x2455, "buddy_boost" },
    { 0x2456, "buddy_boost_restart" },
    { 0x2457, "buddy_down" },
    { 0x2458, "buddy_down_damage_thread" },
    { 0x2459, "buddy_down_dialogue" },
    { 0x245A, "buddy_down_door_damage" },
    { 0x245B, "buddy_down_dropgun" },
    { 0x245C, "buddy_down_enemydead_interrupt" },
    { 0x245D, "buddy_down_gunner_damage_thread" },
    { 0x245E, "buddy_down_gunner_death" },
    { 0x245F, "buddy_down_gunner_flashed_thread" },
    { 0x2460, "buddy_down_player_engaging_early" },
    { 0x2461, "buddy_down_price_anim" },
    { 0x2462, "buddy_down_remove_playerclip" },
    { 0x2463, "buddy_down_skip_move" },
    { 0x2464, "buddy_down_skip_post_clear" },
    { 0x2465, "buddy_down_skip_setup" },
    { 0x2466, "buddy_down_trigger_damage_ondamage" },
    { 0x2467, "buddy_down_trigger_damage_onflashbang" },
    { 0x2468, "buddy_down_two_enemy_dead_thread" },
    { 0x2469, "buddyplayerid" },
    { 0x246A, "buddyspawn" },
    { 0x246B, "buddyspawnid" },
    { 0x246C, "budgetedents" },
    { 0x246D, "budy_death_watcher" },
    { 0x246E, "buffedbyplayers" },
    { 0x246F, "buffered" },
    { 0x2470, "bufferedbestscorestats" },
    { 0x2471, "bufferedchildstats" },
    { 0x2472, "bufferedchildstatsmax" },
    { 0x2473, "bufferednotifications" },
    { 0x2474, "bufferednotify" },
    { 0x2475, "bufferednotify_internal" },
    { 0x2476, "bufferedstats" },
    { 0x2477, "bufferedstatsmax" },
    { 0x2478, "bufferedstatwritethink" },
    { 0x2479, "bufferedweapons" },
    { 0x247A, "bug_out" },
    { 0x247B, "bug_test_move_startpoint" },
    { 0x247C, "bugoutontimeout" },
    { 0x247D, "build_ace" },
    { 0x247E, "build_aianims" },
    { 0x247F, "build_all_treadfx" },
    { 0x2480, "build_atmo_types" },
    { 0x2481, "build_attach_models" },
    { 0x2482, "build_bulletshield" },
    { 0x2483, "build_call_buttons" },
    { 0x2484, "build_deathanimations" },
    { 0x2485, "build_deathfx" },
    { 0x2486, "build_deathmodel" },
    { 0x2487, "build_deathquake" },
    { 0x2488, "build_destructible" },
    { 0x2489, "build_drive" },
    { 0x248A, "build_elevators" },
    { 0x248B, "build_enginefx" },
    { 0x248C, "build_exhaust" },
    { 0x248D, "build_fx" },
    { 0x248E, "build_grenadeshield" },
    { 0x248F, "build_hideparts" },
    { 0x2490, "build_idle" },
    { 0x2491, "build_is_airplane" },
    { 0x2492, "build_is_helicopter" },
    { 0x2493, "build_landanims" },
    { 0x2494, "build_life" },
    { 0x2495, "build_light" },
    { 0x2496, "build_localinit" },
    { 0x2497, "build_mainturret" },
    { 0x2498, "build_matrix_from_up_and_angles" },
    { 0x2499, "build_mine_cart" },
    { 0x249A, "build_path" },
    { 0x249B, "build_path_from_script_linkto" },
    { 0x249C, "build_playercontrolled_model" },
    { 0x249D, "build_quake" },
    { 0x249E, "build_radiusdamage" },
    { 0x249F, "build_rebel_mask_lookup" },
    { 0x24A0, "build_rider_death_func" },
    { 0x24A1, "build_rocket_deathfx" },
    { 0x24A2, "build_rumble" },
    { 0x24A3, "build_semiace" },
    { 0x24A4, "build_single_tread" },
    { 0x24A5, "build_tank_duration" },
    { 0x24A6, "build_tank_path" },
    { 0x24A7, "build_team" },
    { 0x24A8, "build_template" },
    { 0x24A9, "build_treadfx" },
    { 0x24AA, "build_truck_duration" },
    { 0x24AB, "build_truck_path" },
    { 0x24AC, "build_turret" },
    { 0x24AD, "build_turret_struct" },
    { 0x24AE, "build_unload_groups" },
    { 0x24AF, "build_vehicles" },
    { 0x24B0, "build_weapon_name_func" },
    { 0x24B1, "buildac130infilanimstruct" },
    { 0x24B2, "buildandloadweapons" },
    { 0x24B3, "buildattachmentmaps" },
    { 0x24B4, "buildhuntstealthgroupgraphdata" },
    { 0x24B5, "buildhuntstealthgrouptransitiondata" },
    { 0x24B6, "building_expl_sfx" },
    { 0x24B7, "building_rails_destroy" },
    { 0x24B8, "buildkilldeathactionvalue" },
    { 0x24B9, "buildloadoutsforweaponstreaming" },
    { 0x24BA, "buildloadoutstring" },
    { 0x24BB, "buildmeritinfo" },
    { 0x24BC, "buildmerittableinfo" },
    { 0x24BD, "buildprimaries" },
    { 0x24BE, "buildrandomattachmentarray" },
    { 0x24BF, "buildrandomweapontable" },
    { 0x24C0, "buildscoreboardtype" },
    { 0x24C1, "buildsecondaries" },
    { 0x24C2, "buildspawnpointstatestring" },
    { 0x24C3, "buildtripwire" },
    { 0x24C4, "buildtripwiretrap" },
    { 0x24C5, "buildweapon" },
    { 0x24C6, "buildweapon_attachmentidmap" },
    { 0x24C7, "buildweapon_variant" },
    { 0x24C8, "buildweaponassetname" },
    { 0x24C9, "buildweaponattachmentidmap" },
    { 0x24CA, "buildweaponmap" },
    { 0x24CB, "buildweaponmaps" },
    { 0x24CC, "buildweaponname" },
    { 0x24CD, "buildweaponnamecamo" },
    { 0x24CE, "buildweaponnamereticle" },
    { 0x24CF, "buildweaponnamevariantid" },
    { 0x24D0, "buildweaponrootlist" },
    { 0x24D1, "buildweaponuniqueattachments" },
    { 0x24D2, "buildweaponuniqueattachmenttoidmap" },
    { 0x24D3, "buildweaponwithrandomattachments" },
    { 0x24D4, "bulblength" },
    { 0x24D5, "bulbradius" },
    { 0x24D6, "bullet_damage" },
    { 0x24D7, "bullet_damage_scalar" },
    { 0x24D8, "bullet_decal" },
    { 0x24D9, "bullet_feedback_init" },
    { 0x24DA, "bullet_feedback_precache" },
    { 0x24DB, "bullet_fly_fast_to_target" },
    { 0x24DC, "bullet_health" },
    { 0x24DD, "bullet_shield" },
    { 0x24DE, "bullet_show" },
    { 0x24DF, "bullet_whizby_hud" },
    { 0x24E0, "bulletcount" },
    { 0x24E1, "bulletdrop" },
    { 0x24E2, "bulletkillsinaframecount" },
    { 0x24E3, "bulletoutline" },
    { 0x24E4, "bulletoutlineaddenemy" },
    { 0x24E5, "bulletoutlinecheck" },
    { 0x24E6, "bulletoutlineremoveenemy" },
    { 0x24E7, "bulletpoint" },
    { 0x24E8, "bullets" },
    { 0x24E9, "bullets_can_damage" },
    { 0x24EA, "bulletshielded" },
    { 0x24EB, "bulletsinitialstate" },
    { 0x24EC, "bulletstormshield" },
    { 0x24ED, "bullettracer_hack" },
    { 0x24EE, "bulletwhizby_monitor" },
    { 0x24EF, "bump_weapon_onpickup" },
    { 0x24F0, "bunker_black_bars" },
    { 0x24F1, "bunker_black_fade" },
    { 0x24F2, "bunker_blackoverlaylogic" },
    { 0x24F3, "bunker_caption_vo" },
    { 0x24F4, "bunker_catchup" },
    { 0x24F5, "bunker_cine_dof_settings" },
    { 0x24F6, "bunker_flags" },
    { 0x24F7, "bunker_gas_mask_overlay" },
    { 0x24F8, "bunker_getallycovernodes" },
    { 0x24F9, "bunker_hint" },
    { 0x24FA, "bunker_main" },
    { 0x24FB, "bunker_outro_fade" },
    { 0x24FC, "bunker_outrologic" },
    { 0x24FD, "bunker_player_model" },
    { 0x24FE, "bunker_remove_gas_mask" },
    { 0x24FF, "bunker_start" },
    { 0x2500, "bunkerblackoverlay" },
    { 0x2501, "bunkerdoorleft" },
    { 0x2502, "bunkerdoorright" },
    { 0x2503, "bunkeroutroblackoverlay" },
    { 0x2504, "bunkers_enter_watcher" },
    { 0x2505, "bunkers_kill_allies" },
    { 0x2506, "bunkers_main" },
    { 0x2507, "bunkers_start" },
    { 0x2508, "buried_background_conversations" },
    { 0x2509, "buried_black_fade" },
    { 0x250A, "buried_catchup" },
    { 0x250B, "buried_explosion_vfx" },
    { 0x250C, "buried_heard_yells" },
    { 0x250D, "buried_hit_sequence" },
    { 0x250E, "buried_intro_scene" },
    { 0x250F, "buried_kill_trigger" },
    { 0x2510, "buried_main" },
    { 0x2511, "buried_rebar_model" },
    { 0x2512, "buried_rubble_01_model" },
    { 0x2513, "buried_rubble_02_model" },
    { 0x2514, "buried_rubble_03_model" },
    { 0x2515, "buried_rubble_04_model" },
    { 0x2516, "buried_rubble_pile_rocks_model" },
    { 0x2517, "buried_rubble_setup" },
    { 0x2518, "buried_start" },
    { 0x2519, "buried_start_vo" },
    { 0x251A, "buried_struggle_rubble_hero_01_model" },
    { 0x251B, "buried_struggle_rubble_hero_02_model" },
    { 0x251C, "buried_struggle_rubble_hero_03_model" },
    { 0x251D, "buried_struggle_rubble_hero_04_model" },
    { 0x251E, "buried_struggle_rubble_hero_05_model" },
    { 0x251F, "buried_struggle_rubble_hero_06_model" },
    { 0x2520, "buried_struggle_rubble_hero_07_model" },
    { 0x2521, "buried_struggle_rubble_model" },
    { 0x2522, "buried_transient_check_first_frame" },
    { 0x2523, "buried_unheard_yells" },
    { 0x2524, "buried_vo_finished" },
    { 0x2525, "buried_wires_model" },
    { 0x2526, "buriedsunangles" },
    { 0x2527, "burn_death_overlay" },
    { 0x2528, "burn_enemies" },
    { 0x2529, "burn_notetrack_handler" },
    { 0x252A, "burn_player_if_goes_back_down_shaft" },
    { 0x252B, "burndelaytime" },
    { 0x252C, "burnfxcorpstablefunc" },
    { 0x252D, "burnfxenabled" },
    { 0x252E, "burnfxplaying" },
    { 0x252F, "burnfxsuppressed" },
    { 0x2530, "burnfxsupressed" },
    { 0x2531, "burnid" },
    { 0x2532, "burning" },
    { 0x2533, "burning_trash_fire" },
    { 0x2534, "burningcar_indicator" },
    { 0x2535, "burningcarindicator" },
    { 0x2536, "burningdirection" },
    { 0x2537, "burningid" },
    { 0x2538, "burninginfo" },
    { 0x2539, "burningtodeath" },
    { 0x253A, "burnsfx" },
    { 0x253B, "burnsfxenabled" },
    { 0x253C, "burnsource" },
    { 0x253D, "burnvfx" },
    { 0x253E, "burst" },
    { 0x253F, "burst_fire" },
    { 0x2540, "burst_fire_settings" },
    { 0x2541, "burst_fire_unmanned" },
    { 0x2542, "burstdelay" },
    { 0x2543, "burstfirenumshots" },
    { 0x2544, "burstmax" },
    { 0x2545, "burstmin" },
    { 0x2546, "burstshootanimrate" },
    { 0x2547, "bus_anim" },
    { 0x2548, "bus_animated_civs" },
    { 0x2549, "bus_dialogue" },
    { 0x254A, "bus_entered" },
    { 0x254B, "bus_terrorist" },
    { 0x254C, "bus_terrorist_dialogue" },
    { 0x254D, "bus_terrorist_explode" },
    { 0x254E, "bus_terrorist_success" },
    { 0x254F, "bus_terry_killing_logic" },
    { 0x2550, "busereadyidle" },
    { 0x2551, "buseweakrockets" },
    { 0x2552, "busingcqbpoi" },
    { 0x2553, "butcher" },
    { 0x2554, "butcher_dialog_struct" },
    { 0x2555, "butcher_hit_timing_handler" },
    { 0x2556, "butcher_son_dialog_struct" },
    { 0x2557, "butcher_stayahead_chase_speeds" },
    { 0x2558, "butcher_wife_dialog_struct" },
    { 0x2559, "button_combo" },
    { 0x255A, "button_dof" },
    { 0x255B, "button_interaction_thread" },
    { 0x255C, "button_is_clicked" },
    { 0x255D, "button_is_held" },
    { 0x255E, "button_is_kb" },
    { 0x255F, "button_notifies" },
    { 0x2560, "button_parse_parameters" },
    { 0x2561, "button_sound" },
    { 0x2562, "buttonclick" },
    { 0x2563, "buttondebounce" },
    { 0x2564, "buttondown" },
    { 0x2565, "buttonhelddown" },
    { 0x2566, "buttonisheld" },
    { 0x2567, "buttonpress_create_exploder" },
    { 0x2568, "buttonpress_create_interval_sound" },
    { 0x2569, "buttonpress_create_loopfx" },
    { 0x256A, "buttonpress_create_loopsound" },
    { 0x256B, "buttonpress_create_oneshot" },
    { 0x256C, "buttonpress_create_reactiveent" },
    { 0x256D, "buttonpressed_internal" },
    { 0x256E, "buttons" },
    { 0x256F, "buttonspressed" },
    { 0x2570, "buyperkinslot" },
    { 0x2571, "buzzkill" },
    { 0x2572, "bval" },
    { 0x2573, "bvaultover" },
    { 0x2574, "bvictimlinkstoattacker" },
    { 0x2575, "bwaitingforteamselect" },
    { 0x2576, "bwaituntilstop" },
    { 0x2577, "bwantstostrafe" },
    { 0x2578, "bypass_flags" },
    { 0x2579, "bypass_regular_enemy_setmodel" },
    { 0x257A, "bypassclasschoice" },
    { 0x257B, "bypassclasschoicefunc" },
    { 0x257C, "bypassdbcheck" },
    { 0x257D, "c" },
    { 0x257E, "c0" },
    { 0x257F, "c1" },
    { 0x2580, "c12" },
    { 0x2581, "c12_clearscriptedtargets" },
    { 0x2582, "c12_disablerodeo" },
    { 0x2583, "c12_disablerodeohint" },
    { 0x2584, "c12_enableautonomouscombat" },
    { 0x2585, "c12_enablesecondarytargeting" },
    { 0x2586, "c12_enablestrafe" },
    { 0x2587, "c12_enableweakrockets" },
    { 0x2588, "c12_enableweaponslot" },
    { 0x2589, "c12_getweapontypeforweapon" },
    { 0x258A, "c12_initpickuphints" },
    { 0x258B, "c12_islegdismembered" },
    { 0x258C, "c12_player_out_of_heavy_ammo" },
    { 0x258D, "c12_setaimspeedmultiplier" },
    { 0x258E, "c12_setrocketarc" },
    { 0x258F, "c12_setscriptedtargets" },
    { 0x2590, "c12_updateachievement" },
    { 0x2591, "c12_weapon_pickup_hint_check" },
    { 0x2592, "c12_weapon_pickup_hint_delete_check" },
    { 0x2593, "c12_weapon_pickup_respawn_check" },
    { 0x2594, "c12_weaponsetup" },
    { 0x2595, "c130" },
    { 0x2596, "c130_call" },
    { 0x2597, "c130_crash_sequence" },
    { 0x2598, "c130_fightpathmove" },
    { 0x2599, "c130_final_crash_sequence" },
    { 0x259A, "c130_follow_path" },
    { 0x259B, "c130_follow_takeoff_path" },
    { 0x259C, "c130_heightoverride" },
    { 0x259D, "c130_idle" },
    { 0x259E, "c130_parts" },
    { 0x259F, "c130_path_reached" },
    { 0x25A0, "c130_pickrandomflightpath" },
    { 0x25A1, "c130_revive" },
    { 0x25A2, "c130_sealeveloverride" },
    { 0x25A3, "c130_seat_idles" },
    { 0x25A4, "c130_seat_refs" },
    { 0x25A5, "c130_speedoverride" },
    { 0x25A6, "c130_take_off_sequence" },
    { 0x25A7, "c130alignedtolocale" },
    { 0x25A8, "c130distapart" },
    { 0x25A9, "c130firstpassstarted" },
    { 0x25AA, "c130flightdist" },
    { 0x25AB, "c130forcespawnplayer" },
    { 0x25AC, "c130frontlinepos" },
    { 0x25AD, "c130frontlinevec" },
    { 0x25AE, "c130inbounds" },
    { 0x25AF, "c130minpathmovementinterval" },
    { 0x25B0, "c130movementmethod" },
    { 0x25B1, "c130pathkilltracker" },
    { 0x25B2, "c130pathstruct" },
    { 0x25B3, "c130pathstruct_a" },
    { 0x25B4, "c130pathstruct_b" },
    { 0x25B5, "c130spacing_usebigmapsettings" },
    { 0x25B6, "c2" },
    { 0x25B7, "c3" },
    { 0x25B8, "c4" },
    { 0x25B9, "c4_addtoarray" },
    { 0x25BA, "c4_animdetonate" },
    { 0x25BB, "c4_animdetonatecleanup" },
    { 0x25BC, "c4_breach" },
    { 0x25BD, "c4_breach_think" },
    { 0x25BE, "c4_breachable" },
    { 0x25BF, "c4_candetonate" },
    { 0x25C0, "c4_countdown" },
    { 0x25C1, "c4_delete" },
    { 0x25C2, "c4_deleteonownerdisconnect" },
    { 0x25C3, "c4_destroy" },
    { 0x25C4, "c4_destroyonemp" },
    { 0x25C5, "c4_destroyongameend" },
    { 0x25C6, "c4_detonate" },
    { 0x25C7, "c4_detonateall" },
    { 0x25C8, "c4_earthquake" },
    { 0x25C9, "c4_empapplied" },
    { 0x25CA, "c4_escape_array" },
    { 0x25CB, "c4_explode" },
    { 0x25CC, "c4_explodeonnotify" },
    { 0x25CD, "c4_monitor_dmg" },
    { 0x25CE, "c4_nuke" },
    { 0x25CF, "c4_on_door" },
    { 0x25D0, "c4_onownerchanged" },
    { 0x25D1, "c4_pickup_dof" },
    { 0x25D2, "c4_plating_logic" },
    { 0x25D3, "c4_removefromarray" },
    { 0x25D4, "c4_removefromarrayondeath" },
    { 0x25D5, "c4_resetaltdetonpickup" },
    { 0x25D6, "c4_resetscriptableonunlink" },
    { 0x25D7, "c4_set" },
    { 0x25D8, "c4_struct" },
    { 0x25D9, "c4_updatedangerzone" },
    { 0x25DA, "c4_use_think" },
    { 0x25DB, "c4_used" },
    { 0x25DC, "c4_validdetonationstate" },
    { 0x25DD, "c4_watchforaltdetonation" },
    { 0x25DE, "c4_watchfordetonation" },
    { 0x25DF, "c4activate" },
    { 0x25E0, "c4createcursor" },
    { 0x25E1, "c4damage" },
    { 0x25E2, "c4detonateallcharges" },
    { 0x25E3, "c4detonation" },
    { 0x25E4, "c4empdamage" },
    { 0x25E5, "c4explodethisframe" },
    { 0x25E6, "c4firemain" },
    { 0x25E7, "c4implode" },
    { 0x25E8, "c4nodetonatorfiremain" },
    { 0x25E9, "c4s" },
    { 0x25EA, "c4stuck" },
    { 0x25EB, "c4used" },
    { 0x25EC, "c6_initmelee" },
    { 0x25ED, "c6_ismeleevalid" },
    { 0x25EE, "c6_scriptablecleanup" },
    { 0x25EF, "c8_scriptablecleanup" },
    { 0x25F0, "c8deathsound" },
    { 0x25F1, "cac_checkoverkillperk" },
    { 0x25F2, "cac_getaccessorydata" },
    { 0x25F3, "cac_getaccessoryweapon" },
    { 0x25F4, "cac_getcharacterarchetype" },
    { 0x25F5, "cac_getequipmentprimary" },
    { 0x25F6, "cac_getequipmentsecondary" },
    { 0x25F7, "cac_getexecution" },
    { 0x25F8, "cac_getextraequipmentprimary" },
    { 0x25F9, "cac_getextraequipmentsecondary" },
    { 0x25FA, "cac_getfieldupgrade" },
    { 0x25FB, "cac_getgesture" },
    { 0x25FC, "cac_getkillstreak" },
    { 0x25FD, "cac_getloadoutarchetypeperk" },
    { 0x25FE, "cac_getloadoutextraperk" },
    { 0x25FF, "cac_getloadoutperk" },
    { 0x2600, "cac_getloadoutselectedidx" },
    { 0x2601, "cac_getsuper" },
    { 0x2602, "cac_getusingspecialist" },
    { 0x2603, "cac_getweapon" },
    { 0x2604, "cac_getweaponattachment" },
    { 0x2605, "cac_getweaponcamo" },
    { 0x2606, "cac_getweaponcosmeticattachment" },
    { 0x2607, "cac_getweaponlootitemid" },
    { 0x2608, "cac_getweaponreticle" },
    { 0x2609, "cac_getweaponsticker" },
    { 0x260A, "cac_getweaponvariantid" },
    { 0x260B, "cac_modified_damage" },
    { 0x260C, "cache_catchup" },
    { 0x260D, "cache_dialoguelogic" },
    { 0x260E, "cache_exitlogic" },
    { 0x260F, "cache_getanimationstruct" },
    { 0x2610, "cache_getcouch" },
    { 0x2611, "cache_getdoor" },
    { 0x2612, "cache_getfarahbackpack" },
    { 0x2613, "cache_main" },
    { 0x2614, "cache_setupanimatedentities" },
    { 0x2615, "cache_setupdoor" },
    { 0x2616, "cache_spawnfarahbackpack" },
    { 0x2617, "cache_start" },
    { 0x2618, "cache_waittillplayerhassilencedweapon" },
    { 0x2619, "cachearenagungameloadouts" },
    { 0x261A, "cachedactions" },
    { 0x261B, "cachegamemodeloadout" },
    { 0x261C, "cacheloottablename" },
    { 0x261D, "cachelootweaponweaponinfo" },
    { 0x261E, "cacheplayeraction" },
    { 0x261F, "cacherandomloadouts" },
    { 0x2620, "cachewid" },
    { 0x2621, "calc_best_closest_struct" },
    { 0x2622, "calc_length_of_full_veh_path" },
    { 0x2623, "calcanimstartpos" },
    { 0x2624, "calcarrivaltype" },
    { 0x2625, "calccameraduration" },
    { 0x2626, "calcconvergencetarget" },
    { 0x2627, "calcdooropenspeed" },
    { 0x2628, "calcentity" },
    { 0x2629, "calcfirstcamerablendpts" },
    { 0x262A, "calcfrontposbasedonvelocity" },
    { 0x262B, "calcgoodshootpos" },
    { 0x262C, "calchit" },
    { 0x262D, "calckillcamtimes" },
    { 0x262E, "calckillmultiplier" },
    { 0x262F, "calcnormal" },
    { 0x2630, "calcorigin" },
    { 0x2631, "calcprestarttime" },
    { 0x2632, "calcsceneplaybacktimes" },
    { 0x2633, "calcscenepsoffset" },
    { 0x2634, "calcstreakcost" },
    { 0x2635, "calctrailpoint" },
    { 0x2636, "calctraversetype" },
    { 0x2637, "calculate_ai_cluster_spawner_score" },
    { 0x2638, "calculate_ai_spawner_score" },
    { 0x2639, "calculate_ai_veh_spawner_score" },
    { 0x263A, "calculate_and_show_encounter_scores" },
    { 0x263B, "calculate_average_velocity" },
    { 0x263C, "calculate_consumables_earned_score" },
    { 0x263D, "calculate_damage_score" },
    { 0x263E, "calculate_defend_stance" },
    { 0x263F, "calculate_encounter_scores" },
    { 0x2640, "calculate_func" },
    { 0x2641, "calculate_money_earned_score" },
    { 0x2642, "calculate_player_encounter_scores" },
    { 0x2643, "calculate_players_total_end_game_score" },
    { 0x2644, "calculate_tag_on_path_grid" },
    { 0x2645, "calculate_tickets_earned_score" },
    { 0x2646, "calculate_total_end_game_score" },
    { 0x2647, "calculate_traverse_data" },
    { 0x2648, "calculate_under_max_score" },
    { 0x2649, "calculateadjustedspeedforshortpath" },
    { 0x264A, "calculatecameraoffset" },
    { 0x264B, "calculatecorrectbinarysequence" },
    { 0x264C, "calculated_closest_point" },
    { 0x264D, "calculated_nearest_node" },
    { 0x264E, "calculatedroplocationnearlocation" },
    { 0x264F, "calculatefactorscore" },
    { 0x2650, "calculatefourbitbinarysequence" },
    { 0x2651, "calculatefrontline" },
    { 0x2652, "calculatehqmidpoint" },
    { 0x2653, "calculateinterruptdelay" },
    { 0x2654, "calculatematchbonus" },
    { 0x2655, "calculatenodeoffset" },
    { 0x2656, "calculateplayerstatratio" },
    { 0x2657, "calculatepotgscore" },
    { 0x2658, "calculaterangeofprojectilemotion" },
    { 0x2659, "calculaterotationmatrixaroundx" },
    { 0x265A, "calculaterotationmatrixaroundy" },
    { 0x265B, "calculaterotationmatrixaroundz" },
    { 0x265C, "calculatesharpturnanim" },
    { 0x265D, "calculatesonartickrate" },
    { 0x265E, "calculatespawndisttoballstart" },
    { 0x265F, "calculatespawndisttozones" },
    { 0x2660, "calculatestopdata" },
    { 0x2661, "calculatestopdatawarningtime" },
    { 0x2662, "calculateteamclusters" },
    { 0x2663, "calculations_in_progress" },
    { 0x2664, "call_ai_cellphone" },
    { 0x2665, "call_back_func" },
    { 0x2666, "call_continuous" },
    { 0x2667, "call_elevator" },
    { 0x2668, "call_func_set" },
    { 0x2669, "call_func_with_params" },
    { 0x266A, "call_in_reinforcements" },
    { 0x266B, "call_nag_func" },
    { 0x266C, "call_on_notetrack" },
    { 0x266D, "call_on_notify" },
    { 0x266E, "call_on_notify_no_endon_death" },
    { 0x266F, "call_on_notify_no_self" },
    { 0x2670, "call_on_notify_proc" },
    { 0x2671, "call_out_missed_shots" },
    { 0x2672, "call_out_runner_died" },
    { 0x2673, "call_sung_lighting_setup" },
    { 0x2674, "call_wave_on_group_killed" },
    { 0x2675, "call_wave_on_group_killed_interal" },
    { 0x2676, "call_when_thread_ended" },
    { 0x2677, "call_with_params" },
    { 0x2678, "call_with_params_builtin" },
    { 0x2679, "call_with_params_script" },
    { 0x267A, "callback_agent_impaled" },
    { 0x267B, "callback_defaultplayerlaststand" },
    { 0x267C, "callback_finishweaponchange" },
    { 0x267D, "callback_frontendhostmigration" },
    { 0x267E, "callback_frontendplayerconnect" },
    { 0x267F, "callback_frontendplayerdamage" },
    { 0x2680, "callback_frontendplayerdisconnect" },
    { 0x2681, "callback_frontendplayerimpaled" },
    { 0x2682, "callback_frontendplayerkilled" },
    { 0x2683, "callback_frontendplayerlaststand" },
    { 0x2684, "callback_frontendplayermigrated" },
    { 0x2685, "callback_frontendstartgametype" },
    { 0x2686, "callback_hostmigration" },
    { 0x2687, "callback_killingblow" },
    { 0x2688, "callback_playerconnect" },
    { 0x2689, "callback_playerdamage" },
    { 0x268A, "callback_playerdamage_internal" },
    { 0x268B, "callback_playerdisconnect" },
    { 0x268C, "callback_playerimpaled" },
    { 0x268D, "callback_playerkilled" },
    { 0x268E, "callback_playerlaststand" },
    { 0x268F, "callback_playermigrated" },
    { 0x2690, "callback_startgametype" },
    { 0x2691, "callback_vehicledamage" },
    { 0x2692, "callback_vehicledamage_internal" },
    { 0x2693, "callback_vehicledeath" },
    { 0x2694, "callbackcodeendgame" },
    { 0x2695, "callbackfinishweaponchange" },
    { 0x2696, "callbackhostmigration" },
    { 0x2697, "callbackplayerconnect" },
    { 0x2698, "callbackplayerdamage" },
    { 0x2699, "callbackplayerdisconnect" },
    { 0x269A, "callbackplayerimpaled" },
    { 0x269B, "callbackplayerkilled" },
    { 0x269C, "callbackplayerlaststand" },
    { 0x269D, "callbackplayermigrated" },
    { 0x269E, "callbacks" },
    { 0x269F, "callbacksoldieragentdamaged" },
    { 0x26A0, "callbacksoldieragentgametypedamagefinished" },
    { 0x26A1, "callbacksoldieragentgametypekilled" },
    { 0x26A2, "callbackspawnpointcritscore" },
    { 0x26A3, "callbackspawnpointprecalc" },
    { 0x26A4, "callbackspawnpointscore" },
    { 0x26A5, "callbackstartgametype" },
    { 0x26A6, "callbackvoid" },
    { 0x26A7, "callcorpsetablefuncs" },
    { 0x26A8, "called_wave_spawning" },
    { 0x26A9, "calledout" },
    { 0x26AA, "caller" },
    { 0x26AB, "callin" },
    { 0x26AC, "calling_reinforcements" },
    { 0x26AD, "callout" },
    { 0x26AE, "callout_bunch_radius" },
    { 0x26AF, "callout_civilians" },
    { 0x26B0, "callout_debounce_all" },
    { 0x26B1, "callout_debounce_guy" },
    { 0x26B2, "callout_disabled" },
    { 0x26B3, "callout_enabled" },
    { 0x26B4, "callout_func_validator" },
    { 0x26B5, "callout_next" },
    { 0x26B6, "callout_player_gone_hot" },
    { 0x26B7, "callout_player_location" },
    { 0x26B8, "callout_proximity_radius" },
    { 0x26B9, "callout_radius" },
    { 0x26BA, "callout_spotted" },
    { 0x26BB, "callout_trace_contents" },
    { 0x26BC, "callout_traces" },
    { 0x26BD, "callout_type_override" },
    { 0x26BE, "calloutarea" },
    { 0x26BF, "calloutareathink" },
    { 0x26C0, "calloutdestroyed" },
    { 0x26C1, "calloutglobals" },
    { 0x26C2, "calloutinputcount" },
    { 0x26C3, "calloutmarkerping_createcallout" },
    { 0x26C4, "calloutmarkerping_createcalloutbattlechatter" },
    { 0x26C5, "calloutmarkerping_deathtimeout" },
    { 0x26C6, "calloutmarkerping_feedback" },
    { 0x26C7, "calloutmarkerping_feedbackdanger" },
    { 0x26C8, "calloutmarkerping_feedbackenemy" },
    { 0x26C9, "calloutmarkerping_feedbackloot" },
    { 0x26CA, "calloutmarkerping_feedbacknavigation" },
    { 0x26CB, "calloutmarkerping_feedbackvehicle" },
    { 0x26CC, "calloutmarkerping_feedbackworld" },
    { 0x26CD, "calloutmarkerping_getavailablelootindex" },
    { 0x26CE, "calloutmarkerping_geticon" },
    { 0x26CF, "calloutmarkerping_getlootcalloutstringvo" },
    { 0x26D0, "calloutmarkerping_getlootscriptablemarkericon" },
    { 0x26D1, "calloutmarkerping_getlootscriptableoriginfromindex" },
    { 0x26D2, "calloutmarkerping_getplayerangles" },
    { 0x26D3, "calloutmarkerping_getpoolidnavigation" },
    { 0x26D4, "calloutmarkerping_gettype" },
    { 0x26D5, "calloutmarkerping_getzoffset" },
    { 0x26D6, "calloutmarkerping_handlelookingatexistingcalloutmarker" },
    { 0x26D7, "calloutmarkerping_handlelookingatexistingcalloutmarkerscriptable" },
    { 0x26D8, "calloutmarkerping_init" },
    { 0x26D9, "calloutmarkerping_initplayer" },
    { 0x26DA, "calloutmarkerping_islookingatexistingcalloutmarker" },
    { 0x26DB, "calloutmarkerping_islookingatexistingcalloutmarkerscriptable" },
    { 0x26DC, "calloutmarkerping_onplayerdisconnect" },
    { 0x26DD, "calloutmarkerping_playvo" },
    { 0x26DE, "calloutmarkerping_processinput" },
    { 0x26DF, "calloutmarkerping_processscriptable" },
    { 0x26E0, "calloutmarkerping_removecallout" },
    { 0x26E1, "calloutmarkerping_removecalloutfromtacmap" },
    { 0x26E2, "calloutmarkerping_setcalloutdata" },
    { 0x26E3, "calloutmarkerping_watchentitydeath" },
    { 0x26E4, "calloutmarkerping_watchscriptabledeath" },
    { 0x26E5, "calloutmarkerpingpool" },
    { 0x26E6, "calloutmarkers" },
    { 0x26E7, "calloutpoolsizes" },
    { 0x26E8, "callouttable" },
    { 0x26E9, "callouttypewillrepeat" },
    { 0x26EA, "calloutzones" },
    { 0x26EB, "callsetlaserflag" },
    { 0x26EC, "callsign_excluders" },
    { 0x26ED, "callsign_prefix" },
    { 0x26EE, "callsign_squad" },
    { 0x26EF, "callsign_suffix" },
    { 0x26F0, "callstrike" },
    { 0x26F1, "callstrike_findoptimaldirection" },
    { 0x26F2, "callstrike_fuelbombeffect" },
    { 0x26F3, "callstrike_getrandomshotoffset" },
    { 0x26F4, "callstrike_playmultitracerfx" },
    { 0x26F5, "callstrike_precisionbulleteffect" },
    { 0x26F6, "callweapongivencallback" },
    { 0x26F7, "calulatefrontline" },
    { 0x26F8, "cam_angle_change" },
    { 0x26F9, "cam_enemy_caret_follow_target_til_cleanup" },
    { 0x26FA, "cam_enemy_marking" },
    { 0x26FB, "cam_ent" },
    { 0x26FC, "cam_fly_down" },
    { 0x26FD, "cam_fly_path" },
    { 0x26FE, "cam_fly_up" },
    { 0x26FF, "cam_hud" },
    { 0x2700, "cam_org" },
    { 0x2701, "cam_shake_crush" },
    { 0x2702, "cam_shake_ground" },
    { 0x2703, "cam_shake_low" },
    { 0x2704, "cam_shake_off" },
    { 0x2705, "cam_shake_parked" },
    { 0x2706, "cam_shake_running" },
    { 0x2707, "cam_structs" },
    { 0x2708, "cam_switcher" },
    { 0x2709, "cam_switcher_fade_out" },
    { 0x270A, "cam_target" },
    { 0x270B, "camactivation" },
    { 0x270C, "camangle" },
    { 0x270D, "camdata" },
    { 0x270E, "camera" },
    { 0x270F, "camera_anchor" },
    { 0x2710, "camera_and_flag_watcher" },
    { 0x2711, "camera_blackcell" },
    { 0x2712, "camera_blackcell_detail" },
    { 0x2713, "camera_bro_shot" },
    { 0x2714, "camera_change_hint_check" },
    { 0x2715, "camera_character_faction_select_l" },
    { 0x2716, "camera_character_faction_select_l_detail" },
    { 0x2717, "camera_character_faction_select_r" },
    { 0x2718, "camera_character_faction_select_r_detail" },
    { 0x2719, "camera_character_tango" },
    { 0x271A, "camera_character_tournaments" },
    { 0x271B, "camera_controller_init" },
    { 0x271C, "camera_enemy_behavior" },
    { 0x271D, "camera_fov_change" },
    { 0x271E, "camera_ground_point" },
    { 0x271F, "camera_handle_notetracks" },
    { 0x2720, "camera_height" },
    { 0x2721, "camera_interacts_init" },
    { 0x2722, "camera_interacts_remove" },
    { 0x2723, "camera_interacts_remover" },
    { 0x2724, "camera_interacts_watcher" },
    { 0x2725, "camera_intro_dof_off" },
    { 0x2726, "camera_intro_dof_on" },
    { 0x2727, "camera_intro_dof_rack" },
    { 0x2728, "camera_intro_fov_start" },
    { 0x2729, "camera_loadout_showcase" },
    { 0x272A, "camera_loadout_showcase_l" },
    { 0x272B, "camera_loadout_showcase_o" },
    { 0x272C, "camera_loadout_showcase_o_large" },
    { 0x272D, "camera_loadout_showcase_overview" },
    { 0x272E, "camera_loadout_showcase_p" },
    { 0x272F, "camera_loadout_showcase_p_large" },
    { 0x2730, "camera_loadout_showcase_perks" },
    { 0x2731, "camera_loadout_showcase_preview" },
    { 0x2732, "camera_loadout_showcase_preview_barrel" },
    { 0x2733, "camera_loadout_showcase_preview_barrel_alt1" },
    { 0x2734, "camera_loadout_showcase_preview_charm" },
    { 0x2735, "camera_loadout_showcase_preview_charm_alt1" },
    { 0x2736, "camera_loadout_showcase_preview_charm_alt2" },
    { 0x2737, "camera_loadout_showcase_preview_charm_alt3" },
    { 0x2738, "camera_loadout_showcase_preview_large" },
    { 0x2739, "camera_loadout_showcase_preview_large_barrel" },
    { 0x273A, "camera_loadout_showcase_preview_large_barrel_alt1" },
    { 0x273B, "camera_loadout_showcase_preview_large_charm" },
    { 0x273C, "camera_loadout_showcase_preview_large_charm_alt1" },
    { 0x273D, "camera_loadout_showcase_preview_large_charm_alt2" },
    { 0x273E, "camera_loadout_showcase_preview_large_laser" },
    { 0x273F, "camera_loadout_showcase_preview_large_magazine" },
    { 0x2740, "camera_loadout_showcase_preview_large_magazine_alt1" },
    { 0x2741, "camera_loadout_showcase_preview_large_magazine_alt2" },
    { 0x2742, "camera_loadout_showcase_preview_large_muzzle" },
    { 0x2743, "camera_loadout_showcase_preview_large_muzzle_alt1" },
    { 0x2744, "camera_loadout_showcase_preview_large_optic" },
    { 0x2745, "camera_loadout_showcase_preview_large_reargrip" },
    { 0x2746, "camera_loadout_showcase_preview_large_reargrip_alt1" },
    { 0x2747, "camera_loadout_showcase_preview_large_stock" },
    { 0x2748, "camera_loadout_showcase_preview_large_underbarrel" },
    { 0x2749, "camera_loadout_showcase_preview_large_underbarrel_alt1" },
    { 0x274A, "camera_loadout_showcase_preview_laser" },
    { 0x274B, "camera_loadout_showcase_preview_laser_alt1" },
    { 0x274C, "camera_loadout_showcase_preview_laser_alt2" },
    { 0x274D, "camera_loadout_showcase_preview_magazine" },
    { 0x274E, "camera_loadout_showcase_preview_magazine_alt1" },
    { 0x274F, "camera_loadout_showcase_preview_magazine_alt2" },
    { 0x2750, "camera_loadout_showcase_preview_muzzle" },
    { 0x2751, "camera_loadout_showcase_preview_muzzle_alt1" },
    { 0x2752, "camera_loadout_showcase_preview_optic" },
    { 0x2753, "camera_loadout_showcase_preview_optic_alt1" },
    { 0x2754, "camera_loadout_showcase_preview_reargrip" },
    { 0x2755, "camera_loadout_showcase_preview_reargrip_alt1" },
    { 0x2756, "camera_loadout_showcase_preview_reargrip_alt2" },
    { 0x2757, "camera_loadout_showcase_preview_riot" },
    { 0x2758, "camera_loadout_showcase_preview_small" },
    { 0x2759, "camera_loadout_showcase_preview_small_barrel" },
    { 0x275A, "camera_loadout_showcase_preview_small_charm" },
    { 0x275B, "camera_loadout_showcase_preview_small_laser" },
    { 0x275C, "camera_loadout_showcase_preview_small_magazine" },
    { 0x275D, "camera_loadout_showcase_preview_small_magazine_alt1" },
    { 0x275E, "camera_loadout_showcase_preview_small_muzzle" },
    { 0x275F, "camera_loadout_showcase_preview_small_optic" },
    { 0x2760, "camera_loadout_showcase_preview_small_reargrip" },
    { 0x2761, "camera_loadout_showcase_preview_small_stock" },
    { 0x2762, "camera_loadout_showcase_preview_small_trigger" },
    { 0x2763, "camera_loadout_showcase_preview_stock" },
    { 0x2764, "camera_loadout_showcase_preview_stock_alt1" },
    { 0x2765, "camera_loadout_showcase_preview_stock_alt2" },
    { 0x2766, "camera_loadout_showcase_preview_underbarrel" },
    { 0x2767, "camera_loadout_showcase_preview_watch" },
    { 0x2768, "camera_loadout_showcase_s" },
    { 0x2769, "camera_loadout_showcase_specialist" },
    { 0x276A, "camera_loadout_showcase_t" },
    { 0x276B, "camera_loadout_showcase_watch" },
    { 0x276C, "camera_loadout_showcase_x" },
    { 0x276D, "camera_loadout_showcase_y" },
    { 0x276E, "camera_loadout_showcase_z" },
    { 0x276F, "camera_lobby" },
    { 0x2770, "camera_lobby_detail" },
    { 0x2771, "camera_lookat" },
    { 0x2772, "camera_max_height" },
    { 0x2773, "camera_min_height" },
    { 0x2774, "camera_min_height_think" },
    { 0x2775, "camera_move" },
    { 0x2776, "camera_move_helper" },
    { 0x2777, "camera_movement_think" },
    { 0x2778, "camera_nav_obstacle" },
    { 0x2779, "camera_number" },
    { 0x277A, "camera_quartermaster" },
    { 0x277B, "camera_quartermaster_detail" },
    { 0x277C, "camera_reset_think" },
    { 0x277D, "camera_section_change" },
    { 0x277E, "camera_setup_for_lerping" },
    { 0x277F, "camera_store" },
    { 0x2780, "camera_ui_bg_01" },
    { 0x2781, "camera_worldmap" },
    { 0x2782, "camera_zoom_hint_check" },
    { 0x2783, "camera_zoom_think" },
    { 0x2784, "camera_zoomout" },
    { 0x2785, "cameraactivatetrack" },
    { 0x2786, "cameraactivationstructs" },
    { 0x2787, "cameraang" },
    { 0x2788, "cameracapturetrackdata" },
    { 0x2789, "cameraent" },
    { 0x278A, "cameraexecutetrackdata_marines_1st" },
    { 0x278B, "cameraexecutetrackdata_marines_1st_alt" },
    { 0x278C, "cameraexecutetrackdata_marines_2nd" },
    { 0x278D, "cameraexecutetrackdata_marines_3rd" },
    { 0x278E, "cameraexecutetrackdata_opfor_1st" },
    { 0x278F, "cameraexecutetrackdata_opfor_2nd" },
    { 0x2790, "cameraexecutetrackdata_opfor_3rd" },
    { 0x2791, "camerahighestindex" },
    { 0x2792, "cameraidletrackdata_marine" },
    { 0x2793, "cameraidletrackdata_opfor" },
    { 0x2794, "cameraintroidletrackdata" },
    { 0x2795, "cameraintrotrackdata" },
    { 0x2796, "cameraintrotrackdata_marine" },
    { 0x2797, "cameraintrotrackdata_opfor" },
    { 0x2798, "camerakilltrackdata" },
    { 0x2799, "cameralerpto" },
    { 0x279A, "cameramapobjs" },
    { 0x279B, "cameramercytrackdata_marines_1st" },
    { 0x279C, "cameramercytrackdata_marines_2nd" },
    { 0x279D, "cameramercytrackdata_marines_3rd" },
    { 0x279E, "cameramercytrackdata_opfor_1st" },
    { 0x279F, "cameramercytrackdata_opfor_2nd" },
    { 0x27A0, "cameramercytrackdata_opfor_3rd" },
    { 0x27A1, "camerapos" },
    { 0x27A2, "camerastyle" },
    { 0x27A3, "cameratarget" },
    { 0x27A4, "cameratrackcapturecam" },
    { 0x27A5, "cameratrackintrocam" },
    { 0x27A6, "cameratrackkillcam" },
    { 0x27A7, "cameraused" },
    { 0x27A8, "camhint" },
    { 0x27A9, "caminit" },
    { 0x27AA, "cammover" },
    { 0x27AB, "camp_bomb_update" },
    { 0x27AC, "campaign" },
    { 0x27AD, "camper_guy" },
    { 0x27AE, "camper_time_started_hunting" },
    { 0x27AF, "camper_trigger_think" },
    { 0x27B0, "camping_needs_fallback_camp_location" },
    { 0x27B1, "cams" },
    { 0x27B2, "camstr" },
    { 0x27B3, "camtime" },
    { 0x27B4, "can" },
    { 0x27B5, "can_add_item" },
    { 0x27B6, "can_announce_sound" },
    { 0x27B7, "can_auto_adjust" },
    { 0x27B8, "can_be_empd" },
    { 0x27B9, "can_be_executed" },
    { 0x27BA, "can_be_killed" },
    { 0x27BB, "can_be_script_killed" },
    { 0x27BC, "can_be_seen" },
    { 0x27BD, "can_callout_enemy" },
    { 0x27BE, "can_camp_near_others" },
    { 0x27BF, "can_compromise_before_first_target" },
    { 0x27C0, "can_do_hotjoin_via_ac130" },
    { 0x27C1, "can_do_segmented_health_regen" },
    { 0x27C2, "can_emp_player" },
    { 0x27C3, "can_execute" },
    { 0x27C4, "can_exit" },
    { 0x27C5, "can_fake_snipe" },
    { 0x27C6, "can_find_new_target" },
    { 0x27C7, "can_fire_turret" },
    { 0x27C8, "can_flashlight_ai_see_player" },
    { 0x27C9, "can_fulton" },
    { 0x27CA, "can_give_revive_xp" },
    { 0x27CB, "can_give_weapon" },
    { 0x27CC, "can_hypno" },
    { 0x27CD, "can_i_see_an_enemy_or_can_enemies_see_me" },
    { 0x27CE, "can_kill_off_list" },
    { 0x27CF, "can_melee_enemy_time" },
    { 0x27D0, "can_move_to_next_node" },
    { 0x27D1, "can_open_door" },
    { 0x27D2, "can_pickup_bomb_time" },
    { 0x27D3, "can_pickup_hvt" },
    { 0x27D4, "can_pivot_change" },
    { 0x27D5, "can_place_sentry" },
    { 0x27D6, "can_play_dialogue_system" },
    { 0x27D7, "can_play_nearby_gesture" },
    { 0x27D8, "can_play_nearby_interaction" },
    { 0x27D9, "can_play_random_idle" },
    { 0x27DA, "can_player_see_any_part_of_enemy" },
    { 0x27DB, "can_purchase_ammo" },
    { 0x27DC, "can_purchase_interaction" },
    { 0x27DD, "can_purchase_item" },
    { 0x27DE, "can_remind" },
    { 0x27DF, "can_respawn_ied_zone" },
    { 0x27E0, "can_revive" },
    { 0x27E1, "can_rocket_hover" },
    { 0x27E2, "can_route_othercar" },
    { 0x27E3, "can_say_friendlyfire" },
    { 0x27E4, "can_see_attacker_for_a_bit" },
    { 0x27E5, "can_see_drone" },
    { 0x27E6, "can_see_farah_watcher" },
    { 0x27E7, "can_see_hadir_watcher" },
    { 0x27E8, "can_see_origin" },
    { 0x27E9, "can_see_player" },
    { 0x27EA, "can_set_traversal_unit_type" },
    { 0x27EB, "can_spawn_capsule_trace" },
    { 0x27EC, "can_steal_hvt" },
    { 0x27ED, "can_teleport" },
    { 0x27EE, "can_trace_to_ai" },
    { 0x27EF, "can_trace_to_player" },
    { 0x27F0, "can_update_player_armor_model" },
    { 0x27F1, "can_upgrade" },
    { 0x27F2, "can_use" },
    { 0x27F3, "can_use_attachment" },
    { 0x27F4, "can_use_flashlight" },
    { 0x27F5, "can_use_interaction" },
    { 0x27F6, "can_use_munition" },
    { 0x27F7, "can_use_override_func" },
    { 0x27F8, "can_use_perk" },
    { 0x27F9, "can_use_pistol_during_last_stand" },
    { 0x27FA, "can_use_pistol_during_laststand_func" },
    { 0x27FB, "can_weapon_stun_juggernaut" },
    { 0x27FC, "canaiflingweapon" },
    { 0x27FD, "canaimwhilemoving" },
    { 0x27FE, "canal_ambulance_siren" },
    { 0x27FF, "canal_background_fakecivs" },
    { 0x2800, "canal_car_alarms_off" },
    { 0x2801, "canal_car_damage_check" },
    { 0x2802, "canal_car_death_check" },
    { 0x2803, "canal_car_handler" },
    { 0x2804, "canal_car_hit_player" },
    { 0x2805, "canal_car_jumper_setup" },
    { 0x2806, "canal_car_kill_player" },
    { 0x2807, "canal_catchup" },
    { 0x2808, "canal_check_player_shoot_first" },
    { 0x2809, "canal_civ_car_damage_handler" },
    { 0x280A, "canal_civ_car_mb" },
    { 0x280B, "canal_civ_car_setup" },
    { 0x280C, "canal_civ_handler" },
    { 0x280D, "canal_civ_panic" },
    { 0x280E, "canal_civs_flee_car" },
    { 0x280F, "canal_civs_flee_car_handler" },
    { 0x2810, "canal_civs_flee_handler" },
    { 0x2811, "canal_civs_flee_parent_child" },
    { 0x2812, "canal_civs_flee_parent_child_handler" },
    { 0x2813, "canal_civs_onlookers_behavior" },
    { 0x2814, "canal_civs_onlookers_handler" },
    { 0x2815, "canal_containment" },
    { 0x2816, "canal_dead_bodies" },
    { 0x2817, "canal_driveby_vignette" },
    { 0x2818, "canal_enemy_death_monitor" },
    { 0x2819, "canal_enemy_fallback" },
    { 0x281A, "canal_enemy_handler" },
    { 0x281B, "canal_enemy_in_vehicle" },
    { 0x281C, "canal_enemy_rpg_truck" },
    { 0x281D, "canal_enemy_setup" },
    { 0x281E, "canal_enforcer_handler" },
    { 0x281F, "canal_enforcer_mb" },
    { 0x2820, "canal_extra_police_car" },
    { 0x2821, "canal_init" },
    { 0x2822, "canal_kill_rushing_player" },
    { 0x2823, "canal_main" },
    { 0x2824, "canal_price_handler" },
    { 0x2825, "canal_pursuit_timer_handler" },
    { 0x2826, "canal_rpg_earthquake_handler" },
    { 0x2827, "canal_rpg_firing_loop" },
    { 0x2828, "canal_rpg_handler" },
    { 0x2829, "canal_start" },
    { 0x282A, "canal_start_watcher" },
    { 0x282B, "canal_stp_main" },
    { 0x282C, "canal_traffic" },
    { 0x282D, "canal_vig_init" },
    { 0x282E, "canal_vig_start" },
    { 0x282F, "canattackfromexposed" },
    { 0x2830, "canattackfromexposedtime" },
    { 0x2831, "canautodestruct" },
    { 0x2832, "canbecomehvt" },
    { 0x2833, "canbedamaged" },
    { 0x2834, "canbeflashbanged" },
    { 0x2835, "canbemarkedingroup" },
    { 0x2836, "canbeplaced" },
    { 0x2837, "canberepaired" },
    { 0x2838, "canblindfire" },
    { 0x2839, "cancalloutlocation" },
    { 0x283A, "cancapture" },
    { 0x283B, "cancaptureimmediately" },
    { 0x283C, "cancarryloot" },
    { 0x283D, "cancel_fake_molotov" },
    { 0x283E, "cancelanimscriptmp" },
    { 0x283F, "cancelanimscriptmp_internal" },
    { 0x2840, "cancelentitiesinradius" },
    { 0x2841, "cancelinteraction" },
    { 0x2842, "cancelkillcam" },
    { 0x2843, "cancelladder" },
    { 0x2844, "cancellethaldelay" },
    { 0x2845, "cancelmode" },
    { 0x2846, "cancelonuserelease" },
    { 0x2847, "cancelplant" },
    { 0x2848, "cancelpowerovertime" },
    { 0x2849, "cancelsuperdelay" },
    { 0x284A, "cancircledamageplayer" },
    { 0x284B, "canclaim" },
    { 0x284C, "canclaimsmartobject" },
    { 0x284D, "canconcat" },
    { 0x284E, "cancontestclaim" },
    { 0x284F, "candamagetrap" },
    { 0x2850, "candeploykillstreak" },
    { 0x2851, "candeploykillstreakweapon" },
    { 0x2852, "candeploylmg" },
    { 0x2853, "candidatesradio" },
    { 0x2854, "candidatesvoice" },
    { 0x2855, "candisarm" },
    { 0x2856, "candocovermelee_anim" },
    { 0x2857, "candodge" },
    { 0x2858, "candoflavorburst" },
    { 0x2859, "candomeleeanim" },
    { 0x285A, "candomeleeanim_internal" },
    { 0x285B, "candomeleebehind_angles" },
    { 0x285C, "candomeleebehind_anim" },
    { 0x285D, "candomeleeflip_angles" },
    { 0x285E, "candomeleeflip_anim" },
    { 0x285F, "candomeleewrestle_angles" },
    { 0x2860, "candomeleewrestle_anim" },
    { 0x2861, "candomonitoredswitchtoweapon" },
    { 0x2862, "candrophostage" },
    { 0x2863, "canfly" },
    { 0x2864, "cangive_ammo" },
    { 0x2865, "cangiveandfireoffhand" },
    { 0x2866, "cangrenaderespond" },
    { 0x2867, "canholdammobox" },
    { 0x2868, "caninstantrevive" },
    { 0x2869, "caninteractwith" },
    { 0x286A, "canjoin" },
    { 0x286B, "canjumpanywhere" },
    { 0x286C, "canjumpseatsonenter" },
    { 0x286D, "cankeepusingcrate" },
    { 0x286E, "canlean" },
    { 0x286F, "canlogclient" },
    { 0x2870, "canlogdeath" },
    { 0x2871, "canloglife" },
    { 0x2872, "canmeleeduringstealth" },
    { 0x2873, "canmove" },
    { 0x2874, "canmovefrompointtopoint" },
    { 0x2875, "canmovepointtopoint" },
    { 0x2876, "cannon" },
    { 0x2877, "cannon_effect" },
    { 0x2878, "cannonon" },
    { 0x2879, "cannontarget" },
    { 0x287A, "cannonweapon" },
    { 0x287B, "cannotbesuspended" },
    { 0x287C, "cannothypno" },
    { 0x287D, "cannotmelee" },
    { 0x287E, "cannotplacehinton" },
    { 0x287F, "cannotplacestring" },
    { 0x2880, "canoutlineforplayer" },
    { 0x2881, "canparachute" },
    { 0x2882, "canpathtotarget" },
    { 0x2883, "canphaseslide" },
    { 0x2884, "canpickupobject" },
    { 0x2885, "canplaychosenlongdeath" },
    { 0x2886, "canplayerbebuddyspawnedon" },
    { 0x2887, "canplaygesture" },
    { 0x2888, "canplayhalfwayvo" },
    { 0x2889, "canplaynotetrackvo" },
    { 0x288A, "canpressuse" },
    { 0x288B, "canprocessot" },
    { 0x288C, "canprocessselection" },
    { 0x288D, "canrappelreload" },
    { 0x288E, "canrecordcombatrecordstats" },
    { 0x288F, "canregenhealth" },
    { 0x2890, "canreusebox" },
    { 0x2891, "canrevivewithweapon" },
    { 0x2892, "cansay" },
    { 0x2893, "cansaycontact" },
    { 0x2894, "cansayname" },
    { 0x2895, "cansayplayername" },
    { 0x2896, "cansee_armory" },
    { 0x2897, "cansee_bounds" },
    { 0x2898, "cansee_detailed" },
    { 0x2899, "cansee_point" },
    { 0x289A, "cansee_vertical" },
    { 0x289B, "canseeandshootpoint" },
    { 0x289C, "canseeenemy" },
    { 0x289D, "canseeenemyfromexposed" },
    { 0x289E, "canseeenemytime" },
    { 0x289F, "canseepointfromexposedatcorner" },
    { 0x28A0, "canseepointfromexposedatnode" },
    { 0x28A1, "canseetarget" },
    { 0x28A2, "canseethroughfoliage" },
    { 0x28A3, "canshootinvehicle" },
    { 0x28A4, "canshoottarget" },
    { 0x28A5, "canshoottargetfrompos" },
    { 0x28A6, "canshowsplash" },
    { 0x28A7, "canshowtoughenupshield" },
    { 0x28A8, "canslotitem" },
    { 0x28A9, "canspawnballoon" },
    { 0x28AA, "canspawncallback" },
    { 0x28AB, "canspawnheli" },
    { 0x28AC, "canspawnvehicle" },
    { 0x28AD, "canstackpickup" },
    { 0x28AE, "canstartusingcrate" },
    { 0x28AF, "canstartusingcratetriggerobject" },
    { 0x28B0, "canstealmelee" },
    { 0x28B1, "canstompprogress" },
    { 0x28B2, "canstompprogresswithstalemate" },
    { 0x28B3, "canstop" },
    { 0x28B4, "canstow" },
    { 0x28B5, "cansuppressenemy" },
    { 0x28B6, "cansuppressenemyfromexposed" },
    { 0x28B7, "canswitchtosidearm" },
    { 0x28B8, "canswitchtoweaponreliably" },
    { 0x28B9, "cant_get_out_num" },
    { 0x28BA, "cantakedamageduringcapture" },
    { 0x28BB, "cantakepickup" },
    { 0x28BC, "cantarget_turret" },
    { 0x28BD, "canteleslide" },
    { 0x28BE, "canthrow" },
    { 0x28BF, "canthrowgrenade" },
    { 0x28C0, "cantiebysimultaneouskill" },
    { 0x28C1, "cantimeout" },
    { 0x28C2, "cantimeoutfromempty" },
    { 0x28C3, "cantraceto" },
    { 0x28C4, "cantracetoaiignoreents" },
    { 0x28C5, "cantriptrap" },
    { 0x28C6, "cantswitch" },
    { 0x28C7, "canturnoff" },
    { 0x28C8, "cantusehintthink" },
    { 0x28C9, "canuse" },
    { 0x28CA, "canusecallback" },
    { 0x28CB, "canusecondition" },
    { 0x28CC, "canusedeployable" },
    { 0x28CD, "canuseinlaststand" },
    { 0x28CE, "canuselaser" },
    { 0x28CF, "canuseobject" },
    { 0x28D0, "canuseotherboxes" },
    { 0x28D1, "canusesmartobject" },
    { 0x28D2, "canusesmartobject_nostrafenoturn" },
    { 0x28D3, "canusesmartobject_stealth" },
    { 0x28D4, "canwakeupvehicle" },
    { 0x28D5, "canweapondealcriticaldamage" },
    { 0x28D6, "canweaponhaveattachment" },
    { 0x28D7, "cap_round_number" },
    { 0x28D8, "cap_vehicle_type_on_module" },
    { 0x28D9, "cap_wave_spawning" },
    { 0x28DA, "caprate" },
    { 0x28DB, "capsperminute" },
    { 0x28DC, "capsule_check" },
    { 0x28DD, "capsule_debug" },
    { 0x28DE, "capsule_get_closest_point" },
    { 0x28DF, "capsule_trace" },
    { 0x28E0, "capsule_trace_get_all_results" },
    { 0x28E1, "capsule_trace_passed" },
    { 0x28E2, "captive_timeout" },
    { 0x28E3, "captive_vent_unlink_player_from_rig" },
    { 0x28E4, "captive_vo_flags" },
    { 0x28E5, "capture_current_headquarters" },
    { 0x28E6, "capture_flag" },
    { 0x28E7, "capture_radius" },
    { 0x28E8, "capturebehavior" },
    { 0x28E9, "captureblocked" },
    { 0x28EA, "capturecallback" },
    { 0x28EB, "capturecondition" },
    { 0x28EC, "capturecount" },
    { 0x28ED, "capturecrate" },
    { 0x28EE, "captured_civ_screams" },
    { 0x28EF, "capturedecay" },
    { 0x28F0, "captureduration" },
    { 0x28F1, "capturelootcachecallback" },
    { 0x28F2, "capturesequence" },
    { 0x28F3, "capturesequencemarinesdata" },
    { 0x28F4, "capturesequenceopfordata" },
    { 0x28F5, "capturestring" },
    { 0x28F6, "capturetime" },
    { 0x28F7, "capturetype" },
    { 0x28F8, "capturevisualscallback" },
    { 0x28F9, "capturevisualsdeletiondelay" },
    { 0x28FA, "capturingstring" },
    { 0x28FB, "capzones" },
    { 0x28FC, "car" },
    { 0x28FD, "car_alarm_manager" },
    { 0x28FE, "car_alarm_think" },
    { 0x28FF, "car_bomb_event" },
    { 0x2900, "car_brakelights_off" },
    { 0x2901, "car_brakelights_on" },
    { 0x2902, "car_civs" },
    { 0x2903, "car_civs_die" },
    { 0x2904, "car_civs_intro" },
    { 0x2905, "car_civs_post_intro" },
    { 0x2906, "car_coll_trig_logic" },
    { 0x2907, "car_drive_control" },
    { 0x2908, "car_explosion_add_fov_user_scale_override" },
    { 0x2909, "car_explosion_remove_fov_user_scale_override" },
    { 0x290A, "car_getout" },
    { 0x290B, "car_interact" },
    { 0x290C, "car_jumper" },
    { 0x290D, "car_jumper_car_delete_civs" },
    { 0x290E, "car_jumper_logic" },
    { 0x290F, "car_jumper_shooting" },
    { 0x2910, "car_lights" },
    { 0x2911, "car_order" },
    { 0x2912, "car_rummage_scene" },
    { 0x2913, "car_rummage_scene_think" },
    { 0x2914, "car_runner_deathfunc" },
    { 0x2915, "car_stream" },
    { 0x2916, "car_trig_debug" },
    { 0x2917, "car_vignette_guy" },
    { 0x2918, "car_windows_break" },
    { 0x2919, "car_zooms_past_handler" },
    { 0x291A, "car1_terries" },
    { 0x291B, "car1_terry" },
    { 0x291C, "car1_terry2" },
    { 0x291D, "car1_terry3" },
    { 0x291E, "car2_bomb_explosion" },
    { 0x291F, "car2_delete_extras" },
    { 0x2920, "car2_detonates" },
    { 0x2921, "car2_taking_off_vo" },
    { 0x2922, "car2_terries" },
    { 0x2923, "carbomb_main" },
    { 0x2924, "carbomb_player_extras" },
    { 0x2925, "carbomb_player_react" },
    { 0x2926, "carbomb_shop_windows" },
    { 0x2927, "card_refills" },
    { 0x2928, "care_package_activate" },
    { 0x2929, "care_package_createinteraction" },
    { 0x292A, "care_package_hint" },
    { 0x292B, "care_package_interaction" },
    { 0x292C, "careful_logic" },
    { 0x292D, "carepackagedropnodes" },
    { 0x292E, "carepackages" },
    { 0x292F, "cargo_truck_cp_create" },
    { 0x2930, "cargo_truck_cp_createfromstructs" },
    { 0x2931, "cargo_truck_cp_delete" },
    { 0x2932, "cargo_truck_cp_getspawnstructscallback" },
    { 0x2933, "cargo_truck_cp_init" },
    { 0x2934, "cargo_truck_cp_initlate" },
    { 0x2935, "cargo_truck_cp_initspawning" },
    { 0x2936, "cargo_truck_cp_ondeathrespawncallback" },
    { 0x2937, "cargo_truck_cp_spawncallback" },
    { 0x2938, "cargo_truck_cp_waitandspawn" },
    { 0x2939, "cargo_truck_create" },
    { 0x293A, "cargo_truck_deathcallback" },
    { 0x293B, "cargo_truck_deletenextframe" },
    { 0x293C, "cargo_truck_enterend" },
    { 0x293D, "cargo_truck_enterendinternal" },
    { 0x293E, "cargo_truck_exitend" },
    { 0x293F, "cargo_truck_exitendinternal" },
    { 0x2940, "cargo_truck_explode" },
    { 0x2941, "cargo_truck_getspawnstructscallback" },
    { 0x2942, "cargo_truck_init" },
    { 0x2943, "cargo_truck_initfx" },
    { 0x2944, "cargo_truck_initinteract" },
    { 0x2945, "cargo_truck_initlate" },
    { 0x2946, "cargo_truck_initoccupancy" },
    { 0x2947, "cargo_truck_initspawning" },
    { 0x2948, "cargo_truck_mp_create" },
    { 0x2949, "cargo_truck_mp_delete" },
    { 0x294A, "cargo_truck_mp_getspawnstructscallback" },
    { 0x294B, "cargo_truck_mp_init" },
    { 0x294C, "cargo_truck_mp_initdamage" },
    { 0x294D, "cargo_truck_mp_initmines" },
    { 0x294E, "cargo_truck_mp_initspawning" },
    { 0x294F, "cargo_truck_mp_ondeathrespawncallback" },
    { 0x2950, "cargo_truck_mp_spawncallback" },
    { 0x2951, "cargo_truck_mp_waitandspawn" },
    { 0x2952, "cargotrucks" },
    { 0x2953, "carjumper" },
    { 0x2954, "carnage_achievementlogic" },
    { 0x2955, "carnage_doflogic" },
    { 0x2956, "carnage_enemieslogic" },
    { 0x2957, "carnage_enemyanimationlogic" },
    { 0x2958, "carnage_enemyavoidplayerlogic" },
    { 0x2959, "carnage_enemyexitdoorlogic" },
    { 0x295A, "carnage_enemygatevehiclelogic" },
    { 0x295B, "carnage_enterlogic" },
    { 0x295C, "carnage_farahgetdownanimationlogic" },
    { 0x295D, "carnage_getanimationstruct" },
    { 0x295E, "carnage_getcorpseanimations" },
    { 0x295F, "carnage_getenemies" },
    { 0x2960, "carnage_getenemyanimations" },
    { 0x2961, "carnage_getenemynodes" },
    { 0x2962, "carnage_getfarahdoor" },
    { 0x2963, "carnage_getfarahdoorclip" },
    { 0x2964, "carnage_getplayerentertrigger" },
    { 0x2965, "carnage_getspawners" },
    { 0x2966, "carnage_main" },
    { 0x2967, "carnage_playeravoidancelogic" },
    { 0x2968, "carnage_playerbrokestealthlogic" },
    { 0x2969, "carnage_playerheartbeatlogic" },
    { 0x296A, "carnage_playerkillcounterworthy" },
    { 0x296B, "carnage_playerstealthfarahlogic" },
    { 0x296C, "carnage_playerstealthlogic" },
    { 0x296D, "carnage_setupcorpses" },
    { 0x296E, "carnage_setupfarahdoor" },
    { 0x296F, "carnage_spawncorpses" },
    { 0x2970, "carnage_spawnenemies" },
    { 0x2971, "carnage_spawnvehicles" },
    { 0x2972, "carnage_start" },
    { 0x2973, "carnage_vehiclelogic" },
    { 0x2974, "carnage_vehicleslogic" },
    { 0x2975, "carried" },
    { 0x2976, "carried_by_vehicle" },
    { 0x2977, "carried_catchup" },
    { 0x2978, "carried_depth_of_field" },
    { 0x2979, "carried_dof" },
    { 0x297A, "carried_fireworks_trap" },
    { 0x297B, "carried_fov" },
    { 0x297C, "carried_hostage_near_vehicle_monitor" },
    { 0x297D, "carried_main" },
    { 0x297E, "carried_mix_wait" },
    { 0x297F, "carried_remove_fov_user_scale_override" },
    { 0x2980, "carried_start" },
    { 0x2981, "carried_start_vo" },
    { 0x2982, "carried_time_dad_monitor" },
    { 0x2983, "carried_time_player_monitor" },
    { 0x2984, "carried_trap" },
    { 0x2985, "carriedboombox" },
    { 0x2986, "carriedby" },
    { 0x2987, "carriedgascan" },
    { 0x2988, "carriedims" },
    { 0x2989, "carrieditem" },
    { 0x298A, "carriedmedusa" },
    { 0x298B, "carriedobj" },
    { 0x298C, "carriedobject" },
    { 0x298D, "carriedrevocator" },
    { 0x298E, "carriedsentry" },
    { 0x298F, "carriedtrapangles" },
    { 0x2990, "carriedtrapoffset" },
    { 0x2991, "carrier" },
    { 0x2992, "carrierarmor" },
    { 0x2993, "carrierbonusscore" },
    { 0x2994, "carrierbonustime" },
    { 0x2995, "carrierendtime" },
    { 0x2996, "carriergivescore" },
    { 0x2997, "carrierhascarryweaponinloadout" },
    { 0x2998, "carriervisible" },
    { 0x2999, "carrierweaponcurrent" },
    { 0x299A, "carry" },
    { 0x299B, "carry_along_path" },
    { 0x299C, "carry_along_path_targetname" },
    { 0x299D, "carry_struct" },
    { 0x299E, "carry_to" },
    { 0x299F, "carrycount" },
    { 0x29A0, "carrydebuff" },
    { 0x29A1, "carryflag" },
    { 0x29A2, "carryicon" },
    { 0x29A3, "carrying" },
    { 0x29A4, "carrymodel" },
    { 0x29A5, "carryobject" },
    { 0x29A6, "carryobject_overridemovingplatformdeath" },
    { 0x29A7, "carryobjectasset" },
    { 0x29A8, "carryobjectproxthink" },
    { 0x29A9, "carryobjectproxthinkdelayed" },
    { 0x29AA, "carryobjectusethink" },
    { 0x29AB, "carryremoteuav_delete" },
    { 0x29AC, "carryremoteuav_handleexistence" },
    { 0x29AD, "carryremoteuav_setcarried" },
    { 0x29AE, "carryweapon" },
    { 0x29AF, "carryweaponthink" },
    { 0x29B0, "cars" },
    { 0x29B1, "cars_bomb" },
    { 0x29B2, "cart_directional_move" },
    { 0x29B3, "cart_push_trigger_array" },
    { 0x29B4, "cart_stop" },
    { 0x29B5, "case_opened_marker" },
    { 0x29B6, "cash_scalar" },
    { 0x29B7, "cash_scalar_alt_weapon" },
    { 0x29B8, "cash_scalar_weapon" },
    { 0x29B9, "castangles" },
    { 0x29BA, "castcontents" },
    { 0x29BB, "castdata" },
    { 0x29BC, "castdetail" },
    { 0x29BD, "castdir" },
    { 0x29BE, "castdivisions" },
    { 0x29BF, "castend" },
    { 0x29C0, "castfails" },
    { 0x29C1, "castignore" },
    { 0x29C2, "casting_shadows" },
    { 0x29C3, "castingdynolights" },
    { 0x29C4, "castmaxtime" },
    { 0x29C5, "casts" },
    { 0x29C6, "caststart" },
    { 0x29C7, "caststaticshadow" },
    { 0x29C8, "caststhisframe" },
    { 0x29C9, "caststotal" },
    { 0x29CA, "casttype" },
    { 0x29CB, "casual" },
    { 0x29CC, "casual_killer" },
    { 0x29CD, "casual_killer_damage_func" },
    { 0x29CE, "casual_killer_enemy_reaction" },
    { 0x29CF, "casual_killer_sweep" },
    { 0x29D0, "casual_killer_targeting" },
    { 0x29D1, "casualkiller" },
    { 0x29D2, "casualkillernewenemyreaction" },
    { 0x29D3, "casualkillershootpos" },
    { 0x29D4, "casualmode" },
    { 0x29D5, "casualscorestreaks" },
    { 0x29D6, "casualshoulddosharpturn" },
    { 0x29D7, "cat_array_add" },
    { 0x29D8, "cat_array_get" },
    { 0x29D9, "catch_alien_on_fire" },
    { 0x29DA, "catchballoondeployment" },
    { 0x29DB, "catchup" },
    { 0x29DC, "catchup_struct" },
    { 0x29DD, "categories" },
    { 0x29DE, "category" },
    { 0x29DF, "category_1" },
    { 0x29E0, "category_2" },
    { 0x29E1, "cattleprod" },
    { 0x29E2, "cattleprod_think" },
    { 0x29E3, "catwalk_defender_behavior" },
    { 0x29E4, "catwalk_guys" },
    { 0x29E5, "caught_dialogue" },
    { 0x29E6, "caught_enemiesandvehiclesmovementlogic" },
    { 0x29E7, "caught_enemiesreactionlogic" },
    { 0x29E8, "caught_enemiesshootlogic" },
    { 0x29E9, "caught_farahanimationlogic" },
    { 0x29EA, "caught_farahbackpackexplosionlogic" },
    { 0x29EB, "caught_farahreachanimationlogic" },
    { 0x29EC, "caught_getanimationstruct" },
    { 0x29ED, "caught_getenemies" },
    { 0x29EE, "caught_getenemyspawners" },
    { 0x29EF, "caught_getfarahpath" },
    { 0x29F0, "caught_getvehicles" },
    { 0x29F1, "caught_main" },
    { 0x29F2, "caught_spawnenemies" },
    { 0x29F3, "caught_spawnenemiesandvehicleslogic" },
    { 0x29F4, "caught_spawnvehicles" },
    { 0x29F5, "caught_start" },
    { 0x29F6, "caught_vehicleshootlogic" },
    { 0x29F7, "cause_is_explosive" },
    { 0x29F8, "causeofdeath" },
    { 0x29F9, "cautious_approach_till_close" },
    { 0x29FA, "cbfunc" },
    { 0x29FB, "cctv_camera_look_speed" },
    { 0x29FC, "cctv_camera_overlay" },
    { 0x29FD, "cctv_enter_add_fov_user_scale_override" },
    { 0x29FE, "cctv_fade_in" },
    { 0x29FF, "cctv_mic" },
    { 0x2A00, "cctv_opening_scene_bink" },
    { 0x2A01, "cctv_outro_bink_catchup" },
    { 0x2A02, "cctv_outro_bink_main" },
    { 0x2A03, "cctv_outro_bink_start" },
    { 0x2A04, "cctv_part_3_fail_trig" },
    { 0x2A05, "cctv_save_points" },
    { 0x2A06, "cctv_spot_light_limit" },
    { 0x2A07, "cctv_vo" },
    { 0x2A08, "ceiling_custom_death_success" },
    { 0x2A09, "ceiling_guy_corpse_tripwire" },
    { 0x2A0A, "ceiling_guy_flashlight_helper" },
    { 0x2A0B, "ceiling_guy_run_away_if_losses_player" },
    { 0x2A0C, "ceiling_guy_warning_shots" },
    { 0x2A0D, "ceiling_infinite_ammo" },
    { 0x2A0E, "ceiling_stance_think" },
    { 0x2A0F, "ceilingdust" },
    { 0x2A10, "cell_close_doors" },
    { 0x2A11, "cell_door_button_check" },
    { 0x2A12, "cell_door_check" },
    { 0x2A13, "cell_escape_catchup" },
    { 0x2A14, "cell_escape_flags" },
    { 0x2A15, "cell_escape_main" },
    { 0x2A16, "cell_escape_start" },
    { 0x2A17, "cell_open_doors" },
    { 0x2A18, "cell_phone" },
    { 0x2A19, "cellblock_close_door" },
    { 0x2A1A, "cellblock_escape_catchup" },
    { 0x2A1B, "cellblock_escape_flags" },
    { 0x2A1C, "cellblock_escape_main" },
    { 0x2A1D, "cellblock_escape_start" },
    { 0x2A1E, "cellblock_open_door" },
    { 0x2A1F, "cellblockgate" },
    { 0x2A20, "cellchair" },
    { 0x2A21, "celldoorclip" },
    { 0x2A22, "celldoors" },
    { 0x2A23, "celldoorsinuse" },
    { 0x2A24, "celldoorsopen" },
    { 0x2A25, "cellphone" },
    { 0x2A26, "cellphone_deathanim" },
    { 0x2A27, "cellphone_guy_ondeath" },
    { 0x2A28, "cellphone_guy_vo" },
    { 0x2A29, "cellphone_hint" },
    { 0x2A2A, "cellphone_hint_backup" },
    { 0x2A2B, "cellphone_hint_listener" },
    { 0x2A2C, "cellphone_react" },
    { 0x2A2D, "cellphone_timer" },
    { 0x2A2E, "cellphone_use_deathanim" },
    { 0x2A2F, "cells_cascade" },
    { 0x2A30, "center" },
    { 0x2A31, "center_chopper_save_watcher" },
    { 0x2A32, "center_compromises" },
    { 0x2A33, "center_enemy_spawnfunc" },
    { 0x2A34, "center_guys_to_volume" },
    { 0x2A35, "center_invulnerable" },
    { 0x2A36, "center_origin" },
    { 0x2A37, "center_point" },
    { 0x2A38, "centeraimpoint" },
    { 0x2A39, "centerflag" },
    { 0x2A3A, "centerprint" },
    { 0x2A3B, "centerpt" },
    { 0x2A3C, "centerref" },
    { 0x2A3D, "centertarget" },
    { 0x2A3E, "cfxprintln" },
    { 0x2A3F, "cfxprintlnend" },
    { 0x2A40, "cfxprintlnstart" },
    { 0x2A41, "chair" },
    { 0x2A42, "chair_carry_enter" },
    { 0x2A43, "chair_check_show_cursor" },
    { 0x2A44, "chair_done_enter" },
    { 0x2A45, "chair_done_handler" },
    { 0x2A46, "chair_idle_enter" },
    { 0x2A47, "chair_idle_update" },
    { 0x2A48, "chair_place_hint_timer" },
    { 0x2A49, "chair_rotate" },
    { 0x2A4A, "chairneardoorvol" },
    { 0x2A4B, "chairplacedpos" },
    { 0x2A4C, "challenge_name" },
    { 0x2A4D, "challenge_results" },
    { 0x2A4E, "challengefailurenumber" },
    { 0x2A4F, "challengeglobals" },
    { 0x2A50, "challengesallowed" },
    { 0x2A51, "challengescompleted" },
    { 0x2A52, "challengesenabled" },
    { 0x2A53, "challengesenabledforplayer" },
    { 0x2A54, "champion" },
    { 0x2A55, "chance_func" },
    { 0x2A56, "chance_to_play" },
    { 0x2A57, "chancevalue" },
    { 0x2A58, "change_ai_speed_while_offscreen" },
    { 0x2A59, "change_animshot_dir" },
    { 0x2A5A, "change_camera" },
    { 0x2A5B, "change_civ01_deathanim" },
    { 0x2A5C, "change_civ02_deathanim" },
    { 0x2A5D, "change_civ04_deathanima" },
    { 0x2A5E, "change_civ04_deathanimb" },
    { 0x2A5F, "change_convoy_objective_target" },
    { 0x2A60, "change_loadout_watcher" },
    { 0x2A61, "change_module_start_escalation" },
    { 0x2A62, "change_module_status" },
    { 0x2A63, "change_player_health_packets" },
    { 0x2A64, "change_riders_demeanor" },
    { 0x2A65, "change_scene_speed_while_offscreen" },
    { 0x2A66, "change_state" },
    { 0x2A67, "change_stealth_state_to" },
    { 0x2A68, "change_texts_green" },
    { 0x2A69, "change_to_barkov_dof" },
    { 0x2A6A, "change_to_terrorist_archetype_selected" },
    { 0x2A6B, "change_to_terrorist_model" },
    { 0x2A6C, "change_to_terrorist_model_func" },
    { 0x2A6D, "change_to_terrorist_model_internal" },
    { 0x2A6E, "changed_team" },
    { 0x2A6F, "changedarchetypeinfo" },
    { 0x2A70, "changedteams" },
    { 0x2A71, "changeheadicontext" },
    { 0x2A72, "changeheading" },
    { 0x2A73, "changelightcolorto" },
    { 0x2A74, "changelightcolortoworkerthread" },
    { 0x2A75, "changemaxpitchrollwhenclosetogoal" },
    { 0x2A76, "changenumdomflags" },
    { 0x2A77, "changeowner" },
    { 0x2A78, "changestanceforfuntime" },
    { 0x2A79, "changestancestarttime" },
    { 0x2A7A, "changestate" },
    { 0x2A7B, "changetestrig" },
    { 0x2A7C, "changetestslot" },
    { 0x2A7D, "changetesttaunt" },
    { 0x2A7E, "changetomorales2" },
    { 0x2A7F, "changetomorales3" },
    { 0x2A80, "changingtoregularinfected" },
    { 0x2A81, "changingtoregularinfectedbykill" },
    { 0x2A82, "changingweapon" },
    { 0x2A83, "channelname" },
    { 0x2A84, "channels" },
    { 0x2A85, "chaos_update_spending_currency_event" },
    { 0x2A86, "char_index" },
    { 0x2A87, "char_loc" },
    { 0x2A88, "character_hat_index" },
    { 0x2A89, "character_head_index" },
    { 0x2A8A, "character_index_cache" },
    { 0x2A8B, "character_model_cache" },
    { 0x2A8C, "charactercac" },
    { 0x2A8D, "characters" },
    { 0x2A8E, "charge" },
    { 0x2A8F, "charge_ally_variable_speed" },
    { 0x2A90, "charge_allypathlogic" },
    { 0x2A91, "charge_catchup" },
    { 0x2A92, "charge_enemy" },
    { 0x2A93, "charge_enemy_behavior" },
    { 0x2A94, "charge_explosion_01" },
    { 0x2A95, "charge_getallypaths" },
    { 0x2A96, "charge_getplayerexittrigger" },
    { 0x2A97, "charge_getredshirts" },
    { 0x2A98, "charge_main" },
    { 0x2A99, "charge_redshirtssfxlogic" },
    { 0x2A9A, "charge_setalliestoredshirts" },
    { 0x2A9B, "charge_start" },
    { 0x2A9C, "charge_watcher" },
    { 0x2A9D, "charged" },
    { 0x2A9E, "chargemode_hint_displayed" },
    { 0x2A9F, "chargemode_speedscale" },
    { 0x2AA0, "charges" },
    { 0x2AA1, "charges_planted" },
    { 0x2AA2, "charging" },
    { 0x2AA3, "charlie" },
    { 0x2AA4, "charlie_heli_lights" },
    { 0x2AA5, "charlie3" },
    { 0x2AA6, "chase_cam_ent" },
    { 0x2AA7, "chase_cam_last_num" },
    { 0x2AA8, "chase_cam_target" },
    { 0x2AA9, "chasecam" },
    { 0x2AAA, "chasecam_onent" },
    { 0x2AAB, "chaseplayerthenreverttostealth" },
    { 0x2AAC, "chatinitialized" },
    { 0x2AAD, "chatqueue" },
    { 0x2AAE, "chatter_loop" },
    { 0x2AAF, "chatter_loop_internal" },
    { 0x2AB0, "cheapopen" },
    { 0x2AB1, "cheat_save" },
    { 0x2AB2, "cheatammoifnecessary" },
    { 0x2AB3, "check_add_beam_nags" },
    { 0x2AB4, "check_aiming_flashbang" },
    { 0x2AB5, "check_aiming_noisemaker" },
    { 0x2AB6, "check_all_previous_in_pathing" },
    { 0x2AB7, "check_alley_group_dead" },
    { 0x2AB8, "check_allow_mantle_hud" },
    { 0x2AB9, "check_alt_fire" },
    { 0x2ABA, "check_and_kill" },
    { 0x2ABB, "check_and_update_best_stats" },
    { 0x2ABC, "check_around_the_area" },
    { 0x2ABD, "check_attach_jerrycan" },
    { 0x2ABE, "check_backup_is_set" },
    { 0x2ABF, "check_best_score" },
    { 0x2AC0, "check_callin_strike" },
    { 0x2AC1, "check_chair_door_blocked" },
    { 0x2AC2, "check_cleared_residence" },
    { 0x2AC3, "check_close_side_gate" },
    { 0x2AC4, "check_corner_enter" },
    { 0x2AC5, "check_createfx_limit" },
    { 0x2AC6, "check_crouch" },
    { 0x2AC7, "check_defender_damaged" },
    { 0x2AC8, "check_delete" },
    { 0x2AC9, "check_dismemberment_vfx" },
    { 0x2ACA, "check_do_food_nag" },
    { 0x2ACB, "check_door_button_interact" },
    { 0x2ACC, "check_dropped_weapon" },
    { 0x2ACD, "check_drs" },
    { 0x2ACE, "check_encounter_start_conditions" },
    { 0x2ACF, "check_end_bookcase_dialogue" },
    { 0x2AD0, "check_end_game" },
    { 0x2AD1, "check_enter_chair" },
    { 0x2AD2, "check_enter_chair_vo" },
    { 0x2AD3, "check_entered_through_secure_door" },
    { 0x2AD4, "check_event_flag" },
    { 0x2AD5, "check_exit_vent_look" },
    { 0x2AD6, "check_facing_russian_scene" },
    { 0x2AD7, "check_factory_group_dead" },
    { 0x2AD8, "check_feedback_starts_existance" },
    { 0x2AD9, "check_for_blacklisted_attachment" },
    { 0x2ADA, "check_for_clip_deletion" },
    { 0x2ADB, "check_for_close_victim" },
    { 0x2ADC, "check_for_drop" },
    { 0x2ADD, "check_for_empty_munitions" },
    { 0x2ADE, "check_for_explosive_shotgun_damage" },
    { 0x2ADF, "check_for_get_up" },
    { 0x2AE0, "check_for_gl_proj_override" },
    { 0x2AE1, "check_for_grenade_kill" },
    { 0x2AE2, "check_for_invalid_attachments" },
    { 0x2AE3, "check_for_more_players" },
    { 0x2AE4, "check_for_move_change" },
    { 0x2AE5, "check_for_movement" },
    { 0x2AE6, "check_for_objective_timer" },
    { 0x2AE7, "check_for_sniper_achievement" },
    { 0x2AE8, "check_for_special_damage" },
    { 0x2AE9, "check_for_unloading_func" },
    { 0x2AEA, "check_for_vehicle_unload" },
    { 0x2AEB, "check_forest_walk_anim_speed" },
    { 0x2AEC, "check_found_player" },
    { 0x2AED, "check_front_guards_go_hot" },
    { 0x2AEE, "check_gesture_not_obstructed" },
    { 0x2AEF, "check_going_behind_barkov" },
    { 0x2AF0, "check_got_gun" },
    { 0x2AF1, "check_grabbed" },
    { 0x2AF2, "check_grenade" },
    { 0x2AF3, "check_health_status" },
    { 0x2AF4, "check_heard_player" },
    { 0x2AF5, "check_hvt" },
    { 0x2AF6, "check_ied_blow_up_sight_blocker" },
    { 0x2AF7, "check_ied_explodes_near_enemy_hvt" },
    { 0x2AF8, "check_if_ac130_can_see_player" },
    { 0x2AF9, "check_if_guys_are_ready" },
    { 0x2AFA, "check_if_player_is_outside" },
    { 0x2AFB, "check_if_throwing_smoke" },
    { 0x2AFC, "check_in_drain" },
    { 0x2AFD, "check_init_beam_nags" },
    { 0x2AFE, "check_initial_group_dead" },
    { 0x2AFF, "check_interact_door" },
    { 0x2B00, "check_interrupt_search" },
    { 0x2B01, "check_interrupt_threshold" },
    { 0x2B02, "check_is_visible" },
    { 0x2B03, "check_item_found" },
    { 0x2B04, "check_item_interact" },
    { 0x2B05, "check_jump_at_chair" },
    { 0x2B06, "check_kill_azadeh" },
    { 0x2B07, "check_kill_damage" },
    { 0x2B08, "check_kill_final_defender" },
    { 0x2B09, "check_kill_overlook" },
    { 0x2B0A, "check_lightswitch_cleanup" },
    { 0x2B0B, "check_limit_type" },
    { 0x2B0C, "check_littlebird_damage_states" },
    { 0x2B0D, "check_location_start_conditions" },
    { 0x2B0E, "check_lookat" },
    { 0x2B0F, "check_lookat_guy" },
    { 0x2B10, "check_looking_at" },
    { 0x2B11, "check_los_and_proximity" },
    { 0x2B12, "check_lost_player" },
    { 0x2B13, "check_loud_weapon_fire" },
    { 0x2B14, "check_marines" },
    { 0x2B15, "check_molotov_fires" },
    { 0x2B16, "check_mount" },
    { 0x2B17, "check_nag_open_door" },
    { 0x2B18, "check_nag_out_of_cell" },
    { 0x2B19, "check_nag_to_warehouse_door" },
    { 0x2B1A, "check_node_is_claimed" },
    { 0x2B1B, "check_objective_button_pressed" },
    { 0x2B1C, "check_objective_reset_value" },
    { 0x2B1D, "check_open_gun_locker" },
    { 0x2B1E, "check_other_haslevelveteranachievement" },
    { 0x2B1F, "check_overlook_grenades" },
    { 0x2B20, "check_overlook_patrol" },
    { 0x2B21, "check_owner" },
    { 0x2B22, "check_pickup_noisemaker" },
    { 0x2B23, "check_player_attacker" },
    { 0x2B24, "check_player_can_stealth_kill_me" },
    { 0x2B25, "check_player_flashlight_visible_to_patrol" },
    { 0x2B26, "check_player_left_corner" },
    { 0x2B27, "check_player_pos" },
    { 0x2B28, "check_player_pos_flag" },
    { 0x2B29, "check_player_prox_in_air" },
    { 0x2B2A, "check_player_prox_on_ground" },
    { 0x2B2B, "check_player_psycho" },
    { 0x2B2C, "check_player_too_close" },
    { 0x2B2D, "check_player_trying_to_obstruct_exit" },
    { 0x2B2E, "check_player_use_vent" },
    { 0x2B2F, "check_player_visibility_to_patrol" },
    { 0x2B30, "check_prerequisites_then_start_event" },
    { 0x2B31, "check_price_and_player" },
    { 0x2B32, "check_rat_run" },
    { 0x2B33, "check_reactive_fx_type" },
    { 0x2B34, "check_rush_past_guards" },
    { 0x2B35, "check_script_noteworthy" },
    { 0x2B36, "check_show_laser" },
    { 0x2B37, "check_show_take_key_cursor" },
    { 0x2B38, "check_skip" },
    { 0x2B39, "check_skip_outro" },
    { 0x2B3A, "check_sniper_dead" },
    { 0x2B3B, "check_sound_tag_dupe" },
    { 0x2B3C, "check_sound_tag_dupe_reset" },
    { 0x2B3D, "check_spawn_point" },
    { 0x2B3E, "check_spotter_idle_time" },
    { 0x2B3F, "check_sprinting" },
    { 0x2B40, "check_stab_countered" },
    { 0x2B41, "check_stabbed" },
    { 0x2B42, "check_start_conditions" },
    { 0x2B43, "check_stay_in_river" },
    { 0x2B44, "check_stealth" },
    { 0x2B45, "check_stealth_kill_visible" },
    { 0x2B46, "check_stealth_state_change" },
    { 0x2B47, "check_stepped_back_from_bars" },
    { 0x2B48, "check_sting_is_clear" },
    { 0x2B49, "check_swap_weapon" },
    { 0x2B4A, "check_swipe_melee_dmg" },
    { 0x2B4B, "check_take_frag_grenade" },
    { 0x2B4C, "check_target_in_hit_zone" },
    { 0x2B4D, "check_target_is_valid" },
    { 0x2B4E, "check_threw_flashbang" },
    { 0x2B4F, "check_threw_noisemaker" },
    { 0x2B50, "check_throw_grenade_during_patrol" },
    { 0x2B51, "check_time_in_ads" },
    { 0x2B52, "check_tower_guard" },
    { 0x2B53, "check_try_pickup_stunstick" },
    { 0x2B54, "check_unloadgroup" },
    { 0x2B55, "check_use_grate_cover" },
    { 0x2B56, "check_use_vent_cover" },
    { 0x2B57, "check_view_window_scene" },
    { 0x2B58, "check_warp_struct" },
    { 0x2B59, "check_weapon_switch" },
    { 0x2B5A, "checkadvanceonenemyconditions" },
    { 0x2B5B, "checkallowspectating" },
    { 0x2B5C, "checkaltmodestatus" },
    { 0x2B5D, "checkarrivaltypecivilian" },
    { 0x2B5E, "checkattacker" },
    { 0x2B5F, "checkballjiprules" },
    { 0x2B60, "checkbcstatevalid" },
    { 0x2B61, "checkboosttraversal" },
    { 0x2B62, "checkcasualstreaksreset" },
    { 0x2B63, "checkcasualty" },
    { 0x2B64, "checkclassstructarray" },
    { 0x2B65, "checkcodcasterplayerdataexists" },
    { 0x2B66, "checkcoverforsidearm" },
    { 0x2B67, "checkcovermultichangerequest" },
    { 0x2B68, "checkcritchance" },
    { 0x2B69, "checkctfjiprules" },
    { 0x2B6A, "checkcurrentequiptypeammocount" },
    { 0x2B6B, "checkddjiprules" },
    { 0x2B6C, "checkdefaultjiprules" },
    { 0x2B6D, "checkdodge" },
    { 0x2B6E, "checkdomjiprules" },
    { 0x2B6F, "checkdoublejumpfinish" },
    { 0x2B70, "checkdynamicspawns" },
    { 0x2B71, "checkendgame" },
    { 0x2B72, "checkenemiesinfov" },
    { 0x2B73, "checkequipforrugged" },
    { 0x2B74, "checkfeaturevalue" },
    { 0x2B75, "checkffascorejip" },
    { 0x2B76, "checkforafk" },
    { 0x2B77, "checkforbestweapon" },
    { 0x2B78, "checkforghostweaponfire" },
    { 0x2B79, "checkforinstance" },
    { 0x2B7A, "checkforinvalidattachments" },
    { 0x2B7B, "checkforlootitemtrigger" },
    { 0x2B7C, "checkforpersonalbests" },
    { 0x2B7D, "checkforspecialistbonusvo" },
    { 0x2B7E, "checkgesturethread" },
    { 0x2B7F, "checkgrenadethrowdist" },
    { 0x2B80, "checkgroup" },
    { 0x2B81, "checkgrowth" },
    { 0x2B82, "checkgulagusecount" },
    { 0x2B83, "checkhealthwinner" },
    { 0x2B84, "checkhit" },
    { 0x2B85, "checkhostagescoring" },
    { 0x2B86, "checkin" },
    { 0x2B87, "checkin_guard_idle" },
    { 0x2B88, "checkin_weapons" },
    { 0x2B89, "checkinflictor" },
    { 0x2B8A, "checkinteractteam" },
    { 0x2B8B, "checkisfacing" },
    { 0x2B8C, "checkissameequip" },
    { 0x2B8D, "checkkillcamtruncation" },
    { 0x2B8E, "checkkillstreakcratedrop" },
    { 0x2B8F, "checkkillstreakkillevents" },
    { 0x2B90, "checkliveswinner" },
    { 0x2B91, "checkmapfxangles" },
    { 0x2B92, "checkmapoffsets" },
    { 0x2B93, "checkmatchdatakills" },
    { 0x2B94, "checkmeansofdeath" },
    { 0x2B95, "checkmodeoverridetie" },
    { 0x2B96, "checkmodifiedspawnpoint" },
    { 0x2B97, "checkobjectiskeyobject" },
    { 0x2B98, "checkobjweapon" },
    { 0x2B99, "checkpassivemessage" },
    { 0x2B9A, "checkpathtime" },
    { 0x2B9B, "checkpickupequiptypeammocount" },
    { 0x2B9C, "checkpitchvisibility" },
    { 0x2B9D, "checkplayer" },
    { 0x2B9E, "checkplayercarrykeyobject" },
    { 0x2B9F, "checkplayerscorelimitsoon" },
    { 0x2BA0, "checkpoint" },
    { 0x2BA1, "checkpoint_ai_check" },
    { 0x2BA2, "checkpoint_comment" },
    { 0x2BA3, "checkpoint_loop" },
    { 0x2BA4, "checkpoint_revive" },
    { 0x2BA5, "checkpointrevive" },
    { 0x2BA6, "checkpoints_think" },
    { 0x2BA7, "checkpostshipballspawns" },
    { 0x2BA8, "checkpostshipgoalplacement" },
    { 0x2BA9, "checkrealismhudsettings" },
    { 0x2BAA, "checkrequiredteamcount" },
    { 0x2BAB, "checkroundswitch" },
    { 0x2BAC, "checkscopes" },
    { 0x2BAD, "checkscorelimit" },
    { 0x2BAE, "checksdjiprules" },
    { 0x2BAF, "checkshouldallowtradekilltie" },
    { 0x2BB0, "checkspawnselectionafk" },
    { 0x2BB1, "checksprinting" },
    { 0x2BB2, "checksquads" },
    { 0x2BB3, "checkstairsoffsetpoint" },
    { 0x2BB4, "checkstancestatus" },
    { 0x2BB5, "checkstreakreward" },
    { 0x2BB6, "checksuperkillevents" },
    { 0x2BB7, "checksupershutdownevents" },
    { 0x2BB8, "checktacopstimelimit" },
    { 0x2BB9, "checkteam" },
    { 0x2BBA, "checkteamscorelimitsoon" },
    { 0x2BBB, "checktimelimit" },
    { 0x2BBC, "checktransitionpreconditions" },
    { 0x2BBD, "checktraverse" },
    { 0x2BBE, "checktriggeralarm" },
    { 0x2BBF, "checkttlosdeverrors" },
    { 0x2BC0, "checkttlosloaded" },
    { 0x2BC1, "checkttlosoverrides" },
    { 0x2BC2, "chem_room_pad_add_fov_user_scale_override" },
    { 0x2BC3, "chemistcomplaining" },
    { 0x2BC4, "chevrons" },
    { 0x2BC5, "chicken_array" },
    { 0x2BC6, "child" },
    { 0x2BC7, "child_fail_watcher" },
    { 0x2BC8, "child_spawners" },
    { 0x2BC9, "childchannels" },
    { 0x2BCA, "childchecktime" },
    { 0x2BCB, "childoutlineents" },
    { 0x2BCC, "children" },
    { 0x2BCD, "children_crying" },
    { 0x2BCE, "children_func" },
    { 0x2BCF, "children_menu" },
    { 0x2BD0, "childsoundorg" },
    { 0x2BD1, "chill" },
    { 0x2BD2, "chill_blind" },
    { 0x2BD3, "chill_data" },
    { 0x2BD4, "chill_impair" },
    { 0x2BD5, "chill_impairend" },
    { 0x2BD6, "chill_init" },
    { 0x2BD7, "chill_resetdata" },
    { 0x2BD8, "chill_resetscriptable" },
    { 0x2BD9, "chill_update" },
    { 0x2BDA, "chillend" },
    { 0x2BDB, "choke_screen_effects" },
    { 0x2BDC, "chokedeck" },
    { 0x2BDD, "choose_and_decrement_from_aitype_list" },
    { 0x2BDE, "choose_bomb_ids" },
    { 0x2BDF, "choose_escalation_air_vehicle_spawn" },
    { 0x2BE0, "choose_from_weighted_array" },
    { 0x2BE1, "choose_last_weapon" },
    { 0x2BE2, "choose_new_target" },
    { 0x2BE3, "choose_random_air_vehicle_spawn" },
    { 0x2BE4, "choose_random_ground_vehicle_spawn" },
    { 0x2BE5, "choose_rappel_weapon" },
    { 0x2BE6, "choose_spawnpoint" },
    { 0x2BE7, "choose_vehicle_position" },
    { 0x2BE8, "chooseadditivepainanim_stand" },
    { 0x2BE9, "chooseandspawnhealth" },
    { 0x2BEA, "chooseandspawnitems" },
    { 0x2BEB, "chooseandspawnplunder" },
    { 0x2BEC, "chooseandspawntactical" },
    { 0x2BED, "chooseandspawnweapon" },
    { 0x2BEE, "chooseanim_arrival" },
    { 0x2BEF, "chooseanim_burning" },
    { 0x2BF0, "chooseanim_customidle" },
    { 0x2BF1, "chooseanim_damageshieldtoground" },
    { 0x2BF2, "chooseanim_deploylmg" },
    { 0x2BF3, "chooseanim_dodge" },
    { 0x2BF4, "chooseanim_exit" },
    { 0x2BF5, "chooseanim_exitsoldier" },
    { 0x2BF6, "chooseanim_exposedreload" },
    { 0x2BF7, "chooseanim_flashed" },
    { 0x2BF8, "chooseanim_gesture" },
    { 0x2BF9, "chooseanim_newenemyreaction" },
    { 0x2BFA, "chooseanim_patrol_checkflashlight" },
    { 0x2BFB, "chooseanim_patrolreact" },
    { 0x2BFC, "chooseanim_patrolreact_checkflashlight" },
    { 0x2BFD, "chooseanim_patrolreactlookaround" },
    { 0x2BFE, "chooseanim_patrolreactlookaround_checkflashlight" },
    { 0x2BFF, "chooseanim_playerpushed" },
    { 0x2C00, "chooseanim_stairs" },
    { 0x2C01, "chooseanim_stairs_rise_run" },
    { 0x2C02, "chooseanim_strafeaimchange" },
    { 0x2C03, "chooseanim_strafearrival" },
    { 0x2C04, "chooseanim_strafearrive" },
    { 0x2C05, "chooseanim_syncmelee" },
    { 0x2C06, "chooseanim_throwgrenade" },
    { 0x2C07, "chooseanim_tocoverhide" },
    { 0x2C08, "chooseanim_tocoverhide_helper" },
    { 0x2C09, "chooseanim_vehicle" },
    { 0x2C0A, "chooseanim_weaponclassprepended" },
    { 0x2C0B, "chooseanim_weaponswitch" },
    { 0x2C0C, "chooseanim_zeroarrival" },
    { 0x2C0D, "chooseanimantigravfall" },
    { 0x2C0E, "chooseanimantigravfloatidle" },
    { 0x2C0F, "chooseanimantigravrise" },
    { 0x2C10, "chooseanimidle" },
    { 0x2C11, "chooseanimidle_interiorexterior" },
    { 0x2C12, "chooseaniminteractable" },
    { 0x2C13, "chooseanimlongdeath" },
    { 0x2C14, "chooseanimmelee_seekerjump" },
    { 0x2C15, "chooseanimmelee_seekerloop" },
    { 0x2C16, "chooseanimmovetype" },
    { 0x2C17, "chooseanimshoot" },
    { 0x2C18, "chooseanimwithoverride" },
    { 0x2C19, "choosebalconydeathanim" },
    { 0x2C1A, "choosebcdirectionanim" },
    { 0x2C1B, "choosebestweapon" },
    { 0x2C1C, "choosecivilianreactidleanim" },
    { 0x2C1D, "chooseciviliantransitiontoidleanim" },
    { 0x2C1E, "choosecoverdeathanim" },
    { 0x2C1F, "choosecoverlongdeathanims" },
    { 0x2C20, "choosecoverstandlookorpeekanim" },
    { 0x2C21, "choosecratelocation" },
    { 0x2C22, "choosecrawlingpaintransitionanim" },
    { 0x2C23, "choosecrawllongdeathanims" },
    { 0x2C24, "choosecrouchingdeathanim" },
    { 0x2C25, "choosecrouchorstand" },
    { 0x2C26, "choosecrouchturnanim" },
    { 0x2C27, "choosedemeanoranimwithoverride" },
    { 0x2C28, "choosedemeanoranimwithoverridevariants" },
    { 0x2C29, "choosedirection" },
    { 0x2C2A, "choosedirectionalcrouchdeathanim" },
    { 0x2C2B, "choosedirectionaldeathanim" },
    { 0x2C2C, "choosedirectionalfullpainanim_exposedstand" },
    { 0x2C2D, "choosedirectionallargepaindeathanim" },
    { 0x2C2E, "choosedirectionalpainanim_covercrouch" },
    { 0x2C2F, "choosedirectionalpainanim_coverstand" },
    { 0x2C30, "choosedirectionalpainanim_exposedstand" },
    { 0x2C31, "choosedirectionalpainanim_transition" },
    { 0x2C32, "choosedoublejumpanim" },
    { 0x2C33, "choosedyingbackidle" },
    { 0x2C34, "choosedynamicpainanim_back" },
    { 0x2C35, "choosedynamicpainanim_covercrouch" },
    { 0x2C36, "choosedynamicpainanim_coverstand" },
    { 0x2C37, "choosedynamicpainanim_expcrouchlegs" },
    { 0x2C38, "chooseexplosivedeathanim" },
    { 0x2C39, "chooseexposedlongdeathanims" },
    { 0x2C3A, "choosefirstinfected" },
    { 0x2C3B, "choosegestureanim" },
    { 0x2C3C, "choosegrenadereturnthrowanim" },
    { 0x2C3D, "chooseitemrarity" },
    { 0x2C3E, "chooseitemtype" },
    { 0x2C3F, "chooselightreactionanim" },
    { 0x2C40, "chooselongdeathdeathanim" },
    { 0x2C41, "choosemovingdeathanim" },
    { 0x2C42, "choosenlocation" },
    { 0x2C43, "choosenukecratelocation" },
    { 0x2C44, "choosenumshotsandbursts" },
    { 0x2C45, "choosepainanim_covercorner" },
    { 0x2C46, "choosepainanim_covercorner_helper" },
    { 0x2C47, "choosepainanim_covercorner_tocoverhide" },
    { 0x2C48, "choosepainanim_covercrouch" },
    { 0x2C49, "choosepainanim_covercrouchlean" },
    { 0x2C4A, "choosepainanim_coverstand" },
    { 0x2C4B, "choosepainanim_crouch" },
    { 0x2C4C, "choosepainanim_damageshield" },
    { 0x2C4D, "choosepainanim_faceplayer" },
    { 0x2C4E, "choosepainanim_pistol" },
    { 0x2C4F, "choosepainanim_run" },
    { 0x2C50, "choosepainanim_stand" },
    { 0x2C51, "choosepainanim_standtorso" },
    { 0x2C52, "choosepainanim_standtorsotoexposed" },
    { 0x2C53, "choosepainanim_tocoverhide" },
    { 0x2C54, "choosepainanim_tocoverhide_helper" },
    { 0x2C55, "choosepainanimdeafened" },
    { 0x2C56, "choosepainanimshock" },
    { 0x2C57, "choosepassive" },
    { 0x2C58, "chooserandomexplosive" },
    { 0x2C59, "choosereloadwhilemoving" },
    { 0x2C5A, "choosesharpturnanim" },
    { 0x2C5B, "chooseshockdeathanim" },
    { 0x2C5C, "chooseshockpainrecovery" },
    { 0x2C5D, "chooseshootidle" },
    { 0x2C5E, "chooseshootposandobjective" },
    { 0x2C5F, "chooseshootstyle" },
    { 0x2C60, "choosesmartobjectanim" },
    { 0x2C61, "choosesmartobjectdeathalias" },
    { 0x2C62, "choosesmartobjectdeathanim" },
    { 0x2C63, "choosesmartobjectexitanim" },
    { 0x2C64, "choosesmartobjectpainanim" },
    { 0x2C65, "choosesmartobjectreactanim" },
    { 0x2C66, "choosespawninstances" },
    { 0x2C67, "choosespecialdeath" },
    { 0x2C68, "choosesquadleader" },
    { 0x2C69, "choosestandingdeathanim" },
    { 0x2C6A, "choosestandingmeleedeathanim" },
    { 0x2C6B, "choosestandingpistoldeathanim" },
    { 0x2C6C, "choosestrongdamagedeath" },
    { 0x2C6D, "choosestumblingpainanim" },
    { 0x2C6E, "choosetransitiontoexposedanim" },
    { 0x2C6F, "choosetraversaltransition" },
    { 0x2C70, "choosetraverseanim_external" },
    { 0x2C71, "chooseturnanim" },
    { 0x2C72, "chooseturnanim3d" },
    { 0x2C73, "choosewalkandtalkanims" },
    { 0x2C74, "choosewallattachanim" },
    { 0x2C75, "choosewallrunanim" },
    { 0x2C76, "choosewallrunenteranim" },
    { 0x2C77, "choosewallrunexitanim" },
    { 0x2C78, "choosewallrunturn" },
    { 0x2C79, "chopper" },
    { 0x2C7A, "chopper_ads_watcher" },
    { 0x2C7B, "chopper_chatter" },
    { 0x2C7C, "chopper_check" },
    { 0x2C7D, "chopper_crew_behavior" },
    { 0x2C7E, "chopper_damage_watcher" },
    { 0x2C7F, "chopper_final_rocket_behavior" },
    { 0x2C80, "chopper_fx" },
    { 0x2C81, "chopper_gunner_findtargetstruct" },
    { 0x2C82, "chopper_gunner_set_vehicle_hit_damage_data" },
    { 0x2C83, "chopper_gunners_killed_watcher" },
    { 0x2C84, "chopper_guns_watcher" },
    { 0x2C85, "chopper_height" },
    { 0x2C86, "chopper_nags" },
    { 0x2C87, "chopper_pilot_death_watcher" },
    { 0x2C88, "chopper_rocket_behavior" },
    { 0x2C89, "chopper_rockets_watcher" },
    { 0x2C8A, "chopper_support_create_enemy_chopper" },
    { 0x2C8B, "chopper_support_set_vehicle_hit_damage_data" },
    { 0x2C8C, "chopper_transport_crew_behavior" },
    { 0x2C8D, "chopper_turret_off" },
    { 0x2C8E, "chopper_turret_on" },
    { 0x2C8F, "chopper_turret_target" },
    { 0x2C90, "choppergunner_camerashake" },
    { 0x2C91, "choppergunner_crash" },
    { 0x2C92, "choppergunner_delete" },
    { 0x2C93, "choppergunner_empcleared" },
    { 0x2C94, "choppergunner_empstarted" },
    { 0x2C95, "choppergunner_explode" },
    { 0x2C96, "choppergunner_findcrashposition" },
    { 0x2C97, "choppergunner_firemissilefx" },
    { 0x2C98, "choppergunner_getnearbytargets" },
    { 0x2C99, "choppergunner_getpathend" },
    { 0x2C9A, "choppergunner_getvisionsetbystrength" },
    { 0x2C9B, "choppergunner_getvisionsetformat" },
    { 0x2C9C, "choppergunner_handledamage" },
    { 0x2C9D, "choppergunner_handledeathdamage" },
    { 0x2C9E, "choppergunner_handledestroyed" },
    { 0x2C9F, "choppergunner_handlemissiledetection" },
    { 0x2CA0, "choppergunner_handlemissilefire" },
    { 0x2CA1, "choppergunner_handlethermalswitch" },
    { 0x2CA2, "choppergunner_handlethermalswitchinternal" },
    { 0x2CA3, "choppergunner_leave" },
    { 0x2CA4, "choppergunner_lockedoncallback" },
    { 0x2CA5, "choppergunner_lockedonremovedcallback" },
    { 0x2CA6, "choppergunner_modifydamage" },
    { 0x2CA7, "choppergunner_notifyonkillstreakover" },
    { 0x2CA8, "choppergunner_pilotanims" },
    { 0x2CA9, "choppergunner_playdofintroeffects" },
    { 0x2CAA, "choppergunner_playercameratransition" },
    { 0x2CAB, "choppergunner_removetargetmarkergroupsonkillstreakover" },
    { 0x2CAC, "choppergunner_returnplayer" },
    { 0x2CAD, "choppergunner_screeninterference" },
    { 0x2CAE, "choppergunner_spinout" },
    { 0x2CAF, "choppergunner_startfadetransition" },
    { 0x2CB0, "choppergunner_startremotecontrol" },
    { 0x2CB1, "choppergunner_timerthread" },
    { 0x2CB2, "choppergunner_updateflyingspeed" },
    { 0x2CB3, "choppergunner_updatetargetmarkergroups" },
    { 0x2CB4, "choppergunner_vehicleanims" },
    { 0x2CB5, "choppergunner_watchearlyexit" },
    { 0x2CB6, "choppergunner_watchendstrobefx" },
    { 0x2CB7, "choppergunner_watchgameendleave" },
    { 0x2CB8, "choppergunner_watchkills" },
    { 0x2CB9, "choppergunner_watchlifetime" },
    { 0x2CBA, "choppergunner_watchmissilestate" },
    { 0x2CBB, "choppergunner_watchowner" },
    { 0x2CBC, "choppergunner_watchtargets" },
    { 0x2CBD, "choppergunner_watchturretfire" },
    { 0x2CBE, "choppergunnerbeginuse" },
    { 0x2CBF, "choppergunners" },
    { 0x2CC0, "choppers" },
    { 0x2CC1, "choppersipport_randommovement" },
    { 0x2CC2, "choppersupport_acquireturrettarget" },
    { 0x2CC3, "choppersupport_acquireturrettarget_enemy" },
    { 0x2CC4, "choppersupport_canseeenemy" },
    { 0x2CC5, "choppersupport_checkifactivetargets" },
    { 0x2CC6, "choppersupport_cleanup" },
    { 0x2CC7, "choppersupport_clearcurrenttarget" },
    { 0x2CC8, "choppersupport_crash" },
    { 0x2CC9, "choppersupport_engageturrettarget" },
    { 0x2CCA, "choppersupport_engageturrettarget_enemy" },
    { 0x2CCB, "choppersupport_explode" },
    { 0x2CCC, "choppersupport_findclosestpatrolstruct" },
    { 0x2CCD, "choppersupport_findcrashposition" },
    { 0x2CCE, "choppersupport_findtargetstruct" },
    { 0x2CCF, "choppersupport_fireonturrettarget" },
    { 0x2CD0, "choppersupport_fixatetarget" },
    { 0x2CD1, "choppersupport_getactivetargets" },
    { 0x2CD2, "choppersupport_getbesttarget" },
    { 0x2CD3, "choppersupport_getbesttarget_enemy" },
    { 0x2CD4, "choppersupport_gettargets" },
    { 0x2CD5, "choppersupport_gettargets_enemy" },
    { 0x2CD6, "choppersupport_handledeathdamage" },
    { 0x2CD7, "choppersupport_handlemissiledetection" },
    { 0x2CD8, "choppersupport_isactivetarget" },
    { 0x2CD9, "choppersupport_istarget" },
    { 0x2CDA, "choppersupport_istarget_enemy" },
    { 0x2CDB, "choppersupport_leave" },
    { 0x2CDC, "choppersupport_leaveoncommand_enemy" },
    { 0x2CDD, "choppersupport_modifydamage" },
    { 0x2CDE, "choppersupport_monitorowner" },
    { 0x2CDF, "choppersupport_movetolocation" },
    { 0x2CE0, "choppersupport_neargoalsettings" },
    { 0x2CE1, "choppersupport_neargoalsettings_enemy" },
    { 0x2CE2, "choppersupport_patrolfield" },
    { 0x2CE3, "choppersupport_patrolfield_enemy" },
    { 0x2CE4, "choppersupport_setattackpoint" },
    { 0x2CE5, "choppersupport_setcurrenttarget" },
    { 0x2CE6, "choppersupport_spinout" },
    { 0x2CE7, "choppersupport_turretlookingattarget" },
    { 0x2CE8, "choppersupport_watchdestoyed" },
    { 0x2CE9, "choppersupport_watchforlosttarget" },
    { 0x2CEA, "choppersupport_watchforlosttargetaction" },
    { 0x2CEB, "choppersupport_watchgameendleave" },
    { 0x2CEC, "choppersupport_watchlifetime" },
    { 0x2CED, "choppersupport_watchtargetlos" },
    { 0x2CEE, "choppersupport_watchtargettimeout" },
    { 0x2CEF, "choppersupports" },
    { 0x2CF0, "chopperturretfunc" },
    { 0x2CF1, "chopperturretofffunc" },
    { 0x2CF2, "chopperturretonfunc" },
    { 0x2CF3, "chosenarray" },
    { 0x2CF4, "chosentemplates" },
    { 0x2CF5, "chosenvehicleanimpos" },
    { 0x2CF6, "chosenvehicleposition" },
    { 0x2CF7, "chu_bad_places" },
    { 0x2CF8, "chu_bad_places_armory" },
    { 0x2CF9, "chu_bad_places_ids" },
    { 0x2CFA, "chu_chopper" },
    { 0x2CFB, "chu_chopper_pilot_protector" },
    { 0x2CFC, "chu_chopper_spawn_func" },
    { 0x2CFD, "chu_chopper_yaw_updater" },
    { 0x2CFE, "chu_explosion" },
    { 0x2CFF, "chu_guys_alive_check" },
    { 0x2D00, "chu_molotov_death" },
    { 0x2D01, "chu_right_side" },
    { 0x2D02, "chunkloadouts" },
    { 0x2D03, "churnareas" },
    { 0x2D04, "chute" },
    { 0x2D05, "chuteendtime" },
    { 0x2D06, "chutes" },
    { 0x2D07, "cinderblock" },
    { 0x2D08, "cinderblockcount" },
    { 0x2D09, "cine_bars_clamp" },
    { 0x2D0A, "cine_cam_change" },
    { 0x2D0B, "cine_cam_settings" },
    { 0x2D0C, "cine_dof" },
    { 0x2D0D, "cine_idle_bunker_dof" },
    { 0x2D0E, "cine_lb_down" },
    { 0x2D0F, "cine_lb_down_ending" },
    { 0x2D10, "cine_letterboxing" },
    { 0x2D11, "cine_letterboxing_basement" },
    { 0x2D12, "cine_letterboxing_down" },
    { 0x2D13, "cine_letterboxing_intro" },
    { 0x2D14, "cine_letterboxing_up" },
    { 0x2D15, "cine_settings" },
    { 0x2D16, "cine_skip_mayhem_end" },
    { 0x2D17, "cinematic" },
    { 0x2D18, "cinematic_bars_intro" },
    { 0x2D19, "cinematic_camera_settings_tea_house" },
    { 0x2D1A, "cinematic_hack" },
    { 0x2D1B, "cinematic_motion_override" },
    { 0x2D1C, "cinematic_replay_recording" },
    { 0x2D1D, "cinematic_skip_input" },
    { 0x2D1E, "cinematic_waittill_skip_or_time" },
    { 0x2D1F, "cinematiccameratimeline" },
    { 0x2D20, "cinematicmotionoverride" },
    { 0x2D21, "cinematicreplay_scriptdata_openfilewrite" },
    { 0x2D22, "cinematicreplayrecording_scriptdata_dump" },
    { 0x2D23, "cinematicreplaystrings" },
    { 0x2D24, "cinematicreplaystringsconcat" },
    { 0x2D25, "circle_around_target" },
    { 0x2D26, "circle_debug" },
    { 0x2D27, "circle_radius" },
    { 0x2D28, "circle_volumes" },
    { 0x2D29, "circlecenter" },
    { 0x2D2A, "circlecircleintersect" },
    { 0x2D2B, "circledamagemultiplier" },
    { 0x2D2C, "circledamagetick" },
    { 0x2D2D, "circledebugpos" },
    { 0x2D2E, "circledebugradius" },
    { 0x2D2F, "circleemitters" },
    { 0x2D30, "circleent" },
    { 0x2D31, "circleenthidefromplayers" },
    { 0x2D32, "circleindex" },
    { 0x2D33, "circletimer" },
    { 0x2D34, "circling" },
    { 0x2D35, "circling_target" },
    { 0x2D36, "circuitboard" },
    { 0x2D37, "circuitchildren" },
    { 0x2D38, "circuitparents" },
    { 0x2D39, "circuitsiblings" },
    { 0x2D3A, "civ_1" },
    { 0x2D3B, "civ_2" },
    { 0x2D3C, "civ_3" },
    { 0x2D3D, "civ_4" },
    { 0x2D3E, "civ_5" },
    { 0x2D3F, "civ_6" },
    { 0x2D40, "civ_ambush_allies_push_forward" },
    { 0x2D41, "civ_ambush_catchup" },
    { 0x2D42, "civ_ambush_compliment_dialogue" },
    { 0x2D43, "civ_ambush_exit_door_left" },
    { 0x2D44, "civ_ambush_exit_door_right" },
    { 0x2D45, "civ_ambush_exit_door_setup" },
    { 0x2D46, "civ_ambush_init" },
    { 0x2D47, "civ_ambush_main" },
    { 0x2D48, "civ_ambush_marine_color_reset" },
    { 0x2D49, "civ_ambush_marine_color_swap_waiting" },
    { 0x2D4A, "civ_ambush_marine_color_update" },
    { 0x2D4B, "civ_ambush_movement_handler" },
    { 0x2D4C, "civ_ambush_poi_structs" },
    { 0x2D4D, "civ_ambush_stair_blocker_ai_handler" },
    { 0x2D4E, "civ_ambush_stair_blocking_marine_handler" },
    { 0x2D4F, "civ_ambush_stairwell_advance" },
    { 0x2D50, "civ_ambush_start" },
    { 0x2D51, "civ_ambusher" },
    { 0x2D52, "civ_ambusher_ambush_manager" },
    { 0x2D53, "civ_ambusher_autokill" },
    { 0x2D54, "civ_ambusher_cleanup_monitor" },
    { 0x2D55, "civ_ambusher_death_monitor" },
    { 0x2D56, "civ_ambusher_gun_manager" },
    { 0x2D57, "civ_ambusher_init" },
    { 0x2D58, "civ_ambusher_move_fake_target" },
    { 0x2D59, "civ_ambusher_player_ads_monitor" },
    { 0x2D5A, "civ_ambusher_player_threat_monitor" },
    { 0x2D5B, "civ_ambusher_player_whizby_monitor" },
    { 0x2D5C, "civ_ambusher_shooting_manager" },
    { 0x2D5D, "civ_ambusher_target" },
    { 0x2D5E, "civ_car" },
    { 0x2D5F, "civ_car_death_spot" },
    { 0x2D60, "civ_cleanup_array" },
    { 0x2D61, "civ_cleanup_monitor" },
    { 0x2D62, "civ_count" },
    { 0x2D63, "civ_deathfunction" },
    { 0x2D64, "civ_debug" },
    { 0x2D65, "civ_dialogue_handler" },
    { 0x2D66, "civ_different_everything" },
    { 0x2D67, "civ_dmg_trig" },
    { 0x2D68, "civ_exit_door_store_enterers" },
    { 0x2D69, "civ_ff_idle" },
    { 0x2D6A, "civ_flee_to" },
    { 0x2D6B, "civ_friendly_fire_think" },
    { 0x2D6C, "civ_glancedownpath" },
    { 0x2D6D, "civ_hostage" },
    { 0x2D6E, "civ_in_position" },
    { 0x2D6F, "civ_init" },
    { 0x2D70, "civ_killer_internal" },
    { 0x2D71, "civ_killers_loop" },
    { 0x2D72, "civ_life_car_00" },
    { 0x2D73, "civ_life_car_01" },
    { 0x2D74, "civ_loop" },
    { 0x2D75, "civ_stairs_blood_splatter" },
    { 0x2D76, "civ_stairs_death" },
    { 0x2D77, "civ_stationary_ff_penalty_think" },
    { 0x2D78, "civ_struct_ai_go" },
    { 0x2D79, "civ_struct_spawner_init" },
    { 0x2D7A, "civ_struct_spawner_internal" },
    { 0x2D7B, "civ_struct_spawners" },
    { 0x2D7C, "civ_table_animations" },
    { 0x2D7D, "civ_think" },
    { 0x2D7E, "civ_think_run" },
    { 0x2D7F, "civ_think_vignette" },
    { 0x2D80, "civ_time_penalty" },
    { 0x2D81, "civ_trap_hint_clear" },
    { 0x2D82, "civ_trap_hint_started" },
    { 0x2D83, "civ_try_go_to_extract" },
    { 0x2D84, "civ_type" },
    { 0x2D85, "civ_vehicles" },
    { 0x2D86, "civ_walkers_anim_and_run_away" },
    { 0x2D87, "civ_walkers_breakout" },
    { 0x2D88, "civ01_1f_setup" },
    { 0x2D89, "civ01_death" },
    { 0x2D8A, "civ01_deathwatch" },
    { 0x2D8B, "civ02_1f_setup" },
    { 0x2D8C, "civ02_death" },
    { 0x2D8D, "civ02_deathwatch" },
    { 0x2D8E, "civ03_1f_setup" },
    { 0x2D8F, "civ03_death" },
    { 0x2D90, "civ03_deathwatch" },
    { 0x2D91, "civambush_griggs_nag_dialogue" },
    { 0x2D92, "civarrival_finishearly" },
    { 0x2D93, "civdeathinstafail" },
    { 0x2D94, "civilian_ambusher_dialog_struct" },
    { 0x2D95, "civilian_chooseanim_demeanor" },
    { 0x2D96, "civilian_chooseanim_exit" },
    { 0x2D97, "civilian_chooseanim_playerpushed" },
    { 0x2D98, "civilian_death_sequence_01" },
    { 0x2D99, "civilian_dialog_struct" },
    { 0x2D9A, "civilian_exit_cleanup" },
    { 0x2D9B, "civilian_gas_reactions" },
    { 0x2D9C, "civilian_init" },
    { 0x2D9D, "civilian_loopidleanim" },
    { 0x2D9E, "civilian_move_cleanup" },
    { 0x2D9F, "civilian_playanim_exit" },
    { 0x2DA0, "civilian_playexposedloop" },
    { 0x2DA1, "civilian_playmoveloop" },
    { 0x2DA2, "civilian_playmoveloopblendspace" },
    { 0x2DA3, "civilian_playsharpturnanim" },
    { 0x2DA4, "civilian_props" },
    { 0x2DA5, "civilian_stairs_death_handler" },
    { 0x2DA6, "civilian_stairs_shock_handler" },
    { 0x2DA7, "civilian_stairwell_blocker_handler" },
    { 0x2DA8, "civilian_targets" },
    { 0x2DA9, "civilian_walk_animation" },
    { 0x2DAA, "civilian_watchspeed" },
    { 0x2DAB, "civiliancowerindex" },
    { 0x2DAC, "civilianfailwrapper" },
    { 0x2DAD, "civilianflashedarray" },
    { 0x2DAE, "civilianfocusapproachingarrival" },
    { 0x2DAF, "civilianfocuscomputeyawtotarget" },
    { 0x2DB0, "civilianfocuscurvalue" },
    { 0x2DB1, "civilianfocusdirection" },
    { 0x2DB2, "civilianfocuslasttime" },
    { 0x2DB3, "civilianfocusstartthread" },
    { 0x2DB4, "civilianfocusstate" },
    { 0x2DB5, "civilianfocustargetentity" },
    { 0x2DB6, "civilianfocusthreadrunning" },
    { 0x2DB7, "civilianfocusupdateanimparameter" },
    { 0x2DB8, "civilianfocusupdatecurrentfocus" },
    { 0x2DB9, "civilianfocusupdatethread" },
    { 0x2DBA, "civilianjetflyby" },
    { 0x2DBB, "civilianqueue" },
    { 0x2DBC, "civilianreactionalias" },
    { 0x2DBD, "civilians" },
    { 0x2DBE, "civilians_aim" },
    { 0x2DBF, "civilians_callout" },
    { 0x2DC0, "civilians_hallway_flee_handler" },
    { 0x2DC1, "civilians_hallway_flee_single" },
    { 0x2DC2, "civilians_init" },
    { 0x2DC3, "civilians_plead" },
    { 0x2DC4, "civilianstateis" },
    { 0x2DC5, "civilianstateisnot" },
    { 0x2DC6, "civisfocusingleft" },
    { 0x2DC7, "civisfocusingright" },
    { 0x2DC8, "civmoverequested" },
    { 0x2DC9, "civs" },
    { 0x2DCA, "civs_bike" },
    { 0x2DCB, "civs_bike_breakout" },
    { 0x2DCC, "civs_executed" },
    { 0x2DCD, "civs_garage_door_guy" },
    { 0x2DCE, "civs_garage_door_guy_breakout" },
    { 0x2DCF, "civs_garage_door_guy_endon_watcher" },
    { 0x2DD0, "civs_killed" },
    { 0x2DD1, "civs_running_by_sounds_left_side" },
    { 0x2DD2, "civs_running_by_sounds_right_side" },
    { 0x2DD3, "civs_running_exiting_2guys_right_sounds" },
    { 0x2DD4, "civs_running_exiting_sounds" },
    { 0x2DD5, "civs_soccer_guys" },
    { 0x2DD6, "civs_soccer_guys_animation" },
    { 0x2DD7, "civs_soccer_guys_animation_breakout" },
    { 0x2DD8, "civs_spotters" },
    { 0x2DD9, "civs_spotters_breakout" },
    { 0x2DDA, "civs_table" },
    { 0x2DDB, "civs_table_breakout" },
    { 0x2DDC, "civs_walkers" },
    { 0x2DDD, "civspawners" },
    { 0x2DDE, "civstate" },
    { 0x2DDF, "civstatetime" },
    { 0x2DE0, "civvies_killed_calculate" },
    { 0x2DE1, "ck_aggressivemode" },
    { 0x2DE2, "ck_combatmode" },
    { 0x2DE3, "ck_grenadeammo" },
    { 0x2DE4, "ck_target" },
    { 0x2DE5, "clacker" },
    { 0x2DE6, "clacker_attach" },
    { 0x2DE7, "clacker_detach" },
    { 0x2DE8, "clacker_play_and_remove" },
    { 0x2DE9, "clacker_unusable_thread" },
    { 0x2DEA, "clackerattached" },
    { 0x2DEB, "claim_a_node" },
    { 0x2DEC, "claimed" },
    { 0x2DED, "claimed_node" },
    { 0x2DEE, "claimer" },
    { 0x2DEF, "claimgracetime" },
    { 0x2DF0, "claimplayer" },
    { 0x2DF1, "claimsmartobject" },
    { 0x2DF2, "claimteam" },
    { 0x2DF3, "clamp_angles" },
    { 0x2DF4, "clamp_looping" },
    { 0x2DF5, "clampandnormalize" },
    { 0x2DF6, "clampweaponspeed" },
    { 0x2DF7, "clampweaponweightvalue" },
    { 0x2DF8, "class" },
    { 0x2DF9, "class_num" },
    { 0x2DFA, "class_override" },
    { 0x2DFB, "class_progression_init" },
    { 0x2DFC, "classcallback" },
    { 0x2DFD, "classmap" },
    { 0x2DFE, "classname_mp" },
    { 0x2DFF, "classrefreshed" },
    { 0x2E00, "classselectionbeginnonexclusion" },
    { 0x2E01, "classselectionendnonexclusion" },
    { 0x2E02, "classstruct" },
    { 0x2E03, "classtablename" },
    { 0x2E04, "classteam" },
    { 0x2E05, "classtweaks" },
    { 0x2E06, "claxon_light_init" },
    { 0x2E07, "claxon_lights_off" },
    { 0x2E08, "claxon_lights_on" },
    { 0x2E09, "claxon_stop_spin" },
    { 0x2E0A, "claxons" },
    { 0x2E0B, "claymore_delete" },
    { 0x2E0C, "claymore_destroy" },
    { 0x2E0D, "claymore_destroyonemp" },
    { 0x2E0E, "claymore_empapplied" },
    { 0x2E0F, "claymore_explode" },
    { 0x2E10, "claymore_explodefromvehicletrigger" },
    { 0x2E11, "claymore_explodeonnotify" },
    { 0x2E12, "claymore_init" },
    { 0x2E13, "claymore_modifieddamage" },
    { 0x2E14, "claymore_onownerchanged" },
    { 0x2E15, "claymore_plant" },
    { 0x2E16, "claymore_test" },
    { 0x2E17, "claymore_trigger" },
    { 0x2E18, "claymore_triggerfromvehicle" },
    { 0x2E19, "claymore_updatedangerzone" },
    { 0x2E1A, "claymore_use" },
    { 0x2E1B, "claymore_watchfortrigger" },
    { 0x2E1C, "claymoredetectiondot" },
    { 0x2E1D, "claymoredetectiongraceperiod" },
    { 0x2E1E, "claymoredetectionmindist" },
    { 0x2E1F, "claymoredetonateradius" },
    { 0x2E20, "claymoredetonation" },
    { 0x2E21, "claymoreused" },
    { 0x2E22, "clean_fake_actors" },
    { 0x2E23, "clean_streets_enemies" },
    { 0x2E24, "clean_up_bomb" },
    { 0x2E25, "clean_up_breadcrumbs_to_hvt" },
    { 0x2E26, "clean_up_breadcrumbs_to_roof" },
    { 0x2E27, "clean_up_first_floor_corpses" },
    { 0x2E28, "clean_up_first_floor_scriptables" },
    { 0x2E29, "clean_up_monitor" },
    { 0x2E2A, "clean_up_nodes" },
    { 0x2E2B, "clean_up_on_heli_death" },
    { 0x2E2C, "clean_up_on_vehicle_death" },
    { 0x2E2D, "clean_up_overwatch_camera_point" },
    { 0x2E2E, "clean_up_post_spotter_comment" },
    { 0x2E2F, "clean_up_structs" },
    { 0x2E30, "clean_up_think" },
    { 0x2E31, "clean_up_turret" },
    { 0x2E32, "cleanac130struct" },
    { 0x2E33, "cleancustombc" },
    { 0x2E34, "cleanlbarray" },
    { 0x2E35, "cleanme" },
    { 0x2E36, "cleanpatchablecollision" },
    { 0x2E37, "cleanpowercooldowns" },
    { 0x2E38, "cleanup" },
    { 0x2E39, "cleanup_2f" },
    { 0x2E3A, "cleanup_2f_anim" },
    { 0x2E3B, "cleanup_ai" },
    { 0x2E3C, "cleanup_all_dropped_loot" },
    { 0x2E3D, "cleanup_all_poi" },
    { 0x2E3E, "cleanup_area" },
    { 0x2E3F, "cleanup_background_city_heli" },
    { 0x2E40, "cleanup_compound_ents" },
    { 0x2E41, "cleanup_corpses_in_radius" },
    { 0x2E42, "cleanup_corpses_in_trigger" },
    { 0x2E43, "cleanup_cs_file_objects" },
    { 0x2E44, "cleanup_enemies_for_wolf_defuse" },
    { 0x2E45, "cleanup_ents" },
    { 0x2E46, "cleanup_ents_removing_bullet_shield" },
    { 0x2E47, "cleanup_finale_combat_guys" },
    { 0x2E48, "cleanup_heli_rockets" },
    { 0x2E49, "cleanup_intro_ents" },
    { 0x2E4A, "cleanup_marine_spawner_arrays" },
    { 0x2E4B, "cleanup_outlines" },
    { 0x2E4C, "cleanup_player_on_game_end" },
    { 0x2E4D, "cleanup_selectable" },
    { 0x2E4E, "cleanup_state_ents" },
    { 0x2E4F, "cleanup_transitiontocoverhide" },
    { 0x2E50, "cleanup_unused_paths" },
    { 0x2E51, "cleanup_vt" },
    { 0x2E52, "cleanup_wall_truck_civ" },
    { 0x2E53, "cleanup_waypoint_when_near" },
    { 0x2E54, "cleanupafterplayerdeath" },
    { 0x2E55, "cleanupaftertimeoutordeath" },
    { 0x2E56, "cleanupanimscriptedheadlook" },
    { 0x2E57, "cleanupascenduse" },
    { 0x2E58, "cleanupbeamfx" },
    { 0x2E59, "cleanupbethud" },
    { 0x2E5A, "cleanupbodydrop" },
    { 0x2E5B, "cleanupbtactions" },
    { 0x2E5C, "cleanupcivilianreactionalias" },
    { 0x2E5D, "cleanupconcussionstun" },
    { 0x2E5E, "cleanupcrankedplayertimer" },
    { 0x2E5F, "cleanupcrankedtimer" },
    { 0x2E60, "cleanupdeployablemarkerondisconnect" },
    { 0x2E61, "cleanupdeployweapon" },
    { 0x2E62, "cleanupdragallyprototype" },
    { 0x2E63, "cleanupdropbagsoncircle" },
    { 0x2E64, "cleanupents" },
    { 0x2E65, "cleanupepictauntprops" },
    { 0x2E66, "cleanupequipment" },
    { 0x2E67, "cleanupexplosivesondeath" },
    { 0x2E68, "cleanupflashanim" },
    { 0x2E69, "cleanupgamemodes" },
    { 0x2E6A, "cleanupgametypevips" },
    { 0x2E6B, "cleanuphuntbuilddata" },
    { 0x2E6C, "cleanupinteractiveinfilai" },
    { 0x2E6D, "cleanupjuggobjective" },
    { 0x2E6E, "cleanuplastsaytimes" },
    { 0x2E6F, "cleanuplaststandent" },
    { 0x2E70, "cleanuplocalplayersplashlist" },
    { 0x2E71, "cleanuplootitem" },
    { 0x2E72, "cleanuplootitemondelete" },
    { 0x2E73, "cleanuplz" },
    { 0x2E74, "cleanuplzvisuals" },
    { 0x2E75, "cleanupobjectiveiconsforjugg" },
    { 0x2E76, "cleanupoutercrates" },
    { 0x2E77, "cleanupouterspawnclosets" },
    { 0x2E78, "cleanupoverheadicon" },
    { 0x2E79, "cleanuppainanim" },
    { 0x2E7A, "cleanuprevivetriggericons" },
    { 0x2E7B, "cleanupspawn_scriptnoteworthy" },
    { 0x2E7C, "cleanupsuperdisableweapon" },
    { 0x2E7D, "cleanupteamicons" },
    { 0x2E7E, "cleanupthreadforbombobject" },
    { 0x2E7F, "cleanuptransitiontocoverhide" },
    { 0x2E80, "cleanupwallruntransitioncheck" },
    { 0x2E81, "clear_ai_weapon_override" },
    { 0x2E82, "clear_aitype" },
    { 0x2E83, "clear_alias_group" },
    { 0x2E84, "clear_all_allow_info" },
    { 0x2E85, "clear_all_crawl_flags" },
    { 0x2E86, "clear_all_vehicle_lights" },
    { 0x2E87, "clear_allies_demeanor_override" },
    { 0x2E88, "clear_allow_info" },
    { 0x2E89, "clear_animpos" },
    { 0x2E8A, "clear_archetype" },
    { 0x2E8B, "clear_arrival_speed" },
    { 0x2E8C, "clear_backyard_objective" },
    { 0x2E8D, "clear_bot_camping_on_bot_death" },
    { 0x2E8E, "clear_bot_camping_on_reset" },
    { 0x2E8F, "clear_bot_on_bot_death" },
    { 0x2E90, "clear_bot_on_reset" },
    { 0x2E91, "clear_camper_data" },
    { 0x2E92, "clear_colors" },
    { 0x2E93, "clear_custom_anim" },
    { 0x2E94, "clear_custom_animset" },
    { 0x2E95, "clear_custom_death_quote" },
    { 0x2E96, "clear_deathanim" },
    { 0x2E97, "clear_defend" },
    { 0x2E98, "clear_demeanor_override" },
    { 0x2E99, "clear_dont_enter_combat_flag" },
    { 0x2E9A, "clear_earthquake_for_client" },
    { 0x2E9B, "clear_effort_sound" },
    { 0x2E9C, "clear_emp" },
    { 0x2E9D, "clear_enemy_flags" },
    { 0x2E9E, "clear_enemy_grenades" },
    { 0x2E9F, "clear_entity_selection" },
    { 0x2EA0, "clear_eog_tracking_types" },
    { 0x2EA1, "clear_exception" },
    { 0x2EA2, "clear_favorite_enemy" },
    { 0x2EA3, "clear_first_wave_override" },
    { 0x2EA4, "clear_floor" },
    { 0x2EA5, "clear_force_color" },
    { 0x2EA6, "clear_fx_hudelements" },
    { 0x2EA7, "clear_generic_idle_anim" },
    { 0x2EA8, "clear_generic_run_anim" },
    { 0x2EA9, "clear_goliath_bloody_footsteps" },
    { 0x2EAA, "clear_heldspawner" },
    { 0x2EAB, "clear_hill_apcs" },
    { 0x2EAC, "clear_hud_elements" },
    { 0x2EAD, "clear_hunted_flags" },
    { 0x2EAE, "clear_icon_on_cruise_missiles" },
    { 0x2EAF, "clear_icon_on_interceptor_missiles" },
    { 0x2EB0, "clear_idle_anim" },
    { 0x2EB1, "clear_idle_anim_override" },
    { 0x2EB2, "clear_idle_twitch" },
    { 0x2EB3, "clear_infil_ambient_zone" },
    { 0x2EB4, "clear_kill_off_flags" },
    { 0x2EB5, "clear_last_stand_timer" },
    { 0x2EB6, "clear_lookat_delay" },
    { 0x2EB7, "clear_menu_options" },
    { 0x2EB8, "clear_move_anim" },
    { 0x2EB9, "clear_move_with_purpose" },
    { 0x2EBA, "clear_movement_speed" },
    { 0x2EBB, "clear_navobstacle" },
    { 0x2EBC, "clear_node_path" },
    { 0x2EBD, "clear_objective_icons" },
    { 0x2EBE, "clear_omnvar" },
    { 0x2EBF, "clear_path_array" },
    { 0x2EC0, "clear_pathpoints" },
    { 0x2EC1, "clear_player_tired_movement" },
    { 0x2EC2, "clear_plr_vehicle_submix" },
    { 0x2EC3, "clear_pos_from_hunt_pos_array" },
    { 0x2EC4, "clear_power_slot" },
    { 0x2EC5, "clear_powers_hud" },
    { 0x2EC6, "clear_reminder" },
    { 0x2EC7, "clear_root" },
    { 0x2EC8, "clear_rumble_for_client" },
    { 0x2EC9, "clear_run_anim" },
    { 0x2ECA, "clear_run_anim_override" },
    { 0x2ECB, "clear_script_goal_on" },
    { 0x2ECC, "clear_script_origin_other_on_ai" },
    { 0x2ECD, "clear_scripted_anim" },
    { 0x2ECE, "clear_settable_fx" },
    { 0x2ECF, "clear_shackled_squat_override" },
    { 0x2ED0, "clear_snake" },
    { 0x2ED1, "clear_tank_stackup" },
    { 0x2ED2, "clear_target_entity" },
    { 0x2ED3, "clear_target_zone_update" },
    { 0x2ED4, "clear_team_colors" },
    { 0x2ED5, "clear_to_pick_disguise_up" },
    { 0x2ED6, "clear_to_pick_disguise_up_veh" },
    { 0x2ED7, "clear_tool_hud" },
    { 0x2ED8, "clear_universal_buttons" },
    { 0x2ED9, "clear_unresolved_collision_count_next_frame" },
    { 0x2EDA, "clear_up_stealth_meter_when_enter_combat" },
    { 0x2EDB, "clear_vehicle_build_to_spawnpoint" },
    { 0x2EDC, "clear_vision" },
    { 0x2EDD, "clear_wave_ref_override" },
    { 0x2EDE, "clear_weapons_status" },
    { 0x2EDF, "clearactivemapconfigs" },
    { 0x2EE0, "clearactivespawnquerycontext" },
    { 0x2EE1, "clearafterfade" },
    { 0x2EE2, "clearall" },
    { 0x2EE3, "clearallequipment" },
    { 0x2EE4, "clearallgroups" },
    { 0x2EE5, "clearancecheckheight" },
    { 0x2EE6, "clearancecheckminradii" },
    { 0x2EE7, "clearancecheckminradius" },
    { 0x2EE8, "clearancecheckoffsetz" },
    { 0x2EE9, "clearancecheckradius" },
    { 0x2EEA, "cleararchetype" },
    { 0x2EEB, "clearbtgoalonarrival" },
    { 0x2EEC, "clearburnfx" },
    { 0x2EED, "clearcallbacks" },
    { 0x2EEE, "clearcalloutareaondeath" },
    { 0x2EEF, "clearcamoscripts" },
    { 0x2EF0, "clearcarrier" },
    { 0x2EF1, "clearcodefactors" },
    { 0x2EF2, "clearconvergence" },
    { 0x2EF3, "clearcorpsetablefuncs" },
    { 0x2EF4, "clearcover" },
    { 0x2EF5, "clearcoveranim" },
    { 0x2EF6, "clearcoverbb" },
    { 0x2EF7, "clearcurrentcustombcevent" },
    { 0x2EF8, "cleardamagehistory" },
    { 0x2EF9, "cleardamagemodifiers" },
    { 0x2EFA, "cleardata" },
    { 0x2EFB, "cleardemeanorsafe" },
    { 0x2EFC, "cleared_storage" },
    { 0x2EFD, "clearedddsoundmix" },
    { 0x2EFE, "clearfaceanimonanimdone" },
    { 0x2EFF, "clearfacialstate" },
    { 0x2F00, "clearflash" },
    { 0x2F01, "cleargesture" },
    { 0x2F02, "cleargestureanim" },
    { 0x2F03, "clearhealthshield" },
    { 0x2F04, "clearhintobject" },
    { 0x2F05, "clearignoreriotshieldxp" },
    { 0x2F06, "clearirtarget" },
    { 0x2F07, "clearisspeaking" },
    { 0x2F08, "clearjugghud" },
    { 0x2F09, "clearkillcamattachmentomnvars" },
    { 0x2F0A, "clearkillcamkilledbyitemomnvars" },
    { 0x2F0B, "clearkillcamomnvars" },
    { 0x2F0C, "clearkillcamstate" },
    { 0x2F0D, "clearkillstreaks" },
    { 0x2F0E, "clearkillstreakselection" },
    { 0x2F0F, "clearlaststandinvuln" },
    { 0x2F10, "clearlastteamspawns" },
    { 0x2F11, "clearlockedon" },
    { 0x2F12, "clearlockedonondisconnect" },
    { 0x2F13, "clearloopingcoughaudio" },
    { 0x2F14, "clearlootweaponomnvars" },
    { 0x2F15, "clearlowermessage" },
    { 0x2F16, "clearlowermessages" },
    { 0x2F17, "clearmarkonrespawn" },
    { 0x2F18, "clearmatchhasmorethan1playervariablesonroundend" },
    { 0x2F19, "clearmeleeaction" },
    { 0x2F1A, "clearmiss" },
    { 0x2F1B, "clearnvg" },
    { 0x2F1C, "clearobjectivetext" },
    { 0x2F1D, "clearobjectivetextforplayer" },
    { 0x2F1E, "clearomnvarsaftertime" },
    { 0x2F1F, "clearondeath" },
    { 0x2F20, "clearonvictimdisconnect" },
    { 0x2F21, "clearoob" },
    { 0x2F22, "clearoverridearchetype" },
    { 0x2F23, "clearpainturnrate" },
    { 0x2F24, "clearpassivedeathwatching" },
    { 0x2F25, "clearpassives" },
    { 0x2F26, "clearpathactionvalue" },
    { 0x2F27, "clearpinnedobjectives" },
    { 0x2F28, "clearplayeraccessory" },
    { 0x2F29, "clearplayerlockfromremoteuavlaunch" },
    { 0x2F2A, "clearpowers" },
    { 0x2F2B, "clearprematchlook" },
    { 0x2F2C, "clearprojectilelockedon" },
    { 0x2F2D, "clearrideintro" },
    { 0x2F2E, "clearscoreeventlistafterwait" },
    { 0x2F2F, "clearscriptable" },
    { 0x2F30, "clearselectedareaonspawn" },
    { 0x2F31, "clearshotgroup" },
    { 0x2F32, "clearsightposnear" },
    { 0x2F33, "clearsmartobject" },
    { 0x2F34, "clearspawnpointdistancedata" },
    { 0x2F35, "clearspawnpointsightdata" },
    { 0x2F36, "clearstealthvolume" },
    { 0x2F37, "clearstockondrop" },
    { 0x2F38, "clearstoredkillstreakoperatordialog" },
    { 0x2F39, "clearsuper" },
    { 0x2F3A, "clearsuperreminderondeath" },
    { 0x2F3B, "clearsuperreminderondeathinternal" },
    { 0x2F3C, "clearsuperremindersplash" },
    { 0x2F3D, "cleartarget" },
    { 0x2F3E, "clearteamspawnpointdistancedata" },
    { 0x2F3F, "clearteamspawnpointsightdata" },
    { 0x2F40, "cleartextmarker" },
    { 0x2F41, "clearthreatbias" },
    { 0x2F42, "clearusingremote" },
    { 0x2F43, "clearvehiclearchetype" },
    { 0x2F44, "clearvehiclereservation" },
    { 0x2F45, "clearvisionsetnaked" },
    { 0x2F46, "clearvisionsettimer" },
    { 0x2F47, "clearweaponoutlines" },
    { 0x2F48, "clearweaponscriptvfx" },
    { 0x2F49, "clearweaponsfree" },
    { 0x2F4A, "client_is_dev_bot" },
    { 0x2F4B, "client_settle_time_get" },
    { 0x2F4C, "clientid" },
    { 0x2F4D, "clientmatchdata" },
    { 0x2F4E, "clientmatchdata_data_type" },
    { 0x2F4F, "clientmatchdata_struct" },
    { 0x2F50, "clientmatchdataid" },
    { 0x2F51, "clientnum" },
    { 0x2F52, "clientsettletime" },
    { 0x2F53, "clienttweakables" },
    { 0x2F54, "climber" },
    { 0x2F55, "clip" },
    { 0x2F56, "clip_ammo" },
    { 0x2F57, "clip_crawl" },
    { 0x2F58, "clip_delete" },
    { 0x2F59, "clip_nosight" },
    { 0x2F5A, "clip_stand" },
    { 0x2F5B, "clipammo" },
    { 0x2F5C, "clipent" },
    { 0x2F5D, "clipmodel" },
    { 0x2F5E, "clips" },
    { 0x2F5F, "clock_display" },
    { 0x2F60, "close_airport_gate" },
    { 0x2F61, "close_alley_gate" },
    { 0x2F62, "close_and_lock_door" },
    { 0x2F63, "close_angles" },
    { 0x2F64, "close_blockade_gates" },
    { 0x2F65, "close_check" },
    { 0x2F66, "close_dist" },
    { 0x2F67, "close_dist_sq" },
    { 0x2F68, "close_door" },
    { 0x2F69, "close_doors_after_hvt_anim" },
    { 0x2F6A, "close_elevator_doors" },
    { 0x2F6B, "close_elevator_doors_roof" },
    { 0x2F6C, "close_in_on_far_player" },
    { 0x2F6D, "close_in_on_player" },
    { 0x2F6E, "close_inner_doors" },
    { 0x2F6F, "close_map_write" },
    { 0x2F70, "close_outer_doors" },
    { 0x2F71, "close_plane_doors" },
    { 0x2F72, "close_plane_doors_anim" },
    { 0x2F73, "close_prompt" },
    { 0x2F74, "close_runner_logic" },
    { 0x2F75, "close_safehouse_door" },
    { 0x2F76, "close_scripted_door" },
    { 0x2F77, "close_spawn_min_dist_sq" },
    { 0x2F78, "close_time" },
    { 0x2F79, "close_warehouse_door" },
    { 0x2F7A, "closecapturekiller" },
    { 0x2F7B, "closed" },
    { 0x2F7C, "closed_angles" },
    { 0x2F7D, "closed_pos" },
    { 0x2F7E, "closedoor" },
    { 0x2F7F, "closedoorifnecessary" },
    { 0x2F80, "closemonitor" },
    { 0x2F81, "closeomamenuondeath" },
    { 0x2F82, "closerfunc" },
    { 0x2F83, "closest_dist_sq" },
    { 0x2F84, "closest_point_on_grid" },
    { 0x2F85, "closest_type" },
    { 0x2F86, "closestalliesflag" },
    { 0x2F87, "closestaxisflag" },
    { 0x2F88, "closestdistancebetweenlines" },
    { 0x2F89, "closestdistancebetweensegments" },
    { 0x2F8A, "closestdoorpos" },
    { 0x2F8B, "closestenemies" },
    { 0x2F8C, "closestenemies_array" },
    { 0x2F8D, "closestpoint" },
    { 0x2F8E, "closestpointtowall" },
    { 0x2F8F, "closet_runner_ignore_manager" },
    { 0x2F90, "closetacopsmap" },
    { 0x2F91, "closetargetsinouterradius" },
    { 0x2F92, "closetogoalcheck" },
    { 0x2F93, "closetoscorelimit" },
    { 0x2F94, "closeweaponmaxdist" },
    { 0x2F95, "cloth" },
    { 0x2F96, "clothtype" },
    { 0x2F97, "cloudsfx" },
    { 0x2F98, "cluster_spawners" },
    { 0x2F99, "cluster_spawnpoint_scoring" },
    { 0x2F9A, "cluster_spawnpoint_valid" },
    { 0x2F9B, "clusterammoleft" },
    { 0x2F9C, "clustergrenadeexplode" },
    { 0x2F9D, "clustergrenadeinit" },
    { 0x2F9E, "clustergrenadeovercookfunc" },
    { 0x2F9F, "clustergrenadeused" },
    { 0x2FA0, "clusterlist" },
    { 0x2FA1, "clusters" },
    { 0x2FA2, "clusterticks" },
    { 0x2FA3, "cmd_endgame" },
    { 0x2FA4, "cmdattackingteam" },
    { 0x2FA5, "cmddefendingteam" },
    { 0x2FA6, "cmdrules" },
    { 0x2FA7, "co_butcher_mayhem" },
    { 0x2FA8, "co_cine_dof" },
    { 0x2FA9, "co_wolf_mayhem" },
    { 0x2FAA, "cobra_missile_models" },
    { 0x2FAB, "cobra_weapon_tags" },
    { 0x2FAC, "cobraweapon" },
    { 0x2FAD, "cockpitcamera" },
    { 0x2FAE, "codcasterball" },
    { 0x2FAF, "codcasterballcamfollow" },
    { 0x2FB0, "codcasterballinitialforcevector" },
    { 0x2FB1, "codcasterballowner" },
    { 0x2FB2, "codcasterenabled" },
    { 0x2FB3, "codcastermatchdata" },
    { 0x2FB4, "codcastermatchdataid" },
    { 0x2FB5, "codecallbackhandler_spawnpointcritscore" },
    { 0x2FB6, "codecallbackhandler_spawnpointprecalc" },
    { 0x2FB7, "codecallbackhandler_spawnpointscore" },
    { 0x2FB8, "codescripted" },
    { 0x2FB9, "codevehicletest" },
    { 0x2FBA, "cointoss" },
    { 0x2FBB, "cointoss_variable" },
    { 0x2FBC, "cold_weapon" },
    { 0x2FBD, "coldopen_bink_catchup" },
    { 0x2FBE, "coldopen_bink_move_scene" },
    { 0x2FBF, "coldopen_bink_start" },
    { 0x2FC0, "collapse" },
    { 0x2FC1, "collapse_beam_bend" },
    { 0x2FC2, "collapse_burn_player" },
    { 0x2FC3, "collapse_burn_player_death_hint" },
    { 0x2FC4, "collapse_catchup" },
    { 0x2FC5, "collapse_clip" },
    { 0x2FC6, "collapse_crawl_segment_anim" },
    { 0x2FC7, "collapse_delay" },
    { 0x2FC8, "collapse_earthquakes" },
    { 0x2FC9, "collapse_explode" },
    { 0x2FCA, "collapse_exploder" },
    { 0x2FCB, "collapse_farah_crawl" },
    { 0x2FCC, "collapse_farah_demeanor" },
    { 0x2FCD, "collapse_farah_scene" },
    { 0x2FCE, "collapse_fuel_hint_dialogue" },
    { 0x2FCF, "collapse_geo_after" },
    { 0x2FD0, "collapse_geo_before" },
    { 0x2FD1, "collapse_hurt_trig" },
    { 0x2FD2, "collapse_hurt_trigs" },
    { 0x2FD3, "collapse_oil_trap_wait" },
    { 0x2FD4, "collapse_player_slow_crawl" },
    { 0x2FD5, "collapse_sag_beam" },
    { 0x2FD6, "collapse_setup" },
    { 0x2FD7, "collapse_setup_tunnel_scriptables" },
    { 0x2FD8, "collapse_sfx" },
    { 0x2FD9, "collapse_start" },
    { 0x2FDA, "collapse_thread" },
    { 0x2FDB, "collapse_vfx" },
    { 0x2FDC, "collapsed" },
    { 0x2FDD, "collateral" },
    { 0x2FDE, "collateraldamageassessment" },
    { 0x2FDF, "collect_circuit_children" },
    { 0x2FE0, "collect_circuit_siblines" },
    { 0x2FE1, "collect_intel" },
    { 0x2FE2, "collect_investigate" },
    { 0x2FE3, "collect_jugg_key" },
    { 0x2FE4, "collect_lead" },
    { 0x2FE5, "collected_enough_leads" },
    { 0x2FE6, "collectibles" },
    { 0x2FE7, "collision" },
    { 0x2FE8, "collision_check_failed" },
    { 0x2FE9, "collision_created" },
    { 0x2FEA, "collision_down" },
    { 0x2FEB, "collision_up" },
    { 0x2FEC, "colmodelent" },
    { 0x2FED, "color_01" },
    { 0x2FEE, "color_02" },
    { 0x2FEF, "color_arrive_handler" },
    { 0x2FF0, "color_base" },
    { 0x2FF1, "color_debug" },
    { 0x2FF2, "color_doesnt_care_about_classname" },
    { 0x2FF3, "color_index" },
    { 0x2FF4, "color_node" },
    { 0x2FF5, "color_node_arrive" },
    { 0x2FF6, "color_node_finds_a_user" },
    { 0x2FF7, "color_node_finds_user_for_colorcode" },
    { 0x2FF8, "color_node_finds_user_from_colorcodes" },
    { 0x2FF9, "color_node_left_cleanup" },
    { 0x2FFA, "color_node_type_function" },
    { 0x2FFB, "color_ordered_node_assignment" },
    { 0x2FFC, "color_respawn_spawner" },
    { 0x2FFD, "color_teams" },
    { 0x2FFE, "color_traversal_nagtill" },
    { 0x2FFF, "color_trig_touching" },
    { 0x3000, "color_user" },
    { 0x3001, "colorchecklist" },
    { 0x3002, "colorcode_is_used_in_map" },
    { 0x3003, "colordye" },
    { 0x3004, "colorindex" },
    { 0x3005, "colorislegit" },
    { 0x3006, "colorlist" },
    { 0x3007, "colornode_arrived_func" },
    { 0x3008, "colornode_assign_bravo2_2" },
    { 0x3009, "colornode_assign_price" },
    { 0x300A, "colornode_func" },
    { 0x300B, "colornode_replace_on_death" },
    { 0x300C, "colornode_setgoal_func" },
    { 0x300D, "colornode_spawn_reinforcement" },
    { 0x300E, "colornodes_debug_array" },
    { 0x300F, "colors" },
    { 0x3010, "colorspawners" },
    { 0x3011, "colorvolumes_debug_array" },
    { 0x3012, "combat_ambience" },
    { 0x3013, "combat_clearfacialanim" },
    { 0x3014, "combat_counter_reset" },
    { 0x3015, "combat_distract" },
    { 0x3016, "combat_end" },
    { 0x3017, "combat_func" },
    { 0x3018, "combat_func_active" },
    { 0x3019, "combat_func_override" },
    { 0x301A, "combat_getinfoinradius" },
    { 0x301B, "combat_goalradius" },
    { 0x301C, "combat_icon_objective_id" },
    { 0x301D, "combat_init" },
    { 0x301E, "combat_interaction_process" },
    { 0x301F, "combat_interaction_run" },
    { 0x3020, "combat_logic" },
    { 0x3021, "combat_loop" },
    { 0x3022, "combat_objectives" },
    { 0x3023, "combat_playfacialanim" },
    { 0x3024, "combat_reaction_previous_anim" },
    { 0x3025, "combat_reaction_return_state" },
    { 0x3026, "combat_reaction_wait" },
    { 0x3027, "combat_reaction_wait_buffer" },
    { 0x3028, "combat_resource" },
    { 0x3029, "combat_start" },
    { 0x302A, "combat_terminate" },
    { 0x302B, "combat_volume" },
    { 0x302C, "combat_volumes" },
    { 0x302D, "combataimlimits" },
    { 0x302E, "combatcrouchanims" },
    { 0x302F, "combatendtime" },
    { 0x3030, "combatfunc" },
    { 0x3031, "combathigh" },
    { 0x3032, "combathighicon" },
    { 0x3033, "combathighoverlay" },
    { 0x3034, "combathightimer" },
    { 0x3035, "combating" },
    { 0x3036, "combatmemorytimeconst" },
    { 0x3037, "combatmemorytimerand" },
    { 0x3038, "combatradiussq" },
    { 0x3039, "combatrecordarchetypedeath" },
    { 0x303A, "combatrecordarchetypekill" },
    { 0x303B, "combatrecordincrementkillstreakawardedstat" },
    { 0x303C, "combatrecordkillstreakstat" },
    { 0x303D, "combatrecordkillstreakuse" },
    { 0x303E, "combatrecordlethalkill" },
    { 0x303F, "combatrecordsuperkill" },
    { 0x3040, "combatrecordsuperuse" },
    { 0x3041, "combatrecordtacticalstat" },
    { 0x3042, "combatspeedscalar" },
    { 0x3043, "combatstandanims" },
    { 0x3044, "combatstate" },
    { 0x3045, "combatstate_addupdatefunc" },
    { 0x3046, "combatstate_removeupdatefunc" },
    { 0x3047, "combatstate_thread" },
    { 0x3048, "combatstate_updatethread" },
    { 0x3049, "combattime" },
    { 0x304A, "combattraverseenabled" },
    { 0x304B, "combine_module_counters" },
    { 0x304C, "combined_counters" },
    { 0x304D, "combinedefaultandcustomattachmentidmaps" },
    { 0x304E, "comeback" },
    { 0x304F, "comloadout" },
    { 0x3050, "command_given" },
    { 0x3051, "commanddown" },
    { 0x3052, "commander" },
    { 0x3053, "commander_approach" },
    { 0x3054, "commander_delay" },
    { 0x3055, "commander_dialog" },
    { 0x3056, "commander_play_sound_func" },
    { 0x3057, "commander_speaking" },
    { 0x3058, "commanding_bot" },
    { 0x3059, "commands" },
    { 0x305A, "commands_requested_recently" },
    { 0x305B, "commandup" },
    { 0x305C, "common_friendly_convoy_vehicle_func" },
    { 0x305D, "commoninit" },
    { 0x305E, "comms" },
    { 0x305F, "comp_1f_catchup" },
    { 0x3060, "comp_1f_start" },
    { 0x3061, "comp_2f_catchup" },
    { 0x3062, "comp_2f_start" },
    { 0x3063, "comp_3f_catchup" },
    { 0x3064, "comp_3f_finished_vo" },
    { 0x3065, "comp_3f_start" },
    { 0x3066, "comp_cleared_pillage_vo" },
    { 0x3067, "comp_cleared_price_stairs_vo" },
    { 0x3068, "compare" },
    { 0x3069, "compare_arrays" },
    { 0x306A, "compare_bomb_id" },
    { 0x306B, "compare_breadcrumb_order" },
    { 0x306C, "compare_group_name" },
    { 0x306D, "compare_player_pass_dot" },
    { 0x306E, "compare_player_score" },
    { 0x306F, "compare_values" },
    { 0x3070, "compareballindexes" },
    { 0x3071, "compareclassstructs" },
    { 0x3072, "comparepriorityandtime" },
    { 0x3073, "comparescriptindex" },
    { 0x3074, "comparesizesfx" },
    { 0x3075, "comparesoundpriorities" },
    { 0x3076, "comparevehdisttoends" },
    { 0x3077, "comparezoneindexes" },
    { 0x3078, "compasshideshots" },
    { 0x3079, "compassiconenemy" },
    { 0x307A, "compassiconfriendly" },
    { 0x307B, "compassicons" },
    { 0x307C, "compensatetoground" },
    { 0x307D, "complete_breakout" },
    { 0x307E, "complete_checkin_weapons" },
    { 0x307F, "complete_find_hvi" },
    { 0x3080, "complete_func" },
    { 0x3081, "complete_game" },
    { 0x3082, "complete_game_win" },
    { 0x3083, "complete_go_to_the_prison" },
    { 0x3084, "complete_killer" },
    { 0x3085, "complete_meet_with_informant" },
    { 0x3086, "complete_state" },
    { 0x3087, "completearmsraceobj" },
    { 0x3088, "completeballoon" },
    { 0x3089, "completed_delay" },
    { 0x308A, "completed_fusebox_tut_anim" },
    { 0x308B, "completedanims" },
    { 0x308C, "completednodes" },
    { 0x308D, "completedobjective" },
    { 0x308E, "completedobjectives" },
    { 0x308F, "completelyremovelittlebird" },
    { 0x3090, "completemorales_1" },
    { 0x3091, "completemorales_2" },
    { 0x3092, "completemorales_3" },
    { 0x3093, "completemorales_4" },
    { 0x3094, "completemorales_5" },
    { 0x3095, "completemorales_6" },
    { 0x3096, "completemoralesfastloadobj" },
    { 0x3097, "completemoraleshackobj" },
    { 0x3098, "completemoralesholdoutobj" },
    { 0x3099, "completemoralesinfilobj" },
    { 0x309A, "completemoralesrescueobj" },
    { 0x309B, "completemoralessignalobj" },
    { 0x309C, "completemoralesslowloadobj" },
    { 0x309D, "completeobjective" },
    { 0x309E, "completeobjective1" },
    { 0x309F, "completeobjective2" },
    { 0x30A0, "completeobjective3" },
    { 0x30A1, "completepayloadobj" },
    { 0x30A2, "completescavengerquest" },
    { 0x30A3, "completetmtylobj" },
    { 0x30A4, "completeweapon" },
    { 0x30A5, "completion" },
    { 0x30A6, "component_specific_init" },
    { 0x30A7, "compound_door_setup" },
    { 0x30A8, "compound_lights_off" },
    { 0x30A9, "compound_lights_on" },
    { 0x30AA, "compound_lights_sequence" },
    { 0x30AB, "compound_open_side_door" },
    { 0x30AC, "compound_residence" },
    { 0x30AD, "compound_residence_exit" },
    { 0x30AE, "compound_return_lighting" },
    { 0x30AF, "compound_scriptables" },
    { 0x30B0, "compound_technicals" },
    { 0x30B1, "compromise_center_truck" },
    { 0x30B2, "computer" },
    { 0x30B3, "computer_activate" },
    { 0x30B4, "computer_anim_loop" },
    { 0x30B5, "computer_anim_loop_exit" },
    { 0x30B6, "computer_animation" },
    { 0x30B7, "computer_disconnect_handler" },
    { 0x30B8, "computer_event_listener" },
    { 0x30B9, "computer_laststand_handler" },
    { 0x30BA, "computer_name" },
    { 0x30BB, "computer_omnvar_setup" },
    { 0x30BC, "computer_player_allow" },
    { 0x30BD, "computer_result_omnvar" },
    { 0x30BE, "computer_search_action" },
    { 0x30BF, "computer_test" },
    { 0x30C0, "computer_think" },
    { 0x30C1, "computer_think_internal" },
    { 0x30C2, "computer_watch_for_search" },
    { 0x30C3, "computescoreboardslot" },
    { 0x30C4, "conceal_add_cleanup" },
    { 0x30C5, "concrete_blocker_markers" },
    { 0x30C6, "concussionendtime" },
    { 0x30C7, "concussiongrenadefx" },
    { 0x30C8, "cond" },
    { 0x30C9, "cond_func" },
    { 0x30CA, "condition_allplayersoutsideradius" },
    { 0x30CB, "condition_anyplayerinsideradius" },
    { 0x30CC, "condition_circlecount" },
    { 0x30CD, "condition_circlesremaining" },
    { 0x30CE, "condition_debugpaused" },
    { 0x30CF, "condition_disabled" },
    { 0x30D0, "condition_insafecircle" },
    { 0x30D1, "condition_lastencounterstarttime" },
    { 0x30D2, "condition_maxactivelocations" },
    { 0x30D3, "condition_maxaliveplayers" },
    { 0x30D4, "condition_mintimepassed" },
    { 0x30D5, "condition_prematchdone" },
    { 0x30D6, "condition_stateis" },
    { 0x30D7, "conditional_enemies" },
    { 0x30D8, "conf_camper_camp_tags" },
    { 0x30D9, "conf_camping_tag" },
    { 0x30DA, "conf_camping_zone" },
    { 0x30DB, "conf_fx" },
    { 0x30DC, "config" },
    { 0x30DD, "configs" },
    { 0x30DE, "confirm_cut" },
    { 0x30DF, "confirmcontextualworldmarkercb" },
    { 0x30E0, "confirmenemymarkercb" },
    { 0x30E1, "confirmlootmarkercb" },
    { 0x30E2, "confused_about_phone" },
    { 0x30E3, "connect_and_delete" },
    { 0x30E4, "connect_doorway_paths" },
    { 0x30E5, "connect_jumpdown_traversal" },
    { 0x30E6, "connect_ml_p2_doorway_paths" },
    { 0x30E7, "connect_office_door_paths" },
    { 0x30E8, "connect_time" },
    { 0x30E9, "connect_validateplayerteam" },
    { 0x30EA, "connected" },
    { 0x30EB, "connectedpostgame" },
    { 0x30EC, "connectingplayers" },
    { 0x30ED, "connectnewagent" },
    { 0x30EE, "connectpathsfunction" },
    { 0x30EF, "connecttime" },
    { 0x30F0, "consecutivehitsperweapon" },
    { 0x30F1, "const_cos60" },
    { 0x30F2, "constant_quake" },
    { 0x30F3, "constantsize" },
    { 0x30F4, "constraingametype" },
    { 0x30F5, "constructhelipath" },
    { 0x30F6, "construction_animatedcivilianlogic" },
    { 0x30F7, "construction_animatedenemylogic" },
    { 0x30F8, "construction_animatedscenelogic" },
    { 0x30F9, "construction_dialoguelogic" },
    { 0x30FA, "construction_getanimatedcivilian" },
    { 0x30FB, "construction_getanimatedenemies" },
    { 0x30FC, "construction_getanimatedvehicle" },
    { 0x30FD, "construction_getanimatedvehiclecivilians" },
    { 0x30FE, "construction_getanimationstruct" },
    { 0x30FF, "construction_getcivilianworkers" },
    { 0x3100, "construction_getfarahpath" },
    { 0x3101, "construction_getguardvolumealertednotify" },
    { 0x3102, "construction_getplayerabandontrigger" },
    { 0x3103, "construction_getvehicles" },
    { 0x3104, "construction_main" },
    { 0x3105, "construction_objectivelogic" },
    { 0x3106, "construction_playerabandonlogic" },
    { 0x3107, "construction_spawnanimatedcivilian" },
    { 0x3108, "construction_spawnanimatedenemies" },
    { 0x3109, "construction_spawnanimatedunloadercivilian" },
    { 0x310A, "construction_spawnanimatedvehiclecivilians" },
    { 0x310B, "construction_spawncivilians" },
    { 0x310C, "construction_spawncivilianworkers" },
    { 0x310D, "construction_spawnenemies" },
    { 0x310E, "construction_start" },
    { 0x310F, "construction_wallalogic" },
    { 0x3110, "consumable_activate" },
    { 0x3111, "consumable_activate_internal" },
    { 0x3112, "consumable_activate_internal_irish" },
    { 0x3113, "consumable_cash_scalar" },
    { 0x3114, "consumable_meter" },
    { 0x3115, "consumable_meter_full" },
    { 0x3116, "consumable_meter_max" },
    { 0x3117, "consumable_setup_functions" },
    { 0x3118, "consumable_table" },
    { 0x3119, "consumables" },
    { 0x311A, "consumables_equipped" },
    { 0x311B, "consumables_pre_irish_luck_usage" },
    { 0x311C, "consumables_used" },
    { 0x311D, "consume_from_inventory" },
    { 0x311E, "consumepowerovertime" },
    { 0x311F, "contact_pos" },
    { 0x3120, "contacts_animatedenemydeathlogic" },
    { 0x3121, "contacts_animatedenemylogic" },
    { 0x3122, "contacts_animatedenemyreactlogic" },
    { 0x3123, "contacts_dialoguelogic" },
    { 0x3124, "contacts_enemyinvestigatorlogic" },
    { 0x3125, "contacts_farahalertedbyproximitylogic" },
    { 0x3126, "contacts_farahkillremainingenemieslogic" },
    { 0x3127, "contacts_farahpushplayerlogic" },
    { 0x3128, "contacts_getfarahnode" },
    { 0x3129, "contacts_getholetrigger" },
    { 0x312A, "contacts_getinteriortrigger" },
    { 0x312B, "contacts_guardsalertedlogic" },
    { 0x312C, "contacts_main" },
    { 0x312D, "contacts_playerspottedenemieslogic" },
    { 0x312E, "contacts_scenelogic" },
    { 0x312F, "contacts_setupanimateddesk" },
    { 0x3130, "contacts_spawnanimatedenemy" },
    { 0x3131, "contacts_spawnenemies" },
    { 0x3132, "contacts_spawnstealthbrokenenemies" },
    { 0x3133, "contacts_start" },
    { 0x3134, "container_getallypaths" },
    { 0x3135, "container_nodes" },
    { 0x3136, "containers_gate_main" },
    { 0x3137, "containers_gate_start" },
    { 0x3138, "containers_start" },
    { 0x3139, "containers_truck_catchup" },
    { 0x313A, "containers_truck_main" },
    { 0x313B, "containers_truck_start" },
    { 0x313C, "containing_regions" },
    { 0x313D, "containment_civambush" },
    { 0x313E, "containment_civambush_teleport" },
    { 0x313F, "containment_groundfloor" },
    { 0x3140, "containment_groundfloor_teleport" },
    { 0x3141, "containment_init" },
    { 0x3142, "containment_mghall" },
    { 0x3143, "containment_mghall_teleport" },
    { 0x3144, "containment_start" },
    { 0x3145, "containment_wolf" },
    { 0x3146, "containment_wolf_fail_monitor" },
    { 0x3147, "containment_wolf_warn_monitor" },
    { 0x3148, "content_warning_ui" },
    { 0x3149, "contentoverride" },
    { 0x314A, "contents" },
    { 0x314B, "contested" },
    { 0x314C, "contestedbrush" },
    { 0x314D, "contestedzonebrushes" },
    { 0x314E, "context" },
    { 0x314F, "context_melee_allow" },
    { 0x3150, "context_melee_allow_blocked_hint" },
    { 0x3151, "context_melee_allow_directions" },
    { 0x3152, "context_melee_allowed" },
    { 0x3153, "context_melee_angles" },
    { 0x3154, "context_melee_anim" },
    { 0x3155, "context_melee_anim_name" },
    { 0x3156, "context_melee_animation" },
    { 0x3157, "context_melee_back_dot_override" },
    { 0x3158, "context_melee_blocked_hint_allowed" },
    { 0x3159, "context_melee_cansee" },
    { 0x315A, "context_melee_clear_blocked_custom_hint" },
    { 0x315B, "context_melee_clear_custom_hint" },
    { 0x315C, "context_melee_collision_offset" },
    { 0x315D, "context_melee_combat_buffer" },
    { 0x315E, "context_melee_combatsight_buffer" },
    { 0x315F, "context_melee_combatsight_lastime" },
    { 0x3160, "context_melee_cursor_hint_blocked" },
    { 0x3161, "context_melee_cursor_hint_create" },
    { 0x3162, "context_melee_cursor_hint_remove" },
    { 0x3163, "context_melee_death" },
    { 0x3164, "context_melee_direction" },
    { 0x3165, "context_melee_do_launch" },
    { 0x3166, "context_melee_enable" },
    { 0x3167, "context_melee_enabled" },
    { 0x3168, "context_melee_eye_height_crouch" },
    { 0x3169, "context_melee_eye_height_stand" },
    { 0x316A, "context_melee_fail_attempts" },
    { 0x316B, "context_melee_fx" },
    { 0x316C, "context_melee_has_been_enabled" },
    { 0x316D, "context_melee_has_enemy" },
    { 0x316E, "context_melee_hint" },
    { 0x316F, "context_melee_hint_blocked" },
    { 0x3170, "context_melee_hint_blocked_custom" },
    { 0x3171, "context_melee_hint_break" },
    { 0x3172, "context_melee_hint_custom" },
    { 0x3173, "context_melee_hint_ent" },
    { 0x3174, "context_melee_hint_ent_set" },
    { 0x3175, "context_melee_hint_fail" },
    { 0x3176, "context_melee_hint_not_allowed" },
    { 0x3177, "context_melee_hint_scripted_fail" },
    { 0x3178, "context_melee_hint_scripted_noweap" },
    { 0x3179, "context_melee_hinted" },
    { 0x317A, "context_melee_kill_origin" },
    { 0x317B, "context_melee_knife" },
    { 0x317C, "context_melee_last_active_time" },
    { 0x317D, "context_melee_last_inactive_time" },
    { 0x317E, "context_melee_last_melee_finish_time" },
    { 0x317F, "context_melee_lastframe_bone" },
    { 0x3180, "context_melee_lastframe_type" },
    { 0x3181, "context_melee_launch" },
    { 0x3182, "context_melee_launching" },
    { 0x3183, "context_melee_next" },
    { 0x3184, "context_melee_og_allowdeath" },
    { 0x3185, "context_melee_og_animname" },
    { 0x3186, "context_melee_og_battlechatter" },
    { 0x3187, "context_melee_og_maxsightdistsqrd" },
    { 0x3188, "context_melee_og_newenemyreactiondistsq" },
    { 0x3189, "context_melee_origin" },
    { 0x318A, "context_melee_override_anim" },
    { 0x318B, "context_melee_player_link_bone" },
    { 0x318C, "context_melee_ragdoll" },
    { 0x318D, "context_melee_rumble_heavy" },
    { 0x318E, "context_melee_rumble_light" },
    { 0x318F, "context_melee_scripted_enemy_guess" },
    { 0x3190, "context_melee_set_arms" },
    { 0x3191, "context_melee_set_blocked_custom_hint" },
    { 0x3192, "context_melee_set_custom_hint" },
    { 0x3193, "context_melee_set_hint_directions" },
    { 0x3194, "context_melee_set_lastframe_bone" },
    { 0x3195, "context_melee_set_lastframe_type" },
    { 0x3196, "context_melee_set_silent_kill" },
    { 0x3197, "context_melee_set_weapon" },
    { 0x3198, "context_melee_sfx" },
    { 0x3199, "context_melee_sfx_player" },
    { 0x319A, "context_melee_sight_buffer" },
    { 0x319B, "context_melee_sight_disabled" },
    { 0x319C, "context_melee_victim" },
    { 0x319D, "context_melee_victim_lives" },
    { 0x319E, "context_melee_waittill_player_finished" },
    { 0x319F, "context_sensative_dialog" },
    { 0x31A0, "context_sensative_dialog_filler" },
    { 0x31A1, "context_sensative_dialog_guy_crawling" },
    { 0x31A2, "context_sensative_dialog_guy_in_sight" },
    { 0x31A3, "context_sensative_dialog_guy_in_sight_check" },
    { 0x31A4, "context_sensative_dialog_guy_pain" },
    { 0x31A5, "context_sensative_dialog_kill" },
    { 0x31A6, "context_sensative_dialog_kill_thread" },
    { 0x31A7, "context_sensative_dialog_locations" },
    { 0x31A8, "context_sensative_dialog_locations_add_notify_event" },
    { 0x31A9, "context_sensative_dialog_locations_thread" },
    { 0x31AA, "context_sensative_dialog_play_random_group_sound" },
    { 0x31AB, "context_sensative_dialog_secondary_explosion_vehicle" },
    { 0x31AC, "context_sensative_dialog_timedout" },
    { 0x31AD, "context_sensative_dialog_timeouts" },
    { 0x31AE, "context_sensative_dialog_vehicledeath" },
    { 0x31AF, "context_sensative_dialog_vehiclespawn" },
    { 0x31B0, "contextmeleeactive" },
    { 0x31B1, "contextualwalltraversals" },
    { 0x31B2, "continue_interaction" },
    { 0x31B3, "continue_interactions" },
    { 0x31B4, "continue_reminders" },
    { 0x31B5, "continue_to_push_monitor" },
    { 0x31B6, "continuous_stabs" },
    { 0x31B7, "contour_point" },
    { 0x31B8, "contracts" },
    { 0x31B9, "control" },
    { 0x31BA, "control_marine_movement_at_ied" },
    { 0x31BB, "controler_hud_add" },
    { 0x31BC, "controler_hud_update_button" },
    { 0x31BD, "controler_hud_update_text" },
    { 0x31BE, "controlproxyagent" },
    { 0x31BF, "controlroomenterref" },
    { 0x31C0, "controlsfrozen" },
    { 0x31C1, "controltoprogress" },
    { 0x31C2, "converge_after_flag" },
    { 0x31C3, "converge_curtime" },
    { 0x31C4, "converge_laserofftime" },
    { 0x31C5, "converge_locked_on_time" },
    { 0x31C6, "converge_missinnerradius" },
    { 0x31C7, "converge_missouterradius" },
    { 0x31C8, "converge_offsetdir" },
    { 0x31C9, "converge_on_players" },
    { 0x31CA, "converge_shoottime" },
    { 0x31CB, "converge_time" },
    { 0x31CC, "convergence" },
    { 0x31CD, "convergencetargettick" },
    { 0x31CE, "convert_aitruck_to_playertruck" },
    { 0x31CF, "convert_capsule_data" },
    { 0x31D0, "convert_color_to_short_string" },
    { 0x31D1, "convert_guy_to_drone" },
    { 0x31D2, "convert_selection_to_exploder" },
    { 0x31D3, "convert_surface_flag" },
    { 0x31D4, "convert_time_stamp_to_sec" },
    { 0x31D5, "convert_to_time_string" },
    { 0x31D6, "convertfrombinary" },
    { 0x31D7, "converttobinary" },
    { 0x31D8, "convertvar_toarray" },
    { 0x31D9, "convoy" },
    { 0x31DA, "convoy_ambush_catchup" },
    { 0x31DB, "convoy_ambush_explosion" },
    { 0x31DC, "convoy_ambush_main" },
    { 0x31DD, "convoy_ambush_start" },
    { 0x31DE, "convoy_apc_dialog_struct" },
    { 0x31DF, "convoy_apc_spawned_riders" },
    { 0x31E0, "convoy_attempt_pickup" },
    { 0x31E1, "convoy_board_pos" },
    { 0x31E2, "convoy_can_pickup" },
    { 0x31E3, "convoy_damage_monitor" },
    { 0x31E4, "convoy_damaged_tires" },
    { 0x31E5, "convoy_delay_attach" },
    { 0x31E6, "convoy_dialoguelogic" },
    { 0x31E7, "convoy_earlyambushstealthbrokenlogic" },
    { 0x31E8, "convoy_end_this_event" },
    { 0x31E9, "convoy_force_exit" },
    { 0x31EA, "convoy_getenemies" },
    { 0x31EB, "convoy_getspawners" },
    { 0x31EC, "convoy_getvehicles" },
    { 0x31ED, "convoy_getvehiclescovernodes" },
    { 0x31EE, "convoy_go_to_helidown_location" },
    { 0x31EF, "convoy_hud_text" },
    { 0x31F0, "convoy_hvt_squad_alive" },
    { 0x31F1, "convoy_hvt_struct" },
    { 0x31F2, "convoy_init" },
    { 0x31F3, "convoy_init_settings" },
    { 0x31F4, "convoy_intro_marine_anim" },
    { 0x31F5, "convoy_location_dialogue" },
    { 0x31F6, "convoy_main" },
    { 0x31F7, "convoy_movement_handler" },
    { 0x31F8, "convoy_obj_func" },
    { 0x31F9, "convoy_objectivestruct" },
    { 0x31FA, "convoy_path_jitter" },
    { 0x31FB, "convoy_path_number" },
    { 0x31FC, "convoy_paths_override" },
    { 0x31FD, "convoy_pickedup" },
    { 0x31FE, "convoy_pickup_hvt_settings" },
    { 0x31FF, "convoy_player_awareness" },
    { 0x3200, "convoy_proto_event" },
    { 0x3201, "convoy_proto_index" },
    { 0x3202, "convoy_proto_text" },
    { 0x3203, "convoy_proto_type" },
    { 0x3204, "convoy_resume_all_cars" },
    { 0x3205, "convoy_runners" },
    { 0x3206, "convoy_runners_handler" },
    { 0x3207, "convoy_send_out_after_hvt_onboard" },
    { 0x3208, "convoy_set_can_pickup_hvt" },
    { 0x3209, "convoy_set_helidown_pickup_hvt" },
    { 0x320A, "convoy_settings" },
    { 0x320B, "convoy_sfxlogic" },
    { 0x320C, "convoy_spawn" },
    { 0x320D, "convoy_spawnenemiesinvehicles" },
    { 0x320E, "convoy_spawnvehicles" },
    { 0x320F, "convoy_speed_override" },
    { 0x3210, "convoy_start" },
    { 0x3211, "convoy_start_1" },
    { 0x3212, "convoy_start_2" },
    { 0x3213, "convoy_start_2b" },
    { 0x3214, "convoy_start_3" },
    { 0x3215, "convoy_start_3b" },
    { 0x3216, "convoy_start_4" },
    { 0x3217, "convoy_start_4b" },
    { 0x3218, "convoy_start_5" },
    { 0x3219, "convoy_start_6" },
    { 0x321A, "convoy_steal_hvt_from_player_car" },
    { 0x321B, "convoy_stop_all_cars" },
    { 0x321C, "convoy_think_handler" },
    { 0x321D, "convoy_tripwire_monitor" },
    { 0x321E, "convoy_tripwire_nag_handler" },
    { 0x321F, "convoy_unloadanimatedenemylogic" },
    { 0x3220, "convoy_unloadenemylogic" },
    { 0x3221, "convoy_update_label_to_loot_num" },
    { 0x3222, "convoy_vehicle_monitor" },
    { 0x3223, "convoy_vehicle_passenger_handler" },
    { 0x3224, "convoy_vehiclealertedspeeduplogic" },
    { 0x3225, "convoy_vehicledriverdeathlogic" },
    { 0x3226, "convoy_vehiclepathlogic" },
    { 0x3227, "convoy_vehicleslogic" },
    { 0x3228, "convoy_vehiclesunloadlogic" },
    { 0x3229, "convoy_wait_for_pulses" },
    { 0x322A, "convoy4_ac130" },
    { 0x322B, "convoy4_ac130_player" },
    { 0x322C, "convoy4_buildings_secure" },
    { 0x322D, "convoy4_comms_laptop_int_struct" },
    { 0x322E, "convoy4_comms_laptop_sn" },
    { 0x322F, "convoy4_failed_calltrain" },
    { 0x3230, "convoy4_hostage" },
    { 0x3231, "convoy4_module_02a" },
    { 0x3232, "convoy4_module_02a_pre" },
    { 0x3233, "convoy4_module_02b" },
    { 0x3234, "convoy4_module_02b_pre" },
    { 0x3235, "convoy4_module_02b2" },
    { 0x3236, "convoy4_module_02b2_pre" },
    { 0x3237, "convoy4_module_02c" },
    { 0x3238, "convoy4_module_02c_bomber" },
    { 0x3239, "convoy4_module_02c_pre" },
    { 0x323A, "convoy4_module_03a" },
    { 0x323B, "convoy4_module_03b" },
    { 0x323C, "convoy4_module_04a_1" },
    { 0x323D, "convoy4_module_04a_2" },
    { 0x323E, "convoy4_module_04a_3" },
    { 0x323F, "convoy4_module_hostage" },
    { 0x3240, "convoy4_module_juggs_1" },
    { 0x3241, "convoy4_module_juggs_2" },
    { 0x3242, "convoy4_module_juggs_3" },
    { 0x3243, "convoy4_module_roofs" },
    { 0x3244, "convoy4_module_roofs2" },
    { 0x3245, "convoy4_module_smugg_1" },
    { 0x3246, "convoy4_modules_01" },
    { 0x3247, "convoy4_modules_pesants" },
    { 0x3248, "convoy4_objective_func" },
    { 0x3249, "convoy4_startobj_index_1" },
    { 0x324A, "convoy4_startobj_index_2" },
    { 0x324B, "convoy4_startobj_index_3" },
    { 0x324C, "convoy4_terminal_keys" },
    { 0x324D, "convoy4_train" },
    { 0x324E, "convoy4_train_c4objs" },
    { 0x324F, "convoy4_train_c4s" },
    { 0x3250, "convoy4_train_doors" },
    { 0x3251, "convoy4_train_follow" },
    { 0x3252, "convoy4_train_trackers" },
    { 0x3253, "convoy4_vo_hacks" },
    { 0x3254, "convoy4_vo_keys" },
    { 0x3255, "convoy4_vo_nag_hacks" },
    { 0x3256, "convoy4_vo_searches" },
    { 0x3257, "convoyescort_interaction" },
    { 0x3258, "convoyescort_obj_func" },
    { 0x3259, "convtime" },
    { 0x325A, "cool_circle" },
    { 0x325B, "cooldown" },
    { 0x325C, "cooldown_munition" },
    { 0x325D, "cooldown_override" },
    { 0x325E, "cooldown_progress" },
    { 0x325F, "cooldowncounter" },
    { 0x3260, "cooldownleft" },
    { 0x3261, "cooldownpatrolpoint" },
    { 0x3262, "cooldownratemod" },
    { 0x3263, "cooldownsqueued" },
    { 0x3264, "cooldowntime" },
    { 0x3265, "cooldownwaittime" },
    { 0x3266, "cooling_down" },
    { 0x3267, "coop_bomb_defusal_count_down_started" },
    { 0x3268, "coop_bomb_defusal_fail" },
    { 0x3269, "coop_bomb_defusal_success" },
    { 0x326A, "coop_gameshouldend" },
    { 0x326B, "coop_gameshouldendfunc" },
    { 0x326C, "coop_getweaponclass" },
    { 0x326D, "coop_interaction_pregame" },
    { 0x326E, "coop_maydolaststand" },
    { 0x326F, "coop_mode_enable" },
    { 0x3270, "coop_mode_feature" },
    { 0x3271, "coop_mode_has" },
    { 0x3272, "coop_perk_callbacks" },
    { 0x3273, "coop_stealth_init" },
    { 0x3274, "coop_vehicle_race_success" },
    { 0x3275, "coop_weapontable" },
    { 0x3276, "coopspawning_init" },
    { 0x3277, "coopstartgametype" },
    { 0x3278, "coopvehicles_init" },
    { 0x3279, "cop_car_cp_create" },
    { 0x327A, "cop_car_cp_createfromstructs" },
    { 0x327B, "cop_car_cp_delete" },
    { 0x327C, "cop_car_cp_getspawnstructscallback" },
    { 0x327D, "cop_car_cp_init" },
    { 0x327E, "cop_car_cp_initlate" },
    { 0x327F, "cop_car_cp_initspawning" },
    { 0x3280, "cop_car_cp_ondeathrespawncallback" },
    { 0x3281, "cop_car_cp_spawncallback" },
    { 0x3282, "cop_car_cp_waitandspawn" },
    { 0x3283, "cop_car_create" },
    { 0x3284, "cop_car_deathcallback" },
    { 0x3285, "cop_car_deletenextframe" },
    { 0x3286, "cop_car_enterend" },
    { 0x3287, "cop_car_enterendinternal" },
    { 0x3288, "cop_car_exitend" },
    { 0x3289, "cop_car_exitendinternal" },
    { 0x328A, "cop_car_explode" },
    { 0x328B, "cop_car_getspawnstructscallback" },
    { 0x328C, "cop_car_init" },
    { 0x328D, "cop_car_initfx" },
    { 0x328E, "cop_car_initinteract" },
    { 0x328F, "cop_car_initlate" },
    { 0x3290, "cop_car_initoccupancy" },
    { 0x3291, "cop_car_initspawning" },
    { 0x3292, "cop_car_mp_create" },
    { 0x3293, "cop_car_mp_delete" },
    { 0x3294, "cop_car_mp_getspawnstructscallback" },
    { 0x3295, "cop_car_mp_init" },
    { 0x3296, "cop_car_mp_initmines" },
    { 0x3297, "cop_car_mp_initspawning" },
    { 0x3298, "cop_car_mp_ondeathrespawncallback" },
    { 0x3299, "cop_car_mp_spawncallback" },
    { 0x329A, "cop_car_mp_waitandspawn" },
    { 0x329B, "copcars" },
    { 0x329C, "copilot" },
    { 0x329D, "cops_die" },
    { 0x329E, "cops_lead_to_underground_right" },
    { 0x329F, "copterdeathwatcher" },
    { 0x32A0, "copterhealthwatcher" },
    { 0x32A1, "copterpath" },
    { 0x32A2, "copy_all_powers" },
    { 0x32A3, "copy_angles_of_selected_ents" },
    { 0x32A4, "copy_crafting_struct" },
    { 0x32A5, "copy_ents" },
    { 0x32A6, "copy_from_level_struct" },
    { 0x32A7, "copy_from_playerdata" },
    { 0x32A8, "copy_fullweaponlist" },
    { 0x32A9, "copy_names" },
    { 0x32AA, "copy_path_struct_at_new_pos" },
    { 0x32AB, "copy_special_ammo_type" },
    { 0x32AC, "copy_to_soldier_from_spawn_point" },
    { 0x32AD, "copy_vehicle_build_to_spawnpoint" },
    { 0x32AE, "copy_weapon_ammo_clip" },
    { 0x32AF, "copy_weapon_ammo_clip_left" },
    { 0x32B0, "copy_weapon_ammo_stock" },
    { 0x32B1, "copy_weapon_current" },
    { 0x32B2, "copy_weapon_level" },
    { 0x32B3, "copyclassfornextlife" },
    { 0x32B4, "copystructwithoffset" },
    { 0x32B5, "copyvehiclespawndata" },
    { 0x32B6, "core_events" },
    { 0x32B7, "core_health_regen" },
    { 0x32B8, "corner_redshirts" },
    { 0x32B9, "corner_wall_kill_player" },
    { 0x32BA, "cornerarray" },
    { 0x32BB, "cornerchecknode" },
    { 0x32BC, "cornerchecknodestarttime" },
    { 0x32BD, "cornerdeathreleasegrenade" },
    { 0x32BE, "cornerline_height" },
    { 0x32BF, "cornermode" },
    { 0x32C0, "cornerrightgrenadedeath" },
    { 0x32C1, "cornersights" },
    { 0x32C2, "cornerstepoutsdisabled" },
    { 0x32C3, "corpse" },
    { 0x32C4, "corpse_anim_hack" },
    { 0x32C5, "corpse_check_shadow" },
    { 0x32C6, "corpse_cleanup" },
    { 0x32C7, "corpse_clear" },
    { 0x32C8, "corpse_found" },
    { 0x32C9, "corpse_init_entity" },
    { 0x32CA, "corpse_init_level" },
    { 0x32CB, "corpse_is_too_far_away" },
    { 0x32CC, "corpse_nexttime" },
    { 0x32CD, "corpse_seen" },
    { 0x32CE, "corpse_seen_claim" },
    { 0x32CF, "corpse_sight" },
    { 0x32D0, "corpse_weapon_pos" },
    { 0x32D1, "corpse_world_pos" },
    { 0x32D2, "corpselootthink" },
    { 0x32D3, "corpses" },
    { 0x32D4, "corpsetablefunccounts" },
    { 0x32D5, "corpsetablefuncs" },
    { 0x32D6, "correct_alias" },
    { 0x32D7, "cos10" },
    { 0x32D8, "cos15" },
    { 0x32D9, "cos30" },
    { 0x32DA, "cos60" },
    { 0x32DB, "cosine" },
    { 0x32DC, "cost" },
    { 0x32DD, "costomnvars" },
    { 0x32DE, "couldntseeenemypos" },
    { 0x32DF, "count_total" },
    { 0x32E0, "countdown_end" },
    { 0x32E1, "countdown_start" },
    { 0x32E2, "countdownhudpulse" },
    { 0x32E3, "counted" },
    { 0x32E4, "counter" },
    { 0x32E5, "counter_black_fade" },
    { 0x32E6, "counter_hit_effects" },
    { 0x32E7, "counterblackoverlay" },
    { 0x32E8, "counterhintdestroy" },
    { 0x32E9, "countersuccess" },
    { 0x32EA, "counteruavrig" },
    { 0x32EB, "countplayers" },
    { 0x32EC, "countryid" },
    { 0x32ED, "countryids" },
    { 0x32EE, "counts" },
    { 0x32EF, "countteammates" },
    { 0x32F0, "course_accuracy" },
    { 0x32F1, "course_movers" },
    { 0x32F2, "course_start_wait" },
    { 0x32F3, "course_targets" },
    { 0x32F4, "course_triggers" },
    { 0x32F5, "courtyard_bomber" },
    { 0x32F6, "courtyard_defender_spawnfunc" },
    { 0x32F7, "courtyard_mid_catchup" },
    { 0x32F8, "courtyard_retreat_catchup" },
    { 0x32F9, "courtyard_retreat_main" },
    { 0x32FA, "courtyard_retreat_start" },
    { 0x32FB, "courtyardbreachref" },
    { 0x32FC, "courtyarddefendgroup" },
    { 0x32FD, "courtyarddoorleft" },
    { 0x32FE, "courtyarddoorright" },
    { 0x32FF, "courytard_retreat_enemy_kill_at_fallback" },
    { 0x3300, "cover_canattackfromexposed" },
    { 0x3301, "cover_canattackfromexposedcached" },
    { 0x3302, "cover_canattackfromexposedgetcache" },
    { 0x3303, "cover_getplayerinteract" },
    { 0x3304, "cover_main" },
    { 0x3305, "cover_node_spawners" },
    { 0x3306, "cover_node_spawners_override" },
    { 0x3307, "cover_node_spawners_override_id" },
    { 0x3308, "cover_nodes" },
    { 0x3309, "cover_nodes_first" },
    { 0x330A, "cover_nodes_last" },
    { 0x330B, "cover_playerflashbanglogic" },
    { 0x330C, "cover_shouldlookforbettercover" },
    { 0x330D, "cover_spawnenemies" },
    { 0x330E, "cover_start" },
    { 0x330F, "cover3dcanexposedir" },
    { 0x3310, "cover3dexposedirpicked" },
    { 0x3311, "cover3dpickexposedir" },
    { 0x3312, "coverblindfire" },
    { 0x3313, "coverchangestance" },
    { 0x3314, "covercrouchlean_aimmode" },
    { 0x3315, "covercrouchleanpitch" },
    { 0x3316, "covercrouchtype" },
    { 0x3317, "coverexit" },
    { 0x3318, "coverexitangles" },
    { 0x3319, "coverexitdist" },
    { 0x331A, "coverexitpostdist" },
    { 0x331B, "coverexpose" },
    { 0x331C, "coverexposelostenemytime" },
    { 0x331D, "coverexposenewtargettime" },
    { 0x331E, "coverexposenoenemy" },
    { 0x331F, "coverexposenoenemyangle" },
    { 0x3320, "coverexposenoenemytimemax" },
    { 0x3321, "coverexposenoenemytimemin" },
    { 0x3322, "coverexppainselectreturna" },
    { 0x3323, "coverhide" },
    { 0x3324, "coverlmgterminate" },
    { 0x3325, "coverlook" },
    { 0x3326, "covermode" },
    { 0x3327, "covermultiswitch" },
    { 0x3328, "covermultiswitchdata" },
    { 0x3329, "coverpeek" },
    { 0x332A, "coverpose_request" },
    { 0x332B, "coverreload" },
    { 0x332C, "coversetupanim" },
    { 0x332D, "covershoot" },
    { 0x332E, "covershootpoints" },
    { 0x332F, "covershouldexpose" },
    { 0x3330, "covershouldexposelostenemy" },
    { 0x3331, "covershouldexposenoenemy" },
    { 0x3332, "covertest" },
    { 0x3333, "coverthrowgrenade" },
    { 0x3334, "covertrans" },
    { 0x3335, "covertransangles" },
    { 0x3336, "covertransdist" },
    { 0x3337, "covertranslongestdist" },
    { 0x3338, "covertranspredist" },
    { 0x3339, "coverturretterminate" },
    { 0x333A, "coward_buddy_whisper" },
    { 0x333B, "coward_monitor_if_player_is_close" },
    { 0x333C, "coward_monitor_if_player_look_at" },
    { 0x333D, "coward_monitor_if_player_shot_at" },
    { 0x333E, "cowering" },
    { 0x333F, "cp_3_doors_scene" },
    { 0x3340, "cp_3_enemy" },
    { 0x3341, "cp_3_enemy_setup" },
    { 0x3342, "cp_5_fastforward_anim" },
    { 0x3343, "cp_5_redshirt_die" },
    { 0x3344, "cp_add_dialogue_line" },
    { 0x3345, "cp_blockade_spawning" },
    { 0x3346, "cp_br_syrk_tutorial_dialogue" },
    { 0x3347, "cp_destroy_dialogue_hud" },
    { 0x3348, "cp_donetsk_spawning" },
    { 0x3349, "cp_fake_stealth" },
    { 0x334A, "cp_get_spot_by_priority" },
    { 0x334B, "cp_infil_player_allow" },
    { 0x334C, "cp_kidnappers_active" },
    { 0x334D, "cp_mapbounds" },
    { 0x334E, "cp_matchdata" },
    { 0x334F, "cp_player_free_spot" },
    { 0x3350, "cp_player_join_infil_cp" },
    { 0x3351, "cp_relics" },
    { 0x3352, "cp_speed" },
    { 0x3353, "cp_struct_filter" },
    { 0x3354, "cp_suicidebomber_init" },
    { 0x3355, "cp_vehicle_debug" },
    { 0x3356, "cp_weapon_passives" },
    { 0x3357, "cp_weapons_init" },
    { 0x3358, "cp_weapontable" },
    { 0x3359, "cp_zmb_number_of_quest_pieces" },
    { 0x335A, "cpcrateactivatecallback" },
    { 0x335B, "cpcratecapturecallback" },
    { 0x335C, "cploadoutcrateactivatecallback" },
    { 0x335D, "cploadoutcratecapturecallback" },
    { 0x335E, "cpm" },
    { 0x335F, "cponplayerdisconnectinfil" },
    { 0x3360, "cpu_manifest1_idx" },
    { 0x3361, "cqb_aim" },
    { 0x3362, "cqb_marines_movement_monitor" },
    { 0x3363, "cqb_module" },
    { 0x3364, "cqb_player_movement_monitor" },
    { 0x3365, "cqb_point_of_interest" },
    { 0x3366, "cqb_target" },
    { 0x3367, "cqb_walk" },
    { 0x3368, "cqb_when_in_range" },
    { 0x3369, "cqb_wide_poi_track" },
    { 0x336A, "cqb_wide_target_track" },
    { 0x336B, "cqbenabled" },
    { 0x336C, "cqbpointsofinterest" },
    { 0x336D, "cqbtargetendtime" },
    { 0x336E, "cqbtargetnexttwitchtime" },
    { 0x336F, "cqbtargettime" },
    { 0x3370, "cqbtwitchdir" },
    { 0x3371, "cqbtwitchend" },
    { 0x3372, "cqbtwitching" },
    { 0x3373, "cqbtwitchstate" },
    { 0x3374, "craft_scout_drone" },
    { 0x3375, "craftable_weapons" },
    { 0x3376, "crafteditem" },
    { 0x3377, "crafteditemindex" },
    { 0x3378, "crafteditemmodel" },
    { 0x3379, "crafteditempowerreference" },
    { 0x337A, "crafteditemsanimdata" },
    { 0x337B, "crafteditemslist" },
    { 0x337C, "crafteditemstruct" },
    { 0x337D, "crafteditemtype" },
    { 0x337E, "crafting_icon_create_func" },
    { 0x337F, "crafting_materials" },
    { 0x3380, "crafting_remove_func" },
    { 0x3381, "crafting_table_data" },
    { 0x3382, "cranked" },
    { 0x3383, "cranked_end_time" },
    { 0x3384, "crankedbombtimer" },
    { 0x3385, "crash_deathfx" },
    { 0x3386, "crash_dialoguelogic" },
    { 0x3387, "crash_fall_remove_fov_scale_factor_override" },
    { 0x3388, "crash_getanimationstruct" },
    { 0x3389, "crash_hadiranimationlogic" },
    { 0x338A, "crash_main" },
    { 0x338B, "crash_playeranimationlogic" },
    { 0x338C, "crash_speed" },
    { 0x338D, "crash_start" },
    { 0x338E, "crash_start_point" },
    { 0x338F, "crashed" },
    { 0x3390, "crashed_nuke_interaction" },
    { 0x3391, "crashforward" },
    { 0x3392, "crashorigin" },
    { 0x3393, "crashpathused" },
    { 0x3394, "crate" },
    { 0x3395, "crate_calculate_on_path_grid" },
    { 0x3396, "crate_can_use" },
    { 0x3397, "crate_can_use_always" },
    { 0x3398, "crate_drop_time" },
    { 0x3399, "crate_get_bot_target" },
    { 0x339A, "crate_get_bot_target_check_distance" },
    { 0x339B, "crate_get_nearest_valid_nodes" },
    { 0x339C, "crate_has_landed" },
    { 0x339D, "crate_in_range" },
    { 0x339E, "crate_interaction" },
    { 0x339F, "crate_is_on_path_grid" },
    { 0x33A0, "crate_landed_and_on_path_grid" },
    { 0x33A1, "crate_low_ammo_check" },
    { 0x33A2, "crate_monitor_position" },
    { 0x33A3, "crate_picked_up" },
    { 0x33A4, "crate_random_weapons" },
    { 0x33A5, "crate_should_claim" },
    { 0x33A6, "crate_wait_use" },
    { 0x33A7, "crateallcapturethink" },
    { 0x33A8, "crateanimdroptime" },
    { 0x33A9, "crateballoondeath" },
    { 0x33AA, "crateballoonrise" },
    { 0x33AB, "cratebankplunder" },
    { 0x33AC, "cratedata" },
    { 0x33AD, "cratedropdata" },
    { 0x33AE, "cratedropplunder" },
    { 0x33AF, "cratedroptime" },
    { 0x33B0, "cratedroptimer" },
    { 0x33B1, "crateendtime" },
    { 0x33B2, "cratefall" },
    { 0x33B3, "crateguard_bosssetup" },
    { 0x33B4, "crateguard_encounterstart" },
    { 0x33B5, "crateguard_getspawneraitype" },
    { 0x33B6, "crateheadicon" },
    { 0x33B7, "crateiconid" },
    { 0x33B8, "crateid" },
    { 0x33B9, "crateimpactsound" },
    { 0x33BA, "cratekill" },
    { 0x33BB, "cratemantle" },
    { 0x33BC, "cratemodel" },
    { 0x33BD, "cratenonownerusetime" },
    { 0x33BE, "crateownerusetime" },
    { 0x33BF, "crates" },
    { 0x33C0, "crates_active_at_location" },
    { 0x33C1, "cratesetupforuse" },
    { 0x33C2, "cratestoptrailtime" },
    { 0x33C3, "cratethink" },
    { 0x33C4, "cratetype" },
    { 0x33C5, "crateunresolvedcollisioncallback" },
    { 0x33C6, "cratewatcher" },
    { 0x33C7, "crawl_farahlogic" },
    { 0x33C8, "crawl_fx" },
    { 0x33C9, "crawl_fx_rate" },
    { 0x33CA, "crawl_getenemies" },
    { 0x33CB, "crawl_getfarahanimationorigin" },
    { 0x33CC, "crawl_getied" },
    { 0x33CD, "crawl_getpronehinttrigger" },
    { 0x33CE, "crawl_gettriggers" },
    { 0x33CF, "crawl_hint_vo" },
    { 0x33D0, "crawl_main" },
    { 0x33D1, "crawl_nags" },
    { 0x33D2, "crawl_node_reveal" },
    { 0x33D3, "crawl_playerspeedscalinglogic" },
    { 0x33D4, "crawl_pronehinttriggerlogic" },
    { 0x33D5, "crawl_spawnenemy" },
    { 0x33D6, "crawl_spawnied" },
    { 0x33D7, "crawl_start" },
    { 0x33D8, "crawl_targets_init_flags" },
    { 0x33D9, "crawl_triggerlogic" },
    { 0x33DA, "crawled" },
    { 0x33DB, "crawlers" },
    { 0x33DC, "crawlingpain" },
    { 0x33DD, "crawlingpainanimoverridefunc" },
    { 0x33DE, "crawlingpaintransanim" },
    { 0x33DF, "crawlingpistol" },
    { 0x33E0, "crawlmelee" },
    { 0x33E1, "crawlmeleegrab" },
    { 0x33E2, "crawlnode" },
    { 0x33E3, "create_2d_background" },
    { 0x33E4, "create_2d_text" },
    { 0x33E5, "create_a_rider" },
    { 0x33E6, "create_ai_plr_vehicle" },
    { 0x33E7, "create_aim_contents" },
    { 0x33E8, "create_aiment" },
    { 0x33E9, "create_ainoshoot_contents" },
    { 0x33EA, "create_ainosight_contents" },
    { 0x33EB, "create_airdrop_spawn_structs" },
    { 0x33EC, "create_all_contents" },
    { 0x33ED, "create_and_update_box" },
    { 0x33EE, "create_and_validate_node" },
    { 0x33EF, "create_and_validate_node_from_single_grid_point" },
    { 0x33F0, "create_anim_scene" },
    { 0x33F1, "create_array_of_intel_items" },
    { 0x33F2, "create_array_of_origins_from_table" },
    { 0x33F3, "create_attachment_variant_list" },
    { 0x33F4, "create_background" },
    { 0x33F5, "create_backyard_aimpath" },
    { 0x33F6, "create_bleedout_objective_timer" },
    { 0x33F7, "create_blend" },
    { 0x33F8, "create_blood_decal" },
    { 0x33F9, "create_bomb" },
    { 0x33FA, "create_box" },
    { 0x33FB, "create_breadcrumb_for_player" },
    { 0x33FC, "create_breadcrumb_for_team" },
    { 0x33FD, "create_camera_position_list" },
    { 0x33FE, "create_character_contents" },
    { 0x33FF, "create_client_overlay" },
    { 0x3400, "create_client_overlay_custom_size" },
    { 0x3401, "create_client_overlay_fullscreen" },
    { 0x3402, "create_computer_interaction" },
    { 0x3403, "create_contents" },
    { 0x3404, "create_convoy_truck" },
    { 0x3405, "create_copy" },
    { 0x3406, "create_corpses" },
    { 0x3407, "create_cover_node_init" },
    { 0x3408, "create_cover_nodes_from_grid_point" },
    { 0x3409, "create_cover_nodes_from_grid_points" },
    { 0x340A, "create_cover_nodes_from_single_grid_point" },
    { 0x340B, "create_cover_nodes_within_volume" },
    { 0x340C, "create_cursor_hint" },
    { 0x340D, "create_cut_interaction" },
    { 0x340E, "create_cut_interactions" },
    { 0x340F, "create_death_hudelem" },
    { 0x3410, "create_debug_hud_line" },
    { 0x3411, "create_deck" },
    { 0x3412, "create_default_contents" },
    { 0x3413, "create_default_struct" },
    { 0x3414, "create_deposit_box_interaction" },
    { 0x3415, "create_dialog_struct" },
    { 0x3416, "create_direct_heli_path" },
    { 0x3417, "create_direct_path_from_landing_point" },
    { 0x3418, "create_door" },
    { 0x3419, "create_door_clip" },
    { 0x341A, "create_drone" },
    { 0x341B, "create_drone_model" },
    { 0x341C, "create_dummy_defender" },
    { 0x341D, "create_dyndof" },
    { 0x341E, "create_empty_func_ref" },
    { 0x341F, "create_entrance_points" },
    { 0x3420, "create_escort_health_objective" },
    { 0x3421, "create_exfil_interaction" },
    { 0x3422, "create_exposed_node" },
    { 0x3423, "create_extra_structpath" },
    { 0x3424, "create_fake_loot" },
    { 0x3425, "create_feedback_context" },
    { 0x3426, "create_feedback_endfunc" },
    { 0x3427, "create_feedback_endfunc_thread" },
    { 0x3428, "create_feedback_starts" },
    { 0x3429, "create_final_hack_spot_interaction" },
    { 0x342A, "create_flags_and_return_tokens" },
    { 0x342B, "create_fly_cam" },
    { 0x342C, "create_friendly_convoy_vehicle" },
    { 0x342D, "create_fulton_group_interactions" },
    { 0x342E, "create_func_ref" },
    { 0x342F, "create_fx_menu" },
    { 0x3430, "create_fxlighting_object" },
    { 0x3431, "create_glass_contents" },
    { 0x3432, "create_graycard_object" },
    { 0x3433, "create_grid_point" },
    { 0x3434, "create_grid_point_in_volume" },
    { 0x3435, "create_grid_point_new" },
    { 0x3436, "create_group_interaction_linebook" },
    { 0x3437, "create_head_icon_for_ai" },
    { 0x3438, "create_heli_path" },
    { 0x3439, "create_hostage_interact" },
    { 0x343A, "create_hudelem" },
    { 0x343B, "create_interaction_linebook" },
    { 0x343C, "create_interval_sound" },
    { 0x343D, "create_item_contents" },
    { 0x343E, "create_itemclip_contents" },
    { 0x343F, "create_juggernaut_damagedata" },
    { 0x3440, "create_key_card" },
    { 0x3441, "create_key_card_interaction" },
    { 0x3442, "create_level_funcs_tables_and_vars" },
    { 0x3443, "create_light_setting" },
    { 0x3444, "create_light_setting_bpg" },
    { 0x3445, "create_lock" },
    { 0x3446, "create_long_cut_interaction" },
    { 0x3447, "create_long_cut_interactions" },
    { 0x3448, "create_lookat_delay" },
    { 0x3449, "create_looper" },
    { 0x344A, "create_loopsound" },
    { 0x344B, "create_lua_progress_bar" },
    { 0x344C, "create_mantle" },
    { 0x344D, "create_mantle_hint" },
    { 0x344E, "create_mg_team" },
    { 0x344F, "create_mhc_path" },
    { 0x3450, "create_middle_ent" },
    { 0x3451, "create_missile_defense_camera_anchor" },
    { 0x3452, "create_missileattractor_on_player_chopper" },
    { 0x3453, "create_mod_damage_data_empty" },
    { 0x3454, "create_module_debug_struct" },
    { 0x3455, "create_module_struct" },
    { 0x3456, "create_molotov_take_deck" },
    { 0x3457, "create_motion_blur_defaults" },
    { 0x3458, "create_munition_change_points" },
    { 0x3459, "create_munitions_interaction" },
    { 0x345A, "create_myid_from_levelarray" },
    { 0x345B, "create_nag" },
    { 0x345C, "create_navobstacle" },
    { 0x345D, "create_new_projectile" },
    { 0x345E, "create_node_throttle" },
    { 0x345F, "create_node_trace" },
    { 0x3460, "create_not_drivable_player_vehicle" },
    { 0x3461, "create_not_driver_group" },
    { 0x3462, "create_objective" },
    { 0x3463, "create_objective_waypoint" },
    { 0x3464, "create_open_interact_hint" },
    { 0x3465, "create_paratrooper" },
    { 0x3466, "create_paratrooper_spawners" },
    { 0x3467, "create_path_data" },
    { 0x3468, "create_path_from_struct_to_struct" },
    { 0x3469, "create_path_to_delete_node" },
    { 0x346A, "create_player_rig" },
    { 0x346B, "create_player_threatbias_groups" },
    { 0x346C, "create_playerclip_contents" },
    { 0x346D, "create_priority_queue" },
    { 0x346E, "create_radius_around_point" },
    { 0x346F, "create_randomized_ambush_vehicle_group" },
    { 0x3470, "create_reflection_object" },
    { 0x3471, "create_reflection_objects" },
    { 0x3472, "create_scanning_camera_anchor" },
    { 0x3473, "create_script_file_ids" },
    { 0x3474, "create_seat_name_array" },
    { 0x3475, "create_shotclip_contents" },
    { 0x3476, "create_simple_path" },
    { 0x3477, "create_simple_vehicle_path_from_struct" },
    { 0x3478, "create_sniper_rifle_pickup" },
    { 0x3479, "create_solid_ai_contents" },
    { 0x347A, "create_sound_origin_at_eye" },
    { 0x347B, "create_spawn_scoring_struct" },
    { 0x347C, "create_spawn_structs_in_radius" },
    { 0x347D, "create_stair_doors" },
    { 0x347E, "create_start" },
    { 0x347F, "create_state_machine" },
    { 0x3480, "create_state_machine_for_ai" },
    { 0x3481, "create_sunflare_setting" },
    { 0x3482, "create_tag_origin" },
    { 0x3483, "create_trigger_based_on_charges" },
    { 0x3484, "create_triggerfx" },
    { 0x3485, "create_unique_kvp_string" },
    { 0x3486, "create_unload_nodes" },
    { 0x3487, "create_usable_c4_model" },
    { 0x3488, "create_usable_intel_model" },
    { 0x3489, "create_usable_key_model" },
    { 0x348A, "create_usable_laptop_model" },
    { 0x348B, "create_usable_model" },
    { 0x348C, "create_usb_pickup_interaction" },
    { 0x348D, "create_vehicle_builds" },
    { 0x348E, "create_vehicle_contents" },
    { 0x348F, "create_vehicle_interaction" },
    { 0x3490, "create_vehicle_path" },
    { 0x3491, "create_vent_mantle_hint" },
    { 0x3492, "create_vip_fulton_trigger" },
    { 0x3493, "create_vip_trigger" },
    { 0x3494, "create_visionset_stack" },
    { 0x3495, "create_vo_bucket" },
    { 0x3496, "create_vo_data" },
    { 0x3497, "create_waypoint" },
    { 0x3498, "create_weapon_in_script" },
    { 0x3499, "create_weapon_pickups" },
    { 0x349A, "create_world_contents" },
    { 0x349B, "create_zombie_base_to_unique_map" },
    { 0x349C, "createactivecontextualwalltraversal" },
    { 0x349D, "createart_transient_thread" },
    { 0x349E, "createballbase" },
    { 0x349F, "createbar" },
    { 0x34A0, "createbombzone" },
    { 0x34A1, "createboosttrigger" },
    { 0x34A2, "createboxforplayer" },
    { 0x34A3, "createbridgecapturesite" },
    { 0x34A4, "createbullet" },
    { 0x34A5, "createburnvfxpacket" },
    { 0x34A6, "createc130" },
    { 0x34A7, "createcalloutareaidmap" },
    { 0x34A8, "createcalloutdata" },
    { 0x34A9, "createcalloutmarker" },
    { 0x34AA, "createcamnode" },
    { 0x34AB, "createcaptureobjective" },
    { 0x34AC, "createcapzone" },
    { 0x34AD, "createcarriedobject" },
    { 0x34AE, "createcarryobject" },
    { 0x34AF, "createcarryremoteuav" },
    { 0x34B0, "createcenterimage" },
    { 0x34B1, "createchatevent" },
    { 0x34B2, "createchatphrase" },
    { 0x34B3, "createchuteforscripteddrop" },
    { 0x34B4, "createclientbar" },
    { 0x34B5, "createclientfontstring" },
    { 0x34B6, "createclientfontstring_func" },
    { 0x34B7, "createclienticon" },
    { 0x34B8, "createclientprogressbar" },
    { 0x34B9, "createclienttimer" },
    { 0x34BA, "createcluster" },
    { 0x34BB, "createcodcastermatchdataforplayer" },
    { 0x34BC, "createcrate" },
    { 0x34BD, "createcrateforscripteddrop" },
    { 0x34BE, "createcreditelem" },
    { 0x34BF, "createdangerzone" },
    { 0x34C0, "createdefaultcameras" },
    { 0x34C1, "createdevguientryforobjective" },
    { 0x34C2, "createdronestrikeheightpoint" },
    { 0x34C3, "createdropoffheli" },
    { 0x34C4, "createdropplayerhud" },
    { 0x34C5, "createdropweapon" },
    { 0x34C6, "createdropzones" },
    { 0x34C7, "createdynamicholduseobject" },
    { 0x34C8, "createechoalias" },
    { 0x34C9, "createeffect" },
    { 0x34CA, "createendzone" },
    { 0x34CB, "createendzoneobjective" },
    { 0x34CC, "createentityeventdata" },
    { 0x34CD, "createexploder" },
    { 0x34CE, "createexploderex" },
    { 0x34CF, "createextractvfx" },
    { 0x34D0, "createflagsandhud" },
    { 0x34D1, "createfontstring" },
    { 0x34D2, "createfullscreenimage" },
    { 0x34D3, "createfx" },
    { 0x34D4, "createfx_adjust_array" },
    { 0x34D5, "createfx_autosave" },
    { 0x34D6, "createfx_centerprint" },
    { 0x34D7, "createfx_centerprint_thread" },
    { 0x34D8, "createfx_common" },
    { 0x34D9, "createfx_devraw_map" },
    { 0x34DA, "createfx_draw_enabled" },
    { 0x34DB, "createfx_enabled" },
    { 0x34DC, "createfx_ent" },
    { 0x34DD, "createfx_filter_types" },
    { 0x34DE, "createfx_inputlocked" },
    { 0x34DF, "createfx_loopcounter" },
    { 0x34E0, "createfx_offset" },
    { 0x34E1, "createfx_only_triggers" },
    { 0x34E2, "createfx_print3d" },
    { 0x34E3, "createfx_selecting" },
    { 0x34E4, "createfxcursor" },
    { 0x34E5, "createfxent" },
    { 0x34E6, "createfxexploders" },
    { 0x34E7, "createfxlogic" },
    { 0x34E8, "createfxmasks" },
    { 0x34E9, "creategoal" },
    { 0x34EA, "creategulagloadout" },
    { 0x34EB, "createheli" },
    { 0x34EC, "createhelipath" },
    { 0x34ED, "createhelipilot" },
    { 0x34EE, "createhelperdrone" },
    { 0x34EF, "createhintobject" },
    { 0x34F0, "createholduseobject" },
    { 0x34F1, "createhostagelz" },
    { 0x34F2, "createhudelements" },
    { 0x34F3, "createhudelems" },
    { 0x34F4, "createhvt" },
    { 0x34F5, "createhvtextractionsite" },
    { 0x34F6, "createicon" },
    { 0x34F7, "createicon_hudelem" },
    { 0x34F8, "createinitialnavmodifier" },
    { 0x34F9, "createinstance" },
    { 0x34FA, "createinteractobject" },
    { 0x34FB, "createintervalsound" },
    { 0x34FC, "createiwsignature" },
    { 0x34FD, "createjuggcrate" },
    { 0x34FE, "createjuggcrateobjective" },
    { 0x34FF, "createjuggobjective" },
    { 0x3500, "createjuggobjectiveicon" },
    { 0x3501, "createkillcam" },
    { 0x3502, "createkitobjective" },
    { 0x3503, "createkscrate" },
    { 0x3504, "createleaderalias" },
    { 0x3505, "createlightswitchtrigger" },
    { 0x3506, "createline" },
    { 0x3507, "createlineconstantly" },
    { 0x3508, "createlocaleinstance" },
    { 0x3509, "createloopeffect" },
    { 0x350A, "createloopsound" },
    { 0x350B, "createlootcache" },
    { 0x350C, "createmapconfig" },
    { 0x350D, "createminimapicon" },
    { 0x350E, "createmission" },
    { 0x350F, "createmlgcamobject" },
    { 0x3510, "createmodels" },
    { 0x3511, "createmoltovinteract" },
    { 0x3512, "createmoltovinteractwhenavailable" },
    { 0x3513, "createmountmantlemodel" },
    { 0x3514, "createmvparrayentry" },
    { 0x3515, "createmwlogo" },
    { 0x3516, "createnewexploder" },
    { 0x3517, "createnewexploder_internal" },
    { 0x3518, "createnoisedata" },
    { 0x3519, "createnotification" },
    { 0x351A, "createnvidiavideo" },
    { 0x351B, "createobjective" },
    { 0x351C, "createobjective_engineer" },
    { 0x351D, "createobjectiveicon" },
    { 0x351E, "createobjectiveiconsforactivejugg" },
    { 0x351F, "createobjidobject" },
    { 0x3520, "createoneshoteffect" },
    { 0x3521, "createoperatorcustomization" },
    { 0x3522, "createoverlay" },
    { 0x3523, "createpatharray" },
    { 0x3524, "createpenthintobj" },
    { 0x3525, "createpickupicon" },
    { 0x3526, "createpickupuseent" },
    { 0x3527, "createplaceable" },
    { 0x3528, "createplayerdeadcountdownhud" },
    { 0x3529, "createplayersegmentstats" },
    { 0x352A, "createplayerstreakdatastruct" },
    { 0x352B, "createprimaryprogressbar" },
    { 0x352C, "createprimaryprogressbartext" },
    { 0x352D, "createpulluptrigger" },
    { 0x352E, "createquestinstance" },
    { 0x352F, "createreactiveent" },
    { 0x3530, "createremoteuav" },
    { 0x3531, "createrewardicon" },
    { 0x3532, "createrpgrepulsors" },
    { 0x3533, "createscenefromnewevent" },
    { 0x3534, "createscreeneffect" },
    { 0x3535, "createscreeneffectoffsets" },
    { 0x3536, "createscriptfilesinitialized" },
    { 0x3537, "createsentryforplayer" },
    { 0x3538, "createservertimer" },
    { 0x3539, "createsmartobjectinfo" },
    { 0x353A, "createspawner" },
    { 0x353B, "createspawnerstructbehindplayer" },
    { 0x353C, "createspawnlocation" },
    { 0x353D, "createspawnquerycontext" },
    { 0x353E, "createspawnweaponatpos" },
    { 0x353F, "createspawnweaponatposfromname" },
    { 0x3540, "createsquad" },
    { 0x3541, "createstreakinfo" },
    { 0x3542, "createstreakitemstruct" },
    { 0x3543, "createstructs" },
    { 0x3544, "createsupplypack" },
    { 0x3545, "createtacopskitstation" },
    { 0x3546, "createtags" },
    { 0x3547, "createtagsofcolor" },
    { 0x3548, "createtank" },
    { 0x3549, "createteamflag" },
    { 0x354A, "createteamflagbase" },
    { 0x354B, "createteamobjpoint" },
    { 0x354C, "createtestc130path" },
    { 0x354D, "createtesthelipath" },
    { 0x354E, "createtesthelis" },
    { 0x354F, "createthreatbiasgroups" },
    { 0x3550, "createtimer" },
    { 0x3551, "createtomastrikebomber" },
    { 0x3552, "createtomastrikedrone" },
    { 0x3553, "createtoptrigger" },
    { 0x3554, "createtrackedobject" },
    { 0x3555, "createtriggers" },
    { 0x3556, "createuseableobject" },
    { 0x3557, "createuseent" },
    { 0x3558, "createuseobject" },
    { 0x3559, "createvehicleinteraction" },
    { 0x355A, "createweapondefaultsarray" },
    { 0x355B, "createwinnersandlosersarrays" },
    { 0x355C, "createzones" },
    { 0x355D, "creationtime" },
    { 0x355E, "credit_move" },
    { 0x355F, "creditdept_fadeoutin" },
    { 0x3560, "creditdept_moveside_flag_thread" },
    { 0x3561, "creditline" },
    { 0x3562, "creditlinearray" },
    { 0x3563, "creditlogo" },
    { 0x3564, "creditlogo_fadein" },
    { 0x3565, "creditlogo_fadeout" },
    { 0x3566, "creditlogo_move" },
    { 0x3567, "credits" },
    { 0x3568, "credits_active" },
    { 0x3569, "credits_showmessage" },
    { 0x356A, "creditsbg" },
    { 0x356B, "creditscomplete" },
    { 0x356C, "crew_chopper_death_watcher_behavior" },
    { 0x356D, "crew_chopper_transport_behavior" },
    { 0x356E, "crew_ignore_manager" },
    { 0x356F, "crew_spawn" },
    { 0x3570, "crew_unload" },
    { 0x3571, "critchance" },
    { 0x3572, "critical_factor" },
    { 0x3573, "critical_target_icon_objective_id" },
    { 0x3574, "criticalfactors_callback" },
    { 0x3575, "criticalfactortypes" },
    { 0x3576, "criticalhealththreshold" },
    { 0x3577, "critically_damped_move_and_rotate_to" },
    { 0x3578, "critically_damped_move_and_rotate_to_thread" },
    { 0x3579, "critically_damped_move_to" },
    { 0x357A, "critically_damped_move_to_thread" },
    { 0x357B, "critkillcount" },
    { 0x357C, "cross_street_drive" },
    { 0x357D, "cross2d" },
    { 0x357E, "crosshair" },
    { 0x357F, "crosshair_fadetopoint" },
    { 0x3580, "crosshair_overlay" },
    { 0x3581, "crosshair_overlay_dot" },
    { 0x3582, "crosshair_value" },
    { 0x3583, "crossproduct" },
    { 0x3584, "crotch_damage_multiplier" },
    { 0x3585, "crouch_visible_from" },
    { 0x3586, "croucharrivalnode" },
    { 0x3587, "crouchdetectdist" },
    { 0x3588, "crouching_phone" },
    { 0x3589, "crouchupoffset" },
    { 0x358A, "crowbar_anim_think" },
    { 0x358B, "crowbar_breach_try_think" },
    { 0x358C, "crowbar_planted_think" },
    { 0x358D, "crowbar_use_activate" },
    { 0x358E, "crowd" },
    { 0x358F, "crowd_ap" },
    { 0x3590, "crowd_change_anim_at_offices" },
    { 0x3591, "crowd_delete" },
    { 0x3592, "crowd_enterer" },
    { 0x3593, "crowd_get_and_store" },
    { 0x3594, "crowd_individual_vehicle" },
    { 0x3595, "crowd_is_back_row" },
    { 0x3596, "crowd_is_front_row" },
    { 0x3597, "crowd_removed_for_skinned_verts" },
    { 0x3598, "crowd_screams" },
    { 0x3599, "crowd_setup_ap" },
    { 0x359A, "crowd_vehicles" },
    { 0x359B, "crowds" },
    { 0x359C, "crowguy_vo" },
    { 0x359D, "cruise_missile_objective_id" },
    { 0x359E, "cruise_missile_reach_target_ent_monitor" },
    { 0x359F, "cruise_missile_target_ent_clean_up" },
    { 0x35A0, "cruise_missiles" },
    { 0x35A1, "cruisepredator_aicharacterchecks" },
    { 0x35A2, "cruisepredator_cameramove" },
    { 0x35A3, "cruisepredator_cpmarkenemies" },
    { 0x35A4, "cruisepredator_cpunmarkenemies" },
    { 0x35A5, "cruisepredator_createbackupheight" },
    { 0x35A6, "cruisepredator_delaymissilecollision" },
    { 0x35A7, "cruisepredator_delayplayslamzoom" },
    { 0x35A8, "cruisepredator_directionoverride" },
    { 0x35A9, "cruisepredator_empapplied" },
    { 0x35AA, "cruisepredator_eventrecord" },
    { 0x35AB, "cruisepredator_followmissilepod" },
    { 0x35AC, "cruisepredator_handlevfxstates" },
    { 0x35AD, "cruisepredator_istouchingkillborder" },
    { 0x35AE, "cruisepredator_playdofsequence" },
    { 0x35AF, "cruisepredator_registervo" },
    { 0x35B0, "cruisepredator_removeitemfromslot" },
    { 0x35B1, "cruisepredator_returnplayer" },
    { 0x35B2, "cruisepredator_shakerider" },
    { 0x35B3, "cruisepredator_startexplodecamtransition" },
    { 0x35B4, "cruisepredator_startfadecamtransition" },
    { 0x35B5, "cruisepredator_takecontrol" },
    { 0x35B6, "cruisepredator_waittillexplode" },
    { 0x35B7, "cruisepredator_watchexplosion" },
    { 0x35B8, "cruisepredator_watchexplosiondistance" },
    { 0x35B9, "cruisepredator_watchkillborder" },
    { 0x35BA, "cruisepredator_watchkills" },
    { 0x35BB, "cruisepredator_watchmissileboost" },
    { 0x35BC, "cruisepredator_watchmissileexplosion" },
    { 0x35BD, "cruisepredator_watchmissileinfo" },
    { 0x35BE, "cruisepredator_watchownerdisown" },
    { 0x35BF, "cruisepredator_watchtimer" },
    { 0x35C0, "cruisepredatorbeginuse" },
    { 0x35C1, "crushcar" },
    { 0x35C2, "crypto_key_objective" },
    { 0x35C3, "cs_angle_offset" },
    { 0x35C4, "cs_creation_counter" },
    { 0x35C5, "cs_init_flags" },
    { 0x35C6, "cs_is_starttime" },
    { 0x35C7, "cs_object_container" },
    { 0x35C8, "cs_origin_offset" },
    { 0x35C9, "cs_return_and_wait_for_flag" },
    { 0x35CA, "cs_scripted_spawners" },
    { 0x35CB, "cs_scripted_spawners_models" },
    { 0x35CC, "cs_scripted_spawners_triggers" },
    { 0x35CD, "csdependency" },
    { 0x35CE, "csm_enable" },
    { 0x35CF, "csm_max_resolution" },
    { 0x35D0, "csm_sample_size" },
    { 0x35D1, "cspline_adjusttime" },
    { 0x35D2, "cspline_calctangent" },
    { 0x35D3, "cspline_calctangentnatural" },
    { 0x35D4, "cspline_calctangenttcb" },
    { 0x35D5, "cspline_findpathnodes" },
    { 0x35D6, "cspline_getnodes" },
    { 0x35D7, "cspline_getpointatdistance" },
    { 0x35D8, "cspline_getpointattime" },
    { 0x35D9, "cspline_initnoise" },
    { 0x35DA, "cspline_length" },
    { 0x35DB, "cspline_makenoisepath" },
    { 0x35DC, "cspline_makenoisepathnodes" },
    { 0x35DD, "cspline_makepath" },
    { 0x35DE, "cspline_makepath1seg" },
    { 0x35DF, "cspline_makepathtopoint" },
    { 0x35E0, "cspline_movefirstpoint" },
    { 0x35E1, "cspline_noise" },
    { 0x35E2, "cspline_speedfromdistance" },
    { 0x35E3, "cspline_test" },
    { 0x35E4, "cspline_testnodes" },
    { 0x35E5, "cspline_time" },
    { 0x35E6, "csplineseg_calccoeffs" },
    { 0x35E7, "csplineseg_calccoeffscapspeed" },
    { 0x35E8, "csplineseg_calclengthbystepping" },
    { 0x35E9, "csplineseg_calctopspeed" },
    { 0x35EA, "csplineseg_calctopspeedbyderiving" },
    { 0x35EB, "csplineseg_calctopspeedbystepping" },
    { 0x35EC, "csplineseg_copy" },
    { 0x35ED, "csplineseg_getpoint" },
    { 0x35EE, "cstillrighttheredistsq" },
    { 0x35EF, "ctbuddy" },
    { 0x35F0, "ctf_loadouts" },
    { 0x35F1, "ctfteamspawnsetids" },
    { 0x35F2, "ctimetolose" },
    { 0x35F3, "ctpassenger" },
    { 0x35F4, "cue_exit_civs" },
    { 0x35F5, "cuffs" },
    { 0x35F6, "cull_redshirts_for_startpoint" },
    { 0x35F7, "cull_spawners_from_killspawner" },
    { 0x35F8, "cullcoverposesforshort" },
    { 0x35F9, "cur_defend_angle_override" },
    { 0x35FA, "cur_defend_node" },
    { 0x35FB, "cur_defend_point_override" },
    { 0x35FC, "cur_defend_stance" },
    { 0x35FD, "cur_infil_track" },
    { 0x35FE, "cur_move_mode" },
    { 0x35FF, "cur_node" },
    { 0x3600, "cur_shaft_level_index" },
    { 0x3601, "cur_vol" },
    { 0x3602, "curamount" },
    { 0x3603, "curautosave" },
    { 0x3604, "curbombzone" },
    { 0x3605, "curcache" },
    { 0x3606, "curcachelocation" },
    { 0x3607, "curcarrierorigin" },
    { 0x3608, "curclass" },
    { 0x3609, "curevent" },
    { 0x360A, "curiousstarttime" },
    { 0x360B, "curobj" },
    { 0x360C, "curobjectiveindex" },
    { 0x360D, "curobjid" },
    { 0x360E, "curorigin" },
    { 0x360F, "curplayertohavekidnapperspawned" },
    { 0x3610, "curpotgscene" },
    { 0x3611, "curprogress" },
    { 0x3612, "curr" },
    { 0x3613, "curr_anim" },
    { 0x3614, "curr_dist" },
    { 0x3615, "curr_projectile_hits" },
    { 0x3616, "curr_target" },
    { 0x3617, "curr_weap" },
    { 0x3618, "curregion" },
    { 0x3619, "currency_scale_func" },
    { 0x361A, "currencycaches" },
    { 0x361B, "current_anim_data_scene" },
    { 0x361C, "current_blackbox" },
    { 0x361D, "current_blackbox_corpse" },
    { 0x361E, "current_blocks_sequence" },
    { 0x361F, "current_body" },
    { 0x3620, "current_bombzone" },
    { 0x3621, "current_breath_blur" },
    { 0x3622, "current_cbreaker_sequence" },
    { 0x3623, "current_challenge" },
    { 0x3624, "current_color_order" },
    { 0x3625, "current_color_trig" },
    { 0x3626, "current_crafted_inventory" },
    { 0x3627, "current_crafting_struct" },
    { 0x3628, "current_dialogue" },
    { 0x3629, "current_enemy" },
    { 0x362A, "current_enemy_deaths" },
    { 0x362B, "current_escalation_level" },
    { 0x362C, "current_event" },
    { 0x362D, "current_flag" },
    { 0x362E, "current_floor" },
    { 0x362F, "current_follow_path" },
    { 0x3630, "current_forward_dist" },
    { 0x3631, "current_global_hint" },
    { 0x3632, "current_goal" },
    { 0x3633, "current_goal_override" },
    { 0x3634, "current_group" },
    { 0x3635, "current_health_regen_segment_ceiling" },
    { 0x3636, "current_health_regen_segment_floor" },
    { 0x3637, "current_hint_active" },
    { 0x3638, "current_icon" },
    { 0x3639, "current_interaction_structs" },
    { 0x363A, "current_knife_weapon" },
    { 0x363B, "current_knife_weapon_string" },
    { 0x363C, "current_knock_off" },
    { 0x363D, "current_lookahead" },
    { 0x363E, "current_mode_hud" },
    { 0x363F, "current_node" },
    { 0x3640, "current_num_spawned_enemies" },
    { 0x3641, "current_num_spawned_juggernauts" },
    { 0x3642, "current_num_spawned_soldiers" },
    { 0x3643, "current_num_spawned_zombies" },
    { 0x3644, "current_obj" },
    { 0x3645, "current_objectve" },
    { 0x3646, "current_output" },
    { 0x3647, "current_overwatch_vo" },
    { 0x3648, "current_path" },
    { 0x3649, "current_personal_interaction_structs" },
    { 0x364A, "current_pivot_struct" },
    { 0x364B, "current_player" },
    { 0x364C, "current_pos" },
    { 0x364D, "current_reaper_camera_zoom_level" },
    { 0x364E, "current_requested_snd" },
    { 0x364F, "current_revive_icon_color" },
    { 0x3650, "current_room" },
    { 0x3651, "current_sentry" },
    { 0x3652, "current_spawn_scoring_index" },
    { 0x3653, "current_speed" },
    { 0x3654, "current_start" },
    { 0x3655, "current_state" },
    { 0x3656, "current_state_ents" },
    { 0x3657, "current_stealth_meter_progress" },
    { 0x3658, "current_stealth_state" },
    { 0x3659, "current_struct_angles" },
    { 0x365A, "current_sunflare_setting" },
    { 0x365B, "current_target" },
    { 0x365C, "current_time" },
    { 0x365D, "current_uid" },
    { 0x365E, "current_vehicle_seat" },
    { 0x365F, "current_visionset" },
    { 0x3660, "current_vo_queue" },
    { 0x3661, "current_weapon_double_super" },
    { 0x3662, "current_weapon_jump_super" },
    { 0x3663, "current_zone_target" },
    { 0x3664, "currentaction" },
    { 0x3665, "currentactivevehiclecount" },
    { 0x3666, "currentalphanumericcode" },
    { 0x3667, "currentambientgroup" },
    { 0x3668, "currentanimpriority" },
    { 0x3669, "currentcamera" },
    { 0x366A, "currentcarryobject" },
    { 0x366B, "currentcheckgroup" },
    { 0x366C, "currentclustercamera" },
    { 0x366D, "currentcolorcode" },
    { 0x366E, "currentcolorforced" },
    { 0x366F, "currentcombatmode" },
    { 0x3670, "currentcost" },
    { 0x3671, "currentdamagestate" },
    { 0x3672, "currentdoor" },
    { 0x3673, "currentdropcount" },
    { 0x3674, "currentfefx" },
    { 0x3675, "currentfirstupgrade" },
    { 0x3676, "currentfov" },
    { 0x3677, "currentfrac" },
    { 0x3678, "currentfx" },
    { 0x3679, "currentguardlocation" },
    { 0x367A, "currenthealth" },
    { 0x367B, "currentintensity" },
    { 0x367C, "currentkillstreakopvo" },
    { 0x367D, "currentleftangle" },
    { 0x367E, "currentlight" },
    { 0x367F, "currentlookatents" },
    { 0x3680, "currentlycrafteditem" },
    { 0x3681, "currentmeleeweapon" },
    { 0x3682, "currentmode" },
    { 0x3683, "currentmoduledeaths" },
    { 0x3684, "currentmodulekills" },
    { 0x3685, "currentmovespeed" },
    { 0x3686, "currentnagindex" },
    { 0x3687, "currentnode" },
    { 0x3688, "currentnotifyhandlers" },
    { 0x3689, "currentobj" },
    { 0x368A, "currentobjective" },
    { 0x368B, "currentobjectiveindex" },
    { 0x368C, "currentpatrolstruct" },
    { 0x368D, "currentpatternduration" },
    { 0x368E, "currentpiece" },
    { 0x368F, "currentplayeroffset" },
    { 0x3690, "currentplayertarget" },
    { 0x3691, "currentpoi" },
    { 0x3692, "currentpronespeedscale" },
    { 0x3693, "currentregendelay" },
    { 0x3694, "currentrelativeanimpriority" },
    { 0x3695, "currentreservedindex" },
    { 0x3696, "currentrightangle" },
    { 0x3697, "currentround" },
    { 0x3698, "currentscramblerstrength" },
    { 0x3699, "currentsectionname" },
    { 0x369A, "currentselectedkillstreakslot" },
    { 0x369B, "currentsetup" },
    { 0x369C, "currentshottarget" },
    { 0x369D, "currentsnaptonodeis" },
    { 0x369E, "currentspawnlogicsupportsfrontline" },
    { 0x369F, "currentspectatorcamref" },
    { 0x36A0, "currentspeedscale" },
    { 0x36A1, "currentstate" },
    { 0x36A2, "currentstatename" },
    { 0x36A3, "currentstealthlevel" },
    { 0x36A4, "currentstring" },
    { 0x36A5, "currentsubstate" },
    { 0x36A6, "currenttarget" },
    { 0x36A7, "currenttargettag" },
    { 0x36A8, "currentteam" },
    { 0x36A9, "currentteamobjectivechain" },
    { 0x36AA, "currentthrowobject" },
    { 0x36AB, "currenttier" },
    { 0x36AC, "currenttimelimitdelay" },
    { 0x36AD, "currenttrackindex" },
    { 0x36AE, "currentturret" },
    { 0x36AF, "currentvehicle" },
    { 0x36B0, "currentvehicleanimalias" },
    { 0x36B1, "currentvisionset" },
    { 0x36B2, "currentvol" },
    { 0x36B3, "currentwarningindex" },
    { 0x36B4, "currentweaponatspawn" },
    { 0x36B5, "currentweaponpose" },
    { 0x36B6, "curroutepoint" },
    { 0x36B7, "currtarget" },
    { 0x36B8, "cursor" },
    { 0x36B9, "cursor_highlight" },
    { 0x36BA, "cursor_hint_ent" },
    { 0x36BB, "cursor_hint_thread" },
    { 0x36BC, "cursor_hint_unusable_think" },
    { 0x36BD, "cursor_hints" },
    { 0x36BE, "cursor_hints_game" },
    { 0x36BF, "cursor_hints_max" },
    { 0x36C0, "cursor_pos" },
    { 0x36C1, "cursor_refresh" },
    { 0x36C2, "cursorhintdir" },
    { 0x36C3, "curstate" },
    { 0x36C4, "curstates" },
    { 0x36C5, "cursuspsensetrack" },
    { 0x36C6, "curteam" },
    { 0x36C7, "custom_allowedweaponnames" },
    { 0x36C8, "custom_ammo_function" },
    { 0x36C9, "custom_animscript" },
    { 0x36CA, "custom_arrival_animmode" },
    { 0x36CB, "custom_battlechatter" },
    { 0x36CC, "custom_battlechatter_init_valid_phrases" },
    { 0x36CD, "custom_battlechatter_internal" },
    { 0x36CE, "custom_battlechatter_validate_phrase" },
    { 0x36CF, "custom_cangive_weapon_func" },
    { 0x36D0, "custom_collapse_oilfire_think" },
    { 0x36D1, "custom_combat_jugg" },
    { 0x36D2, "custom_context_range" },
    { 0x36D3, "custom_crawl_sound" },
    { 0x36D4, "custom_crawling_death_array" },
    { 0x36D5, "custom_damage_challenge_func" },
    { 0x36D6, "custom_death_effect" },
    { 0x36D7, "custom_death_override_quote" },
    { 0x36D8, "custom_death_quote" },
    { 0x36D9, "custom_death_script" },
    { 0x36DA, "custom_death_sound" },
    { 0x36DB, "custom_dof_trace" },
    { 0x36DC, "custom_eject_door_back_left" },
    { 0x36DD, "custom_eject_door_front_left" },
    { 0x36DE, "custom_eject_fin" },
    { 0x36DF, "custom_eject_hood" },
    { 0x36E0, "custom_eject_rack_bar" },
    { 0x36E1, "custom_eject_siren" },
    { 0x36E2, "custom_eject_spoiler" },
    { 0x36E3, "custom_eject_trunk" },
    { 0x36E4, "custom_ending" },
    { 0x36E5, "custom_epehermal_attachment_func" },
    { 0x36E6, "custom_epehermal_weapon_func" },
    { 0x36E7, "custom_ephermal_camo_func" },
    { 0x36E8, "custom_followpath_parameter_func" },
    { 0x36E9, "custom_fov" },
    { 0x36EA, "custom_friendly_fire_message" },
    { 0x36EB, "custom_friendly_fire_shader" },
    { 0x36EC, "custom_giveloadout" },
    { 0x36ED, "custom_gl_proj_func_init" },
    { 0x36EE, "custom_grenade_pullback_func" },
    { 0x36EF, "custom_hdromeo_check" },
    { 0x36F0, "custom_hint_text" },
    { 0x36F1, "custom_impact_nose" },
    { 0x36F2, "custom_initializeweaponpickups" },
    { 0x36F3, "custom_intermission_func" },
    { 0x36F4, "custom_laser_function" },
    { 0x36F5, "custom_linkto_slide" },
    { 0x36F6, "custom_marine" },
    { 0x36F7, "custom_no_game_setupfunc" },
    { 0x36F8, "custom_nvg_update_func" },
    { 0x36F9, "custom_oilfire_think" },
    { 0x36FA, "custom_onplayerconnect_func" },
    { 0x36FB, "custom_onspawnplayer_func" },
    { 0x36FC, "custom_player_hotjoin_func" },
    { 0x36FD, "custom_playerdamage_challenge_func" },
    { 0x36FE, "custom_proj_func" },
    { 0x36FF, "custom_search_dist" },
    { 0x3700, "custom_state_functions" },
    { 0x3701, "custom_var_done" },
    { 0x3702, "custom_vehicle_damage_function" },
    { 0x3703, "custom_weaponnamestring_func" },
    { 0x3704, "custombc_alias2" },
    { 0x3705, "custombcs_validphrases" },
    { 0x3706, "custombcshiftarray" },
    { 0x3707, "customchatevent" },
    { 0x3708, "customchatphrase" },
    { 0x3709, "customdata" },
    { 0x370A, "customdeath" },
    { 0x370B, "customfunc" },
    { 0x370C, "customground" },
    { 0x370D, "customgroup" },
    { 0x370E, "customheight_mode" },
    { 0x370F, "customheight_mode_off" },
    { 0x3710, "customheight_mode_offsetmodels" },
    { 0x3711, "customhostmigrationend" },
    { 0x3712, "customidleanimset" },
    { 0x3713, "customidlenode" },
    { 0x3714, "customjuiced" },
    { 0x3715, "customlaststandactionset" },
    { 0x3716, "custommoveanimset" },
    { 0x3717, "customnotetrackfx" },
    { 0x3718, "customnotetrackhandler" },
    { 0x3719, "customrotation_mode" },
    { 0x371A, "customrotation_mode_off" },
    { 0x371B, "customtargetpos" },
    { 0x371C, "customwaypointid" },
    { 0x371D, "customweaponname" },
    { 0x371E, "cut" },
    { 0x371F, "cut_alt" },
    { 0x3720, "cut_alt_model" },
    { 0x3721, "cut_anim_short" },
    { 0x3722, "cut_interactions" },
    { 0x3723, "cut_model" },
    { 0x3724, "cut_objective_progress" },
    { 0x3725, "cut_pa_on_flag" },
    { 0x3726, "cut_progress" },
    { 0x3727, "cut_progress_objective" },
    { 0x3728, "cut_progress_think" },
    { 0x3729, "cut_short_if_player_enters_quickly" },
    { 0x372A, "cut_to_back" },
    { 0x372B, "cut_vault_gate" },
    { 0x372C, "cutframe" },
    { 0x372D, "cutoff_distance_current" },
    { 0x372E, "cutoff_distance_goal" },
    { 0x372F, "cutoff_falloff_current" },
    { 0x3730, "cutoff_falloff_goal" },
    { 0x3731, "cutout_door_main" },
    { 0x3732, "cutout_pilot" },
    { 0x3733, "cutout_pilot_long" },
    { 0x3734, "cutout_test" },
    { 0x3735, "cutters" },
    { 0x3736, "cutters_stress_test" },
    { 0x3737, "cyber_loadouts" },
    { 0x3738, "cyberattack" },
    { 0x3739, "cyberemp" },
    { 0x373A, "cycle_bank_combat_cut_spawn_modules" },
    { 0x373B, "cycle_damage_scalar" },
    { 0x373C, "cycle_reward_scalar" },
    { 0x373D, "cycle_score_scalar" },
    { 0x373E, "cyclevalidsquadspectate" },
    { 0x373F, "d1_health" },
    { 0x3740, "d2_health" },
    { 0x3741, "d3_health" },
    { 0x3742, "d4_health" },
    { 0x3743, "dad_beckon_loop" },
    { 0x3744, "dad_boost_mayhem" },
    { 0x3745, "dad_dies_fight_hits" },
    { 0x3746, "dad_dies_fight_hits_hadir" },
    { 0x3747, "dad_glance_loop" },
    { 0x3748, "dad_go_to_house" },
    { 0x3749, "dad_move_speed" },
    { 0x374A, "dad_phone_blocker" },
    { 0x374B, "dad_procedural_bones" },
    { 0x374C, "dad_shot_by_boss_listener" },
    { 0x374D, "dadchildangles" },
    { 0x374E, "damagable" },
    { 0x374F, "damage_alien_over_time" },
    { 0x3750, "damage_armored_player" },
    { 0x3751, "damage_auto_range" },
    { 0x3752, "damage_breakout_of_anim" },
    { 0x3753, "damage_counter" },
    { 0x3754, "damage_done" },
    { 0x3755, "damage_feedback_setup" },
    { 0x3756, "damage_functions" },
    { 0x3757, "damage_handler" },
    { 0x3758, "damage_hint_bullet_only" },
    { 0x3759, "damage_hints" },
    { 0x375A, "damage_hints_cleanup" },
    { 0x375B, "damage_hostages" },
    { 0x375C, "damage_infront_of_train" },
    { 0x375D, "damage_init" },
    { 0x375E, "damage_is_explosive" },
    { 0x375F, "damage_is_fire" },
    { 0x3760, "damage_is_valid_for_friendlyfire_warning" },
    { 0x3761, "damage_monitor" },
    { 0x3762, "damage_nearby_dynolights" },
    { 0x3763, "damage_nearby_map_vehicles" },
    { 0x3764, "damage_nearby_players" },
    { 0x3765, "damage_nearby_vehicles" },
    { 0x3766, "damage_on_elbow_strike" },
    { 0x3767, "damage_on_gun_shot" },
    { 0x3768, "damage_on_marked_enemies" },
    { 0x3769, "damage_on_rooftop_enter" },
    { 0x376A, "damage_over_time" },
    { 0x376B, "damage_parts_enabled" },
    { 0x376C, "damage_should_ignore_blast_shield" },
    { 0x376D, "damage_sight_range" },
    { 0x376E, "damage_state" },
    { 0x376F, "damage_think" },
    { 0x3770, "damage_watcher" },
    { 0x3771, "damage_watcher_for_c130" },
    { 0x3772, "damageapplied" },
    { 0x3773, "damagearea" },
    { 0x3774, "damagearmor" },
    { 0x3775, "damagearray" },
    { 0x3776, "damageattacker" },
    { 0x3777, "damageblockedtotal" },
    { 0x3778, "damagebloodoverlay" },
    { 0x3779, "damagebloodoverlaydirectional" },
    { 0x377A, "damagebloodoverlayfullscreen" },
    { 0x377B, "damagecallback" },
    { 0x377C, "damagecallbacks" },
    { 0x377D, "damagecenter" },
    { 0x377E, "damaged" },
    { 0x377F, "damaged_by_player" },
    { 0x3780, "damaged_by_players" },
    { 0x3781, "damagedata" },
    { 0x3782, "damagedatalookup" },
    { 0x3783, "damagedby" },
    { 0x3784, "damagedplayer" },
    { 0x3785, "damagedplayers" },
    { 0x3786, "damagedsubpart" },
    { 0x3787, "damageeffects" },
    { 0x3788, "damageent" },
    { 0x3789, "damageeventcount" },
    { 0x378A, "damageevents" },
    { 0x378B, "damagefeedback" },
    { 0x378C, "damagefeedback_took_damage" },
    { 0x378D, "damagefeedbackgroupheavy" },
    { 0x378E, "damagefeedbackgrouplight" },
    { 0x378F, "damagefeedbacknosound" },
    { 0x3790, "damagefire" },
    { 0x3791, "damageflag" },
    { 0x3792, "damageflags" },
    { 0x3793, "damagefunctions" },
    { 0x3794, "damagehelmet" },
    { 0x3795, "damageinfo" },
    { 0x3796, "damageinfocolorindex" },
    { 0x3797, "damageinfovictim" },
    { 0x3798, "damageinvulnerability" },
    { 0x3799, "damagelistindex" },
    { 0x379A, "damagelocationisany" },
    { 0x379B, "damagemodifier" },
    { 0x379C, "damagemonitor" },
    { 0x379D, "damagemonitorfunc" },
    { 0x379E, "damagemultiplierarmor" },
    { 0x379F, "damagemultiplierexplosive" },
    { 0x37A0, "damagemultiplierhealth" },
    { 0x37A1, "damageorigin" },
    { 0x37A2, "damageowner" },
    { 0x37A3, "damagepainvision" },
    { 0x37A4, "damageparts" },
    { 0x37A5, "damagepartshandler" },
    { 0x37A6, "damagepartshandlerpart" },
    { 0x37A7, "damagepartshandlersubpart" },
    { 0x37A8, "damagepoint" },
    { 0x37A9, "damagepos" },
    { 0x37AA, "damageradialdistortion" },
    { 0x37AB, "damageratio" },
    { 0x37AC, "damagerumble" },
    { 0x37AD, "damagerumblequake" },
    { 0x37AE, "damagescreenshake" },
    { 0x37AF, "damagesfx" },
    { 0x37B0, "damageshakebulletnum" },
    { 0x37B1, "damageshakeexplosivenum" },
    { 0x37B2, "damageshellshockandrumble" },
    { 0x37B3, "damageshieldcounter" },
    { 0x37B4, "damageshieldexpiretime" },
    { 0x37B5, "damageshieldpain" },
    { 0x37B6, "damageshock" },
    { 0x37B7, "damagesubpartlocationisany" },
    { 0x37B8, "damagetick" },
    { 0x37B9, "damagetracker" },
    { 0x37BA, "damagetrapfuncthink" },
    { 0x37BB, "damageui" },
    { 0x37BC, "damagewatch" },
    { 0x37BD, "damagewatcher" },
    { 0x37BE, "damageweaponnames" },
    { 0x37BF, "damgeignoreents" },
    { 0x37C0, "dance_floor_volume" },
    { 0x37C1, "dangercircleent" },
    { 0x37C2, "dangercircletick" },
    { 0x37C3, "dangercircleui" },
    { 0x37C4, "dangericonent" },
    { 0x37C5, "dangerzone" },
    { 0x37C6, "dangerzoneheight" },
    { 0x37C7, "dangerzoneid" },
    { 0x37C8, "dangerzoneradius" },
    { 0x37C9, "dangerzones" },
    { 0x37CA, "darine" },
    { 0x37CB, "dark_visionset_turbine_room" },
    { 0x37CC, "data" },
    { 0x37CD, "data_center_sfx_loop" },
    { 0x37CE, "data_room_2f_enemy_vo" },
    { 0x37CF, "data_room_nag" },
    { 0x37D0, "databyref" },
    { 0x37D1, "dataciv" },
    { 0x37D2, "dataciv_death_watcher" },
    { 0x37D3, "dataenemies" },
    { 0x37D4, "datalog_archivesaved" },
    { 0x37D5, "datalog_getlogversion" },
    { 0x37D6, "datalog_isloggingenabled" },
    { 0x37D7, "datalog_newevent" },
    { 0x37D8, "datalog_scenefinalized" },
    { 0x37D9, "datalogprint" },
    { 0x37DA, "datapoints" },
    { 0x37DB, "datawritten" },
    { 0x37DC, "date" },
    { 0x37DD, "db_2_enemy" },
    { 0x37DE, "dbgmoloburnlooponly" },
    { 0x37DF, "dbgmolodiedownonly" },
    { 0x37E0, "dbgmolodrawhits" },
    { 0x37E1, "dbgmoloflareuponly" },
    { 0x37E2, "dd" },
    { 0x37E3, "dd_endgame" },
    { 0x37E4, "ddbombmodel" },
    { 0x37E5, "ddlz" },
    { 0x37E6, "ddtimetoadd" },
    { 0x37E7, "deactivate" },
    { 0x37E8, "deactivate_bomb_interactions" },
    { 0x37E9, "deactivate_cloak" },
    { 0x37EA, "deactivate_cluster_strike" },
    { 0x37EB, "deactivate_enemy_turret" },
    { 0x37EC, "deactivate_infinite_ammo" },
    { 0x37ED, "deactivate_instant_revive" },
    { 0x37EE, "deactivate_inv_cooldown" },
    { 0x37EF, "deactivate_invulnerability" },
    { 0x37F0, "deactivate_linked_ied_spawners" },
    { 0x37F1, "deactivate_mark_enemies" },
    { 0x37F2, "deactivate_scavenger" },
    { 0x37F3, "deactivate_stealth_kill_check" },
    { 0x37F4, "deactivate_team_armor_buff" },
    { 0x37F5, "deactivate_uav" },
    { 0x37F6, "deactivateagent" },
    { 0x37F7, "deactivateagentdelayed" },
    { 0x37F8, "deactivateallspawnsets" },
    { 0x37F9, "deactivatebrushmodel" },
    { 0x37FA, "deactivatecallback" },
    { 0x37FB, "deactivatecrate" },
    { 0x37FC, "deactivatecratephysics" },
    { 0x37FD, "deactivateendzone" },
    { 0x37FE, "deactivatejuggernaut" },
    { 0x37FF, "deactivatepower" },
    { 0x3800, "deactivatespawnset" },
    { 0x3801, "deactivatezone" },
    { 0x3802, "dead_body_create" },
    { 0x3803, "dead_body_search_patrol" },
    { 0x3804, "dead_boss_blocker" },
    { 0x3805, "dead_boss_blocker_use" },
    { 0x3806, "dead_charred_bodies" },
    { 0x3807, "dead_dad_blocker" },
    { 0x3808, "dead_dad_blocker_hadir" },
    { 0x3809, "dead_from_smoke" },
    { 0x380A, "deaddriver" },
    { 0x380B, "deadeye_charge" },
    { 0x380C, "deadeyekillcount" },
    { 0x380D, "deadquote_recently_used" },
    { 0x380E, "deadsilencebeginuse" },
    { 0x380F, "deadsilenceenduse" },
    { 0x3810, "deadsilencekills" },
    { 0x3811, "deadsilenceuistate" },
    { 0x3812, "deal_damage_to_enemies" },
    { 0x3813, "deal_damage_to_zombies_entering_the_link" },
    { 0x3814, "dealaoedamage" },
    { 0x3815, "death_01_snd_handle" },
    { 0x3816, "death_02_snd_handle" },
    { 0x3817, "death_03_snd_handle" },
    { 0x3818, "death_alert_timeout" },
    { 0x3819, "death_anim_no_ragdoll" },
    { 0x381A, "death_badplace" },
    { 0x381B, "death_cleanup" },
    { 0x381C, "death_count" },
    { 0x381D, "death_delayed_ragdoll" },
    { 0x381E, "death_earthquake" },
    { 0x381F, "death_face" },
    { 0x3820, "death_fight1" },
    { 0x3821, "death_fight2" },
    { 0x3822, "death_firesound" },
    { 0x3823, "death_fx" },
    { 0x3824, "death_fx_on_self" },
    { 0x3825, "death_hint_think" },
    { 0x3826, "death_hint_watcher_marines_civ_ambush_death" },
    { 0x3827, "death_hint_watcher_marines_machinegun_death" },
    { 0x3828, "death_hint_watcher_marines_mg_death" },
    { 0x3829, "death_hint_watcher_marines_tripwire_death" },
    { 0x382A, "death_icon_budget_delete" },
    { 0x382B, "death_icon_enemy_budget_delete" },
    { 0x382C, "death_jolt" },
    { 0x382D, "death_monitor" },
    { 0x382E, "death_no_ragdoll" },
    { 0x382F, "death_origin" },
    { 0x3830, "death_radiusdamage" },
    { 0x3831, "death_safety" },
    { 0x3832, "death_scene_3f" },
    { 0x3833, "death_scene_enemy" },
    { 0x3834, "death_stance" },
    { 0x3835, "death_think" },
    { 0x3836, "death_thread" },
    { 0x3837, "death_vo" },
    { 0x3838, "death_vo_cleanup" },
    { 0x3839, "deathalias" },
    { 0x383A, "deathanim" },
    { 0x383B, "deathanimations" },
    { 0x383C, "deathanimduration" },
    { 0x383D, "deathanime" },
    { 0x383E, "deathanimmode" },
    { 0x383F, "deathanimscript" },
    { 0x3840, "deathbysuffocation" },
    { 0x3841, "deathcallback" },
    { 0x3842, "deathcallbacks" },
    { 0x3843, "deathchain_goalvolume" },
    { 0x3844, "deathcleanup" },
    { 0x3845, "deathdamagemax" },
    { 0x3846, "deathdamagemin" },
    { 0x3847, "deathdamageradius" },
    { 0x3848, "deathdelaycleanup" },
    { 0x3849, "deathflag" },
    { 0x384A, "deathflags" },
    { 0x384B, "deathfunc" },
    { 0x384C, "deathfunction" },
    { 0x384D, "deathfunctions" },
    { 0x384E, "deathfx" },
    { 0x384F, "deathfx_ent" },
    { 0x3850, "deathfx1" },
    { 0x3851, "deathfx2" },
    { 0x3852, "deathfxfire" },
    { 0x3853, "deathfxoverlay" },
    { 0x3854, "deathhints" },
    { 0x3855, "deathicon" },
    { 0x3856, "deathisanimexempt" },
    { 0x3857, "deathlmgcleanup" },
    { 0x3858, "deathmodel" },
    { 0x3859, "deathmonitor" },
    { 0x385A, "deathnotetrackhandler" },
    { 0x385B, "deathoverridecallback" },
    { 0x385C, "deathposition" },
    { 0x385D, "deathreset" },
    { 0x385E, "deathretainstreaks" },
    { 0x385F, "deathrolloff" },
    { 0x3860, "deathrollon" },
    { 0x3861, "deaths_door" },
    { 0x3862, "deathscenetimems" },
    { 0x3863, "deathscenetimesec" },
    { 0x3864, "deathscript" },
    { 0x3865, "deathsdoor" },
    { 0x3866, "deathsdoor_enabled" },
    { 0x3867, "deathsdoor_sfx" },
    { 0x3868, "deathsdoorduration" },
    { 0x3869, "deathsdooroverlaypulse" },
    { 0x386A, "deathsdooroverlaypulsefinal" },
    { 0x386B, "deathsdooroverride" },
    { 0x386C, "deathsdoorpulsenorm" },
    { 0x386D, "deathshieldfunc" },
    { 0x386E, "deathshieldinvulnerability" },
    { 0x386F, "deathsound" },
    { 0x3870, "deathsoundent" },
    { 0x3871, "deathspawnerents" },
    { 0x3872, "deathspawnerpreview" },
    { 0x3873, "deathspectateangles" },
    { 0x3874, "deathspectatepos" },
    { 0x3875, "deathstate" },
    { 0x3876, "deathstateoverride" },
    { 0x3877, "deathstring" },
    { 0x3878, "deathstring_passed" },
    { 0x3879, "deathswitch_loopblinkinglight" },
    { 0x387A, "deathswitch_payloadrelease" },
    { 0x387B, "deathswitch_payloadreleaseondeath" },
    { 0x387C, "deathswitch_payloadreleasetype" },
    { 0x387D, "deathswitch_releaseartilleryexplosion" },
    { 0x387E, "deathswitch_releaselocalexplosion" },
    { 0x387F, "deathswitch_startpayloadreleasesequence" },
    { 0x3880, "deathswitch_watchbleedout" },
    { 0x3881, "deathswitchent" },
    { 0x3882, "deathtime" },
    { 0x3883, "deathtype" },
    { 0x3884, "deathvfx" },
    { 0x3885, "debounce" },
    { 0x3886, "debounced" },
    { 0x3887, "debris_logic" },
    { 0x3888, "debuffedbyplayers" },
    { 0x3889, "debug" },
    { 0x388A, "debug_activity" },
    { 0x388B, "debug_animsoundtag" },
    { 0x388C, "debug_animsoundtagselected" },
    { 0x388D, "debug_assignroles" },
    { 0x388E, "debug_attack_heli_test_start" },
    { 0x388F, "debug_beat_func" },
    { 0x3890, "debug_boxes" },
    { 0x3891, "debug_boxes_count" },
    { 0x3892, "debug_boxes_max_count" },
    { 0x3893, "debug_breakout" },
    { 0x3894, "debug_button_combos" },
    { 0x3895, "debug_cars" },
    { 0x3896, "debug_change_vo_prefix_watcher" },
    { 0x3897, "debug_character_count" },
    { 0x3898, "debug_checkin_weapons" },
    { 0x3899, "debug_color_friendlies" },
    { 0x389A, "debug_color_huds" },
    { 0x389B, "debug_colornodes" },
    { 0x389C, "debug_corner" },
    { 0x389D, "debug_cursor" },
    { 0x389E, "debug_cutters" },
    { 0x389F, "debug_data" },
    { 0x38A0, "debug_display_rule_of_thirds" },
    { 0x38A1, "debug_draw" },
    { 0x38A2, "debug_draw_slope_angles" },
    { 0x38A3, "debug_draw_until_newpath" },
    { 0x38A4, "debug_droploadoutcrateonplayer" },
    { 0x38A5, "debug_enabled" },
    { 0x38A6, "debug_enemypos" },
    { 0x38A7, "debug_enemyposproc" },
    { 0x38A8, "debug_enemyposreplay" },
    { 0x38A9, "debug_fail_player_prone_dirt_fx" },
    { 0x38AA, "debug_find_hvi" },
    { 0x38AB, "debug_friendlyfire" },
    { 0x38AC, "debug_fxlighting" },
    { 0x38AD, "debug_fxlighting_buttons" },
    { 0x38AE, "debug_give_class" },
    { 0x38AF, "debug_give_faction" },
    { 0x38B0, "debug_give_super" },
    { 0x38B1, "debug_go_to_the_prison" },
    { 0x38B2, "debug_gray_card" },
    { 0x38B3, "debug_gray_card_mp" },
    { 0x38B4, "debug_graycard_buttons" },
    { 0x38B5, "debug_hiding_spots" },
    { 0x38B6, "debug_hudelem" },
    { 0x38B7, "debug_interaction_point" },
    { 0x38B8, "debug_kill_soldier" },
    { 0x38B9, "debug_kill_soldier_after_anim" },
    { 0x38BA, "debug_last_triggered" },
    { 0x38BB, "debug_line" },
    { 0x38BC, "debug_logarchiveresult" },
    { 0x38BD, "debug_loop_explosion" },
    { 0x38BE, "debug_loopbuddyboostanims" },
    { 0x38BF, "debug_m1_p1_obj_start" },
    { 0x38C0, "debug_m1_p3_obj_start" },
    { 0x38C1, "debug_meet_with_informant" },
    { 0x38C2, "debug_message" },
    { 0x38C3, "debug_message_clear" },
    { 0x38C4, "debug_message_players" },
    { 0x38C5, "debug_ml_p2_interrogate_start" },
    { 0x38C6, "debug_node_array" },
    { 0x38C7, "debug_nuke" },
    { 0x38C8, "debug_oil_fire_snake" },
    { 0x38C9, "debug_outline" },
    { 0x38CA, "debug_pass_player_prone_dirt_fx" },
    { 0x38CB, "debug_patrol_point_score" },
    { 0x38CC, "debug_patrol_point_score_loop" },
    { 0x38CD, "debug_player_death" },
    { 0x38CE, "debug_player_fwd" },
    { 0x38CF, "debug_pre_start_coop_defuse" },
    { 0x38D0, "debug_pre_start_coop_escort" },
    { 0x38D1, "debug_pre_start_coop_push" },
    { 0x38D2, "debug_print" },
    { 0x38D3, "debug_print_target" },
    { 0x38D4, "debug_print_vo" },
    { 0x38D5, "debug_print3d" },
    { 0x38D6, "debug_print3d_simple" },
    { 0x38D7, "debug_println" },
    { 0x38D8, "debug_randomflightpathstest" },
    { 0x38D9, "debug_reach_drop_zone" },
    { 0x38DA, "debug_reach_lz" },
    { 0x38DB, "debug_reflection_buttons" },
    { 0x38DC, "debug_reflection_probes" },
    { 0x38DD, "debug_rooftop_heli_start" },
    { 0x38DE, "debug_rooftopobjstart" },
    { 0x38DF, "debug_safehouse_return_start" },
    { 0x38E0, "debug_safehouse_start" },
    { 0x38E1, "debug_set_relic" },
    { 0x38E2, "debug_set_super" },
    { 0x38E3, "debug_setup_warp_jeep_to_players" },
    { 0x38E4, "debug_setupmatchdata" },
    { 0x38E5, "debug_show_all_live_events" },
    { 0x38E6, "debug_start" },
    { 0x38E7, "debug_start_apprehension" },
    { 0x38E8, "debug_start_caches" },
    { 0x38E9, "debug_start_caches_threaded" },
    { 0x38EA, "debug_start_call" },
    { 0x38EB, "debug_start_convoyescort" },
    { 0x38EC, "debug_start_event_force" },
    { 0x38ED, "debug_start_extraction" },
    { 0x38EE, "debug_start_hostages" },
    { 0x38EF, "debug_start_iedrace" },
    { 0x38F0, "debug_start_keys" },
    { 0x38F1, "debug_start_overwatch" },
    { 0x38F2, "debug_start_switches" },
    { 0x38F3, "debug_start_terminal" },
    { 0x38F4, "debug_start_waittrain" },
    { 0x38F5, "debug_state_print" },
    { 0x38F6, "debug_stop_event_force" },
    { 0x38F7, "debug_stopenemypos" },
    { 0x38F8, "debug_struct" },
    { 0x38F9, "debug_tag_accessory" },
    { 0x38FA, "debug_teleport_to_c130" },
    { 0x38FB, "debug_temp_sphere" },
    { 0x38FC, "debug_test_next_mission" },
    { 0x38FD, "debug_testcratedroplocationpicker" },
    { 0x38FE, "debug_trigger_objective_events" },
    { 0x38FF, "debug_unset_relic" },
    { 0x3900, "debug_vault_assault_crypto" },
    { 0x3901, "debug_vault_assault_cut" },
    { 0x3902, "debug_vault_assault_hack" },
    { 0x3903, "debug_vault_assault_obj_start" },
    { 0x3904, "debug_vault_assault_roof_defend_start" },
    { 0x3905, "debug_vault_assault_roof_exfil_start" },
    { 0x3906, "debug_vault_assault_roof_obj_start" },
    { 0x3907, "debug_vault_assault_vault" },
    { 0x3908, "debug_vest_pos_ang" },
    { 0x3909, "debug_warp_jeep_to_player" },
    { 0x390A, "debug_watcharchivefinished" },
    { 0x390B, "debug_watcharchiveinterrupted" },
    { 0x390C, "debug_watcharchivesize" },
    { 0x390D, "debugafterlifearcadeenabled" },
    { 0x390E, "debugarmsraceobjectivestart" },
    { 0x390F, "debugbeatobjective" },
    { 0x3910, "debugbeatobjective3" },
    { 0x3911, "debugbroshot" },
    { 0x3912, "debugburstprint" },
    { 0x3913, "debugcaptureflares" },
    { 0x3914, "debugcircle" },
    { 0x3915, "debugcircleincircle" },
    { 0x3916, "debugcircleplayerfx" },
    { 0x3917, "debugcolorfriendlies" },
    { 0x3918, "debugdata" },
    { 0x3919, "debugdestroyempdrones" },
    { 0x391A, "debugdrawtocameras" },
    { 0x391B, "debugdvars" },
    { 0x391C, "debugemp" },
    { 0x391D, "debugempdrone" },
    { 0x391E, "debugequip_disguise" },
    { 0x391F, "debugexfilc130objective" },
    { 0x3920, "debugextractlz" },
    { 0x3921, "debugfakeduel" },
    { 0x3922, "debugfakewinner" },
    { 0x3923, "debuggiveperkpoints" },
    { 0x3924, "debughackequipment" },
    { 0x3925, "debugholdout" },
    { 0x3926, "debughostagegame" },
    { 0x3927, "debughud" },
    { 0x3928, "debuginfil_plane" },
    { 0x3929, "debuginstances" },
    { 0x392A, "debugjump" },
    { 0x392B, "debugkill_tunnel_spawns" },
    { 0x392C, "debuglandatlz" },
    { 0x392D, "debugline" },
    { 0x392E, "debuglitehud" },
    { 0x392F, "debugloc" },
    { 0x3930, "debugmisstime" },
    { 0x3931, "debugmisstimeoff" },
    { 0x3932, "debugmoralesobjectivesstart" },
    { 0x3933, "debugmovingplatformview" },
    { 0x3934, "debugnewspawnmodule" },
    { 0x3935, "debugorigin" },
    { 0x3936, "debugpathspheres" },
    { 0x3937, "debugpayloadobjectivesstart" },
    { 0x3938, "debugplanecircle" },
    { 0x3939, "debugplantjammers" },
    { 0x393A, "debugplayercirclevfx" },
    { 0x393B, "debugpos" },
    { 0x393C, "debugposinternal" },
    { 0x393D, "debugpossize" },
    { 0x393E, "debugprint" },
    { 0x393F, "debugprintevents" },
    { 0x3940, "debugprintline" },
    { 0x3941, "debugprintsquads" },
    { 0x3942, "debugqueueevents" },
    { 0x3943, "debugrecover_nuclear_core" },
    { 0x3944, "debugremoveinteractionandsendmessage" },
    { 0x3945, "debugresetguns" },
    { 0x3946, "debugrocks" },
    { 0x3947, "debugsetlasttime" },
    { 0x3948, "debugshutdown" },
    { 0x3949, "debugspawners" },
    { 0x394A, "debugspawnlocations" },
    { 0x394B, "debugspawns" },
    { 0x394C, "debugsphereonlocation" },
    { 0x394D, "debugstartc130objective" },
    { 0x394E, "debugstartdestroyc130" },
    { 0x394F, "debugtestcirclevfx" },
    { 0x3950, "debugthreat" },
    { 0x3951, "debugthreatcalc" },
    { 0x3952, "debugtimeout" },
    { 0x3953, "debugtmtylobjectivesstart" },
    { 0x3954, "debugview" },
    { 0x3955, "debugwarptojail" },
    { 0x3956, "debugwarptojailsingle" },
    { 0x3957, "debugweaponchangeprint" },
    { 0x3958, "decaygraceperiod" },
    { 0x3959, "decayholdtime" },
    { 0x395A, "decayrate" },
    { 0x395B, "decayreviveprogress" },
    { 0x395C, "decaythreshold" },
    { 0x395D, "decaytime" },
    { 0x395E, "decc" },
    { 0x395F, "decel" },
    { 0x3960, "decho_brakes_off" },
    { 0x3961, "decho_brakes_on" },
    { 0x3962, "decho_lights_off" },
    { 0x3963, "decho_lights_on" },
    { 0x3964, "decidenumcrawls" },
    { 0x3965, "decidenumshotsforburst" },
    { 0x3966, "decidenumshotsforfull" },
    { 0x3967, "decidenumshotsformg" },
    { 0x3968, "decidewhatandhowtoshoot" },
    { 0x3969, "deck_add" },
    { 0x396A, "deck_draw" },
    { 0x396B, "deck_draw_specific" },
    { 0x396C, "deck_is_empty" },
    { 0x396D, "deck_nag" },
    { 0x396E, "deck_nag_internal" },
    { 0x396F, "deck_remove" },
    { 0x3970, "deck_select_ready" },
    { 0x3971, "deck_shuffle" },
    { 0x3972, "decks" },
    { 0x3973, "decoy_activated" },
    { 0x3974, "decoy_addtogloballist" },
    { 0x3975, "decoy_debuffenemiesinrange" },
    { 0x3976, "decoy_debuffenemy" },
    { 0x3977, "decoy_delete" },
    { 0x3978, "decoy_destroy" },
    { 0x3979, "decoy_empapplied" },
    { 0x397A, "decoy_fireevent" },
    { 0x397B, "decoy_firesequence" },
    { 0x397C, "decoy_getfireeventangles" },
    { 0x397D, "decoy_getfireeventimpulse" },
    { 0x397E, "decoy_getfiretype" },
    { 0x397F, "decoy_getleveldata" },
    { 0x3980, "decoy_getvelocity" },
    { 0x3981, "decoy_givepointsfordestroy" },
    { 0x3982, "decoy_handledamage" },
    { 0x3983, "decoy_handlefataldamage" },
    { 0x3984, "decoy_init" },
    { 0x3985, "decoy_isonground" },
    { 0x3986, "decoy_isongroundraycastonly" },
    { 0x3987, "decoy_monitorfuse" },
    { 0x3988, "decoy_monitorposition" },
    { 0x3989, "decoy_removefromgloballist" },
    { 0x398A, "decoy_used" },
    { 0x398B, "decoygrenadedata" },
    { 0x398C, "decoygrenades" },
    { 0x398D, "decrease_delayed_spawn_slots" },
    { 0x398E, "decrease_escalation_counter" },
    { 0x398F, "decrease_hint_timer" },
    { 0x3990, "decrease_lookat_weight" },
    { 0x3991, "decrease_material_amount" },
    { 0x3992, "decrease_reserved_spawn_slots" },
    { 0x3993, "decrease_stealth_meter" },
    { 0x3994, "decrease_super_progress" },
    { 0x3995, "decrease_threatlevel" },
    { 0x3996, "decreasecurrentstealthvalue" },
    { 0x3997, "decrement_airdrop_requests" },
    { 0x3998, "decrement_counter_of_consumables" },
    { 0x3999, "decrement_door_count_on_death" },
    { 0x399A, "decrement_escalation_level" },
    { 0x399B, "decrement_list_offset" },
    { 0x399C, "decrement_spawners_using_count" },
    { 0x399D, "decrement_vehicles_active" },
    { 0x399E, "decrement_wave_veh_count" },
    { 0x399F, "decrementalivecount" },
    { 0x39A0, "decrementbulletsinclip" },
    { 0x39A1, "decrementcolorusers" },
    { 0x39A2, "decremented" },
    { 0x39A3, "decrementequipmentammo" },
    { 0x39A4, "decrementequipmentslotammo" },
    { 0x39A5, "decrementfauxvehiclecount" },
    { 0x39A6, "def" },
    { 0x39A7, "default_ambient_vals" },
    { 0x39A8, "default_ball_origin" },
    { 0x39A9, "default_door_node_flashbang_frequency" },
    { 0x39AA, "default_flag_origins" },
    { 0x39AB, "default_footsteps" },
    { 0x39AC, "default_gametype_think" },
    { 0x39AD, "default_goal_origins" },
    { 0x39AE, "default_goalheight" },
    { 0x39AF, "default_goalradius" },
    { 0x39B0, "default_if_undefined" },
    { 0x39B1, "default_init" },
    { 0x39B2, "default_init_objective" },
    { 0x39B3, "default_meleechargedist" },
    { 0x39B4, "default_on_damage" },
    { 0x39B5, "default_on_damage_finished" },
    { 0x39B6, "default_on_enter_animstate" },
    { 0x39B7, "default_on_killed" },
    { 0x39B8, "default_ondeadevent" },
    { 0x39B9, "default_onhalftime" },
    { 0x39BA, "default_ononeleftevent" },
    { 0x39BB, "default_ontimelimit" },
    { 0x39BC, "default_patrol_style" },
    { 0x39BD, "default_player_init_laststand" },
    { 0x39BE, "default_player_spawns" },
    { 0x39BF, "default_playerlaststand" },
    { 0x39C0, "default_prisoner_movement_speeds" },
    { 0x39C1, "default_should_update" },
    { 0x39C2, "default_spawn_func" },
    { 0x39C3, "default_start" },
    { 0x39C4, "default_start_override" },
    { 0x39C5, "default_start_override_alt" },
    { 0x39C6, "default_starting_melee_weapon" },
    { 0x39C7, "default_starting_pistol" },
    { 0x39C8, "default_strike_player_connect_black_screen" },
    { 0x39C9, "default_trigger_loop" },
    { 0x39CA, "default_undefined" },
    { 0x39CB, "default_unresolved_collision_handler" },
    { 0x39CC, "default_weapon" },
    { 0x39CD, "default_weapon_hint_func" },
    { 0x39CE, "default_weaponsetup" },
    { 0x39CF, "defaultalliesspawn" },
    { 0x39D0, "defaultalliesspawncamera" },
    { 0x39D1, "defaultaxisspawn" },
    { 0x39D2, "defaultaxisspawncamera" },
    { 0x39D3, "defaultbody" },
    { 0x39D4, "defaultbodymodels" },
    { 0x39D5, "defaultcapturevisualscallback" },
    { 0x39D6, "defaultclass" },
    { 0x39D7, "defaultcompleteobjective" },
    { 0x39D8, "defaultdamagenotify" },
    { 0x39D9, "defaultdestroyvisualscallback" },
    { 0x39DA, "defaultdroppitch" },
    { 0x39DB, "defaultdropyaw" },
    { 0x39DC, "defaultemissive" },
    { 0x39DD, "defaultendgame" },
    { 0x39DE, "defaultexception" },
    { 0x39DF, "defaultfilter" },
    { 0x39E0, "defaultgetspawnpoint" },
    { 0x39E1, "defaulthead" },
    { 0x39E2, "defaultheadmodels" },
    { 0x39E3, "defaulthostmigration" },
    { 0x39E4, "defaultlightfx" },
    { 0x39E5, "defaultnvgvision" },
    { 0x39E6, "defaultonmode" },
    { 0x39E7, "defaultoperatorskinindex" },
    { 0x39E8, "defaultoperatorskins" },
    { 0x39E9, "defaultoperatorteam" },
    { 0x39EA, "defaultownerteam" },
    { 0x39EB, "defaultpitchturnthreshold" },
    { 0x39EC, "defaultplayerconnect" },
    { 0x39ED, "defaultplayerdamage" },
    { 0x39EE, "defaultplayerdisconnect" },
    { 0x39EF, "defaultplayerkilled" },
    { 0x39F0, "defaultplayermaxhealth" },
    { 0x39F1, "defaultplayermigrated" },
    { 0x39F2, "defaults" },
    { 0x39F3, "defaultslot" },
    { 0x39F4, "defaultsortfunc" },
    { 0x39F5, "defaultspectaterules" },
    { 0x39F6, "defaulttalk" },
    { 0x39F7, "defaultturnthreshold" },
    { 0x39F8, "defaultusetime" },
    { 0x39F9, "defaultviewarmmodels" },
    { 0x39FA, "defaultvm" },
    { 0x39FB, "defaultvoices" },
    { 0x39FC, "defaultweapon" },
    { 0x39FD, "defaultweight" },
    { 0x39FE, "defconlevel" },
    { 0x39FF, "defeated_on_kill_backup" },
    { 0x3A00, "defeatedlookat" },
    { 0x3A01, "defend_approach_catchup" },
    { 0x3A02, "defend_approach_hadir_to_roof" },
    { 0x3A03, "defend_approach_main" },
    { 0x3A04, "defend_approach_start" },
    { 0x3A05, "defend_autosaves" },
    { 0x3A06, "defend_entrance_index" },
    { 0x3A07, "defend_flag" },
    { 0x3A08, "defend_get_ally_bots_at_zone_for_stance" },
    { 0x3A09, "defend_inits" },
    { 0x3A0A, "defend_mortar_house_favela" },
    { 0x3A0B, "defend_objective_radius" },
    { 0x3A0C, "defend_planted_bomb_update" },
    { 0x3A0D, "defend_push_weapon_cleanup" },
    { 0x3A0E, "defend_valid_center" },
    { 0x3A0F, "defend_wait_time_when_no_path" },
    { 0x3A10, "defend_wave_0_catchup" },
    { 0x3A11, "defend_wave_0_main" },
    { 0x3A12, "defend_wave_0_start" },
    { 0x3A13, "defend_wave_1_catchup" },
    { 0x3A14, "defend_wave_1_main" },
    { 0x3A15, "defend_wave_1_start" },
    { 0x3A16, "defend_wave_2_mortars_catchup" },
    { 0x3A17, "defend_wave_2_mortars_main" },
    { 0x3A18, "defend_wave_2_mortars_start" },
    { 0x3A19, "defend_wave_2_push_catchup" },
    { 0x3A1A, "defend_wave_2_push_main" },
    { 0x3A1B, "defend_wave_2_push_start" },
    { 0x3A1C, "defend_wave_2_trucks_catchup" },
    { 0x3A1D, "defend_wave_2_trucks_main" },
    { 0x3A1E, "defend_wave_2_trucks_start" },
    { 0x3A1F, "defend_wave_3_buildings_catchup" },
    { 0x3A20, "defend_wave_3_buildings_main" },
    { 0x3A21, "defend_wave_3_buildings_start" },
    { 0x3A22, "defend_wave_3_ladder_vo" },
    { 0x3A23, "defend_wave_3_triage_catchup" },
    { 0x3A24, "defend_wave_3_triage_main" },
    { 0x3A25, "defend_wave_3_triage_start" },
    { 0x3A26, "defend_wave_4_snipers_main" },
    { 0x3A27, "defend_wave_4_snipers_start" },
    { 0x3A28, "defend_wave_4_targeting_catchup" },
    { 0x3A29, "defend_wave_4_targeting_main" },
    { 0x3A2A, "defend_wave_4_targeting_start" },
    { 0x3A2B, "defend_wave_4_technicles_catchup" },
    { 0x3A2C, "defend_wave_4_technicles_main" },
    { 0x3A2D, "defend_wave_4_technicles_start" },
    { 0x3A2E, "defend_wave_5_mortar_attack_catchup" },
    { 0x3A2F, "defend_wave_5_mortar_attack_main" },
    { 0x3A30, "defend_wave_5_mortar_attack_start" },
    { 0x3A31, "defend_wave_5_mortar_house_boost_catchup" },
    { 0x3A32, "defend_wave_5_mortar_house_boost_main" },
    { 0x3A33, "defend_wave_5_mortar_house_boost_start" },
    { 0x3A34, "defend_wave_5_mortar_house_catchup" },
    { 0x3A35, "defend_wave_5_mortar_house_main" },
    { 0x3A36, "defend_wave_5_mortar_house_start" },
    { 0x3A37, "defend_wave_6_catchup" },
    { 0x3A38, "defend_wave_6_main" },
    { 0x3A39, "defend_wave_6_start" },
    { 0x3A3A, "defend_while_chopper_arrives" },
    { 0x3A3B, "defend_wolf_escapes_catchup" },
    { 0x3A3C, "defend_wolf_escapes_ending" },
    { 0x3A3D, "defend_wolf_escapes_ending_camera_settings" },
    { 0x3A3E, "defend_wolf_escapes_main" },
    { 0x3A3F, "defend_wolf_escapes_scene_main" },
    { 0x3A40, "defend_wolf_escapes_scene_start" },
    { 0x3A41, "defend_wolf_escapes_start" },
    { 0x3A42, "defend_wolf_hostage" },
    { 0x3A43, "defend_zone" },
    { 0x3A44, "defendedplayer" },
    { 0x3A45, "defender_set_script_pathstyle" },
    { 0x3A46, "defender_update" },
    { 0x3A47, "defenderendzone" },
    { 0x3A48, "defendloc" },
    { 0x3A49, "defendlocation" },
    { 0x3A4A, "defendlocationescort" },
    { 0x3A4B, "defense_cautious_approach" },
    { 0x3A4C, "defense_death_monitor" },
    { 0x3A4D, "defense_force_next_node_goal" },
    { 0x3A4E, "defense_get_initial_entrances" },
    { 0x3A4F, "defense_investigate_specific_point" },
    { 0x3A50, "defense_override_entrances" },
    { 0x3A51, "defense_override_watch_nodes" },
    { 0x3A52, "defense_score_flags" },
    { 0x3A53, "defense_sequence_duration" },
    { 0x3A54, "defense_watch_entrances_at_goal" },
    { 0x3A55, "defibrillator" },
    { 0x3A56, "define" },
    { 0x3A57, "define_as_cluster_spawner" },
    { 0x3A58, "define_as_vehicle_spawner" },
    { 0x3A59, "define_crafting_materials" },
    { 0x3A5A, "define_face_anim_if_exists" },
    { 0x3A5B, "define_interacton_position" },
    { 0x3A5C, "define_spawner" },
    { 0x3A5D, "define_var_if_undefined" },
    { 0x3A5E, "definechestweapons" },
    { 0x3A5F, "definepassivevalue" },
    { 0x3A60, "defineplayerloadout" },
    { 0x3A61, "definepowerovertimeduration" },
    { 0x3A62, "defines" },
    { 0x3A63, "defuse_bomb" },
    { 0x3A64, "defuse_count" },
    { 0x3A65, "defuse_failed" },
    { 0x3A66, "defuse_tripwires" },
    { 0x3A67, "defusec4" },
    { 0x3A68, "defused" },
    { 0x3A69, "defuseendtime" },
    { 0x3A6A, "defusehintstruct" },
    { 0x3A6B, "defuser_bad_path_counter" },
    { 0x3A6C, "defuser_wait_for_death" },
    { 0x3A6D, "defusethink" },
    { 0x3A6E, "defusetime" },
    { 0x3A6F, "defusetrig" },
    { 0x3A70, "defuseusemonitoring" },
    { 0x3A71, "dejected_idle_count" },
    { 0x3A72, "delay" },
    { 0x3A73, "delay_activate_laser" },
    { 0x3A74, "delay_allow_pickup" },
    { 0x3A75, "delay_allowdeath" },
    { 0x3A76, "delay_and_play_vo_to_team" },
    { 0x3A77, "delay_before_delete" },
    { 0x3A78, "delay_coop_escort_spawning" },
    { 0x3A79, "delay_debug_roof_start" },
    { 0x3A7A, "delay_delete" },
    { 0x3A7B, "delay_delete_combat_icon" },
    { 0x3A7C, "delay_delete_objective" },
    { 0x3A7D, "delay_deletescriptable" },
    { 0x3A7E, "delay_demeanor_override" },
    { 0x3A7F, "delay_deploy_friendly_convoy" },
    { 0x3A80, "delay_deploy_suicide_truck" },
    { 0x3A81, "delay_disable_use" },
    { 0x3A82, "delay_end_game_hvt_escaped" },
    { 0x3A83, "delay_endon" },
    { 0x3A84, "delay_enter_combat" },
    { 0x3A85, "delay_enter_combat_after_stealth" },
    { 0x3A86, "delay_enter_vehicle" },
    { 0x3A87, "delay_exit_drone" },
    { 0x3A88, "delay_fade" },
    { 0x3A89, "delay_for_clip" },
    { 0x3A8A, "delay_give_archetype_loadout" },
    { 0x3A8B, "delay_giving_controls_back" },
    { 0x3A8C, "delay_hide_progress_widget" },
    { 0x3A8D, "delay_hint" },
    { 0x3A8E, "delay_init_infil" },
    { 0x3A8F, "delay_jackal_arrive_sfx" },
    { 0x3A90, "delay_kill_convoy_accessories" },
    { 0x3A91, "delay_kill_convoy_ents" },
    { 0x3A92, "delay_kill_convoy_riders" },
    { 0x3A93, "delay_kill_main_truck" },
    { 0x3A94, "delay_nag_mark_ied_vo" },
    { 0x3A95, "delay_node_creation_from_look_at" },
    { 0x3A96, "delay_node_creation_from_single_point" },
    { 0x3A97, "delay_nvgs" },
    { 0x3A98, "delay_objective_update" },
    { 0x3A99, "delay_orbit_cam" },
    { 0x3A9A, "delay_plane_explosion" },
    { 0x3A9B, "delay_play_ignition_vfx" },
    { 0x3A9C, "delay_play_marker_vfx_to_players_waiting_to_respawn" },
    { 0x3A9D, "delay_player_open_door_monitor" },
    { 0x3A9E, "delay_player_say_attached" },
    { 0x3A9F, "delay_player_say_hellyeah" },
    { 0x3AA0, "delay_player_say_in_air" },
    { 0x3AA1, "delay_poi_enable" },
    { 0x3AA2, "delay_relax_view_arc" },
    { 0x3AA3, "delay_reset_player_wander_nag" },
    { 0x3AA4, "delay_reset_team_score_omnvar" },
    { 0x3AA5, "delay_respawn_ied_zone" },
    { 0x3AA6, "delay_set_goal_volume" },
    { 0x3AA7, "delay_set_plane_specific_vars" },
    { 0x3AA8, "delay_set_starge_three_flag" },
    { 0x3AA9, "delay_set_starge_two_flag" },
    { 0x3AAA, "delay_set_team_score_omnvar" },
    { 0x3AAB, "delay_set_up_coop_push" },
    { 0x3AAC, "delay_set_up_ieds" },
    { 0x3AAD, "delay_spawn_player_vehicle" },
    { 0x3AAE, "delay_start" },
    { 0x3AAF, "delay_start_cover_node_spawning" },
    { 0x3AB0, "delay_start_gun_game" },
    { 0x3AB1, "delay_start_player_wire_cutting_think" },
    { 0x3AB2, "delay_start_specified_module" },
    { 0x3AB3, "delay_start_wave_spawning" },
    { 0x3AB4, "delay_str" },
    { 0x3AB5, "delay_suspend_vehicle" },
    { 0x3AB6, "delay_target_cruise_missile_target" },
    { 0x3AB7, "delay_teleport_players" },
    { 0x3AB8, "delay_test_explodes" },
    { 0x3AB9, "delay_then_run_cover_node_spawning" },
    { 0x3ABA, "delay_then_run_spawn_module" },
    { 0x3ABB, "delay_time" },
    { 0x3ABC, "delay_turn_on_birds_eye_hud" },
    { 0x3ABD, "delay_unset_wire_color_shown_on_bomb_detonator" },
    { 0x3ABE, "delay_until_first_shot" },
    { 0x3ABF, "delay_update_damagefeedback" },
    { 0x3AC0, "delay_use_assault_drone_vo" },
    { 0x3AC1, "delay_use_gunner_turret_vo" },
    { 0x3AC2, "delay_values" },
    { 0x3AC3, "delay_vip_death_vo" },
    { 0x3AC4, "delaybulletshow" },
    { 0x3AC5, "delaybulletvfx" },
    { 0x3AC6, "delaycall" },
    { 0x3AC7, "delaycall_proc" },
    { 0x3AC8, "delaycall_proc_watchself" },
    { 0x3AC9, "delaycallwatchself" },
    { 0x3ACA, "delaychildthread" },
    { 0x3ACB, "delaychildthread_proc" },
    { 0x3ACC, "delaydeletefxents" },
    { 0x3ACD, "delaydialogstatustoavoidcaptureoverlap" },
    { 0x3ACE, "delaydisabledof" },
    { 0x3ACF, "delayed_activation_stim" },
    { 0x3AD0, "delayed_creation_calls" },
    { 0x3AD1, "delayed_disable_respawns" },
    { 0x3AD2, "delayed_earthquake" },
    { 0x3AD3, "delayed_enable_fulton_extract" },
    { 0x3AD4, "delayed_player_seek_think" },
    { 0x3AD5, "delayed_remove_peent_interaction" },
    { 0x3AD6, "delayed_spawn_slots" },
    { 0x3AD7, "delayed_stun_damage" },
    { 0x3AD8, "delayed_trigger_unset" },
    { 0x3AD9, "delayedfofoverlay" },
    { 0x3ADA, "delayedhostagespawn" },
    { 0x3ADB, "delayedleaderdialog" },
    { 0x3ADC, "delayedprocesskill" },
    { 0x3ADD, "delayedspawnedplayernotify" },
    { 0x3ADE, "delayedsuperbonus" },
    { 0x3ADF, "delayenabledof" },
    { 0x3AE0, "delayentdelete" },
    { 0x3AE1, "delayer" },
    { 0x3AE2, "delayfxcall" },
    { 0x3AE3, "delayfxdelete" },
    { 0x3AE4, "delaygivecurrency" },
    { 0x3AE5, "delayinc" },
    { 0x3AE6, "delayjackalloopsfx" },
    { 0x3AE7, "delaykill" },
    { 0x3AE8, "delayleadtakendialog" },
    { 0x3AE9, "delayminetime" },
    { 0x3AEA, "delaymodifybasefov" },
    { 0x3AEB, "delayplayer" },
    { 0x3AEC, "delayplayerscorepopup" },
    { 0x3AED, "delayplayerwarning" },
    { 0x3AEE, "delayreturningperks" },
    { 0x3AEF, "delayscriptablechangethread" },
    { 0x3AF0, "delayset" },
    { 0x3AF1, "delaysetclientomnvar" },
    { 0x3AF2, "delayslowmotion" },
    { 0x3AF3, "delayspawntoc130" },
    { 0x3AF4, "delayspawnuntilpointcap" },
    { 0x3AF5, "delaystartragdoll" },
    { 0x3AF6, "delayswaploadout" },
    { 0x3AF7, "delaytakeminigun" },
    { 0x3AF8, "delaythread" },
    { 0x3AF9, "delaythread_proc" },
    { 0x3AFA, "delayusetime" },
    { 0x3AFB, "deletable_magic_bullet_shield" },
    { 0x3AFC, "deletables_convoy_ambush" },
    { 0x3AFD, "deletables_thread" },
    { 0x3AFE, "deletables_wait_convoy_ambush" },
    { 0x3AFF, "delete_accessories" },
    { 0x3B00, "delete_after_anim" },
    { 0x3B01, "delete_after_time" },
    { 0x3B02, "delete_aiment" },
    { 0x3B03, "delete_all_bad_guys" },
    { 0x3B04, "delete_all_leads" },
    { 0x3B05, "delete_all_molotovs" },
    { 0x3B06, "delete_all_script_models_with_modelname" },
    { 0x3B07, "delete_all_script_models_with_modelname_async" },
    { 0x3B08, "delete_all_team_chain_objectives" },
    { 0x3B09, "delete_all_vehicles_in_friendly_convoy" },
    { 0x3B0A, "delete_alley_trucks_monitor" },
    { 0x3B0B, "delete_allies" },
    { 0x3B0C, "delete_at_distance_to_player" },
    { 0x3B0D, "delete_barricaded_door_boards" },
    { 0x3B0E, "delete_basement_runner_wait_trig" },
    { 0x3B0F, "delete_bomb_strip" },
    { 0x3B10, "delete_breadcrumb" },
    { 0x3B11, "delete_breadcrumb_array" },
    { 0x3B12, "delete_camera_point" },
    { 0x3B13, "delete_cattleprod" },
    { 0x3B14, "delete_center_guys" },
    { 0x3B15, "delete_clip_during_walk" },
    { 0x3B16, "delete_combat_icon" },
    { 0x3B17, "delete_convoy_at_pathend" },
    { 0x3B18, "delete_corpses_around_pos" },
    { 0x3B19, "delete_cover_after_timer" },
    { 0x3B1A, "delete_critical_target_icon_on_death" },
    { 0x3B1B, "delete_destructibles_in_volumes" },
    { 0x3B1C, "delete_door" },
    { 0x3B1D, "delete_drone_model" },
    { 0x3B1E, "delete_exploder" },
    { 0x3B1F, "delete_exploder_proc" },
    { 0x3B20, "delete_exploders_in_volumes" },
    { 0x3B21, "delete_fly_choppers" },
    { 0x3B22, "delete_grenade_when_thrown" },
    { 0x3B23, "delete_ied_marker_vfx_to_non_overwatch" },
    { 0x3B24, "delete_interactives_in_volumes" },
    { 0x3B25, "delete_last_second_grenade_throws" },
    { 0x3B26, "delete_launchers_on_death" },
    { 0x3B27, "delete_links_then_self" },
    { 0x3B28, "delete_live_grenades" },
    { 0x3B29, "delete_lotus_decho" },
    { 0x3B2A, "delete_magic_flash_if_triggered" },
    { 0x3B2B, "delete_mansion_spawners" },
    { 0x3B2C, "delete_model_and_fx_on_crate_drop" },
    { 0x3B2D, "delete_molotov" },
    { 0x3B2E, "delete_my_drone_models" },
    { 0x3B2F, "delete_my_old_path" },
    { 0x3B30, "delete_my_script_collision" },
    { 0x3B31, "delete_nav_obstacle" },
    { 0x3B32, "delete_nav_obstacle_on_death" },
    { 0x3B33, "delete_non_overwatch_ied_marker_vfx_for_player" },
    { 0x3B34, "delete_noteworthy_ents" },
    { 0x3B35, "delete_objective" },
    { 0x3B36, "delete_off_screen" },
    { 0x3B37, "delete_old_objective_location" },
    { 0x3B38, "delete_old_rebels" },
    { 0x3B39, "delete_on_animend" },
    { 0x3B3A, "delete_on_death" },
    { 0x3B3B, "delete_on_death_delayed" },
    { 0x3B3C, "delete_on_death_wait_sound" },
    { 0x3B3D, "delete_on_end" },
    { 0x3B3E, "delete_on_ent_notify" },
    { 0x3B3F, "delete_on_flag" },
    { 0x3B40, "delete_on_level_notify" },
    { 0x3B41, "delete_on_load" },
    { 0x3B42, "delete_on_notify" },
    { 0x3B43, "delete_on_notify_delay" },
    { 0x3B44, "delete_on_removed" },
    { 0x3B45, "delete_on_sounddone" },
    { 0x3B46, "delete_onflag" },
    { 0x3B47, "delete_org_on_finish" },
    { 0x3B48, "delete_orgs" },
    { 0x3B49, "delete_player_overlay" },
    { 0x3B4A, "delete_pressed" },
    { 0x3B4B, "delete_rebar_model" },
    { 0x3B4C, "delete_respawner_markers" },
    { 0x3B4D, "delete_riders" },
    { 0x3B4E, "delete_screens" },
    { 0x3B4F, "delete_scriptables_in_bar" },
    { 0x3B50, "delete_scriptables_in_canal" },
    { 0x3B51, "delete_selection" },
    { 0x3B52, "delete_shell" },
    { 0x3B53, "delete_stealth_meter" },
    { 0x3B54, "delete_storefront_signs" },
    { 0x3B55, "delete_targetname" },
    { 0x3B56, "delete_technical_roof_trig" },
    { 0x3B57, "delete_tires" },
    { 0x3B58, "delete_trigger_with_noteworthy" },
    { 0x3B59, "delete_trigger_with_targetname" },
    { 0x3B5A, "delete_vehicles_turrets" },
    { 0x3B5B, "delete_waste_groundfloor" },
    { 0x3B5C, "delete_weapon_after_time" },
    { 0x3B5D, "delete_when_dist_away" },
    { 0x3B5E, "delete_when_offscreen" },
    { 0x3B5F, "delete_window_blocker" },
    { 0x3B60, "deleteaftertime" },
    { 0x3B61, "deleteallgrenades" },
    { 0x3B62, "deleteatframeend" },
    { 0x3B63, "deletebullet" },
    { 0x3B64, "deletecarryobject" },
    { 0x3B65, "deletecover" },
    { 0x3B66, "deletecrate" },
    { 0x3B67, "deletecrateold" },
    { 0x3B68, "deletedelay" },
    { 0x3B69, "deletedestructiblekillcament" },
    { 0x3B6A, "deletedisparateplacedequipment" },
    { 0x3B6B, "deletedomflaggameobject" },
    { 0x3B6C, "deletedriver" },
    { 0x3B6D, "deletedroppedobject" },
    { 0x3B6E, "deletedroppedscriptablebatch" },
    { 0x3B6F, "deleteendzone" },
    { 0x3B70, "deleteepictauntprops" },
    { 0x3B71, "deleteexplosive" },
    { 0x3B72, "deleteextantvehicles" },
    { 0x3B73, "deletefunc" },
    { 0x3B74, "deletehandler" },
    { 0x3B75, "deleteheli" },
    { 0x3B76, "deleteinfilclip" },
    { 0x3B77, "deleteme" },
    { 0x3B78, "deletemine" },
    { 0x3B79, "deleteobjectiveicon" },
    { 0x3B7A, "deleteobjpoint" },
    { 0x3B7B, "deleteondeath" },
    { 0x3B7C, "deleteonentnotify" },
    { 0x3B7D, "deleteoninfilcomplete" },
    { 0x3B7E, "deleteonownerdeath" },
    { 0x3B7F, "deleteonparentdeath" },
    { 0x3B80, "deleteonplayerdeathdisconnect" },
    { 0x3B81, "deleteonspawn" },
    { 0x3B82, "deleteotpreview" },
    { 0x3B83, "deletepentsondisconnect" },
    { 0x3B84, "deletepentsonrespawn" },
    { 0x3B85, "deletepickupafterawhile" },
    { 0x3B86, "deletepickuphostage" },
    { 0x3B87, "deleteplacedequipment" },
    { 0x3B88, "deleteshortly" },
    { 0x3B89, "deletespawncamera" },
    { 0x3B8A, "deletesquad" },
    { 0x3B8B, "deletestackedstreak" },
    { 0x3B8C, "deletestruct_ref" },
    { 0x3B8D, "deletestructarray" },
    { 0x3B8E, "deletestructarray_ref" },
    { 0x3B8F, "deletetacinsert" },
    { 0x3B90, "deletetrackedobject" },
    { 0x3B91, "deletetrackedobjectoncarrierdisconnect" },
    { 0x3B92, "deleteuseent" },
    { 0x3B93, "deleteuseobject" },
    { 0x3B94, "deletevfx" },
    { 0x3B95, "deleting" },
    { 0x3B96, "delivertime" },
    { 0x3B97, "deliverybox" },
    { 0x3B98, "deliverydrone_delivertopoint" },
    { 0x3B99, "deliverytarget" },
    { 0x3B9A, "delta_to_mover" },
    { 0x3B9B, "demeanor_exit_func_wait" },
    { 0x3B9C, "demeanor_hack" },
    { 0x3B9D, "demeanor_override" },
    { 0x3B9E, "demeanor_override_all_enemies" },
    { 0x3B9F, "demeanor_switch" },
    { 0x3BA0, "demeanorhasblendspace" },
    { 0x3BA1, "demeanoroverride" },
    { 0x3BA2, "demeanorsafeenabled" },
    { 0x3BA3, "demeanorsprintdisable" },
    { 0x3BA4, "demo" },
    { 0x3BA5, "demo_allowed_debug_outline" },
    { 0x3BA6, "demo_bathroom_fakeblood" },
    { 0x3BA7, "demo_button_combo_debug_watcher" },
    { 0x3BA8, "demo_button_combos" },
    { 0x3BA9, "demo_debug_outline_button_watcher" },
    { 0x3BAA, "demo_debug_outline_settings" },
    { 0x3BAB, "demo_toggle_godmode" },
    { 0x3BAC, "demo_toggle_infiniteammo" },
    { 0x3BAD, "demo_toggle_ufo" },
    { 0x3BAE, "demo_trigger_damage" },
    { 0x3BAF, "density" },
    { 0x3BB0, "density_cap" },
    { 0x3BB1, "density_cap_count" },
    { 0x3BB2, "density_radius" },
    { 0x3BB3, "denyascendmessage" },
    { 0x3BB4, "denyclasschoice" },
    { 0x3BB5, "denysystemicteamchoice" },
    { 0x3BB6, "depends" },
    { 0x3BB7, "deploy_ac130_drone" },
    { 0x3BB8, "deploy_collection_drone" },
    { 0x3BB9, "deploy_concrtete_blockers_for_puzzle" },
    { 0x3BBA, "deploy_drone" },
    { 0x3BBB, "deploy_enemy_turret" },
    { 0x3BBC, "deploy_enemy_turrets" },
    { 0x3BBD, "deploy_fast_rope" },
    { 0x3BBE, "deploy_friendly_convoy" },
    { 0x3BBF, "deploy_friendly_hvi_vehicle" },
    { 0x3BC0, "deploy_friendly_reinforcement_convoy" },
    { 0x3BC1, "deploy_helper_drone_actual" },
    { 0x3BC2, "deploy_ladder" },
    { 0x3BC3, "deploy_scout_detonate_drone" },
    { 0x3BC4, "deploy_scout_drone" },
    { 0x3BC5, "deploy_scout_drone_generic" },
    { 0x3BC6, "deploy_smoke_grenades_for_infil" },
    { 0x3BC7, "deploy_smoke_grenades_for_infil_via_structs" },
    { 0x3BC8, "deploy_suicide_truck" },
    { 0x3BC9, "deploy_vehicle" },
    { 0x3BCA, "deploy_vehicle_to_push" },
    { 0x3BCB, "deployable_box" },
    { 0x3BCC, "deployable_box_interaction" },
    { 0x3BCD, "deployable_box_onuse_message" },
    { 0x3BCE, "deployable_ladder_init" },
    { 0x3BCF, "deployable_ladder_thread" },
    { 0x3BD0, "deployablebox_vest_max" },
    { 0x3BD1, "deployablebox_vest_rank" },
    { 0x3BD2, "deployableexclusion" },
    { 0x3BD3, "deployables" },
    { 0x3BD4, "deployanimduration" },
    { 0x3BD5, "deployedsfx" },
    { 0x3BD6, "deployflares" },
    { 0x3BD7, "deployfunc" },
    { 0x3BD8, "deployweaponname" },
    { 0x3BD9, "deployweaponobj" },
    { 0x3BDA, "deployweapontaken" },
    { 0x3BDB, "deposit_ai_from_drones_in_vehicle" },
    { 0x3BDC, "deposit_box_activate" },
    { 0x3BDD, "deposit_box_hint" },
    { 0x3BDE, "deposit_box_interactions" },
    { 0x3BDF, "deposit_box_search" },
    { 0x3BE0, "depotmakeunsabletoall" },
    { 0x3BE1, "depotmakeunusabletoplayer" },
    { 0x3BE2, "depotmakeusabletoplayer" },
    { 0x3BE3, "depotplayerprogressthink" },
    { 0x3BE4, "depotprogressthink" },
    { 0x3BE5, "depotthink" },
    { 0x3BE6, "depthoffieldvalues" },
    { 0x3BE7, "dequeuecorpsetablefunc" },
    { 0x3BE8, "deregistered" },
    { 0x3BE9, "deregisterentforoob" },
    { 0x3BEA, "deregisterloot" },
    { 0x3BEB, "deregisterpotgentity" },
    { 0x3BEC, "deregisterspawn" },
    { 0x3BED, "descend" },
    { 0x3BEE, "descendstarts" },
    { 0x3BEF, "describerole" },
    { 0x3BF0, "description" },
    { 0x3BF1, "deselect" },
    { 0x3BF2, "deselect_all_ents" },
    { 0x3BF3, "deselect_entity" },
    { 0x3BF4, "desired_accel" },
    { 0x3BF5, "desired_anim_pose" },
    { 0x3BF6, "desired_dist_from_vehicle_to_chase" },
    { 0x3BF7, "desired_enemy_deaths_this_wave" },
    { 0x3BF8, "desired_speed" },
    { 0x3BF9, "desiredaction" },
    { 0x3BFA, "desiredaimpos" },
    { 0x3BFB, "desiredbone" },
    { 0x3BFC, "desiredmovetype" },
    { 0x3BFD, "desiredtimeofdeath" },
    { 0x3BFE, "desiredturnyaw" },
    { 0x3BFF, "desiredturretposeis" },
    { 0x3C00, "despawn_dist" },
    { 0x3C01, "despawn_dist_enable" },
    { 0x3C02, "despawn_hostage" },
    { 0x3C03, "despawned_vehicles" },
    { 0x3C04, "destination" },
    { 0x3C05, "destinationentity" },
    { 0x3C06, "destinationhit" },
    { 0x3C07, "destinationnormal" },
    { 0x3C08, "destinationtime" },
    { 0x3C09, "destoyedsplash" },
    { 0x3C0A, "destroy_bleedout_timer" },
    { 0x3C0B, "destroy_building" },
    { 0x3C0C, "destroy_cars" },
    { 0x3C0D, "destroy_dialogue_hud" },
    { 0x3C0E, "destroy_dyndof" },
    { 0x3C0F, "destroy_first_roof_mortar" },
    { 0x3C10, "destroy_hint_on_endon" },
    { 0x3C11, "destroy_hint_on_endon_proc" },
    { 0x3C12, "destroy_hint_on_friendlyfire" },
    { 0x3C13, "destroy_hint_on_player_death" },
    { 0x3C14, "destroy_menu" },
    { 0x3C15, "destroy_objective_waypoint" },
    { 0x3C16, "destroy_scripternote" },
    { 0x3C17, "destroy_scripternote_bg" },
    { 0x3C18, "destroy_service_fusebox" },
    { 0x3C19, "destroyactiveobjects" },
    { 0x3C1A, "destroycallback" },
    { 0x3C1B, "destroychute" },
    { 0x3C1C, "destroycrate" },
    { 0x3C1D, "destroydangerzone" },
    { 0x3C1E, "destroydroneoncollision" },
    { 0x3C1F, "destroyed" },
    { 0x3C20, "destroyedapc" },
    { 0x3C21, "destroyedbydamage" },
    { 0x3C22, "destroyedobject" },
    { 0x3C23, "destroyedsplash" },
    { 0x3C24, "destroyedvo" },
    { 0x3C25, "destroyelem" },
    { 0x3C26, "destroyemitters" },
    { 0x3C27, "destroyenemyiconslowly" },
    { 0x3C28, "destroyexplosiveoncollision" },
    { 0x3C29, "destroyheadiconsondeath" },
    { 0x3C2A, "destroyheli" },
    { 0x3C2B, "destroyhelicallback" },
    { 0x3C2C, "destroyhqaftertime" },
    { 0x3C2D, "destroyiconsondeath" },
    { 0x3C2E, "destroying" },
    { 0x3C2F, "destroylight" },
    { 0x3C30, "destroylootnotification" },
    { 0x3C31, "destroyminimapicon" },
    { 0x3C32, "destroymountmantlemodel" },
    { 0x3C33, "destroyonactivate" },
    { 0x3C34, "destroyoncapture" },
    { 0x3C35, "destroyonownerdisconnect" },
    { 0x3C36, "destroyoverlay" },
    { 0x3C37, "destroyslowly" },
    { 0x3C38, "destroytvs" },
    { 0x3C39, "destroyvisualscallback" },
    { 0x3C3A, "destroyvisualsdeletiondelay" },
    { 0x3C3B, "destructable_destruct" },
    { 0x3C3C, "destructable_think" },
    { 0x3C3D, "destructible" },
    { 0x3C3E, "destructible_death" },
    { 0x3C3F, "destructible_ignore_attacker" },
    { 0x3C40, "destructible_interactions" },
    { 0x3C41, "destructible_model" },
    { 0x3C42, "destructible_objective_think" },
    { 0x3C43, "destructible_objectives_init" },
    { 0x3C44, "destructible_perimeter" },
    { 0x3C45, "destructible_piece_thread" },
    { 0x3C46, "destructible_vehicle_init" },
    { 0x3C47, "destructible_vehicle_main" },
    { 0x3C48, "destructible_vehicle_thread" },
    { 0x3C49, "destructible_wall_mortar_end" },
    { 0x3C4A, "destructibles" },
    { 0x3C4B, "destructibletrucksetup" },
    { 0x3C4C, "destruction_encounterstart" },
    { 0x3C4D, "det_sparks_vfx" },
    { 0x3C4E, "detach_bomb" },
    { 0x3C4F, "detach_getoutrigs" },
    { 0x3C50, "detach_linkedaniment" },
    { 0x3C51, "detach_linkedaniments" },
    { 0x3C52, "detach_models_with_substr" },
    { 0x3C53, "detach_player_knife" },
    { 0x3C54, "detachallweaponmodels" },
    { 0x3C55, "detachflag" },
    { 0x3C56, "detachflashlight" },
    { 0x3C57, "detachgrenadeonscriptchange" },
    { 0x3C58, "detachifattached" },
    { 0x3C59, "detachobjectifcarried" },
    { 0x3C5A, "detachusemodels" },
    { 0x3C5B, "detachweapon" },
    { 0x3C5C, "detect" },
    { 0x3C5D, "detect_bulletwhizby" },
    { 0x3C5E, "detect_distsqrd" },
    { 0x3C5F, "detect_events" },
    { 0x3C60, "detect_people" },
    { 0x3C61, "detect_people_trigger" },
    { 0x3C62, "detect_player_death" },
    { 0x3C63, "detect_player_event" },
    { 0x3C64, "detect_player_leaving_after_wolf_death" },
    { 0x3C65, "detected_temp_stealth_meter" },
    { 0x3C66, "detected_temp_stealth_meter_delete" },
    { 0x3C67, "detectfriendlyfireonentity" },
    { 0x3C68, "detection" },
    { 0x3C69, "detectiongraceperiod" },
    { 0x3C6A, "detectionheight" },
    { 0x3C6B, "detectionradius" },
    { 0x3C6C, "detectplayerdamage" },
    { 0x3C6D, "detectplayersinvicinity" },
    { 0x3C6E, "determine_correct_month" },
    { 0x3C6F, "determine_max_gun_game_level" },
    { 0x3C70, "determinecurrentstairsstate" },
    { 0x3C71, "determinedesiredexitspeed" },
    { 0x3C72, "determinelocalecenter" },
    { 0x3C73, "determineobjectiveiconvisibility" },
    { 0x3C74, "determineobjectivevisibility" },
    { 0x3C75, "determineoperation" },
    { 0x3C76, "determinerequestedstance" },
    { 0x3C77, "determinespawnangles" },
    { 0x3C78, "determinespawnorigin" },
    { 0x3C79, "determinesquadleader" },
    { 0x3C7A, "determinestartanim" },
    { 0x3C7B, "determinestashlocation" },
    { 0x3C7C, "determinetargetbounty" },
    { 0x3C7D, "determinetargetplayer" },
    { 0x3C7E, "determinetargetteam" },
    { 0x3C7F, "determinetrackingcircleposition" },
    { 0x3C80, "detonate_after_time" },
    { 0x3C81, "detonate_disabletruckvisionvolume" },
    { 0x3C82, "detonate_distractedenemieslogic" },
    { 0x3C83, "detonate_effectslogic" },
    { 0x3C84, "detonate_enabletruckvisionvolume" },
    { 0x3C85, "detonate_explosive" },
    { 0x3C86, "detonate_explosives" },
    { 0x3C87, "detonate_getenemynodes" },
    { 0x3C88, "detonate_getlights" },
    { 0x3C89, "detonate_gettruckvisionvolume" },
    { 0x3C8A, "detonate_getvehicle" },
    { 0x3C8B, "detonate_main" },
    { 0x3C8C, "detonate_mines" },
    { 0x3C8D, "detonate_playerleaveroomlogic" },
    { 0x3C8E, "detonate_spawnenemies" },
    { 0x3C8F, "detonate_spewing_barrel" },
    { 0x3C90, "detonate_start" },
    { 0x3C91, "detonate_the_bomb_monitor" },
    { 0x3C92, "detonateball" },
    { 0x3C93, "detonated_grenade_origin" },
    { 0x3C94, "detonatescore" },
    { 0x3C95, "detonationtime" },
    { 0x3C96, "detonator" },
    { 0x3C97, "detonator_hero_lighting_on" },
    { 0x3C98, "detonator_hero_lighting_setup" },
    { 0x3C99, "dev_build" },
    { 0x3C9A, "dev_damage_show_damage_numbers" },
    { 0x3C9B, "dev_debug_menus" },
    { 0x3C9C, "dev_flag_find_ground" },
    { 0x3C9D, "dev_forcelivelobbystart" },
    { 0x3C9E, "dev_spawning_bots" },
    { 0x3C9F, "devaliengiveplayersmoney" },
    { 0x3CA0, "devball" },
    { 0x3CA1, "devfindhost" },
    { 0x3CA2, "devgivefieldupgradethink" },
    { 0x3CA3, "devgivesuperthink" },
    { 0x3CA4, "devgui_setup_func" },
    { 0x3CA5, "devlistinventory" },
    { 0x3CA6, "devmonitoroperatorcustomization" },
    { 0x3CA7, "devmonitoroperatorcustomizationprint" },
    { 0x3CA8, "devmonitoroperatorskincustomization" },
    { 0x3CA9, "devoverridematchstart" },
    { 0x3CAA, "devprintweaponlist" },
    { 0x3CAB, "devui_bg_swap" },
    { 0x3CAC, "diable_heli_lights" },
    { 0x3CAD, "dialgue_armory_01_enemies" },
    { 0x3CAE, "dialog" },
    { 0x3CAF, "dialog_clear_start_watcher" },
    { 0x3CB0, "dialog_collateral_watcher" },
    { 0x3CB1, "dialog_hurry_up_thread" },
    { 0x3CB2, "dialog_hurry_up_watcher" },
    { 0x3CB3, "dialog_init" },
    { 0x3CB4, "dialog_kill_watcher" },
    { 0x3CB5, "dialog_killstreak_acknowledgement" },
    { 0x3CB6, "dialog_missed_shots_watcher" },
    { 0x3CB7, "dialog_nags_heli" },
    { 0x3CB8, "dialog_new_line_monitor" },
    { 0x3CB9, "dialog_push_forward" },
    { 0x3CBA, "dialoge_fly_off_course" },
    { 0x3CBB, "dialogue" },
    { 0x3CBC, "dialogue_armory_01" },
    { 0x3CBD, "dialogue_armory_02" },
    { 0x3CBE, "dialogue_armory_boost" },
    { 0x3CBF, "dialogue_armory_hatch" },
    { 0x3CC0, "dialogue_arr" },
    { 0x3CC1, "dialogue_bookcase_scene" },
    { 0x3CC2, "dialogue_cam_change" },
    { 0x3CC3, "dialogue_cctv_cell_phone" },
    { 0x3CC4, "dialogue_cctv_first_room_exit" },
    { 0x3CC5, "dialogue_cctv_intro" },
    { 0x3CC6, "dialogue_cctv_intro_gameplay" },
    { 0x3CC7, "dialogue_cctv_nodes" },
    { 0x3CC8, "dialogue_charge" },
    { 0x3CC9, "dialogue_check_lock_and_nag_boost" },
    { 0x3CCA, "dialogue_containers_gate" },
    { 0x3CCB, "dialogue_containers_gate_smash" },
    { 0x3CCC, "dialogue_cooldown_setup" },
    { 0x3CCD, "dialogue_cooldown_timer" },
    { 0x3CCE, "dialogue_decks_init" },
    { 0x3CCF, "dialogue_distant_threat_callouts" },
    { 0x3CD0, "dialogue_drag_scene" },
    { 0x3CD1, "dialogue_ending_scene" },
    { 0x3CD2, "dialogue_fly" },
    { 0x3CD3, "dialogue_fob_bunkers" },
    { 0x3CD4, "dialogue_fob_center" },
    { 0x3CD5, "dialogue_glanceatentity" },
    { 0x3CD6, "dialogue_hadirstruct" },
    { 0x3CD7, "dialogue_hangar_defend" },
    { 0x3CD8, "dialogue_huds" },
    { 0x3CD9, "dialogue_killstreak_chopper" },
    { 0x3CDA, "dialogue_killstreak_waiting" },
    { 0x3CDB, "dialogue_last_flare" },
    { 0x3CDC, "dialogue_nag_open_armory_02" },
    { 0x3CDD, "dialogue_naganimationlogic" },
    { 0x3CDE, "dialogue_nagendonlogic" },
    { 0x3CDF, "dialogue_nagendonnotifies_proc" },
    { 0x3CE0, "dialogue_nagflaglogic" },
    { 0x3CE1, "dialogue_naglogic" },
    { 0x3CE2, "dialogue_naglogic_proc" },
    { 0x3CE3, "dialogue_play_backup" },
    { 0x3CE4, "dialogue_play_sound" },
    { 0x3CE5, "dialogue_playing" },
    { 0x3CE6, "dialogue_pre_charge" },
    { 0x3CE7, "dialogue_pre_charge_branch" },
    { 0x3CE8, "dialogue_pre_charge_fire_cannon" },
    { 0x3CE9, "dialogue_pre_charge_pep" },
    { 0x3CEA, "dialogue_proc" },
    { 0x3CEB, "dialogue_queue" },
    { 0x3CEC, "dialogue_rooftops" },
    { 0x3CED, "dialogue_rooftops_approach" },
    { 0x3CEE, "dialogue_rooftops_wave_0" },
    { 0x3CEF, "dialogue_rooftops_wave_0_cafe" },
    { 0x3CF0, "dialogue_rooftops_wave_0_lights_shot" },
    { 0x3CF1, "dialogue_rooftops_wave_0_shooting_nags" },
    { 0x3CF2, "dialogue_rooftops_wave_1" },
    { 0x3CF3, "dialogue_rooftops_wave_1_post_flare" },
    { 0x3CF4, "dialogue_rooftops_wave_2" },
    { 0x3CF5, "dialogue_rooftops_wave_2_mortars" },
    { 0x3CF6, "dialogue_rooftops_wave_3" },
    { 0x3CF7, "dialogue_rooftops_wave_3_building" },
    { 0x3CF8, "dialogue_rooftops_wave_4" },
    { 0x3CF9, "dialogue_rooftops_wave_4_technicals" },
    { 0x3CFA, "dialogue_rooftops_wave_5" },
    { 0x3CFB, "dialogue_rooftops_wave_6" },
    { 0x3CFC, "dialogue_safehouse_interior" },
    { 0x3CFD, "dialogue_setup" },
    { 0x3CFE, "dialogue_stop" },
    { 0x3CFF, "dialogue_stop_and_clear_stack" },
    { 0x3D00, "dialogue_tarmac" },
    { 0x3D01, "dialogue_wave_1_flare_2_chatter" },
    { 0x3D02, "dialogue_wave_1_flare_3_chatter" },
    { 0x3D03, "dialogue_wave_4_snipers" },
    { 0x3D04, "dialogue_wave_5_marines" },
    { 0x3D05, "dialogue_wheel_check" },
    { 0x3D06, "dialogue_wheel_player_state" },
    { 0x3D07, "dialogue_wheel_start" },
    { 0x3D08, "dialogue_wounded_scene" },
    { 0x3D09, "dialoguecooldowns" },
    { 0x3D0A, "dialoguehud" },
    { 0x3D0B, "dialoguelinescale" },
    { 0x3D0C, "dialoguenotetrack" },
    { 0x3D0D, "dialogueprefix" },
    { 0x3D0E, "did_anyone_see_this" },
    { 0x3D0F, "diddamagewithlethalequipment" },
    { 0x3D10, "diddamagewithprimary" },
    { 0x3D11, "diddamagewithtacticalequipment" },
    { 0x3D12, "didfocus" },
    { 0x3D13, "didhalfscorevoboost" },
    { 0x3D14, "didinitiallog" },
    { 0x3D15, "didnonmeleedamage" },
    { 0x3D16, "didnotselectclassintime" },
    { 0x3D17, "didnt_shoot_ak_in_time" },
    { 0x3D18, "didsomethingotherthanshooting" },
    { 0x3D19, "didstatusnotify" },
    { 0x3D1A, "didzoom" },
    { 0x3D1B, "die" },
    { 0x3D1C, "die_a_statue" },
    { 0x3D1D, "die_a_statue_new" },
    { 0x3D1E, "die_after_anim" },
    { 0x3D1F, "die_when_offscreen_and_distant" },
    { 0x3D20, "died_of_headshot" },
    { 0x3D21, "died_poorly" },
    { 0x3D22, "died_poorly_health" },
    { 0x3D23, "diedrecentlycooldown" },
    { 0x3D24, "diehardmode" },
    { 0x3D25, "diewithowner" },
    { 0x3D26, "differentteamsinsamevehicle" },
    { 0x3D27, "difficulty" },
    { 0x3D28, "difficultysettings" },
    { 0x3D29, "difficultystring" },
    { 0x3D2A, "difficultytype" },
    { 0x3D2B, "dim_hangar_lights" },
    { 0x3D2C, "dining_death_counter" },
    { 0x3D2D, "dining_death_vo" },
    { 0x3D2E, "dining_delete_clip" },
    { 0x3D2F, "dining_dialogue" },
    { 0x3D30, "dining_dialogue_from_kitchen" },
    { 0x3D31, "dining_drop_phone" },
    { 0x3D32, "dining_enemies" },
    { 0x3D33, "dining_enemy_flashbang" },
    { 0x3D34, "dining_enemy_react" },
    { 0x3D35, "dining_enemy1_react_lookat" },
    { 0x3D36, "dining_enemy2_investigate" },
    { 0x3D37, "dining_enemy2_investigate_react" },
    { 0x3D38, "dining_enemy3_grenade" },
    { 0x3D39, "dining_enemy3_react" },
    { 0x3D3A, "dining_enemy3_react_goto_gun" },
    { 0x3D3B, "dining_engage_enemy" },
    { 0x3D3C, "dining_light_death" },
    { 0x3D3D, "dining_long_death_vo" },
    { 0x3D3E, "dining_longdeath_count_get" },
    { 0x3D3F, "dining_longdeath_counter" },
    { 0x3D40, "dining_nolight_delay" },
    { 0x3D41, "dining_nolight_dist_thread" },
    { 0x3D42, "dining_nolight_enemy3_dialogue" },
    { 0x3D43, "dining_nolight_scaredlook" },
    { 0x3D44, "dining_nolight_wait_anim" },
    { 0x3D45, "dining_nolight_wait_time" },
    { 0x3D46, "dining_price_dialogue" },
    { 0x3D47, "dining_react_death" },
    { 0x3D48, "dining_react_dialogue" },
    { 0x3D49, "dining_react_flagwait" },
    { 0x3D4A, "dining_room" },
    { 0x3D4B, "dining_room_animrate_adjust" },
    { 0x3D4C, "dining_room_catchup" },
    { 0x3D4D, "dining_room_ceiling_dialogue" },
    { 0x3D4E, "dining_room_ceiling_dialogue_internal" },
    { 0x3D4F, "dining_room_chair_anim_end" },
    { 0x3D50, "dining_room_chair_init" },
    { 0x3D51, "dining_room_chest_fx" },
    { 0x3D52, "dining_room_clear" },
    { 0x3D53, "dining_room_door_damage" },
    { 0x3D54, "dining_room_foyer_trigger" },
    { 0x3D55, "dining_room_is_light_dead" },
    { 0x3D56, "dining_room_late_long_death" },
    { 0x3D57, "dining_room_main" },
    { 0x3D58, "dining_room_start" },
    { 0x3D59, "dining_room_teleport_price" },
    { 0x3D5A, "dining_trigger_damage_onnotify" },
    { 0x3D5B, "dining_trigger_damage_thread" },
    { 0x3D5C, "diningroom_skipanimreach" },
    { 0x3D5D, "dinnig_enemy_react_then_pain" },
    { 0x3D5E, "dir" },
    { 0x3D5F, "dir_fails" },
    { 0x3D60, "dir_override" },
    { 0x3D61, "dir_valid" },
    { 0x3D62, "diraimlimit" },
    { 0x3D63, "direct_shoot" },
    { 0x3D64, "directing_01" },
    { 0x3D65, "directing_02" },
    { 0x3D66, "directing_breakout" },
    { 0x3D67, "direction_vec" },
    { 0x3D68, "directlineofsighttest" },
    { 0x3D69, "dirfacing" },
    { 0x3D6A, "dirteffect" },
    { 0x3D6B, "dirty" },
    { 0x3D6C, "dirtyrate" },
    { 0x3D6D, "dirtystart" },
    { 0x3D6E, "disable_accuracy_at_dist" },
    { 0x3D6F, "disable_ai_color" },
    { 0x3D70, "disable_ai_dynolight_behavior" },
    { 0x3D71, "disable_all_players_use" },
    { 0x3D72, "disable_allies_firing" },
    { 0x3D73, "disable_ally_firing" },
    { 0x3D74, "disable_ally_vision" },
    { 0x3D75, "disable_armor" },
    { 0x3D76, "disable_arrivals" },
    { 0x3D77, "disable_bleedout_ent_usability" },
    { 0x3D78, "disable_bleedout_ent_usability_func" },
    { 0x3D79, "disable_blindfire" },
    { 0x3D7A, "disable_blindfire_behavior" },
    { 0x3D7B, "disable_blood_pool" },
    { 0x3D7C, "disable_bounceback" },
    { 0x3D7D, "disable_breath_fx" },
    { 0x3D7E, "disable_breathing_sound" },
    { 0x3D7F, "disable_bulletwhizbyreaction" },
    { 0x3D80, "disable_burnsfx" },
    { 0x3D81, "disable_canal_trigs" },
    { 0x3D82, "disable_canshootinvehicle" },
    { 0x3D83, "disable_careful" },
    { 0x3D84, "disable_casual_killer" },
    { 0x3D85, "disable_casual_killer_internal" },
    { 0x3D86, "disable_chair_carry" },
    { 0x3D87, "disable_consumable" },
    { 0x3D88, "disable_consumables" },
    { 0x3D89, "disable_context_melee" },
    { 0x3D8A, "disable_cover_node_behavior" },
    { 0x3D8B, "disable_covering_fire" },
    { 0x3D8C, "disable_cqbwalk" },
    { 0x3D8D, "disable_crosshair_for_time" },
    { 0x3D8E, "disable_damagefeedback" },
    { 0x3D8F, "disable_danger_react" },
    { 0x3D90, "disable_default_player_control_carry" },
    { 0x3D91, "disable_delay" },
    { 0x3D92, "disable_dontevershoot" },
    { 0x3D93, "disable_dynamic_run_speed" },
    { 0x3D94, "disable_dynamic_takedowns" },
    { 0x3D95, "disable_enemy_battlechatter_while_inside" },
    { 0x3D96, "disable_enemy_monitor" },
    { 0x3D97, "disable_escort_gesture" },
    { 0x3D98, "disable_exit_sounds" },
    { 0x3D99, "disable_exits" },
    { 0x3D9A, "disable_exposed_nodes" },
    { 0x3D9B, "disable_features_for_core_carrier" },
    { 0x3D9C, "disable_features_for_disguised_player" },
    { 0x3D9D, "disable_fire_triggers" },
    { 0x3D9E, "disable_firing" },
    { 0x3D9F, "disable_force_sprint" },
    { 0x3DA0, "disable_fuseboxes_on_grid" },
    { 0x3DA1, "disable_global_vehicle_spawn" },
    { 0x3DA2, "disable_green_beam" },
    { 0x3DA3, "disable_gun_recall" },
    { 0x3DA4, "disable_heat_behavior" },
    { 0x3DA5, "disable_horn" },
    { 0x3DA6, "disable_hotjoin_via_ac130" },
    { 0x3DA7, "disable_hvt_nomantle" },
    { 0x3DA8, "disable_if_player_close" },
    { 0x3DA9, "disable_ignorerandombulletdamage_drone" },
    { 0x3DAA, "disable_jugg_objective_position_on_death" },
    { 0x3DAB, "disable_juggernaut_move_behavior" },
    { 0x3DAC, "disable_kill_off" },
    { 0x3DAD, "disable_killcam" },
    { 0x3DAE, "disable_killstreak_useexit" },
    { 0x3DAF, "disable_ladders" },
    { 0x3DB0, "disable_leave_truck" },
    { 0x3DB1, "disable_light_fx" },
    { 0x3DB2, "disable_lobby_color_triggers" },
    { 0x3DB3, "disable_long_death" },
    { 0x3DB4, "disable_lookat" },
    { 0x3DB5, "disable_loot_drop" },
    { 0x3DB6, "disable_lower_priority_states" },
    { 0x3DB7, "disable_magic_bullet_delete" },
    { 0x3DB8, "disable_magic_bullet_shield" },
    { 0x3DB9, "disable_map_tablet" },
    { 0x3DBA, "disable_marines_backtrack_color" },
    { 0x3DBB, "disable_menu" },
    { 0x3DBC, "disable_munitions" },
    { 0x3DBD, "disable_nearby_vehicles" },
    { 0x3DBE, "disable_nvg" },
    { 0x3DBF, "disable_nvg_proc" },
    { 0x3DC0, "disable_objective_update" },
    { 0x3DC1, "disable_on_world_progress_bar_for_other_players" },
    { 0x3DC2, "disable_outline" },
    { 0x3DC3, "disable_outline_for_player" },
    { 0x3DC4, "disable_outline_for_players" },
    { 0x3DC5, "disable_overwatch_model" },
    { 0x3DC6, "disable_pain" },
    { 0x3DC7, "disable_pipes_lights" },
    { 0x3DC8, "disable_player_headtracking" },
    { 0x3DC9, "disable_player_sealth" },
    { 0x3DCA, "disable_player_weapon_info" },
    { 0x3DCB, "disable_playeruse" },
    { 0x3DCC, "disable_procedural_bones" },
    { 0x3DCD, "disable_push" },
    { 0x3DCE, "disable_readystand" },
    { 0x3DCF, "disable_repeating_event" },
    { 0x3DD0, "disable_replace_on_death" },
    { 0x3DD1, "disable_respawns" },
    { 0x3DD2, "disable_retreat_exterior_triggers" },
    { 0x3DD3, "disable_revive_icon_hotjoin_monitor" },
    { 0x3DD4, "disable_sas_color" },
    { 0x3DD5, "disable_scriptable_shadows" },
    { 0x3DD6, "disable_segmented_health_regen" },
    { 0x3DD7, "disable_self_revive" },
    { 0x3DD8, "disable_set_speed" },
    { 0x3DD9, "disable_slide_trigger" },
    { 0x3DDA, "disable_slow_aim" },
    { 0x3DDB, "disable_snakecams_by_target" },
    { 0x3DDC, "disable_sniper_glint" },
    { 0x3DDD, "disable_spawn_point" },
    { 0x3DDE, "disable_spawn_window" },
    { 0x3DDF, "disable_spawner_until_owner_death" },
    { 0x3DE0, "disable_spawners_until_owner_death" },
    { 0x3DE1, "disable_sprint" },
    { 0x3DE2, "disable_start_spawn_on_navmesh" },
    { 0x3DE3, "disable_stayahead" },
    { 0x3DE4, "disable_stealth_system" },
    { 0x3DE5, "disable_super" },
    { 0x3DE6, "disable_surprise" },
    { 0x3DE7, "disable_teamflashbangimmunity" },
    { 0x3DE8, "disable_thermalswitch" },
    { 0x3DE9, "disable_this_node_for_us" },
    { 0x3DEA, "disable_traversalassists" },
    { 0x3DEB, "disable_trigger" },
    { 0x3DEC, "disable_trigger_helper" },
    { 0x3DED, "disable_trigger_with_noteworthy" },
    { 0x3DEE, "disable_trigger_with_targetname" },
    { 0x3DEF, "disable_turnanims" },
    { 0x3DF0, "disable_vehicle_idle" },
    { 0x3DF1, "disable_vehicle_interaction" },
    { 0x3DF2, "disable_volumetrics" },
    { 0x3DF3, "disable_wall_buy_interactions" },
    { 0x3DF4, "disable_wash" },
    { 0x3DF5, "disable_wave_hud" },
    { 0x3DF6, "disable_weapon_check_interactions_on_death" },
    { 0x3DF7, "disable_weapon_pickup_near_hvt" },
    { 0x3DF8, "disable_weapon_progression" },
    { 0x3DF9, "disable_weapon_swap" },
    { 0x3DFA, "disable_weapons" },
    { 0x3DFB, "disable_you_spotted_message" },
    { 0x3DFC, "disableactivation" },
    { 0x3DFD, "disableaimchangetime" },
    { 0x3DFE, "disableallambulancesforplayer" },
    { 0x3DFF, "disablealldepotsforplayer" },
    { 0x3E00, "disablearrivals" },
    { 0x3E01, "disableattack" },
    { 0x3E02, "disablebattlechatter" },
    { 0x3E03, "disablebuddyspawn" },
    { 0x3E04, "disablebulletwhizbyreaction" },
    { 0x3E05, "disableburnfx" },
    { 0x3E06, "disableciviliantargetfocus" },
    { 0x3E07, "disableclassswapallowed" },
    { 0x3E08, "disablecopycatloadout" },
    { 0x3E09, "disabled" },
    { 0x3E0A, "disabled_by_convoy" },
    { 0x3E0B, "disabled_due_to_damage" },
    { 0x3E0C, "disabled_interactions" },
    { 0x3E0D, "disabled_nodes" },
    { 0x3E0E, "disabled_use_for" },
    { 0x3E0F, "disabledamageinvulnerability" },
    { 0x3E10, "disabledamageshieldpain" },
    { 0x3E11, "disabledbyallow" },
    { 0x3E12, "disableddodge" },
    { 0x3E13, "disabledeathdirectionalorient" },
    { 0x3E14, "disabledeathsdoor" },
    { 0x3E15, "disabledefaultfacialanims" },
    { 0x3E16, "disabledemeanorsafe" },
    { 0x3E17, "disabledgesture" },
    { 0x3E18, "disabledguidedinteractions" },
    { 0x3E19, "disabledinteractions" },
    { 0x3E1A, "disabledismemberbehaviors" },
    { 0x3E1B, "disabledmelee" },
    { 0x3E1C, "disabledodge" },
    { 0x3E1D, "disabledomflagscriptable" },
    { 0x3E1E, "disabledpaths" },
    { 0x3E1F, "disabledreason" },
    { 0x3E20, "disabledropbagobjective" },
    { 0x3E21, "disabledsecondaryoffhandweapons" },
    { 0x3E22, "disabledspeedmod" },
    { 0x3E23, "disabledstats" },
    { 0x3E24, "disabledteleportation" },
    { 0x3E25, "disableeasystealthheadshot" },
    { 0x3E26, "disableenemybaseoutline" },
    { 0x3E27, "disableescalation" },
    { 0x3E28, "disableexecutionattackfunc" },
    { 0x3E29, "disableexecutionattackwrapper" },
    { 0x3E2A, "disableexecutionvictimfunc" },
    { 0x3E2B, "disableexecutionvictimwrapper" },
    { 0x3E2C, "disableexits" },
    { 0x3E2D, "disableexplosiveshellshock" },
    { 0x3E2E, "disablefade" },
    { 0x3E2F, "disableforfeit" },
    { 0x3E30, "disablegrenaderesponse" },
    { 0x3E31, "disableheadpopbyturret" },
    { 0x3E32, "disableinitplayergameobjects" },
    { 0x3E33, "disableinteractable" },
    { 0x3E34, "disableinteraction" },
    { 0x3E35, "disablelifepackboost" },
    { 0x3E36, "disablelittlebirdrally" },
    { 0x3E37, "disablelmgmount" },
    { 0x3E38, "disablelongdeath" },
    { 0x3E39, "disablelongpain" },
    { 0x3E3A, "disablelookat" },
    { 0x3E3B, "disablelookdownpath" },
    { 0x3E3C, "disableloopingcoughaudio" },
    { 0x3E3D, "disableloopingcoughaudiosupression" },
    { 0x3E3E, "disablemonitorflash" },
    { 0x3E3F, "disablemusic" },
    { 0x3E40, "disablenavobstacleteams" },
    { 0x3E41, "disablenoisemakers" },
    { 0x3E42, "disableobject" },
    { 0x3E43, "disableobjectiveongameended" },
    { 0x3E44, "disableoob" },
    { 0x3E45, "disableoobimmunity" },
    { 0x3E46, "disableotflag" },
    { 0x3E47, "disableotherseats" },
    { 0x3E48, "disablepain" },
    { 0x3E49, "disableplayerinfil" },
    { 0x3E4A, "disableplayerminimap" },
    { 0x3E4B, "disablepowerfunc" },
    { 0x3E4C, "disableprecomputedlos" },
    { 0x3E4D, "disablerespawnscenarios" },
    { 0x3E4E, "disablescriptableplayeruseall" },
    { 0x3E4F, "disableshellshockfunc" },
    { 0x3E50, "disableslotinternal" },
    { 0x3E51, "disablesmartobjects" },
    { 0x3E52, "disablespawning" },
    { 0x3E53, "disablespawnpointlist" },
    { 0x3E54, "disablespawnwarnings" },
    { 0x3E55, "disablestairsexits" },
    { 0x3E56, "disablestattracking" },
    { 0x3E57, "disablestrangeondeath" },
    { 0x3E58, "disablesupersprint" },
    { 0x3E59, "disabletacopskitstationuse" },
    { 0x3E5A, "disabletakecoverwarning" },
    { 0x3E5B, "disableteamstartspawns" },
    { 0x3E5C, "disabletrigger" },
    { 0x3E5D, "disableunloadanim" },
    { 0x3E5E, "disableusabilityatspawn" },
    { 0x3E5F, "disablevehiclescripts" },
    { 0x3E60, "disableweaponlaser" },
    { 0x3E61, "disableweaponsovertime" },
    { 0x3E62, "disableweaponstats" },
    { 0x3E63, "disabling_truck_1_node_handler" },
    { 0x3E64, "disabling_truck_2_node_handler" },
    { 0x3E65, "disabling_vehicle_due_to_damage" },
    { 0x3E66, "disallow_tablet_usage_on_player" },
    { 0x3E67, "disallow_tablet_usage_on_players" },
    { 0x3E68, "disallowheadiconid" },
    { 0x3E69, "disallowplayertobreach" },
    { 0x3E6A, "disarmfunc" },
    { 0x3E6B, "disarmfuncfrag" },
    { 0x3E6C, "disarmfuncsemtex" },
    { 0x3E6D, "disarmfuncthink" },
    { 0x3E6E, "disarmgiveweapon" },
    { 0x3E6F, "discardtime" },
    { 0x3E70, "disconnect_jumpdown_traversal" },
    { 0x3E71, "disconnect_paths" },
    { 0x3E72, "disconnect_paths_whenstopped" },
    { 0x3E73, "disconnect_player_team_slot_assignment" },
    { 0x3E74, "disconnect_traversals" },
    { 0x3E75, "disconnected" },
    { 0x3E76, "disconnectpathsfunction" },
    { 0x3E77, "disconnectshouldforceend" },
    { 0x3E78, "discotrap_active" },
    { 0x3E79, "discovergasref" },
    { 0x3E7A, "discrete_waittill" },
    { 0x3E7B, "disengage_enter" },
    { 0x3E7C, "disengage_watcher" },
    { 0x3E7D, "disguise_as_enemy" },
    { 0x3E7E, "disguise_catchup" },
    { 0x3E7F, "disguise_cleanuptunnels" },
    { 0x3E80, "disguise_ent" },
    { 0x3E81, "disguise_fovlogic" },
    { 0x3E82, "disguise_getanimationstruct" },
    { 0x3E83, "disguise_getcurtain" },
    { 0x3E84, "disguise_getfarahfoldeddisguise" },
    { 0x3E85, "disguise_getplayerdisguise" },
    { 0x3E86, "disguise_getplayerfoldeddisguise" },
    { 0x3E87, "disguise_holsterhintlogic" },
    { 0x3E88, "disguise_intro_remove_fov_user_scale" },
    { 0x3E89, "disguise_main" },
    { 0x3E8A, "disguise_overlay" },
    { 0x3E8B, "disguise_player" },
    { 0x3E8C, "disguise_playerdisguiseshowlogic" },
    { 0x3E8D, "disguise_playerfoldeddisguiselogic" },
    { 0x3E8E, "disguise_playerinteractedlogic" },
    { 0x3E8F, "disguise_setupcurtain" },
    { 0x3E90, "disguise_setupfarahfoldeddisguise" },
    { 0x3E91, "disguise_setupplayerfoldeddisguise" },
    { 0x3E92, "disguise_start" },
    { 0x3E93, "disguise_technical" },
    { 0x3E94, "disguised" },
    { 0x3E95, "disguised_players" },
    { 0x3E96, "dismantlehintstring" },
    { 0x3E97, "dismantleobj" },
    { 0x3E98, "dismember_crawl" },
    { 0x3E99, "dismemberedparts" },
    { 0x3E9A, "dismemberheavyfx" },
    { 0x3E9B, "dismembermentcheck" },
    { 0x3E9C, "disownalarmmonitor" },
    { 0x3E9D, "dispersedamage" },
    { 0x3E9E, "display_ai" },
    { 0x3E9F, "display_ai_count" },
    { 0x3EA0, "display_ai_group_info" },
    { 0x3EA1, "display_ai_keys" },
    { 0x3EA2, "display_all_ent_names" },
    { 0x3EA3, "display_all_last_anims" },
    { 0x3EA4, "display_all_node_names" },
    { 0x3EA5, "display_avg_dmg" },
    { 0x3EA6, "display_bomb_id" },
    { 0x3EA7, "display_combat_icon_to_player" },
    { 0x3EA8, "display_detonate_hint_message" },
    { 0x3EA9, "display_enemy_count" },
    { 0x3EAA, "display_enemy_lasknown_pos" },
    { 0x3EAB, "display_equipment" },
    { 0x3EAC, "display_feedback_context" },
    { 0x3EAD, "display_fov" },
    { 0x3EAE, "display_fx_add_options" },
    { 0x3EAF, "display_fx_info" },
    { 0x3EB0, "display_get_away_from_vehicle_message" },
    { 0x3EB1, "display_goto_path" },
    { 0x3EB2, "display_heli_hint" },
    { 0x3EB3, "display_hint" },
    { 0x3EB4, "display_hint_dist_check" },
    { 0x3EB5, "display_hint_function_cancel_logic" },
    { 0x3EB6, "display_hint_proc" },
    { 0x3EB7, "display_icon_logic" },
    { 0x3EB8, "display_icon_shutdown_logic" },
    { 0x3EB9, "display_ied_warning_dialogue_or_end_game" },
    { 0x3EBA, "display_name" },
    { 0x3EBB, "display_obj_hint_if_needed" },
    { 0x3EBC, "display_objective_text_func" },
    { 0x3EBD, "display_range" },
    { 0x3EBE, "display_retry_dialog" },
    { 0x3EBF, "display_retry_loadout" },
    { 0x3EC0, "display_starts" },
    { 0x3EC1, "display_super_fired_splash" },
    { 0x3EC2, "display_super_ready_splash" },
    { 0x3EC3, "display_warning_message_to_player" },
    { 0x3EC4, "displayed_hints" },
    { 0x3EC5, "displayed_ied_ahead_warning" },
    { 0x3EC6, "displaygameend" },
    { 0x3EC7, "displayingdamagehints" },
    { 0x3EC8, "displayplayersplash" },
    { 0x3EC9, "displayroundend" },
    { 0x3ECA, "displayroundswitch" },
    { 0x3ECB, "displayscoreeventpoints" },
    { 0x3ECC, "displayteamsplash" },
    { 0x3ECD, "displaythreat" },
    { 0x3ECE, "dissociate_from_player" },
    { 0x3ECF, "dist" },
    { 0x3ED0, "dist_ambulance_sfx" },
    { 0x3ED1, "dist_from_node_to_end" },
    { 0x3ED2, "dist_test" },
    { 0x3ED3, "dist_to_chopper_pos" },
    { 0x3ED4, "dist_to_next" },
    { 0x3ED5, "distance_2d_squared" },
    { 0x3ED6, "distance_checker" },
    { 0x3ED7, "distance_compare" },
    { 0x3ED8, "distance_notify" },
    { 0x3ED9, "distance_z" },
    { 0x3EDA, "distancebeforedeescalate" },
    { 0x3EDB, "distancefalloff" },
    { 0x3EDC, "distancetobottom" },
    { 0x3EDD, "distancetotarg" },
    { 0x3EDE, "distant_civs" },
    { 0x3EDF, "distant_enemies_spawn_func" },
    { 0x3EE0, "distant_guy_spawner_watcher" },
    { 0x3EE1, "distant_guys" },
    { 0x3EE2, "distant_threat" },
    { 0x3EE3, "distant_threat_gate_init" },
    { 0x3EE4, "distant_threat_gate_move" },
    { 0x3EE5, "distanttargetmarkergroup" },
    { 0x3EE6, "distanttargetsinouterradius" },
    { 0x3EE7, "distdown" },
    { 0x3EE8, "distforward" },
    { 0x3EE9, "distforwardwall" },
    { 0x3EEA, "distmax" },
    { 0x3EEB, "distmin" },
    { 0x3EEC, "distmove" },
    { 0x3EED, "distract" },
    { 0x3EEE, "distract_check" },
    { 0x3EEF, "distract_end" },
    { 0x3EF0, "distract_end_followup" },
    { 0x3EF1, "distract_followup" },
    { 0x3EF2, "distracted_breakout" },
    { 0x3EF3, "distraction_dialogue" },
    { 0x3EF4, "distraction_fx" },
    { 0x3EF5, "distraction_icons" },
    { 0x3EF6, "distraction_structs" },
    { 0x3EF7, "distraction_triggers_logic" },
    { 0x3EF8, "distsq" },
    { 0x3EF9, "distsqrd" },
    { 0x3EFA, "distsqtoballstart" },
    { 0x3EFB, "distsqtokothzones" },
    { 0x3EFC, "distsquaredcheck" },
    { 0x3EFD, "distsumsquared" },
    { 0x3EFE, "distsumsquaredcapped" },
    { 0x3EFF, "disttohomebase" },
    { 0x3F00, "disttravelled" },
    { 0x3F01, "distup" },
    { 0x3F02, "div" },
    { 0x3F03, "divebombpos" },
    { 0x3F04, "divisions" },
    { 0x3F05, "dlc_get_non_agent_enemies" },
    { 0x3F06, "dlog_init" },
    { 0x3F07, "dlogdata" },
    { 0x3F08, "dlogid" },
    { 0x3F09, "dmg_from_player" },
    { 0x3F0A, "dmg_models" },
    { 0x3F0B, "dmg_vfx_hp" },
    { 0x3F0C, "dmg_vfx_smoke" },
    { 0x3F0D, "dmg_vfx_smoke_move" },
    { 0x3F0E, "dmg_vfx_tag" },
    { 0x3F0F, "dmgarray" },
    { 0x3F10, "dmgpoint" },
    { 0x3F11, "dmgtoplayer" },
    { 0x3F12, "do_abort" },
    { 0x3F13, "do_additional_damage" },
    { 0x3F14, "do_animation" },
    { 0x3F15, "do_as_chatter" },
    { 0x3F16, "do_as_chatter_internal" },
    { 0x3F17, "do_computer_anims" },
    { 0x3F18, "do_context_melee" },
    { 0x3F19, "do_cough" },
    { 0x3F1A, "do_cut_anims" },
    { 0x3F1B, "do_cut_anims_long" },
    { 0x3F1C, "do_damage" },
    { 0x3F1D, "do_damage_to_all_players_as_passenger" },
    { 0x3F1E, "do_damage_to_player_armor" },
    { 0x3F1F, "do_damage_to_target_in_range" },
    { 0x3F20, "do_damage_when_trigger" },
    { 0x3F21, "do_death_sound" },
    { 0x3F22, "do_defuse_anim" },
    { 0x3F23, "do_deletable_delete" },
    { 0x3F24, "do_door_spawn" },
    { 0x3F25, "do_earthquake" },
    { 0x3F26, "do_executing_anim" },
    { 0x3F27, "do_facial_anim" },
    { 0x3F28, "do_fadeout" },
    { 0x3F29, "do_fast_hvt_pickup" },
    { 0x3F2A, "do_flir_footsteps" },
    { 0x3F2B, "do_funcs" },
    { 0x3F2C, "do_gl_hint" },
    { 0x3F2D, "do_heli_crash" },
    { 0x3F2E, "do_hood_repair_animation" },
    { 0x3F2F, "do_hood_repair_animation_actual" },
    { 0x3F30, "do_hood_repair_anims" },
    { 0x3F31, "do_hvt_drop_anim" },
    { 0x3F32, "do_hvt_load_on_truck_anim" },
    { 0x3F33, "do_hvt_pickup_anim" },
    { 0x3F34, "do_hvt_pickup_from_truck_anim" },
    { 0x3F35, "do_idle_twitch" },
    { 0x3F36, "do_immediate_ragdoll" },
    { 0x3F37, "do_killstreaks" },
    { 0x3F38, "do_landing" },
    { 0x3F39, "do_laser_target_on_player_humvee" },
    { 0x3F3A, "do_level_first_frame" },
    { 0x3F3B, "do_level_specific_callback" },
    { 0x3F3C, "do_lilly_execition" },
    { 0x3F3D, "do_lilly_struggle" },
    { 0x3F3E, "do_ls_anims" },
    { 0x3F3F, "do_melee_attack_anim" },
    { 0x3F40, "do_multiple_treads" },
    { 0x3F41, "do_no_game_start" },
    { 0x3F42, "do_no_game_start_teleport" },
    { 0x3F43, "do_pain" },
    { 0x3F44, "do_resurrection_logic" },
    { 0x3F45, "do_seated_anim" },
    { 0x3F46, "do_single_tread" },
    { 0x3F47, "do_slide_hint" },
    { 0x3F48, "do_sound_on_death" },
    { 0x3F49, "do_starts" },
    { 0x3F4A, "do_state" },
    { 0x3F4B, "do_state_change" },
    { 0x3F4C, "do_stealth" },
    { 0x3F4D, "do_subduing_anim" },
    { 0x3F4E, "do_terrorist_ragdoll" },
    { 0x3F4F, "do_traverse_anim" },
    { 0x3F50, "do_vehicle_repair_animation" },
    { 0x3F51, "do_vehicle_repair_animation_actual" },
    { 0x3F52, "do_vent_rumble" },
    { 0x3F53, "do_wait" },
    { 0x3F54, "do_wait_any" },
    { 0x3F55, "do_wait_endons_array" },
    { 0x3F56, "do_whizby_flinch" },
    { 0x3F57, "doaction" },
    { 0x3F58, "doaction_begin" },
    { 0x3F59, "doaction_end" },
    { 0x3F5A, "doaction_tick" },
    { 0x3F5B, "doairstrike" },
    { 0x3F5C, "doalert" },
    { 0x3F5D, "doambushcoverfind" },
    { 0x3F5E, "doambushspawning" },
    { 0x3F5F, "doantigravgrenaderagdoll" },
    { 0x3F60, "doapcshellshot" },
    { 0x3F61, "doarrival" },
    { 0x3F62, "doblinkinglight" },
    { 0x3F63, "docache1" },
    { 0x3F64, "docache2" },
    { 0x3F65, "docache3" },
    { 0x3F66, "docache4" },
    { 0x3F67, "docache5" },
    { 0x3F68, "docapturekill" },
    { 0x3F69, "dochangeweapon" },
    { 0x3F6A, "dochants" },
    { 0x3F6B, "dock_door_init" },
    { 0x3F6C, "dock_doors_move" },
    { 0x3F6D, "docmdoutro" },
    { 0x3F6E, "docovermultiswitchnode" },
    { 0x3F6F, "docovermultiswitchnodetype" },
    { 0x3F70, "docratedropfrommanualheli" },
    { 0x3F71, "docratedropfromscripted" },
    { 0x3F72, "docratedropfromscriptedheli" },
    { 0x3F73, "docratedropsmoke" },
    { 0x3F74, "dodamagefilter" },
    { 0x3F75, "dodamagetokillstreak" },
    { 0x3F76, "dodamagewhiledown" },
    { 0x3F77, "dodeathfromarray" },
    { 0x3F78, "dodgeanim" },
    { 0x3F79, "dodgecooldown" },
    { 0x3F7A, "dodgedbullet" },
    { 0x3F7B, "dodgedefenseignorefunc" },
    { 0x3F7C, "dodging" },
    { 0x3F7D, "dodirectionalswivelmove" },
    { 0x3F7E, "dodisintegrate" },
    { 0x3F7F, "dodragonsbreathpainfxhack" },
    { 0x3F80, "dodyingcrawlbloodsmear" },
    { 0x3F81, "doearthquake" },
    { 0x3F82, "doeomcombat" },
    { 0x3F83, "doepictauntscriptablestep" },
    { 0x3F84, "does_day_fit_in_current_month" },
    { 0x3F85, "does_goliath_know_where_player_is" },
    { 0x3F86, "does_hero_player_pass_traces" },
    { 0x3F87, "does_team_have_active_chain" },
    { 0x3F88, "does_want_to_move" },
    { 0x3F89, "doesattachmentconflict" },
    { 0x3F8A, "doesmodesupportplayerteamchoice" },
    { 0x3F8B, "doesscenefitincurrentarchive" },
    { 0x3F8C, "doesscenehaveenoughbufferrecordingtime" },
    { 0x3F8D, "doesscenehaveenoughtotalrecordingtime" },
    { 0x3F8E, "doesshareammo" },
    { 0x3F8F, "doesstumblingpainstatehavealias" },
    { 0x3F90, "doesteamhaveactivejugg" },
    { 0x3F91, "doesweaponhaveattachmenttype" },
    { 0x3F92, "doexfilsplashforpassengers" },
    { 0x3F93, "doexposedcalloutresponse" },
    { 0x3F94, "dof" },
    { 0x3F95, "dof_apply_to_results" },
    { 0x3F96, "dof_auto_barkov" },
    { 0x3F97, "dof_auto_knife" },
    { 0x3F98, "dof_auto_knife_prompt" },
    { 0x3F99, "dof_blend_interior_ads" },
    { 0x3F9A, "dof_blend_interior_ads_element" },
    { 0x3F9B, "dof_blend_interior_ads_scalar" },
    { 0x3F9C, "dof_blend_interior_generic" },
    { 0x3F9D, "dof_calc_results" },
    { 0x3F9E, "dof_default" },
    { 0x3F9F, "dof_disable" },
    { 0x3FA0, "dof_disable_ads" },
    { 0x3FA1, "dof_disable_autofocus" },
    { 0x3FA2, "dof_disable_script" },
    { 0x3FA3, "dof_enable" },
    { 0x3FA4, "dof_enable_ads" },
    { 0x3FA5, "dof_enable_autofocus" },
    { 0x3FA6, "dof_enable_script" },
    { 0x3FA7, "dof_finale_choke_stab01" },
    { 0x3FA8, "dof_finale_choke_stab04" },
    { 0x3FA9, "dof_func" },
    { 0x3FAA, "dof_init" },
    { 0x3FAB, "dof_interrogation_enforcer" },
    { 0x3FAC, "dof_interrogation_revolver_pickup" },
    { 0x3FAD, "dof_interrogation_van_open" },
    { 0x3FAE, "dof_kyledrone" },
    { 0x3FAF, "dof_off" },
    { 0x3FB0, "dof_process_ads" },
    { 0x3FB1, "dof_process_physical_ads" },
    { 0x3FB2, "dof_ref_ent" },
    { 0x3FB3, "dof_set_base" },
    { 0x3FB4, "dof_set_generic" },
    { 0x3FB5, "dof_update" },
    { 0x3FB6, "doffarblur" },
    { 0x3FB7, "doffarend" },
    { 0x3FB8, "doffarstart" },
    { 0x3FB9, "dofinalkillcam" },
    { 0x3FBA, "dofirstcache" },
    { 0x3FBB, "doflyby" },
    { 0x3FBC, "dofnearblur" },
    { 0x3FBD, "dofnearend" },
    { 0x3FBE, "dofnearstart" },
    { 0x3FBF, "dofovzoom" },
    { 0x3FC0, "dog_combat_init" },
    { 0x3FC1, "dog_followenemy" },
    { 0x3FC2, "dog_followenemy_init" },
    { 0x3FC3, "dog_followenemy_terminate" },
    { 0x3FC4, "dog_idle" },
    { 0x3FC5, "dog_idle_init" },
    { 0x3FC6, "dog_idle_init_task" },
    { 0x3FC7, "dog_idle_terminate_task" },
    { 0x3FC8, "dog_init" },
    { 0x3FC9, "dog_investigate" },
    { 0x3FCA, "dog_investigate_init_task" },
    { 0x3FCB, "dog_investigate_terminate_task" },
    { 0x3FCC, "dog_is_killed" },
    { 0x3FCD, "dog_jump_down" },
    { 0x3FCE, "dog_kill_and_main_house_vo" },
    { 0x3FCF, "dog_notehandler" },
    { 0x3FD0, "dogfighttarget" },
    { 0x3FD1, "dogfn0" },
    { 0x3FD2, "doghostweaponfired" },
    { 0x3FD3, "dogib" },
    { 0x3FD4, "dogibdefault" },
    { 0x3FD5, "dogoalreset" },
    { 0x3FD6, "dograb" },
    { 0x3FD7, "dogrenadethrow" },
    { 0x3FD8, "dogs" },
    { 0x3FD9, "dogs_dialoguedeathlogic" },
    { 0x3FDA, "dogs_dialoguelogic" },
    { 0x3FDB, "dogs_dialogueplayermisslogic" },
    { 0x3FDC, "dogs_main" },
    { 0x3FDD, "dogs_pathlogic" },
    { 0x3FDE, "dogs_playerspotteddogslogic" },
    { 0x3FDF, "dogs_runlogic" },
    { 0x3FE0, "dogs_spawndogs" },
    { 0x3FE1, "dogs_start" },
    { 0x3FE2, "dogtag" },
    { 0x3FE3, "dogtag_revive" },
    { 0x3FE4, "dogtagallyonusecb" },
    { 0x3FE5, "dogtagallyonusecbconf" },
    { 0x3FE6, "dogtagcommonallyonusecb" },
    { 0x3FE7, "dogtagcommonenemyonusecb" },
    { 0x3FE8, "dogtagenemyonusecb" },
    { 0x3FE9, "dogtagenemyonusecbconf" },
    { 0x3FEA, "dogtags" },
    { 0x3FEB, "dogtagsenabled" },
    { 0x3FEC, "dogtagsicon" },
    { 0x3FED, "dogtagsplayer" },
    { 0x3FEE, "dogtagstext" },
    { 0x3FEF, "dogundropphysicsimpulse" },
    { 0x3FF0, "dohalftimevo" },
    { 0x3FF1, "dohalfwayflash" },
    { 0x3FF2, "dohoist" },
    { 0x3FF3, "doidlemovement" },
    { 0x3FF4, "doimmediateragdolldeath" },
    { 0x3FF5, "doingadditivepain" },
    { 0x3FF6, "doingbroshot" },
    { 0x3FF7, "doingkillcamslowmo" },
    { 0x3FF8, "doinglongdeath" },
    { 0x3FF9, "doingpoi" },
    { 0x3FFA, "doingsplash" },
    { 0x3FFB, "doinjuredgesture" },
    { 0x3FFC, "dointro" },
    { 0x3FFD, "dojailbreak" },
    { 0x3FFE, "dokillcam" },
    { 0x3FFF, "dokillcamfromstruct" },
    { 0x4000, "dokillcamslowmo" },
    { 0x4001, "dokillstreakaction" },
    { 0x4002, "doleaderfinalsurrender" },
    { 0x4003, "doleaderreturntocombat" },
    { 0x4004, "doleaderstun" },
    { 0x4005, "doleadersurrender" },
    { 0x4006, "doline" },
    { 0x4007, "dolmgtracking" },
    { 0x4008, "dolocalrailgundamage" },
    { 0x4009, "dom_circletick" },
    { 0x400A, "dom_encounterstart" },
    { 0x400B, "dom_initquest" },
    { 0x400C, "dom_questthink" },
    { 0x400D, "dom_removequestinstance" },
    { 0x400E, "dom_removequestthread" },
    { 0x400F, "domagicdoorchecks" },
    { 0x4010, "domeleeaction" },
    { 0x4011, "domencounter_icons" },
    { 0x4012, "domencounter_onenduse" },
    { 0x4013, "domencounter_onuse" },
    { 0x4014, "domencounter_onuseupdate" },
    { 0x4015, "domencounter_setdomscriptablepartstate" },
    { 0x4016, "domeritcallback" },
    { 0x4017, "domflag" },
    { 0x4018, "domflag_dropplunder" },
    { 0x4019, "domflag_icons" },
    { 0x401A, "domflag_onenduse" },
    { 0x401B, "domflag_onuse" },
    { 0x401C, "domflag_onuseupdate" },
    { 0x401D, "domflag_setdomscriptablepartstate" },
    { 0x401E, "domflag_setneutral" },
    { 0x401F, "domflagassignments" },
    { 0x4020, "domflags" },
    { 0x4021, "domflagupdateicons" },
    { 0x4022, "dominating_music" },
    { 0x4023, "domlocale_checkiflocaleisavailable" },
    { 0x4024, "domlocale_circletick" },
    { 0x4025, "domlocale_createquestlocale" },
    { 0x4026, "domlocale_findsearcharea" },
    { 0x4027, "domlocale_removelocaleinstance" },
    { 0x4028, "domlocale_removequestinstances" },
    { 0x4029, "dommainloop" },
    { 0x402A, "domonitoredweaponswitch" },
    { 0x402B, "domoralestiedanim" },
    { 0x402C, "dompoint_cancelholdtimer" },
    { 0x402D, "dompoint_holdtimer" },
    { 0x402E, "dompoint_onactivateobjective" },
    { 0x402F, "dompoint_onbeginuse" },
    { 0x4030, "dompoint_oncontested" },
    { 0x4031, "dompoint_ondisableobjective" },
    { 0x4032, "dompoint_onenableobjective" },
    { 0x4033, "dompoint_onenduse" },
    { 0x4034, "dompoint_onpinnedstate" },
    { 0x4035, "dompoint_onuncontested" },
    { 0x4036, "dompoint_onunoccupied" },
    { 0x4037, "dompoint_onunpinnedstate" },
    { 0x4038, "dompoint_onuse" },
    { 0x4039, "dompoint_onusebegin" },
    { 0x403A, "dompoint_onuseend" },
    { 0x403B, "dompoint_onuseupdate" },
    { 0x403C, "dompoint_setcaptured" },
    { 0x403D, "dompoint_setupflagmodels" },
    { 0x403E, "dompoint_stompprogressreward" },
    { 0x403F, "domquest_dropplunder" },
    { 0x4040, "domquest_icons" },
    { 0x4041, "domquest_onenduse" },
    { 0x4042, "domquest_onuse" },
    { 0x4043, "domquest_onuseupdate" },
    { 0x4044, "domquest_removequestinstance" },
    { 0x4045, "domquest_removequestinstances" },
    { 0x4046, "domquest_setdomscriptablepartstate" },
    { 0x4047, "donelosttargetshot" },
    { 0x4048, "donightvision" },
    { 0x4049, "doninebang" },
    { 0x404A, "donotetracks" },
    { 0x404B, "donotetracks_vsplayer" },
    { 0x404C, "donotetracksforever" },
    { 0x404D, "donotetracksforeverintercept" },
    { 0x404E, "donotetracksforeverproc" },
    { 0x404F, "donotetracksfortime" },
    { 0x4050, "donotetracksfortimeendnotify" },
    { 0x4051, "donotetracksfortimeintercept" },
    { 0x4052, "donotetracksfortimeout" },
    { 0x4053, "donotetracksfortimeproc" },
    { 0x4054, "donotetracksintercept" },
    { 0x4055, "donotetrackspostcallback" },
    { 0x4056, "donotetrackswithtimeout" },
    { 0x4057, "donothing" },
    { 0x4058, "donothingfunc" },
    { 0x4059, "donotmodifydamage" },
    { 0x405A, "donotunloadondriverdeath" },
    { 0x405B, "donotunloadonend" },
    { 0x405C, "donotuse" },
    { 0x405D, "dont_auto_balance" },
    { 0x405E, "dont_auto_ride" },
    { 0x405F, "dont_callout_sniper_kill" },
    { 0x4060, "dont_cleanup" },
    { 0x4061, "dont_crouch" },
    { 0x4062, "dont_delete" },
    { 0x4063, "dont_do_flir_footsteps" },
    { 0x4064, "dont_drop_weapons" },
    { 0x4065, "dont_enter_combat" },
    { 0x4066, "dont_explode" },
    { 0x4067, "dont_kill_flag" },
    { 0x4068, "dont_kill_off" },
    { 0x4069, "dont_lerp_player" },
    { 0x406A, "dont_let_player_die_in_tunnel" },
    { 0x406B, "dont_link" },
    { 0x406C, "dont_lmg" },
    { 0x406D, "dont_move_from_drone" },
    { 0x406E, "dont_plant_until_time" },
    { 0x406F, "dont_prone" },
    { 0x4070, "dont_propagate_events_prespawn" },
    { 0x4071, "dont_scriptkill" },
    { 0x4072, "dont_shoot_player_in_the_back" },
    { 0x4073, "dont_shoot_through_bp_glass" },
    { 0x4074, "dont_shoot_through_civilians" },
    { 0x4075, "dont_stand" },
    { 0x4076, "dont_unlink_ragdoll" },
    { 0x4077, "dont_use_charges" },
    { 0x4078, "dontbreakhelmet" },
    { 0x4079, "dontchangepushplayer" },
    { 0x407A, "dontchatter" },
    { 0x407B, "dontcolormove" },
    { 0x407C, "dontdisconnectpaths" },
    { 0x407D, "dontdonotetracks" },
    { 0x407E, "dontdrawoncompass" },
    { 0x407F, "dontdropweapon" },
    { 0x4080, "dontendonscore" },
    { 0x4081, "dontgetonpath" },
    { 0x4082, "dontgiveuponsuppression" },
    { 0x4083, "dontgiveuponsuppressionyet" },
    { 0x4084, "dontgrenademe" },
    { 0x4085, "dontkilloff" },
    { 0x4086, "dontmelee" },
    { 0x4087, "dontmeleeme" },
    { 0x4088, "dontrallynag" },
    { 0x4089, "dontsave" },
    { 0x408A, "dontshootwhileparachuting" },
    { 0x408B, "dontsyncmelee" },
    { 0x408C, "dontunloadondeath" },
    { 0x408D, "dontunloadonend" },
    { 0x408E, "dontwaitforpathend" },
    { 0x408F, "door" },
    { 0x4090, "door_1" },
    { 0x4091, "door_2" },
    { 0x4092, "door_add_opener" },
    { 0x4093, "door_ai_allowed" },
    { 0x4094, "door_ajar" },
    { 0x4095, "door_ajar_custom_func" },
    { 0x4096, "door_angle_check" },
    { 0x4097, "door_back_left_dmg" },
    { 0x4098, "door_back_right_dmg" },
    { 0x4099, "door_bash_open" },
    { 0x409A, "door_bash_presentation" },
    { 0x409B, "door_bash_thread" },
    { 0x409C, "door_bashable_by_player" },
    { 0x409D, "door_bust_guy" },
    { 0x409E, "door_bust_guy_autosave" },
    { 0x409F, "door_bust_scene" },
    { 0x40A0, "door_can_open_check" },
    { 0x40A1, "door_check_base" },
    { 0x40A2, "door_clip" },
    { 0x40A3, "door_clip_boss_enter" },
    { 0x40A4, "door_clip_delay" },
    { 0x40A5, "door_close" },
    { 0x40A6, "door_col" },
    { 0x40A7, "door_creak_sound" },
    { 0x40A8, "door_creak_sound_stop" },
    { 0x40A9, "door_createnavobstacle" },
    { 0x40AA, "door_cut_interactions" },
    { 0x40AB, "door_cut_precache" },
    { 0x40AC, "door_damage_scale" },
    { 0x40AD, "door_destroynavobstacle" },
    { 0x40AE, "door_disableaudioportal" },
    { 0x40AF, "door_dmg" },
    { 0x40B0, "door_dynamic_parse_parameters" },
    { 0x40B1, "door_dynamic_setup" },
    { 0x40B2, "door_dynamic_setup_adapter" },
    { 0x40B3, "door_dynamic_setup_post_init" },
    { 0x40B4, "door_ease_in_open_input" },
    { 0x40B5, "door_enableaudioportal" },
    { 0x40B6, "door_ent" },
    { 0x40B7, "door_ent_movement" },
    { 0x40B8, "door_entitylessscriptable_togglelock" },
    { 0x40B9, "door_event_wait" },
    { 0x40BA, "door_force_open_fully" },
    { 0x40BB, "door_front_left_dmg" },
    { 0x40BC, "door_front_right_dmg" },
    { 0x40BD, "door_gag_door_watcher" },
    { 0x40BE, "door_gag_magic_bullet" },
    { 0x40BF, "door_gags" },
    { 0x40C0, "door_get_pushspot" },
    { 0x40C1, "door_guy_spawn" },
    { 0x40C2, "door_hint_dist_scale" },
    { 0x40C3, "door_hit_fx" },
    { 0x40C4, "door_interact_presentation" },
    { 0x40C5, "door_interaction" },
    { 0x40C6, "door_intro_end" },
    { 0x40C7, "door_intro_performance" },
    { 0x40C8, "door_is_at_max_yaw" },
    { 0x40C9, "door_is_half_open" },
    { 0x40CA, "door_kick_player_push" },
    { 0x40CB, "door_kick_scene" },
    { 0x40CC, "door_latch" },
    { 0x40CD, "door_manage_openers" },
    { 0x40CE, "door_manager_try_ai_opener" },
    { 0x40CF, "door_name" },
    { 0x40D0, "door_needs_to_close" },
    { 0x40D1, "door_open" },
    { 0x40D2, "door_open_close_loop" },
    { 0x40D3, "door_open_completely" },
    { 0x40D4, "door_open_think" },
    { 0x40D5, "door_opened" },
    { 0x40D6, "door_opener_check_for_damage" },
    { 0x40D7, "door_parse_parameters" },
    { 0x40D8, "door_peak_alerted_monitor" },
    { 0x40D9, "door_peak_death_monitor" },
    { 0x40DA, "door_peak_timer" },
    { 0x40DB, "door_peek_death_fail" },
    { 0x40DC, "door_post_load" },
    { 0x40DD, "door_react" },
    { 0x40DE, "door_react_anim" },
    { 0x40DF, "door_remove_open_prompts" },
    { 0x40E0, "door_scene_init" },
    { 0x40E1, "door_script_model_anims" },
    { 0x40E2, "door_setup" },
    { 0x40E3, "door_spawn_entrance" },
    { 0x40E4, "door_spawner" },
    { 0x40E5, "door_speed_modifier_monitor" },
    { 0x40E6, "door_state_change" },
    { 0x40E7, "door_state_exit" },
    { 0x40E8, "door_state_next" },
    { 0x40E9, "door_state_on_interrupt" },
    { 0x40EA, "door_state_update" },
    { 0x40EB, "door_state_update_sound" },
    { 0x40EC, "door_surprise_breach" },
    { 0x40ED, "door_system_init" },
    { 0x40EE, "door_team_member_arrived" },
    { 0x40EF, "door_team_member_at_gate" },
    { 0x40F0, "door_think" },
    { 0x40F1, "door_unlocked" },
    { 0x40F2, "door_unresolved_collision_count" },
    { 0x40F3, "door_unresolved_collision_origin" },
    { 0x40F4, "door_unresolved_collision_start_time" },
    { 0x40F5, "door_waittill_open" },
    { 0x40F6, "door_waittill_snakecam" },
    { 0x40F7, "door_watch_unresolved_collision" },
    { 0x40F8, "door_watch_unresolved_collision_count" },
    { 0x40F9, "dooralarment" },
    { 0x40FA, "dooralarmowner" },
    { 0x40FB, "dooralarmprompt" },
    { 0x40FC, "dooralreadyopen" },
    { 0x40FD, "doorarrivalcount" },
    { 0x40FE, "doorbottomcenter" },
    { 0x40FF, "doorbottomhandle" },
    { 0x4100, "doorbottomorigin" },
    { 0x4101, "doorbust_guy_becomes_ai_if_alive" },
    { 0x4102, "doorbust_guy_spawn_func" },
    { 0x4103, "doorbuttoninteract" },
    { 0x4104, "doorcenter" },
    { 0x4105, "doorclip" },
    { 0x4106, "doorclose" },
    { 0x4107, "doorcontentoverride" },
    { 0x4108, "doorcount" },
    { 0x4109, "doordamagemod" },
    { 0x410A, "doordamagepoint" },
    { 0x410B, "doorfirecount" },
    { 0x410C, "doorflashchance" },
    { 0x410D, "doorgatecount" },
    { 0x410E, "doorguy" },
    { 0x410F, "doorid" },
    { 0x4110, "doormovetime" },
    { 0x4111, "doornavobstacle" },
    { 0x4112, "doorneedstoclose" },
    { 0x4113, "doornode" },
    { 0x4114, "dooroffset" },
    { 0x4115, "dooropen" },
    { 0x4116, "dooropenfunc" },
    { 0x4117, "doorphase" },
    { 0x4118, "doorpos" },
    { 0x4119, "doorrot" },
    { 0x411A, "doors" },
    { 0x411B, "doors_initialized" },
    { 0x411C, "doors_opened" },
    { 0x411D, "doors_think" },
    { 0x411E, "doors_waittill_any_open" },
    { 0x411F, "doors_waittill_any_snakecam" },
    { 0x4120, "doors_waittill_open_internal" },
    { 0x4121, "doors_waittill_snakecam" },
    { 0x4122, "doorsetupfinished" },
    { 0x4123, "doorsetupstarted" },
    { 0x4124, "doorspeedscale" },
    { 0x4125, "doortarget" },
    { 0x4126, "doortargetccw" },
    { 0x4127, "doortoopen" },
    { 0x4128, "doortraceframetime" },
    { 0x4129, "doortracemetrics" },
    { 0x412A, "doortracequeue" },
    { 0x412B, "doortraces" },
    { 0x412C, "doortracesthisframe" },
    { 0x412D, "doortype" },
    { 0x412E, "doorused" },
    { 0x412F, "dopain" },
    { 0x4130, "dopainfromarray" },
    { 0x4131, "dopickyautosavechecks" },
    { 0x4132, "doping" },
    { 0x4133, "doplanestrike" },
    { 0x4134, "doplayerkilledsplashes" },
    { 0x4135, "dopotgkillcam" },
    { 0x4136, "dopotgkillcamforplayer" },
    { 0x4137, "doprematch" },
    { 0x4138, "doradiationdamage" },
    { 0x4139, "dorandomguardanim" },
    { 0x413A, "doshellshock" },
    { 0x413B, "doshieldbashdeath" },
    { 0x413C, "doshoot" },
    { 0x413D, "doshoot_lmg" },
    { 0x413E, "doshoot_mgturret" },
    { 0x413F, "doslide" },
    { 0x4140, "doslowmo" },
    { 0x4141, "dosmartobject" },
    { 0x4142, "dosmartobject_init" },
    { 0x4143, "dosmartobjectterminate" },
    { 0x4144, "dosmokecurtains" },
    { 0x4145, "dosoloboost" },
    { 0x4146, "dosound" },
    { 0x4147, "dospawnvfx" },
    { 0x4148, "doswivelfiring" },
    { 0x4149, "dot" },
    { 0x414A, "dot_override" },
    { 0x414B, "dotaunt" },
    { 0x414C, "dothreatcalloutresponse" },
    { 0x414D, "dotimer" },
    { 0x414E, "dotraversal" },
    { 0x414F, "dotraversalwithflexibleheight" },
    { 0x4150, "dotraversalwithflexibleheight_internal" },
    { 0x4151, "dotraverse" },
    { 0x4152, "dotypelimit" },
    { 0x4153, "double_doors_hint_pos" },
    { 0x4154, "double_doors_init" },
    { 0x4155, "double_doors_init_auto" },
    { 0x4156, "double_doors_init_targetname" },
    { 0x4157, "double_doors_waittill_bashed" },
    { 0x4158, "double_doors_waittill_interact" },
    { 0x4159, "double_doors_waittill_open_completely" },
    { 0x415A, "double_grenades_allowed" },
    { 0x415B, "doublebubblesort" },
    { 0x415C, "doubledip" },
    { 0x415D, "doubledoorother" },
    { 0x415E, "doubledoors" },
    { 0x415F, "doublejumpdetected" },
    { 0x4160, "doublejumpearlyterminate" },
    { 0x4161, "doublejumpenergy" },
    { 0x4162, "doublejumpenergyrestorerate" },
    { 0x4163, "doublejumpmantlepos" },
    { 0x4164, "doublejumpneedsfinishanim" },
    { 0x4165, "doublejumpterminate" },
    { 0x4166, "doublekillreloadwatcher" },
    { 0x4167, "dovisualdeath" },
    { 0x4168, "dovofacingwait" },
    { 0x4169, "dovofacingwaittime" },
    { 0x416A, "dowait" },
    { 0x416B, "doweaponperkupdate" },
    { 0x416C, "dowhizby" },
    { 0x416D, "dowhizbycleanup" },
    { 0x416E, "down_angles" },
    { 0x416F, "downed_pilot_dialogue" },
    { 0x4170, "downed_pilot_nag" },
    { 0x4171, "downgradeweapon" },
    { 0x4172, "downgradeweaponaftertimeout" },
    { 0x4173, "downsperweaponlog" },
    { 0x4174, "downstairs_catchup" },
    { 0x4175, "downstairs_clip_management" },
    { 0x4176, "downstairs_nags" },
    { 0x4177, "downstairs_start" },
    { 0x4178, "downswithweapon" },
    { 0x4179, "downtime" },
    { 0x417A, "dpad_consumable_selection_watch" },
    { 0x417B, "dpad_drain_activations" },
    { 0x417C, "dpad_drain_time" },
    { 0x417D, "dpad_drain_triggerpassive" },
    { 0x417E, "dpad_drain_wave" },
    { 0x417F, "dpad_munition_monitor" },
    { 0x4180, "dpad_selection_index" },
    { 0x4181, "dpadcallback" },
    { 0x4182, "dpaddown" },
    { 0x4183, "dpadleft" },
    { 0x4184, "dpadname" },
    { 0x4185, "dpadright" },
    { 0x4186, "dpadup" },
    { 0x4187, "drag_buddy_go_to_combat" },
    { 0x4188, "drag_main" },
    { 0x4189, "drag_pistol_swap" },
    { 0x418A, "drag_player_away" },
    { 0x418B, "drag_playerblackoverlaylogic" },
    { 0x418C, "drag_playerblurlogic" },
    { 0x418D, "drag_playerfovlogic" },
    { 0x418E, "drag_playergasmaskoverlaylogic" },
    { 0x418F, "drag_scene" },
    { 0x4190, "drag_scene_internal" },
    { 0x4191, "drag_scene_shoot" },
    { 0x4192, "drag_start" },
    { 0x4193, "dragallyprototype" },
    { 0x4194, "draggedmarine" },
    { 0x4195, "draggingmarine" },
    { 0x4196, "dragonpoints" },
    { 0x4197, "dragons_breath_catchup" },
    { 0x4198, "dragons_breath_hit_farah" },
    { 0x4199, "dragons_breath_main" },
    { 0x419A, "dragons_breath_scene" },
    { 0x419B, "dragons_breath_shot" },
    { 0x419C, "dragons_breath_start" },
    { 0x419D, "dragonsbreathpainfxhack" },
    { 0x419E, "dragonsbreathpainfxhackspawnfunc" },
    { 0x419F, "dragtaguntildeath" },
    { 0x41A0, "dragtoidle" },
    { 0x41A1, "drain_super_meter" },
    { 0x41A2, "draining_health" },
    { 0x41A3, "drainroomdoorinteract" },
    { 0x41A4, "draw_3d_path" },
    { 0x41A5, "draw_angles" },
    { 0x41A6, "draw_angles_on_line" },
    { 0x41A7, "draw_arrow" },
    { 0x41A8, "draw_arrow_for_time" },
    { 0x41A9, "draw_arrow_time" },
    { 0x41AA, "draw_axis" },
    { 0x41AB, "draw_box" },
    { 0x41AC, "draw_box_forever" },
    { 0x41AD, "draw_capsule" },
    { 0x41AE, "draw_capsule_until_notifies" },
    { 0x41AF, "draw_character_capsule" },
    { 0x41B0, "draw_circle" },
    { 0x41B1, "draw_circle_lines_until_notify" },
    { 0x41B2, "draw_circle_until_notify" },
    { 0x41B3, "draw_closest_wall_points" },
    { 0x41B4, "draw_color_friendlies" },
    { 0x41B5, "draw_colornodes" },
    { 0x41B6, "draw_cool_circle" },
    { 0x41B7, "draw_cool_circle_for_time" },
    { 0x41B8, "draw_cool_circle_til_notify" },
    { 0x41B9, "draw_cross" },
    { 0x41BA, "draw_debug_cross" },
    { 0x41BB, "draw_debug_rectangle" },
    { 0x41BC, "draw_distance" },
    { 0x41BD, "draw_dot_for_ent" },
    { 0x41BE, "draw_dot_for_guy" },
    { 0x41BF, "draw_effects_list" },
    { 0x41C0, "draw_ent_axis" },
    { 0x41C1, "draw_ent_axis_forever" },
    { 0x41C2, "draw_ent_bone_forever" },
    { 0x41C3, "draw_entity_bounds" },
    { 0x41C4, "draw_flashlight_fov" },
    { 0x41C5, "draw_fov" },
    { 0x41C6, "draw_highlight" },
    { 0x41C7, "draw_line" },
    { 0x41C8, "draw_line_for_time" },
    { 0x41C9, "draw_line_for_time_endon_death" },
    { 0x41CA, "draw_line_from_ent_for_time" },
    { 0x41CB, "draw_line_from_ent_to_ent_for_time" },
    { 0x41CC, "draw_line_from_ent_to_ent_until_notify" },
    { 0x41CD, "draw_line_from_ent_to_vec_for_time" },
    { 0x41CE, "draw_line_to_ent_for_time" },
    { 0x41CF, "draw_line_until_endons" },
    { 0x41D0, "draw_line_until_notify" },
    { 0x41D1, "draw_lines_based_on_delay" },
    { 0x41D2, "draw_max_yaw" },
    { 0x41D3, "draw_menu_options" },
    { 0x41D4, "draw_node" },
    { 0x41D5, "draw_node_line" },
    { 0x41D6, "draw_origin" },
    { 0x41D7, "draw_placement_circle" },
    { 0x41D8, "draw_player_capsule" },
    { 0x41D9, "draw_point" },
    { 0x41DA, "draw_small_arrow" },
    { 0x41DB, "draw_spawner" },
    { 0x41DC, "draw_spawner_edit_path" },
    { 0x41DD, "draw_spotlight_fov" },
    { 0x41DE, "draw_tag_axis" },
    { 0x41DF, "draw_tag_axis_forever" },
    { 0x41E0, "draw_text" },
    { 0x41E1, "draw_thermal" },
    { 0x41E2, "draw_trace" },
    { 0x41E3, "draw_trace_hit" },
    { 0x41E4, "draw_trace_type" },
    { 0x41E5, "drawangles" },
    { 0x41E6, "drawarrow" },
    { 0x41E7, "drawassignedgoalpos" },
    { 0x41E8, "drawaxis" },
    { 0x41E9, "drawbcdirections" },
    { 0x41EA, "drawbcobject" },
    { 0x41EB, "drawboxfrompoints" },
    { 0x41EC, "drawcircle" },
    { 0x41ED, "drawcirculararrow" },
    { 0x41EE, "drawcount" },
    { 0x41EF, "drawcross" },
    { 0x41F0, "drawcylinder" },
    { 0x41F1, "drawdebugdestination" },
    { 0x41F2, "drawent" },
    { 0x41F3, "drawenttag" },
    { 0x41F4, "drawfriend" },
    { 0x41F5, "drawgoalpos" },
    { 0x41F6, "drawline" },
    { 0x41F7, "drawminimapbounds" },
    { 0x41F8, "drawn" },
    { 0x41F9, "drawneedtoturn" },
    { 0x41FA, "drawsphere" },
    { 0x41FB, "drawstring" },
    { 0x41FC, "drawstringtime" },
    { 0x41FD, "drawtag" },
    { 0x41FE, "drawtagforever" },
    { 0x41FF, "drive_along_path" },
    { 0x4200, "drive_black_fade" },
    { 0x4201, "drive_caption_vo" },
    { 0x4202, "drive_catchup" },
    { 0x4203, "drive_cine_dof_settings" },
    { 0x4204, "drive_down_hill_enemy_spawn_think" },
    { 0x4205, "drive_main" },
    { 0x4206, "drive_normal" },
    { 0x4207, "drive_or_slow_for_collision" },
    { 0x4208, "drive_skip_blackoverlay" },
    { 0x4209, "drive_spline_path_fun" },
    { 0x420A, "drive_start" },
    { 0x420B, "drive_start_vo" },
    { 0x420C, "driveby_proximity_monitor" },
    { 0x420D, "driveidle" },
    { 0x420E, "driveidle_animrate" },
    { 0x420F, "driveidle_normal_speed" },
    { 0x4210, "driveidle_r" },
    { 0x4211, "driver" },
    { 0x4212, "driver_death_watcher" },
    { 0x4213, "driver_idle_speed" },
    { 0x4214, "driver_models" },
    { 0x4215, "driver_play_sound_func" },
    { 0x4216, "driver_ready" },
    { 0x4217, "driver_shooting" },
    { 0x4218, "driverdead" },
    { 0x4219, "drivernode" },
    { 0x421A, "driverseatid" },
    { 0x421B, "driverwindow" },
    { 0x421C, "drivingtank" },
    { 0x421D, "drivingvehicle" },
    { 0x421E, "drone" },
    { 0x421F, "drone_ammo_watcher" },
    { 0x4220, "drone_anims" },
    { 0x4221, "drone_array_handling" },
    { 0x4222, "drone_attack_checks" },
    { 0x4223, "drone_cancel_notify_delay" },
    { 0x4224, "drone_catchup" },
    { 0x4225, "drone_control" },
    { 0x4226, "drone_controls_hints" },
    { 0x4227, "drone_counter" },
    { 0x4228, "drone_death_handler" },
    { 0x4229, "drone_death_thread" },
    { 0x422A, "drone_delete_on_unload" },
    { 0x422B, "drone_destroy_catcher" },
    { 0x422C, "drone_drop_real_weapon_on_death" },
    { 0x422D, "drone_exit_delayed" },
    { 0x422E, "drone_explode" },
    { 0x422F, "drone_fail_audio" },
    { 0x4230, "drone_fight" },
    { 0x4231, "drone_fire_randomly" },
    { 0x4232, "drone_friendly_fire_watcher" },
    { 0x4233, "drone_get_goal_loc_with_arrival" },
    { 0x4234, "drone_give_soul" },
    { 0x4235, "drone_gone_watcher" },
    { 0x4236, "drone_hero_lighting_on" },
    { 0x4237, "drone_hero_lighting_setup" },
    { 0x4238, "drone_idle" },
    { 0x4239, "drone_idle_custom" },
    { 0x423A, "drone_idle_override" },
    { 0x423B, "drone_init" },
    { 0x423C, "drone_init_path" },
    { 0x423D, "drone_intro_cine_camera_settings" },
    { 0x423E, "drone_intro_scene" },
    { 0x423F, "drone_inverted_controls_swap" },
    { 0x4240, "drone_killed_due_to_out_of_range_monitor" },
    { 0x4241, "drone_look_ahead_point" },
    { 0x4242, "drone_lookahead_value" },
    { 0x4243, "drone_lookat" },
    { 0x4244, "drone_loop_custom" },
    { 0x4245, "drone_loop_override" },
    { 0x4246, "drone_main" },
    { 0x4247, "drone_model" },
    { 0x4248, "drone_move" },
    { 0x4249, "drone_move_callback" },
    { 0x424A, "drone_move_z" },
    { 0x424B, "drone_nags" },
    { 0x424C, "drone_nags_disable" },
    { 0x424D, "drone_nags_enable" },
    { 0x424E, "drone_origin_updater" },
    { 0x424F, "drone_paths" },
    { 0x4250, "drone_play_looping_anim" },
    { 0x4251, "drone_play_scripted_anim" },
    { 0x4252, "drone_play_weapon_sound" },
    { 0x4253, "drone_rocket_delay_msg" },
    { 0x4254, "drone_run_speed" },
    { 0x4255, "drone_shoot" },
    { 0x4256, "drone_shoot_fx" },
    { 0x4257, "drone_spawn_func" },
    { 0x4258, "drone_start" },
    { 0x4259, "drone_start_position" },
    { 0x425A, "drone_strike_activate_function" },
    { 0x425B, "drone_strike_dir_override" },
    { 0x425C, "drone_target" },
    { 0x425D, "drone_thermal_draw_disable" },
    { 0x425E, "drone_updater" },
    { 0x425F, "drone_vo" },
    { 0x4260, "drone_wait_move" },
    { 0x4261, "droneanim" },
    { 0x4262, "droneanims" },
    { 0x4263, "dronebankeffects" },
    { 0x4264, "dronecallbackthread" },
    { 0x4265, "dronedamageeffectslogic" },
    { 0x4266, "dronedamagelogic" },
    { 0x4267, "dronedamagerotatelogic" },
    { 0x4268, "dronedamagevisionlogic" },
    { 0x4269, "dronedetonatewatcher" },
    { 0x426A, "droneenemieslogic" },
    { 0x426B, "droneenemiestargetlogic" },
    { 0x426C, "droneenemyshootvfxlogic" },
    { 0x426D, "droneenemyvalid" },
    { 0x426E, "droneenginesfx" },
    { 0x426F, "dronefailed" },
    { 0x4270, "dronegetimpactinfoondeath" },
    { 0x4271, "droneheliimpactwatcher" },
    { 0x4272, "droneimpactexplosion" },
    { 0x4273, "droneimpactwatcher" },
    { 0x4274, "dronekillcamlogic" },
    { 0x4275, "dronemissilespawnarray" },
    { 0x4276, "droneoutofboundslogic" },
    { 0x4277, "droneoutofboundsvisionlogic" },
    { 0x4278, "droneplayerrestore" },
    { 0x4279, "droneplayersetup" },
    { 0x427A, "dronepropellerfx" },
    { 0x427B, "dronerunoffset" },
    { 0x427C, "drones" },
    { 0x427D, "drones_disabled" },
    { 0x427E, "drones_targets_sets_to_default" },
    { 0x427F, "dronescreenfx" },
    { 0x4280, "dronesetvehspeed" },
    { 0x4281, "dronesetvehspeedthreaded" },
    { 0x4282, "dronespawn" },
    { 0x4283, "dronespawn_bodyonly" },
    { 0x4284, "dronespawner_init" },
    { 0x4285, "dronesprinteffectsinlogic" },
    { 0x4286, "dronesprinteffectsoutlogic" },
    { 0x4287, "dronesprintlogic" },
    { 0x4288, "dronestaticmbscreenfx" },
    { 0x4289, "dronesthermalteamselect" },
    { 0x428A, "dronestrikeactivatefunc" },
    { 0x428B, "dronetimeoutlogic" },
    { 0x428C, "droneupdateoriginandanglestildeath" },
    { 0x428D, "drop_bomb_detonator" },
    { 0x428E, "drop_bomb_detonator_from_ai" },
    { 0x428F, "drop_bomb_detonator_from_player" },
    { 0x4290, "drop_bots" },
    { 0x4291, "drop_fast_rope" },
    { 0x4292, "drop_flare_when_dead" },
    { 0x4293, "drop_glowstick" },
    { 0x4294, "drop_grenade" },
    { 0x4295, "drop_gun" },
    { 0x4296, "drop_hvt_key" },
    { 0x4297, "drop_intel_from_hvt" },
    { 0x4298, "drop_intel_piece" },
    { 0x4299, "drop_interaction_structs_to_ground" },
    { 0x429A, "drop_marker_after_time" },
    { 0x429B, "drop_obstacle_on_death" },
    { 0x429C, "drop_officer" },
    { 0x429D, "drop_on_death" },
    { 0x429E, "drop_pistol_on_death" },
    { 0x429F, "drop_ready_item" },
    { 0x42A0, "drop_script_weapon_from_ai" },
    { 0x42A1, "drop_selection_to_ground" },
    { 0x42A2, "drop_special_item" },
    { 0x42A3, "drop_to_ground" },
    { 0x42A4, "drop_to_ground_ignore_vehicle" },
    { 0x42A5, "drop_walkie_prop" },
    { 0x42A6, "drop_weapon" },
    { 0x42A7, "drop_weapon_func" },
    { 0x42A8, "drop_weapon_now" },
    { 0x42A9, "dropaiweapon" },
    { 0x42AA, "dropaiweaponinternal" },
    { 0x42AB, "dropallaiweapons" },
    { 0x42AC, "dropanim" },
    { 0x42AD, "droparmcratefromscriptedheli" },
    { 0x42AE, "droparmor" },
    { 0x42AF, "dropbagspawned" },
    { 0x42B0, "dropbagstruct" },
    { 0x42B1, "dropbody" },
    { 0x42B2, "dropbombmodel" },
    { 0x42B3, "dropbombs" },
    { 0x42B4, "dropbrcratefrommanualheli" },
    { 0x42B5, "dropbrcratefromscriptedheli" },
    { 0x42B6, "dropbrloadoutcrate" },
    { 0x42B7, "dropbrloot" },
    { 0x42B8, "dropbrpersonalcratefrommanualheli" },
    { 0x42B9, "dropcarepackage" },
    { 0x42BA, "dropcarryobject" },
    { 0x42BB, "dropchances" },
    { 0x42BC, "dropclipmodel" },
    { 0x42BD, "dropcrate" },
    { 0x42BE, "dropcratefrommanualheli" },
    { 0x42BF, "dropcratefromscriptedheli" },
    { 0x42C0, "dropcrates" },
    { 0x42C1, "dropdefconkillstreaks" },
    { 0x42C2, "dropequipmentinslot" },
    { 0x42C3, "dropgrenade" },
    { 0x42C4, "drophelicrate" },
    { 0x42C5, "drophintstring" },
    { 0x42C6, "drophostage" },
    { 0x42C7, "drophud" },
    { 0x42C8, "dropintolaststand" },
    { 0x42C9, "dropitemfrominventory" },
    { 0x42CA, "dropjuggernautweapon" },
    { 0x42CB, "dropkillstreakcrate" },
    { 0x42CC, "dropkillstreakcratefrommanualheli" },
    { 0x42CD, "dropkillstreakcratefromscriptedheli" },
    { 0x42CE, "dropkillstreakcrates" },
    { 0x42CF, "droplaunchchunkbots" },
    { 0x42D0, "droplocations" },
    { 0x42D1, "droploot" },
    { 0x42D2, "dropnukeweapon" },
    { 0x42D3, "dropoldequipinplace" },
    { 0x42D4, "droponplayerdeath" },
    { 0x42D5, "dropped_weapon_func" },
    { 0x42D6, "dropped_weapons" },
    { 0x42D7, "droppeddeathweapon" },
    { 0x42D8, "droppeditems" },
    { 0x42D9, "droppedlmgpickuptime" },
    { 0x42DA, "droppedscriptables" },
    { 0x42DB, "droppedteam" },
    { 0x42DC, "droppedweaponent" },
    { 0x42DD, "droppedweapons" },
    { 0x42DE, "droppingtoground" },
    { 0x42DF, "dropplayerstags" },
    { 0x42E0, "dropplunder" },
    { 0x42E1, "dropplunderbyrarity" },
    { 0x42E2, "dropplundersounds" },
    { 0x42E3, "dropposition" },
    { 0x42E4, "droppostoground" },
    { 0x42E5, "dropscavengerfordeath" },
    { 0x42E6, "dropscavengerfordeathinternal" },
    { 0x42E7, "dropship_change_thrust_sfx" },
    { 0x42E8, "dropspawn" },
    { 0x42E9, "dropspawnmindist2dsqrbyref" },
    { 0x42EA, "dropspawnmindistbyref" },
    { 0x42EB, "dropspawns" },
    { 0x42EC, "dropstruct" },
    { 0x42ED, "droptags" },
    { 0x42EE, "droptagsesc" },
    { 0x42EF, "droptagsoftype" },
    { 0x42F0, "droptank_deathwatcherandspawn" },
    { 0x42F1, "droptank_onposition" },
    { 0x42F2, "droptank_playincomingdialog" },
    { 0x42F3, "droptestminigunondeath" },
    { 0x42F4, "droptime" },
    { 0x42F5, "droptonavmeshtriggers" },
    { 0x42F6, "dropturret" },
    { 0x42F7, "dropturretproc" },
    { 0x42F8, "droptype" },
    { 0x42F9, "dropusestraceorigin" },
    { 0x42FA, "dropweaponcarepackage" },
    { 0x42FB, "dropweaponfordeath" },
    { 0x42FC, "dropweaponfordeathlaunch" },
    { 0x42FD, "dropweaponwrapper" },
    { 0x42FE, "drug_guy_kill" },
    { 0x42FF, "druggedwomanresponsecount" },
    { 0x4300, "dry_fire_bullet_anims" },
    { 0x4301, "dual_firing" },
    { 0x4302, "duckingtime" },
    { 0x4303, "dudes_carried_anim" },
    { 0x4304, "dudgrenadeused" },
    { 0x4305, "dummy" },
    { 0x4306, "dummy_damage_watcher" },
    { 0x4307, "dummy_flares" },
    { 0x4308, "dummy_flares_snake_go" },
    { 0x4309, "dummy_player" },
    { 0x430A, "dummy_target" },
    { 0x430B, "dummy_targets" },
    { 0x430C, "dummychopper" },
    { 0x430D, "dummydefender" },
    { 0x430E, "dummymodel" },
    { 0x430F, "dummytarget" },
    { 0x4310, "dump_models" },
    { 0x4311, "dumplogsloop" },
    { 0x4312, "dumpster_guy_stand_up" },
    { 0x4313, "duplicate_struct" },
    { 0x4314, "duration" },
    { 0x4315, "duration_increase" },
    { 0x4316, "duration_multiplier" },
    { 0x4317, "dustfx" },
    { 0x4318, "dustmaterial" },
    { 0x4319, "dvar" },
    { 0x431A, "dvarfloatvalue" },
    { 0x431B, "dvarfuncs" },
    { 0x431C, "dvarintvalue" },
    { 0x431D, "dwn_twn_safehouse_loadout" },
    { 0x431E, "dx_mortar_launch_callout" },
    { 0x431F, "dyanmic_sun_sample_size" },
    { 0x4320, "dying" },
    { 0x4321, "dying_boy_face" },
    { 0x4322, "dying_soon" },
    { 0x4323, "dyingcrawl" },
    { 0x4324, "dyingcrawlaiming" },
    { 0x4325, "dyingcrawlbackaim" },
    { 0x4326, "dyingcrawlbloodsmear" },
    { 0x4327, "dynamic_backdist" },
    { 0x4328, "dynamic_dof" },
    { 0x4329, "dynamic_frontdist" },
    { 0x432A, "dynamic_knife_anims" },
    { 0x432B, "dynamic_knife_kill_anims" },
    { 0x432C, "dynamic_knife_kill_anims_player" },
    { 0x432D, "dynamic_middist" },
    { 0x432E, "dynamic_run_setup" },
    { 0x432F, "dynamic_run_speed_goalpos" },
    { 0x4330, "dynamic_run_speed_set" },
    { 0x4331, "dynamic_run_speed_thread" },
    { 0x4332, "dynamic_spawn_locations" },
    { 0x4333, "dynamic_takedowns_monitor" },
    { 0x4334, "dynamicent" },
    { 0x4335, "dynamicladders" },
    { 0x4336, "dynamiclightset" },
    { 0x4337, "dynamiclightsethq" },
    { 0x4338, "dynamicspawns" },
    { 0x4339, "dyndof" },
    { 0x433A, "dyndof_debug" },
    { 0x433B, "dyndof_disable" },
    { 0x433C, "dyndof_distance" },
    { 0x433D, "dyndof_getplayerangles" },
    { 0x433E, "dyndof_getplayerorigin" },
    { 0x433F, "dyndof_hastag" },
    { 0x4340, "dyndof_thread" },
    { 0x4341, "dyndof_trace_internal" },
    { 0x4342, "dyndof_trace_target" },
    { 0x4343, "dynolight_area_ai" },
    { 0x4344, "dynolight_area_trigger_logic" },
    { 0x4345, "dynolight_death_watcher" },
    { 0x4346, "dynolight_falloff_dist" },
    { 0x4347, "dynolight_postload_state_init" },
    { 0x4348, "dynolight_set_onoff_state" },
    { 0x4349, "dynolight_trace_contents" },
    { 0x434A, "dynolight_trace_passed" },
    { 0x434B, "dynolight_update_nvg_mode" },
    { 0x434C, "dynolights" },
    { 0x434D, "dynolights_initialized" },
    { 0x434E, "dzmainloop" },
    { 0x434F, "e" },
    { 0x4350, "e1" },
    { 0x4351, "e2" },
    { 0x4352, "e3" },
    { 0x4353, "e3_audio_demo" },
    { 0x4354, "e3_audio_demo_start" },
    { 0x4355, "e4" },
    { 0x4356, "e5" },
    { 0x4357, "each_player_remotestarted" },
    { 0x4358, "eairstrikeheight" },
    { 0x4359, "early_death" },
    { 0x435A, "early_level" },
    { 0x435B, "early_return" },
    { 0x435C, "early_tank_guy" },
    { 0x435D, "earlyexit" },
    { 0x435E, "earlyfinishtime" },
    { 0x435F, "earlyremoveradarperk" },
    { 0x4360, "earned" },
    { 0x4361, "earnedfastexfil" },
    { 0x4362, "earnedmaxkillstreak" },
    { 0x4363, "earnedstreaklevel" },
    { 0x4364, "earnkillstreak" },
    { 0x4365, "earthquake" },
    { 0x4366, "earthquake_and_rumble" },
    { 0x4367, "earthquake_for_client" },
    { 0x4368, "east_gate" },
    { 0x4369, "east_wall_01" },
    { 0x436A, "east_wall_02" },
    { 0x436B, "east_wall_03" },
    { 0x436C, "east_wall_04" },
    { 0x436D, "east_wall_05" },
    { 0x436E, "east_wall_06" },
    { 0x436F, "east_wall_07" },
    { 0x4370, "east_wall_mortars" },
    { 0x4371, "easter_egg_tv_light_flicker" },
    { 0x4372, "easter_egg_tv_teddy" },
    { 0x4373, "easter_egg_tv_teddy_monitor" },
    { 0x4374, "easter_egg_tv_teddy_monitor_helper" },
    { 0x4375, "easter_eggs" },
    { 0x4376, "easy_position_creator" },
    { 0x4377, "eattacker" },
    { 0x4378, "edge_placement" },
    { 0x4379, "edge_point_valid" },
    { 0x437A, "edit_loadout" },
    { 0x437B, "edit_spawner" },
    { 0x437C, "edit_spawner_exit" },
    { 0x437D, "effect" },
    { 0x437E, "effect_list_offset" },
    { 0x437F, "effect_list_offset_max" },
    { 0x4380, "effect_loopsound" },
    { 0x4381, "effect_soundalias" },
    { 0x4382, "effect_tag" },
    { 0x4383, "effectid" },
    { 0x4384, "effecttime" },
    { 0x4385, "effortvoice" },
    { 0x4386, "efsm_add_machine_state" },
    { 0x4387, "efsm_add_machine_transition" },
    { 0x4388, "efsm_can_interrupt" },
    { 0x4389, "efsm_change_state" },
    { 0x438A, "efsm_event_monitor" },
    { 0x438B, "efsm_get_state" },
    { 0x438C, "efsm_idle_check" },
    { 0x438D, "efsm_init" },
    { 0x438E, "efsm_is_valid_transition" },
    { 0x438F, "efsm_request_state" },
    { 0x4390, "efsm_setup_movement_machine" },
    { 0x4391, "efsm_spawn_machine" },
    { 0x4392, "efsm_stick_input" },
    { 0x4393, "eight_point_strafe_requested" },
    { 0x4394, "einflictor" },
    { 0x4395, "either_player_looking_at" },
    { 0x4396, "electrictrap_hint_displayed" },
    { 0x4397, "electrocuted" },
    { 0x4398, "elements" },
    { 0x4399, "elemtype" },
    { 0x439A, "elevator_accel" },
    { 0x439B, "elevator_aggressive_call" },
    { 0x439C, "elevator_button_activate" },
    { 0x439D, "elevator_button_hint" },
    { 0x439E, "elevator_call" },
    { 0x439F, "elevator_callbutton_link_h" },
    { 0x43A0, "elevator_callbutton_link_v" },
    { 0x43A1, "elevator_callbuttons" },
    { 0x43A2, "elevator_debug" },
    { 0x43A3, "elevator_decel" },
    { 0x43A4, "elevator_floor_update" },
    { 0x43A5, "elevator_fsm" },
    { 0x43A6, "elevator_get_dvar" },
    { 0x43A7, "elevator_get_dvar_int" },
    { 0x43A8, "elevator_innerdoorspeed" },
    { 0x43A9, "elevator_interrupt" },
    { 0x43AA, "elevator_interrupted" },
    { 0x43AB, "elevator_motion_detection" },
    { 0x43AC, "elevator_move" },
    { 0x43AD, "elevator_moving" },
    { 0x43AE, "elevator_music" },
    { 0x43AF, "elevator_outterdoorspeed" },
    { 0x43B0, "elevator_return" },
    { 0x43B1, "elevator_sound_think" },
    { 0x43B2, "elevator_speed" },
    { 0x43B3, "elevator_think" },
    { 0x43B4, "elevator_update_global_dvars" },
    { 0x43B5, "elevator_waittime" },
    { 0x43B6, "elevators" },
    { 0x43B7, "eliminated" },
    { 0x43B8, "eliminatenullweapons" },
    { 0x43B9, "elite_chance" },
    { 0x43BA, "emb_nt_fire_magic_bullet" },
    { 0x43BB, "emb_nt_hide_viewmodel" },
    { 0x43BC, "emb_roof_door_open" },
    { 0x43BD, "emb_roof_door_remove" },
    { 0x43BE, "emb_roof_door_setup" },
    { 0x43BF, "emb_roof_pre_office_vo" },
    { 0x43C0, "emb_roof_vo" },
    { 0x43C1, "emb_rooftop_corner_clean" },
    { 0x43C2, "emb_rooftop_corner_destructed" },
    { 0x43C3, "embassy_alarm_sound_ent_01" },
    { 0x43C4, "embassy_alarm_sound_ent_02" },
    { 0x43C5, "embassy_alarm_sound_ent_03" },
    { 0x43C6, "embassy_alarm_sound_ent_04" },
    { 0x43C7, "embassy_cctv_flags" },
    { 0x43C8, "embassy_cctv_fx" },
    { 0x43C9, "embassy_cctv_init" },
    { 0x43CA, "embassy_cctv_precache" },
    { 0x43CB, "embassy_crowd_sound_ent_01" },
    { 0x43CC, "embassy_crowd_sound_ent_02" },
    { 0x43CD, "embassy_defend_flags" },
    { 0x43CE, "embassy_defend_fx" },
    { 0x43CF, "embassy_defend_precache" },
    { 0x43D0, "embassy_defend_precache_delay" },
    { 0x43D1, "embassy_flags" },
    { 0x43D2, "embassy_fx" },
    { 0x43D3, "embassy_gate_sound_ent_01" },
    { 0x43D4, "embassy_helicopter_struggle_sound_ent" },
    { 0x43D5, "embassy_helicopter_struggle_tone_sound_ent" },
    { 0x43D6, "embassy_hints" },
    { 0x43D7, "embassy_infil_chopper_crash_explo_sfx" },
    { 0x43D8, "embassy_infil_flags" },
    { 0x43D9, "embassy_infil_fx" },
    { 0x43DA, "embassy_infil_hints" },
    { 0x43DB, "embassy_infil_init" },
    { 0x43DC, "embassy_infil_objectives" },
    { 0x43DD, "embassy_infil_precache" },
    { 0x43DE, "embassy_infil_precache_delay" },
    { 0x43DF, "embassy_infil_scriptables_grab" },
    { 0x43E0, "embassy_inits" },
    { 0x43E1, "embassy_palm_trees" },
    { 0x43E2, "embassy_post_truck_alarm_sound_ent_01" },
    { 0x43E3, "embassy_post_truck_alarm_sound_ent_02" },
    { 0x43E4, "embassy_precache" },
    { 0x43E5, "embassy_roof_catchup" },
    { 0x43E6, "embassy_roof_main" },
    { 0x43E7, "embassy_roof_start" },
    { 0x43E8, "embassy_scale_speed_near_price" },
    { 0x43E9, "embassy_starts" },
    { 0x43EA, "embassy_technicals" },
    { 0x43EB, "embassy_util_flags" },
    { 0x43EC, "embassy_weapon_cleanup" },
    { 0x43ED, "emerge_main" },
    { 0x43EE, "emerge_playerspeedscalinglogic" },
    { 0x43EF, "emerge_start" },
    { 0x43F0, "emitfalldamage" },
    { 0x43F1, "emp" },
    { 0x43F2, "emp_damage_callback" },
    { 0x43F3, "emp_debuff_init" },
    { 0x43F4, "emp_drone_targeted_getmapselectpoint" },
    { 0x43F5, "emp_drone_targeted_monitordamage" },
    { 0x43F6, "emp_drone_targeted_startmapselectsequence" },
    { 0x43F7, "emp_effects_flickering" },
    { 0x43F8, "emp_effects_on_nearby_players" },
    { 0x43F9, "emp_get_level_data" },
    { 0x43FA, "emp_grenade_apply_non_player" },
    { 0x43FB, "emp_grenade_apply_player" },
    { 0x43FC, "emp_grenade_end_early" },
    { 0x43FD, "emp_grenade_used" },
    { 0x43FE, "emp_init" },
    { 0x43FF, "emp_reset_ents" },
    { 0x4400, "emp_update_ents" },
    { 0x4401, "empapplycallback" },
    { 0x4402, "empclearcallback" },
    { 0x4403, "empcount" },
    { 0x4404, "empdamage" },
    { 0x4405, "empdamageenabled" },
    { 0x4406, "empdrone_applyemp" },
    { 0x4407, "empdrone_beginsuper" },
    { 0x4408, "empdrone_calculatepositions" },
    { 0x4409, "empdrone_clearomnvars" },
    { 0x440A, "empdrone_collidethink" },
    { 0x440B, "empdrone_createdrone" },
    { 0x440C, "empdrone_delete" },
    { 0x440D, "empdrone_destroy" },
    { 0x440E, "empdrone_divebombthink" },
    { 0x440F, "empdrone_empapplied" },
    { 0x4410, "empdrone_empendearly" },
    { 0x4411, "empdrone_equipment_wrapper" },
    { 0x4412, "empdrone_exit" },
    { 0x4413, "empdrone_explode" },
    { 0x4414, "empdrone_explodeemp" },
    { 0x4415, "empdrone_findstartposition" },
    { 0x4416, "empdrone_givepointsfordeath" },
    { 0x4417, "empdrone_handledeathdamage" },
    { 0x4418, "empdrone_returnplayer" },
    { 0x4419, "empdrone_rundrone" },
    { 0x441A, "empdrone_superusethink" },
    { 0x441B, "empdrone_timeoutthink" },
    { 0x441C, "empdrone_tryuse" },
    { 0x441D, "empdrone_watchdetonate" },
    { 0x441E, "empdrone_watchearlyexit" },
    { 0x441F, "empdrone_weapongiven" },
    { 0x4420, "empdronebeginuse" },
    { 0x4421, "empendtime" },
    { 0x4422, "empgrenaded" },
    { 0x4423, "empjamandrumbleclients" },
    { 0x4424, "emplights" },
    { 0x4425, "emplightsoff" },
    { 0x4426, "emplooptime" },
    { 0x4427, "empmarked" },
    { 0x4428, "empnotallowed" },
    { 0x4429, "empplayer" },
    { 0x442A, "empradarwatcher" },
    { 0x442B, "empremovecallback" },
    { 0x442C, "empremoved" },
    { 0x442D, "empscramblelevels" },
    { 0x442E, "empsitewatcher" },
    { 0x442F, "empspawnindex" },
    { 0x4430, "empstartcallback" },
    { 0x4431, "empstuntime" },
    { 0x4432, "emptriggerholdonuse" },
    { 0x4433, "empty_breathing_func" },
    { 0x4434, "empty_func" },
    { 0x4435, "empty_init_func" },
    { 0x4436, "empty_spawner" },
    { 0x4437, "emptyallvehicles" },
    { 0x4438, "emptyfunc" },
    { 0x4439, "emptylocations" },
    { 0x443A, "emptytimeelapsed" },
    { 0x443B, "emptytimeoutduration" },
    { 0x443C, "empvfx" },
    { 0x443D, "emradiation" },
    { 0x443E, "enable_a10_wait_flags" },
    { 0x443F, "enable_ai_color" },
    { 0x4440, "enable_ai_color_dontmove" },
    { 0x4441, "enable_ai_dynolight_behavior" },
    { 0x4442, "enable_alien_scripted" },
    { 0x4443, "enable_allies_firing" },
    { 0x4444, "enable_allowdeath" },
    { 0x4445, "enable_ally_firing" },
    { 0x4446, "enable_ally_vision" },
    { 0x4447, "enable_arrivals" },
    { 0x4448, "enable_bleedout_ent_usability" },
    { 0x4449, "enable_bleedout_ent_usability_func" },
    { 0x444A, "enable_blindfire_behavior" },
    { 0x444B, "enable_blood_pool" },
    { 0x444C, "enable_breath_fx" },
    { 0x444D, "enable_bulletwhizbyreaction" },
    { 0x444E, "enable_c4_on_locked" },
    { 0x444F, "enable_careful" },
    { 0x4450, "enable_casual_killer" },
    { 0x4451, "enable_cell_door_collision" },
    { 0x4452, "enable_chair_carry" },
    { 0x4453, "enable_context_melee" },
    { 0x4454, "enable_cover_node_behavior" },
    { 0x4455, "enable_cqbwalk" },
    { 0x4456, "enable_damage" },
    { 0x4457, "enable_damage_on_landing" },
    { 0x4458, "enable_damagefeedback" },
    { 0x4459, "enable_danger_react" },
    { 0x445A, "enable_death_clearscriptedanim" },
    { 0x445B, "enable_defeat_on_kill_backup" },
    { 0x445C, "enable_dogtag_revive" },
    { 0x445D, "enable_dontevershoot" },
    { 0x445E, "enable_dynamic_run_speed" },
    { 0x445F, "enable_dynamic_takedowns" },
    { 0x4460, "enable_eight_point_strafe" },
    { 0x4461, "enable_escort_gesture" },
    { 0x4462, "enable_exits" },
    { 0x4463, "enable_features_for_disguised_player" },
    { 0x4464, "enable_firing" },
    { 0x4465, "enable_flashlight" },
    { 0x4466, "enable_global_vehicle_spawn_functions" },
    { 0x4467, "enable_hangar_vehicles" },
    { 0x4468, "enable_heat_behavior" },
    { 0x4469, "enable_ied" },
    { 0x446A, "enable_ignorerandombulletdamage_drone" },
    { 0x446B, "enable_infinite_ammo" },
    { 0x446C, "enable_intro_wait_flags" },
    { 0x446D, "enable_jammer_damage" },
    { 0x446E, "enable_juggernaut_move_behavior" },
    { 0x446F, "enable_laser" },
    { 0x4470, "enable_long_death" },
    { 0x4471, "enable_lookat" },
    { 0x4472, "enable_magic_bullet_shield" },
    { 0x4473, "enable_manual_revive" },
    { 0x4474, "enable_menu" },
    { 0x4475, "enable_on_world_progress_bar_for_other_players" },
    { 0x4476, "enable_outline" },
    { 0x4477, "enable_outline_for_player" },
    { 0x4478, "enable_outline_for_players" },
    { 0x4479, "enable_overwatch_model" },
    { 0x447A, "enable_pain" },
    { 0x447B, "enable_pilot_carry" },
    { 0x447C, "enable_pipes_hero_lights" },
    { 0x447D, "enable_pipes_jumpdown_lights" },
    { 0x447E, "enable_player_headtracking" },
    { 0x447F, "enable_procedural_bones" },
    { 0x4480, "enable_readystand" },
    { 0x4481, "enable_retreat_exterior_triggers" },
    { 0x4482, "enable_runout_bullet_clip" },
    { 0x4483, "enable_scriptable_shadows" },
    { 0x4484, "enable_segmented_health_regen" },
    { 0x4485, "enable_self_revive" },
    { 0x4486, "enable_snake_cams" },
    { 0x4487, "enable_snakecams_by_target" },
    { 0x4488, "enable_springcam" },
    { 0x4489, "enable_sprint" },
    { 0x448A, "enable_stayahead" },
    { 0x448B, "enable_stayahead_turbo" },
    { 0x448C, "enable_stealth_for_ai" },
    { 0x448D, "enable_stealth_system" },
    { 0x448E, "enable_stop_all_cars" },
    { 0x448F, "enable_surprise" },
    { 0x4490, "enable_tank_stackup" },
    { 0x4491, "enable_teamflashbangimmunity" },
    { 0x4492, "enable_teamflashbangimmunity_proc" },
    { 0x4493, "enable_trigger" },
    { 0x4494, "enable_trigger_with_noteworthy" },
    { 0x4495, "enable_trigger_with_targetname" },
    { 0x4496, "enable_turnanims" },
    { 0x4497, "enable_van_lights" },
    { 0x4498, "enable_vehicle_interaction" },
    { 0x4499, "enable_volumetrics" },
    { 0x449A, "enablealldepotsforplayer" },
    { 0x449B, "enableapcturretinteraction" },
    { 0x449C, "enablebattlechatter" },
    { 0x449D, "enableburnfx" },
    { 0x449E, "enableburnfxfortime" },
    { 0x449F, "enableburnsfx" },
    { 0x44A0, "enableciviliantargetfocus" },
    { 0x44A1, "enabled" },
    { 0x44A2, "enabledamageinvulnerability" },
    { 0x44A3, "enabledcollisionnotifies" },
    { 0x44A4, "enabledeathsdoor" },
    { 0x44A5, "enabledemeanorsafe" },
    { 0x44A6, "enabledequipdeployvfx" },
    { 0x44A7, "enabledignoreme" },
    { 0x44A8, "enabledropbagobjective" },
    { 0x44A9, "enableenemybaseoutline" },
    { 0x44AA, "enableeventlisteners" },
    { 0x44AB, "enableexecutionattackfunc" },
    { 0x44AC, "enableexecutionattackwrapper" },
    { 0x44AD, "enableexecutionvictimfunc" },
    { 0x44AE, "enableexecutionvictimwrapper" },
    { 0x44AF, "enableexitprompt" },
    { 0x44B0, "enableinfectedtracker" },
    { 0x44B1, "enablelookdownpathtime" },
    { 0x44B2, "enableloopingcoughaudio" },
    { 0x44B3, "enableloopingcoughaudiosupression" },
    { 0x44B4, "enablemanualpullchute" },
    { 0x44B5, "enablemeleeforsentry" },
    { 0x44B6, "enablemultibombui" },
    { 0x44B7, "enablemusic" },
    { 0x44B8, "enableobject" },
    { 0x44B9, "enableoob" },
    { 0x44BA, "enableoobimmunity" },
    { 0x44BB, "enableovertimegameplay" },
    { 0x44BC, "enableping" },
    { 0x44BD, "enableplayerforspawnlogic" },
    { 0x44BE, "enableplayeroutlinesforoverheadcam" },
    { 0x44BF, "enablepowerfunc" },
    { 0x44C0, "enableragdollzerog" },
    { 0x44C1, "enablerl" },
    { 0x44C2, "enablescriptableplayeruseall" },
    { 0x44C3, "enableshellshockfunc" },
    { 0x44C4, "enableslotinternal" },
    { 0x44C5, "enablespawnpointlist" },
    { 0x44C6, "enabletacopskit" },
    { 0x44C7, "enabletacopsstations" },
    { 0x44C8, "enabletrigger" },
    { 0x44C9, "enablevariantdrops" },
    { 0x44CA, "enablevisibilitycullingforclient" },
    { 0x44CB, "enableweaponlaser" },
    { 0x44CC, "encounter" },
    { 0x44CD, "encounter_end" },
    { 0x44CE, "encounter_location_start_functions" },
    { 0x44CF, "encounter_manager" },
    { 0x44D0, "encounter_performance" },
    { 0x44D1, "encounter_score_components" },
    { 0x44D2, "encounter_start" },
    { 0x44D3, "encounter_start_functions" },
    { 0x44D4, "encounterdeletedomgameobjectonend" },
    { 0x44D5, "encounterdeleteentonend" },
    { 0x44D6, "encounterlocation" },
    { 0x44D7, "encounterremovenavobstacle" },
    { 0x44D8, "encounterremovenavobstacledelay" },
    { 0x44D9, "encounterremovenavobstacleonencounterend" },
    { 0x44DA, "encounters" },
    { 0x44DB, "encourage_explosive_use" },
    { 0x44DC, "end" },
    { 0x44DD, "end_angles" },
    { 0x44DE, "end_barkov_model" },
    { 0x44DF, "end_blended_interaction_anims" },
    { 0x44E0, "end_bridge_start_struct_index" },
    { 0x44E1, "end_bus_bomber" },
    { 0x44E2, "end_captive_01_model" },
    { 0x44E3, "end_captive_02_model" },
    { 0x44E4, "end_captive_03_model" },
    { 0x44E5, "end_captive_04_model" },
    { 0x44E6, "end_captive_truck_model" },
    { 0x44E7, "end_collect_nuclear_core" },
    { 0x44E8, "end_color" },
    { 0x44E9, "end_destroy_c130" },
    { 0x44EA, "end_equip_disguise" },
    { 0x44EB, "end_exfil_plane" },
    { 0x44EC, "end_extract_lz" },
    { 0x44ED, "end_fardist" },
    { 0x44EE, "end_func" },
    { 0x44EF, "end_function_after_time" },
    { 0x44F0, "end_game_logic" },
    { 0x44F1, "end_game_score" },
    { 0x44F2, "end_game_score_component_ref" },
    { 0x44F3, "end_game_sequence" },
    { 0x44F4, "end_game_string_index" },
    { 0x44F5, "end_game_string_override" },
    { 0x44F6, "end_guys" },
    { 0x44F7, "end_heli_spawn_group" },
    { 0x44F8, "end_holdout" },
    { 0x44F9, "end_infil_plane" },
    { 0x44FA, "end_kill_tunnel_spawns" },
    { 0x44FB, "end_land_at_lz" },
    { 0x44FC, "end_level" },
    { 0x44FD, "end_ml_p1_intel" },
    { 0x44FE, "end_ml_p3_intel" },
    { 0x44FF, "end_ml_p3_intel_2" },
    { 0x4500, "end_ml_p3_intel_3" },
    { 0x4501, "end_neardist" },
    { 0x4502, "end_node_origin" },
    { 0x4503, "end_objective_when_all_dead" },
    { 0x4504, "end_objective_when_all_dead_interal" },
    { 0x4505, "end_p1_spawn_loop" },
    { 0x4506, "end_plant_jammers" },
    { 0x4507, "end_player_model" },
    { 0x4508, "end_point" },
    { 0x4509, "end_pos" },
    { 0x450A, "end_pre_vault_assault" },
    { 0x450B, "end_prisoner_hood_model" },
    { 0x450C, "end_reach_drop_zone" },
    { 0x450D, "end_reach_lz" },
    { 0x450E, "end_recover_nuclear_core" },
    { 0x450F, "end_reinforcements" },
    { 0x4510, "end_rope_rumble" },
    { 0x4511, "end_russian_01_model" },
    { 0x4512, "end_russian_02_model" },
    { 0x4513, "end_russian_03_model" },
    { 0x4514, "end_russian_truck_model" },
    { 0x4515, "end_sequence_dof" },
    { 0x4516, "end_slide_delay" },
    { 0x4517, "end_slow_mode" },
    { 0x4518, "end_spawn_group" },
    { 0x4519, "end_super_meter_progress_early" },
    { 0x451A, "end_thread" },
    { 0x451B, "end_time" },
    { 0x451C, "end_trial_sequence" },
    { 0x451D, "end_turret_reservation" },
    { 0x451E, "end_vault_assault" },
    { 0x451F, "end_vault_assault_crypto" },
    { 0x4520, "end_vault_assault_cut" },
    { 0x4521, "end_vault_assault_rooftop" },
    { 0x4522, "end_vault_assault_rooftop_call_exfil" },
    { 0x4523, "end_vault_assault_rooftop_defend" },
    { 0x4524, "end_vault_assault_rooftop_exfil" },
    { 0x4525, "end_vault_assault_rooftop_heli" },
    { 0x4526, "end_vault_assault_vault" },
    { 0x4527, "end_vault_assault_vault_fake_end" },
    { 0x4528, "end_vo_group" },
    { 0x4529, "end1" },
    { 0x452A, "end2" },
    { 0x452B, "endactionflag" },
    { 0x452C, "endangleoffset" },
    { 0x452D, "endangles" },
    { 0x452E, "endascenderanim" },
    { 0x452F, "endat" },
    { 0x4530, "endbetting" },
    { 0x4531, "endbroshot" },
    { 0x4532, "endcondition_focuschanged" },
    { 0x4533, "endconditionwatcher_focuschanged" },
    { 0x4534, "endconditionwatcher_gameended" },
    { 0x4535, "endconditionwatcher_mapchanged" },
    { 0x4536, "endconditionwatcher_mapcleared" },
    { 0x4537, "endconditionwatcher_nuke" },
    { 0x4538, "endconditionwatcher_selectionmade" },
    { 0x4539, "endcreatescript" },
    { 0x453A, "endcustomevent" },
    { 0x453B, "ended" },
    { 0x453C, "endedby" },
    { 0x453D, "endedkillcamcleanup" },
    { 0x453E, "ender" },
    { 0x453F, "endfunc" },
    { 0x4540, "endgame" },
    { 0x4541, "endgame_clientmatchdata" },
    { 0x4542, "endgame_endgame" },
    { 0x4543, "endgame_endround" },
    { 0x4544, "endgame_overlay" },
    { 0x4545, "endgame_regularmp" },
    { 0x4546, "endgame_showkillcam" },
    { 0x4547, "endgame_write_clientmatchdata_for_player_func" },
    { 0x4548, "endgamedeath" },
    { 0x4549, "endgameencounterscorefunc" },
    { 0x454A, "endgameicon" },
    { 0x454B, "endgameontimelimit" },
    { 0x454C, "endgametimer" },
    { 0x454D, "endhostagegame" },
    { 0x454E, "endhover" },
    { 0x454F, "endhud" },
    { 0x4550, "endinactiveinstructionondeath" },
    { 0x4551, "ending_bink_audio_transition" },
    { 0x4552, "ending_bink_init" },
    { 0x4553, "ending_bink_skipped_audio_transition" },
    { 0x4554, "ending_camera_animation" },
    { 0x4555, "ending_cleanup" },
    { 0x4556, "ending_extras" },
    { 0x4557, "ending_scene" },
    { 0x4558, "ending_scene_anims" },
    { 0x4559, "ending_scene_bodies" },
    { 0x455A, "ending_scene_celebration" },
    { 0x455B, "ending_scene_dof" },
    { 0x455C, "ending_scene_ent_cleanup" },
    { 0x455D, "ending_scene_ent_cleanup_loop" },
    { 0x455E, "ending_scene_lights" },
    { 0x455F, "ending_scene_lights_off" },
    { 0x4560, "ending_scene_main" },
    { 0x4561, "ending_scene_mayhem_anims" },
    { 0x4562, "ending_scene_start" },
    { 0x4563, "ending_truck_idle_scene" },
    { 0x4564, "endingsoon" },
    { 0x4565, "endinstructiononnotification" },
    { 0x4566, "endkillcamifnothingtoshow" },
    { 0x4567, "endlesslobbyfloor" },
    { 0x4568, "endmatchonhostdisconnect" },
    { 0x4569, "endmission_bink_skip" },
    { 0x456A, "endmission_main_func" },
    { 0x456B, "endmusicplayed" },
    { 0x456C, "endnode" },
    { 0x456D, "endnode_pos" },
    { 0x456E, "endnodepos" },
    { 0x456F, "endnote" },
    { 0x4570, "endofgamesummarylogger" },
    { 0x4571, "endofroundvisionset" },
    { 0x4572, "endofspeedwatcher" },
    { 0x4573, "endon_str" },
    { 0x4574, "endondeath" },
    { 0x4575, "endonnotification" },
    { 0x4576, "endonremoveanimactive" },
    { 0x4577, "endonshutdown" },
    { 0x4578, "endonstring" },
    { 0x4579, "endontest" },
    { 0x457A, "endontest_endon" },
    { 0x457B, "endorigin" },
    { 0x457C, "endpoint" },
    { 0x457D, "endpos" },
    { 0x457E, "endpt" },
    { 0x457F, "endrespawnnotify" },
    { 0x4580, "endreviveonownerdeathordisconnect" },
    { 0x4581, "endscene" },
    { 0x4582, "endselectiononaction" },
    { 0x4583, "endselectiononendgame" },
    { 0x4584, "endsliding" },
    { 0x4585, "endslidinglegacy" },
    { 0x4586, "endspawncamera" },
    { 0x4587, "endspectatorview" },
    { 0x4588, "endsuperdisableweapon" },
    { 0x4589, "endtime" },
    { 0x458A, "endtimes" },
    { 0x458B, "endtimeutcseconds" },
    { 0x458C, "endturretonplayer" },
    { 0x458D, "endturretusewatch" },
    { 0x458E, "enduavonlatejoiner" },
    { 0x458F, "endusefunc" },
    { 0x4590, "endvehiclemotionwarp" },
    { 0x4591, "endzone_oncontested" },
    { 0x4592, "endzone_onuncontested" },
    { 0x4593, "endzone_onuse" },
    { 0x4594, "endzone_onusebegin" },
    { 0x4595, "endzone_onuseend" },
    { 0x4596, "endzone_setcaptured" },
    { 0x4597, "endzone_stompprogressreward" },
    { 0x4598, "endzoneobjid" },
    { 0x4599, "endzones" },
    { 0x459A, "enemies" },
    { 0x459B, "enemies_alive_watcher" },
    { 0x459C, "enemies_battlecry" },
    { 0x459D, "enemies_cleared_move_forward" },
    { 0x459E, "enemies_distracted" },
    { 0x459F, "enemies_flood_interior" },
    { 0x45A0, "enemies_goal_player" },
    { 0x45A1, "enemies_hunt_player" },
    { 0x45A2, "enemies_init" },
    { 0x45A3, "enemies_killed" },
    { 0x45A4, "enemies_look_at_jets" },
    { 0x45A5, "enemies_management" },
    { 0x45A6, "enemies_missed" },
    { 0x45A7, "enemies_shoot_down_nearest" },
    { 0x45A8, "enemies_skip_front_2" },
    { 0x45A9, "enemies_spawnif_noactive" },
    { 0x45AA, "enemies_wave_01_engage" },
    { 0x45AB, "enemies_wave_01_refill" },
    { 0x45AC, "enemies_wave_01_scatter_delay" },
    { 0x45AD, "enemiesactivenb" },
    { 0x45AE, "enemiesaffectedbyscambler" },
    { 0x45AF, "enemieskilled" },
    { 0x45B0, "enemieskilledintimewindow" },
    { 0x45B1, "enemiesmarked" },
    { 0x45B2, "enemiestotal" },
    { 0x45B3, "enemy_3f_damage" },
    { 0x45B4, "enemy_3f_death" },
    { 0x45B5, "enemy_3f_door_action" },
    { 0x45B6, "enemy_3f_weap_clip" },
    { 0x45B7, "enemy_ac130" },
    { 0x45B8, "enemy_accuracy_think" },
    { 0x45B9, "enemy_ai_corpse_locations" },
    { 0x45BA, "enemy_ai_enter_alert" },
    { 0x45BB, "enemy_ai_target_marker_group_id" },
    { 0x45BC, "enemy_alive_counter_gate" },
    { 0x45BD, "enemy_already_near_node" },
    { 0x45BE, "enemy_ambush_vehicle_spawned_monitor" },
    { 0x45BF, "enemy_ambush_vehicle_think" },
    { 0x45C0, "enemy_armory_guards" },
    { 0x45C1, "enemy_armory_guards_ignored" },
    { 0x45C2, "enemy_back_line_spawner_think" },
    { 0x45C3, "enemy_blocker_vehicle_think" },
    { 0x45C4, "enemy_camp_assassin" },
    { 0x45C5, "enemy_camp_assassin_goal" },
    { 0x45C6, "enemy_camp_spots" },
    { 0x45C7, "enemy_chatter" },
    { 0x45C8, "enemy_chopper_infil_think" },
    { 0x45C9, "enemy_combatantfn0" },
    { 0x45CA, "enemy_combatantfn1" },
    { 0x45CB, "enemy_combatantfn2" },
    { 0x45CC, "enemy_combatantfn3" },
    { 0x45CD, "enemy_combatantfn4" },
    { 0x45CE, "enemy_combatantfn5" },
    { 0x45CF, "enemy_combatantfn6" },
    { 0x45D0, "enemy_combatantfn7" },
    { 0x45D1, "enemy_combatantfn8" },
    { 0x45D2, "enemy_combatantfn9" },
    { 0x45D3, "enemy_death_by_fire" },
    { 0x45D4, "enemy_death_by_fire_think" },
    { 0x45D5, "enemy_death_count" },
    { 0x45D6, "enemy_delay_shooting" },
    { 0x45D7, "enemy_end_death_logic" },
    { 0x45D8, "enemy_engages_ambo" },
    { 0x45D9, "enemy_fall_back_killer" },
    { 0x45DA, "enemy_favor_player" },
    { 0x45DB, "enemy_flare_behavior" },
    { 0x45DC, "enemy_flare_behavior_wave_3" },
    { 0x45DD, "enemy_fob_movement" },
    { 0x45DE, "enemy_force_ak47" },
    { 0x45DF, "enemy_force_ak47_bright_muzzleflash" },
    { 0x45E0, "enemy_force_lmg" },
    { 0x45E1, "enemy_force_pistol" },
    { 0x45E2, "enemy_goal_volume" },
    { 0x45E3, "enemy_group" },
    { 0x45E4, "enemy_gun_pump" },
    { 0x45E5, "enemy_heli_attacking" },
    { 0x45E6, "enemy_heli_killed" },
    { 0x45E7, "enemy_hitmarker" },
    { 0x45E8, "enemy_hvt_bodyguard_vehicle_think" },
    { 0x45E9, "enemy_hvt_boss_watcher" },
    { 0x45EA, "enemy_hvt_got_away_fail" },
    { 0x45EB, "enemy_hvt_mover_vertical_offset" },
    { 0x45EC, "enemy_hvt_start_to_get_away" },
    { 0x45ED, "enemy_hvt_vehicle" },
    { 0x45EE, "enemy_hvt_vehicle_damage_monitor" },
    { 0x45EF, "enemy_hvt_vehicle_damage_state" },
    { 0x45F0, "enemy_hvt_vehicle_explodes" },
    { 0x45F1, "enemy_hvt_vehicle_should_speed_up" },
    { 0x45F2, "enemy_individual_spawn" },
    { 0x45F3, "enemy_info" },
    { 0x45F4, "enemy_info_table" },
    { 0x45F5, "enemy_is_a_threat" },
    { 0x45F6, "enemy_killed_thread" },
    { 0x45F7, "enemy_last_scripted_vo" },
    { 0x45F8, "enemy_list" },
    { 0x45F9, "enemy_magic_bullet_shield" },
    { 0x45FA, "enemy_model_setup" },
    { 0x45FB, "enemy_monitor" },
    { 0x45FC, "enemy_monitor_death" },
    { 0x45FD, "enemy_monitor_func" },
    { 0x45FE, "enemy_mortar" },
    { 0x45FF, "enemy_mortar_animations" },
    { 0x4600, "enemy_mortar_end" },
    { 0x4601, "enemy_mortar_house_mortar_guy" },
    { 0x4602, "enemy_mortar_launch" },
    { 0x4603, "enemy_mortar_strike_exists" },
    { 0x4604, "enemy_mortar_think" },
    { 0x4605, "enemy_move_and_cover" },
    { 0x4606, "enemy_move_to_exposed" },
    { 0x4607, "enemy_notify_range" },
    { 0x4608, "enemy_odin_assault_exists" },
    { 0x4609, "enemy_radio_vo" },
    { 0x460A, "enemy_shoot_buddy_down_door" },
    { 0x460B, "enemy_sight_increased" },
    { 0x460C, "enemy_sight_trace" },
    { 0x460D, "enemy_sight_trace_passed" },
    { 0x460E, "enemy_sight_trace_process" },
    { 0x460F, "enemy_sight_trace_request" },
    { 0x4610, "enemy_sniper_player_monitor" },
    { 0x4611, "enemy_soldier_think" },
    { 0x4612, "enemy_spawn" },
    { 0x4613, "enemy_spawn_influence_dist_sq" },
    { 0x4614, "enemy_spawn_logic" },
    { 0x4615, "enemy_spawner_checkdist" },
    { 0x4616, "enemy_spawner_umike_think" },
    { 0x4617, "enemy_spawner_vehicle_spawned_monitor" },
    { 0x4618, "enemy_spawner_vehicle_think" },
    { 0x4619, "enemy_spawner_vehicles" },
    { 0x461A, "enemy_suicide_truck_think" },
    { 0x461B, "enemy_switchblade_exists" },
    { 0x461C, "enemy_tanks" },
    { 0x461D, "enemy_target" },
    { 0x461E, "enemy_targets" },
    { 0x461F, "enemy_team" },
    { 0x4620, "enemy_team_name" },
    { 0x4621, "enemy_test_trig" },
    { 0x4622, "enemy_turn_off_lantern" },
    { 0x4623, "enemy_turret_fire_think" },
    { 0x4624, "enemy_turret_player_monitor" },
    { 0x4625, "enemy_turret_players_connect_monitor" },
    { 0x4626, "enemy_turret_should_keep_firing" },
    { 0x4627, "enemy_turrets" },
    { 0x4628, "enemy_vehicle_damage_monitor" },
    { 0x4629, "enemy_vehicle_explodes" },
    { 0x462A, "enemy_vehicle_no_rider_monitor" },
    { 0x462B, "enemy_vehicles" },
    { 0x462C, "enemy_vo_wave_1" },
    { 0x462D, "enemy_volume_changer" },
    { 0x462E, "enemy_watcher" },
    { 0x462F, "enemyactionsref" },
    { 0x4630, "enemyaveragedist" },
    { 0x4631, "enemybasekillreveal" },
    { 0x4632, "enemybasekillstreakwatcher" },
    { 0x4633, "enemybasescore" },
    { 0x4634, "enemybasetriggerwatcher" },
    { 0x4635, "enemybasewatcher" },
    { 0x4636, "enemybodymodels" },
    { 0x4637, "enemybrush" },
    { 0x4638, "enemyclass" },
    { 0x4639, "enemydistcheck" },
    { 0x463A, "enemyendtimes" },
    { 0x463B, "enemyfiring" },
    { 0x463C, "enemyflashed" },
    { 0x463D, "enemyhasauav" },
    { 0x463E, "enemyhascuav" },
    { 0x463F, "enemyheadmodels" },
    { 0x4640, "enemyids" },
    { 0x4641, "enemyinfotabledata" },
    { 0x4642, "enemyinlowcover_init" },
    { 0x4643, "enemyinlowcover_terminate" },
    { 0x4644, "enemyinlowcover_update" },
    { 0x4645, "enemyisapproaching" },
    { 0x4646, "enemyishiding" },
    { 0x4647, "enemyisingeneraldirection" },
    { 0x4648, "enemykilled" },
    { 0x4649, "enemymodel" },
    { 0x464A, "enemynearbylistener" },
    { 0x464B, "enemynearplayer" },
    { 0x464C, "enemyobjid" },
    { 0x464D, "enemyonuse" },
    { 0x464E, "enemyoutlineinfos" },
    { 0x464F, "enemypulsebrush" },
    { 0x4650, "enemyspawners" },
    { 0x4651, "enemyspawninfluencedistsq" },
    { 0x4652, "enemystartpos" },
    { 0x4653, "enemytargetmarkergroup" },
    { 0x4654, "enemytargets" },
    { 0x4655, "enemyteam" },
    { 0x4656, "enemyteamid" },
    { 0x4657, "enemytrigger" },
    { 0x4658, "enemyvelocity" },
    { 0x4659, "enemywasmeleed" },
    { 0x465A, "enemyzonebrushes" },
    { 0x465B, "enforceantiboosting" },
    { 0x465C, "enforcer" },
    { 0x465D, "enforcer_ads_anims" },
    { 0x465E, "enforcer_backroom_shot" },
    { 0x465F, "enforcer_blindfire" },
    { 0x4660, "enforcer_chair_swap" },
    { 0x4661, "enforcer_death_fail" },
    { 0x4662, "enforcer_grenade_throw" },
    { 0x4663, "enforcer_ground_impact" },
    { 0x4664, "enforcer_hurt_nag" },
    { 0x4665, "enforcer_los_handler" },
    { 0x4666, "enforcer_monitor_health_handler" },
    { 0x4667, "enforcer_pistol_fire" },
    { 0x4668, "enforcer_play_additive_anim" },
    { 0x4669, "enforcer_react_death" },
    { 0x466A, "enforcer_reset_fake_health" },
    { 0x466B, "enforcer_safe_run" },
    { 0x466C, "enforcer_set_low_fake_health" },
    { 0x466D, "enforcer_van_hit" },
    { 0x466E, "enforcer_window_break" },
    { 0x466F, "enforceranimnode" },
    { 0x4670, "enforcerchair" },
    { 0x4671, "enforcerdeathack" },
    { 0x4672, "enforcerson" },
    { 0x4673, "enforcerwife" },
    { 0x4674, "engage_target_circle_strafe" },
    { 0x4675, "engage_target_from_pos" },
    { 0x4676, "engage_target_think" },
    { 0x4677, "engagedradius" },
    { 0x4678, "engagementstarttime" },
    { 0x4679, "engagementtimes" },
    { 0x467A, "engageprimarytarget" },
    { 0x467B, "engagesecondarytarget" },
    { 0x467C, "engine_audio_active" },
    { 0x467D, "engine_fx" },
    { 0x467E, "enginebanksfxtag" },
    { 0x467F, "engineblock" },
    { 0x4680, "engineer_enablemarksafterprematch" },
    { 0x4681, "engineerdrone_earthquake" },
    { 0x4682, "enginefx_effort_scale" },
    { 0x4683, "enginesfxtag" },
    { 0x4684, "enginevfxtag" },
    { 0x4685, "engstructks" },
    { 0x4686, "enhanced_vision" },
    { 0x4687, "enqueuecorpsetablefunc" },
    { 0x4688, "enqueueweapononkillcorpsetablefuncs" },
    { 0x4689, "ensure_players_are_near" },
    { 0x468A, "ent" },
    { 0x468B, "ent_createheadicon" },
    { 0x468C, "ent_deleteheadicon" },
    { 0x468D, "ent_draw_axis" },
    { 0x468E, "ent_facing_away_from_mypos" },
    { 0x468F, "ent_flag" },
    { 0x4690, "ent_flag_assert" },
    { 0x4691, "ent_flag_clear" },
    { 0x4692, "ent_flag_clear_delayed" },
    { 0x4693, "ent_flag_exist" },
    { 0x4694, "ent_flag_init" },
    { 0x4695, "ent_flag_set" },
    { 0x4696, "ent_flag_set_delayed" },
    { 0x4697, "ent_flag_wait" },
    { 0x4698, "ent_flag_wait_either" },
    { 0x4699, "ent_flag_wait_or_timeout" },
    { 0x469A, "ent_flag_wait_vehicle_node" },
    { 0x469B, "ent_flag_waitopen" },
    { 0x469C, "ent_flag_waitopen_either" },
    { 0x469D, "ent_flags_lock" },
    { 0x469E, "ent_is_highlighted" },
    { 0x469F, "ent_is_near_equipment" },
    { 0x46A0, "ent_is_selected" },
    { 0x46A1, "ent_wait_for_flag_or_time_elapses" },
    { 0x46A2, "ent_waits_for_trigger" },
    { 0x46A3, "entbudget" },
    { 0x46A4, "entbudgetused" },
    { 0x46A5, "entcleanup" },
    { 0x46A6, "entcount" },
    { 0x46A7, "entdeletefunc" },
    { 0x46A8, "enter_3f_vo" },
    { 0x46A9, "enter_alert" },
    { 0x46AA, "enter_bleed_out" },
    { 0x46AB, "enter_camera_zoomout" },
    { 0x46AC, "enter_casual" },
    { 0x46AD, "enter_change_loadout" },
    { 0x46AE, "enter_combat" },
    { 0x46AF, "enter_combat_after_go_to_node" },
    { 0x46B0, "enter_combat_after_stealth" },
    { 0x46B1, "enter_combat_flag" },
    { 0x46B2, "enter_current_stealth_state" },
    { 0x46B3, "enter_demeanor_green_beam" },
    { 0x46B4, "enter_demeanor_normal" },
    { 0x46B5, "enter_demeanor_relaxed" },
    { 0x46B6, "enter_demeanor_safe" },
    { 0x46B7, "enter_execution_sequence" },
    { 0x46B8, "enter_gamemodespecificaction" },
    { 0x46B9, "enter_globaldefaultaction" },
    { 0x46BA, "enter_globaldefaultaction_getcurrentweapon" },
    { 0x46BB, "enter_grenadier_seat" },
    { 0x46BC, "enter_gunner_seat" },
    { 0x46BD, "enter_hacked_cam" },
    { 0x46BE, "enter_hacked_cam_model" },
    { 0x46BF, "enter_hood_repair" },
    { 0x46C0, "enter_laststand" },
    { 0x46C1, "enter_launcher" },
    { 0x46C2, "enter_left_back_seat" },
    { 0x46C3, "enter_mine_drone" },
    { 0x46C4, "enter_mine_drone_left" },
    { 0x46C5, "enter_mine_drone_right" },
    { 0x46C6, "enter_missile_defense" },
    { 0x46C7, "enter_missile_defense_control" },
    { 0x46C8, "enter_missile_defense_left" },
    { 0x46C9, "enter_missile_defense_right" },
    { 0x46CA, "enter_missile_defense_view" },
    { 0x46CB, "enter_missile_defense_vision_set" },
    { 0x46CC, "enter_overwatch" },
    { 0x46CD, "enter_overwatch_control" },
    { 0x46CE, "enter_overwatch_vision_set" },
    { 0x46CF, "enter_passenger_seat" },
    { 0x46D0, "enter_ragdoll_focus_camera" },
    { 0x46D1, "enter_reaper" },
    { 0x46D2, "enter_reaper_control" },
    { 0x46D3, "enter_reaper_left" },
    { 0x46D4, "enter_reaper_right" },
    { 0x46D5, "enter_reaper_view" },
    { 0x46D6, "enter_refill_ammo" },
    { 0x46D7, "enter_repair" },
    { 0x46D8, "enter_retrieve_hostage" },
    { 0x46D9, "enter_revive_use_hold_think" },
    { 0x46DA, "enter_right_back_seat" },
    { 0x46DB, "enter_seat" },
    { 0x46DC, "enter_seat_omnvar" },
    { 0x46DD, "enter_seat_omnvar_internal" },
    { 0x46DE, "enter_spawn_queue" },
    { 0x46DF, "enter_spectate" },
    { 0x46E0, "enter_spectator_func" },
    { 0x46E1, "enter_stealth_state_func" },
    { 0x46E2, "enter_through_3f_balcony_vo" },
    { 0x46E3, "enter_trap_door_vo" },
    { 0x46E4, "enter_vehicle" },
    { 0x46E5, "enter_vent_hint" },
    { 0x46E6, "enterattackheli" },
    { 0x46E7, "entercallbacks" },
    { 0x46E8, "entered_combat" },
    { 0x46E9, "entered_foyer_timer" },
    { 0x46EA, "entered_playspace" },
    { 0x46EB, "entered_vehicle_notify" },
    { 0x46EC, "enteredcamera" },
    { 0x46ED, "enteredroom" },
    { 0x46EE, "enteredvehicle" },
    { 0x46EF, "enterendcallback" },
    { 0x46F0, "enterexitvehiclemotionwarp" },
    { 0x46F1, "entergulag" },
    { 0x46F2, "entergulagwait" },
    { 0x46F3, "enterpronewrapper" },
    { 0x46F4, "enterpronewrapperproc" },
    { 0x46F5, "enterspectator" },
    { 0x46F6, "enterspectatorfunc" },
    { 0x46F7, "enterstartcallback" },
    { 0x46F8, "enterstartcomplete" },
    { 0x46F9, "enterstartwaitmsg" },
    { 0x46FA, "enterstealthstate" },
    { 0x46FB, "entervehicle" },
    { 0x46FC, "entervehicle_terminate" },
    { 0x46FD, "entinfos" },
    { 0x46FE, "entinfrontarc" },
    { 0x46FF, "entities" },
    { 0x4700, "entities_are_selected" },
    { 0x4701, "entity_count" },
    { 0x4702, "entity_count_delta" },
    { 0x4703, "entity_count_hud" },
    { 0x4704, "entity_getbehindentitydistance" },
    { 0x4705, "entity_getbehindforwarddistance" },
    { 0x4706, "entity_getlateralentitydistance" },
    { 0x4707, "entity_getnextclosestgoalinpath" },
    { 0x4708, "entity_handle_notetrack" },
    { 0x4709, "entity_highlight_disable" },
    { 0x470A, "entity_highlight_enable" },
    { 0x470B, "entity_init" },
    { 0x470C, "entity_is_approved" },
    { 0x470D, "entity_isbehindentitydistance" },
    { 0x470E, "entity_isbesideentitydistance" },
    { 0x470F, "entity_number" },
    { 0x4710, "entityheadicon" },
    { 0x4711, "entityheadiconoffset" },
    { 0x4712, "entityheadicons" },
    { 0x4713, "entityheadiconteam" },
    { 0x4714, "entitylerpovertime" },
    { 0x4715, "entitylookingat" },
    { 0x4716, "entitynumber" },
    { 0x4717, "entityoutlines" },
    { 0x4718, "entlockedonto" },
    { 0x4719, "entmarked" },
    { 0x471A, "entnum" },
    { 0x471B, "entnumber" },
    { 0x471C, "entoutlineid" },
    { 0x471D, "entowner" },
    { 0x471E, "entrance_add_fov_scale_factor_override" },
    { 0x471F, "entrance_blindfire_vignette" },
    { 0x4720, "entrance_indices" },
    { 0x4721, "entrance_is_fully_repaired" },
    { 0x4722, "entrance_origin_points" },
    { 0x4723, "entrance_points" },
    { 0x4724, "entrance_points_finished_caching" },
    { 0x4725, "entrance_to_enemy_zone" },
    { 0x4726, "entrance_visible_from" },
    { 0x4727, "entrance_watched_by_ally" },
    { 0x4728, "entrance_watched_by_player" },
    { 0x4729, "entries" },
    { 0x472A, "ents" },
    { 0x472B, "entscurrent" },
    { 0x472C, "entsinside" },
    { 0x472D, "entsound" },
    { 0x472E, "entstotal" },
    { 0x472F, "entstouching" },
    { 0x4730, "enttargetjoint" },
    { 0x4731, "environment_listener" },
    { 0x4732, "eog_player_tracking_init" },
    { 0x4733, "eog_player_update_pvpve_downs" },
    { 0x4734, "eog_player_update_stat" },
    { 0x4735, "eog_score_components" },
    { 0x4736, "eog_setup_track_items" },
    { 0x4737, "eog_to_lb_playerdata_mapping" },
    { 0x4738, "eog_update_on_player_disconnect" },
    { 0x4739, "eogscoreboard" },
    { 0x473A, "eogscoringtable" },
    { 0x473B, "eogscoringtotalpoints" },
    { 0x473C, "eogtracking" },
    { 0x473D, "eol" },
    { 0x473E, "eomcamerapullout" },
    { 0x473F, "eomcombatwaitforhitmarkersanddelaystartpostgameui" },
    { 0x4740, "ephemeral_downgrade" },
    { 0x4741, "ephemeralweapon" },
    { 0x4742, "epic" },
    { 0x4743, "epic_scripted_fx" },
    { 0x4744, "epictauntlistener" },
    { 0x4745, "eq" },
    { 0x4746, "eqforclient" },
    { 0x4747, "equal_to_goal" },
    { 0x4748, "equals_any" },
    { 0x4749, "equip_armor" },
    { 0x474A, "equip_helmet" },
    { 0x474B, "equipextras" },
    { 0x474C, "equipgasmask" },
    { 0x474D, "equipkillstreak" },
    { 0x474E, "equipment" },
    { 0x474F, "equipment_enabled" },
    { 0x4750, "equipment_init" },
    { 0x4751, "equipment_nags" },
    { 0x4752, "equipmentdeathvfx" },
    { 0x4753, "equipmentdeletevfx" },
    { 0x4754, "equipmentdestroyed" },
    { 0x4755, "equipmentempstunvfx" },
    { 0x4756, "equipmenthit" },
    { 0x4757, "equipmentinteract_init" },
    { 0x4758, "equipmentmatchstartshieldms" },
    { 0x4759, "equipmentpingactive" },
    { 0x475A, "equipmentref" },
    { 0x475B, "equipmentslothasroom" },
    { 0x475C, "equipmentusedbyslot" },
    { 0x475D, "equipmentwatchuse" },
    { 0x475E, "equiponplayerdamaged" },
    { 0x475F, "equiponplayerspawned" },
    { 0x4760, "equipping_lastpingtime" },
    { 0x4761, "equipslotonekillstreak" },
    { 0x4762, "equipslotthreekillstreak" },
    { 0x4763, "equipslottwokillstreak" },
    { 0x4764, "equiptype" },
    { 0x4765, "erasefinalkillcam" },
    { 0x4766, "error" },
    { 0x4767, "error_print" },
    { 0x4768, "errormessagebitflipper" },
    { 0x4769, "esc_com_aq" },
    { 0x476A, "esc_com_aq_alley_health_drop" },
    { 0x476B, "esc_com_aq_alley_start" },
    { 0x476C, "esc_com_aq_courtyard" },
    { 0x476D, "esc_com_aq_courtyard_exit" },
    { 0x476E, "esc_com_aq_garage_courtyard" },
    { 0x476F, "esc_com_aq_handler" },
    { 0x4770, "esc_com_enemy_vo" },
    { 0x4771, "esc_com_farah" },
    { 0x4772, "esc_com_keycard" },
    { 0x4773, "esc_com_price" },
    { 0x4774, "esc_com_stacy" },
    { 0x4775, "esc_com_vo" },
    { 0x4776, "esc_embassy_fallen_vo" },
    { 0x4777, "esc_garage_vo" },
    { 0x4778, "esc_lootinfo" },
    { 0x4779, "escalate_grounds" },
    { 0x477A, "escalate_grounds_to_alert" },
    { 0x477B, "escalate_grounds_to_hunt" },
    { 0x477C, "escalate_grounds_with_func" },
    { 0x477D, "escalation_counter" },
    { 0x477E, "escalation_level" },
    { 0x477F, "escalation_level_clamp" },
    { 0x4780, "escalation_patroller_combat_filter" },
    { 0x4781, "escalation_patroller_init" },
    { 0x4782, "escalation_patroller_investigate_think" },
    { 0x4783, "escalation_patrollers" },
    { 0x4784, "escalation_patrollers_callout_think" },
    { 0x4785, "escalation_patrollers_interrupt_think" },
    { 0x4786, "escalation_state" },
    { 0x4787, "escape_animatedsceneslogic" },
    { 0x4788, "escape_barkovspeakerlogic" },
    { 0x4789, "escape_binary_sequence" },
    { 0x478A, "escape_bullyciviliandamagelogic" },
    { 0x478B, "escape_bullycivilianexitlogic" },
    { 0x478C, "escape_bullydamageanimationcleanup" },
    { 0x478D, "escape_bullyenemyknifefxlogic" },
    { 0x478E, "escape_bullyidledialoguelogic" },
    { 0x478F, "escape_bullyidlelogic" },
    { 0x4790, "escape_bullymeleeallowcleanup" },
    { 0x4791, "escape_bullymeleeanimationeffectslogic" },
    { 0x4792, "escape_bullymeleeanimationlogic" },
    { 0x4793, "escape_bullymeleehintlogic" },
    { 0x4794, "escape_bullymeleeplayeranimationlogic" },
    { 0x4795, "escape_bullymeleeplayerenemyanimationlogic" },
    { 0x4796, "escape_bullyscenelogic" },
    { 0x4797, "escape_catchup" },
    { 0x4798, "escape_cinderblockdrophintlogic" },
    { 0x4799, "escape_cine_dof" },
    { 0x479A, "escape_cinematictelevisionstandbylogic" },
    { 0x479B, "escape_civilianbuilderalertedlogic" },
    { 0x479C, "escape_civilianbuilderlogic" },
    { 0x479D, "escape_color_trig_think" },
    { 0x479E, "escape_combat_catchup" },
    { 0x479F, "escape_combat_main" },
    { 0x47A0, "escape_combat_start" },
    { 0x47A1, "escape_demeanor_think" },
    { 0x47A2, "escape_dialogue" },
    { 0x47A3, "escape_dialoguefindguardlogic" },
    { 0x47A4, "escape_enter_to_idle" },
    { 0x47A5, "escape_exteriorenemylogic" },
    { 0x47A6, "escape_exteriorholsterdialoguelogic" },
    { 0x47A7, "escape_exteriorlogic" },
    { 0x47A8, "escape_farahexitlogic" },
    { 0x47A9, "escape_farahmeleesceneaanimationlogic" },
    { 0x47AA, "escape_farahmeleesceneadoorlogic" },
    { 0x47AB, "escape_farahmeleesceneaendguardlogic" },
    { 0x47AC, "escape_farahmeleesceneaenemyanimationlogic" },
    { 0x47AD, "escape_farahmeleesceneaenemydamagelogic" },
    { 0x47AE, "escape_farahmeleesceneaenemydieearlylogic" },
    { 0x47AF, "escape_farahmeleescenealogic" },
    { 0x47B0, "escape_farahmeleescenebendguardlogic" },
    { 0x47B1, "escape_farahmeleescenebenemydeathlogic" },
    { 0x47B2, "escape_farahmeleesceneblogic" },
    { 0x47B3, "escape_farahmeleescenedoorinteractlogic" },
    { 0x47B4, "escape_farahmeleescenelogic" },
    { 0x47B5, "escape_garage_exit_door" },
    { 0x47B6, "escape_garage_keycard" },
    { 0x47B7, "escape_getcinderblockanimations" },
    { 0x47B8, "escape_getescapeanimationstruct" },
    { 0x47B9, "escape_getexitdoor" },
    { 0x47BA, "escape_getexitdoorclip" },
    { 0x47BB, "escape_getfarahdoor" },
    { 0x47BC, "escape_getfarahdoorclip" },
    { 0x47BD, "escape_goal_hint_trigger" },
    { 0x47BE, "escape_guardsalertedfarahlogic" },
    { 0x47BF, "escape_heli" },
    { 0x47C0, "escape_heli_spawn_func" },
    { 0x47C1, "escape_idle_nags" },
    { 0x47C2, "escape_interaction_registration_func" },
    { 0x47C3, "escape_interiorlogic" },
    { 0x47C4, "escape_intro_catchup" },
    { 0x47C5, "escape_intro_main" },
    { 0x47C6, "escape_intro_scene" },
    { 0x47C7, "escape_intro_start" },
    { 0x47C8, "escape_kyle_third_person" },
    { 0x47C9, "escape_lerp_value_fill" },
    { 0x47CA, "escape_lerp_value_rim" },
    { 0x47CB, "escape_main" },
    { 0x47CC, "escape_meleescenegetplayertrigger" },
    { 0x47CD, "escape_nags" },
    { 0x47CE, "escape_now" },
    { 0x47CF, "escape_objective" },
    { 0x47D0, "escape_player_attack_think" },
    { 0x47D1, "escape_player_attack_wait" },
    { 0x47D2, "escape_player_exposed" },
    { 0x47D3, "escape_player_hidden" },
    { 0x47D4, "escape_price_crew_door" },
    { 0x47D5, "escape_rank_array" },
    { 0x47D6, "escape_scene_fadein" },
    { 0x47D7, "escape_setupexitdoor" },
    { 0x47D8, "escape_setupfarahdoor" },
    { 0x47D9, "escape_spawnbullycivilian" },
    { 0x47DA, "escape_spawnbullyenemy" },
    { 0x47DB, "escape_spawncivilianbuilder" },
    { 0x47DC, "escape_spawnenemies" },
    { 0x47DD, "escape_spawnfarahenemy" },
    { 0x47DE, "escape_start" },
    { 0x47DF, "escape_start_fade_off_lighting" },
    { 0x47E0, "escape_start_fade_on_lighting" },
    { 0x47E1, "escape_trig" },
    { 0x47E2, "escape_trig_logic" },
    { 0x47E3, "escape_vo_init" },
    { 0x47E4, "escape_waittillplayerholsteredlogic" },
    { 0x47E5, "escapepathpermutations" },
    { 0x47E6, "escort" },
    { 0x47E7, "escort_containment" },
    { 0x47E8, "escort_disengage" },
    { 0x47E9, "escort_drone_swap" },
    { 0x47EA, "escort_engage" },
    { 0x47EB, "escort_gesture_rumble" },
    { 0x47EC, "escort_hvi" },
    { 0x47ED, "escort_hvi_damage_monitor" },
    { 0x47EE, "escort_init" },
    { 0x47EF, "escort_monitors" },
    { 0x47F0, "escort_phase_init" },
    { 0x47F1, "escort_suit_toggle" },
    { 0x47F2, "escort_vip" },
    { 0x47F3, "escort_vip_to_chopper" },
    { 0x47F4, "escortdrones" },
    { 0x47F5, "escortheli" },
    { 0x47F6, "escortidle" },
    { 0x47F7, "escortlookatoffset" },
    { 0x47F8, "escortphase" },
    { 0x47F9, "escortspawners" },
    { 0x47FA, "escorttargetanimnode" },
    { 0x47FB, "escorttargetdrone" },
    { 0x47FC, "escorttargets" },
    { 0x47FD, "estate" },
    { 0x47FE, "estate_escape_flags" },
    { 0x47FF, "estate_escape_precache" },
    { 0x4800, "estate_flags" },
    { 0x4801, "estate_gl_endtag_delay_music_change" },
    { 0x4802, "estate_grounds_flags" },
    { 0x4803, "estate_grounds_precache" },
    { 0x4804, "estate_infil_flags" },
    { 0x4805, "estate_infil_precache" },
    { 0x4806, "estate_intro" },
    { 0x4807, "estate_objectives_create" },
    { 0x4808, "estate_objectives_reveal" },
    { 0x4809, "estate_precache" },
    { 0x480A, "estate_rappel_catchup" },
    { 0x480B, "estate_rappel_main" },
    { 0x480C, "estate_rappel_start" },
    { 0x480D, "estate_starts" },
    { 0x480E, "estimatedtimetillscorelimit" },
    { 0x480F, "etarget" },
    { 0x4810, "evac_hvt" },
    { 0x4811, "evac_pilot" },
    { 0x4812, "evade_animate_door" },
    { 0x4813, "evade_autosave_in_cafe" },
    { 0x4814, "evade_cafe_molotov_handler" },
    { 0x4815, "evade_catchup" },
    { 0x4816, "evade_enforcer_escape_goal" },
    { 0x4817, "evade_enforcer_exit_door_bash" },
    { 0x4818, "evade_enforcer_handler" },
    { 0x4819, "evade_main" },
    { 0x481A, "evade_molotov_throw" },
    { 0x481B, "evade_player_extra_fire_damage" },
    { 0x481C, "evade_player_gesture" },
    { 0x481D, "evade_player_kill" },
    { 0x481E, "evade_player_stray_fail" },
    { 0x481F, "evade_police_assault" },
    { 0x4820, "evade_police_assault_extra" },
    { 0x4821, "evade_police_driveby_handler" },
    { 0x4822, "evade_police_enter_anim" },
    { 0x4823, "evade_police_handler" },
    { 0x4824, "evade_police_runby" },
    { 0x4825, "evade_police_runby_exit" },
    { 0x4826, "evade_police_runby_retreat" },
    { 0x4827, "evade_police_window_shooter" },
    { 0x4828, "evade_price_handler" },
    { 0x4829, "evade_price_molotov_react_anim" },
    { 0x482A, "evade_price_shoot_at_ent" },
    { 0x482B, "evade_radius" },
    { 0x482C, "evade_spawn_flashbangs" },
    { 0x482D, "evade_sprinklers_triggered" },
    { 0x482E, "evade_start" },
    { 0x482F, "evade_stp_main" },
    { 0x4830, "evade_window_shoot_at" },
    { 0x4831, "eval" },
    { 0x4832, "evaluadeallaccolades" },
    { 0x4833, "evaluate_rules" },
    { 0x4834, "evaluateaccolade" },
    { 0x4835, "evaluateattackevent" },
    { 0x4836, "evaluatedemotion" },
    { 0x4837, "evaluatefiringevent" },
    { 0x4838, "evaluatefrontline" },
    { 0x4839, "evaluatefunc" },
    { 0x483A, "evaluatemeleeevent" },
    { 0x483B, "evaluatemoveevent" },
    { 0x483C, "evaluateprecomputedlos" },
    { 0x483D, "evaluatereloadevent" },
    { 0x483E, "evaluatespawnforcameraselection" },
    { 0x483F, "evaluatesquadspawn" },
    { 0x4840, "evaluatesuppressionevent" },
    { 0x4841, "evaluatesyncedmelee" },
    { 0x4842, "evaluatesyncedmeleebyxanim" },
    { 0x4843, "evalweaponscore" },
    { 0x4844, "evasive_addpoint" },
    { 0x4845, "evasive_createmaneuvers" },
    { 0x4846, "evasive_drawpoints" },
    { 0x4847, "evasive_endmaneuvers" },
    { 0x4848, "evasive_getallpoints" },
    { 0x4849, "evasive_points" },
    { 0x484A, "evasive_startmaneuvers" },
    { 0x484B, "evasive_think" },
    { 0x484C, "evasivemaneuvers" },
    { 0x484D, "event" },
    { 0x484E, "event_active" },
    { 0x484F, "event_anyone_within_radius" },
    { 0x4850, "event_broadcast_axis" },
    { 0x4851, "event_broadcast_axis_by_sight" },
    { 0x4852, "event_broadcast_axis_by_sight_thread" },
    { 0x4853, "event_broadcast_axis_by_tacsight" },
    { 0x4854, "event_broadcast_generic" },
    { 0x4855, "event_can_pickup_hvt" },
    { 0x4856, "event_change" },
    { 0x4857, "event_director" },
    { 0x4858, "event_entity_core_set_enabled" },
    { 0x4859, "event_escalation" },
    { 0x485A, "event_escalation_clear" },
    { 0x485B, "event_escalation_count" },
    { 0x485C, "event_escalation_get" },
    { 0x485D, "event_escalation_scalar" },
    { 0x485E, "event_escalation_scalar_get" },
    { 0x485F, "event_escalation_scalars" },
    { 0x4860, "event_escalation_to_combat" },
    { 0x4861, "event_escalation_to_combat_get" },
    { 0x4862, "event_handler_should_ignore" },
    { 0x4863, "event_handler_translate_severity" },
    { 0x4864, "event_heli_type" },
    { 0x4865, "event_init_entity" },
    { 0x4866, "event_init_level" },
    { 0x4867, "event_listener_thread" },
    { 0x4868, "event_override_controlling_robot" },
    { 0x4869, "event_override_disguise" },
    { 0x486A, "event_priority" },
    { 0x486B, "event_severity" },
    { 0x486C, "event_severity_compare" },
    { 0x486D, "event_severity_get" },
    { 0x486E, "event_severity_min" },
    { 0x486F, "event_severity_set" },
    { 0x4870, "event_severity_shift" },
    { 0x4871, "event_table_ref" },
    { 0x4872, "event_to_stop" },
    { 0x4873, "event_update_internal" },
    { 0x4874, "eventaction" },
    { 0x4875, "eventactionminwait" },
    { 0x4876, "eventchance" },
    { 0x4877, "eventdata" },
    { 0x4878, "eventduration" },
    { 0x4879, "eventflag" },
    { 0x487A, "eventid" },
    { 0x487B, "eventname" },
    { 0x487C, "eventpriority" },
    { 0x487D, "eventref" },
    { 0x487E, "events" },
    { 0x487F, "events_issliding" },
    { 0x4880, "events_monitorslideupdate" },
    { 0x4881, "eventsplashesthink" },
    { 0x4882, "eventsslideendtime" },
    { 0x4883, "eventstring" },
    { 0x4884, "eventswassliding" },
    { 0x4885, "eventtable" },
    { 0x4886, "eventtable_getscore" },
    { 0x4887, "eventtable_isaddonevent" },
    { 0x4888, "eventtable_isevent" },
    { 0x4889, "eventtotals" },
    { 0x488A, "eventtype" },
    { 0x488B, "eventtypeminwait" },
    { 0x488C, "eventvalue" },
    { 0x488D, "everhadarmor" },
    { 0x488E, "everusessecondaryweapon" },
    { 0x488F, "everyone_else_all_in_laststand" },
    { 0x4890, "exceededmaxhelipilots" },
    { 0x4891, "exceededmaxhelperdrones" },
    { 0x4892, "exceededmaxlittlebirds" },
    { 0x4893, "exceededmaxremoteuavs" },
    { 0x4894, "exception" },
    { 0x4895, "exclude_interaction" },
    { 0x4896, "exclude_ladder_centerline" },
    { 0x4897, "exclude_mantle_on" },
    { 0x4898, "exclude_mantle_over" },
    { 0x4899, "exclude_mount" },
    { 0x489A, "excludedattachments" },
    { 0x489B, "excludedfromrandompool" },
    { 0x489C, "excludedir" },
    { 0x489D, "excludedpatrolpoints" },
    { 0x489E, "excludedplayers" },
    { 0x489F, "exclusionmax" },
    { 0x48A0, "exclusionmin" },
    { 0x48A1, "exclusiveclaim" },
    { 0x48A2, "exclusiveuse" },
    { 0x48A3, "exec_call" },
    { 0x48A4, "exec_call_noself" },
    { 0x48A5, "exec_func" },
    { 0x48A6, "execute_entities" },
    { 0x48A7, "execute_transition" },
    { 0x48A8, "execute_use_hold_think" },
    { 0x48A9, "executeclasschange" },
    { 0x48AA, "executed" },
    { 0x48AB, "executeent" },
    { 0x48AC, "executeent_use_think" },
    { 0x48AD, "executehover" },
    { 0x48AE, "executehvt" },
    { 0x48AF, "executeoffhandfired" },
    { 0x48B0, "executewiretapsweeps" },
    { 0x48B1, "executing" },
    { 0x48B2, "execution" },
    { 0x48B3, "execution_anim_node" },
    { 0x48B4, "execution_blockladders" },
    { 0x48B5, "execution_civs_array" },
    { 0x48B6, "execution_getexecutionbyref" },
    { 0x48B7, "execution_getidbyref" },
    { 0x48B8, "execution_getpropweaponbyref" },
    { 0x48B9, "execution_getrefbyplayer" },
    { 0x48BA, "execution_init" },
    { 0x48BB, "execution_loadtable" },
    { 0x48BC, "execution_mp_init" },
    { 0x48BD, "execution_scene" },
    { 0x48BE, "execution_scene_end" },
    { 0x48BF, "execution_skip_monitor" },
    { 0x48C0, "executionref" },
    { 0x48C1, "executionscharge" },
    { 0x48C2, "exfil_delay" },
    { 0x48C3, "exfil_heli" },
    { 0x48C4, "exfil_helpers" },
    { 0x48C5, "exfil_hopoff_think" },
    { 0x48C6, "exfil_morales" },
    { 0x48C7, "exfil_pilot" },
    { 0x48C8, "exfil_players" },
    { 0x48C9, "exfil_players_on_rescue_fail" },
    { 0x48CA, "exfil_spawn_anim_model" },
    { 0x48CB, "exfil_struct" },
    { 0x48CC, "exfil_use_think" },
    { 0x48CD, "exfilactive" },
    { 0x48CE, "exfilactivetimer" },
    { 0x48CF, "exfilactorloop" },
    { 0x48D0, "exfilactorloopthink" },
    { 0x48D1, "exfilactorthinkanim" },
    { 0x48D2, "exfilactorthinkpath" },
    { 0x48D3, "exfilextracttimer" },
    { 0x48D4, "exfilgoalent" },
    { 0x48D5, "exfilgoaltrigger" },
    { 0x48D6, "exfilinit" },
    { 0x48D7, "exfilleavesequence" },
    { 0x48D8, "exfilnotactive" },
    { 0x48D9, "exfilobjid" },
    { 0x48DA, "exfilpilotactorthink" },
    { 0x48DB, "exfilspace" },
    { 0x48DC, "exfilstarted" },
    { 0x48DD, "exfilstruct" },
    { 0x48DE, "exfilusetriggerused" },
    { 0x48DF, "exhaust_fx" },
    { 0x48E0, "existinarray" },
    { 0x48E1, "exists_global_spawn_function" },
    { 0x48E2, "exit_alert" },
    { 0x48E3, "exit_anim" },
    { 0x48E4, "exit_bed_remove_fov_user_scale" },
    { 0x48E5, "exit_breach_area" },
    { 0x48E6, "exit_breach_door" },
    { 0x48E7, "exit_button" },
    { 0x48E8, "exit_camera_zoomout" },
    { 0x48E9, "exit_casual" },
    { 0x48EA, "exit_change_loadout" },
    { 0x48EB, "exit_combat" },
    { 0x48EC, "exit_current_stealth_state" },
    { 0x48ED, "exit_demeanor_normal" },
    { 0x48EE, "exit_demeanor_relaxed" },
    { 0x48EF, "exit_demeanor_safe" },
    { 0x48F0, "exit_done" },
    { 0x48F1, "exit_driver_role" },
    { 0x48F2, "exit_drone" },
    { 0x48F3, "exit_execution_sequence" },
    { 0x48F4, "exit_finish_time" },
    { 0x48F5, "exit_gamemodespecificaction" },
    { 0x48F6, "exit_globaldefaultaction" },
    { 0x48F7, "exit_grenadier_seat" },
    { 0x48F8, "exit_guard" },
    { 0x48F9, "exit_gunner_seat" },
    { 0x48FA, "exit_hood_repair" },
    { 0x48FB, "exit_last_finish_time" },
    { 0x48FC, "exit_laststand" },
    { 0x48FD, "exit_laststand_func" },
    { 0x48FE, "exit_launcher" },
    { 0x48FF, "exit_left_back_seat" },
    { 0x4900, "exit_map" },
    { 0x4901, "exit_menu" },
    { 0x4902, "exit_mine_drone" },
    { 0x4903, "exit_missile_defense" },
    { 0x4904, "exit_missile_defense_view" },
    { 0x4905, "exit_missile_defense_vision_set" },
    { 0x4906, "exit_node" },
    { 0x4907, "exit_overwatch" },
    { 0x4908, "exit_overwatch_control" },
    { 0x4909, "exit_overwatch_vision_set" },
    { 0x490A, "exit_parts" },
    { 0x490B, "exit_passenger_seat" },
    { 0x490C, "exit_patrol_mode" },
    { 0x490D, "exit_points" },
    { 0x490E, "exit_ragdoll_focus_camera" },
    { 0x490F, "exit_reaper" },
    { 0x4910, "exit_reaper_view" },
    { 0x4911, "exit_repair" },
    { 0x4912, "exit_retrieve_hostage" },
    { 0x4913, "exit_right_back_seat" },
    { 0x4914, "exit_seat" },
    { 0x4915, "exit_seat_but_stay_in_vehicle" },
    { 0x4916, "exit_seat_but_stay_on_seat" },
    { 0x4917, "exit_seat_omnvar" },
    { 0x4918, "exit_speed" },
    { 0x4919, "exit_stealth_state_func" },
    { 0x491A, "exit_use_func" },
    { 0x491B, "exit_vehicle" },
    { 0x491C, "exit_vehicle_when_exit_seat" },
    { 0x491D, "exitandcleanup" },
    { 0x491E, "exitangle" },
    { 0x491F, "exitangles" },
    { 0x4920, "exitboundinginfo" },
    { 0x4921, "exitcallbacks" },
    { 0x4922, "exitdirections" },
    { 0x4923, "exited_suv" },
    { 0x4924, "exitedvehicle" },
    { 0x4925, "exitendcallback" },
    { 0x4926, "exitextents" },
    { 0x4927, "exitfallbackoffset" },
    { 0x4928, "exitfallbackoffsetinverted" },
    { 0x4929, "exitids" },
    { 0x492A, "exitignorelistcallback" },
    { 0x492B, "exiting" },
    { 0x492C, "exiting_waittill_pickup_players" },
    { 0x492D, "exitingafterlifearcade" },
    { 0x492E, "exitingvehicle" },
    { 0x492F, "exitinteract" },
    { 0x4930, "exitmenu" },
    { 0x4931, "exitoffsets" },
    { 0x4932, "exitposition" },
    { 0x4933, "exitpositions" },
    { 0x4934, "exitpronewrapper" },
    { 0x4935, "exitpronewrapperproc" },
    { 0x4936, "exitsfailed" },
    { 0x4937, "exitspeedtarget" },
    { 0x4938, "exitstartcallback" },
    { 0x4939, "exitstartcomplete" },
    { 0x493A, "exitstate" },
    { 0x493B, "exitstates" },
    { 0x493C, "exitstealthstate" },
    { 0x493D, "exittag" },
    { 0x493E, "exittopcastoffset" },
    { 0x493F, "exitvehicle" },
    { 0x4940, "exitvehicle_terminate" },
    { 0x4941, "exitvehicleanimindex" },
    { 0x4942, "exitvehiclerequested" },
    { 0x4943, "exitvehiclewatchpath" },
    { 0x4944, "exitvent" },
    { 0x4945, "exp_touch" },
    { 0x4946, "exp_trig" },
    { 0x4947, "expand_goalradius" },
    { 0x4948, "expandmaxs" },
    { 0x4949, "expandmins" },
    { 0x494A, "expandspawnpointbounds" },
    { 0x494B, "expectedstate" },
    { 0x494C, "expire_time" },
    { 0x494D, "expiretime" },
    { 0x494E, "expl_dmg_monitor" },
    { 0x494F, "explode_results" },
    { 0x4950, "explode_tarmac_scriptables" },
    { 0x4951, "explode_tarmac_scriptables_by_trigger" },
    { 0x4952, "explode1available" },
    { 0x4953, "explode2available" },
    { 0x4954, "exploded" },
    { 0x4955, "explodeent" },
    { 0x4956, "explodeonexpire" },
    { 0x4957, "exploder" },
    { 0x4958, "exploder_after_load" },
    { 0x4959, "exploder_before_load" },
    { 0x495A, "exploder_damage" },
    { 0x495B, "exploder_delay" },
    { 0x495C, "exploder_earthquake" },
    { 0x495D, "exploder_fade" },
    { 0x495E, "exploder_flag_wait" },
    { 0x495F, "exploder_is_chunk" },
    { 0x4960, "exploder_is_damaged_model" },
    { 0x4961, "exploder_load" },
    { 0x4962, "exploder_name" },
    { 0x4963, "exploder_playsound" },
    { 0x4964, "exploder_rumble" },
    { 0x4965, "exploder_sound" },
    { 0x4966, "exploder_starts_hidden" },
    { 0x4967, "exploderfunction" },
    { 0x4968, "exploderindex" },
    { 0x4969, "exploders" },
    { 0x496A, "explodevfx" },
    { 0x496B, "exploding" },
    { 0x496C, "exploding_barrel_death" },
    { 0x496D, "exploimpactmod" },
    { 0x496E, "explore_dof" },
    { 0x496F, "explosion" },
    { 0x4970, "explosion_and_fire_sounds" },
    { 0x4971, "explosion_death" },
    { 0x4972, "explosion_death_offset" },
    { 0x4973, "explosion_death_ragdollfraction" },
    { 0x4974, "explosion_flicker" },
    { 0x4975, "explosion_gethellcannonstructs" },
    { 0x4976, "explosion_gethellcannontargetstructs" },
    { 0x4977, "explosion_monitor" },
    { 0x4978, "explosive" },
    { 0x4979, "explosive_bulletshielded" },
    { 0x497A, "explosive_canisters_init" },
    { 0x497B, "explosive_damage_scalar" },
    { 0x497C, "explosive_kills" },
    { 0x497D, "explosive_up_func" },
    { 0x497E, "explosivedamagemod" },
    { 0x497F, "explosivehandlemovers" },
    { 0x4980, "explosiveinfo" },
    { 0x4981, "explosiveplanttime" },
    { 0x4982, "explosivetrigger" },
    { 0x4983, "exponent" },
    { 0x4984, "export" },
    { 0x4985, "exposed_nodes" },
    { 0x4986, "exposed_shouldlookforbettercover" },
    { 0x4987, "exposed_to_enemy_sniper_time" },
    { 0x4988, "exposed_to_enemy_turret_time" },
    { 0x4989, "exposedtransition" },
    { 0x498A, "exposure_monitor" },
    { 0x498B, "exposure_to_sniper_monitor" },
    { 0x498C, "extendtacopstimelimitms" },
    { 0x498D, "exterior_allies_run_inside" },
    { 0x498E, "exterior_aq_face_enemy_dist_override" },
    { 0x498F, "exterior_cascade" },
    { 0x4990, "exterior_fight_catchup" },
    { 0x4991, "exterior_fight_flags" },
    { 0x4992, "exterior_fight_main" },
    { 0x4993, "exterior_fight_start" },
    { 0x4994, "exterior_fight_truck_reinforce_spawn_func" },
    { 0x4995, "extinguisher_fx" },
    { 0x4996, "extinguishonexplode" },
    { 0x4997, "extra_autosave_checks" },
    { 0x4998, "extra_autosave_checks_failed" },
    { 0x4999, "extra_charge_func" },
    { 0x499A, "extra_drone_delay" },
    { 0x499B, "extra_infil_time" },
    { 0x499C, "extra_location_trigger_mapping" },
    { 0x499D, "extra_patrol_triggers" },
    { 0x499E, "extra_sas_guys" },
    { 0x499F, "extra_street_alles_movement" },
    { 0x49A0, "extra_street_alles_movement_internal" },
    { 0x49A1, "extra_vo" },
    { 0x49A2, "extract_proximity" },
    { 0x49A3, "extract_toggle_objective" },
    { 0x49A4, "extracted" },
    { 0x49A5, "extractindex" },
    { 0x49A6, "extraction_active" },
    { 0x49A7, "extraction_attachfultonballoontoescort" },
    { 0x49A8, "extraction_changeescortusefunction" },
    { 0x49A9, "extraction_checkescortradius" },
    { 0x49AA, "extraction_cooldown" },
    { 0x49AB, "extraction_createescort" },
    { 0x49AC, "extraction_dropbody" },
    { 0x49AD, "extraction_encounterstart" },
    { 0x49AE, "extraction_escortthink" },
    { 0x49AF, "extraction_func" },
    { 0x49B0, "extraction_function_toggle" },
    { 0x49B1, "extraction_in_progress" },
    { 0x49B2, "extraction_infil_player_rig" },
    { 0x49B3, "extraction_playerpickupbody" },
    { 0x49B4, "extraction_structs" },
    { 0x49B5, "extraction_uses" },
    { 0x49B6, "extraction_vehicle" },
    { 0x49B7, "extraction_vehicles" },
    { 0x49B8, "extractionactive" },
    { 0x49B9, "extractioninfo" },
    { 0x49BA, "extractionlocent" },
    { 0x49BB, "extractionpos" },
    { 0x49BC, "extractionteam" },
    { 0x49BD, "extractionzone" },
    { 0x49BE, "extractloc" },
    { 0x49BF, "extractteam" },
    { 0x49C0, "extracttriggerwatcher" },
    { 0x49C1, "extractunusabletoallplayers" },
    { 0x49C2, "extractvehicledeathwatcher" },
    { 0x49C3, "extractzone" },
    { 0x49C4, "extractzone_oncontested" },
    { 0x49C5, "extractzone_onuncontested" },
    { 0x49C6, "extractzone_onuse" },
    { 0x49C7, "extractzone_onusebegin" },
    { 0x49C8, "extractzone_onuseend" },
    { 0x49C9, "extractzone_setcaptured" },
    { 0x49CA, "extractzone_stompprogressreward" },
    { 0x49CB, "extradelay" },
    { 0x49CC, "extrahuds" },
    { 0x49CD, "extraperkmap" },
    { 0x49CE, "extrapoints" },
    { 0x49CF, "extras" },
    { 0x49D0, "extratime" },
    { 0x49D1, "extratimebonus" },
    { 0x49D2, "eye_activated" },
    { 0x49D3, "eye_blend_in_time" },
    { 0x49D4, "eye_catchup_speed" },
    { 0x49D5, "eyes_leftright_anim" },
    { 0x49D6, "eyes_lookat" },
    { 0x49D7, "eyes_updown_anim" },
    { 0x49D8, "eyeshutoverlay" },
    { 0x49D9, "eyespyalerted" },
    { 0x49DA, "f_churn" },
    { 0x49DB, "f_endon" },
    { 0x49DC, "f_match" },
    { 0x49DD, "f_notify" },
    { 0x49DE, "f_resume" },
    { 0x49DF, "f_running_func" },
    { 0x49E0, "f_running_func_call" },
    { 0x49E1, "f_running_nested_1" },
    { 0x49E2, "f_running_nested_2" },
    { 0x49E3, "f_running_nested_3" },
    { 0x49E4, "f_running_nested_4" },
    { 0x49E5, "f_running_nested_5" },
    { 0x49E6, "f_running_nested_call" },
    { 0x49E7, "f_running_thread_call" },
    { 0x49E8, "f_waitframe" },
    { 0x49E9, "f_waitframeend" },
    { 0x49EA, "f1" },
    { 0x49EB, "f14_puzzle_active" },
    { 0x49EC, "f2" },
    { 0x49ED, "fa_franticnodeyaws" },
    { 0x49EE, "fa_nodeyaws" },
    { 0x49EF, "fa_state_machines" },
    { 0x49F0, "face_pip" },
    { 0x49F1, "faceawayfromowner" },
    { 0x49F2, "faceenemyincombat" },
    { 0x49F3, "faceenemywhenneeded" },
    { 0x49F4, "facegoalthread" },
    { 0x49F5, "facegoalthread_newenemyreaction" },
    { 0x49F6, "faceplayer" },
    { 0x49F7, "facial" },
    { 0x49F8, "facial_death" },
    { 0x49F9, "facial_notetrack_handler" },
    { 0x49FA, "facial_state" },
    { 0x49FB, "facialanimdone" },
    { 0x49FC, "facialanimidx" },
    { 0x49FD, "facialidx" },
    { 0x49FE, "facialsounddone" },
    { 0x49FF, "facialstate" },
    { 0x4A00, "facingventpos" },
    { 0x4A01, "fact_str_to_name" },
    { 0x4A02, "faction" },
    { 0x4A03, "faction_progression_init" },
    { 0x4A04, "factionenemyheadicon" },
    { 0x4A05, "factionfriendlyheadicon" },
    { 0x4A06, "factor_value" },
    { 0x4A07, "factorparams" },
    { 0x4A08, "factors" },
    { 0x4A09, "factory_cascade" },
    { 0x4A0A, "factory_floor_catchup" },
    { 0x4A0B, "factory_floor_enter" },
    { 0x4A0C, "factory_floor_flags" },
    { 0x4A0D, "factory_floor_main" },
    { 0x4A0E, "factory_floor_start" },
    { 0x4A0F, "factoryfloordoor" },
    { 0x4A10, "facts" },
    { 0x4A11, "fade" },
    { 0x4A12, "fade_farah_glowstick" },
    { 0x4A13, "fade_in" },
    { 0x4A14, "fade_in_time" },
    { 0x4A15, "fade_out" },
    { 0x4A16, "fade_out_time" },
    { 0x4A17, "fade_over_time" },
    { 0x4A18, "fade_text_over_time" },
    { 0x4A19, "fade_time" },
    { 0x4A1A, "fade_to_black" },
    { 0x4A1B, "fade_tree_fire_out" },
    { 0x4A1C, "fade_up" },
    { 0x4A1D, "fade_up_light_buried_mom" },
    { 0x4A1E, "fadeaway" },
    { 0x4A1F, "fadeblackforgeo" },
    { 0x4A20, "fadecurrent" },
    { 0x4A21, "fadeinblackout" },
    { 0x4A22, "fadeinscreen" },
    { 0x4A23, "fadeout" },
    { 0x4A24, "fadeoutblackout" },
    { 0x4A25, "fadeoutin" },
    { 0x4A26, "fadeoutpinnedicon" },
    { 0x4A27, "fadeoutscreen" },
    { 0x4A28, "fadeoverlayanddestroy" },
    { 0x4A29, "fadesoundanddelete" },
    { 0x4A2A, "fadetoalpha" },
    { 0x4A2B, "fadetoalphatime" },
    { 0x4A2C, "fadetoblack" },
    { 0x4A2D, "fadetoblackforplayer" },
    { 0x4A2E, "faf_burned_out" },
    { 0x4A2F, "fail" },
    { 0x4A30, "fail_cut" },
    { 0x4A31, "fail_for_wild_firing" },
    { 0x4A32, "fail_for_wild_firing_charlie" },
    { 0x4A33, "fail_huds" },
    { 0x4A34, "fail_mission" },
    { 0x4A35, "fail_objective" },
    { 0x4A36, "fail_on_friendly_fire" },
    { 0x4A37, "fail_state_active" },
    { 0x4A38, "fail_steal_truck" },
    { 0x4A39, "failcondition_noplayersinengagedradius" },
    { 0x4A3A, "failcondition_outsidedangercircle" },
    { 0x4A3B, "failconditionengagedradiustime" },
    { 0x4A3C, "failingmission" },
    { 0x4A3D, "failonfriendlyfire" },
    { 0x4A3E, "failsafe_2f_balcony_death" },
    { 0x4A3F, "failsafe_2f_balcony_setup" },
    { 0x4A40, "failsafetimeout" },
    { 0x4A41, "failscavengerquest" },
    { 0x4A42, "failtrigger" },
    { 0x4A43, "failure" },
    { 0x4A44, "fake_actor_anims" },
    { 0x4A45, "fake_actor_random_death" },
    { 0x4A46, "fake_actor_think" },
    { 0x4A47, "fake_actor_think_kill" },
    { 0x4A48, "fake_ally_death_watcher" },
    { 0x4A49, "fake_ally_setup" },
    { 0x4A4A, "fake_animation" },
    { 0x4A4B, "fake_animscripted" },
    { 0x4A4C, "fake_back_left_passenger" },
    { 0x4A4D, "fake_back_right_passenger" },
    { 0x4A4E, "fake_bomber_audio" },
    { 0x4A4F, "fake_bullet" },
    { 0x4A50, "fake_civ_stream" },
    { 0x4A51, "fake_detonator_lights_off" },
    { 0x4A52, "fake_driver_anim_loop" },
    { 0x4A53, "fake_drone_activation" },
    { 0x4A54, "fake_effects" },
    { 0x4A55, "fake_enemy_death_watcher" },
    { 0x4A56, "fake_enemy_setup" },
    { 0x4A57, "fake_flashlight" },
    { 0x4A58, "fake_headlights" },
    { 0x4A59, "fake_health" },
    { 0x4A5A, "fake_jugg_detonator_lights_off" },
    { 0x4A5B, "fake_molotov_explode" },
    { 0x4A5C, "fake_molotov_trig" },
    { 0x4A5D, "fake_player" },
    { 0x4A5E, "fake_player_damage" },
    { 0x4A5F, "fake_players" },
    { 0x4A60, "fake_slerp" },
    { 0x4A61, "fake_snake_cam_logic" },
    { 0x4A62, "fake_stealth" },
    { 0x4A63, "fake_stealth_funcs" },
    { 0x4A64, "fake_stealth_state" },
    { 0x4A65, "fake_structs" },
    { 0x4A66, "fake_target" },
    { 0x4A67, "fake_trees" },
    { 0x4A68, "fake_vista_windows" },
    { 0x4A69, "fake_weapon" },
    { 0x4A6A, "fake_weapon_models" },
    { 0x4A6B, "fake_windows_close" },
    { 0x4A6C, "fake_world_structs_defend_download" },
    { 0x4A6D, "fakeactor_check_delete" },
    { 0x4A6E, "fakeactor_check_node" },
    { 0x4A6F, "fakeactor_cross_canal_runners" },
    { 0x4A70, "fakeactor_droppedweapons" },
    { 0x4A71, "fakeactor_face_anim" },
    { 0x4A72, "fakeactor_give_soul" },
    { 0x4A73, "fakeactor_init" },
    { 0x4A74, "fakeactor_loop_override" },
    { 0x4A75, "fakeactor_node_allow_arrivals" },
    { 0x4A76, "fakeactor_node_allow_exits" },
    { 0x4A77, "fakeactor_node_clear_claimed" },
    { 0x4A78, "fakeactor_node_clear_path_claimed" },
    { 0x4A79, "fakeactor_node_debug" },
    { 0x4A7A, "fakeactor_node_get_all_valid" },
    { 0x4A7B, "fakeactor_node_get_angles" },
    { 0x4A7C, "fakeactor_node_get_cover_list" },
    { 0x4A7D, "fakeactor_node_get_next" },
    { 0x4A7E, "fakeactor_node_get_path" },
    { 0x4A7F, "fakeactor_node_get_valid_count" },
    { 0x4A80, "fakeactor_node_group" },
    { 0x4A81, "fakeactor_node_group_set_disabled" },
    { 0x4A82, "fakeactor_node_init_flags" },
    { 0x4A83, "fakeactor_node_init_params" },
    { 0x4A84, "fakeactor_node_init_type" },
    { 0x4A85, "fakeactor_node_is_animation" },
    { 0x4A86, "fakeactor_node_is_claimed_by" },
    { 0x4A87, "fakeactor_node_is_disabled" },
    { 0x4A88, "fakeactor_node_is_end_path" },
    { 0x4A89, "fakeactor_node_is_locked" },
    { 0x4A8A, "fakeactor_node_is_on_moving_platform" },
    { 0x4A8B, "fakeactor_node_is_passthrough" },
    { 0x4A8C, "fakeactor_node_is_traverse" },
    { 0x4A8D, "fakeactor_node_is_turn" },
    { 0x4A8E, "fakeactor_node_is_valid" },
    { 0x4A8F, "fakeactor_node_is_wait" },
    { 0x4A90, "fakeactor_node_remove_claimed" },
    { 0x4A91, "fakeactor_node_set_claimed" },
    { 0x4A92, "fakeactor_node_set_disabled" },
    { 0x4A93, "fakeactor_node_set_locked" },
    { 0x4A94, "fakeactor_node_set_passthrough" },
    { 0x4A95, "fakeactor_node_set_path_claimed" },
    { 0x4A96, "fakeactor_node_set_wait" },
    { 0x4A97, "fakeactor_node_setup" },
    { 0x4A98, "fakeactor_node_update" },
    { 0x4A99, "fakeactor_rotate_to" },
    { 0x4A9A, "fakeactor_scripted_override" },
    { 0x4A9B, "fakeactor_spawn" },
    { 0x4A9C, "fakeactor_spawn_func" },
    { 0x4A9D, "fakeactor_spawner_init" },
    { 0x4A9E, "fakeactor_thinks" },
    { 0x4A9F, "fakeactors" },
    { 0x4AA0, "fakeactors_aim" },
    { 0x4AA1, "fakeactors_callout" },
    { 0x4AA2, "fakeactorspawn" },
    { 0x4AA3, "fakeactorspawner_init" },
    { 0x4AA4, "fakeaq" },
    { 0x4AA5, "fakebreachdoor" },
    { 0x4AA6, "fakedrone" },
    { 0x4AA7, "fakegun" },
    { 0x4AA8, "fakehealth" },
    { 0x4AA9, "fakeknob" },
    { 0x4AAA, "fakelaser" },
    { 0x4AAB, "fakepapa" },
    { 0x4AAC, "fakepickups" },
    { 0x4AAD, "fakesniper" },
    { 0x4AAE, "fakesniper_control" },
    { 0x4AAF, "fakestreakinfo" },
    { 0x4AB0, "fakevote" },
    { 0x4AB1, "fall_back_func" },
    { 0x4AB2, "fall_damage_remove_setup" },
    { 0x4AB3, "fall_damage_remove_think" },
    { 0x4AB4, "fallback_enemieslogic" },
    { 0x4AB5, "fallback_getenemies" },
    { 0x4AB6, "fallback_getenemygoalvolume" },
    { 0x4AB7, "fallback_getspawners" },
    { 0x4AB8, "fallback_main" },
    { 0x4AB9, "fallback_spawnenemies" },
    { 0x4ABA, "fallback_start" },
    { 0x4ABB, "fallback_to_closest_spot" },
    { 0x4ABC, "fallback_to_pos_if_weapons_free" },
    { 0x4ABD, "fallback_trigger_func" },
    { 0x4ABE, "fallbackspawnpoints" },
    { 0x4ABF, "fallbackspawnset" },
    { 0x4AC0, "fallbackspawnsets" },
    { 0x4AC1, "falldir" },
    { 0x4AC2, "falldist" },
    { 0x4AC3, "falling_rocks_thingy_time" },
    { 0x4AC4, "false_positive_dots_bank" },
    { 0x4AC5, "family_setup" },
    { 0x4AC6, "familychair" },
    { 0x4AC7, "familyflinchanims" },
    { 0x4AC8, "fan_spin" },
    { 0x4AC9, "far" },
    { 0x4ACA, "far_dist" },
    { 0x4ACB, "far_dist_sq" },
    { 0x4ACC, "far_score" },
    { 0x4ACD, "farah" },
    { 0x4ACE, "farah_ai" },
    { 0x4ACF, "farah_as_player_vo" },
    { 0x4AD0, "farah_asking_are_you_ok" },
    { 0x4AD1, "farah_basement_intro_enter_anim_with_glowstick" },
    { 0x4AD2, "farah_body_swap" },
    { 0x4AD3, "farah_body_swap_again" },
    { 0x4AD4, "farah_call_out_runner" },
    { 0x4AD5, "farah_calls_out_ceiling_guys" },
    { 0x4AD6, "farah_calls_out_ceiling_hole" },
    { 0x4AD7, "farah_ceiling_takedown" },
    { 0x4AD8, "farah_ceiling_takedown_aq" },
    { 0x4AD9, "farah_ceiling_takedown_early_watch" },
    { 0x4ADA, "farah_ceiling_takedown_scene" },
    { 0x4ADB, "farah_ceiling_takedown_scene_on" },
    { 0x4ADC, "farah_collapse_nag" },
    { 0x4ADD, "farah_collapse_react" },
    { 0x4ADE, "farah_collapse_react_timeout" },
    { 0x4ADF, "farah_defuse_anim" },
    { 0x4AE0, "farah_door_kill" },
    { 0x4AE1, "farah_drs_setup" },
    { 0x4AE2, "farah_father_ai" },
    { 0x4AE3, "farah_first_cell_guy_warn_vo" },
    { 0x4AE4, "farah_gasmask_swap" },
    { 0x4AE5, "farah_gesture_timing" },
    { 0x4AE6, "farah_gesture1" },
    { 0x4AE7, "farah_gesture2" },
    { 0x4AE8, "farah_gestures_fallback" },
    { 0x4AE9, "farah_glow_stick_attach" },
    { 0x4AEA, "farah_hallway_takedown" },
    { 0x4AEB, "farah_hallway_takedown_aq" },
    { 0x4AEC, "farah_hallway_takedown_clean_enemies" },
    { 0x4AED, "farah_hallway_takedown_scene" },
    { 0x4AEE, "farah_hit_grunts" },
    { 0x4AEF, "farah_idle_hide_hints" },
    { 0x4AF0, "farah_intro_anim" },
    { 0x4AF1, "farah_kick_light" },
    { 0x4AF2, "farah_main_light" },
    { 0x4AF3, "farah_monitor_mg_shot" },
    { 0x4AF4, "farah_mother_model" },
    { 0x4AF5, "farah_move_up" },
    { 0x4AF6, "farah_nobraids_body_swap" },
    { 0x4AF7, "farah_poi" },
    { 0x4AF8, "farah_pushable_reset" },
    { 0x4AF9, "farah_right_flank_hint" },
    { 0x4AFA, "farah_set_stayahead_values" },
    { 0x4AFB, "farah_sister_model" },
    { 0x4AFC, "farah_swap_mask_back" },
    { 0x4AFD, "farah_tag_acc_ang" },
    { 0x4AFE, "farah_tag_acc_org" },
    { 0x4AFF, "farah_takedown_burst_fire" },
    { 0x4B00, "farah_teleport" },
    { 0x4B01, "farah_teleport_and_reset" },
    { 0x4B02, "farah_teleport_in_player_fov" },
    { 0x4B03, "farah_to_van_start" },
    { 0x4B04, "farah_trap_scene_enable_ai_color" },
    { 0x4B05, "farah_trapped_blend_anim_init" },
    { 0x4B06, "farblur" },
    { 0x4B07, "farendfactor" },
    { 0x4B08, "farexploderthink" },
    { 0x4B09, "farm_danger_path_taken" },
    { 0x4B0A, "farrah_anim_think" },
    { 0x4B0B, "farstartfactor" },
    { 0x4B0C, "fartrackthink" },
    { 0x4B0D, "fast_open" },
    { 0x4B0E, "fast_rope" },
    { 0x4B0F, "fast_rope_approach" },
    { 0x4B10, "fast_tread_vfx_trigger_speed" },
    { 0x4B11, "fastburst" },
    { 0x4B12, "fastburstfirenumshots" },
    { 0x4B13, "fastcrouchspeedmod" },
    { 0x4B14, "fasteranimspeed" },
    { 0x4B15, "fastreloadlaunchers" },
    { 0x4B16, "fastrope_anim" },
    { 0x4B17, "fastroperig" },
    { 0x4B18, "fastroperiganimating" },
    { 0x4B19, "fastthrow" },
    { 0x4B1A, "fate_card_weapon" },
    { 0x4B1B, "father_body_model" },
    { 0x4B1C, "father_mayhem" },
    { 0x4B1D, "father_spawn_func" },
    { 0x4B1E, "fatigue" },
    { 0x4B1F, "faux" },
    { 0x4B20, "faux_spawn_infected" },
    { 0x4B21, "faux_spawn_stance" },
    { 0x4B22, "fauxdead" },
    { 0x4B23, "fauxvehiclecount" },
    { 0x4B24, "favela_door" },
    { 0x4B25, "favela_door_distance_check" },
    { 0x4B26, "favela_door_fastopen" },
    { 0x4B27, "favela_door_guy" },
    { 0x4B28, "favela_door_guy_anims" },
    { 0x4B29, "favela_door_open" },
    { 0x4B2A, "favela_door_open_loop" },
    { 0x4B2B, "favela_door_trigger" },
    { 0x4B2C, "favor_blindfire" },
    { 0x4B2D, "favorclosespawnent" },
    { 0x4B2E, "favorclosespawnscalar" },
    { 0x4B2F, "favoritenemy" },
    { 0x4B30, "fbt_desireddistmax" },
    { 0x4B31, "fbt_firstburst" },
    { 0x4B32, "fbt_lastbursterid" },
    { 0x4B33, "fbt_linebreakmax" },
    { 0x4B34, "fbt_linebreakmin" },
    { 0x4B35, "fbt_waitmax" },
    { 0x4B36, "fbt_waitmin" },
    { 0x4B37, "features" },
    { 0x4B38, "feedaction" },
    { 0x4B39, "feedback_check_end" },
    { 0x4B3A, "feedback_check_endfunc" },
    { 0x4B3B, "feedback_check_start" },
    { 0x4B3C, "feedback_context" },
    { 0x4B3D, "feedback_increase_index" },
    { 0x4B3E, "feedback_start_point" },
    { 0x4B3F, "feedback_starts" },
    { 0x4B40, "feedbackcontextual" },
    { 0x4B41, "feedbackenemy" },
    { 0x4B42, "feedbackloot" },
    { 0x4B43, "feedbackruggedeqp" },
    { 0x4B44, "feedcount" },
    { 0x4B45, "femaleprisoner" },
    { 0x4B46, "fence_ai_clear" },
    { 0x4B47, "feral_occludes" },
    { 0x4B48, "ffmessageonspawn" },
    { 0x4B49, "field_cover_direction" },
    { 0x4B4A, "field_ent_cleanup" },
    { 0x4B4B, "field_ent_cleanup_logic" },
    { 0x4B4C, "field_light_ondamage" },
    { 0x4B4D, "field_lights" },
    { 0x4B4E, "field_weapon_cleanup" },
    { 0x4B4F, "fight_enemy" },
    { 0x4B50, "fight_idle" },
    { 0x4B51, "fight_think" },
    { 0x4B52, "fight_with_player" },
    { 0x4B53, "fightdist" },
    { 0x4B54, "fighter_deathfx" },
    { 0x4B55, "fighterindex" },
    { 0x4B56, "fighters" },
    { 0x4B57, "fighting_with_player" },
    { 0x4B58, "fightover" },
    { 0x4B59, "fightspawns" },
    { 0x4B5A, "fil" },
    { 0x4B5B, "file_path" },
    { 0x4B5C, "fileprint_launcher" },
    { 0x4B5D, "fileprint_launcher_end_file" },
    { 0x4B5E, "fileprint_launcher_start_file" },
    { 0x4B5F, "fileprint_map_entity_end" },
    { 0x4B60, "fileprint_map_entity_start" },
    { 0x4B61, "fileprint_map_header" },
    { 0x4B62, "fileprint_map_keypairprint" },
    { 0x4B63, "fileprint_map_start" },
    { 0x4B64, "fileprint_radiant_vec" },
    { 0x4B65, "fileprint_start" },
    { 0x4B66, "fileprintlauncher_linecount" },
    { 0x4B67, "fill_linked_struct_array" },
    { 0x4B68, "fill_max_intensity" },
    { 0x4B69, "fill_type" },
    { 0x4B6A, "fillemptystreakslots" },
    { 0x4B6B, "filloffhandweapons" },
    { 0x4B6C, "filter_out_friendly_damage" },
    { 0x4B6D, "filter_surface_type" },
    { 0x4B6E, "filterattachments" },
    { 0x4B6F, "filterattachmenttoidmap" },
    { 0x4B70, "filtercondition_hasbeeningulag" },
    { 0x4B71, "filtercondition_hasbeentracked" },
    { 0x4B72, "filtercondition_ingulag" },
    { 0x4B73, "filtercondition_isdead" },
    { 0x4B74, "filtercondition_isdowned" },
    { 0x4B75, "filterdamage" },
    { 0x4B76, "filterinform" },
    { 0x4B77, "filterinvalidattachmentsfromidmap" },
    { 0x4B78, "filterorder" },
    { 0x4B79, "filterpairs" },
    { 0x4B7A, "filterpreset" },
    { 0x4B7B, "filterreaction" },
    { 0x4B7C, "filterresponse" },
    { 0x4B7D, "filters" },
    { 0x4B7E, "filterspawnpoints" },
    { 0x4B7F, "filterstealth" },
    { 0x4B80, "filterstructs" },
    { 0x4B81, "filterthreat" },
    { 0x4B82, "filtervehicle" },
    { 0x4B83, "final_defender_behavior" },
    { 0x4B84, "final_defender_check_damage" },
    { 0x4B85, "final_defender_death_anim" },
    { 0x4B86, "final_defender_setup_from_start" },
    { 0x4B87, "final_hack" },
    { 0x4B88, "final_hack_location" },
    { 0x4B89, "final_hack_locations" },
    { 0x4B8A, "final_hack_spot_activate" },
    { 0x4B8B, "final_hack_spot_hint" },
    { 0x4B8C, "final_pipes_catchup" },
    { 0x4B8D, "final_pipes_main" },
    { 0x4B8E, "final_pipes_start" },
    { 0x4B8F, "final_scene_remove_weapons" },
    { 0x4B90, "final_shot_shake" },
    { 0x4B91, "final_vehicle_check" },
    { 0x4B92, "final_walk_scene" },
    { 0x4B93, "final_waterboard_sequence" },
    { 0x4B94, "final_wave_enemies" },
    { 0x4B95, "finaldefender" },
    { 0x4B96, "finale_cam_anim" },
    { 0x4B97, "finale_cam_barkov_anims" },
    { 0x4B98, "finale_cam_extras" },
    { 0x4B99, "finale_cam_farah_anims" },
    { 0x4B9A, "finale_cam_finish" },
    { 0x4B9B, "finale_cam_finish_kickoff" },
    { 0x4B9C, "finale_cam_other_anims" },
    { 0x4B9D, "finale_cam_player_anims" },
    { 0x4B9E, "finale_choke_stab01_add_fov_user_scale_override" },
    { 0x4B9F, "finale_choke_stab04_remove_fov_user_scale_override" },
    { 0x4BA0, "finale_combat_ai" },
    { 0x4BA1, "finale_extras_setup" },
    { 0x4BA2, "finale_heli" },
    { 0x4BA3, "finale_heli_catchup" },
    { 0x4BA4, "finale_heli_intro" },
    { 0x4BA5, "finale_heli_lights" },
    { 0x4BA6, "finale_heli_main" },
    { 0x4BA7, "finale_heli_setup" },
    { 0x4BA8, "finale_heli_start" },
    { 0x4BA9, "finale_kick_scene_setup_rig" },
    { 0x4BAA, "finale_kickoff_catchup" },
    { 0x4BAB, "finale_kickoff_main" },
    { 0x4BAC, "finale_kickoff_sh01_add_fov_user_scale_override" },
    { 0x4BAD, "finale_kickoff_start" },
    { 0x4BAE, "finale_knock_down_add_fov_user_scale_override" },
    { 0x4BAF, "finale_knockdown_scene_setup_rig" },
    { 0x4BB0, "finale_perspective_catchup" },
    { 0x4BB1, "finale_perspective_main" },
    { 0x4BB2, "finale_perspective_start" },
    { 0x4BB3, "finale_player_dialogue" },
    { 0x4BB4, "finale_player_setup" },
    { 0x4BB5, "finale_postload" },
    { 0x4BB6, "finale_preload" },
    { 0x4BB7, "finale_shot_cleanup" },
    { 0x4BB8, "finale_show_heli" },
    { 0x4BB9, "finale_skip" },
    { 0x4BBA, "finale_skippable_section" },
    { 0x4BBB, "finale_stab" },
    { 0x4BBC, "finale_stab_loop_vo" },
    { 0x4BBD, "finale_stab02_remove_fov_user_scale_override" },
    { 0x4BBE, "finale_trees_delete" },
    { 0x4BBF, "finaledialogue" },
    { 0x4BC0, "finaledialoguelong" },
    { 0x4BC1, "finalizeallrecordings" },
    { 0x4BC2, "finalized" },
    { 0x4BC3, "finalizeplayertimes" },
    { 0x4BC4, "finalizepotgsystem" },
    { 0x4BC5, "finalizescene" },
    { 0x4BC6, "finalizespawnpointchoice" },
    { 0x4BC7, "finalkill" },
    { 0x4BC8, "finalkillcam_killcamentityindex" },
    { 0x4BC9, "finalkillcam_winner" },
    { 0x4BCA, "finalkillcamenabled" },
    { 0x4BCB, "finalkillcams" },
    { 0x4BCC, "finalkillcamtype" },
    { 0x4BCD, "finalorg" },
    { 0x4BCE, "finalroundenddelay" },
    { 0x4BCF, "finalsequence" },
    { 0x4BD0, "finalstr" },
    { 0x4BD1, "finalsurvivoruav" },
    { 0x4BD2, "find_a_new_turret_spot" },
    { 0x4BD3, "find_ai_to_kill" },
    { 0x4BD4, "find_ally_to_respond" },
    { 0x4BD5, "find_ambush_node" },
    { 0x4BD6, "find_and_register_vo_source" },
    { 0x4BD7, "find_and_teleport_to_cover" },
    { 0x4BD8, "find_best_bombzone" },
    { 0x4BD9, "find_camp_node" },
    { 0x4BDA, "find_camp_node_worker" },
    { 0x4BDB, "find_closest_bombzone_to_player" },
    { 0x4BDC, "find_closest_heli_node_2d" },
    { 0x4BDD, "find_closest_path_struct" },
    { 0x4BDE, "find_cluster_rocket_for_bot" },
    { 0x4BDF, "find_connected_turrets" },
    { 0x4BE0, "find_current_radio" },
    { 0x4BE1, "find_defend_node_bodyguard" },
    { 0x4BE2, "find_defend_node_capture" },
    { 0x4BE3, "find_defend_node_capture_zone" },
    { 0x4BE4, "find_defend_node_patrol" },
    { 0x4BE5, "find_defend_node_protect" },
    { 0x4BE6, "find_defend_node_protect_zone" },
    { 0x4BE7, "find_different_way_to_attack_last_seen_position" },
    { 0x4BE8, "find_final_position" },
    { 0x4BE9, "find_good_ambush_spot" },
    { 0x4BEA, "find_hadir_dof" },
    { 0x4BEB, "find_hvt_1_start" },
    { 0x4BEC, "find_hvt_2_start" },
    { 0x4BED, "find_hvt_3_start" },
    { 0x4BEE, "find_hvt_catchup" },
    { 0x4BEF, "find_hvt_jump_to_start" },
    { 0x4BF0, "find_hvt_main" },
    { 0x4BF1, "find_new_chase_target" },
    { 0x4BF2, "find_new_health_regen_segment_ceiling" },
    { 0x4BF3, "find_new_patrol" },
    { 0x4BF4, "find_safe_spawn" },
    { 0x4BF5, "find_spawn_loc_from_vehicle_spawner" },
    { 0x4BF6, "find_squad_member_index" },
    { 0x4BF7, "find_ticking_bomb" },
    { 0x4BF8, "find_unclaimed_node" },
    { 0x4BF9, "findandrunrandomprimaryobjective" },
    { 0x4BFA, "findbestpoi" },
    { 0x4BFB, "findbestrespawncloset" },
    { 0x4BFC, "findboxcenter" },
    { 0x4BFD, "findbuddypathnode" },
    { 0x4BFE, "findbuddyspawn" },
    { 0x4BFF, "findclosestdroplocation" },
    { 0x4C00, "findclosestlospointwithin" },
    { 0x4C01, "findcqbpointsofinterest" },
    { 0x4C02, "findcurposonroute" },
    { 0x4C03, "findequipmentslot" },
    { 0x4C04, "findexistingdomflag" },
    { 0x4C05, "findfirstpoiinlink" },
    { 0x4C06, "findfirststreakdifferentcost" },
    { 0x4C07, "findgoodinvestigatelookdir" },
    { 0x4C08, "findgoodsuppressspot" },
    { 0x4C09, "findingcqbpointsofinterest" },
    { 0x4C0A, "findisfacing" },
    { 0x4C0B, "findkillstreakslotnumber" },
    { 0x4C0C, "findmaxstreakcost" },
    { 0x4C0D, "findnearestdompoint" },
    { 0x4C0E, "findnearestsquad" },
    { 0x4C0F, "findnewdomflagorigin" },
    { 0x4C10, "findnewowner" },
    { 0x4C11, "findnextpoiinlink" },
    { 0x4C12, "findnextpointofinterest" },
    { 0x4C13, "findorcreatesquad" },
    { 0x4C14, "findoverridearchetype" },
    { 0x4C15, "findpathcount" },
    { 0x4C16, "findpoint" },
    { 0x4C17, "findspawnlocationnearplayer" },
    { 0x4C18, "findteammatebuddyspawn" },
    { 0x4C19, "findunobstructedfiringinfo" },
    { 0x4C1A, "findunobstructedfiringpoint" },
    { 0x4C1B, "findunobstructedfiringpointaroundy" },
    { 0x4C1C, "findunobstructedfiringpointaroundz" },
    { 0x4C1D, "findunuseddropbaglocation" },
    { 0x4C1E, "finish_creating_entity" },
    { 0x4C1F, "finish_spline_path" },
    { 0x4C20, "finishairstrikeusage" },
    { 0x4C21, "finisharrival" },
    { 0x4C22, "finishcovermultichangerequest" },
    { 0x4C23, "finished_attic_clear_vo" },
    { 0x4C24, "finished_convo" },
    { 0x4C25, "finished_spawning" },
    { 0x4C26, "finishmapselectairstrikeusage" },
    { 0x4C27, "finishpain" },
    { 0x4C28, "finishplayerdamagewrapper" },
    { 0x4C29, "finishstandardairstrikeusage" },
    { 0x4C2A, "finishtraversedrop" },
    { 0x4C2B, "fire" },
    { 0x4C2C, "fire_at_player" },
    { 0x4C2D, "fire_at_player_easy" },
    { 0x4C2E, "fire_aware" },
    { 0x4C2F, "fire_bullets_and_tracers" },
    { 0x4C30, "fire_count" },
    { 0x4C31, "fire_cruise_missile_toward" },
    { 0x4C32, "fire_death" },
    { 0x4C33, "fire_deployable_cover" },
    { 0x4C34, "fire_dps" },
    { 0x4C35, "fire_drone_rocket" },
    { 0x4C36, "fire_drone_rocket_internal" },
    { 0x4C37, "fire_duration" },
    { 0x4C38, "fire_effect" },
    { 0x4C39, "fire_exploder_on" },
    { 0x4C3A, "fire_fill_hurt" },
    { 0x4C3B, "fire_flicker" },
    { 0x4C3C, "fire_flicker_alley_heli_crash" },
    { 0x4C3D, "fire_flicker_bpg_car" },
    { 0x4C3E, "fire_flicker_bpg_metal_detector" },
    { 0x4C3F, "fire_flicker_roof_heli_crash" },
    { 0x4C40, "fire_flicker_stair_b_car" },
    { 0x4C41, "fire_guns" },
    { 0x4C42, "fire_homing_rpg_to_leading_vehicle" },
    { 0x4C43, "fire_hp" },
    { 0x4C44, "fire_if_alive" },
    { 0x4C45, "fire_interceptor_missile_toward" },
    { 0x4C46, "fire_launcher" },
    { 0x4C47, "fire_mb_1_hit" },
    { 0x4C48, "fire_mb_1_miss" },
    { 0x4C49, "fire_mb_2_hit" },
    { 0x4C4A, "fire_mb_2_miss" },
    { 0x4C4B, "fire_missile" },
    { 0x4C4C, "fire_missiles" },
    { 0x4C4D, "fire_notetrack_functions" },
    { 0x4C4E, "fire_on_nearby_players" },
    { 0x4C4F, "fire_one_shot" },
    { 0x4C50, "fire_projectile" },
    { 0x4C51, "fire_reaper_missile" },
    { 0x4C52, "fire_rpg_to_payload" },
    { 0x4C53, "fire_sfx_1f_door" },
    { 0x4C54, "fire_silent_weapon" },
    { 0x4C55, "fire_struct" },
    { 0x4C56, "fire_super" },
    { 0x4C57, "fire_suppression_button_off" },
    { 0x4C58, "fire_suppression_button_on" },
    { 0x4C59, "fire_suppression_fx_on" },
    { 0x4C5A, "fire_suppression_jugg_vo" },
    { 0x4C5B, "fire_suppression_logic" },
    { 0x4C5C, "fire_trigger_on_and_off" },
    { 0x4C5D, "fire_turret" },
    { 0x4C5E, "fire_victim_watch_for_player_damage" },
    { 0x4C5F, "fire_warhead_toward_target" },
    { 0x4C60, "fire_weapon" },
    { 0x4C61, "fire_weapon_fail" },
    { 0x4C62, "firebullet" },
    { 0x4C63, "firebullettrace" },
    { 0x4C64, "fired" },
    { 0x4C65, "fired_commands" },
    { 0x4C66, "firedamage" },
    { 0x4C67, "firedamagefx" },
    { 0x4C68, "firedamagefxoff" },
    { 0x4C69, "firedamagegesture" },
    { 0x4C6A, "firedamagegesturesoff" },
    { 0x4C6B, "firedamageoverlay" },
    { 0x4C6C, "firedamageratio" },
    { 0x4C6D, "firedamagevfxintensitythink" },
    { 0x4C6E, "firednotify" },
    { 0x4C6F, "firedronesfx" },
    { 0x4C70, "firefuncs" },
    { 0x4C71, "firefx_hack_viewkick" },
    { 0x4C72, "firegesture" },
    { 0x4C73, "firegesturegrenade" },
    { 0x4C74, "firehealth" },
    { 0x4C75, "fireholdtime" },
    { 0x4C76, "fireintervalmaxtimes" },
    { 0x4C77, "fireintervalmintimes" },
    { 0x4C78, "fireloopmod" },
    { 0x4C79, "firemanager" },
    { 0x4C7A, "firemaxcounts" },
    { 0x4C7B, "firemaxforwardimpulse" },
    { 0x4C7C, "firemaxupimpulse" },
    { 0x4C7D, "fireminforwardimpulse" },
    { 0x4C7E, "fireminupimpulse" },
    { 0x4C7F, "firemissile" },
    { 0x4C80, "firemode_feedback" },
    { 0x4C81, "fireoncannontarget" },
    { 0x4C82, "fireontarget" },
    { 0x4C83, "fireonturrettarget" },
    { 0x4C84, "firepainoverlay" },
    { 0x4C85, "firepistolhint" },
    { 0x4C86, "firerapidmissiles" },
    { 0x4C87, "firerumble" },
    { 0x4C88, "firesfx" },
    { 0x4C89, "fireshield" },
    { 0x4C8A, "firesmolsfx" },
    { 0x4C8B, "firetarget" },
    { 0x4C8C, "fireteamleader" },
    { 0x4C8D, "firetimes" },
    { 0x4C8E, "firetype" },
    { 0x4C8F, "firetypes" },
    { 0x4C90, "firetypeweights" },
    { 0x4C91, "firevfx" },
    { 0x4C92, "firingbullet" },
    { 0x4C93, "firingdeathallowed" },
    { 0x4C94, "firingguns" },
    { 0x4C95, "firingmissiles" },
    { 0x4C96, "first_blast_enemy" },
    { 0x4C97, "first_cell_look_at_watch" },
    { 0x4C98, "first_entered_search_area" },
    { 0x4C99, "first_equipped" },
    { 0x4C9A, "first_floor_clear_dialogue_handler" },
    { 0x4C9B, "first_floor_lookup_handler" },
    { 0x4C9C, "first_floor_stairs_climbing_dialogue_handler" },
    { 0x4C9D, "first_frame" },
    { 0x4C9E, "first_frame_time" },
    { 0x4C9F, "first_hint_func" },
    { 0x4CA0, "first_hvt_callout" },
    { 0x4CA1, "first_hvt_pickup" },
    { 0x4CA2, "first_intro_text" },
    { 0x4CA3, "first_lost" },
    { 0x4CA4, "first_press" },
    { 0x4CA5, "first_roof_struct" },
    { 0x4CA6, "first_spotted" },
    { 0x4CA7, "first_stab_lines" },
    { 0x4CA8, "first_struct" },
    { 0x4CA9, "first_time_enter_vehicle" },
    { 0x4CAA, "first_touch" },
    { 0x4CAB, "first_trip_defused_vo" },
    { 0x4CAC, "first_waterboard_sequence" },
    { 0x4CAD, "first_wave_override" },
    { 0x4CAE, "firstblendtargetpos" },
    { 0x4CAF, "firstblendtargetrot" },
    { 0x4CB0, "firstblood" },
    { 0x4CB1, "firstc130endtime" },
    { 0x4CB2, "firstcapture" },
    { 0x4CB3, "firstcirclecomplete" },
    { 0x4CB4, "firstcircletimer" },
    { 0x4CB5, "firstclosetime" },
    { 0x4CB6, "firstcontact" },
    { 0x4CB7, "firstcratedrop" },
    { 0x4CB8, "firstdamagedone" },
    { 0x4CB9, "firstdelaytime" },
    { 0x4CBA, "firstforwarddist" },
    { 0x4CBB, "firstforwarddistwall" },
    { 0x4CBC, "firstforwardmindist" },
    { 0x4CBD, "firstforwardmodanglesfunc" },
    { 0x4CBE, "firstinit" },
    { 0x4CBF, "firstkillplayers" },
    { 0x4CC0, "firstminimapradius" },
    { 0x4CC1, "firstnomovetime" },
    { 0x4CC2, "firstphaseend" },
    { 0x4CC3, "firstpickup" },
    { 0x4CC4, "firstplacement" },
    { 0x4CC5, "firstradius" },
    { 0x4CC6, "firststabs" },
    { 0x4CC7, "firsttaunttracker" },
    { 0x4CC8, "firstthink" },
    { 0x4CC9, "firsttime" },
    { 0x4CCA, "firsttimebomb" },
    { 0x4CCB, "firsttimedamaged" },
    { 0x4CCC, "firsttimehit" },
    { 0x4CCD, "firsttimeplace" },
    { 0x4CCE, "firstupgrade" },
    { 0x4CCF, "firstzoneactivationdelay" },
    { 0x4CD0, "fists_weapon" },
    { 0x4CD1, "fix_heli_blades" },
    { 0x4CD2, "fixarchetype" },
    { 0x4CD3, "fixattachment" },
    { 0x4CD4, "fixedlzs" },
    { 0x4CD5, "fixednodesaferadius_default" },
    { 0x4CD6, "fixednodeshouldsticktocover" },
    { 0x4CD7, "fixednodewason" },
    { 0x4CD8, "fixedshouldsticktocovercached" },
    { 0x4CD9, "fixedshouldsticktocovertime" },
    { 0x4CDA, "fixinvaliditems" },
    { 0x4CDB, "fixkillstreaks" },
    { 0x4CDC, "fixloadout" },
    { 0x4CDD, "fixperk" },
    { 0x4CDE, "fixplacedweapons" },
    { 0x4CDF, "fixpower" },
    { 0x4CE0, "fixsuper" },
    { 0x4CE1, "fixture" },
    { 0x4CE2, "fixupplayerweapons" },
    { 0x4CE3, "fixweapon" },
    { 0x4CE4, "flag" },
    { 0x4CE5, "flag_assert" },
    { 0x4CE6, "flag_carriers" },
    { 0x4CE7, "flag_clear" },
    { 0x4CE8, "flag_clear_delayed" },
    { 0x4CE9, "flag_clear_delayed_endonset" },
    { 0x4CEA, "flag_create_team_goal" },
    { 0x4CEB, "flag_default_origins" },
    { 0x4CEC, "flag_distances" },
    { 0x4CED, "flag_exist" },
    { 0x4CEE, "flag_find_ground" },
    { 0x4CEF, "flag_has_been_captured_before" },
    { 0x4CF0, "flag_has_never_been_captured" },
    { 0x4CF1, "flag_init" },
    { 0x4CF2, "flag_on_button" },
    { 0x4CF3, "flag_on_crouch_pressed" },
    { 0x4CF4, "flag_on_death" },
    { 0x4CF5, "flag_on_jump_pressed" },
    { 0x4CF6, "flag_on_moving_forward" },
    { 0x4CF7, "flag_on_sprint_pressed" },
    { 0x4CF8, "flag_react_sound_array" },
    { 0x4CF9, "flag_set" },
    { 0x4CFA, "flag_set_delayed" },
    { 0x4CFB, "flag_setup" },
    { 0x4CFC, "flag_setupvfx" },
    { 0x4CFD, "flag_struct" },
    { 0x4CFE, "flag_think" },
    { 0x4CFF, "flag_trigger_init" },
    { 0x4D00, "flag_triggers_init" },
    { 0x4D01, "flag_wait" },
    { 0x4D02, "flag_wait_all" },
    { 0x4D03, "flag_wait_any" },
    { 0x4D04, "flag_wait_any_return" },
    { 0x4D05, "flag_wait_any_timeout" },
    { 0x4D06, "flag_wait_either" },
    { 0x4D07, "flag_wait_either_or_timeout" },
    { 0x4D08, "flag_wait_either_return" },
    { 0x4D09, "flag_wait_or_timeout" },
    { 0x4D0A, "flag_waitopen" },
    { 0x4D0B, "flag_waitopen_all_array" },
    { 0x4D0C, "flag_waitopen_any_array" },
    { 0x4D0D, "flag_waitopen_either" },
    { 0x4D0E, "flag_waitopen_or_timeout" },
    { 0x4D0F, "flagbase" },
    { 0x4D10, "flagbaseglowfxid" },
    { 0x4D11, "flagcapsuccess" },
    { 0x4D12, "flagcapturetime" },
    { 0x4D13, "flagged_for_use" },
    { 0x4D14, "flaginit" },
    { 0x4D15, "flagmodel" },
    { 0x4D16, "flagname" },
    { 0x4D17, "flagneutralization" },
    { 0x4D18, "flagownersalive" },
    { 0x4D19, "flagradiusfxid" },
    { 0x4D1A, "flags_lock" },
    { 0x4D1B, "flagsetup" },
    { 0x4D1C, "flagsrequiredtoscore" },
    { 0x4D1D, "flagstatforbufferedwrite" },
    { 0x4D1E, "flagwaitthread" },
    { 0x4D1F, "flagwaitthread_proc" },
    { 0x4D20, "flame_damage_time" },
    { 0x4D21, "flank_alley_helis_1" },
    { 0x4D22, "flank_alley_helis_2" },
    { 0x4D23, "flappy_clothes" },
    { 0x4D24, "flaps" },
    { 0x4D25, "flapsthink" },
    { 0x4D26, "flare" },
    { 0x4D27, "flare_ai_ent_flag_setting" },
    { 0x4D28, "flare_box_setup" },
    { 0x4D29, "flare_box_think" },
    { 0x4D2A, "flare_boxes" },
    { 0x4D2B, "flare_countdown" },
    { 0x4D2C, "flare_counter" },
    { 0x4D2D, "flare_duration" },
    { 0x4D2E, "flare_enable_loop" },
    { 0x4D2F, "flare_fx" },
    { 0x4D30, "flare_fx_ent" },
    { 0x4D31, "flare_held" },
    { 0x4D32, "flare_launchers" },
    { 0x4D33, "flare_lifetime" },
    { 0x4D34, "flare_light" },
    { 0x4D35, "flare_light_up" },
    { 0x4D36, "flare_mover" },
    { 0x4D37, "flare_nag_1" },
    { 0x4D38, "flare_nag_2" },
    { 0x4D39, "flare_nag_2_skipped" },
    { 0x4D3A, "flare_nag_3" },
    { 0x4D3B, "flare_objective_struct" },
    { 0x4D3C, "flare_pickup_disabled" },
    { 0x4D3D, "flare_spawn_array" },
    { 0x4D3E, "flare_timer" },
    { 0x4D3F, "flarefastpickup" },
    { 0x4D40, "flarenag" },
    { 0x4D41, "flarenags" },
    { 0x4D42, "flareorigin" },
    { 0x4D43, "flares_areavailable" },
    { 0x4D44, "flares_cleanflareslivearray" },
    { 0x4D45, "flares_deleteaftertime" },
    { 0x4D46, "flares_deploy" },
    { 0x4D47, "flares_fire" },
    { 0x4D48, "flares_fire_burst" },
    { 0x4D49, "flares_get_vehicle_velocity" },
    { 0x4D4A, "flares_getflarelive" },
    { 0x4D4B, "flares_getflarereserve" },
    { 0x4D4C, "flares_getnumleft" },
    { 0x4D4D, "flares_handleincomingsam" },
    { 0x4D4E, "flares_handleincomingstinger" },
    { 0x4D4F, "flares_init" },
    { 0x4D50, "flares_monitor" },
    { 0x4D51, "flares_playfx" },
    { 0x4D52, "flares_redirect_missiles" },
    { 0x4D53, "flares_reducereserves" },
    { 0x4D54, "flares_think" },
    { 0x4D55, "flares_watchsamproximity" },
    { 0x4D56, "flares_watchstingerproximity" },
    { 0x4D57, "flarescount" },
    { 0x4D58, "flareslive" },
    { 0x4D59, "flaresreservecount" },
    { 0x4D5A, "flash_allies" },
    { 0x4D5B, "flash_color" },
    { 0x4D5C, "flash_hint_timer" },
    { 0x4D5D, "flash_inventory" },
    { 0x4D5E, "flash_react_thread" },
    { 0x4D5F, "flashanimindex" },
    { 0x4D60, "flashbang_immunity" },
    { 0x4D61, "flashbang_tutorial" },
    { 0x4D62, "flashbang_watcher" },
    { 0x4D63, "flashbanganim" },
    { 0x4D64, "flashbanged" },
    { 0x4D65, "flashbangedloop" },
    { 0x4D66, "flashbanggettimeleftsec" },
    { 0x4D67, "flashbangimmunity" },
    { 0x4D68, "flashbanginvulnerability" },
    { 0x4D69, "flashbangisactive" },
    { 0x4D6A, "flashbangmonitor" },
    { 0x4D6B, "flashbangrumbleloop" },
    { 0x4D6C, "flashbangstart" },
    { 0x4D6D, "flashbangstop" },
    { 0x4D6E, "flashed" },
    { 0x4D6F, "flashed_animnode" },
    { 0x4D70, "flashendtime" },
    { 0x4D71, "flashfiremain" },
    { 0x4D72, "flashfrac" },
    { 0x4D73, "flashing_lights_decho_loop" },
    { 0x4D74, "flashingteam" },
    { 0x4D75, "flashinvul" },
    { 0x4D76, "flashlight" },
    { 0x4D77, "flashlight_equip_hint_check" },
    { 0x4D78, "flashlight_laser_cleanup" },
    { 0x4D79, "flashlight_laser_off" },
    { 0x4D7A, "flashlight_laser_on" },
    { 0x4D7B, "flashlight_management" },
    { 0x4D7C, "flashlight_off" },
    { 0x4D7D, "flashlight_on" },
    { 0x4D7E, "flashlight_tutorial" },
    { 0x4D7F, "flashlightfx" },
    { 0x4D80, "flashlightfxoverride" },
    { 0x4D81, "flashlightfxoverridetag" },
    { 0x4D82, "flashlightfxtag" },
    { 0x4D83, "flashlightinuse" },
    { 0x4D84, "flashlightlaser" },
    { 0x4D85, "flashlightlaserweapon" },
    { 0x4D86, "flashlightmodel" },
    { 0x4D87, "flashlightmodeloverride" },
    { 0x4D88, "flashlightnotehandler" },
    { 0x4D89, "flashlighton" },
    { 0x4D8A, "flashlightoverride" },
    { 0x4D8B, "flashlightreactionnotehandler" },
    { 0x4D8C, "flashlightxanim" },
    { 0x4D8D, "flashme" },
    { 0x4D8E, "flashpoint_addeventtoqueue" },
    { 0x4D8F, "flashpoint_checkforownerupdate" },
    { 0x4D90, "flashpoint_clearoldestpoint" },
    { 0x4D91, "flashpoint_createmarker" },
    { 0x4D92, "flashpoint_createnew" },
    { 0x4D93, "flashpoint_endingsoon" },
    { 0x4D94, "flashpoint_objectives" },
    { 0x4D95, "flashpoint_processnewevent" },
    { 0x4D96, "flashpoint_shutdown" },
    { 0x4D97, "flashpoint_spawnselectionvfx" },
    { 0x4D98, "flashpoint_struct" },
    { 0x4D99, "flashpoint_systemthink" },
    { 0x4D9A, "flashpoint_systemtoggle" },
    { 0x4D9B, "flashpoint_trackingevents" },
    { 0x4D9C, "flashpoint_trackplayerevents" },
    { 0x4D9D, "flashpoint_updatepoint" },
    { 0x4D9E, "flashpoint_usebigmapsettings" },
    { 0x4D9F, "flashpointactive" },
    { 0x4DA0, "flashpointdebugactive" },
    { 0x4DA1, "flashpointmindist" },
    { 0x4DA2, "flashpoints" },
    { 0x4DA3, "flashrumbleloop" },
    { 0x4DA4, "flashthread" },
    { 0x4DA5, "flat_angle" },
    { 0x4DA6, "flat_origin" },
    { 0x4DA7, "flatten_vector" },
    { 0x4DA8, "flavorburstlinedebug" },
    { 0x4DA9, "flavorbursts" },
    { 0x4DAA, "flavorbursts_off" },
    { 0x4DAB, "flavorbursts_on" },
    { 0x4DAC, "flavorburstsused" },
    { 0x4DAD, "flavorburstvoices" },
    { 0x4DAE, "flavorburstwouldrepeat" },
    { 0x4DAF, "flicker_flare" },
    { 0x4DB0, "flicker_flare_up" },
    { 0x4DB1, "flicker_light" },
    { 0x4DB2, "flicker_light_and_fixture" },
    { 0x4DB3, "flicker_light_setup" },
    { 0x4DB4, "flicker_tank_lights" },
    { 0x4DB5, "flickerdelay" },
    { 0x4DB6, "flickerendtime" },
    { 0x4DB7, "flickerfire" },
    { 0x4DB8, "flickerlightintensity" },
    { 0x4DB9, "flickerlightmh" },
    { 0x4DBA, "flickersinglelight" },
    { 0x4DBB, "flickersource" },
    { 0x4DBC, "flight_pos" },
    { 0x4DBD, "flight_pos_dot" },
    { 0x4DBE, "flightdir" },
    { 0x4DBF, "flightheight" },
    { 0x4DC0, "flightpath" },
    { 0x4DC1, "flighttime" },
    { 0x4DC2, "flinch_civs" },
    { 0x4DC3, "flinching" },
    { 0x4DC4, "fling_zombie_thundergun_harpoon" },
    { 0x4DC5, "flipleftright" },
    { 0x4DC6, "flipping" },
    { 0x4DC7, "flir" },
    { 0x4DC8, "flirfootprinteffects" },
    { 0x4DC9, "flirfootprints" },
    { 0x4DCA, "float_remap" },
    { 0x4DCB, "floating" },
    { 0x4DCC, "flood_and_secure" },
    { 0x4DCD, "flood_and_secure_spawn" },
    { 0x4DCE, "flood_and_secure_spawn_goal" },
    { 0x4DCF, "flood_and_secure_spawner" },
    { 0x4DD0, "flood_and_secure_spawner_think" },
    { 0x4DD1, "flood_spawn" },
    { 0x4DD2, "flood_spawn_allies" },
    { 0x4DD3, "flood_spawner_init" },
    { 0x4DD4, "flood_spawner_scripted" },
    { 0x4DD5, "flood_spawner_think" },
    { 0x4DD6, "flood_trigger_think" },
    { 0x4DD7, "floodlight_blowout_think" },
    { 0x4DD8, "floodlight_controller_init" },
    { 0x4DD9, "floodlight_controllers" },
    { 0x4DDA, "floodlight_death_watcher" },
    { 0x4DDB, "floodlights" },
    { 0x4DDC, "floodlights_death_hint" },
    { 0x4DDD, "floodlights_init" },
    { 0x4DDE, "floodlights_off" },
    { 0x4DDF, "floodlights_on" },
    { 0x4DE0, "floodlights_on_audio" },
    { 0x4DE1, "floodlights_stealth_filter" },
    { 0x4DE2, "floodlights_think" },
    { 0x4DE3, "floodlights_vision_think" },
    { 0x4DE4, "floor" },
    { 0x4DE5, "floor_num" },
    { 0x4DE6, "floor_override" },
    { 0x4DE7, "floor_turrets_11" },
    { 0x4DE8, "floorobjectives" },
    { 0x4DE9, "flung" },
    { 0x4DEA, "flushmidmatchawardqueue" },
    { 0x4DEB, "flushmidmatchawardqueuewhenable" },
    { 0x4DEC, "flushscoreeventpopupqueue" },
    { 0x4DED, "flushscoreeventpopupqueueonspawn" },
    { 0x4DEE, "flushscorepointspopupqueue" },
    { 0x4DEF, "flushscorepointspopupqueueonspawn" },
    { 0x4DF0, "fly_allydroneflynearplayerupdate" },
    { 0x4DF1, "fly_allydronepathlogic" },
    { 0x4DF2, "fly_allydronesshotdownlogic" },
    { 0x4DF3, "fly_blima_death" },
    { 0x4DF4, "fly_blima_god_mode_off" },
    { 0x4DF5, "fly_catchup" },
    { 0x4DF6, "fly_enemieslogic" },
    { 0x4DF7, "fly_getallydronestartnodes" },
    { 0x4DF8, "fly_getallyvehiclespawners" },
    { 0x4DF9, "fly_getenemynodes" },
    { 0x4DFA, "fly_getenemyspawners" },
    { 0x4DFB, "fly_getenemyvehiclespawners" },
    { 0x4DFC, "fly_getplayerdrone" },
    { 0x4DFD, "fly_getplayerdronestartnode" },
    { 0x4DFE, "fly_getplayerdronesuccessvolume" },
    { 0x4DFF, "fly_hintlogic" },
    { 0x4E00, "fly_in_lights" },
    { 0x4E01, "fly_main" },
    { 0x4E02, "fly_player_hit_helo" },
    { 0x4E03, "fly_spawnallyvehicles" },
    { 0x4E04, "fly_spawnenemies" },
    { 0x4E05, "fly_spawnenemyvehicles" },
    { 0x4E06, "fly_start" },
    { 0x4E07, "fly_tarmac_blima_01" },
    { 0x4E08, "fly_tarmac_blima_02" },
    { 0x4E09, "flycam_intro_start" },
    { 0x4E0A, "flyheight" },
    { 0x4E0B, "fn_weapons_free" },
    { 0x4E0C, "fnachievements" },
    { 0x4E0D, "fnaddeventplaybcs" },
    { 0x4E0E, "fnadditive_twitch_get" },
    { 0x4E0F, "fnaddthreatevent" },
    { 0x4E10, "fnanimbranch" },
    { 0x4E11, "fnanimgenericcustomanimmode" },
    { 0x4E12, "fnasm_clearfingerposes" },
    { 0x4E13, "fnasm_handlenotetrack" },
    { 0x4E14, "fnasm_init" },
    { 0x4E15, "fnasm_initfingerposes" },
    { 0x4E16, "fnasm_playadditiveanimloopstate" },
    { 0x4E17, "fnasm_playfacialanim" },
    { 0x4E18, "fnasm_setanimmode" },
    { 0x4E19, "fnasm_setorientmode" },
    { 0x4E1A, "fnasm_setupaim" },
    { 0x4E1B, "fnasm_setupgesture" },
    { 0x4E1C, "fnasmsoldiergetpainweaponsize" },
    { 0x4E1D, "fnbegin" },
    { 0x4E1E, "fnbotdamagecallback" },
    { 0x4E1F, "fnbuildweapon" },
    { 0x4E20, "fnbuildweaponspecial" },
    { 0x4E21, "fncanmovefrompointtopoint" },
    { 0x4E22, "fncleanupbt" },
    { 0x4E23, "fnclearstealthvolume" },
    { 0x4E24, "fndamage" },
    { 0x4E25, "fndamagefunctions" },
    { 0x4E26, "fndamagesubparthandler" },
    { 0x4E27, "fndismembermenthandler" },
    { 0x4E28, "fndispersedamage" },
    { 0x4E29, "fndooralreadyopen" },
    { 0x4E2A, "fndoorclose" },
    { 0x4E2B, "fndoorinit" },
    { 0x4E2C, "fndoorneedstoclose" },
    { 0x4E2D, "fndooropen" },
    { 0x4E2E, "fnend" },
    { 0x4E2F, "fnevaluateattackevent" },
    { 0x4E30, "fnevaluatemoveevent" },
    { 0x4E31, "fnevaluatereloadevent" },
    { 0x4E32, "fnf_upgrade_weapon" },
    { 0x4E33, "fnfimmune" },
    { 0x4E34, "fnfindcqbpointsofinterest" },
    { 0x4E35, "fnfootprinteffect" },
    { 0x4E36, "fnfootstepeffect" },
    { 0x4E37, "fnfootstepeffectsmall" },
    { 0x4E38, "fngetcorpsearrayfunc" },
    { 0x4E39, "fngetcorpseorigin" },
    { 0x4E3A, "fngetdoorcenter" },
    { 0x4E3B, "fngetfootstepsound" },
    { 0x4E3C, "fngetinfo" },
    { 0x4E3D, "fngetprioritymultiplier" },
    { 0x4E3E, "fngetturretaimangles" },
    { 0x4E3F, "fngetusedturret" },
    { 0x4E40, "fngetweaponrootname" },
    { 0x4E41, "fngrenadecooldownelapsedoverride" },
    { 0x4E42, "fngroupspottedflag" },
    { 0x4E43, "fnhelmetpop" },
    { 0x4E44, "fnhudoutlinedefaultsettings" },
    { 0x4E45, "fninitenemygame" },
    { 0x4E46, "fninterrupt" },
    { 0x4E47, "fnisinstealthcombat" },
    { 0x4E48, "fnisinstealthhunt" },
    { 0x4E49, "fnisinstealthidle" },
    { 0x4E4A, "fnisinstealthidlescriptedanim" },
    { 0x4E4B, "fnisinstealthinvestigate" },
    { 0x4E4C, "fnismeleevalid" },
    { 0x4E4D, "fnlaseroff" },
    { 0x4E4E, "fnlaseron" },
    { 0x4E4F, "fnlookforcover" },
    { 0x4E50, "fnmeleeaction_init" },
    { 0x4E51, "fnmeleecharge_init" },
    { 0x4E52, "fnmeleecharge_terminate" },
    { 0x4E53, "fnmeleevsplayer_init" },
    { 0x4E54, "fnmeleevsplayer_terminate" },
    { 0x4E55, "fnmovetocovernode" },
    { 0x4E56, "fnnag" },
    { 0x4E57, "fnnotetrackhandle" },
    { 0x4E58, "fnnotetrackmodeltranslate" },
    { 0x4E59, "fnnotetrackprefixhandler" },
    { 0x4E5A, "fnonuse" },
    { 0x4E5B, "fnplaceweaponon" },
    { 0x4E5C, "fnplaybattlechatter" },
    { 0x4E5D, "fnplayerlootenabled" },
    { 0x4E5E, "fnplaysoundonentity" },
    { 0x4E5F, "fnplaysoundontag" },
    { 0x4E60, "fnpreragdoll" },
    { 0x4E61, "fnreact" },
    { 0x4E62, "fnreactanime" },
    { 0x4E63, "fnresetmisstime" },
    { 0x4E64, "fnsaygenericdialogue" },
    { 0x4E65, "fnscriptedweaponassignment" },
    { 0x4E66, "fnsetbattlechatter" },
    { 0x4E67, "fnsetcorpseremovetimerfunc" },
    { 0x4E68, "fnsetdisguised" },
    { 0x4E69, "fnsetlaserflag" },
    { 0x4E6A, "fnsetstealthmode" },
    { 0x4E6B, "fnsetstealthstate" },
    { 0x4E6C, "fnshoulddogesture" },
    { 0x4E6D, "fnshouldlookforcover" },
    { 0x4E6E, "fnshouldplaypainanim" },
    { 0x4E6F, "fnstealthflashlightdetach" },
    { 0x4E70, "fnstealthflashlightoff" },
    { 0x4E71, "fnstealthflashlighton" },
    { 0x4E72, "fnstealthgotonode" },
    { 0x4E73, "fnstealthisidlecurious" },
    { 0x4E74, "fnstealthmusictransition" },
    { 0x4E75, "fnstealthupdatevisionforlighting" },
    { 0x4E76, "fnthreatsightplayersightaudio" },
    { 0x4E77, "fnthreatsightsetstateparameters" },
    { 0x4E78, "fntick" },
    { 0x4E79, "fnunlink" },
    { 0x4E7A, "fnupdatefrantic" },
    { 0x4E7B, "fnupdatelightmeter" },
    { 0x4E7C, "fnusecondition" },
    { 0x4E7D, "fob_allies_spawn_setup" },
    { 0x4E7E, "fob_center_autosave" },
    { 0x4E7F, "fob_center_chopper_behavior" },
    { 0x4E80, "fob_center_chopper_guys_spawn_func" },
    { 0x4E81, "fob_center_chopper_spawn_func" },
    { 0x4E82, "fob_center_guys_spawn_func" },
    { 0x4E83, "fob_center_main" },
    { 0x4E84, "fob_center_start" },
    { 0x4E85, "fob_center_transport_behavior" },
    { 0x4E86, "fob_chopper_transport_guys_spawn_func" },
    { 0x4E87, "fob_chopper_transport_spawn_func" },
    { 0x4E88, "fob_container_guys_spawn_func" },
    { 0x4E89, "fob_enemies" },
    { 0x4E8A, "fob_enemies_chu" },
    { 0x4E8B, "fob_enemies_rear" },
    { 0x4E8C, "fob_flags" },
    { 0x4E8D, "fob_front_guys_spawn_func" },
    { 0x4E8E, "fob_fx" },
    { 0x4E8F, "fob_getallyentrancevolume" },
    { 0x4E90, "fob_guys_center_spawn_func" },
    { 0x4E91, "fob_guys_center_start_spawn_func" },
    { 0x4E92, "fob_guys_chu_right" },
    { 0x4E93, "fob_helo_count" },
    { 0x4E94, "fob_ks_chopper_behavior" },
    { 0x4E95, "fob_left_flank_init" },
    { 0x4E96, "fob_post_load_inits" },
    { 0x4E97, "fob_precache" },
    { 0x4E98, "fob_scriptables_cleanup" },
    { 0x4E99, "fob_spawn_funcs" },
    { 0x4E9A, "fob_spawn_manager" },
    { 0x4E9B, "fob_umike_03" },
    { 0x4E9C, "fobcenter_getallycovernodes" },
    { 0x4E9D, "fobchu_getallycovernodes" },
    { 0x4E9E, "focus" },
    { 0x4E9F, "focus_ambo_finder" },
    { 0x4EA0, "focus_display_hint" },
    { 0x4EA1, "focus_held_down" },
    { 0x4EA2, "focus_infinite_hold" },
    { 0x4EA3, "focus_objectives_update_display" },
    { 0x4EA4, "focus_pressed" },
    { 0x4EA5, "focus_reminder" },
    { 0x4EA6, "focus_test_mode" },
    { 0x4EA7, "focusactivate" },
    { 0x4EA8, "focusdeactivate" },
    { 0x4EA9, "focusdisable" },
    { 0x4EAA, "focusdistance" },
    { 0x4EAB, "focusenable" },
    { 0x4EAC, "focusflag" },
    { 0x4EAD, "focushighlightadditionalentsdisable" },
    { 0x4EAE, "focushighlightadditionalentsenable" },
    { 0x4EAF, "focusmonitor" },
    { 0x4EB0, "focusrelease_waittill" },
    { 0x4EB1, "focusspeed" },
    { 0x4EB2, "focustimeadjust" },
    { 0x4EB3, "fog_fx_check" },
    { 0x4EB4, "foliage_react_radius_monitor" },
    { 0x4EB5, "foliage_react_radius_set" },
    { 0x4EB6, "follow_another_vehicle" },
    { 0x4EB7, "follow_enemy_hvt_vehicle" },
    { 0x4EB8, "follow_ent" },
    { 0x4EB9, "follow_ents" },
    { 0x4EBA, "follow_first_vehicle_driver" },
    { 0x4EBB, "follow_path" },
    { 0x4EBC, "follow_path_and_animate" },
    { 0x4EBD, "follow_path_animate_set_ent" },
    { 0x4EBE, "follow_path_animate_set_node" },
    { 0x4EBF, "follow_path_animate_set_struct" },
    { 0x4EC0, "follow_path_from_grid" },
    { 0x4EC1, "follow_path_until" },
    { 0x4EC2, "follow_path_wait_for_player" },
    { 0x4EC3, "follow_player_look_at" },
    { 0x4EC4, "follow_sniper_bullet" },
    { 0x4EC5, "follow_tag_laser_attach" },
    { 0x4EC6, "follow_triggering_player" },
    { 0x4EC7, "followairpath" },
    { 0x4EC8, "followcam_enabled" },
    { 0x4EC9, "followclip" },
    { 0x4ECA, "followhelipath" },
    { 0x4ECB, "following" },
    { 0x4ECC, "following_player" },
    { 0x4ECD, "followingplayer" },
    { 0x4ECE, "follownaglineindex" },
    { 0x4ECF, "followoff" },
    { 0x4ED0, "followplayer" },
    { 0x4ED1, "fontheight" },
    { 0x4ED2, "fontpulse" },
    { 0x4ED3, "fontpulseinit" },
    { 0x4ED4, "foo" },
    { 0x4ED5, "food" },
    { 0x4ED6, "foodbowl" },
    { 0x4ED7, "foodbowl_dof" },
    { 0x4ED8, "foot" },
    { 0x4ED9, "footprint_mask_enable" },
    { 0x4EDA, "footprint_mask_group" },
    { 0x4EDB, "footstep_sound" },
    { 0x4EDC, "footsteps" },
    { 0x4EDD, "footsteps_heard" },
    { 0x4EDE, "for_simple" },
    { 0x4EDF, "force_ai_see_player_car_flank" },
    { 0x4EE0, "force_ai_see_player_gas_start" },
    { 0x4EE1, "force_ai_see_player_gas_start_execution" },
    { 0x4EE2, "force_ai_see_player_square" },
    { 0x4EE3, "force_all_complete" },
    { 0x4EE4, "force_all_players_to_role" },
    { 0x4EE5, "force_armor_drop" },
    { 0x4EE6, "force_close_door" },
    { 0x4EE7, "force_crawl_angle" },
    { 0x4EE8, "force_crawling_death" },
    { 0x4EE9, "force_crawling_death_proc" },
    { 0x4EEA, "force_driver_out_of_vehicle" },
    { 0x4EEB, "force_drop" },
    { 0x4EEC, "force_flash" },
    { 0x4EED, "force_flash_enemy" },
    { 0x4EEE, "force_gunship_off_time" },
    { 0x4EEF, "force_high_reaction" },
    { 0x4EF0, "force_hint_prompt_timer" },
    { 0x4EF1, "force_intel_drop" },
    { 0x4EF2, "force_long_death" },
    { 0x4EF3, "force_long_death_crawling_away" },
    { 0x4EF4, "force_long_death_on_back_with_pistol" },
    { 0x4EF5, "force_long_death_on_back_with_pistol_lab" },
    { 0x4EF6, "force_long_death_stumbling" },
    { 0x4EF7, "force_low_reaction" },
    { 0x4EF8, "force_module_cqb_scoring" },
    { 0x4EF9, "force_molotov_throw" },
    { 0x4EFA, "force_new_goal" },
    { 0x4EFB, "force_num_crawls" },
    { 0x4EFC, "force_nvg" },
    { 0x4EFD, "force_open_door" },
    { 0x4EFE, "force_open_door_targetname" },
    { 0x4EFF, "force_open_doors" },
    { 0x4F00, "force_p_ent_reset" },
    { 0x4F01, "force_player_exit_vehicle" },
    { 0x4F02, "force_player_exit_vehicle_gas_sequence" },
    { 0x4F03, "force_player_to_stand" },
    { 0x4F04, "force_player_vehicle_to_stop" },
    { 0x4F05, "force_reminder_delay" },
    { 0x4F06, "force_respawn_location" },
    { 0x4F07, "force_save" },
    { 0x4F08, "force_search" },
    { 0x4F09, "force_select" },
    { 0x4F0A, "force_select_ent" },
    { 0x4F0B, "force_start_catchup" },
    { 0x4F0C, "force_start_event_non_repeating" },
    { 0x4F0D, "force_stop_anim" },
    { 0x4F0E, "force_usability_enabled" },
    { 0x4F0F, "force_visible" },
    { 0x4F10, "force_visible_thread" },
    { 0x4F11, "force_wave_vehicles_on" },
    { 0x4F12, "forceac130onplayernow" },
    { 0x4F13, "forceactivategimmekillstreak" },
    { 0x4F14, "forceactivatekillstreak" },
    { 0x4F15, "forceamount" },
    { 0x4F16, "forcebalconydeath" },
    { 0x4F17, "forcebark" },
    { 0x4F18, "forcebleedout" },
    { 0x4F19, "forcebroshot" },
    { 0x4F1A, "forcebuddyspawn" },
    { 0x4F1B, "forcecolor" },
    { 0x4F1C, "forcecustomization" },
    { 0x4F1D, "forced_node_path" },
    { 0x4F1E, "forced_start_catchup" },
    { 0x4F1F, "forced_startingposition" },
    { 0x4F20, "forcedavailablespawnlocation" },
    { 0x4F21, "forcedc4" },
    { 0x4F22, "forcedefaultmodel" },
    { 0x4F23, "forcedemeanorsafe" },
    { 0x4F24, "forcedemeanorsafeinteral" },
    { 0x4F25, "forcedend" },
    { 0x4F26, "forcedgameskill" },
    { 0x4F27, "forcedisable" },
    { 0x4F28, "forcedisconnectuntil" },
    { 0x4F29, "forcedobjectiveindex" },
    { 0x4F2A, "forcedpatrol" },
    { 0x4F2B, "forcedropweapon" },
    { 0x4F2C, "forcedspawncameraref" },
    { 0x4F2D, "forcedweapon" },
    { 0x4F2E, "forcedweaponclose" },
    { 0x4F2F, "forcedweaponfar" },
    { 0x4F30, "forcedweaponoriginal" },
    { 0x4F31, "forceejectall" },
    { 0x4F32, "forceend" },
    { 0x4F33, "forceendgame" },
    { 0x4F34, "forceendmonitor" },
    { 0x4F35, "forceendscene" },
    { 0x4F36, "forceexit" },
    { 0x4F37, "forcefallthroughonropes" },
    { 0x4F38, "forceflashlightplayercanseeifnecessary" },
    { 0x4F39, "forcegameendcontesttimeout" },
    { 0x4F3A, "forcegivesuper" },
    { 0x4F3B, "forcegoal_radius" },
    { 0x4F3C, "forcegrowl" },
    { 0x4F3D, "forceheadpop" },
    { 0x4F3E, "forcehitlocation" },
    { 0x4F3F, "forceinitbroshot" },
    { 0x4F40, "forcejumpaftertimeout" },
    { 0x4F41, "forcelinkgoaltriggerwatcher" },
    { 0x4F42, "forcelongdeath" },
    { 0x4F43, "forcelongdeathskipintroanim" },
    { 0x4F44, "forcemeleeyaw" },
    { 0x4F45, "forcenewenemyreaction" },
    { 0x4F46, "forceoldatv" },
    { 0x4F47, "forceplayerspectatetarget" },
    { 0x4F48, "forcepos" },
    { 0x4F49, "forcequickduration" },
    { 0x4F4A, "forceranking" },
    { 0x4F4B, "forcereset" },
    { 0x4F4C, "forcerumble" },
    { 0x4F4D, "forceselfdestructtimer" },
    { 0x4F4E, "forcesetamount" },
    { 0x4F4F, "forcesethudoutlinealpha" },
    { 0x4F50, "forceshowlootcaches" },
    { 0x4F51, "forcespawn" },
    { 0x4F52, "forcespawnangles" },
    { 0x4F53, "forcespawncameraang" },
    { 0x4F54, "forcespawncameraorg" },
    { 0x4F55, "forcespawnitem" },
    { 0x4F56, "forcespawnnearteammates" },
    { 0x4F57, "forcespawnorigin" },
    { 0x4F58, "forcespawnplayers" },
    { 0x4F59, "forcespawnsettings" },
    { 0x4F5A, "forcespawnteam" },
    { 0x4F5B, "forcestoprecording" },
    { 0x4F5C, "forcesuppressai" },
    { 0x4F5D, "forcesuppression" },
    { 0x4F5E, "forcetopickafob" },
    { 0x4F5F, "forcetostand" },
    { 0x4F60, "forcetrackloop" },
    { 0x4F61, "forceupdate" },
    { 0x4F62, "forceusekillstreak" },
    { 0x4F63, "forceuseweapon" },
    { 0x4F64, "forcevalidweapon" },
    { 0x4F65, "foreach_shared_variables" },
    { 0x4F66, "foreach_simple" },
    { 0x4F67, "forest_exit_ally" },
    { 0x4F68, "forest_exit_catchup" },
    { 0x4F69, "forest_exit_main" },
    { 0x4F6A, "forest_exit_start" },
    { 0x4F6B, "forest_magic_bullet_volley" },
    { 0x4F6C, "forest_overlook_alpha1" },
    { 0x4F6D, "forest_overlook_alpha2" },
    { 0x4F6E, "forest_overlook_catchup" },
    { 0x4F6F, "forest_overlook_door" },
    { 0x4F70, "forest_overlook_main" },
    { 0x4F71, "forest_overlook_start" },
    { 0x4F72, "forest_patrol_ally" },
    { 0x4F73, "forest_patrol_catchup" },
    { 0x4F74, "forest_patrol_eliminate_speed_runner" },
    { 0x4F75, "forest_patrol_enemy_approach" },
    { 0x4F76, "forest_patrol_enemy_approach_flashlight" },
    { 0x4F77, "forest_patrol_enemy_light_sweep" },
    { 0x4F78, "forest_patrol_enemy_return" },
    { 0x4F79, "forest_patrol_main" },
    { 0x4F7A, "forest_patrol_player_fire_checker" },
    { 0x4F7B, "forest_patrol_player_visible_checker" },
    { 0x4F7C, "forest_patrol_start" },
    { 0x4F7D, "forest_phosphorus_alpha" },
    { 0x4F7E, "forest_phosphorus_bravo" },
    { 0x4F7F, "forest_phosphorus_catchup" },
    { 0x4F80, "forest_phosphorus_freeze_offscreen" },
    { 0x4F81, "forest_phosphorus_main" },
    { 0x4F82, "forest_phosphorus_start" },
    { 0x4F83, "forest_trees_ally_alpha" },
    { 0x4F84, "forest_trees_ally_bravo" },
    { 0x4F85, "forest_trees_alpha_to_ridge" },
    { 0x4F86, "forest_trees_catchup" },
    { 0x4F87, "forest_trees_main" },
    { 0x4F88, "forest_trees_start" },
    { 0x4F89, "forestmoveref" },
    { 0x4F8A, "forfeit_aborted" },
    { 0x4F8B, "forfeitinprogress" },
    { 0x4F8C, "forfeitwaitforabort" },
    { 0x4F8D, "forgefreeze_hint_display" },
    { 0x4F8E, "forgetpassives" },
    { 0x4F8F, "formedtime" },
    { 0x4F90, "former_mule_weapon" },
    { 0x4F91, "forteam" },
    { 0x4F92, "fortune_visit_cost_1" },
    { 0x4F93, "fortune_visit_cost_2" },
    { 0x4F94, "forward_nag_notify" },
    { 0x4F95, "forward_notify" },
    { 0x4F96, "forwardanim" },
    { 0x4F97, "forwarddistance" },
    { 0x4F98, "forwardplus" },
    { 0x4F99, "forwardpushevent" },
    { 0x4F9A, "forwardv" },
    { 0x4F9B, "forwardvec" },
    { 0x4F9C, "found" },
    { 0x4F9D, "found_distsqrd" },
    { 0x4F9E, "found_exposed_pos" },
    { 0x4F9F, "found_left_edge" },
    { 0x4FA0, "found_player" },
    { 0x4FA1, "found_right_edge" },
    { 0x4FA2, "found_toucher" },
    { 0x4FA3, "found_up_edge" },
    { 0x4FA4, "found_valid_node_pos" },
    { 0x4FA5, "fourprisoners" },
    { 0x4FA6, "fourth_floor_catchup" },
    { 0x4FA7, "fourth_floor_clear_nag" },
    { 0x4FA8, "fourth_floor_door" },
    { 0x4FA9, "fourth_floor_main" },
    { 0x4FAA, "fourth_floor_movement" },
    { 0x4FAB, "fourth_floor_price_anim" },
    { 0x4FAC, "fourth_floor_price_movement" },
    { 0x4FAD, "fourth_floor_price_open_door" },
    { 0x4FAE, "fourth_floor_start" },
    { 0x4FAF, "fov_basement" },
    { 0x4FB0, "fov_calculation" },
    { 0x4FB1, "fov_close" },
    { 0x4FB2, "fov_collimation" },
    { 0x4FB3, "fov_default" },
    { 0x4FB4, "fov_inner" },
    { 0x4FB5, "fov_mine" },
    { 0x4FB6, "fov_open" },
    { 0x4FB7, "fov_outer" },
    { 0x4FB8, "fov_wolf_bomb_defuse" },
    { 0x4FB9, "fovanimframe" },
    { 0x4FBA, "fovkey" },
    { 0x4FBB, "fovshift" },
    { 0x4FBC, "fovtest" },
    { 0x4FBD, "fovzoomstyle" },
    { 0x4FBE, "frac" },
    { 0x4FBF, "fragfiremain" },
    { 0x4FC0, "fraggrenadeovercookfunc" },
    { 0x4FC1, "frame" },
    { 0x4FC2, "frame_events" },
    { 0x4FC3, "framedurationseconds" },
    { 0x4FC4, "frames_visible" },
    { 0x4FC5, "framescloserequired" },
    { 0x4FC6, "framesclosetotarget" },
    { 0x4FC7, "frametimestamp" },
    { 0x4FC8, "frantic" },
    { 0x4FC9, "franticaimlimits" },
    { 0x4FCA, "franticcooldowntime" },
    { 0x4FCB, "franticnodeexposedyaws" },
    { 0x4FCC, "franticnodeleanyaws" },
    { 0x4FCD, "franticnodeyaws" },
    { 0x4FCE, "franticstate" },
    { 0x4FCF, "free_groupname" },
    { 0x4FD0, "free_lilly_civs" },
    { 0x4FD1, "free_prisoners_catchup" },
    { 0x4FD2, "free_prisoners_flags" },
    { 0x4FD3, "free_prisoners_main" },
    { 0x4FD4, "free_prisoners_start" },
    { 0x4FD5, "freecamcallback" },
    { 0x4FD6, "freed" },
    { 0x4FD7, "freefallstartcb" },
    { 0x4FD8, "freefallstartdefault" },
    { 0x4FD9, "freefallstartfunc" },
    { 0x4FDA, "freegameplayhudelems" },
    { 0x4FDB, "freeplayer" },
    { 0x4FDC, "freesquadindex" },
    { 0x4FDD, "freeworldid" },
    { 0x4FDE, "freeworldidbyobjid" },
    { 0x4FDF, "freeze_all_players_control" },
    { 0x4FE0, "freeze_controls_when_standing" },
    { 0x4FE1, "freeze_location" },
    { 0x4FE2, "freeze_player_controls" },
    { 0x4FE3, "freeze_until_phototaken" },
    { 0x4FE4, "freeze_zombie" },
    { 0x4FE5, "freezeallplayers" },
    { 0x4FE6, "freezecontrolswrapper" },
    { 0x4FE7, "freezeplayerforroundend" },
    { 0x4FE8, "freezestatename" },
    { 0x4FE9, "frequency" },
    { 0x4FEA, "frequencytime" },
    { 0x4FEB, "friend_kill_points" },
    { 0x4FEC, "friendlies" },
    { 0x4FED, "friendlies_at_door" },
    { 0x4FEE, "friendlies_defend_using_volume" },
    { 0x4FEF, "friendlies_end_of_bridge" },
    { 0x4FF0, "friendlies_follow_tanks" },
    { 0x4FF1, "friendlies_on_bridge_move" },
    { 0x4FF2, "friendlies_scared_of_dark" },
    { 0x4FF3, "friendliesaffectedbyscrambler" },
    { 0x4FF4, "friendly_convoy" },
    { 0x4FF5, "friendly_convoy_vehicle_damage_monitor" },
    { 0x4FF6, "friendly_convoy_vehicle_explodes" },
    { 0x4FF7, "friendly_convoy_vehicle_id" },
    { 0x4FF8, "friendly_convoy_vehicle_path_think" },
    { 0x4FF9, "friendly_convoy_vehicle_rider_model_index" },
    { 0x4FFA, "friendly_convoy_vehicle_rider_models" },
    { 0x4FFB, "friendly_damage_check" },
    { 0x4FFC, "friendly_death_func" },
    { 0x4FFD, "friendly_fire_checkpoints" },
    { 0x4FFE, "friendly_fire_combat_start" },
    { 0x4FFF, "friendly_fire_dialogue_monitor" },
    { 0x5000, "friendly_fire_fail_check" },
    { 0x5001, "friendly_fire_grenade_think" },
    { 0x5002, "friendly_fire_melee_think" },
    { 0x5003, "friendly_fire_skip_function" },
    { 0x5004, "friendly_fire_think" },
    { 0x5005, "friendly_flare_sender" },
    { 0x5006, "friendly_flare_sender_loop" },
    { 0x5007, "friendly_groundfloor_setup" },
    { 0x5008, "friendly_hvi_vehicle" },
    { 0x5009, "friendly_hvi_vehicle_add_additional_parts_func" },
    { 0x500A, "friendly_hvi_vehicle_death_monitor" },
    { 0x500B, "friendly_mg42" },
    { 0x500C, "friendly_mg42_cleanup" },
    { 0x500D, "friendly_mg42_death_notify" },
    { 0x500E, "friendly_mg42_doneusingturret" },
    { 0x500F, "friendly_mg42_endtrigger" },
    { 0x5010, "friendly_mg42_think" },
    { 0x5011, "friendly_mg42_useable" },
    { 0x5012, "friendly_mg42_wait_for_use" },
    { 0x5013, "friendly_mgturret" },
    { 0x5014, "friendly_nav_repulsor" },
    { 0x5015, "friendly_nearby" },
    { 0x5016, "friendly_nvg_setup" },
    { 0x5017, "friendly_projectile_nearby" },
    { 0x5018, "friendly_promotion_thread" },
    { 0x5019, "friendly_respawn_lock_func" },
    { 0x501A, "friendly_respawn_vision_checker_thread" },
    { 0x501B, "friendly_spawner_vision_checker" },
    { 0x501C, "friendly_startup_thread" },
    { 0x501D, "friendly_stealth_off" },
    { 0x501E, "friendly_struct" },
    { 0x501F, "friendly_tank_force_target" },
    { 0x5020, "friendly_tank_stop_internal" },
    { 0x5021, "friendlybasescore" },
    { 0x5022, "friendlybasetriggerwatcher" },
    { 0x5023, "friendlybasewatcher" },
    { 0x5024, "friendlybrush" },
    { 0x5025, "friendlydamage" },
    { 0x5026, "friendlyfire" },
    { 0x5027, "friendlyfire_damage_modifier" },
    { 0x5028, "friendlyfire_destructible_attacker" },
    { 0x5029, "friendlyfire_enable_attacker_owner_check" },
    { 0x502A, "friendlyfire_force" },
    { 0x502B, "friendlyfire_ignoresdamageattacker" },
    { 0x502C, "friendlyfire_warning" },
    { 0x502D, "friendlyfire_warning_team" },
    { 0x502E, "friendlyfire_warnings" },
    { 0x502F, "friendlyfire_warnings_disable" },
    { 0x5030, "friendlyfire_warnings_off" },
    { 0x5031, "friendlyfire_warnings_on" },
    { 0x5032, "friendlyfire_whizby_distances_valid" },
    { 0x5033, "friendlyfirecheck" },
    { 0x5034, "friendlyfiredisabled" },
    { 0x5035, "friendlyfiredisabledfordestructible" },
    { 0x5036, "friendlymarker" },
    { 0x5037, "friendlymodel" },
    { 0x5038, "friendlyoutlineid" },
    { 0x5039, "friendlypulsebrush" },
    { 0x503A, "friendlytargetmarkergroup" },
    { 0x503B, "friendlyteamid" },
    { 0x503C, "friendlyuseonly" },
    { 0x503D, "friendlyzonebrushes" },
    { 0x503E, "front_2_timeout" },
    { 0x503F, "front_door_boost_open_anim" },
    { 0x5040, "front_door_boost_open_mask_spawn" },
    { 0x5041, "front_door_light" },
    { 0x5042, "front_gate_l" },
    { 0x5043, "front_gate_r" },
    { 0x5044, "front_goal_vol" },
    { 0x5045, "front_mantle_handler_left" },
    { 0x5046, "front_mantle_handler_right" },
    { 0x5047, "front_offset_from_tag_origin" },
    { 0x5048, "front_passenger" },
    { 0x5049, "front_row" },
    { 0x504A, "front_suicide_truck_speed_manager" },
    { 0x504B, "front_trig" },
    { 0x504C, "front_window_scene" },
    { 0x504D, "frontdoordog" },
    { 0x504E, "frontend_camera_move" },
    { 0x504F, "frontend_camera_setup" },
    { 0x5050, "frontend_camera_teleport" },
    { 0x5051, "frontend_camera_watcher" },
    { 0x5052, "frontendfx" },
    { 0x5053, "frontextents" },
    { 0x5054, "frontinteract" },
    { 0x5055, "frontline_police_logic" },
    { 0x5056, "frontlineinfo" },
    { 0x5057, "frontlinelogictypes" },
    { 0x5058, "frontlinespawnsets" },
    { 0x5059, "frontlineteam" },
    { 0x505A, "frontpoint" },
    { 0x505B, "fronttest" },
    { 0x505C, "frontturret" },
    { 0x505D, "frozen" },
    { 0x505E, "frozentick" },
    { 0x505F, "fs_soundorg" },
    { 0x5060, "fs_systemactive" },
    { 0x5061, "fsa_02" },
    { 0x5062, "fstop" },
    { 0x5063, "fubar_breach_logic" },
    { 0x5064, "fubar_breach_logic_plane_combat" },
    { 0x5065, "fubar_breach_spawners" },
    { 0x5066, "fubar_hint_breach" },
    { 0x5067, "fuitems" },
    { 0x5068, "full_gib" },
    { 0x5069, "full_partname" },
    { 0x506A, "fullmodel" },
    { 0x506B, "fullscreen_overlay" },
    { 0x506C, "fullsights" },
    { 0x506D, "fulton_group_exfil_at_pos" },
    { 0x506E, "fulton_group_exfil_at_pos_internal" },
    { 0x506F, "fulton_group_use_think" },
    { 0x5070, "fulton_interactions" },
    { 0x5071, "fulton_last_usetime" },
    { 0x5072, "fulton_launch_player_effects" },
    { 0x5073, "fultonextract_used" },
    { 0x5074, "func" },
    { 0x5075, "func_after_anim" },
    { 0x5076, "func_bcs_location_trigs" },
    { 0x5077, "func_bot_get_closest_navigable_point" },
    { 0x5078, "func_create_loopsound" },
    { 0x5079, "func_encounterstart" },
    { 0x507A, "func_get_level_fx" },
    { 0x507B, "func_get_nodes_on_path" },
    { 0x507C, "func_get_path_dist" },
    { 0x507D, "func_getspawneraitype" },
    { 0x507E, "func_glass_handler" },
    { 0x507F, "func_loopfxthread" },
    { 0x5080, "func_oneshotfxthread" },
    { 0x5081, "func_patch" },
    { 0x5082, "func_player_speed" },
    { 0x5083, "func_pointer" },
    { 0x5084, "func_position_player" },
    { 0x5085, "func_position_player_get" },
    { 0x5086, "func_process_fx_rotater" },
    { 0x5087, "func_ref_exist" },
    { 0x5088, "func_run_lean_threads" },
    { 0x5089, "func_thread" },
    { 0x508A, "func_updatefx" },
    { 0x508B, "funcs" },
    { 0x508C, "funcs_after_notifies" },
    { 0x508D, "function" },
    { 0x508E, "function_stack" },
    { 0x508F, "function_stack_caller_waits_for_turn" },
    { 0x5090, "function_stack_clear" },
    { 0x5091, "function_stack_func_begun" },
    { 0x5092, "function_stack_proc" },
    { 0x5093, "function_stack_self_death" },
    { 0x5094, "function_stack_timeout" },
    { 0x5095, "function_stack_wait" },
    { 0x5096, "function_stack_wait_finish" },
    { 0x5097, "furthestspawndistsq" },
    { 0x5098, "fusebox" },
    { 0x5099, "fusebox_animnode" },
    { 0x509A, "fusebox_damage_think" },
    { 0x509B, "fusebox_door_interact" },
    { 0x509C, "fusebox_handle_down" },
    { 0x509D, "fusebox_init" },
    { 0x509E, "fusebox_interact_anim" },
    { 0x509F, "fusebox_interact_anim_unlink_player" },
    { 0x50A0, "fusebox_runner_stealth_filter" },
    { 0x50A1, "fusebox_switch" },
    { 0x50A2, "fusebox_switchoff_think" },
    { 0x50A3, "fusebox_tut_catchup" },
    { 0x50A4, "fusebox_tut_cleanup" },
    { 0x50A5, "fusebox_tut_gate" },
    { 0x50A6, "fusebox_tut_main" },
    { 0x50A7, "fusebox_tut_price" },
    { 0x50A8, "fusebox_tut_price_breakout" },
    { 0x50A9, "fusebox_tut_price_finish" },
    { 0x50AA, "fusebox_tut_start" },
    { 0x50AB, "fusebox_tut_victim" },
    { 0x50AC, "fusebox_tutorial_temp_sounds" },
    { 0x50AD, "fusebox_victim" },
    { 0x50AE, "fuseboxes" },
    { 0x50AF, "fwd" },
    { 0x50B0, "fwd_anim" },
    { 0x50B1, "fx" },
    { 0x50B2, "fx_airstrike_afterburner" },
    { 0x50B3, "fx_airstrike_contrail" },
    { 0x50B4, "fx_airstrike_wingtip_light_green" },
    { 0x50B5, "fx_airstrike_wingtip_light_red" },
    { 0x50B6, "fx_array_fire_chains" },
    { 0x50B7, "fx_contrail_tag" },
    { 0x50B8, "fx_death_check" },
    { 0x50B9, "fx_ent" },
    { 0x50BA, "fx_explode" },
    { 0x50BB, "fx_flare_oil_fire" },
    { 0x50BC, "fx_forward" },
    { 0x50BD, "fx_highlightedent" },
    { 0x50BE, "fx_kill_watcher" },
    { 0x50BF, "fx_killontag_safe" },
    { 0x50C0, "fx_killontag_safe_internal" },
    { 0x50C1, "fx_leave_tag" },
    { 0x50C2, "fx_on" },
    { 0x50C3, "fx_origin" },
    { 0x50C4, "fx_paused" },
    { 0x50C5, "fx_playontag_safe" },
    { 0x50C6, "fx_playontag_safe_internal" },
    { 0x50C7, "fx_regulate" },
    { 0x50C8, "fx_regulate_init" },
    { 0x50C9, "fx_regulator" },
    { 0x50CA, "fx_rotating" },
    { 0x50CB, "fx_stopontag_safe" },
    { 0x50CC, "fx_stopontag_safe_internal" },
    { 0x50CD, "fx_struct" },
    { 0x50CE, "fx_stun_damage" },
    { 0x50CF, "fx_tag" },
    { 0x50D0, "fx_tags" },
    { 0x50D1, "fx_ticket" },
    { 0x50D2, "fx_ticket_queue" },
    { 0x50D3, "fx_up" },
    { 0x50D4, "fx_volume_pause" },
    { 0x50D5, "fx_volume_pause_noteworthy" },
    { 0x50D6, "fx_volume_pause_noteworthy_thread" },
    { 0x50D7, "fx_volume_restart" },
    { 0x50D8, "fx_volume_restart_noteworthy" },
    { 0x50D9, "fx_volume_restart_noteworthy_thread" },
    { 0x50DA, "fxdelay" },
    { 0x50DB, "fxdlightent" },
    { 0x50DC, "fxent" },
    { 0x50DD, "fxentdeletelist" },
    { 0x50DE, "fxexists" },
    { 0x50DF, "fxhudelements" },
    { 0x50E0, "fxid_contrail" },
    { 0x50E1, "fxid_explode" },
    { 0x50E2, "fxid_leave" },
    { 0x50E3, "fxid_light1" },
    { 0x50E4, "fxid_ping" },
    { 0x50E5, "fxid_sparks" },
    { 0x50E6, "fxname" },
    { 0x50E7, "fxobj" },
    { 0x50E8, "fxoffset" },
    { 0x50E9, "fxstart" },
    { 0x50EA, "fxstop" },
    { 0x50EB, "fxtag" },
    { 0x50EC, "fxtime" },
    { 0x50ED, "fxtoplay" },
    { 0x50EE, "g_bob_scale_get_func" },
    { 0x50EF, "g_bob_scale_set_func" },
    { 0x50F0, "g_effect" },
    { 0x50F1, "g_inuse" },
    { 0x50F2, "g_nextusepress" },
    { 0x50F3, "g_speed" },
    { 0x50F4, "g_speed_get_func" },
    { 0x50F5, "g_speed_set_func" },
    { 0x50F6, "gainedjuggupdater" },
    { 0x50F7, "game_end" },
    { 0x50F8, "game_ended_fadeout" },
    { 0x50F9, "game_ended_vo_watcher" },
    { 0x50FA, "game_init" },
    { 0x50FB, "game_mode_attachment_map" },
    { 0x50FC, "game_mode_statstable" },
    { 0x50FD, "game_should_end_early" },
    { 0x50FE, "game_start" },
    { 0x50FF, "game_type_col" },
    { 0x5100, "game_utility_cp_gettimesincegamestart" },
    { 0x5101, "game_utility_cp_init" },
    { 0x5102, "game_utility_init" },
    { 0x5103, "game_utility_mp_gettimesincegamestart" },
    { 0x5104, "game_utility_mp_init" },
    { 0x5105, "gamealreadyended" },
    { 0x5106, "gameended" },
    { 0x5107, "gameendlistener" },
    { 0x5108, "gameendtime" },
    { 0x5109, "gameflag" },
    { 0x510A, "gameflagclear" },
    { 0x510B, "gameflaginit" },
    { 0x510C, "gameflagset" },
    { 0x510D, "gameflagwait" },
    { 0x510E, "gamehasinfil" },
    { 0x510F, "gamehasneutralcrateowner" },
    { 0x5110, "gamehasstarted" },
    { 0x5111, "gamemode_chosenclass" },
    { 0x5112, "gamemodecalloutent" },
    { 0x5113, "gamemodecallouttime" },
    { 0x5114, "gamemodefirstspawn" },
    { 0x5115, "gamemodeforcednewloadout" },
    { 0x5116, "gamemodegesturecalloutassign" },
    { 0x5117, "gamemodegesturecalloutverify" },
    { 0x5118, "gamemodejoinedatstart" },
    { 0x5119, "gamemodemaydropweapon" },
    { 0x511A, "gamemodemodifyplayerdamage" },
    { 0x511B, "gamemodespawnpointnames" },
    { 0x511C, "gamemodestartspawnpointnames" },
    { 0x511D, "gamemodeusesdeathmatchscoring" },
    { 0x511E, "gameobject" },
    { 0x511F, "gameobject_fauxspawn" },
    { 0x5120, "gameobjectreleaseid_delayed" },
    { 0x5121, "gameobjects_getcurrentprimaryweapon" },
    { 0x5122, "gameoff" },
    { 0x5123, "gameon" },
    { 0x5124, "gameon_thread" },
    { 0x5125, "gameon_toggle" },
    { 0x5126, "gamepadwasenabled" },
    { 0x5127, "gameplay_asset_adjustments" },
    { 0x5128, "gamescore_init" },
    { 0x5129, "gamescoreevent" },
    { 0x512A, "gameshouldend" },
    { 0x512B, "gameskill" },
    { 0x512C, "gameskill_breath_func" },
    { 0x512D, "gameskill_change_monitor" },
    { 0x512E, "gamestarted" },
    { 0x512F, "gametime" },
    { 0x5130, "gametimer" },
    { 0x5131, "gametimerbeeps" },
    { 0x5132, "gametweaks" },
    { 0x5133, "gametype" },
    { 0x5134, "gametype_agent_init" },
    { 0x5135, "gametype_interaction_func" },
    { 0x5136, "gametypestarted" },
    { 0x5137, "gametypesupportsbasejumping" },
    { 0x5138, "gametypexpmodifier" },
    { 0x5139, "gamewinnerdialog" },
    { 0x513A, "gap_ai_cleanup" },
    { 0x513B, "gap_bomber" },
    { 0x513C, "gap_bomber_detoantes" },
    { 0x513D, "gap_bomber_dmg" },
    { 0x513E, "gap_bomber_internal" },
    { 0x513F, "gap_bomber_logic" },
    { 0x5140, "gap_flags" },
    { 0x5141, "gap_hostage_beeper_loop" },
    { 0x5142, "gap_hostage_dmg_monitor" },
    { 0x5143, "gap_nag" },
    { 0x5144, "gap_right_combat" },
    { 0x5145, "garage" },
    { 0x5146, "garage_ambush_thread" },
    { 0x5147, "garage_ambusher" },
    { 0x5148, "garage_approach_vo" },
    { 0x5149, "garage_door" },
    { 0x514A, "garage_door_anim" },
    { 0x514B, "garage_door_lights_off" },
    { 0x514C, "garage_enemy_going_hot" },
    { 0x514D, "garage_entry_catchup" },
    { 0x514E, "garage_entry_dialog" },
    { 0x514F, "garage_entry_main" },
    { 0x5150, "garage_entry_start" },
    { 0x5151, "garage_exit" },
    { 0x5152, "garage_explosive_explode" },
    { 0x5153, "garage_explosive_thread" },
    { 0x5154, "garage_explosives_init" },
    { 0x5155, "garage_fire" },
    { 0x5156, "garage_fire_init" },
    { 0x5157, "garage_fire_thread" },
    { 0x5158, "garage_init" },
    { 0x5159, "garage_inner_main" },
    { 0x515A, "garage_inner_start" },
    { 0x515B, "garage_knock" },
    { 0x515C, "garage_knock_enemy" },
    { 0x515D, "garage_knock_vo" },
    { 0x515E, "garage_model_swap" },
    { 0x515F, "garage_office_alert_thread" },
    { 0x5160, "garage_office_alert_wait" },
    { 0x5161, "garage_scriptables" },
    { 0x5162, "garage_tires" },
    { 0x5163, "garage_tripwire_init" },
    { 0x5164, "garage_tv" },
    { 0x5165, "garage2_carjack" },
    { 0x5166, "garage2_easy_light" },
    { 0x5167, "garage2_exit_vo" },
    { 0x5168, "garage2_force_combat" },
    { 0x5169, "garage2_is_light_off" },
    { 0x516A, "garage2_lifted_taxi" },
    { 0x516B, "garage2_lights" },
    { 0x516C, "garage2_lower_carjack" },
    { 0x516D, "garage2_price_exit" },
    { 0x516E, "garage2_scene" },
    { 0x516F, "garage2_temp_sounds" },
    { 0x5170, "garage2_train" },
    { 0x5171, "garagedoor" },
    { 0x5172, "garbage_collector" },
    { 0x5173, "garbage_collector_think" },
    { 0x5174, "gas_alley_hadir_blocker" },
    { 0x5175, "gas_alley_start_blocker" },
    { 0x5176, "gas_allieslogic" },
    { 0x5177, "gas_and_kidnap_sequence" },
    { 0x5178, "gas_applyblur" },
    { 0x5179, "gas_applycough" },
    { 0x517A, "gas_applyspeedredux" },
    { 0x517B, "gas_attack_anim_node" },
    { 0x517C, "gas_attack_catchup" },
    { 0x517D, "gas_attack_corpse_shader" },
    { 0x517E, "gas_attack_house_door_model" },
    { 0x517F, "gas_attack_left_anim_node" },
    { 0x5180, "gas_attack_main" },
    { 0x5181, "gas_attack_start" },
    { 0x5182, "gas_attack_triggers_monitor" },
    { 0x5183, "gas_begincoughing" },
    { 0x5184, "gas_blockers" },
    { 0x5185, "gas_can_save" },
    { 0x5186, "gas_cannister_launch" },
    { 0x5187, "gas_catchup" },
    { 0x5188, "gas_chambers_catchup" },
    { 0x5189, "gas_chambers_main" },
    { 0x518A, "gas_chambers_start" },
    { 0x518B, "gas_clear" },
    { 0x518C, "gas_clearblur" },
    { 0x518D, "gas_clearcough" },
    { 0x518E, "gas_clearspeedredux" },
    { 0x518F, "gas_coughisblocked" },
    { 0x5190, "gas_cover_blown_monitor" },
    { 0x5191, "gas_crawl_end_blocker" },
    { 0x5192, "gas_crawl_start_blocker" },
    { 0x5193, "gas_createtrigger" },
    { 0x5194, "gas_destroytrigger" },
    { 0x5195, "gas_dialoguelogic" },
    { 0x5196, "gas_door_down" },
    { 0x5197, "gas_dyingaidamagelogic" },
    { 0x5198, "gas_dyingailogic" },
    { 0x5199, "gas_exit_catchup" },
    { 0x519A, "gas_exit_main" },
    { 0x519B, "gas_exit_start" },
    { 0x519C, "gas_exit_start_vo" },
    { 0x519D, "gas_exit_trigger_monitor" },
    { 0x519E, "gas_explosionlogic" },
    { 0x519F, "gas_explosionsfxlogic" },
    { 0x51A0, "gas_factory_mid_spawn_func" },
    { 0x51A1, "gas_fail_timer" },
    { 0x51A2, "gas_fail_trigger" },
    { 0x51A3, "gas_getanimationstruct" },
    { 0x51A4, "gas_getbarrels" },
    { 0x51A5, "gas_getblurinterruptdelayms" },
    { 0x51A6, "gas_getplayermask" },
    { 0x51A7, "gas_isintrigger" },
    { 0x51A8, "gas_killai" },
    { 0x51A9, "gas_main" },
    { 0x51AA, "gas_main_setup" },
    { 0x51AB, "gas_mask" },
    { 0x51AC, "gas_mask_from_boss_model" },
    { 0x51AD, "gas_mask_from_boss_model_pre" },
    { 0x51AE, "gas_mask_overlay" },
    { 0x51AF, "gas_mask_pickup_playerlogic" },
    { 0x51B0, "gas_mask_remove_trigger_monitor" },
    { 0x51B1, "gas_mask_swap" },
    { 0x51B2, "gas_masks_middle" },
    { 0x51B3, "gas_masks_side" },
    { 0x51B4, "gas_mid_catchup" },
    { 0x51B5, "gas_mid_main" },
    { 0x51B6, "gas_mid_start" },
    { 0x51B7, "gas_mid_start_vo" },
    { 0x51B8, "gas_mid_trigger_monitor" },
    { 0x51B9, "gas_modifyspeed" },
    { 0x51BA, "gas_monitorcoughduration" },
    { 0x51BB, "gas_monitorcoughweaponfired" },
    { 0x51BC, "gas_monitorcoughweapontaken" },
    { 0x51BD, "gas_objectivelogic" },
    { 0x51BE, "gas_onentertrigger" },
    { 0x51BF, "gas_onexittrigger" },
    { 0x51C0, "gas_onplayerdamaged" },
    { 0x51C1, "gas_playerexposedblackoverlaylogic" },
    { 0x51C2, "gas_playerexposedblurlogic" },
    { 0x51C3, "gas_playerexposedeffects" },
    { 0x51C4, "gas_playerexposedfovlogic" },
    { 0x51C5, "gas_playerexposedlogic" },
    { 0x51C6, "gas_playerexposedproneimpactlogic" },
    { 0x51C7, "gas_playerexposedspeedlogic" },
    { 0x51C8, "gas_playerpassoutlogic" },
    { 0x51C9, "gas_playerpistolweaponlogic" },
    { 0x51CA, "gas_playerrecovereffects" },
    { 0x51CB, "gas_queuecough" },
    { 0x51CC, "gas_removeblur" },
    { 0x51CD, "gas_removecough" },
    { 0x51CE, "gas_removespeedredux" },
    { 0x51CF, "gas_restoreheldoffhand" },
    { 0x51D0, "gas_shouldtakeheldoffhand" },
    { 0x51D1, "gas_sources" },
    { 0x51D2, "gas_start" },
    { 0x51D3, "gas_start_execution" },
    { 0x51D4, "gas_start_soldier" },
    { 0x51D5, "gas_start_vo" },
    { 0x51D6, "gas_takeheldoffhand" },
    { 0x51D7, "gas_trail_ground_done" },
    { 0x51D8, "gas_trigger_monitor" },
    { 0x51D9, "gas_updateplayereffects" },
    { 0x51DA, "gas_used" },
    { 0x51DB, "gas_victim_spawn_and_loop" },
    { 0x51DC, "gas_victims" },
    { 0x51DD, "gas_victims_start_loops" },
    { 0x51DE, "gas_watchexplode" },
    { 0x51DF, "gas_watchtriggerenter" },
    { 0x51E0, "gas_watchtriggerexit" },
    { 0x51E1, "gas_window_blocker" },
    { 0x51E2, "gasattack_ambulance_truck_model" },
    { 0x51E3, "gasattack_attack_rus_01_model" },
    { 0x51E4, "gasattack_attack_rus_02_model" },
    { 0x51E5, "gasattack_attack_rus_03_model" },
    { 0x51E6, "gasattack_civ_female_01" },
    { 0x51E7, "gasattack_civ_male_01" },
    { 0x51E8, "gasattack_civ_male_02" },
    { 0x51E9, "gasattack_civ_male_03" },
    { 0x51EA, "gasattack_civ01_model" },
    { 0x51EB, "gasattack_civ02_model" },
    { 0x51EC, "gasattack_civ03_model" },
    { 0x51ED, "gasattack_civ04_model" },
    { 0x51EE, "gasattack_civ05_model" },
    { 0x51EF, "gasattack_civ06_model" },
    { 0x51F0, "gasattack_civ07_model" },
    { 0x51F1, "gasattack_enemy_truck_01_model" },
    { 0x51F2, "gasattack_enemy_truck_02_model" },
    { 0x51F3, "gasattack_wh01_model" },
    { 0x51F4, "gasattack_wh02_model" },
    { 0x51F5, "gasattack_wh03_model" },
    { 0x51F6, "gascan_hint_displayed" },
    { 0x51F7, "gascankills" },
    { 0x51F8, "gascanowner" },
    { 0x51F9, "gascanownercount" },
    { 0x51FA, "gascoughinprogress" },
    { 0x51FB, "gasdamagebuffer" },
    { 0x51FC, "gaslabanimref" },
    { 0x51FD, "gaslabdoor" },
    { 0x51FE, "gaslabdoorinteract" },
    { 0x51FF, "gasmask" },
    { 0x5200, "gasmask_on" },
    { 0x5201, "gasmask_on_belt" },
    { 0x5202, "gasmaskequipped" },
    { 0x5203, "gasmaskhealth" },
    { 0x5204, "gasmaskoverlay" },
    { 0x5205, "gasmaskswapinprogress" },
    { 0x5206, "gasspeedmod" },
    { 0x5207, "gastakenweaponammo" },
    { 0x5208, "gastakenweaponobj" },
    { 0x5209, "gastriggerstouching" },
    { 0x520A, "gate_already_open_and_connect_paths" },
    { 0x520B, "gate_aq_spawners" },
    { 0x520C, "gate_breach_sfx" },
    { 0x520D, "gate_burning_cars" },
    { 0x520E, "gate_catchup" },
    { 0x520F, "gate_chain" },
    { 0x5210, "gate_chain_init" },
    { 0x5211, "gate_climber" },
    { 0x5212, "gate_climbers_respawner" },
    { 0x5213, "gate_climbers_setup" },
    { 0x5214, "gate_collapse_rumble_handler" },
    { 0x5215, "gate_damage_monitor" },
    { 0x5216, "gate_enemy_goes_hot" },
    { 0x5217, "gate_enemy_react_to_sprinting" },
    { 0x5218, "gate_enemy_stealth_filter" },
    { 0x5219, "gate_light_watcher" },
    { 0x521A, "gate_lock_swap" },
    { 0x521B, "gate_main" },
    { 0x521C, "gate_marine_spawners" },
    { 0x521D, "gate_mob_aq_spawners" },
    { 0x521E, "gate_mob_civ_spawners" },
    { 0x521F, "gate_nvg_hint" },
    { 0x5220, "gate_open_and_connect_paths" },
    { 0x5221, "gate_overrun" },
    { 0x5222, "gate_overrun_fire_rate_controller" },
    { 0x5223, "gate_overrun_respawner_aq_fighters" },
    { 0x5224, "gate_overrun_respawner_marines" },
    { 0x5225, "gate_overrun_respawner_mob_aq" },
    { 0x5226, "gate_overrun_respawner_mob_civ" },
    { 0x5227, "gate_overrun_set_dont_shoot" },
    { 0x5228, "gate_overrunners_aq" },
    { 0x5229, "gate_overrunners_marine" },
    { 0x522A, "gate_overrunners_mob_aq" },
    { 0x522B, "gate_overrunners_mob_civ" },
    { 0x522C, "gate_start" },
    { 0x522D, "gate_team_approach_and_mask_up" },
    { 0x522E, "gate_team_open_and_enter" },
    { 0x522F, "gate_truck" },
    { 0x5230, "gatelock" },
    { 0x5231, "gates" },
    { 0x5232, "gatesmash_laswell_convo" },
    { 0x5233, "gather_delay" },
    { 0x5234, "gather_delay_proc" },
    { 0x5235, "gatherc130playerstospawn" },
    { 0x5236, "gatherdynamiccqbstructs" },
    { 0x5237, "gathergroups" },
    { 0x5238, "gathermappointinfo" },
    { 0x5239, "gatheroutercrates" },
    { 0x523A, "gathervalidspawnclosets" },
    { 0x523B, "gator" },
    { 0x523C, "gauntlet_actor_animate_single_then_loop" },
    { 0x523D, "gauntlet_aq_chasing_handler" },
    { 0x523E, "gauntlet_aq_chasing_player_van" },
    { 0x523F, "gauntlet_aq_clean_up_handler" },
    { 0x5240, "gauntlet_aq_create_badplace_in_combat" },
    { 0x5241, "gauntlet_aq_create_badplace_on_death" },
    { 0x5242, "gauntlet_aq_dead" },
    { 0x5243, "gauntlet_aq_death_count_monitor" },
    { 0x5244, "gauntlet_aq_fighting_police" },
    { 0x5245, "gauntlet_aq_force_target_police_cars" },
    { 0x5246, "gauntlet_aq_force_target_van" },
    { 0x5247, "gauntlet_aq_on_foot_spawner" },
    { 0x5248, "gauntlet_aq_runner_handler" },
    { 0x5249, "gauntlet_aq_spawn_handler" },
    { 0x524A, "gauntlet_aq_state_handler" },
    { 0x524B, "gauntlet_aq_vehicle_cleanup" },
    { 0x524C, "gauntlet_aq_vehicle_destroyed" },
    { 0x524D, "gauntlet_aq_vehicle_driver_death_handler" },
    { 0x524E, "gauntlet_aq_vehicle_movement_handler" },
    { 0x524F, "gauntlet_autosave_weapon_pickup" },
    { 0x5250, "gauntlet_background_fakecivs" },
    { 0x5251, "gauntlet_blood_handler" },
    { 0x5252, "gauntlet_car_death_check" },
    { 0x5253, "gauntlet_car_death_monitor" },
    { 0x5254, "gauntlet_car_fx_handler" },
    { 0x5255, "gauntlet_car_fx_stopper" },
    { 0x5256, "gauntlet_car_wheel_fx_handler" },
    { 0x5257, "gauntlet_car_wheel_fx_stopper" },
    { 0x5258, "gauntlet_catchup" },
    { 0x5259, "gauntlet_check_player_returning_fire" },
    { 0x525A, "gauntlet_civ_car_climb_handler" },
    { 0x525B, "gauntlet_civ_setup" },
    { 0x525C, "gauntlet_civilian_vehicle_explosion_handler" },
    { 0x525D, "gauntlet_civilian_vehicles" },
    { 0x525E, "gauntlet_containment" },
    { 0x525F, "gauntlet_containment_handler" },
    { 0x5260, "gauntlet_enforcer_force_cold_breath" },
    { 0x5261, "gauntlet_enforcer_health_check_during_van_load" },
    { 0x5262, "gauntlet_enforcer_in_van_handler" },
    { 0x5263, "gauntlet_enforcer_ragdoll_clamp" },
    { 0x5264, "gauntlet_enforcer_ragdoll_handler" },
    { 0x5265, "gauntlet_enter_van_handler" },
    { 0x5266, "gauntlet_enter_van_timer" },
    { 0x5267, "gauntlet_grenade_interact" },
    { 0x5268, "gauntlet_hack_bench_badplace" },
    { 0x5269, "gauntlet_increase_player_grenades" },
    { 0x526A, "gauntlet_increase_player_lmg_ammo" },
    { 0x526B, "gauntlet_init" },
    { 0x526C, "gauntlet_init_threatbias" },
    { 0x526D, "gauntlet_main" },
    { 0x526E, "gauntlet_player_attackeraccuracy_handler" },
    { 0x526F, "gauntlet_police_car_array_setup" },
    { 0x5270, "gauntlet_police_cars" },
    { 0x5271, "gauntlet_police_handler" },
    { 0x5272, "gauntlet_police_sirens" },
    { 0x5273, "gauntlet_police_vehicle_lights" },
    { 0x5274, "gauntlet_price_get_in_van" },
    { 0x5275, "gauntlet_price_handler" },
    { 0x5276, "gauntlet_remove_enforcer_clip" },
    { 0x5277, "gauntlet_set_ai_in_range_to_pacifist" },
    { 0x5278, "gauntlet_set_van_health" },
    { 0x5279, "gauntlet_shootout_autosave" },
    { 0x527A, "gauntlet_shootout_catchup" },
    { 0x527B, "gauntlet_shootout_combat_handler" },
    { 0x527C, "gauntlet_shootout_main" },
    { 0x527D, "gauntlet_shootout_mb_windows" },
    { 0x527E, "gauntlet_shootout_police_arrive" },
    { 0x527F, "gauntlet_shootout_price_handler" },
    { 0x5280, "gauntlet_shootout_setup_van" },
    { 0x5281, "gauntlet_shootout_start" },
    { 0x5282, "gauntlet_shootout_stp_main" },
    { 0x5283, "gauntlet_shootout_van_destroyed" },
    { 0x5284, "gauntlet_spawn_nikolai" },
    { 0x5285, "gauntlet_start" },
    { 0x5286, "gauntlet_stop_vehicle_fx" },
    { 0x5287, "gauntlet_stp_main" },
    { 0x5288, "gauntlet_swap_van_clip" },
    { 0x5289, "gauntlet_van_attach_windows" },
    { 0x528A, "gauntlet_van_bullethit_monitor" },
    { 0x528B, "gauntlet_van_cleanup" },
    { 0x528C, "gauntlet_van_create_bullethole" },
    { 0x528D, "gauntlet_van_create_random_bullethole" },
    { 0x528E, "gauntlet_van_damage_impact" },
    { 0x528F, "gauntlet_van_engine" },
    { 0x5290, "gauntlet_van_health_monitor" },
    { 0x5291, "gauntlet_van_hit_vignette" },
    { 0x5292, "gauntlet_van_light_off" },
    { 0x5293, "gauntlet_van_light_on" },
    { 0x5294, "gauntlet_van_sunblocker_handler" },
    { 0x5295, "gauntlet_van_takeoff" },
    { 0x5296, "gauntlet_van_to_interrogation" },
    { 0x5297, "gauntlet_vehicle_unload" },
    { 0x5298, "gauntlet_vfx" },
    { 0x5299, "gauntlet_vig_civ_1" },
    { 0x529A, "gauntlet_vig_civ_2" },
    { 0x529B, "gauntlet_vig_civ_3" },
    { 0x529C, "gauntlet_vig_civ_4" },
    { 0x529D, "gauntlet_vig_civ_5" },
    { 0x529E, "gauntlet_vig_civ_6" },
    { 0x529F, "gauntlet_vig_civ_7" },
    { 0x52A0, "gauntlet_vig_civ_8" },
    { 0x52A1, "gauntlet_vig_civ_prox_handler" },
    { 0x52A2, "gauntlet_vig_civ_react_handler" },
    { 0x52A3, "gauntlet_vig_init" },
    { 0x52A4, "gauntlet_vig_start" },
    { 0x52A5, "gauntlet_weapon_pickup_handler" },
    { 0x52A6, "gavehcr" },
    { 0x52A7, "ge" },
    { 0x52A8, "gearchangedfromloadout" },
    { 0x52A9, "gearup_nag_count" },
    { 0x52AA, "gearup_nags" },
    { 0x52AB, "gender" },
    { 0x52AC, "general" },
    { 0x52AD, "general_notetrack_handler" },
    { 0x52AE, "generate_fx_log" },
    { 0x52AF, "generatenearbyspawner" },
    { 0x52B0, "generatepath" },
    { 0x52B1, "generatinglosdata" },
    { 0x52B2, "generic" },
    { 0x52B3, "generic_combat" },
    { 0x52B4, "generic_damage_monitor" },
    { 0x52B5, "generic_damage_think" },
    { 0x52B6, "generic_dialogue_queue" },
    { 0x52B7, "generic_double_strobe" },
    { 0x52B8, "generic_human" },
    { 0x52B9, "generic_human_anims" },
    { 0x52BA, "generic_index" },
    { 0x52BB, "generic_lerp_value" },
    { 0x52BC, "generic_pulsing" },
    { 0x52BD, "generic_radio_confrimation" },
    { 0x52BE, "generic_spot" },
    { 0x52BF, "generic_voice_override" },
    { 0x52C0, "geneva" },
    { 0x52C1, "geo" },
    { 0x52C2, "gesture" },
    { 0x52C3, "gesture_active" },
    { 0x52C4, "gesture_armup_anim" },
    { 0x52C5, "gesture_body_knob" },
    { 0x52C6, "gesture_catchup_speed" },
    { 0x52C7, "gesture_coinflipthink" },
    { 0x52C8, "gesture_cross_anim" },
    { 0x52C9, "gesture_custom" },
    { 0x52CA, "gesture_death_anim" },
    { 0x52CB, "gesture_determinerockpaperscissorswinner" },
    { 0x52CC, "gesture_directional_custom" },
    { 0x52CD, "gesture_door" },
    { 0x52CE, "gesture_door_hard" },
    { 0x52CF, "gesture_eye_dart_loop" },
    { 0x52D0, "gesture_eyes_stop" },
    { 0x52D1, "gesture_fallback_down_anim" },
    { 0x52D2, "gesture_fallback_up_anim" },
    { 0x52D3, "gesture_finishearly" },
    { 0x52D4, "gesture_follow_eye_update" },
    { 0x52D5, "gesture_follow_eyes" },
    { 0x52D6, "gesture_follow_lookat" },
    { 0x52D7, "gesture_follow_lookat_natural" },
    { 0x52D8, "gesture_follow_lookat_update" },
    { 0x52D9, "gesture_follow_torso" },
    { 0x52DA, "gesture_getrockpaperscissorsplayers" },
    { 0x52DB, "gesture_head_stop" },
    { 0x52DC, "gesture_hold_anim" },
    { 0x52DD, "gesture_lookat" },
    { 0x52DE, "gesture_manage3rdperson" },
    { 0x52DF, "gesture_moveup_anim" },
    { 0x52E0, "gesture_nod_anim" },
    { 0x52E1, "gesture_nvgs" },
    { 0x52E2, "gesture_on_start_cough" },
    { 0x52E3, "gesture_onme_anim" },
    { 0x52E4, "gesture_pickrockpaperscissors" },
    { 0x52E5, "gesture_playrockpaperscissors" },
    { 0x52E6, "gesture_point" },
    { 0x52E7, "gesture_point_center" },
    { 0x52E8, "gesture_point_down" },
    { 0x52E9, "gesture_point_left" },
    { 0x52EA, "gesture_point_parent" },
    { 0x52EB, "gesture_point_right" },
    { 0x52EC, "gesture_point_up" },
    { 0x52ED, "gesture_reaction_distance_based" },
    { 0x52EE, "gesture_reaction_queue" },
    { 0x52EF, "gesture_resetcoinflipgesture" },
    { 0x52F0, "gesture_resetrockpaperscissorsgesture" },
    { 0x52F1, "gesture_rockpaperscissorsthink" },
    { 0x52F2, "gesture_salute_anim" },
    { 0x52F3, "gesture_shake_head_anim" },
    { 0x52F4, "gesture_should_disable_lookat" },
    { 0x52F5, "gesture_shrug_anim" },
    { 0x52F6, "gesture_simple" },
    { 0x52F7, "gesture_simple_when_close" },
    { 0x52F8, "gesture_stop" },
    { 0x52F9, "gesture_target" },
    { 0x52FA, "gesture_torso_stop" },
    { 0x52FB, "gesture_wait_anim" },
    { 0x52FC, "gesture_wave_anim" },
    { 0x52FD, "gesture_window" },
    { 0x52FE, "gesturedonotetracks" },
    { 0x52FF, "gestureinfo" },
    { 0x5300, "gestureinfobyindex" },
    { 0x5301, "gestureinterruptible" },
    { 0x5302, "gestureinterruptibleifplayerwithindist" },
    { 0x5303, "gesturenotetracktimeoutthread" },
    { 0x5304, "gesturerequest" },
    { 0x5305, "gestures" },
    { 0x5306, "gestures_enabled" },
    { 0x5307, "gesturesounds" },
    { 0x5308, "gestureweapon" },
    { 0x5309, "get_accuracy" },
    { 0x530A, "get_action_slot_weapon" },
    { 0x530B, "get_active_from_grouped_modules" },
    { 0x530C, "get_active_objectives" },
    { 0x530D, "get_active_oil_fires" },
    { 0x530E, "get_activecount_from_group" },
    { 0x530F, "get_actor_alive_states" },
    { 0x5310, "get_actual_tag_flash_loc" },
    { 0x5311, "get_actual_time_from_civil" },
    { 0x5312, "get_add_item_func" },
    { 0x5313, "get_additional_num_false_positive_dots_needed" },
    { 0x5314, "get_adjacent_volumes_from_volume" },
    { 0x5315, "get_adjusted_armor" },
    { 0x5316, "get_adjusted_difficulty" },
    { 0x5317, "get_adjusted_friendly_kill_points" },
    { 0x5318, "get_adjusted_marker_vfx_pos" },
    { 0x5319, "get_agent_type" },
    { 0x531A, "get_ai_by_groupname" },
    { 0x531B, "get_ai_from_array_by_targetname" },
    { 0x531C, "get_ai_group_ai" },
    { 0x531D, "get_ai_group_count" },
    { 0x531E, "get_ai_group_death_count" },
    { 0x531F, "get_ai_group_sentient_count" },
    { 0x5320, "get_ai_group_spawner_count" },
    { 0x5321, "get_ai_group_spawners" },
    { 0x5322, "get_ai_highlight_hudoutline" },
    { 0x5323, "get_ai_number" },
    { 0x5324, "get_ai_team" },
    { 0x5325, "get_ai_touching_volume" },
    { 0x5326, "get_ai_type" },
    { 0x5327, "get_aim_anim" },
    { 0x5328, "get_aim_target" },
    { 0x5329, "get_aim_to_hide_anim" },
    { 0x532A, "get_aitype_settings" },
    { 0x532B, "get_aitypes_from_spawner" },
    { 0x532C, "get_ak_remove_fov_user_scale" },
    { 0x532D, "get_alias_2d_func" },
    { 0x532E, "get_alias_2d_version" },
    { 0x532F, "get_alias_3d_version" },
    { 0x5330, "get_alias_from_stored" },
    { 0x5331, "get_aliensession_stat" },
    { 0x5332, "get_alive_enemies" },
    { 0x5333, "get_alive_riders" },
    { 0x5334, "get_alive_wave_1_guys" },
    { 0x5335, "get_all_bashable_doors" },
    { 0x5336, "get_all_closed_doors" },
    { 0x5337, "get_all_closest_living" },
    { 0x5338, "get_all_cluster_spawners" },
    { 0x5339, "get_all_connected_nodes" },
    { 0x533A, "get_all_force_color_friendlies" },
    { 0x533B, "get_all_good_guys" },
    { 0x533C, "get_all_hero_players" },
    { 0x533D, "get_all_infils" },
    { 0x533E, "get_all_interactive_doors" },
    { 0x533F, "get_all_interactive_doors_blocking_paths" },
    { 0x5340, "get_all_my_locations" },
    { 0x5341, "get_all_nodes" },
    { 0x5342, "get_all_script_models_with_modelname" },
    { 0x5343, "get_alley_gate" },
    { 0x5344, "get_allied_attackers_for_team" },
    { 0x5345, "get_allied_defenders_for_team" },
    { 0x5346, "get_allowed_vehicle_types" },
    { 0x5347, "get_ally_flags" },
    { 0x5348, "get_ally_target" },
    { 0x5349, "get_ambient_max_count" },
    { 0x534A, "get_ambient_min_count" },
    { 0x534B, "get_angle_offset" },
    { 0x534C, "get_angles_between_two_vehicle" },
    { 0x534D, "get_angles_from_actor" },
    { 0x534E, "get_angles_to_attacker" },
    { 0x534F, "get_anim_data" },
    { 0x5350, "get_anim_direction" },
    { 0x5351, "get_anim_frac_from_time" },
    { 0x5352, "get_anim_from_direction" },
    { 0x5353, "get_anim_model_root" },
    { 0x5354, "get_anim_position" },
    { 0x5355, "get_animated_player_death" },
    { 0x5356, "get_animation" },
    { 0x5357, "get_animation_from_alias" },
    { 0x5358, "get_any_speaking_vo_source" },
    { 0x5359, "get_any_vo_source_is_speaking" },
    { 0x535A, "get_aq_for_shootout_anim" },
    { 0x535B, "get_area" },
    { 0x535C, "get_area_for_power" },
    { 0x535D, "get_array_of_closest" },
    { 0x535E, "get_array_of_farthest" },
    { 0x535F, "get_array_of_living_allies_by_color" },
    { 0x5360, "get_array_of_valid_players" },
    { 0x5361, "get_array_of_valid_spawnpoints" },
    { 0x5362, "get_array_rule_token_value" },
    { 0x5363, "get_arrival_anim" },
    { 0x5364, "get_arrivalstate_from_interaction" },
    { 0x5365, "get_at_goalpos" },
    { 0x5366, "get_attachment_from_interaction" },
    { 0x5367, "get_attachment_mod_damage_data" },
    { 0x5368, "get_attacker_as_player" },
    { 0x5369, "get_available_bomb_detonator_id" },
    { 0x536A, "get_available_players" },
    { 0x536B, "get_available_respawn_locs" },
    { 0x536C, "get_available_slot_index_for_team_id" },
    { 0x536D, "get_availablepositions" },
    { 0x536E, "get_average_origin" },
    { 0x536F, "get_away_from_target_entity_monitor" },
    { 0x5370, "get_badcountryidstr" },
    { 0x5371, "get_barrels" },
    { 0x5372, "get_base_weapon_name" },
    { 0x5373, "get_baseweapon_pap_level" },
    { 0x5374, "get_bash_yaw" },
    { 0x5375, "get_bb_string" },
    { 0x5376, "get_best_area_attack_node" },
    { 0x5377, "get_best_available_colored_node" },
    { 0x5378, "get_best_available_new_colored_node" },
    { 0x5379, "get_best_civ_node" },
    { 0x537A, "get_best_end_point" },
    { 0x537B, "get_best_goto_node" },
    { 0x537C, "get_best_hover_point" },
    { 0x537D, "get_best_node_at_fork" },
    { 0x537E, "get_best_scoring_target" },
    { 0x537F, "get_best_weapons" },
    { 0x5380, "get_bestdrone" },
    { 0x5381, "get_bit_position" },
    { 0x5382, "get_bleed_out_time" },
    { 0x5383, "get_bomb_id_vfx" },
    { 0x5384, "get_bomb_serial_number_based_on_bomb_id" },
    { 0x5385, "get_bot_defusing_zone" },
    { 0x5386, "get_bot_planting_zone" },
    { 0x5387, "get_bots_defending_flag" },
    { 0x5388, "get_bots_using_zone" },
    { 0x5389, "get_bridge_start_struct" },
    { 0x538A, "get_brushmodel_dependencies" },
    { 0x538B, "get_buddy_down_gunner_animnode" },
    { 0x538C, "get_building_def_time" },
    { 0x538D, "get_building_loc" },
    { 0x538E, "get_building_support_time" },
    { 0x538F, "get_cache_num" },
    { 0x5390, "get_camera_control_up_offset" },
    { 0x5391, "get_camera_dist_per_frame" },
    { 0x5392, "get_camera_final_pos" },
    { 0x5393, "get_camera_pos_relative_to_bullet_pos" },
    { 0x5394, "get_camera_reset_point" },
    { 0x5395, "get_camera_spawn_point" },
    { 0x5396, "get_car_type" },
    { 0x5397, "get_card_deck_size" },
    { 0x5398, "get_cart_incline" },
    { 0x5399, "get_categories_from_alias" },
    { 0x539A, "get_cell_chair" },
    { 0x539B, "get_center_of_array" },
    { 0x539C, "get_center_point" },
    { 0x539D, "get_center_point_of_array" },
    { 0x539E, "get_character_bit_value" },
    { 0x539F, "get_chatter_item_index" },
    { 0x53A0, "get_civ_cower_anim" },
    { 0x53A1, "get_close_distance_var" },
    { 0x53A2, "get_closed_door_closest_to_nav_modifier" },
    { 0x53A3, "get_closer_track" },
    { 0x53A4, "get_closest_actor" },
    { 0x53A5, "get_closest_ai" },
    { 0x53A6, "get_closest_ai_exclude" },
    { 0x53A7, "get_closest_alive_enemy" },
    { 0x53A8, "get_closest_alive_player" },
    { 0x53A9, "get_closest_aq" },
    { 0x53AA, "get_closest_available_player" },
    { 0x53AB, "get_closest_bomber_target" },
    { 0x53AC, "get_closest_car_in_front_of_player" },
    { 0x53AD, "get_closest_civ" },
    { 0x53AE, "get_closest_colored_friendly" },
    { 0x53AF, "get_closest_colored_friendly_with_classname" },
    { 0x53B0, "get_closest_enemy_to_hadir" },
    { 0x53B1, "get_closest_entrance" },
    { 0x53B2, "get_closest_exclude" },
    { 0x53B3, "get_closest_flag" },
    { 0x53B4, "get_closest_guy_by_path" },
    { 0x53B5, "get_closest_heli_entrance" },
    { 0x53B6, "get_closest_ied_triggering_tag" },
    { 0x53B7, "get_closest_in_front" },
    { 0x53B8, "get_closest_index" },
    { 0x53B9, "get_closest_index_to_player_view" },
    { 0x53BA, "get_closest_living" },
    { 0x53BB, "get_closest_living_ai" },
    { 0x53BC, "get_closest_living_player" },
    { 0x53BD, "get_closest_look_at_interact" },
    { 0x53BE, "get_closest_ls_entrance" },
    { 0x53BF, "get_closest_male_redshirt" },
    { 0x53C0, "get_closest_marine" },
    { 0x53C1, "get_closest_marine_no_vo" },
    { 0x53C2, "get_closest_on_path" },
    { 0x53C3, "get_closest_pa_object" },
    { 0x53C4, "get_closest_respawner_on_direction" },
    { 0x53C5, "get_closest_speaker" },
    { 0x53C6, "get_closest_squad_guy" },
    { 0x53C7, "get_closest_tank_targets" },
    { 0x53C8, "get_closest_to_player_view" },
    { 0x53C9, "get_closest_unhunted_player" },
    { 0x53CA, "get_closest_vehicle_door_available" },
    { 0x53CB, "get_closest_vehicle_in_convoy" },
    { 0x53CC, "get_closest_vehicle_within_range" },
    { 0x53CD, "get_closet_alive_player" },
    { 0x53CE, "get_color_from_order" },
    { 0x53CF, "get_color_info_from_trigger" },
    { 0x53D0, "get_color_list" },
    { 0x53D1, "get_color_nodes_from_trigger" },
    { 0x53D2, "get_color_spawner" },
    { 0x53D3, "get_color_volume_from_trigger" },
    { 0x53D4, "get_colorcoded_volume" },
    { 0x53D5, "get_colorcodes" },
    { 0x53D6, "get_colorcodes_and_activate_trigger" },
    { 0x53D7, "get_colorcodes_from_trigger" },
    { 0x53D8, "get_colortable" },
    { 0x53D9, "get_combat_volume_targetname" },
    { 0x53DA, "get_comp_count" },
    { 0x53DB, "get_consumable_index_in_player_data" },
    { 0x53DC, "get_consumable_loot_id" },
    { 0x53DD, "get_convoy_target" },
    { 0x53DE, "get_convoy_targeted_hvt" },
    { 0x53DF, "get_cop_barriers" },
    { 0x53E0, "get_corpse_origin" },
    { 0x53E1, "get_countdown_hud" },
    { 0x53E2, "get_country_prefix" },
    { 0x53E3, "get_cover_volume_forward" },
    { 0x53E4, "get_createfx_array" },
    { 0x53E5, "get_createfx_exploders" },
    { 0x53E6, "get_createfx_types" },
    { 0x53E7, "get_cumulative_weights" },
    { 0x53E8, "get_curfloor" },
    { 0x53E9, "get_currency_penalty_amount" },
    { 0x53EA, "get_current_exterior_path" },
    { 0x53EB, "get_current_fov" },
    { 0x53EC, "get_current_house_room" },
    { 0x53ED, "get_current_menu_name" },
    { 0x53EE, "get_current_spawn_score_player_index" },
    { 0x53EF, "get_current_state" },
    { 0x53F0, "get_current_stealth_state" },
    { 0x53F1, "get_current_vo_alias" },
    { 0x53F2, "get_current_wave_ref" },
    { 0x53F3, "get_current_weapon" },
    { 0x53F4, "get_current_zone" },
    { 0x53F5, "get_cursorhintent" },
    { 0x53F6, "get_custom_gl_projectile" },
    { 0x53F7, "get_damage_direction" },
    { 0x53F8, "get_damage_from_grey" },
    { 0x53F9, "get_damageable_grenade" },
    { 0x53FA, "get_damageable_grenade_pos" },
    { 0x53FB, "get_damageable_mine" },
    { 0x53FC, "get_damageable_player" },
    { 0x53FD, "get_damageable_player_pos" },
    { 0x53FE, "get_damageable_sentry" },
    { 0x53FF, "get_data_to_update" },
    { 0x5400, "get_datascene" },
    { 0x5401, "get_death_anim" },
    { 0x5402, "get_death_callback" },
    { 0x5403, "get_default_num_equipment_charges" },
    { 0x5404, "get_defined_value" },
    { 0x5405, "get_desired_bodyguard_vehicle_angle" },
    { 0x5406, "get_desired_direction_based_on_input" },
    { 0x5407, "get_desried_camera_pos" },
    { 0x5408, "get_destructible_heli_target" },
    { 0x5409, "get_detect_range" },
    { 0x540A, "get_different_player" },
    { 0x540B, "get_difficultysetting" },
    { 0x540C, "get_difficultysetting_frac" },
    { 0x540D, "get_difficultysetting_global" },
    { 0x540E, "get_direction_override" },
    { 0x540F, "get_direction_value" },
    { 0x5410, "get_dist_on_segment" },
    { 0x5411, "get_door_angles" },
    { 0x5412, "get_door_anim_from_ai_anim" },
    { 0x5413, "get_door_audio_material" },
    { 0x5414, "get_door_bottom_center" },
    { 0x5415, "get_door_bottom_handle" },
    { 0x5416, "get_door_bottom_origin" },
    { 0x5417, "get_door_center" },
    { 0x5418, "get_door_dependencies" },
    { 0x5419, "get_door_targetname" },
    { 0x541A, "get_dot" },
    { 0x541B, "get_dot_by_direction" },
    { 0x541C, "get_double_door_mid_point" },
    { 0x541D, "get_doublejumpenergy" },
    { 0x541E, "get_doublejumpenergyrestorerate" },
    { 0x541F, "get_download_state_hud" },
    { 0x5420, "get_drones_touching_volume" },
    { 0x5421, "get_drones_with_targetname" },
    { 0x5422, "get_drop_item_func" },
    { 0x5423, "get_dummy_flares" },
    { 0x5424, "get_duration_between_points" },
    { 0x5425, "get_dyndof_contents" },
    { 0x5426, "get_either_nags" },
    { 0x5427, "get_emp_damage_callback" },
    { 0x5428, "get_emp_ents" },
    { 0x5429, "get_empty_munition_slot" },
    { 0x542A, "get_end_condition" },
    { 0x542B, "get_end_door_state" },
    { 0x542C, "get_end_game_string_index" },
    { 0x542D, "get_enemies_in_range" },
    { 0x542E, "get_enemies_to_advance_on_players" },
    { 0x542F, "get_enemy_flags" },
    { 0x5430, "get_enemy_group_randomized" },
    { 0x5431, "get_enemy_info_all" },
    { 0x5432, "get_enemy_info_loop" },
    { 0x5433, "get_enemy_left_max_spawn" },
    { 0x5434, "get_enemy_right_max_spawn" },
    { 0x5435, "get_enemy_rpg_max_spawn" },
    { 0x5436, "get_enemy_sniper_max_spawn" },
    { 0x5437, "get_enemy_team" },
    { 0x5438, "get_enemy_vanguard" },
    { 0x5439, "get_entity_count_list" },
    { 0x543A, "get_entrance_pos" },
    { 0x543B, "get_eog_tracking_idx" },
    { 0x543C, "get_equipment_ammo" },
    { 0x543D, "get_escalation_aliases" },
    { 0x543E, "get_escalation_counter" },
    { 0x543F, "get_event_location" },
    { 0x5440, "get_event_xp_base_value" },
    { 0x5441, "get_event_xp_multiplier_value" },
    { 0x5442, "get_exit_anim" },
    { 0x5443, "get_exit_base_interaction_point" },
    { 0x5444, "get_exit_direction_vector" },
    { 0x5445, "get_exit_route" },
    { 0x5446, "get_exit_vehicle_teleport_to_loc" },
    { 0x5447, "get_exitstate_from_interaction" },
    { 0x5448, "get_exploder_array" },
    { 0x5449, "get_exploder_array_proc" },
    { 0x544A, "get_exploders" },
    { 0x544B, "get_explosive_damage_on_player" },
    { 0x544C, "get_extended_path" },
    { 0x544D, "get_extraction_cooldown" },
    { 0x544E, "get_fact_value_from_context" },
    { 0x544F, "get_fake_attacker_struct" },
    { 0x5450, "get_fake_slerped_angles" },
    { 0x5451, "get_fakeactors" },
    { 0x5452, "get_false_positive_dots_within_scan_range" },
    { 0x5453, "get_far_away_startpath" },
    { 0x5454, "get_farthest_ent" },
    { 0x5455, "get_farthest_living_ai" },
    { 0x5456, "get_final_fly_segment_camera_end_pos" },
    { 0x5457, "get_final_hvt_location" },
    { 0x5458, "get_fire_damage_vfx" },
    { 0x5459, "get_first_living_in_array" },
    { 0x545A, "get_first_vehicle_in_convoy" },
    { 0x545B, "get_flag_capture_radius" },
    { 0x545C, "get_flag_label" },
    { 0x545D, "get_flag_protect_radius" },
    { 0x545E, "get_flare_launch_entrance" },
    { 0x545F, "get_flashed_anim" },
    { 0x5460, "get_flight_path" },
    { 0x5461, "get_flight_path_down" },
    { 0x5462, "get_flight_path_up" },
    { 0x5463, "get_floor" },
    { 0x5464, "get_follow_anim_from_breach_anim" },
    { 0x5465, "get_force_color" },
    { 0x5466, "get_force_color_guys" },
    { 0x5467, "get_forward_scalar" },
    { 0x5468, "get_friendly_convoy_vehicle_behind" },
    { 0x5469, "get_friendly_hvi_vehicle_info" },
    { 0x546A, "get_from_entity" },
    { 0x546B, "get_from_spawnstruct" },
    { 0x546C, "get_from_vehicle_node" },
    { 0x546D, "get_fullrank_by_id" },
    { 0x546E, "get_func_by_name" },
    { 0x546F, "get_fx_direction" },
    { 0x5470, "get_fx_ticket" },
    { 0x5471, "get_gamemode_subdir" },
    { 0x5472, "get_gameskill" },
    { 0x5473, "get_gameskill_as_string" },
    { 0x5474, "get_garage_milk_crate" },
    { 0x5475, "get_gender" },
    { 0x5476, "get_generic_anime" },
    { 0x5477, "get_gesture" },
    { 0x5478, "get_gesture_alias" },
    { 0x5479, "get_globalthreat_timer_paused" },
    { 0x547A, "get_goalpos" },
    { 0x547B, "get_goto_nodes" },
    { 0x547C, "get_grenade_cast_contents" },
    { 0x547D, "get_grenade_from_struct" },
    { 0x547E, "get_ground_slope_angles" },
    { 0x547F, "get_group" },
    { 0x5480, "get_group_flagname" },
    { 0x5481, "get_gun_game_weapon_at_level" },
    { 0x5482, "get_gun_nags" },
    { 0x5483, "get_gun_vo" },
    { 0x5484, "get_gunner" },
    { 0x5485, "get_guys_in_stealthgroups" },
    { 0x5486, "get_hadir_gas_escape_nag" },
    { 0x5487, "get_has_seen_tutorial" },
    { 0x5488, "get_height_offset" },
    { 0x5489, "get_heli_spawn_struct" },
    { 0x548A, "get_heli_target" },
    { 0x548B, "get_helicopter_path_positions" },
    { 0x548C, "get_hellfire_killcount" },
    { 0x548D, "get_hide_to_aim_anim" },
    { 0x548E, "get_highest_dot" },
    { 0x548F, "get_him_farah" },
    { 0x5490, "get_hint_dist" },
    { 0x5491, "get_hint_timer" },
    { 0x5492, "get_hit_damage" },
    { 0x5493, "get_hives_destroyed_stat" },
    { 0x5494, "get_hostage_drop_pos" },
    { 0x5495, "get_housing_children" },
    { 0x5496, "get_housing_closedpos" },
    { 0x5497, "get_housing_door_trigger" },
    { 0x5498, "get_housing_inside_trigger" },
    { 0x5499, "get_housing_leftdoor" },
    { 0x549A, "get_housing_leftdoor_opened_pos" },
    { 0x549B, "get_housing_mainframe" },
    { 0x549C, "get_housing_models" },
    { 0x549D, "get_housing_musak_model" },
    { 0x549E, "get_housing_primarylight" },
    { 0x549F, "get_housing_rightdoor" },
    { 0x54A0, "get_housing_rightdoor_opened_pos" },
    { 0x54A1, "get_hudoutline_for_player_health" },
    { 0x54A2, "get_hudoutline_item" },
    { 0x54A3, "get_human_player" },
    { 0x54A4, "get_humvee_info" },
    { 0x54A5, "get_icon_by_id" },
    { 0x54A6, "get_ideal_dist" },
    { 0x54A7, "get_ideal_heli_spot" },
    { 0x54A8, "get_idle_anim" },
    { 0x54A9, "get_idle_scene" },
    { 0x54AA, "get_idlestate_from_interaction" },
    { 0x54AB, "get_ignoreme" },
    { 0x54AC, "get_in_danger" },
    { 0x54AD, "get_in_moving_vehicle" },
    { 0x54AE, "get_in_there_nags" },
    { 0x54AF, "get_in_vehicle" },
    { 0x54B0, "get_infil_rider_start_targetname" },
    { 0x54B1, "get_info_for_player_powers" },
    { 0x54B2, "get_ingamerank_by_id" },
    { 0x54B3, "get_init_func" },
    { 0x54B4, "get_initfloor" },
    { 0x54B5, "get_int_or_0" },
    { 0x54B6, "get_intel_loc" },
    { 0x54B7, "get_intel_omnvar" },
    { 0x54B8, "get_intel_weapon_hold_time" },
    { 0x54B9, "get_interact_vehicle" },
    { 0x54BA, "get_interact_vehicle_array" },
    { 0x54BB, "get_interaction" },
    { 0x54BC, "get_interaction_actor_lookatidle" },
    { 0x54BD, "get_interaction_actor_optionalstruct" },
    { 0x54BE, "get_interaction_cost" },
    { 0x54BF, "get_interaction_hintstring" },
    { 0x54C0, "get_interaction_origin" },
    { 0x54C1, "get_interaction_sound" },
    { 0x54C2, "get_interaction_starting_idle" },
    { 0x54C3, "get_interaction_vo_line" },
    { 0x54C4, "get_interaction_vo_line_array" },
    { 0x54C5, "get_interactive_door" },
    { 0x54C6, "get_interactive_door_array" },
    { 0x54C7, "get_interrogate_anim_priority" },
    { 0x54C8, "get_intro_cars" },
    { 0x54C9, "get_investigate_loc" },
    { 0x54CA, "get_investigate_point_in_oil_fire" },
    { 0x54CB, "get_is_looking_at" },
    { 0x54CC, "get_is_vehicle_right_before_player_vehicle" },
    { 0x54CD, "get_jammer_mdl" },
    { 0x54CE, "get_jugg_minpaindamage" },
    { 0x54CF, "get_killoff_time" },
    { 0x54D0, "get_ladder_struct" },
    { 0x54D1, "get_laser_end_loc" },
    { 0x54D2, "get_laser_end_pos" },
    { 0x54D3, "get_last_anim_frame" },
    { 0x54D4, "get_last_anim_name" },
    { 0x54D5, "get_last_ent_in_chain" },
    { 0x54D6, "get_last_none_player_vehicle_in_convoy" },
    { 0x54D7, "get_last_selected_ent" },
    { 0x54D8, "get_last_spawn_time" },
    { 0x54D9, "get_last_stand_count" },
    { 0x54DA, "get_last_stand_pistol" },
    { 0x54DB, "get_lastentinspline" },
    { 0x54DC, "get_lastentinsplinefunction" },
    { 0x54DD, "get_lb_escape_rank" },
    { 0x54DE, "get_leads_type" },
    { 0x54DF, "get_least_used_from_array" },
    { 0x54E0, "get_least_used_index" },
    { 0x54E1, "get_least_used_model" },
    { 0x54E2, "get_left_vindia_infil_rider_start_targetname" },
    { 0x54E3, "get_lerped_origin" },
    { 0x54E4, "get_level_by_id" },
    { 0x54E5, "get_level_xp_scale" },
    { 0x54E6, "get_light_and_linkto" },
    { 0x54E7, "get_lightswitch_fx_tag" },
    { 0x54E8, "get_line_from_landmark" },
    { 0x54E9, "get_line_to_play" },
    { 0x54EA, "get_linked_ent" },
    { 0x54EB, "get_linked_ents" },
    { 0x54EC, "get_linked_nodes" },
    { 0x54ED, "get_linked_points" },
    { 0x54EE, "get_linked_scriptables" },
    { 0x54EF, "get_linked_spawners" },
    { 0x54F0, "get_linked_struct" },
    { 0x54F1, "get_linked_structs" },
    { 0x54F2, "get_linked_vehicle_node" },
    { 0x54F3, "get_linked_vehicle_nodes" },
    { 0x54F4, "get_linked_vehicle_spawners" },
    { 0x54F5, "get_linked_vehicles" },
    { 0x54F6, "get_linkedentitiesinspline" },
    { 0x54F7, "get_links" },
    { 0x54F8, "get_linkto_goals" },
    { 0x54F9, "get_linkto_structs_return_to_array" },
    { 0x54FA, "get_living_ai" },
    { 0x54FB, "get_living_ai_array" },
    { 0x54FC, "get_living_aispecies" },
    { 0x54FD, "get_living_aispecies_array" },
    { 0x54FE, "get_living_players_on_team" },
    { 0x54FF, "get_load_trigger_classes" },
    { 0x5500, "get_load_trigger_funcs" },
    { 0x5501, "get_locked_on_cruise_missile_to_intercept" },
    { 0x5502, "get_longest_anim_ent" },
    { 0x5503, "get_longest_animating_ent" },
    { 0x5504, "get_lookat_angles" },
    { 0x5505, "get_ls_entrance" },
    { 0x5506, "get_main_road_targetname" },
    { 0x5507, "get_main_turret" },
    { 0x5508, "get_mapped_lb_ref_from_eog_ref" },
    { 0x5509, "get_mark_target_array" },
    { 0x550A, "get_mark_ui_duration" },
    { 0x550B, "get_mask_anim_node" },
    { 0x550C, "get_mask_nags" },
    { 0x550D, "get_mask_remove_fov_user_scale" },
    { 0x550E, "get_mask_vo" },
    { 0x550F, "get_max_agent_count" },
    { 0x5510, "get_max_escalation_decay_rate" },
    { 0x5511, "get_max_escalation_decay_start" },
    { 0x5512, "get_max_escalation_level" },
    { 0x5513, "get_max_meter" },
    { 0x5514, "get_max_num_defenders_wanted_per_flag" },
    { 0x5515, "get_max_weapon_rank" },
    { 0x5516, "get_max_weapon_rank_for_root_weapon" },
    { 0x5517, "get_max_yaw" },
    { 0x5518, "get_max_yaw_internal" },
    { 0x5519, "get_max_yaws" },
    { 0x551A, "get_maxxp_by_id" },
    { 0x551B, "get_melee_contents" },
    { 0x551C, "get_melee_sight_contents" },
    { 0x551D, "get_melee_weapon" },
    { 0x551E, "get_melee_weapon_fov" },
    { 0x551F, "get_melee_weapon_hit_distance" },
    { 0x5520, "get_melee_weapon_max_enemies" },
    { 0x5521, "get_melee_weapon_melee_damage" },
    { 0x5522, "get_mid_point" },
    { 0x5523, "get_min_escalation_level" },
    { 0x5524, "get_min_time_to_point" },
    { 0x5525, "get_mindia_infil_rider_start_targetname" },
    { 0x5526, "get_mine_ignore_list" },
    { 0x5527, "get_minutes_and_seconds" },
    { 0x5528, "get_minxp_by_id" },
    { 0x5529, "get_missile_defense_player" },
    { 0x552A, "get_mod_damage" },
    { 0x552B, "get_mod_damage_modifier" },
    { 0x552C, "get_model_dependencies" },
    { 0x552D, "get_model_for_color_wire" },
    { 0x552E, "get_model_trace_start" },
    { 0x552F, "get_module_debug_data" },
    { 0x5530, "get_module_spawn_points" },
    { 0x5531, "get_module_structs_by_groupname" },
    { 0x5532, "get_mortar_group_randomized" },
    { 0x5533, "get_mortar_impact_pos" },
    { 0x5534, "get_mortar_impact_spot" },
    { 0x5535, "get_most_recent_dmg_or_death_time" },
    { 0x5536, "get_mount_activation_mode" },
    { 0x5537, "get_move_direction_from_vectors" },
    { 0x5538, "get_movement_anim" },
    { 0x5539, "get_mover_ents" },
    { 0x553A, "get_mph_speed" },
    { 0x553B, "get_munition" },
    { 0x553C, "get_my_node" },
    { 0x553D, "get_my_spline_node" },
    { 0x553E, "get_nag" },
    { 0x553F, "get_name" },
    { 0x5540, "get_name_for_nationality" },
    { 0x5541, "get_near_vehicle_spawner" },
    { 0x5542, "get_nearby_enemy" },
    { 0x5543, "get_nearby_players" },
    { 0x5544, "get_nearby_respawners" },
    { 0x5545, "get_nearby_vehicles" },
    { 0x5546, "get_nearest_free_color_node" },
    { 0x5547, "get_nerf_scalar" },
    { 0x5548, "get_nervous" },
    { 0x5549, "get_new_camera_anchor_pos" },
    { 0x554A, "get_new_intel_dropper" },
    { 0x554B, "get_new_random_wire_color_except" },
    { 0x554C, "get_new_vehicle_speed" },
    { 0x554D, "get_new_wire_currently_looking_at" },
    { 0x554E, "get_next" },
    { 0x554F, "get_next_alias_in_group" },
    { 0x5550, "get_next_anim" },
    { 0x5551, "get_next_closest_path_id" },
    { 0x5552, "get_next_empty_slot" },
    { 0x5553, "get_next_free_num" },
    { 0x5554, "get_next_node_array" },
    { 0x5555, "get_next_node_on_spline" },
    { 0x5556, "get_next_origin" },
    { 0x5557, "get_next_player_index" },
    { 0x5558, "get_next_point_in_chain" },
    { 0x5559, "get_next_struct" },
    { 0x555A, "get_next_volume_origin" },
    { 0x555B, "get_nexttargetedpathgoal" },
    { 0x555C, "get_nextxp_by_id" },
    { 0x555D, "get_nice_text_elem" },
    { 0x555E, "get_nitrate_label" },
    { 0x555F, "get_node_or_struct" },
    { 0x5560, "get_node_type_from_type" },
    { 0x5561, "get_normal_anim_time" },
    { 0x5562, "get_normal_revive_time" },
    { 0x5563, "get_notetrack_movement" },
    { 0x5564, "get_notetrack_time" },
    { 0x5565, "get_noteworthy_array" },
    { 0x5566, "get_noteworthy_ent" },
    { 0x5567, "get_num_ai_capturing_headquarters" },
    { 0x5568, "get_num_allies_capturing_flag" },
    { 0x5569, "get_num_allies_getting_tag" },
    { 0x556A, "get_num_ally_flags" },
    { 0x556B, "get_num_ambient" },
    { 0x556C, "get_num_nerf_selected" },
    { 0x556D, "get_num_of_alive_riders" },
    { 0x556E, "get_num_of_charges_for_power" },
    { 0x556F, "get_num_of_ied_to_spawn" },
    { 0x5570, "get_num_of_player_touching_volume" },
    { 0x5571, "get_num_of_segments" },
    { 0x5572, "get_num_players_on_team" },
    { 0x5573, "get_num_spots_taken_at_higher_priority" },
    { 0x5574, "get_number_of_last_stand_clips" },
    { 0x5575, "get_nums_from_origins" },
    { 0x5576, "get_nvg_bar_level" },
    { 0x5577, "get_object" },
    { 0x5578, "get_object_array" },
    { 0x5579, "get_objective_slot" },
    { 0x557A, "get_objective_struct" },
    { 0x557B, "get_objective_type" },
    { 0x557C, "get_off_tank_path" },
    { 0x557D, "get_offhand_box_item_slot_struct" },
    { 0x557E, "get_offhand_item_model" },
    { 0x557F, "get_offhand_item_pickup_hint" },
    { 0x5580, "get_oldest_item_at_priority" },
    { 0x5581, "get_omnvar_value_based_on_color" },
    { 0x5582, "get_on_north_roof_nag" },
    { 0x5583, "get_opposite_door" },
    { 0x5584, "get_option" },
    { 0x5585, "get_optional_overlay" },
    { 0x5586, "get_origin_offset_decho_dirty" },
    { 0x5587, "get_origin_offset_decho_rebel" },
    { 0x5588, "get_other_blocker_vehicles_in_front" },
    { 0x5589, "get_other_bodyguard_vehicles_in_front" },
    { 0x558A, "get_other_flag" },
    { 0x558B, "get_out_override" },
    { 0x558C, "get_outer_closedpos" },
    { 0x558D, "get_outer_doorset" },
    { 0x558E, "get_outer_doorsets" },
    { 0x558F, "get_outer_leftdoor" },
    { 0x5590, "get_outer_leftdoor_openedpos" },
    { 0x5591, "get_outer_reticle_targets" },
    { 0x5592, "get_outer_rightdoor" },
    { 0x5593, "get_outer_rightdoor_openedpos" },
    { 0x5594, "get_outside_range" },
    { 0x5595, "get_overheat_org" },
    { 0x5596, "get_overlay" },
    { 0x5597, "get_override_flag_targets" },
    { 0x5598, "get_override_zone_targets" },
    { 0x5599, "get_overwatch_camera_zoom_max_delta" },
    { 0x559A, "get_p1_intel_group_spawner" },
    { 0x559B, "get_pacifist" },
    { 0x559C, "get_pain_anim" },
    { 0x559D, "get_pain_breathing_sfx_alias" },
    { 0x559E, "get_painter_groups" },
    { 0x559F, "get_pap_camo" },
    { 0x55A0, "get_parachute_path" },
    { 0x55A1, "get_passive_spawn_window_time" },
    { 0x55A2, "get_passive_wave_high_threshold" },
    { 0x55A3, "get_passive_wave_low_threshold" },
    { 0x55A4, "get_passive_wave_spawn_time" },
    { 0x55A5, "get_path_array" },
    { 0x55A6, "get_path_choice_entering_farm" },
    { 0x55A7, "get_path_choice_entering_lumber" },
    { 0x55A8, "get_path_dist_sq" },
    { 0x55A9, "get_path_end_node" },
    { 0x55AA, "get_path_getfunc" },
    { 0x55AB, "get_path_over_players" },
    { 0x55AC, "get_path_points" },
    { 0x55AD, "get_path_start_node_array" },
    { 0x55AE, "get_patharray" },
    { 0x55AF, "get_patrol_react_magnitude_int" },
    { 0x55B0, "get_patrol_style" },
    { 0x55B1, "get_patrol_style_default" },
    { 0x55B2, "get_perk" },
    { 0x55B3, "get_perk_machine_cost" },
    { 0x55B4, "get_perk_mod_damage_data" },
    { 0x55B5, "get_phase_anim" },
    { 0x55B6, "get_phraseinvalidstr" },
    { 0x55B7, "get_picc_civ_spawner" },
    { 0x55B8, "get_pilot_exfil" },
    { 0x55B9, "get_play_time" },
    { 0x55BA, "get_player" },
    { 0x55BB, "get_player_armor_amount" },
    { 0x55BC, "get_player_at_spot" },
    { 0x55BD, "get_player_body" },
    { 0x55BE, "get_player_character_num" },
    { 0x55BF, "get_player_class" },
    { 0x55C0, "get_player_controller_direction_in_world" },
    { 0x55C1, "get_player_currency" },
    { 0x55C2, "get_player_deaths" },
    { 0x55C3, "get_player_demeanor" },
    { 0x55C4, "get_player_encounter_performance" },
    { 0x55C5, "get_player_expose_time_to_sniper" },
    { 0x55C6, "get_player_feet_from_view" },
    { 0x55C7, "get_player_from_self" },
    { 0x55C8, "get_player_gameskill" },
    { 0x55C9, "get_player_gun_game_level" },
    { 0x55CA, "get_player_health_after_revived_func" },
    { 0x55CB, "get_player_interaction_trigger" },
    { 0x55CC, "get_player_legs" },
    { 0x55CD, "get_player_looking_at_interact_dot" },
    { 0x55CE, "get_player_matchdata" },
    { 0x55CF, "get_player_max_currency" },
    { 0x55D0, "get_player_offhand_ammo" },
    { 0x55D1, "get_player_offhand_max_ammo" },
    { 0x55D2, "get_player_offhand_weapon" },
    { 0x55D3, "get_player_on_right" },
    { 0x55D4, "get_player_past_loc" },
    { 0x55D5, "get_player_pistol_data" },
    { 0x55D6, "get_player_prestige" },
    { 0x55D7, "get_player_progress_flag_to_set" },
    { 0x55D8, "get_player_progress_toward_self" },
    { 0x55D9, "get_player_rank" },
    { 0x55DA, "get_player_rig" },
    { 0x55DB, "get_player_seat_org" },
    { 0x55DC, "get_player_session_rankup" },
    { 0x55DD, "get_player_session_tokens" },
    { 0x55DE, "get_player_session_xp" },
    { 0x55DF, "get_player_side_spawn_group_randomized" },
    { 0x55E0, "get_player_target_score" },
    { 0x55E1, "get_player_target_score_for_sniper" },
    { 0x55E2, "get_player_view_controller" },
    { 0x55E3, "get_player_weapon_rank_cp_xp" },
    { 0x55E4, "get_player_weapon_rank_mp_xp" },
    { 0x55E5, "get_player_weapon_xp_scalar" },
    { 0x55E6, "get_player_weapons" },
    { 0x55E7, "get_player_with_player_id" },
    { 0x55E8, "get_player_xp" },
    { 0x55E9, "get_players_by_role" },
    { 0x55EA, "get_players_defending_flag" },
    { 0x55EB, "get_players_defending_zone" },
    { 0x55EC, "get_players_groups_by_whether_in_killzone" },
    { 0x55ED, "get_players_in_area" },
    { 0x55EE, "get_players_in_killzone" },
    { 0x55EF, "get_players_not_in_laststand" },
    { 0x55F0, "get_players_on_rooftop" },
    { 0x55F1, "get_players_watching" },
    { 0x55F2, "get_poi_total_time" },
    { 0x55F3, "get_point_in_local_ent_space" },
    { 0x55F4, "get_point_on_parabola" },
    { 0x55F5, "get_point_on_struct_target" },
    { 0x55F6, "get_poppies_nags" },
    { 0x55F7, "get_portable_mg_spot" },
    { 0x55F8, "get_position_from_actor" },
    { 0x55F9, "get_possible_attachments_by_weaponclass" },
    { 0x55FA, "get_post_mod_damage_callback" },
    { 0x55FB, "get_potential_hero_players_as_target" },
    { 0x55FC, "get_pre_mod_damage_callback" },
    { 0x55FD, "get_pre_respawn_group_wait" },
    { 0x55FE, "get_prefab_base_ent" },
    { 0x55FF, "get_prev_struct" },
    { 0x5600, "get_primary_equipment" },
    { 0x5601, "get_primary_equipment_ammo" },
    { 0x5602, "get_print3d_text" },
    { 0x5603, "get_prioritized_colorcoded_nodes" },
    { 0x5604, "get_progress" },
    { 0x5605, "get_proper_zoom_weapon" },
    { 0x5606, "get_proto_convoy_event" },
    { 0x5607, "get_proto_convoy_type" },
    { 0x5608, "get_prototype_scriptable_map" },
    { 0x5609, "get_pushent" },
    { 0x560A, "get_queue_max_entries" },
    { 0x560B, "get_radio_alias" },
    { 0x560C, "get_radius" },
    { 0x560D, "get_random_array_element_no_repeat" },
    { 0x560E, "get_random_attachments" },
    { 0x560F, "get_random_available_air_ai_infil" },
    { 0x5610, "get_random_available_ground_ai_infil" },
    { 0x5611, "get_random_character" },
    { 0x5612, "get_random_civilian_speed" },
    { 0x5613, "get_random_line" },
    { 0x5614, "get_random_outside_target" },
    { 0x5615, "get_random_pos" },
    { 0x5616, "get_random_rider_model" },
    { 0x5617, "get_random_spawner" },
    { 0x5618, "get_random_spawner_type" },
    { 0x5619, "get_random_spec" },
    { 0x561A, "get_random_spot" },
    { 0x561B, "get_random_spot_in_infil" },
    { 0x561C, "get_random_value_in_segment" },
    { 0x561D, "get_random_weapon" },
    { 0x561E, "get_random_wire_color" },
    { 0x561F, "get_randomized_group" },
    { 0x5620, "get_randomized_rpg_group_name" },
    { 0x5621, "get_randomly_weighted_character" },
    { 0x5622, "get_rank_by_xp" },
    { 0x5623, "get_rank_xp_for_bot" },
    { 0x5624, "get_raw_or_devraw_subdir" },
    { 0x5625, "get_react_type" },
    { 0x5626, "get_reactive_sound_ent" },
    { 0x5627, "get_reaper_player_look_at_ground_pos" },
    { 0x5628, "get_rebel_spawn_struct" },
    { 0x5629, "get_ref_by_id" },
    { 0x562A, "get_reload_anim" },
    { 0x562B, "get_repair_interaction_point_name" },
    { 0x562C, "get_replaceable_weapon" },
    { 0x562D, "get_requested_spawn_count" },
    { 0x562E, "get_reserved_slot_count_by_string_id" },
    { 0x562F, "get_respawn_cooldown" },
    { 0x5630, "get_respawn_loc_near_team_center" },
    { 0x5631, "get_respawn_loc_rated" },
    { 0x5632, "get_respawners_in_desired_direction" },
    { 0x5633, "get_revive_gesture" },
    { 0x5634, "get_revive_icon_initial_alpha" },
    { 0x5635, "get_revive_result" },
    { 0x5636, "get_revolver_reminders" },
    { 0x5637, "get_reward_point_for_kill" },
    { 0x5638, "get_rid_of_guys_blocking_path" },
    { 0x5639, "get_rider_animation" },
    { 0x563A, "get_rider_initial_target" },
    { 0x563B, "get_right_vindia_infil_rider_start_targetname" },
    { 0x563C, "get_role_munition" },
    { 0x563D, "get_rotation_anchor_move_speed" },
    { 0x563E, "get_round_end_time" },
    { 0x563F, "get_rpg_fire_duration_limit" },
    { 0x5640, "get_rpg_fire_pos" },
    { 0x5641, "get_rpg_group_randomized" },
    { 0x5642, "get_rpg_guy_target" },
    { 0x5643, "get_rpg_miss_offset" },
    { 0x5644, "get_rule_result" },
    { 0x5645, "get_rule_token_value" },
    { 0x5646, "get_rumble_ent" },
    { 0x5647, "get_safe_spawners" },
    { 0x5648, "get_sat_objective" },
    { 0x5649, "get_scale_for_axis" },
    { 0x564A, "get_scaled_xp" },
    { 0x564B, "get_scoot_velocity" },
    { 0x564C, "get_scoot_velocity_bump" },
    { 0x564D, "get_score_target_override" },
    { 0x564E, "get_score_target_pos" },
    { 0x564F, "get_screens" },
    { 0x5650, "get_script_car_collision" },
    { 0x5651, "get_script_delay" },
    { 0x5652, "get_script_delay2" },
    { 0x5653, "get_script_index" },
    { 0x5654, "get_script_linkto_targets" },
    { 0x5655, "get_script_loop" },
    { 0x5656, "get_script_noteworthy" },
    { 0x5657, "get_script_palette" },
    { 0x5658, "get_script_radius" },
    { 0x5659, "get_script_team" },
    { 0x565A, "get_scriptable_door_anim" },
    { 0x565B, "get_scriptable_map" },
    { 0x565C, "get_scriptablepartinfo" },
    { 0x565D, "get_scripted_movement_arrivefuncs" },
    { 0x565E, "get_search_point" },
    { 0x565F, "get_seat_omnvar_name" },
    { 0x5660, "get_seat_tag" },
    { 0x5661, "get_seat_tag_name" },
    { 0x5662, "get_second_fly_segment_bullet_end_pos" },
    { 0x5663, "get_secondary_equipment" },
    { 0x5664, "get_secondary_equipment_ammo" },
    { 0x5665, "get_section_state" },
    { 0x5666, "get_section_time" },
    { 0x5667, "get_see_recently_time_overrides" },
    { 0x5668, "get_segments" },
    { 0x5669, "get_selectable_ent" },
    { 0x566A, "get_selectable_from_array" },
    { 0x566B, "get_selected_move_vector" },
    { 0x566C, "get_selected_nerf" },
    { 0x566D, "get_selected_option" },
    { 0x566E, "get_selection_index_loop_around" },
    { 0x566F, "get_shelfs" },
    { 0x5670, "get_shock_anim" },
    { 0x5671, "get_shoot_anim" },
    { 0x5672, "get_shoot_start" },
    { 0x5673, "get_shortrank_by_id" },
    { 0x5674, "get_shot_fired" },
    { 0x5675, "get_single_value_struct" },
    { 0x5676, "get_skill_from_index" },
    { 0x5677, "get_smoke_grenade_struct_targetname" },
    { 0x5678, "get_smuggler_loot_amount" },
    { 0x5679, "get_snakecam_interactions_by_target" },
    { 0x567A, "get_snd_priority" },
    { 0x567B, "get_sniper_group_randomized" },
    { 0x567C, "get_soldier_model_from_type" },
    { 0x567D, "get_sound_length" },
    { 0x567E, "get_spawn_anim" },
    { 0x567F, "get_spawn_count_from_groupname" },
    { 0x5680, "get_spawn_point_targetname" },
    { 0x5681, "get_spawn_scoring_array" },
    { 0x5682, "get_spawn_scoring_type" },
    { 0x5683, "get_spawn_time_from_wave" },
    { 0x5684, "get_spawn_volume_func" },
    { 0x5685, "get_spawn_volumes_player_is_in" },
    { 0x5686, "get_spawned_ai_from_group_struct" },
    { 0x5687, "get_spawner" },
    { 0x5688, "get_spawner_array" },
    { 0x5689, "get_specific_flag" },
    { 0x568A, "get_specific_flag_by_label" },
    { 0x568B, "get_specific_flag_by_letter" },
    { 0x568C, "get_specific_zone" },
    { 0x568D, "get_spectator_revive_time" },
    { 0x568E, "get_speed_addition_from_distance" },
    { 0x568F, "get_speed_addition_from_player_cheating" },
    { 0x5690, "get_speed_type" },
    { 0x5691, "get_splash_by_id" },
    { 0x5692, "get_splineid" },
    { 0x5693, "get_splineidarray" },
    { 0x5694, "get_spot_by_priority" },
    { 0x5695, "get_spot_from_player" },
    { 0x5696, "get_spot_in_lane" },
    { 0x5697, "get_spot_taken_count" },
    { 0x5698, "get_stance" },
    { 0x5699, "get_stance_change_anim" },
    { 0x569A, "get_start_dvars" },
    { 0x569B, "get_start_func" },
    { 0x569C, "get_start_node" },
    { 0x569D, "get_start_to_end" },
    { 0x569E, "get_starting_currency" },
    { 0x569F, "get_state" },
    { 0x56A0, "get_state_interaction" },
    { 0x56A1, "get_state_machine" },
    { 0x56A2, "get_status_bit_value" },
    { 0x56A3, "get_stealth_state" },
    { 0x56A4, "get_sticky_grenade_destination" },
    { 0x56A5, "get_stop_func" },
    { 0x56A6, "get_stop_watch" },
    { 0x56A7, "get_storage_mg_target" },
    { 0x56A8, "get_stored_primary_equipment" },
    { 0x56A9, "get_stored_primary_equipment_ammo" },
    { 0x56AA, "get_stored_secondary_equipment" },
    { 0x56AB, "get_stored_secondary_equipment_ammo" },
    { 0x56AC, "get_stowed_primary_weapon" },
    { 0x56AD, "get_string_for_starts" },
    { 0x56AE, "get_struct_with_sight_to_player" },
    { 0x56AF, "get_super_from_playerdata" },
    { 0x56B0, "get_suppress_point" },
    { 0x56B1, "get_surface_types" },
    { 0x56B2, "get_synch_direction_list" },
    { 0x56B3, "get_table_name" },
    { 0x56B4, "get_table_time" },
    { 0x56B5, "get_tag_anim_offset" },
    { 0x56B6, "get_tag_list" },
    { 0x56B7, "get_tagorigin" },
    { 0x56B8, "get_taken_spot_count" },
    { 0x56B9, "get_taken_spot_percent" },
    { 0x56BA, "get_target_array" },
    { 0x56BB, "get_target_ent" },
    { 0x56BC, "get_target_ent_position_on_player" },
    { 0x56BD, "get_target_goals" },
    { 0x56BE, "get_target_intel" },
    { 0x56BF, "get_target_laser_angles" },
    { 0x56C0, "get_target_point" },
    { 0x56C1, "get_target_priority_level" },
    { 0x56C2, "get_target_tag_to_link_to" },
    { 0x56C3, "get_targetedentitiesinspline" },
    { 0x56C4, "get_targetedentwithcallinsplinewithkvp" },
    { 0x56C5, "get_targetname" },
    { 0x56C6, "get_targets" },
    { 0x56C7, "get_team" },
    { 0x56C8, "get_team_and_slot_number_struct" },
    { 0x56C9, "get_team_encounter_performance" },
    { 0x56CA, "get_team_id_one_assignment_first" },
    { 0x56CB, "get_team_id_one_slot" },
    { 0x56CC, "get_team_id_zero_assignment_first" },
    { 0x56CD, "get_team_id_zero_slot" },
    { 0x56CE, "get_team_number" },
    { 0x56CF, "get_team_score_component_name" },
    { 0x56D0, "get_team_slot_assignment_from_player_disconnect" },
    { 0x56D1, "get_team_substr" },
    { 0x56D2, "get_threatlevel" },
    { 0x56D3, "get_to_charge" },
    { 0x56D4, "get_to_target_player" },
    { 0x56D5, "get_token_reward_by_id" },
    { 0x56D6, "get_too_far_ahead_monitor" },
    { 0x56D7, "get_tool_hudelem" },
    { 0x56D8, "get_tossed_flares" },
    { 0x56D9, "get_total_count_color" },
    { 0x56DA, "get_total_leads_label_large" },
    { 0x56DB, "get_total_leads_label_small" },
    { 0x56DC, "get_total_line_duration" },
    { 0x56DD, "get_total_reserved_slot_count" },
    { 0x56DE, "get_touching_goal_vol" },
    { 0x56DF, "get_touching_goal_vol_index" },
    { 0x56E0, "get_trace_types" },
    { 0x56E1, "get_train_special_speed" },
    { 0x56E2, "get_trap" },
    { 0x56E3, "get_traverse_anim" },
    { 0x56E4, "get_tread_vfx" },
    { 0x56E5, "get_treadfx" },
    { 0x56E6, "get_trigger_flag" },
    { 0x56E7, "get_trigger_targs" },
    { 0x56E8, "get_truck_driver" },
    { 0x56E9, "get_truck_turret_start_node" },
    { 0x56EA, "get_turn_anim" },
    { 0x56EB, "get_turret_model_from_short" },
    { 0x56EC, "get_turret_path" },
    { 0x56ED, "get_turret_setup_anim" },
    { 0x56EE, "get_turrets" },
    { 0x56EF, "get_type_label" },
    { 0x56F0, "get_unarmed_response" },
    { 0x56F1, "get_under_bridge_enemy_start_structs" },
    { 0x56F2, "get_under_bridge_max_spawn" },
    { 0x56F3, "get_unidentidied_ieds_within_scan_range" },
    { 0x56F4, "get_unload_group" },
    { 0x56F5, "get_unload_marker_for_spawn_group" },
    { 0x56F6, "get_unused_crash_locations" },
    { 0x56F7, "get_unused_struct_from_array" },
    { 0x56F8, "get_up_from_seat_after_teleporting" },
    { 0x56F9, "get_valid_lines" },
    { 0x56FA, "get_validated_priority" },
    { 0x56FB, "get_value_with_index" },
    { 0x56FC, "get_veh_linked_structs" },
    { 0x56FD, "get_vehicle" },
    { 0x56FE, "get_vehicle_adjust_speed" },
    { 0x56FF, "get_vehicle_array" },
    { 0x5700, "get_vehicle_classname" },
    { 0x5701, "get_vehicle_driver" },
    { 0x5702, "get_vehicle_effect" },
    { 0x5703, "get_vehicle_hit_damage_data" },
    { 0x5704, "get_vehicle_interaction_info" },
    { 0x5705, "get_vehicle_interaction_point" },
    { 0x5706, "get_vehicle_mod_damage_data" },
    { 0x5707, "get_vehicle_node_to_wait_based_on_group" },
    { 0x5708, "get_vehicle_part_struct" },
    { 0x5709, "get_vehicle_riders_spawners" },
    { 0x570A, "get_vehicle_spawn_points" },
    { 0x570B, "get_vehiclenode_any_dynamic" },
    { 0x570C, "get_vehicles_in_field" },
    { 0x570D, "get_vip_close_to_exfil_dist_sq" },
    { 0x570E, "get_visible_nodes_array" },
    { 0x570F, "get_vo_bucket_sequential" },
    { 0x5710, "get_vo_duration" },
    { 0x5711, "get_vo_line" },
    { 0x5712, "get_vo_source" },
    { 0x5713, "get_vo_source_from_line" },
    { 0x5714, "get_vo_source_is_speaking" },
    { 0x5715, "get_vo_to_play" },
    { 0x5716, "get_volume_and_linkto" },
    { 0x5717, "get_wait_for_repeating_event" },
    { 0x5718, "get_wait_node" },
    { 0x5719, "get_wall_buy_hint_func" },
    { 0x571A, "get_wash_effect" },
    { 0x571B, "get_wash_fx" },
    { 0x571C, "get_wave_group_name" },
    { 0x571D, "get_wave_high_threshold" },
    { 0x571E, "get_wave_max_spawns" },
    { 0x571F, "get_wave_name" },
    { 0x5720, "get_wave_perc_increase" },
    { 0x5721, "get_weapon_base_ads_fov" },
    { 0x5722, "get_weapon_class_mod_damage_data" },
    { 0x5723, "get_weapon_hit_damage_data" },
    { 0x5724, "get_weapon_level" },
    { 0x5725, "get_weapon_level_func" },
    { 0x5726, "get_weapon_max_rank_xp" },
    { 0x5727, "get_weapon_name_from_alt" },
    { 0x5728, "get_weapon_name_string" },
    { 0x5729, "get_weapon_passive_xp_scale" },
    { 0x572A, "get_weapon_rank_for_xp" },
    { 0x572B, "get_weapon_rank_info_max_xp" },
    { 0x572C, "get_weapon_rank_info_min_xp" },
    { 0x572D, "get_weapon_redirect" },
    { 0x572E, "get_weapon_ref" },
    { 0x572F, "get_weapon_scope_fov" },
    { 0x5730, "get_weapon_type_from_input" },
    { 0x5731, "get_weapon_variant_id" },
    { 0x5732, "get_weapon_variation_obj" },
    { 0x5733, "get_weapon_weighted" },
    { 0x5734, "get_weapon_with_most_kills" },
    { 0x5735, "get_weapons_list_primaries" },
    { 0x5736, "get_weighted_anim" },
    { 0x5737, "get_whizby_fx_from_weapon" },
    { 0x5738, "get_wind_index" },
    { 0x5739, "get_wind_string" },
    { 0x573A, "get_winning_team_name" },
    { 0x573B, "get_wire_cut_hint" },
    { 0x573C, "get_wire_from_interact" },
    { 0x573D, "get_wire_hudoutline" },
    { 0x573E, "get_within_range" },
    { 0x573F, "get_xp_value" },
    { 0x5740, "get_zombie_killed_weapon_xp_multiplier_type" },
    { 0x5741, "get_zombie_targets" },
    { 0x5742, "getac130weaponrootname" },
    { 0x5743, "getaccessorydata" },
    { 0x5744, "getaccessorydatabyindex" },
    { 0x5745, "getaccessorylogic" },
    { 0x5746, "getaccessoryweapon" },
    { 0x5747, "getaccessoryweaponbyindex" },
    { 0x5748, "getachievement" },
    { 0x5749, "getactionallowfunc" },
    { 0x574A, "getactionscenedurationmax" },
    { 0x574B, "getactionscenedurationmin" },
    { 0x574C, "getactiveagentsofspecies" },
    { 0x574D, "getactiveagentsoftype" },
    { 0x574E, "getactivebradleys" },
    { 0x574F, "getactiveenemyagents" },
    { 0x5750, "getactiveequipmentarray" },
    { 0x5751, "getactivekillstreakid" },
    { 0x5752, "getactivemapconfig" },
    { 0x5753, "getactiveplayerlist" },
    { 0x5754, "getactivespawnquerycontext" },
    { 0x5755, "getactorsinradius" },
    { 0x5756, "getadjustedfirstroundbombcaseposition" },
    { 0x5757, "getaicurrentweapon" },
    { 0x5758, "getaicurrentweaponslot" },
    { 0x5759, "getaimpitchdifftolerance" },
    { 0x575A, "getaimpitchtopoint3d" },
    { 0x575B, "getaimpitchtoshootentorpos" },
    { 0x575C, "getaimyawtopoint" },
    { 0x575D, "getaimyawtopoint3d" },
    { 0x575E, "getaimyawtoshootentorpos" },
    { 0x575F, "getaiprimaryweapon" },
    { 0x5760, "getairdropcrates" },
    { 0x5761, "getaisecondaryweapon" },
    { 0x5762, "getaisidearmweapon" },
    { 0x5763, "getaisightdirection" },
    { 0x5764, "getaliastypefromsoundalias" },
    { 0x5765, "getaliveagents" },
    { 0x5766, "getaliveagentsofteam" },
    { 0x5767, "getalivecount" },
    { 0x5768, "getallavailablekillstreakstructs" },
    { 0x5769, "getallequip" },
    { 0x576A, "getallies" },
    { 0x576B, "getallredbarrels" },
    { 0x576C, "getallrespawnableplayers" },
    { 0x576D, "getallweapons" },
    { 0x576E, "getallyhelitarget" },
    { 0x576F, "getallyspawners" },
    { 0x5770, "getalphabetstring" },
    { 0x5771, "getaltgunanimstring" },
    { 0x5772, "getaltmodeweapon" },
    { 0x5773, "getambientgroup" },
    { 0x5774, "getammofromcache" },
    { 0x5775, "getammolootamount" },
    { 0x5776, "getammoname" },
    { 0x5777, "getammonameamount" },
    { 0x5778, "getammonamemaxamount" },
    { 0x5779, "getammooverride" },
    { 0x577A, "getammopurchasestring" },
    { 0x577B, "getangleindexfromselfyaw" },
    { 0x577C, "getanim" },
    { 0x577D, "getanim_from_animname" },
    { 0x577E, "getanim_generic" },
    { 0x577F, "getanimatemodel" },
    { 0x5780, "getanimdataforexplosive" },
    { 0x5781, "getanimendpos" },
    { 0x5782, "getanimscalefactors" },
    { 0x5783, "getanimsdatafromthedestructiontable" },
    { 0x5784, "getanimselectorfilenames" },
    { 0x5785, "getarbitraryuptrigger" },
    { 0x5786, "getarbitraryuptriggerbase" },
    { 0x5787, "getarbitraryuptriggerblinkloc" },
    { 0x5788, "getarenaroundendmusictype" },
    { 0x5789, "getarkattachmentlist" },
    { 0x578A, "getarmcratedatabystreakname" },
    { 0x578B, "getarmkillsteakstoexcludebyteamdefconlevel" },
    { 0x578C, "getarmoramount" },
    { 0x578D, "getarmormaxamount" },
    { 0x578E, "getarmorplateperpickup" },
    { 0x578F, "getarmorvestamount" },
    { 0x5790, "getarmorvestmaxamount" },
    { 0x5791, "getarrayofdialoguealiases" },
    { 0x5792, "getarrivalnode" },
    { 0x5793, "getarrivaltype" },
    { 0x5794, "getassignedspawnpoint" },
    { 0x5795, "getassignedspawnpointbasedonteam" },
    { 0x5796, "getassistbonusamount" },
    { 0x5797, "getattachedpersonalent" },
    { 0x5798, "getattachmentbasenames" },
    { 0x5799, "getattachmentlist" },
    { 0x579A, "getattachmentlistbasenames" },
    { 0x579B, "getattachmentlistforpickup" },
    { 0x579C, "getattachmentlistforscriptablepartname" },
    { 0x579D, "getattachmentlistuniquenames" },
    { 0x579E, "getattachmentloadoutstring" },
    { 0x579F, "getattachmenttype" },
    { 0x57A0, "getattachmenttypeslist" },
    { 0x57A1, "getautodeploynorm" },
    { 0x57A2, "getavailableattachments" },
    { 0x57A3, "getavailableequippedkillstreakstructs" },
    { 0x57A4, "getavailableperks" },
    { 0x57A5, "getavailablesquadindex" },
    { 0x57A6, "getaverageforwardvectorforplayersinteam" },
    { 0x57A7, "getaveragelowspawnpoint" },
    { 0x57A8, "getaverageorigin" },
    { 0x57A9, "getbackdeathanim" },
    { 0x57AA, "getballorigin" },
    { 0x57AB, "getballstarts" },
    { 0x57AC, "getballtriggers" },
    { 0x57AD, "getbandagehealfractionbr" },
    { 0x57AE, "getbandagehealtimebr" },
    { 0x57AF, "getbandagetime" },
    { 0x57B0, "getbasearchetype" },
    { 0x57B1, "getbasearray" },
    { 0x57B2, "getbaseeventcalloutsplash" },
    { 0x57B3, "getbasekillstreakdialog" },
    { 0x57B4, "getbaseperkname" },
    { 0x57B5, "getbaseweaponforpickup" },
    { 0x57B6, "getbaseweaponforscriptablepartname" },
    { 0x57B7, "getbaseweaponname" },
    { 0x57B8, "getbattlechatteralias" },
    { 0x57B9, "getbattleslideoffensedamage" },
    { 0x57BA, "getbcintensity" },
    { 0x57BB, "getbcstate" },
    { 0x57BC, "getbcwaittime" },
    { 0x57BD, "getbestcovermultinodetype" },
    { 0x57BE, "getbestmissilespawnpoint" },
    { 0x57BF, "getbestplayer" },
    { 0x57C0, "getbestpotgscore" },
    { 0x57C1, "getbestprimarytarget" },
    { 0x57C2, "getbestsentientfrompool" },
    { 0x57C3, "getbestsmartobject" },
    { 0x57C4, "getbestsmartobjectalongline" },
    { 0x57C5, "getbestspawnpoint" },
    { 0x57C6, "getbeststingertarget" },
    { 0x57C7, "getbesttarget" },
    { 0x57C8, "getbestteammate" },
    { 0x57C9, "getbetterplayer" },
    { 0x57CA, "getbetterteam" },
    { 0x57CB, "getbettingplayers" },
    { 0x57CC, "getbinarysequencemapping" },
    { 0x57CD, "getbleedouttime" },
    { 0x57CE, "getbodymodel" },
    { 0x57CF, "getbombmodel" },
    { 0x57D0, "getbot" },
    { 0x57D1, "getbrcratedatabytype" },
    { 0x57D2, "getbrnuketraveltime" },
    { 0x57D3, "getbsmstate" },
    { 0x57D4, "getbtaction" },
    { 0x57D5, "getbuddyspawnangles" },
    { 0x57D6, "getbulletstokill" },
    { 0x57D7, "getburnvfxtagpackets" },
    { 0x57D8, "getburstdelaytime" },
    { 0x57D9, "getburstdelaytimemg" },
    { 0x57DA, "getburster" },
    { 0x57DB, "getburstsize" },
    { 0x57DC, "getbuttonpressed" },
    { 0x57DD, "getc130height" },
    { 0x57DE, "getc130sealevel" },
    { 0x57DF, "getc130speed" },
    { 0x57E0, "getcachedloadoutstruct" },
    { 0x57E1, "getcallback" },
    { 0x57E2, "getcallsign" },
    { 0x57E3, "getcamdata" },
    { 0x57E4, "getcameravecorang" },
    { 0x57E5, "getcamotablecolumnindex" },
    { 0x57E6, "getcannedresponse" },
    { 0x57E7, "getcanshootandsee" },
    { 0x57E8, "getcanshootandsee_hometown" },
    { 0x57E9, "getcapturebehavior" },
    { 0x57EA, "getcapturedialog" },
    { 0x57EB, "getcaptureprogress" },
    { 0x57EC, "getcapturetype" },
    { 0x57ED, "getcapxpscale" },
    { 0x57EE, "getcashsoundaliasforplayer" },
    { 0x57EF, "getcenterfrac" },
    { 0x57F0, "getcenterpoint" },
    { 0x57F1, "getchain" },
    { 0x57F2, "getchains" },
    { 0x57F3, "getcharactercardgesturelength" },
    { 0x57F4, "getchildoutlineents" },
    { 0x57F5, "getclaimednode" },
    { 0x57F6, "getclaimteam" },
    { 0x57F7, "getclasschoice" },
    { 0x57F8, "getclassiclaststandpistol" },
    { 0x57F9, "getclassindex" },
    { 0x57FA, "getclientwaypointicon" },
    { 0x57FB, "getcloseambulance" },
    { 0x57FC, "getclosenoderadiusdist" },
    { 0x57FD, "getclosest" },
    { 0x57FE, "getclosestavailablespawnlocation" },
    { 0x57FF, "getclosestcheckpoint" },
    { 0x5800, "getclosestfleezone" },
    { 0x5801, "getclosestfriendlyspeaker" },
    { 0x5802, "getclosestfx" },
    { 0x5803, "getclosestplayeronteam" },
    { 0x5804, "getcloseststruct" },
    { 0x5805, "getclosesttargetinview" },
    { 0x5806, "getclosesttocoverhideindex" },
    { 0x5807, "getcodcasterplayervalue" },
    { 0x5808, "getcollateraldamagegrade" },
    { 0x5809, "getcolornumberarray" },
    { 0x580A, "getcombatspeedscalar" },
    { 0x580B, "getcommanderassets" },
    { 0x580C, "getcompletenameforweapon" },
    { 0x580D, "getcompleteweaponnamenoalt" },
    { 0x580E, "getcooldowntime" },
    { 0x580F, "getcornersfromarray" },
    { 0x5810, "getcornerstepoutsdisabled" },
    { 0x5811, "getcorpsearraymp" },
    { 0x5812, "getcorpsearraysp" },
    { 0x5813, "getcorpseorigin" },
    { 0x5814, "getcorrectheight" },
    { 0x5815, "getcorrectheightescort" },
    { 0x5816, "getcover3dnodeoffset" },
    { 0x5817, "getcoverlongdeathalias" },
    { 0x5818, "getcovernodehelitarget" },
    { 0x5819, "getcoverstate" },
    { 0x581A, "getcpcratedatabytype" },
    { 0x581B, "getcraftingmaterialmax" },
    { 0x581C, "getcratedatabytype" },
    { 0x581D, "getcratedropcastend" },
    { 0x581E, "getcratedropcaststart" },
    { 0x581F, "getcratedropdestination" },
    { 0x5820, "getcratedropignorelist" },
    { 0x5821, "getcrawllongdeathalias" },
    { 0x5822, "getcrouchdeathanim" },
    { 0x5823, "getcrouchpainanim" },
    { 0x5824, "getcurpotgscene" },
    { 0x5825, "getcurrent_groupstruct" },
    { 0x5826, "getcurrentarmsracecachelocation" },
    { 0x5827, "getcurrentbtaction" },
    { 0x5828, "getcurrentcamoname" },
    { 0x5829, "getcurrentdesiredbtactionname" },
    { 0x582A, "getcurrentents" },
    { 0x582B, "getcurrentequipment" },
    { 0x582C, "getcurrentfraction" },
    { 0x582D, "getcurrentmonitoredweaponswitchweapon" },
    { 0x582E, "getcurrentplayerlifeidforkillstreak" },
    { 0x582F, "getcurrentpoistate" },
    { 0x5830, "getcurrentprimaryweaponsminusalt" },
    { 0x5831, "getcurrentreliableweaponswitchweapon" },
    { 0x5832, "getcurrentstagespawners" },
    { 0x5833, "getcurrentsuper" },
    { 0x5834, "getcurrentsuperbasepoints" },
    { 0x5835, "getcurrentsuperextrapoints" },
    { 0x5836, "getcurrentsuperpoints" },
    { 0x5837, "getcurrentsuperref" },
    { 0x5838, "getcurrentvalue" },
    { 0x5839, "getcurrentweaponslotname" },
    { 0x583A, "getcurwindowstarttime" },
    { 0x583B, "getcustomarrivalangles" },
    { 0x583C, "getcustombc" },
    { 0x583D, "getcustombcradioprefix" },
    { 0x583E, "getcustomgametypeteammax" },
    { 0x583F, "getcustomization" },
    { 0x5840, "getcustomizationprefix" },
    { 0x5841, "getdamageableents" },
    { 0x5842, "getdamagedirection" },
    { 0x5843, "getdamagedirectionsuffix" },
    { 0x5844, "getdamagedirstring" },
    { 0x5845, "getdamagefromzombietype" },
    { 0x5846, "getdamagemod" },
    { 0x5847, "getdamagemodifiertotal" },
    { 0x5848, "getdamageshieldpainanim" },
    { 0x5849, "getdamagetype" },
    { 0x584A, "getdangercircleorigin" },
    { 0x584B, "getdangercircleradius" },
    { 0x584C, "getdaytime" },
    { 0x584D, "getdeathanim" },
    { 0x584E, "getdeathsdoorduration" },
    { 0x584F, "getdeathsfortypeandstance" },
    { 0x5850, "getdeathsshieldduration" },
    { 0x5851, "getdeathtypefromcause" },
    { 0x5852, "getdebuffattackersbyweapon" },
    { 0x5853, "getdefaultcapturevisualscallback" },
    { 0x5854, "getdefaultcapturevisualsdeletiondelay" },
    { 0x5855, "getdefaultdestroyvisualscallback" },
    { 0x5856, "getdefaultdestroyvisualsdeletiondelay" },
    { 0x5857, "getdefaultlaststandrevivetimervalue" },
    { 0x5858, "getdefaultlaststandtimervalue" },
    { 0x5859, "getdefaultminedangerzoneradiussize" },
    { 0x585A, "getdefaultmountmantlemodel" },
    { 0x585B, "getdefaultslot" },
    { 0x585C, "getdegreeselevation" },
    { 0x585D, "getdescription" },
    { 0x585E, "getdesiredgrenadetimervalue" },
    { 0x585F, "getdesiredoffset" },
    { 0x5860, "getdialoguedebouncetime" },
    { 0x5861, "getdifficulty" },
    { 0x5862, "getdifficultylevel" },
    { 0x5863, "getdirectioncompass" },
    { 0x5864, "getdirectionfacingclock" },
    { 0x5865, "getdirectionfacingflank" },
    { 0x5866, "getdisarmfunc" },
    { 0x5867, "getdisplayweapon" },
    { 0x5868, "getdistancemeters" },
    { 0x5869, "getdistancemetersnormalized" },
    { 0x586A, "getdistancemiles" },
    { 0x586B, "getdistancemilesnormalized" },
    { 0x586C, "getdompointsearchorigin" },
    { 0x586D, "getdoorcenter" },
    { 0x586E, "getdooropenspeedlookup" },
    { 0x586F, "getdoorowner" },
    { 0x5870, "getdoublejumpoffsetposition" },
    { 0x5871, "getdragonsbreathvfxpackets" },
    { 0x5872, "getdriverassets" },
    { 0x5873, "getdropzonecratetype" },
    { 0x5874, "getearliestclaimplayer" },
    { 0x5875, "getemptyleveldata" },
    { 0x5876, "getenemycount" },
    { 0x5877, "getenemyeyepos" },
    { 0x5878, "getenemyplayers" },
    { 0x5879, "getenemysightpos" },
    { 0x587A, "getenemytarget" },
    { 0x587B, "getenemytargets" },
    { 0x587C, "getenemyteams" },
    { 0x587D, "getent_or_struct" },
    { 0x587E, "getentarraywithflag" },
    { 0x587F, "getenthitpos" },
    { 0x5880, "getentitiesinradius" },
    { 0x5881, "getentityeventdata" },
    { 0x5882, "getentityid" },
    { 0x5883, "getentitypotgdata" },
    { 0x5884, "getentwithflag" },
    { 0x5885, "getequipmentammo" },
    { 0x5886, "getequipmenthinticon" },
    { 0x5887, "getequipmenthintstring" },
    { 0x5888, "getequipmentmaxammo" },
    { 0x5889, "getequipmentmodel" },
    { 0x588A, "getequipmentreffromweapon" },
    { 0x588B, "getequipmentslotammo" },
    { 0x588C, "getequipmentstartammo" },
    { 0x588D, "getequipmenttableinfo" },
    { 0x588E, "getequipmenttype" },
    { 0x588F, "getequippedkillstreakbyname" },
    { 0x5890, "getequippedkillstreakslotbyname" },
    { 0x5891, "geteventstate" },
    { 0x5892, "getexfilloccallback" },
    { 0x5893, "getexfilstructs" },
    { 0x5894, "getexitnode" },
    { 0x5895, "getexitsplittime" },
    { 0x5896, "getexplodedistance" },
    { 0x5897, "getexploderdelaydefault" },
    { 0x5898, "getexplosiveusableoffset" },
    { 0x5899, "getexposedlongdeathalias" },
    { 0x589A, "getexternaltraverseinfo" },
    { 0x589B, "getextractionbtmflag" },
    { 0x589C, "getextractiontimeconst" },
    { 0x589D, "geteyeheightfromstance" },
    { 0x589E, "getfaction" },
    { 0x589F, "getfactorfunction" },
    { 0x58A0, "getfactorparamreflist" },
    { 0x58A1, "getfadetime" },
    { 0x58A2, "getfarnoderadiusdist" },
    { 0x58A3, "getfarrahbloodymodel" },
    { 0x58A4, "getfarthest" },
    { 0x58A5, "getfinalpotginfo" },
    { 0x58A6, "getfirechainstarget" },
    { 0x58A7, "getfireengulfrate" },
    { 0x58A8, "getfireinvulseconds" },
    { 0x58A9, "getfirstaidhealtimebr" },
    { 0x58AA, "getfirstbtmbombloc" },
    { 0x58AB, "getfirstopenjumporigin" },
    { 0x58AC, "getfirstopenslot" },
    { 0x58AD, "getfirstprimaryweapon" },
    { 0x58AE, "getfirsttimevoforobjective" },
    { 0x58AF, "getfirstzone" },
    { 0x58B0, "getflagcount" },
    { 0x58B1, "getflagpos" },
    { 0x58B2, "getflagspawnidforobjectivekey" },
    { 0x58B3, "getflagteam" },
    { 0x58B4, "getflankingpointforenemyonmedian" },
    { 0x58B5, "getflankpositiononplayer" },
    { 0x58B6, "getflashlightmodel" },
    { 0x58B7, "getflavorburstaliases" },
    { 0x58B8, "getflavorburstid" },
    { 0x58B9, "getflightpath" },
    { 0x58BA, "getfloatproperty" },
    { 0x58BB, "getfocusendtime" },
    { 0x58BC, "getforcedloadoutweapon" },
    { 0x58BD, "getforcedlongdeathalias" },
    { 0x58BE, "getformattedtimestamp" },
    { 0x58BF, "getfreeagent" },
    { 0x58C0, "getfreeagentcount" },
    { 0x58C1, "getfriendlies" },
    { 0x58C2, "getfriendlyplayers" },
    { 0x58C3, "getfrontarcclockdirection" },
    { 0x58C4, "getfrontcrawldeath" },
    { 0x58C5, "getfrontlineteamcenter" },
    { 0x58C6, "getfx" },
    { 0x58C7, "getgamemodestat" },
    { 0x58C8, "getgamemodeweaponspeed" },
    { 0x58C9, "getgametype" },
    { 0x58CA, "getgametypenumlives" },
    { 0x58CB, "getgametypexpmultiplier" },
    { 0x58CC, "getgenericanim" },
    { 0x58CD, "getgesturedata" },
    { 0x58CE, "getgesturedatabyindex" },
    { 0x58CF, "getgimmeslotkillstreakstructs" },
    { 0x58D0, "getglcustomization" },
    { 0x58D1, "getglcustomizationhackney" },
    { 0x58D2, "getglobalfrontlineinfo" },
    { 0x58D3, "getglobalintermissionpoint" },
    { 0x58D4, "getglobalrankxpmultiplier" },
    { 0x58D5, "getglobalweaponrankxpmultiplier" },
    { 0x58D6, "getgrenadeammofromcache" },
    { 0x58D7, "getgrenadedropvelocity" },
    { 0x58D8, "getgrenadeheldatdeath" },
    { 0x58D9, "getgrenadeinpullback" },
    { 0x58DA, "getgrenadeithrew" },
    { 0x58DB, "getgrenademodel" },
    { 0x58DC, "getgrenadethrowoffset" },
    { 0x58DD, "getgrenadetimertime" },
    { 0x58DE, "getgroundangle" },
    { 0x58DF, "getgroundcompensationheight" },
    { 0x58E0, "getgroup" },
    { 0x58E1, "getgulagarenaspawns" },
    { 0x58E2, "getgulagcenter" },
    { 0x58E3, "getgulagpickupsforclass" },
    { 0x58E4, "getgunanimindex" },
    { 0x58E5, "getgunanimstring" },
    { 0x58E6, "getgunbenchents" },
    { 0x58E7, "getgunfromcache" },
    { 0x58E8, "getgungameloadoutindex" },
    { 0x58E9, "getgungameloadoutomnvarindex" },
    { 0x58EA, "getgunputawayduration" },
    { 0x58EB, "getgunshipweaponrootname" },
    { 0x58EC, "gethalftime" },
    { 0x58ED, "gethardenedaward" },
    { 0x58EE, "gethealthcap" },
    { 0x58EF, "gethealthperframe" },
    { 0x58F0, "gethealthpersec" },
    { 0x58F1, "gethealthregendelay" },
    { 0x58F2, "gethealthregenpersecond" },
    { 0x58F3, "gethealthregentime" },
    { 0x58F4, "gethealthshielddamage" },
    { 0x58F5, "getheavyarmor" },
    { 0x58F6, "gethelipilotmeshoffset" },
    { 0x58F7, "gethelipilottraceoffset" },
    { 0x58F8, "gethighestallowedstance" },
    { 0x58F9, "gethighestpriorityevent" },
    { 0x58FA, "gethighestprogressedplayers" },
    { 0x58FB, "gethighestscoringplayer" },
    { 0x58FC, "gethighestscoringspawn" },
    { 0x58FD, "gethighestscoringteam" },
    { 0x58FE, "gethitlocheight" },
    { 0x58FF, "gethitmarkerpriority" },
    { 0x5900, "gethostplayer" },
    { 0x5901, "gethours" },
    { 0x5902, "gethourtime" },
    { 0x5903, "gethqownerteamvalue" },
    { 0x5904, "gethumandamagedirstring" },
    { 0x5905, "gethunterkillerid" },
    { 0x5906, "gethuntroutepoints" },
    { 0x5907, "gethuntstealthgroups" },
    { 0x5908, "gethuntstealthgroupvolumelists" },
    { 0x5909, "geticonshader" },
    { 0x590A, "getimpactsfx" },
    { 0x590B, "getin" },
    { 0x590C, "getin_enteredvehicletrack" },
    { 0x590D, "getin_hints" },
    { 0x590E, "getin_idle_func" },
    { 0x590F, "getindexfromhitloc" },
    { 0x5910, "getindicesofelements" },
    { 0x5911, "getinfillocationselectionfunc" },
    { 0x5912, "getinfilpath" },
    { 0x5913, "getinfilspawnoffset" },
    { 0x5914, "getinfilspawnselectendfunc" },
    { 0x5915, "getinfilspawnselectstartfunc" },
    { 0x5916, "getinfo" },
    { 0x5917, "getinorgs" },
    { 0x5918, "getintensitysuffix" },
    { 0x5919, "getinteractionbynoteworthy" },
    { 0x591A, "getinteractiveinfilline" },
    { 0x591B, "getinteractiveoutlineasset" },
    { 0x591C, "getintervalsounddelaymaxdefault" },
    { 0x591D, "getintervalsounddelaymindefault" },
    { 0x591E, "getintproperty" },
    { 0x591F, "getinvultime" },
    { 0x5920, "getitemdroporiginandangles" },
    { 0x5921, "getitemfromcache" },
    { 0x5922, "getitemslot" },
    { 0x5923, "getitemweaponname" },
    { 0x5924, "getjointeampermissions" },
    { 0x5925, "getjuggmaxhealth" },
    { 0x5926, "getjuggorcratepos" },
    { 0x5927, "getjuggspeedscalar" },
    { 0x5928, "getjuggtimeout" },
    { 0x5929, "getjuggtimeoutenabled" },
    { 0x592A, "getkeepweapons" },
    { 0x592B, "getkillcamentity" },
    { 0x592C, "getkillstreak" },
    { 0x592D, "getkillstreakaudioref" },
    { 0x592E, "getkillstreakaudiorefoverride" },
    { 0x592F, "getkillstreakcratedatabystreakname" },
    { 0x5930, "getkillstreakdeployweapon" },
    { 0x5931, "getkillstreakdialogcooldown" },
    { 0x5932, "getkillstreakenemyusedialogue" },
    { 0x5933, "getkillstreakgameweapons" },
    { 0x5934, "getkillstreakindex" },
    { 0x5935, "getkillstreakinslot" },
    { 0x5936, "getkillstreakkills" },
    { 0x5937, "getkillstreaklifeid" },
    { 0x5938, "getkillstreaknamefromweapon" },
    { 0x5939, "getkillstreaknomeleetarget" },
    { 0x593A, "getkillstreakoverheadicon" },
    { 0x593B, "getkillstreaksetupinfo" },
    { 0x593C, "getkillstreaktypepassives" },
    { 0x593D, "getkillstreakvisibleslotbyname" },
    { 0x593E, "getkillstreakweapon" },
    { 0x593F, "getkilltriggerspawnloc" },
    { 0x5940, "getkothzonedeadzonedist" },
    { 0x5941, "getlabel" },
    { 0x5942, "getlabelid" },
    { 0x5943, "getlaserangles" },
    { 0x5944, "getlaserdirection" },
    { 0x5945, "getlaserstartpoint" },
    { 0x5946, "getlastclaimteam" },
    { 0x5947, "getlastlivingplayer" },
    { 0x5948, "getlastoobtrigger" },
    { 0x5949, "getlastweapon" },
    { 0x594A, "getlaunchangles" },
    { 0x594B, "getlengthofconversation" },
    { 0x594C, "getlethaltypepassives" },
    { 0x594D, "getlevelbink" },
    { 0x594E, "getlevelcompleted" },
    { 0x594F, "getleveldata" },
    { 0x5950, "getlevelindex" },
    { 0x5951, "getlevelmlgcams" },
    { 0x5952, "getlevelname" },
    { 0x5953, "getlevelskill" },
    { 0x5954, "getlevelstreamsync" },
    { 0x5955, "getleveltriggers" },
    { 0x5956, "getlevelveteranaward" },
    { 0x5957, "getlifelinktarget" },
    { 0x5958, "getlightarmorvalue" },
    { 0x5959, "getlightingvalues" },
    { 0x595A, "getlightswitchstatus" },
    { 0x595B, "getlighttrigger" },
    { 0x595C, "getlinespacetime" },
    { 0x595D, "getlinkedvehiclenodes" },
    { 0x595E, "getlinknamenodes" },
    { 0x595F, "getlinks_array" },
    { 0x5960, "getlistenerdirection" },
    { 0x5961, "getlistenerorigin" },
    { 0x5962, "getlivingplayers" },
    { 0x5963, "getlivingplayers_team" },
    { 0x5964, "getloadoutindex" },
    { 0x5965, "getloadoutstreaktypefromstreaktype" },
    { 0x5966, "getlocaleent" },
    { 0x5967, "getlocaleid" },
    { 0x5968, "getlocalized" },
    { 0x5969, "getlocation" },
    { 0x596A, "getloccalloutalias" },
    { 0x596B, "getloopeffectdelaydefault" },
    { 0x596C, "getlootinfoforweapon" },
    { 0x596D, "getlootsound" },
    { 0x596E, "getlootvariant" },
    { 0x596F, "getlootweaponref" },
    { 0x5970, "getlosingplayers" },
    { 0x5971, "getlowermessage" },
    { 0x5972, "getlowestclientnum" },
    { 0x5973, "getlowestskill" },
    { 0x5974, "getmapname" },
    { 0x5975, "getmapselectweapon" },
    { 0x5976, "getmarkingdelay" },
    { 0x5977, "getmatchbonusspm" },
    { 0x5978, "getmatchendtimeutc" },
    { 0x5979, "getmatchrulesdatawithteamandindex" },
    { 0x597A, "getmatchrulesspecialclass" },
    { 0x597B, "getmatchspm" },
    { 0x597C, "getmatchstarttimeutc" },
    { 0x597D, "getmatchstat" },
    { 0x597E, "getmatchstatpathkey" },
    { 0x597F, "getmaxarrivaldistfornodetype" },
    { 0x5980, "getmaxattachments" },
    { 0x5981, "getmaxdamage" },
    { 0x5982, "getmaxdistancetolos" },
    { 0x5983, "getmaxoutofboundscooldown" },
    { 0x5984, "getmaxoutofboundsminefieldtime" },
    { 0x5985, "getmaxoutofboundsrestrictedtime" },
    { 0x5986, "getmaxoutofboundstime" },
    { 0x5987, "getmaxovertimeroundsbygametype" },
    { 0x5988, "getmaxplantedhackedequip" },
    { 0x5989, "getmaxplantedlethalequip" },
    { 0x598A, "getmaxplantedsuperequip" },
    { 0x598B, "getmaxplantedtacticalequip" },
    { 0x598C, "getmaxplatesperslot" },
    { 0x598D, "getmaxplayers" },
    { 0x598E, "getmaxprimaryattachments" },
    { 0x598F, "getmaxsceneduration" },
    { 0x5990, "getmaxsecondaryattachments" },
    { 0x5991, "getmaxweaponrank" },
    { 0x5992, "getmaxweaponrankforrootweapon" },
    { 0x5993, "getmaxwinbytworounds" },
    { 0x5994, "getmedianpointforplayersinteam" },
    { 0x5995, "getmeleechargerange" },
    { 0x5996, "getmeritfilter" },
    { 0x5997, "getmeritmasterchallenge" },
    { 0x5998, "getmeritstatus" },
    { 0x5999, "getminimumscorerequired" },
    { 0x599A, "getminimumscorerequirednvidiahighlights" },
    { 0x599B, "getminradiusofteamblob" },
    { 0x599C, "getmintimetillpointindangercircle" },
    { 0x599D, "getminutespassed" },
    { 0x599E, "getmissedinfilcamerapositions" },
    { 0x599F, "getmissileexplradius" },
    { 0x59A0, "getmissileexplscale" },
    { 0x59A1, "getmlgteamcolor" },
    { 0x59A2, "getmodel" },
    { 0x59A3, "getmodestatindex" },
    { 0x59A4, "getmodifiedantikillstreakdamage" },
    { 0x59A5, "getmodifiedbarrierdamage" },
    { 0x59A6, "getmodifiedtankdamage" },
    { 0x59A7, "getmovespeedforsuperweapon" },
    { 0x59A8, "getmovetime" },
    { 0x59A9, "getmovetimescale" },
    { 0x59AA, "getmovetype" },
    { 0x59AB, "getname" },
    { 0x59AC, "getnames" },
    { 0x59AD, "getnearestflagteam" },
    { 0x59AE, "getnewenemyreactalias" },
    { 0x59AF, "getnewenemyreactangleindex" },
    { 0x59B0, "getnewenemyreactdirindex" },
    { 0x59B1, "getnewpoint" },
    { 0x59B2, "getnewsquadindex" },
    { 0x59B3, "getnewtargetplayer" },
    { 0x59B4, "getnextarenaspawn" },
    { 0x59B5, "getnextflashanim" },
    { 0x59B6, "getnextgun" },
    { 0x59B7, "getnexthelicopterwithroom" },
    { 0x59B8, "getnexthelispawnmodule" },
    { 0x59B9, "getnextholdoutspawnmodule" },
    { 0x59BA, "getnextjailspawn" },
    { 0x59BB, "getnextlevelindex" },
    { 0x59BC, "getnextminimapid" },
    { 0x59BD, "getnextmissilespawnindex" },
    { 0x59BE, "getnextobjective" },
    { 0x59BF, "getnextobjectiveid" },
    { 0x59C0, "getnextoperatorindex" },
    { 0x59C1, "getnextquarrydefensespawnmodule" },
    { 0x59C2, "getnextselectablekillstreakslot" },
    { 0x59C3, "getnextskinindex" },
    { 0x59C4, "getnextstreakname" },
    { 0x59C5, "getnexttruckwithroom" },
    { 0x59C6, "getnextwalkarspawnmodule" },
    { 0x59C7, "getnextwalksniperspawnmodule" },
    { 0x59C8, "getnextworldid" },
    { 0x59C9, "getnextzone" },
    { 0x59CA, "getninebangsubexplosionpos" },
    { 0x59CB, "getnodeaimpitchoffset" },
    { 0x59CC, "getnodeaimyawoffset" },
    { 0x59CD, "getnodearrayfunction" },
    { 0x59CE, "getnodeforwardangles" },
    { 0x59CF, "getnodeforwardyaw" },
    { 0x59D0, "getnodeforwardyawnodetypelookupoverride" },
    { 0x59D1, "getnodefunction" },
    { 0x59D2, "getnodeinzone" },
    { 0x59D3, "getnodeleanyaw" },
    { 0x59D4, "getnodeoffset" },
    { 0x59D5, "getnodeoffsetposeoverride" },
    { 0x59D6, "getnodetypename" },
    { 0x59D7, "getnodeyawfromoffsettable" },
    { 0x59D8, "getnodeyawoffset" },
    { 0x59D9, "getnodeyawtoenemy" },
    { 0x59DA, "getnodeyawtoorigin" },
    { 0x59DB, "getnonopticattachmentlistbasenames" },
    { 0x59DC, "getnormtripwirelength" },
    { 0x59DD, "getnumactiveagents" },
    { 0x59DE, "getnumactivekillstreakperteam" },
    { 0x59DF, "getnumactivetanksforteam" },
    { 0x59E0, "getnumairdropcrates" },
    { 0x59E1, "getnumberstring" },
    { 0x59E2, "getnumdroppedcrates" },
    { 0x59E3, "getnumownedactiveagents" },
    { 0x59E4, "getnumownedactiveagentsbytype" },
    { 0x59E5, "getnumownedagentsonteambytype" },
    { 0x59E6, "getnumownedjackals" },
    { 0x59E7, "getnumplayersusingthisinteraction" },
    { 0x59E8, "getnumtouchingexceptteam" },
    { 0x59E9, "getnumtouchingforteam" },
    { 0x59EA, "getobjanimfile" },
    { 0x59EB, "getobjectiveforfloor" },
    { 0x59EC, "getobjectivehinttext" },
    { 0x59ED, "getobjectivescoretext" },
    { 0x59EE, "getobjectivestate" },
    { 0x59EF, "getobjectivestructfromref" },
    { 0x59F0, "getobjectivetext" },
    { 0x59F1, "getobjpointbyindex" },
    { 0x59F2, "getobjpointbyname" },
    { 0x59F3, "getobjzonedeadzonedist" },
    { 0x59F4, "getofffirevfxnames" },
    { 0x59F5, "getoffhandprobabilityfromname" },
    { 0x59F6, "getoffhandweaponname" },
    { 0x59F7, "getoffsetspawnorigin" },
    { 0x59F8, "getoffvehiclefunc" },
    { 0x59F9, "getoldarmorent" },
    { 0x59FA, "getoneshoteffectdelaydefault" },
    { 0x59FB, "getonfirevfxnames" },
    { 0x59FC, "getonpath" },
    { 0x59FD, "getoobdata" },
    { 0x59FE, "getoperatorcustomization" },
    { 0x59FF, "getoperatorexecution" },
    { 0x5A00, "getoperatorgender" },
    { 0x5A01, "getoperatorsuperfaction" },
    { 0x5A02, "getoperatorteambyref" },
    { 0x5A03, "getoperatorvoice" },
    { 0x5A04, "getopticattachmentlistbasenames" },
    { 0x5A05, "getoriginidentifierstring" },
    { 0x5A06, "getoriginoffsets" },
    { 0x5A07, "getothermode" },
    { 0x5A08, "getotherteam" },
    { 0x5A09, "getout" },
    { 0x5A0A, "getout_delete" },
    { 0x5A0B, "getout_hover_land" },
    { 0x5A0C, "getout_hover_loop" },
    { 0x5A0D, "getout_landed" },
    { 0x5A0E, "getout_rig_delay" },
    { 0x5A0F, "getout_rigspawn" },
    { 0x5A10, "getout_secondary" },
    { 0x5A11, "getout_secondary_tag" },
    { 0x5A12, "getout_timed_anim" },
    { 0x5A13, "getoutlineasset" },
    { 0x5A14, "getoutloopsnd" },
    { 0x5A15, "getoutofboundstime" },
    { 0x5A16, "getoutrig_abort" },
    { 0x5A17, "getoutrig_abort_while_deploying" },
    { 0x5A18, "getoutrig_disable_abort_notify_after_riders_out" },
    { 0x5A19, "getoutrig_model" },
    { 0x5A1A, "getoutrig_model_idle" },
    { 0x5A1B, "getoutrig_model_new" },
    { 0x5A1C, "getoutsnd" },
    { 0x5A1D, "getoutstance" },
    { 0x5A1E, "getoverridedvarfloat" },
    { 0x5A1F, "getoverridedvarint" },
    { 0x5A20, "getovertimebombzone" },
    { 0x5A21, "getowneddomflags" },
    { 0x5A22, "getownerteam" },
    { 0x5A23, "getownerteamplayer" },
    { 0x5A24, "getpainanim" },
    { 0x5A25, "getpainbodypartcrouchdeath" },
    { 0x5A26, "getpainbodypartdeath" },
    { 0x5A27, "getpaindirectiontoactor" },
    { 0x5A28, "getpainweaponsize" },
    { 0x5A29, "getpainweaponsize_exposed" },
    { 0x5A2A, "getparent" },
    { 0x5A2B, "getparticipantsinradius" },
    { 0x5A2C, "getpasserdirection" },
    { 0x5A2D, "getpasserorigin" },
    { 0x5A2E, "getpassiveattachment" },
    { 0x5A2F, "getpassivedeathwatching" },
    { 0x5A30, "getpassivemessage" },
    { 0x5A31, "getpassiveperk" },
    { 0x5A32, "getpassivesforweapon" },
    { 0x5A33, "getpassivestruct" },
    { 0x5A34, "getpassivevalue" },
    { 0x5A35, "getpathactionvalue" },
    { 0x5A36, "getpatharray" },
    { 0x5A37, "getpathend" },
    { 0x5A38, "getpathsighttestnodes" },
    { 0x5A39, "getpathstart" },
    { 0x5A3A, "getpatrolreactalias" },
    { 0x5A3B, "getpatrolreactdirindex" },
    { 0x5A3C, "getpatrolscore" },
    { 0x5A3D, "getpentinteractionusefunc" },
    { 0x5A3E, "getpentparams" },
    { 0x5A3F, "getperkadjustedkillstreakcost" },
    { 0x5A40, "getperkid" },
    { 0x5A41, "getperkslot" },
    { 0x5A42, "getpersonalpatrolscore" },
    { 0x5A43, "getpersstat" },
    { 0x5A44, "getphysicspointaboutnavmesh" },
    { 0x5A45, "getpitchtoshootentorpos" },
    { 0x5A46, "getpitchtoshootspot" },
    { 0x5A47, "getpitchtospot3d" },
    { 0x5A48, "getplaneflightplan" },
    { 0x5A49, "getplaneflyheight" },
    { 0x5A4A, "getplateinsertiontime" },
    { 0x5A4B, "getplayeranimfile" },
    { 0x5A4C, "getplayerassets" },
    { 0x5A4D, "getplayerbodymodel" },
    { 0x5A4E, "getplayerbuffs" },
    { 0x5A4F, "getplayercharacter" },
    { 0x5A50, "getplayerclaymores" },
    { 0x5A51, "getplayercustomization" },
    { 0x5A52, "getplayerdataloadoutgroup" },
    { 0x5A53, "getplayerdebuffs" },
    { 0x5A54, "getplayerempimmune" },
    { 0x5A55, "getplayerfoleytype" },
    { 0x5A56, "getplayerforguid" },
    { 0x5A57, "getplayerfromclientnum" },
    { 0x5A58, "getplayerheadmodel" },
    { 0x5A59, "getplayerhelispeed" },
    { 0x5A5A, "getplayerkills" },
    { 0x5A5B, "getplayerkillstreakcombatmode" },
    { 0x5A5C, "getplayerlookattarget" },
    { 0x5A5D, "getplayermodelindex" },
    { 0x5A5E, "getplayermodelname" },
    { 0x5A5F, "getplayerpitch" },
    { 0x5A60, "getplayerrespawnloc" },
    { 0x5A61, "getplayerrotationforbreach" },
    { 0x5A62, "getplayers" },
    { 0x5A63, "getplayersidesfromposition" },
    { 0x5A64, "getplayersinradius" },
    { 0x5A65, "getplayersinradiusview" },
    { 0x5A66, "getplayersinteam" },
    { 0x5A67, "getplayerspeedbyweapon" },
    { 0x5A68, "getplayerstat" },
    { 0x5A69, "getplayerstatpathkey" },
    { 0x5A6A, "getplayerstreakdata" },
    { 0x5A6B, "getplayersuperfaction" },
    { 0x5A6C, "getplayersusingthisinteraction" },
    { 0x5A6D, "getplayerthatseesmyscope" },
    { 0x5A6E, "getplayertospectate" },
    { 0x5A6F, "getplayertraceheight" },
    { 0x5A70, "getplayerviewmodelfrombody" },
    { 0x5A71, "getplayerweaponrank" },
    { 0x5A72, "getplayerweaponrankxp" },
    { 0x5A73, "getplayeryaw" },
    { 0x5A74, "getplcratedata" },
    { 0x5A75, "getpoolindex" },
    { 0x5A76, "getpostloadbink" },
    { 0x5A77, "getpotentiallivingplayers" },
    { 0x5A78, "getpower" },
    { 0x5A79, "getpowercooldowntime" },
    { 0x5A7A, "getpowerovertimeduration" },
    { 0x5A7B, "getpowerpassiveasset" },
    { 0x5A7C, "getpowerpassivestruct" },
    { 0x5A7D, "getpredictedaimpitchtoshootentorpos3d" },
    { 0x5A7E, "getpredictedaimyawtoshootentorpos" },
    { 0x5A7F, "getpredictedaimyawtoshootentorpos3d" },
    { 0x5A80, "getpreferreddompoints" },
    { 0x5A81, "getpreferredweapon" },
    { 0x5A82, "getprematchlocationspawnorigins" },
    { 0x5A83, "getprematchradius" },
    { 0x5A84, "getprematchspawnorigin" },
    { 0x5A85, "getprestigelevel" },
    { 0x5A86, "getpreviousselectablekillstreakslot" },
    { 0x5A87, "getpriceenemytarget" },
    { 0x5A88, "getprioritymultiplier" },
    { 0x5A89, "getprioritywaittime" },
    { 0x5A8A, "getpronedeathanim" },
    { 0x5A8B, "getpronepainanim" },
    { 0x5A8C, "getproperty" },
    { 0x5A8D, "getqacalloutalias" },
    { 0x5A8E, "getquadrant" },
    { 0x5A8F, "getquestdata" },
    { 0x5A90, "getquestindex" },
    { 0x5A91, "getquestinstancedata" },
    { 0x5A92, "getquestreward" },
    { 0x5A93, "getquesttableindex" },
    { 0x5A94, "getquesttablereward" },
    { 0x5A95, "getqueueevents" },
    { 0x5A96, "getradiuspathsighttestnodes" },
    { 0x5A97, "getraidspawnpoint" },
    { 0x5A98, "getrallyvehiclespawndata" },
    { 0x5A99, "getrandom_spammodel" },
    { 0x5A9A, "getrandomanimentry" },
    { 0x5A9B, "getrandomarchetype" },
    { 0x5A9C, "getrandomarmkillstreak" },
    { 0x5A9D, "getrandomattachments" },
    { 0x5A9E, "getrandomdirection" },
    { 0x5A9F, "getrandomgraverobberattachment" },
    { 0x5AA0, "getrandomindex" },
    { 0x5AA1, "getrandomintfromseed" },
    { 0x5AA2, "getrandomkeyfromweightsarray" },
    { 0x5AA3, "getrandomkillstreak" },
    { 0x5AA4, "getrandomplayersinteam" },
    { 0x5AA5, "getrandompoint" },
    { 0x5AA6, "getrandompointincircle" },
    { 0x5AA7, "getrandompointincpmap" },
    { 0x5AA8, "getrandompointincurrentcircle" },
    { 0x5AA9, "getrandomspawnpointfromactivesets" },
    { 0x5AAA, "getrandomspawnpointfromset" },
    { 0x5AAB, "getrandomspawnweapon" },
    { 0x5AAC, "getrandomunblockedanim" },
    { 0x5AAD, "getrandomweapon" },
    { 0x5AAE, "getrandomweaponattachments" },
    { 0x5AAF, "getrandomweaponforweapontier" },
    { 0x5AB0, "getrandomweaponfromcategory" },
    { 0x5AB1, "getrank" },
    { 0x5AB2, "getrankforxp" },
    { 0x5AB3, "getrankfromname" },
    { 0x5AB4, "getrankinfofull" },
    { 0x5AB5, "getrankinfoicon" },
    { 0x5AB6, "getrankinfolevel" },
    { 0x5AB7, "getrankinfomaxxp" },
    { 0x5AB8, "getrankinfominxp" },
    { 0x5AB9, "getrankinfoxpamt" },
    { 0x5ABA, "getrankxp" },
    { 0x5ABB, "getrankxpmultiplier" },
    { 0x5ABC, "getrankxpmultipliertotal" },
    { 0x5ABD, "getrapidarchivewarningrate" },
    { 0x5ABE, "getrawbaseweaponname" },
    { 0x5ABF, "getreactangleindex" },
    { 0x5AC0, "getrecoilreductionvalue" },
    { 0x5AC1, "getregendata" },
    { 0x5AC2, "getregionforpos" },
    { 0x5AC3, "getrelativeangles" },
    { 0x5AC4, "getrelativeteam" },
    { 0x5AC5, "getremainingburstdelaytime" },
    { 0x5AC6, "getremotename" },
    { 0x5AC7, "getreservedobjid" },
    { 0x5AC8, "getrespawnableplayers" },
    { 0x5AC9, "getrespawndelay" },
    { 0x5ACA, "getresponder" },
    { 0x5ACB, "getrestartlevel" },
    { 0x5ACC, "getreticleindex" },
    { 0x5ACD, "getrevivecameradata" },
    { 0x5ACE, "getrevivetimescaler" },
    { 0x5ACF, "getridofweapon" },
    { 0x5AD0, "getrigindexfromarchetyperef" },
    { 0x5AD1, "getrigsuperputawaydurationfromref" },
    { 0x5AD2, "getrigsupertakeoutdurationfromref" },
    { 0x5AD3, "getrigtransstringfromref" },
    { 0x5AD4, "getrockettargetpos" },
    { 0x5AD5, "getrootsuperref" },
    { 0x5AD6, "getroundswon" },
    { 0x5AD7, "getrunningforwarddeathanim" },
    { 0x5AD8, "getrunningforwardpainanim" },
    { 0x5AD9, "getsafeanimmovedeltapercentage" },
    { 0x5ADA, "getsafecircleorigin" },
    { 0x5ADB, "getsafecircleradius" },
    { 0x5ADC, "getsantizedhealth" },
    { 0x5ADD, "getscenebufferduration" },
    { 0x5ADE, "getscoredpatrolpoint" },
    { 0x5ADF, "getscoredpatrolpoint2" },
    { 0x5AE0, "getscoredpatrolpoints" },
    { 0x5AE1, "getscoreeventpriority" },
    { 0x5AE2, "getscoreinfocategory" },
    { 0x5AE3, "getscoreinfovalue" },
    { 0x5AE4, "getscorelimit" },
    { 0x5AE5, "getscoreperminute" },
    { 0x5AE6, "getscoreperminuteroundbased" },
    { 0x5AE7, "getscoreremaining" },
    { 0x5AE8, "getscriptdataversion" },
    { 0x5AE9, "getscriptedhelidropheight" },
    { 0x5AEA, "getscriptedhelidropheightbase" },
    { 0x5AEB, "getscriptedweapon" },
    { 0x5AEC, "getseatoriginangles" },
    { 0x5AED, "getsecondbtmbombloc" },
    { 0x5AEE, "getsecondspassed" },
    { 0x5AEF, "getselectedkillstreak" },
    { 0x5AF0, "getselectedkillstreakindex" },
    { 0x5AF1, "getselectmappoint" },
    { 0x5AF2, "getselfobjcaptureddialog" },
    { 0x5AF3, "getsetclassicsuit" },
    { 0x5AF4, "getsettdefsuit" },
    { 0x5AF5, "getsharedfunc" },
    { 0x5AF6, "getshellshockinterruptdelayms" },
    { 0x5AF7, "getshootfrompos" },
    { 0x5AF8, "getshootpos" },
    { 0x5AF9, "getshotdistancetype" },
    { 0x5AFA, "getsidearmdist" },
    { 0x5AFB, "getsitreplocname" },
    { 0x5AFC, "getsmartobjectinfo" },
    { 0x5AFD, "getsmartobjectradiussq" },
    { 0x5AFE, "getsmartobjecttype" },
    { 0x5AFF, "getsmoothstep" },
    { 0x5B00, "getsniper_starttime" },
    { 0x5B01, "getsniperadsblurtime" },
    { 0x5B02, "getsniperburstdelaytime" },
    { 0x5B03, "getsoonerhud" },
    { 0x5B04, "getsoundlength" },
    { 0x5B05, "getspawnangles" },
    { 0x5B06, "getspawnbucketfromstring" },
    { 0x5B07, "getspawncamera" },
    { 0x5B08, "getspawncamerawaittime" },
    { 0x5B09, "getspawnclosetposition" },
    { 0x5B0A, "getspawnerarrayfunction" },
    { 0x5B0B, "getspawnerstructbehindcurplayer" },
    { 0x5B0C, "getspawninfo" },
    { 0x5B0D, "getspawninfofunc" },
    { 0x5B0E, "getspawnorigin" },
    { 0x5B0F, "getspawnpoint" },
    { 0x5B10, "getspawnpoint_legacy" },
    { 0x5B11, "getspawnpoint_random" },
    { 0x5B12, "getspawnpoint_startspawn" },
    { 0x5B13, "getspawnpointarray" },
    { 0x5B14, "getspawnpointdist" },
    { 0x5B15, "getspawnpointflagassignment" },
    { 0x5B16, "getspawnpointfromcode" },
    { 0x5B17, "getspawnpointfromlist" },
    { 0x5B18, "getspawnpointpreprocess" },
    { 0x5B19, "getspawnselectionconstexclusiongrowth" },
    { 0x5B1A, "getspawnselectioncontexclusiongrowth" },
    { 0x5B1B, "getspawnselectionexclusionsize" },
    { 0x5B1C, "getspawnselectionlerpexclusiongrowth" },
    { 0x5B1D, "getspawnselectionlockedtimer" },
    { 0x5B1E, "getspawnselectionpoi" },
    { 0x5B1F, "getspawnsessionteamassignment" },
    { 0x5B20, "getspawnsetsize" },
    { 0x5B21, "getspawnstructscallback" },
    { 0x5B22, "getspawnteam" },
    { 0x5B23, "getspawnteamassignment" },
    { 0x5B24, "getspeakerinfo" },
    { 0x5B25, "getspeakerorigin" },
    { 0x5B26, "getspeakers" },
    { 0x5B27, "getspecialistindexforstreak" },
    { 0x5B28, "getspecialistperkforstreak" },
    { 0x5B29, "getspecialistsplashfromkillstreak" },
    { 0x5B2A, "getspectatepoint" },
    { 0x5B2B, "getspeedmatchanimrate" },
    { 0x5B2C, "getsplashid" },
    { 0x5B2D, "getsplashtablemaxaltdisplays" },
    { 0x5B2E, "getsplashtablename" },
    { 0x5B2F, "getsplittimes" },
    { 0x5B30, "getsplittimesside" },
    { 0x5B31, "getsppmdata" },
    { 0x5B32, "getsquadleader" },
    { 0x5B33, "getsquadteam" },
    { 0x5B34, "getstackcount" },
    { 0x5B35, "getstackvalues" },
    { 0x5B36, "getstairsenterdist" },
    { 0x5B37, "getstairsexitdist" },
    { 0x5B38, "getstairsexitdistup" },
    { 0x5B39, "getstancecenter" },
    { 0x5B3A, "getstanddeathanim" },
    { 0x5B3B, "getstandpainanim" },
    { 0x5B3C, "getstandpistoldeathanim" },
    { 0x5B3D, "getstandpistolpainanim" },
    { 0x5B3E, "getstartanim" },
    { 0x5B3F, "getstartmindist" },
    { 0x5B40, "getstartspawnavg" },
    { 0x5B41, "getstartspawnpoint_freeforall" },
    { 0x5B42, "getstat_intel" },
    { 0x5B43, "getstat_progression" },
    { 0x5B44, "getstaticcameraposition" },
    { 0x5B45, "getstealthlocationalias" },
    { 0x5B46, "getstealthstate" },
    { 0x5B47, "getstickerloadoutstring" },
    { 0x5B48, "getstopanims" },
    { 0x5B49, "getstopdatafortransition" },
    { 0x5B4A, "getstrafeanimweights" },
    { 0x5B4B, "getstreakrecordtype" },
    { 0x5B4C, "getstrongbulletdamagedeathanim" },
    { 0x5B4D, "getstruct" },
    { 0x5B4E, "getstruct_delete" },
    { 0x5B4F, "getstructarray" },
    { 0x5B50, "getstructarray_delete" },
    { 0x5B51, "getsuffocationdeathanim" },
    { 0x5B52, "getsuperid" },
    { 0x5B53, "getsuperpointsforevent" },
    { 0x5B54, "getsuperpointsneeded" },
    { 0x5B55, "getsuperrefforsuperoffhand" },
    { 0x5B56, "getsuperrefforsuperuseweapon" },
    { 0x5B57, "getsuperrefforsuperweapon" },
    { 0x5B58, "getsuperuseuiprogress" },
    { 0x5B59, "getsuppressionstrength" },
    { 0x5B5A, "getsuspendedvehiclecount" },
    { 0x5B5B, "getswitchside_spawnpoint" },
    { 0x5B5C, "gettacopstimeextensionsms" },
    { 0x5B5D, "gettacopstimelimitms" },
    { 0x5B5E, "gettacopstimepassedms" },
    { 0x5B5F, "gettacopstimeremainingms" },
    { 0x5B60, "gettacticaltypepassives" },
    { 0x5B61, "gettag" },
    { 0x5B62, "gettagcode" },
    { 0x5B63, "gettagcountfromcache" },
    { 0x5B64, "gettagforpos" },
    { 0x5B65, "gettakennodes" },
    { 0x5B66, "gettangentoncirclefrompoint" },
    { 0x5B67, "gettarget" },
    { 0x5B68, "gettargetangleoffset" },
    { 0x5B69, "gettargetarray" },
    { 0x5B6A, "gettargetbounty" },
    { 0x5B6B, "gettargetchargepos" },
    { 0x5B6C, "gettargetmarker" },
    { 0x5B6D, "gettargetmarkergroup" },
    { 0x5B6E, "gettargetoffset" },
    { 0x5B6F, "gettargetorigin" },
    { 0x5B70, "gettargettingai" },
    { 0x5B71, "getteamarray" },
    { 0x5B72, "getteambalance" },
    { 0x5B73, "getteamcenter" },
    { 0x5B74, "getteamcount" },
    { 0x5B75, "getteamdata" },
    { 0x5B76, "getteamdompoints" },
    { 0x5B77, "getteamfallbackspawnpoints" },
    { 0x5B78, "getteamflagcount" },
    { 0x5B79, "getteamheadicon" },
    { 0x5B7A, "getteamicon" },
    { 0x5B7B, "getteamindex" },
    { 0x5B7C, "getteammatesoutofcombat" },
    { 0x5B7D, "getteamname" },
    { 0x5B7E, "getteamoperatorvoicefaction" },
    { 0x5B7F, "getteamrankxpmultiplier" },
    { 0x5B80, "getteamscoreint" },
    { 0x5B81, "getteamshortname" },
    { 0x5B82, "getteamsize" },
    { 0x5B83, "getteamspawnpoints" },
    { 0x5B84, "getteamvehiclearray" },
    { 0x5B85, "getteamvoiceinfix" },
    { 0x5B86, "getthermalswitchplayercommand" },
    { 0x5B87, "getthreatinfantrycallouttype" },
    { 0x5B88, "getthreatsovertime" },
    { 0x5B89, "gettimefrommatchstart" },
    { 0x5B8A, "gettimelimit" },
    { 0x5B8B, "gettimepassed" },
    { 0x5B8C, "gettimepassedpercentage" },
    { 0x5B8D, "gettimeremaining" },
    { 0x5B8E, "gettimeremainingpercentage" },
    { 0x5B8F, "gettimesincedompointcapture" },
    { 0x5B90, "gettimesincegamestart" },
    { 0x5B91, "getting_too_close_with_player_humvee" },
    { 0x5B92, "getting_too_close_with_vehicle_to_chase" },
    { 0x5B93, "gettinggassed" },
    { 0x5B94, "gettingloadout" },
    { 0x5B95, "gettotalpercentcompletesp" },
    { 0x5B96, "gettouchinglocaletriggers" },
    { 0x5B97, "gettranssplittime" },
    { 0x5B98, "gettraversalendpos" },
    { 0x5B99, "gettraversalstartnode" },
    { 0x5B9A, "gettraverserindex" },
    { 0x5B9B, "gettriggeredslotfromnotify" },
    { 0x5B9C, "gettriggerfunc" },
    { 0x5B9D, "gettriggerobject" },
    { 0x5B9E, "gettriggertype" },
    { 0x5B9F, "gettripwiremodel" },
    { 0x5BA0, "gettripwirestaticmodel" },
    { 0x5BA1, "gettripwirestretchanim" },
    { 0x5BA2, "gettripwiretraps" },
    { 0x5BA3, "gettripwiretriggeranim" },
    { 0x5BA4, "gettripwiretriggersound" },
    { 0x5BA5, "gettruenodeangles" },
    { 0x5BA6, "getturndesiredpitch3d" },
    { 0x5BA7, "getturndesiredyaw" },
    { 0x5BA8, "getturndesiredyaw3d" },
    { 0x5BA9, "getturretaimangles" },
    { 0x5BAA, "getturretaimanglessp" },
    { 0x5BAB, "gettweakabledvar" },
    { 0x5BAC, "gettweakabledvarvalue" },
    { 0x5BAD, "gettweakablelastvalue" },
    { 0x5BAE, "gettweakablevalue" },
    { 0x5BAF, "getuavrig" },
    { 0x5BB0, "getunclaimedpersonalent" },
    { 0x5BB1, "getunifedspawnselectioncameraheight" },
    { 0x5BB2, "getuniqueflagnameindex" },
    { 0x5BB3, "getuniqueid" },
    { 0x5BB4, "getuniquekillstreakid" },
    { 0x5BB5, "getuniquematerialscost" },
    { 0x5BB6, "getuniqueobjectid" },
    { 0x5BB7, "getunownedflagneareststart" },
    { 0x5BB8, "getup_from_prone" },
    { 0x5BB9, "getupdateteams" },
    { 0x5BBA, "getupenemy" },
    { 0x5BBB, "getupenemy_logic" },
    { 0x5BBC, "getusedturret" },
    { 0x5BBD, "getusingproxdoors" },
    { 0x5BBE, "getvalidattachments" },
    { 0x5BBF, "getvalidextraammoweapons" },
    { 0x5BC0, "getvalidlocation" },
    { 0x5BC1, "getvalidplayersinarray" },
    { 0x5BC2, "getvalidplayersinteam" },
    { 0x5BC3, "getvalidpointtopointmovelocation" },
    { 0x5BC4, "getvalidspawnpathnodenearplayer" },
    { 0x5BC5, "getvalidtakeweapon" },
    { 0x5BC6, "getvartype" },
    { 0x5BC7, "getvectorarrayaverage" },
    { 0x5BC8, "getvectorrightangle" },
    { 0x5BC9, "getvehicle" },
    { 0x5BCA, "getvehicleanimtargetoriginandangles" },
    { 0x5BCB, "getvehiclearray" },
    { 0x5BCC, "getvehiclearray_in_radius" },
    { 0x5BCD, "getvehiclecount" },
    { 0x5BCE, "getvehiclepath" },
    { 0x5BCF, "getvehiclespawndata" },
    { 0x5BD0, "getvehiclespawner" },
    { 0x5BD1, "getvehiclespawnerarray" },
    { 0x5BD2, "getvisiblekillstreakavailable" },
    { 0x5BD3, "getvisionlerprate" },
    { 0x5BD4, "getvocalpainsfx" },
    { 0x5BD5, "getvoforobjective" },
    { 0x5BD6, "getvolumebasenamefromlinkname" },
    { 0x5BD7, "getvulnerableplayersinteam" },
    { 0x5BD8, "getwalkandtalkanimweights" },
    { 0x5BD9, "getwallattachoffsetposition" },
    { 0x5BDA, "getwallnodeposition" },
    { 0x5BDB, "getwallrundirection" },
    { 0x5BDC, "getwallrundirectionfromstartnode" },
    { 0x5BDD, "getwallrunmantleangles" },
    { 0x5BDE, "getwallrunmantleposition" },
    { 0x5BDF, "getwallruntomantletype" },
    { 0x5BE0, "getwallrunyawfromstartnode" },
    { 0x5BE1, "getwatcheddvar" },
    { 0x5BE2, "getwatcheddvarstring" },
    { 0x5BE3, "getwaypointbackgroundcolor" },
    { 0x5BE4, "getwaypointbackgroundtype" },
    { 0x5BE5, "getwaypointobjpulse" },
    { 0x5BE6, "getwaypointshader" },
    { 0x5BE7, "getwaypointstring" },
    { 0x5BE8, "getweapon" },
    { 0x5BE9, "getweapon_aq" },
    { 0x5BEA, "getweapon_hero" },
    { 0x5BEB, "getweapon_reb" },
    { 0x5BEC, "getweapon_ru" },
    { 0x5BED, "getweapon_ru_1999" },
    { 0x5BEE, "getweapon_ru_lab" },
    { 0x5BEF, "getweapon_sas" },
    { 0x5BF0, "getweapon_so15" },
    { 0x5BF1, "getweapon_usmc" },
    { 0x5BF2, "getweaponassetfromrootweapon" },
    { 0x5BF3, "getweaponattachmentarray" },
    { 0x5BF4, "getweaponattachmentarrayfromstats" },
    { 0x5BF5, "getweaponattachmentsbasenames" },
    { 0x5BF6, "getweaponbasenamescript" },
    { 0x5BF7, "getweaponcamo" },
    { 0x5BF8, "getweaponchoice" },
    { 0x5BF9, "getweaponclass" },
    { 0x5BFA, "getweaponcosmeticattachment" },
    { 0x5BFB, "getweaponcostint" },
    { 0x5BFC, "getweapondefaults" },
    { 0x5BFD, "getweaponforpos" },
    { 0x5BFE, "getweaponfromequipmentref" },
    { 0x5BFF, "getweaponfrommerit" },
    { 0x5C00, "getweaponfullname" },
    { 0x5C01, "getweapongroup" },
    { 0x5C02, "getweapongunsmithattachmenttable" },
    { 0x5C03, "getweaponheaviestvalue" },
    { 0x5C04, "getweaponmaxrankxp" },
    { 0x5C05, "getweaponnamestring" },
    { 0x5C06, "getweaponnvgattachment" },
    { 0x5C07, "getweaponoffhandclass" },
    { 0x5C08, "getweaponoffhandtype" },
    { 0x5C09, "getweaponpaintjobid" },
    { 0x5C0A, "getweaponpassives" },
    { 0x5C0B, "getweaponqualitybyid" },
    { 0x5C0C, "getweaponrankforxp" },
    { 0x5C0D, "getweaponrankinfomaxxp" },
    { 0x5C0E, "getweaponrankinfominxp" },
    { 0x5C0F, "getweaponrankinfoxptonextrank" },
    { 0x5C10, "getweaponrankxpmultiplier" },
    { 0x5C11, "getweaponrankxpmultipliertotal" },
    { 0x5C12, "getweaponreticle" },
    { 0x5C13, "getweaponrootname" },
    { 0x5C14, "getweapons" },
    { 0x5C15, "getweaponslist" },
    { 0x5C16, "getweaponspeed" },
    { 0x5C17, "getweaponspeedslowest" },
    { 0x5C18, "getweaponswithpassive" },
    { 0x5C19, "getweapontoswitchbackto" },
    { 0x5C1A, "getweapontype" },
    { 0x5C1B, "getweapontypepassives" },
    { 0x5C1C, "getweaponvariantattachments" },
    { 0x5C1D, "getweaponvarianttablename" },
    { 0x5C1E, "getweaponweight" },
    { 0x5C1F, "getweightedchanceroll" },
    { 0x5C20, "getwholescenedurationmax" },
    { 0x5C21, "getwholescenedurationmin" },
    { 0x5C22, "getwingamebytype" },
    { 0x5C23, "getwinningteam" },
    { 0x5C24, "getyaw" },
    { 0x5C25, "getyaw2d" },
    { 0x5C26, "getyawfromorigin" },
    { 0x5C27, "getyawtoenemy" },
    { 0x5C28, "getyawtoorigin" },
    { 0x5C29, "getyawtospot" },
    { 0x5C2A, "getyawtospot3d" },
    { 0x5C2B, "getzbaseweaponname" },
    { 0x5C2C, "getzombiestealthvalues" },
    { 0x5C2D, "getzonearray" },
    { 0x5C2E, "ghalia" },
    { 0x5C2F, "ghostadvanceduavwatcher" },
    { 0x5C30, "ghostskulls_complete_status" },
    { 0x5C31, "ghostskulls_total_waves" },
    { 0x5C32, "ghostskullstimestart" },
    { 0x5C33, "gib_override_func" },
    { 0x5C34, "gibbing_buildskeletonlower" },
    { 0x5C35, "gibbing_buildskeletonupper" },
    { 0x5C36, "gibbing_cleanupgibmodels" },
    { 0x5C37, "gibbing_codeversion" },
    { 0x5C38, "gibbing_gibai" },
    { 0x5C39, "gibbing_scriptversion" },
    { 0x5C3A, "gibbing_shouldgibai" },
    { 0x5C3B, "gibbing_skeltonbuildpart" },
    { 0x5C3C, "giv_emp_drone" },
    { 0x5C3D, "give_action_slot_weapon" },
    { 0x5C3E, "give_adrenaline_for_time" },
    { 0x5C3F, "give_adrenaline_shot" },
    { 0x5C40, "give_alex_weapon" },
    { 0x5C41, "give_all_players_munition" },
    { 0x5C42, "give_all_players_nearby" },
    { 0x5C43, "give_ally_equipment" },
    { 0x5C44, "give_ammo" },
    { 0x5C45, "give_ammo_clip" },
    { 0x5C46, "give_ammo_from_scavenged_weapon" },
    { 0x5C47, "give_ammo_to_player_through_crate" },
    { 0x5C48, "give_amped" },
    { 0x5C49, "give_and_switch_to_loadout_weapons" },
    { 0x5C4A, "give_and_switch_to_weapon" },
    { 0x5C4B, "give_armor_loadout" },
    { 0x5C4C, "give_assault_class" },
    { 0x5C4D, "give_attacker_kill_rewards" },
    { 0x5C4E, "give_auto_revive" },
    { 0x5C4F, "give_auto_revive_crate" },
    { 0x5C50, "give_beam_ammo" },
    { 0x5C51, "give_bullet_penetration" },
    { 0x5C52, "give_capture_credit" },
    { 0x5C53, "give_cloak" },
    { 0x5C54, "give_closest_player_nearby" },
    { 0x5C55, "give_cluster_strike" },
    { 0x5C56, "give_consumable" },
    { 0x5C57, "give_core" },
    { 0x5C58, "give_crafted_ammo_crate" },
    { 0x5C59, "give_crafted_sentry" },
    { 0x5C5A, "give_crusader_class" },
    { 0x5C5B, "give_death_intel" },
    { 0x5C5C, "give_default_class" },
    { 0x5C5D, "give_default_terrorist_loadout" },
    { 0x5C5E, "give_deployable_cover" },
    { 0x5C5F, "give_disguise_via_clothes" },
    { 0x5C60, "give_engineer_class" },
    { 0x5C61, "give_eod" },
    { 0x5C62, "give_fast_fire" },
    { 0x5C63, "give_fists_if_no_real_weapon" },
    { 0x5C64, "give_flashlight" },
    { 0x5C65, "give_green_beam" },
    { 0x5C66, "give_grenade" },
    { 0x5C67, "give_grenadier_launcher" },
    { 0x5C68, "give_gunner_turret" },
    { 0x5C69, "give_gunship_access_after_personal_delay" },
    { 0x5C6A, "give_guy_pacifist_override" },
    { 0x5C6B, "give_hack_target" },
    { 0x5C6C, "give_health_pack" },
    { 0x5C6D, "give_hunter_class" },
    { 0x5C6E, "give_hvt_ar" },
    { 0x5C6F, "give_infinite_ammo" },
    { 0x5C70, "give_instant_revive" },
    { 0x5C71, "give_intel_weapon" },
    { 0x5C72, "give_inv_cooldown" },
    { 0x5C73, "give_invulnerability" },
    { 0x5C74, "give_juggernaut_suit" },
    { 0x5C75, "give_kidnapper_loadout" },
    { 0x5C76, "give_kyle_weapon" },
    { 0x5C77, "give_laststand" },
    { 0x5C78, "give_loadout_after_entire_landing_is_done" },
    { 0x5C79, "give_loadout_and_core" },
    { 0x5C7A, "give_loadout_back_after_landing" },
    { 0x5C7B, "give_loadout_func" },
    { 0x5C7C, "give_long_range_loadout" },
    { 0x5C7D, "give_loot_based_on_pickup" },
    { 0x5C7E, "give_mark_enemies" },
    { 0x5C7F, "give_max_ammo_to_player" },
    { 0x5C80, "give_medic_class" },
    { 0x5C81, "give_melee_weapon" },
    { 0x5C82, "give_message_to_player" },
    { 0x5C83, "give_missile_defense_weapons" },
    { 0x5C84, "give_mp_super_weapon" },
    { 0x5C85, "give_munition" },
    { 0x5C86, "give_munition_to_slot" },
    { 0x5C87, "give_nuclear_core" },
    { 0x5C88, "give_nuclear_core_from_parachute" },
    { 0x5C89, "give_objective_skillpoints" },
    { 0x5C8A, "give_offhand" },
    { 0x5C8B, "give_offhands" },
    { 0x5C8C, "give_one_lead_to_each_player" },
    { 0x5C8D, "give_permanent_perks" },
    { 0x5C8E, "give_pistol_ammo" },
    { 0x5C8F, "give_pistol_ammo_if_nerf_active" },
    { 0x5C90, "give_player_class" },
    { 0x5C91, "give_player_crafted_power" },
    { 0x5C92, "give_player_currency" },
    { 0x5C93, "give_player_faction" },
    { 0x5C94, "give_player_max_ammo" },
    { 0x5C95, "give_player_max_ammo_on_pickup" },
    { 0x5C96, "give_player_max_armor" },
    { 0x5C97, "give_player_session_tokens" },
    { 0x5C98, "give_player_session_xp" },
    { 0x5C99, "give_player_super" },
    { 0x5C9A, "give_player_wall_bought_power" },
    { 0x5C9B, "give_player_weapon_xp" },
    { 0x5C9C, "give_player_xp" },
    { 0x5C9D, "give_playtest_munitions" },
    { 0x5C9E, "give_point" },
    { 0x5C9F, "give_poison_gas_loadout" },
    { 0x5CA0, "give_primary_weapon" },
    { 0x5CA1, "give_reaper_weapons" },
    { 0x5CA2, "give_recon_silencer" },
    { 0x5CA3, "give_restock" },
    { 0x5CA4, "give_scavenger" },
    { 0x5CA5, "give_score_to_hero_team" },
    { 0x5CA6, "give_secondary_weapon" },
    { 0x5CA7, "give_sentry_turret" },
    { 0x5CA8, "give_shoulder_launchers" },
    { 0x5CA9, "give_shrapnel" },
    { 0x5CAA, "give_skill_points" },
    { 0x5CAB, "give_skillpoints_at_start" },
    { 0x5CAC, "give_soldier_armor" },
    { 0x5CAD, "give_soldier_helmet" },
    { 0x5CAE, "give_spotter_scope" },
    { 0x5CAF, "give_stealth_loadout" },
    { 0x5CB0, "give_suicide_bomber_loadout" },
    { 0x5CB1, "give_super_weapon" },
    { 0x5CB2, "give_surrendered_intel" },
    { 0x5CB3, "give_tank_class" },
    { 0x5CB4, "give_team_armor_buff" },
    { 0x5CB5, "give_team_auto_revive" },
    { 0x5CB6, "give_team_stopping_power" },
    { 0x5CB7, "give_thermite_launcher" },
    { 0x5CB8, "give_toma_strike" },
    { 0x5CB9, "give_tune_up" },
    { 0x5CBA, "give_uav" },
    { 0x5CBB, "give_up_asset" },
    { 0x5CBC, "give_up_counter" },
    { 0x5CBD, "give_up_easy_setup" },
    { 0x5CBE, "give_up_func" },
    { 0x5CBF, "give_up_loop" },
    { 0x5CC0, "give_up_monitor" },
    { 0x5CC1, "give_up_push_anim" },
    { 0x5CC2, "give_up_release_anim" },
    { 0x5CC3, "give_up_release_sequence" },
    { 0x5CC4, "give_up_request_sequence" },
    { 0x5CC5, "give_up_requested" },
    { 0x5CC6, "give_up_rumble_ent" },
    { 0x5CC7, "give_up_state" },
    { 0x5CC8, "give_updated_loadout" },
    { 0x5CC9, "give_weapon" },
    { 0x5CCA, "give_weapon_coop" },
    { 0x5CCB, "give_weapons_back" },
    { 0x5CCC, "give_weapons_from_loadout" },
    { 0x5CCD, "giveachievement_wrapper" },
    { 0x5CCE, "giveadrenalinecrate" },
    { 0x5CCF, "giveammocrate" },
    { 0x5CD0, "givearmor" },
    { 0x5CD1, "givearmorcrate" },
    { 0x5CD2, "giveaward" },
    { 0x5CD3, "giveboostscore" },
    { 0x5CD4, "givebreachscore" },
    { 0x5CD5, "givecaptureawards" },
    { 0x5CD6, "givecarryremoteuav" },
    { 0x5CD7, "givecover" },
    { 0x5CD8, "givecrafteditemthruluinotify" },
    { 0x5CD9, "givedefaultlaststandweapon" },
    { 0x5CDA, "givedefaultloadout" },
    { 0x5CDB, "givedefusescore" },
    { 0x5CDC, "givedisguiseonspawn" },
    { 0x5CDD, "giveequipment" },
    { 0x5CDE, "giveequipmentasaweapon" },
    { 0x5CDF, "giveextraaonperks" },
    { 0x5CE0, "giveextrainfectedperks" },
    { 0x5CE1, "giveflagassistedcapturepoints" },
    { 0x5CE2, "giveflagcaptureassistxp" },
    { 0x5CE3, "giveflagcapturexp" },
    { 0x5CE4, "givefriendlyperks" },
    { 0x5CE5, "givegesture" },
    { 0x5CE6, "givegoproattachments" },
    { 0x5CE7, "givegrabscore" },
    { 0x5CE8, "givegrenadelauncher" },
    { 0x5CE9, "givegunless" },
    { 0x5CEA, "givegunlesscp" },
    { 0x5CEB, "givehealedoverlay" },
    { 0x5CEC, "givehealthcrate" },
    { 0x5CED, "giveholywater" },
    { 0x5CEE, "giveinteractiveinfilweapon" },
    { 0x5CEF, "giveitembasedoncraftingstruct" },
    { 0x5CF0, "givejuggernaut" },
    { 0x5CF1, "givejuggloadout" },
    { 0x5CF2, "givekillreward" },
    { 0x5CF3, "givekillstreak" },
    { 0x5CF4, "giveknifeback" },
    { 0x5CF5, "givekscratetoteam" },
    { 0x5CF6, "givelastonteamwarning" },
    { 0x5CF7, "givelaststandweapon" },
    { 0x5CF8, "giveloadout" },
    { 0x5CF9, "giveloadoutafterinfil" },
    { 0x5CFA, "givematchbonus" },
    { 0x5CFB, "givematchloadout" },
    { 0x5CFC, "givematchloadoutfordropbags" },
    { 0x5CFD, "givemeritscore" },
    { 0x5CFE, "givemidmatchaward" },
    { 0x5CFF, "givemidmatchawardfunc" },
    { 0x5D00, "givemunitionfromluinotify" },
    { 0x5D01, "givenextgun" },
    { 0x5D02, "giveobject" },
    { 0x5D03, "giveonemanarmyclass" },
    { 0x5D04, "giveortakethrowingknife" },
    { 0x5D05, "giveperk" },
    { 0x5D06, "giveperkoffhand" },
    { 0x5D07, "giveperkpointstoplayer" },
    { 0x5D08, "giveperks" },
    { 0x5D09, "giveperksafterspawn" },
    { 0x5D0A, "giveplaceable" },
    { 0x5D0B, "giveplayeraccessory" },
    { 0x5D0C, "giveplayerbonuscash" },
    { 0x5D0D, "giveplayerpassive" },
    { 0x5D0E, "giveplayerscore" },
    { 0x5D0F, "giveplayerweaponxp" },
    { 0x5D10, "givepower" },
    { 0x5D11, "givepracticemessage" },
    { 0x5D12, "giveprematchloadout" },
    { 0x5D13, "giverankxp" },
    { 0x5D14, "giverankxpafterwait" },
    { 0x5D15, "giverateye" },
    { 0x5D16, "giverecentshieldxp" },
    { 0x5D17, "giveriotshield" },
    { 0x5D18, "givescavengerammo" },
    { 0x5D19, "givescoreforassistdestroymarkedtarget" },
    { 0x5D1A, "givescoreforblackhat" },
    { 0x5D1B, "givescorefordestorymarkedtarget" },
    { 0x5D1C, "givescorefordestroyedtacinsert" },
    { 0x5D1D, "givescoreforempedkillstreak" },
    { 0x5D1E, "givescoreforempedplayer" },
    { 0x5D1F, "givescoreforempedvehicle" },
    { 0x5D20, "givescoreforequipment" },
    { 0x5D21, "givescoreforhack" },
    { 0x5D22, "givescoreformarktarget" },
    { 0x5D23, "givescorefortriggeredalarmeddoor" },
    { 0x5D24, "givescorefortrophyblocks" },
    { 0x5D25, "givesentry" },
    { 0x5D26, "giveskillpointsthruluinotify" },
    { 0x5D27, "givespecialistbonus" },
    { 0x5D28, "givestealthperks" },
    { 0x5D29, "givestreakpoints" },
    { 0x5D2A, "givestreakpointswithtext" },
    { 0x5D2B, "givesuper" },
    { 0x5D2C, "givesuperdisableweapon" },
    { 0x5D2D, "givesuperpoints" },
    { 0x5D2E, "givesuperweapon" },
    { 0x5D2F, "givesurvivortimescore" },
    { 0x5D30, "givetagsfromcache" },
    { 0x5D31, "giveteamplunderdistributive" },
    { 0x5D32, "giveteamplunderflat" },
    { 0x5D33, "giveteamscoreforobjective" },
    { 0x5D34, "givetkontispawn" },
    { 0x5D35, "giveunifiedpoints" },
    { 0x5D36, "giveuponsuppressiontime" },
    { 0x5D37, "givevalidweapon" },
    { 0x5D38, "giveweaponmaxammo" },
    { 0x5D39, "giveweaponpassives" },
    { 0x5D3A, "giveweaponpickup" },
    { 0x5D3B, "giveweaponsfromdropbag" },
    { 0x5D3C, "gl_audio_hooks" },
    { 0x5D3D, "gl_proj_override" },
    { 0x5D3E, "glancestop" },
    { 0x5D3F, "glancing" },
    { 0x5D40, "glass" },
    { 0x5D41, "glass_management" },
    { 0x5D42, "glass_panes" },
    { 0x5D43, "glinton" },
    { 0x5D44, "global_ai_func_array" },
    { 0x5D45, "global_callbacks" },
    { 0x5D46, "global_civ_spawn_func" },
    { 0x5D47, "global_color_func" },
    { 0x5D48, "global_door_threads" },
    { 0x5D49, "global_empty_callback" },
    { 0x5D4A, "global_fx" },
    { 0x5D4B, "global_physics_sound_monitor" },
    { 0x5D4C, "global_spawn_func" },
    { 0x5D4D, "global_stealth_broken" },
    { 0x5D4E, "global_stealth_tracker" },
    { 0x5D4F, "global_tables" },
    { 0x5D50, "global_vehicle_spawn_func" },
    { 0x5D51, "global_weapons_free" },
    { 0x5D52, "globalchatqueuecheck" },
    { 0x5D53, "globalobjectives" },
    { 0x5D54, "globalsonarthink" },
    { 0x5D55, "globalspawnareas" },
    { 0x5D56, "globalthink" },
    { 0x5D57, "globalthreatlevel" },
    { 0x5D58, "glowstick" },
    { 0x5D59, "glowstick_anim" },
    { 0x5D5A, "glowstick_fade_vfx" },
    { 0x5D5B, "glowstick_tag" },
    { 0x5D5C, "glowstick_vfx" },
    { 0x5D5D, "glprox_trygetweaponname" },
    { 0x5D5E, "glstarthelidownevent" },
    { 0x5D5F, "glstophelidownevent" },
    { 0x5D60, "glstopmoralesquest" },
    { 0x5D61, "go_away" },
    { 0x5D62, "go_check_out_corpse" },
    { 0x5D63, "go_fight" },
    { 0x5D64, "go_hunt_down_player" },
    { 0x5D65, "go_into_elevator" },
    { 0x5D66, "go_investigate_player_loc" },
    { 0x5D67, "go_through_patharray" },
    { 0x5D68, "go_to_3rd_floor_stairtain" },
    { 0x5D69, "go_to_backyard_main" },
    { 0x5D6A, "go_to_backyard_start" },
    { 0x5D6B, "go_to_exfil_location" },
    { 0x5D6C, "go_to_hunt" },
    { 0x5D6D, "go_to_landing_destination" },
    { 0x5D6E, "go_to_last_player_position" },
    { 0x5D6F, "go_to_node" },
    { 0x5D70, "go_to_node_arrived" },
    { 0x5D71, "go_to_node_end" },
    { 0x5D72, "go_to_node_internal" },
    { 0x5D73, "go_to_node_post_wait" },
    { 0x5D74, "go_to_node_set_goal" },
    { 0x5D75, "go_to_node_set_goal_ent" },
    { 0x5D76, "go_to_node_set_goal_node" },
    { 0x5D77, "go_to_node_set_goal_pos" },
    { 0x5D78, "go_to_node_should_stop" },
    { 0x5D79, "go_to_node_targetname" },
    { 0x5D7A, "go_to_node_wait" },
    { 0x5D7B, "go_to_node_wait_for_player" },
    { 0x5D7C, "go_to_node_wait_investigate" },
    { 0x5D7D, "go_to_spot" },
    { 0x5D7E, "go_to_struct_targetname" },
    { 0x5D7F, "go_to_targetname" },
    { 0x5D80, "go_to_targetname_helper" },
    { 0x5D81, "goal_distance" },
    { 0x5D82, "goal_ent" },
    { 0x5D83, "goal_ent_player" },
    { 0x5D84, "goal_ent_position" },
    { 0x5D85, "goal_pos_override" },
    { 0x5D86, "goal_position" },
    { 0x5D87, "goal_radius" },
    { 0x5D88, "goal_type" },
    { 0x5D89, "goal_watch_game_ended" },
    { 0x5D8A, "goal_waypoint" },
    { 0x5D8B, "goal_zone" },
    { 0x5D8C, "goalang" },
    { 0x5D8D, "goalanims" },
    { 0x5D8E, "goalenabletimer" },
    { 0x5D8F, "goalent" },
    { 0x5D90, "goalflag" },
    { 0x5D91, "goalmovetimer" },
    { 0x5D92, "goalnode_pw" },
    { 0x5D93, "goalnodes" },
    { 0x5D94, "goalpos_and_nagtill" },
    { 0x5D95, "goals" },
    { 0x5D96, "goaltime" },
    { 0x5D97, "goaltriggerwatcher" },
    { 0x5D98, "goalvolumecoveryaw" },
    { 0x5D99, "goalvolumes" },
    { 0x5D9A, "goback_func" },
    { 0x5D9B, "god_until_damage_by_player" },
    { 0x5D9C, "godmode" },
    { 0x5D9D, "godoff" },
    { 0x5D9E, "godon" },
    { 0x5D9F, "going_for_knife" },
    { 0x5DA0, "going_to_exfil" },
    { 0x5DA1, "going_to_object" },
    { 0x5DA2, "going_to_player" },
    { 0x5DA3, "goingtoproneaim" },
    { 0x5DA4, "golden_enemydamage" },
    { 0x5DA5, "golden_enemydeath" },
    { 0x5DA6, "golden_friendlyfire" },
    { 0x5DA7, "golden_path_fail" },
    { 0x5DA8, "goldenpath_moveto" },
    { 0x5DA9, "goldscore" },
    { 0x5DAA, "goldtime" },
    { 0x5DAB, "goliath_ai" },
    { 0x5DAC, "goliath_blood_stab_hands" },
    { 0x5DAD, "goliath_blood_stab_vfx" },
    { 0x5DAE, "goliath_bloody_footsteps" },
    { 0x5DAF, "goliath_body_model" },
    { 0x5DB0, "goliath_boss" },
    { 0x5DB1, "goliath_boss_location_monitor" },
    { 0x5DB2, "goliath_boss_round" },
    { 0x5DB3, "goliath_counter_kill" },
    { 0x5DB4, "goliath_counter_monitor" },
    { 0x5DB5, "goliath_delete_weapon_interacts_monitor" },
    { 0x5DB6, "goliath_flashlight" },
    { 0x5DB7, "goliath_grab_give_up_and_shoot" },
    { 0x5DB8, "goliath_grab_init" },
    { 0x5DB9, "goliath_grab_monitor" },
    { 0x5DBA, "goliath_has_lost_enemy" },
    { 0x5DBB, "goliath_hunt_known_location_monitor" },
    { 0x5DBC, "goliath_investigate" },
    { 0x5DBD, "goliath_knife_fov_scale_factor" },
    { 0x5DBE, "goliath_knife_monitor" },
    { 0x5DBF, "goliath_melee_allowed" },
    { 0x5DC0, "goliath_melee_weapon_interact" },
    { 0x5DC1, "goliath_melee_weapon_spawn_count" },
    { 0x5DC2, "goliath_melee_weapon_spawn_interact" },
    { 0x5DC3, "goliath_melee_weapon_swap" },
    { 0x5DC4, "goliath_player_death_monitor" },
    { 0x5DC5, "goliath_player_location_monitor" },
    { 0x5DC6, "goliath_procedural_bones" },
    { 0x5DC7, "goliath_room_time_monitor" },
    { 0x5DC8, "goliath_round_monitor" },
    { 0x5DC9, "goliath_sees_player_monitor" },
    { 0x5DCA, "goliath_setup_stealth" },
    { 0x5DCB, "goliath_smartobject_notetrack_handler" },
    { 0x5DCC, "goliath_spawn_func" },
    { 0x5DCD, "goliath_stab_model_swap_monitor" },
    { 0x5DCE, "goliath_stab_time_monitor" },
    { 0x5DCF, "goliath_stealth_filter" },
    { 0x5DD0, "goliath_strangle_effects" },
    { 0x5DD1, "goliath_strangle_effects_capture" },
    { 0x5DD2, "goliath_struggle" },
    { 0x5DD3, "goliath_struggle_fail" },
    { 0x5DD4, "goliath_struggle_fill_intensity" },
    { 0x5DD5, "goliath_struggle_key_intensity" },
    { 0x5DD6, "goliath_struggle_lights" },
    { 0x5DD7, "goliath_struggle_player_check_final_pos" },
    { 0x5DD8, "goliath_struggle_stab" },
    { 0x5DD9, "goliath_struggle_stab_check_for_close_victim" },
    { 0x5DDA, "goliath_struggle_stab_direction" },
    { 0x5DDB, "goliath_struggle_stab_monitor" },
    { 0x5DDC, "goliath_struggle_stab_slow" },
    { 0x5DDD, "goliath_struggle_stab_slow_player" },
    { 0x5DDE, "goliath_struggle_use_gun_scene" },
    { 0x5DDF, "goliath_swipe_awareness" },
    { 0x5DE0, "goliath_weapon_exists" },
    { 0x5DE1, "goliath_weapon_interacts_array" },
    { 0x5DE2, "gonevo" },
    { 0x5DE3, "good_guys" },
    { 0x5DE4, "good_hit" },
    { 0x5DE5, "goodbye_father_vo_captions" },
    { 0x5DE6, "goodenemy" },
    { 0x5DE7, "goodshootpos" },
    { 0x5DE8, "gopath" },
    { 0x5DE9, "goprocamerasettings" },
    { 0x5DEA, "goprohasattachments" },
    { 0x5DEB, "goprohelmet" },
    { 0x5DEC, "goprohelmetprecache" },
    { 0x5DED, "gopronone" },
    { 0x5DEE, "goprooverlay" },
    { 0x5DEF, "goproplayerthread" },
    { 0x5DF0, "goprotest" },
    { 0x5DF1, "goprovision" },
    { 0x5DF2, "got_a_lead_return_to_safehouse_vo" },
    { 0x5DF3, "got_gas_mask" },
    { 0x5DF4, "got_hint" },
    { 0x5DF5, "got_rebar" },
    { 0x5DF6, "gotachievement" },
    { 0x5DF7, "goto_alarm_or_nearest_cover" },
    { 0x5DF8, "goto_anim_pos" },
    { 0x5DF9, "goto_bomb_and_use" },
    { 0x5DFA, "goto_boss_phase" },
    { 0x5DFB, "goto_current_colorindex" },
    { 0x5DFC, "goto_delete" },
    { 0x5DFD, "goto_finished" },
    { 0x5DFE, "goto_last_goal" },
    { 0x5DFF, "goto_last_goal_and_clear" },
    { 0x5E00, "goto_nextnode" },
    { 0x5E01, "goto_node_and_callout" },
    { 0x5E02, "goto_patharray" },
    { 0x5E03, "goto_selected" },
    { 0x5E04, "goto_state" },
    { 0x5E05, "goto_state_previous" },
    { 0x5E06, "gotocombatonly" },
    { 0x5E07, "gotocornernagindex" },
    { 0x5E08, "gotonextspawn" },
    { 0x5E09, "gotopatrolpoint" },
    { 0x5E0A, "gotopoistate" },
    { 0x5E0B, "gotopoistateontimer" },
    { 0x5E0C, "gotopos" },
    { 0x5E0D, "gotoprevspawn" },
    { 0x5E0E, "gotpullbacknotify" },
    { 0x5E0F, "grab_and_store_gates" },
    { 0x5E10, "grab_disguise" },
    { 0x5E11, "grab_glowstick" },
    { 0x5E12, "grab_halligan" },
    { 0x5E13, "grab_nearby_soldiers_and_apply_settings" },
    { 0x5E14, "grab_rope_nags" },
    { 0x5E15, "graceperiod" },
    { 0x5E16, "graceperiodgrenademod" },
    { 0x5E17, "graceperiodmonitor" },
    { 0x5E18, "graduallyincreasespeed" },
    { 0x5E19, "granthelicopterpilot" },
    { 0x5E1A, "grantspotterkit" },
    { 0x5E1B, "graph_position" },
    { 0x5E1C, "graverobberammo" },
    { 0x5E1D, "gravity_gameplay" },
    { 0x5E1E, "gravity_physics" },
    { 0x5E1F, "greatestuniqueplayerkills" },
    { 0x5E20, "green_beam" },
    { 0x5E21, "green_beam_demeanor" },
    { 0x5E22, "green_beam_does_vo" },
    { 0x5E23, "green_beam_equip_hint_check" },
    { 0x5E24, "green_beam_fade_off_lighting" },
    { 0x5E25, "green_beam_fade_on_lighting" },
    { 0x5E26, "green_beam_fill_light" },
    { 0x5E27, "green_beam_icon" },
    { 0x5E28, "green_beam_pickup" },
    { 0x5E29, "green_beam_rim_light" },
    { 0x5E2A, "green_beam_swap_hint_check" },
    { 0x5E2B, "green_beam_target_hint_check" },
    { 0x5E2C, "green_beam_weapon" },
    { 0x5E2D, "green_light_transition" },
    { 0x5E2E, "green_marines_move_to_hospital" },
    { 0x5E2F, "green_wire" },
    { 0x5E30, "greenbeamerror" },
    { 0x5E31, "greenhouse_misters" },
    { 0x5E32, "greenlight_end" },
    { 0x5E33, "greenlight_end_blackoverlay" },
    { 0x5E34, "greenlight_fade_to_black" },
    { 0x5E35, "greenlight_fadeout" },
    { 0x5E36, "greenlight_mission_end_monitor" },
    { 0x5E37, "greeter_marine" },
    { 0x5E38, "grenade_array" },
    { 0x5E39, "grenade_backup_handler" },
    { 0x5E3A, "grenade_badplace_think" },
    { 0x5E3B, "grenade_cache" },
    { 0x5E3C, "grenade_cache_index" },
    { 0x5E3D, "grenade_crate_init" },
    { 0x5E3E, "grenade_detonated" },
    { 0x5E3F, "grenade_drop_cooldown" },
    { 0x5E40, "grenade_earthquake" },
    { 0x5E41, "grenade_earthquakeatposition" },
    { 0x5E42, "grenade_earthquakeatposition_internal" },
    { 0x5E43, "grenade_handler" },
    { 0x5E44, "grenade_listener" },
    { 0x5E45, "grenade_location_monitor" },
    { 0x5E46, "grenade_model_anims" },
    { 0x5E47, "grenade_pickup_handler" },
    { 0x5E48, "grenade_shield" },
    { 0x5E49, "grenade_swap" },
    { 0x5E4A, "grenade_swap_clear" },
    { 0x5E4B, "grenadeavoid_terminate" },
    { 0x5E4C, "grenadecooldownelapsed" },
    { 0x5E4D, "grenadecowerfunction" },
    { 0x5E4E, "grenadedamagedialogdeck" },
    { 0x5E4F, "grenadedroptimer" },
    { 0x5E50, "grenadeexplosionfx" },
    { 0x5E51, "grenadefire" },
    { 0x5E52, "grenadehealth" },
    { 0x5E53, "grenadeheldatdeath" },
    { 0x5E54, "grenadehits" },
    { 0x5E55, "grenadeinitialize" },
    { 0x5E56, "grenadeinpullback" },
    { 0x5E57, "grenadelandednearplayer" },
    { 0x5E58, "grenadelauncherfirerate" },
    { 0x5E59, "grenadeline" },
    { 0x5E5A, "grenadepossafewrapper" },
    { 0x5E5B, "grenadeproximitytracking" },
    { 0x5E5C, "grenadepullback" },
    { 0x5E5D, "grenadepullenabled" },
    { 0x5E5E, "grenadepulltime" },
    { 0x5E5F, "grenadepulltimer" },
    { 0x5E60, "grenadereturnthrow" },
    { 0x5E61, "grenadereturnthrow_terminate" },
    { 0x5E62, "grenades" },
    { 0x5E63, "grenadesafedist" },
    { 0x5E64, "grenadeshielded" },
    { 0x5E65, "grenadestuckto" },
    { 0x5E66, "grenadestucktosplash" },
    { 0x5E67, "grenadetag" },
    { 0x5E68, "grenadethrowanims" },
    { 0x5E69, "grenadethrown" },
    { 0x5E6A, "grenadethrownevent" },
    { 0x5E6B, "grenadethrowoffsets" },
    { 0x5E6C, "grenadethrowvaliditycheck" },
    { 0x5E6D, "grenadetimers" },
    { 0x5E6E, "grenadeusefunc" },
    { 0x5E6F, "grenadeweaponoverride" },
    { 0x5E70, "grenadier_anchor" },
    { 0x5E71, "grenadier_weapon" },
    { 0x5E72, "grid_origin" },
    { 0x5E73, "grid_points_found" },
    { 0x5E74, "griggs" },
    { 0x5E75, "griggs_can_smoke_nag" },
    { 0x5E76, "griggs_damage_juggle_decay_handler" },
    { 0x5E77, "griggs_damage_juggle_monitor" },
    { 0x5E78, "griggs_damage_points" },
    { 0x5E79, "griggs_dialog_struct" },
    { 0x5E7A, "griggs_equipment_nag_monitor" },
    { 0x5E7B, "griggs_ied_street_stayahead_behavior" },
    { 0x5E7C, "griggs_initial_smoke_reminder_called" },
    { 0x5E7D, "griggs_loadout" },
    { 0x5E7E, "griggs_lobby_cleared_vo_done" },
    { 0x5E7F, "griggs_move_up" },
    { 0x5E80, "griggs_movement_handler" },
    { 0x5E81, "griggs_movement_to_alley" },
    { 0x5E82, "griggs_retreat_line_done" },
    { 0x5E83, "griggs_retreat_speaking" },
    { 0x5E84, "griggs_stairwell_advance_demeanor" },
    { 0x5E85, "griggs_supplies_refill" },
    { 0x5E86, "griggs_vo_civambush_speaking" },
    { 0x5E87, "grill_dead" },
    { 0x5E88, "grind_waiting_to_bank" },
    { 0x5E89, "grnd_previouscratetypes" },
    { 0x5E8A, "grndextraprimaryspawnpoints" },
    { 0x5E8B, "ground_ent" },
    { 0x5E8C, "ground_ent_angles_offset" },
    { 0x5E8D, "ground_ent_offset" },
    { 0x5E8E, "ground_origin" },
    { 0x5E8F, "ground_plane_seats" },
    { 0x5E90, "ground_pos" },
    { 0x5E91, "ground_ref_ent" },
    { 0x5E92, "ground_veh_spawner" },
    { 0x5E93, "ground_vehicle_sound_handler" },
    { 0x5E94, "ground_vehicle_spawn_points" },
    { 0x5E95, "ground_vehicle_structs" },
    { 0x5E96, "groundent" },
    { 0x5E97, "groundfloor_aq_alive_monitor" },
    { 0x5E98, "groundfloor_bed_civ_hack_ally" },
    { 0x5E99, "groundfloor_catchup" },
    { 0x5E9A, "groundfloor_civ_manager" },
    { 0x5E9B, "groundfloor_civ_run_2_early_death" },
    { 0x5E9C, "groundfloor_cleanup" },
    { 0x5E9D, "groundfloor_color_advance_manager" },
    { 0x5E9E, "groundfloor_color_handler" },
    { 0x5E9F, "groundfloor_door_bash_monitor" },
    { 0x5EA0, "groundfloor_doors" },
    { 0x5EA1, "groundfloor_entry_door_handler" },
    { 0x5EA2, "groundfloor_entry_door_left" },
    { 0x5EA3, "groundfloor_entry_door_right" },
    { 0x5EA4, "groundfloor_entry_doors_door_ajar_custom_func" },
    { 0x5EA5, "groundfloor_extra_marines_handler" },
    { 0x5EA6, "groundfloor_floodspawn_1_handler" },
    { 0x5EA7, "groundfloor_floodspawn_2_handler" },
    { 0x5EA8, "groundfloor_floodspawn_3_handler" },
    { 0x5EA9, "groundfloor_floodspawn_3_reinforce" },
    { 0x5EAA, "groundfloor_floodspawn_3_reinforce_flank" },
    { 0x5EAB, "groundfloor_floodspawn_4_handler" },
    { 0x5EAC, "groundfloor_floodspawner_3_reinforce" },
    { 0x5EAD, "groundfloor_friendly_fire_penalty_manager" },
    { 0x5EAE, "groundfloor_glass_hack" },
    { 0x5EAF, "groundfloor_last_stand_handler" },
    { 0x5EB0, "groundfloor_last_stand_ignoreme_monitor" },
    { 0x5EB1, "groundfloor_last_stand_manager" },
    { 0x5EB2, "groundfloor_main" },
    { 0x5EB3, "groundfloor_start" },
    { 0x5EB4, "groundfloor_tripwire_defuse_monitor" },
    { 0x5EB5, "groundlockmisses" },
    { 0x5EB6, "groundlockonent" },
    { 0x5EB7, "groundnormals" },
    { 0x5EB8, "groundorigin" },
    { 0x5EB9, "groundpoints" },
    { 0x5EBA, "groundpos" },
    { 0x5EBB, "groundpound_raisefx" },
    { 0x5EBC, "groundpoundboost_onimpact" },
    { 0x5EBD, "groundpoundshield" },
    { 0x5EBE, "groundpoundshield_break" },
    { 0x5EBF, "groundpoundshield_breakfx" },
    { 0x5EC0, "groundpoundshield_damagedfx" },
    { 0x5EC1, "groundpoundshield_deleteondisconnect" },
    { 0x5EC2, "groundpoundshield_deleteshield" },
    { 0x5EC3, "groundpoundshield_lower" },
    { 0x5EC4, "groundpoundshield_lowerfx" },
    { 0x5EC5, "groundpoundshield_loweronjump" },
    { 0x5EC6, "groundpoundshield_loweronleavearea" },
    { 0x5EC7, "groundpoundshield_lowerontime" },
    { 0x5EC8, "groundpoundshield_monitorhealth" },
    { 0x5EC9, "groundpoundshield_monitorjoinedteam" },
    { 0x5ECA, "groundpoundshield_onimpact" },
    { 0x5ECB, "groundpoundshield_raise" },
    { 0x5ECC, "groundpoundshield_raiseondelay" },
    { 0x5ECD, "groundpoundshock_empplayer" },
    { 0x5ECE, "groundpoundshock_onimpact" },
    { 0x5ECF, "groundpoundshock_onimpactfx" },
    { 0x5ED0, "groundraycast" },
    { 0x5ED1, "groundrefent" },
    { 0x5ED2, "grounds_alerted" },
    { 0x5ED3, "grounds_axis_deathfunc" },
    { 0x5ED4, "grounds_axis_spawnfunc" },
    { 0x5ED5, "grounds_hunting" },
    { 0x5ED6, "groundspawning_usebigmapsettings" },
    { 0x5ED7, "groundtargetent" },
    { 0x5ED8, "group" },
    { 0x5ED9, "group_add" },
    { 0x5EDA, "group_anyoneincombat" },
    { 0x5EDB, "group_assigntocombatpod" },
    { 0x5EDC, "group_assigntohuntpod" },
    { 0x5EDD, "group_assigntoinvestigatepod" },
    { 0x5EDE, "group_by_flag" },
    { 0x5EDF, "group_checkrequestbackupoutsideofvolume" },
    { 0x5EE0, "group_coverblown_seekbackup" },
    { 0x5EE1, "group_delayedcombatpropagation" },
    { 0x5EE2, "group_delayedcombatpropagationfromhunt" },
    { 0x5EE3, "group_delayedcoverblownpropagation" },
    { 0x5EE4, "group_end_index" },
    { 0x5EE5, "group_eventcombat" },
    { 0x5EE6, "group_eventcoverblown" },
    { 0x5EE7, "group_eventhunt" },
    { 0x5EE8, "group_eventinvestigate" },
    { 0x5EE9, "group_fallback_to_pos" },
    { 0x5EEA, "group_findpod" },
    { 0x5EEB, "group_findsomeotherguytoinvestigate" },
    { 0x5EEC, "group_flag" },
    { 0x5EED, "group_flag_clear" },
    { 0x5EEE, "group_flag_init" },
    { 0x5EEF, "group_flag_set" },
    { 0x5EF0, "group_flag_wait" },
    { 0x5EF1, "group_flag_wait_or_timeout" },
    { 0x5EF2, "group_flag_waitopen" },
    { 0x5EF3, "group_flag_waitopen_or_timeout" },
    { 0x5EF4, "group_generateinitialinvestigatepoints" },
    { 0x5EF5, "group_getinvestigatepoint" },
    { 0x5EF6, "group_has_combined_counters" },
    { 0x5EF7, "group_investigate_seekbackup" },
    { 0x5EF8, "group_isplayerfocus" },
    { 0x5EF9, "group_light" },
    { 0x5EFA, "group_name" },
    { 0x5EFB, "group_removefrompod" },
    { 0x5EFC, "group_setcombatgoalradius" },
    { 0x5EFD, "group_spotted_flag" },
    { 0x5EFE, "group_trytojoinexistingpod" },
    { 0x5EFF, "group_updatepodhuntorigin" },
    { 0x5F00, "group_vignette_death_func" },
    { 0x5F01, "group_vignette_dmg_func" },
    { 0x5F02, "group_wait_for_activecount_notify" },
    { 0x5F03, "group_waitfordeath" },
    { 0x5F04, "group1_damage_func" },
    { 0x5F05, "group1_guy_logic" },
    { 0x5F06, "groupdata" },
    { 0x5F07, "grouped_modules" },
    { 0x5F08, "groupedanim_pos" },
    { 0x5F09, "groupname" },
    { 0x5F0A, "groups" },
    { 0x5F0B, "groups_combat_checklosttarget" },
    { 0x5F0C, "groupspawned" },
    { 0x5F0D, "growpet" },
    { 0x5F0E, "growthtime" },
    { 0x5F0F, "gs" },
    { 0x5F10, "gt" },
    { 0x5F11, "guantlet_first_car_collision_kill" },
    { 0x5F12, "guard" },
    { 0x5F13, "guard_1_patrol_unaware" },
    { 0x5F14, "guard_2_patrol_unaware" },
    { 0x5F15, "guard_damage" },
    { 0x5F16, "guard_takedown_anim" },
    { 0x5F17, "guard_tower_logic" },
    { 0x5F18, "guard1" },
    { 0x5F19, "guard2" },
    { 0x5F1A, "guard3" },
    { 0x5F1B, "guarded_barkovspeakerlogic" },
    { 0x5F1C, "guarded_cinematictelevisionstandbylogic" },
    { 0x5F1D, "guarded_cleanuppreviousscenelogic" },
    { 0x5F1E, "guarded_dialoguelogic" },
    { 0x5F1F, "guarded_enemiesconversationlogic" },
    { 0x5F20, "guarded_farahlogic" },
    { 0x5F21, "guarded_getanimationstruct" },
    { 0x5F22, "guarded_getcivilians" },
    { 0x5F23, "guarded_getenemies" },
    { 0x5F24, "guarded_getfarahpath" },
    { 0x5F25, "guarded_getguardvolumealertednotify" },
    { 0x5F26, "guarded_getplayersilencerinteract" },
    { 0x5F27, "guarded_getstreettrigger" },
    { 0x5F28, "guarded_main" },
    { 0x5F29, "guarded_objectivecleanuplogic" },
    { 0x5F2A, "guarded_playerfalsesilencerinteractlogic" },
    { 0x5F2B, "guarded_silencerdialoguelogic" },
    { 0x5F2C, "guarded_spawncivilians" },
    { 0x5F2D, "guarded_spawnenemies" },
    { 0x5F2E, "guarded_start" },
    { 0x5F2F, "guardlocation" },
    { 0x5F30, "guardposition" },
    { 0x5F31, "guardpositionescort" },
    { 0x5F32, "guards_killed_by_sas" },
    { 0x5F33, "guared_farahreactdialoguelogic" },
    { 0x5F34, "gui_giveattachment" },
    { 0x5F35, "gui_giveattachment_internal" },
    { 0x5F36, "guid" },
    { 0x5F37, "guided_interaction_offset_func" },
    { 0x5F38, "guidedinteractionendposoverride" },
    { 0x5F39, "guidedinteractionexclusion" },
    { 0x5F3A, "guidgen" },
    { 0x5F3B, "guidtoplayer" },
    { 0x5F3C, "gulag" },
    { 0x5F3D, "gulagarena" },
    { 0x5F3E, "gulagblackoverlay" },
    { 0x5F3F, "gulagcountdowntimer" },
    { 0x5F40, "gulagdone" },
    { 0x5F41, "gulagfadefromblack" },
    { 0x5F42, "gulagfadetoblack" },
    { 0x5F43, "gulaggesturesinit" },
    { 0x5F44, "gulaggetarenas" },
    { 0x5F45, "gulaginitloadouts" },
    { 0x5F46, "gulagisspawnpositionsafe" },
    { 0x5F47, "gulagjailbreakhud" },
    { 0x5F48, "gulagloadingtext" },
    { 0x5F49, "gulagloadingtextclear" },
    { 0x5F4A, "gulagloser" },
    { 0x5F4B, "gulaglosercleanup" },
    { 0x5F4C, "gulagposition" },
    { 0x5F4D, "gulagqueuehud" },
    { 0x5F4E, "gulagstreamlocationend" },
    { 0x5F4F, "gulagstreamlocationstart" },
    { 0x5F50, "gulagstreamlocationwait" },
    { 0x5F51, "gulagstreamlocationwaittimeout" },
    { 0x5F52, "gulagtimerhud" },
    { 0x5F53, "gulaguses" },
    { 0x5F54, "gulagvictory" },
    { 0x5F55, "gulagwinnerremembergunandammo" },
    { 0x5F56, "gulagwinnerrespawn" },
    { 0x5F57, "gun" },
    { 0x5F58, "gun_fired_and_ready_105mm" },
    { 0x5F59, "gun_firstspawn" },
    { 0x5F5A, "gun_game_change_to_weapon_at_level" },
    { 0x5F5B, "gun_guns" },
    { 0x5F5C, "gun_launched" },
    { 0x5F5D, "gun_leave_behind" },
    { 0x5F5E, "gun_loadouts" },
    { 0x5F5F, "gun_model" },
    { 0x5F60, "gun_on_death" },
    { 0x5F61, "gun_on_ground" },
    { 0x5F62, "gun_pickup_left" },
    { 0x5F63, "gun_pickup_right" },
    { 0x5F64, "gun_recall" },
    { 0x5F65, "gun_remove" },
    { 0x5F66, "gun_targ" },
    { 0x5F67, "gun_try_pickup" },
    { 0x5F68, "gun_try_pickup_hadir" },
    { 0x5F69, "gun_up_for_reload" },
    { 0x5F6A, "gunadditiveoverride" },
    { 0x5F6B, "gunbed" },
    { 0x5F6C, "gunbenchbulletent" },
    { 0x5F6D, "gunblockedbywalltime" },
    { 0x5F6E, "gunfireloopfx" },
    { 0x5F6F, "gunfireloopfxthread" },
    { 0x5F70, "gungamegunindex" },
    { 0x5F71, "gungameprevgunindex" },
    { 0x5F72, "gunhand" },
    { 0x5F73, "gunkillerhackthread" },
    { 0x5F74, "gunlessweapon" },
    { 0x5F75, "gunner" },
    { 0x5F76, "gunner_bravo_spawn" },
    { 0x5F77, "gunner_can_shoot_player" },
    { 0x5F78, "gunner_death_watcher" },
    { 0x5F79, "gunner_ignore_delay" },
    { 0x5F7A, "gunner_think" },
    { 0x5F7B, "gunner_turret" },
    { 0x5F7C, "gunner_weapon" },
    { 0x5F7D, "gunner1_final_vol" },
    { 0x5F7E, "gunner2_final_vol" },
    { 0x5F7F, "gunners" },
    { 0x5F80, "gunnerturret" },
    { 0x5F81, "gunnerweapon" },
    { 0x5F82, "gunnlessweapon" },
    { 0x5F83, "gunpose_enabler" },
    { 0x5F84, "gunremoved" },
    { 0x5F85, "gunship" },
    { 0x5F86, "gunship_allowstances" },
    { 0x5F87, "gunship_assigntargetmarkers" },
    { 0x5F88, "gunship_attachgunner" },
    { 0x5F89, "gunship_cloudsfx" },
    { 0x5F8A, "gunship_control_bot_aiming" },
    { 0x5F8B, "gunship_crash" },
    { 0x5F8C, "gunship_crash_audio" },
    { 0x5F8D, "gunship_crashanimlength" },
    { 0x5F8E, "gunship_crashexplosionradiostatic" },
    { 0x5F8F, "gunship_crashexplosionscreenshake" },
    { 0x5F90, "gunship_delayhide" },
    { 0x5F91, "gunship_disabledstances" },
    { 0x5F92, "gunship_findboxcenter" },
    { 0x5F93, "gunship_getbombingpoints" },
    { 0x5F94, "gunship_getdofinfobyweapon" },
    { 0x5F95, "gunship_getnearbytargets" },
    { 0x5F96, "gunship_getvisionset" },
    { 0x5F97, "gunship_getvisionsetformat" },
    { 0x5F98, "gunship_handlemissiledetection" },
    { 0x5F99, "gunship_handlemovement" },
    { 0x5F9A, "gunship_hideintromodelonplayerconnect" },
    { 0x5F9B, "gunship_intromodel" },
    { 0x5F9C, "gunship_iskillstreakweapon" },
    { 0x5F9D, "gunship_islargemap" },
    { 0x5F9E, "gunship_leave" },
    { 0x5F9F, "gunship_linklightfxent" },
    { 0x5FA0, "gunship_linkwingfxents" },
    { 0x5FA1, "gunship_lockedoncallback" },
    { 0x5FA2, "gunship_lockedonremovedcallback" },
    { 0x5FA3, "gunship_magnitude" },
    { 0x5FA4, "gunship_monitormanualplayerexit" },
    { 0x5FA5, "gunship_movetocrashpos" },
    { 0x5FA6, "gunship_playdofintroeffects" },
    { 0x5FA7, "gunship_playfakebodyexplosion" },
    { 0x5FA8, "gunship_playflaresfx" },
    { 0x5FA9, "gunship_playintro" },
    { 0x5FAA, "gunship_playpilotfx" },
    { 0x5FAB, "gunship_queuecamerazoom" },
    { 0x5FAC, "gunship_removeplane" },
    { 0x5FAD, "gunship_restoreplayerweapon" },
    { 0x5FAE, "gunship_returnplayer" },
    { 0x5FAF, "gunship_screeninterference" },
    { 0x5FB0, "gunship_showflashlight" },
    { 0x5FB1, "gunship_spawn" },
    { 0x5FB2, "gunship_spawnvfx" },
    { 0x5FB3, "gunship_speed" },
    { 0x5FB4, "gunship_startbrrespawn" },
    { 0x5FB5, "gunship_startengineblowoutfx" },
    { 0x5FB6, "gunship_startintroshake" },
    { 0x5FB7, "gunship_startuse" },
    { 0x5FB8, "gunship_track105mmmissile" },
    { 0x5FB9, "gunship_trackvelocity" },
    { 0x5FBA, "gunship_updateaimingcoords" },
    { 0x5FBB, "gunship_updateoverlaycoords" },
    { 0x5FBC, "gunship_updateplanemodelcoords" },
    { 0x5FBD, "gunship_updateplayercount" },
    { 0x5FBE, "gunship_updateplayerpositioncoords" },
    { 0x5FBF, "gunship_uses" },
    { 0x5FC0, "gunship_waitforweaponreloadtime" },
    { 0x5FC1, "gunship_waittilldestination" },
    { 0x5FC2, "gunship_watch105mmexplosion" },
    { 0x5FC3, "gunship_watchchangeweapons" },
    { 0x5FC4, "gunship_watchdamage" },
    { 0x5FC5, "gunship_watchendgame" },
    { 0x5FC6, "gunship_watchkills" },
    { 0x5FC7, "gunship_watchowner" },
    { 0x5FC8, "gunship_watchtargets" },
    { 0x5FC9, "gunship_watchthermalflashlightpos" },
    { 0x5FCA, "gunship_watchthermalflashlighttoggle" },
    { 0x5FCB, "gunship_watchthermaltoggle" },
    { 0x5FCC, "gunship_watchthermaltoggleinternal" },
    { 0x5FCD, "gunship_watchtimeout" },
    { 0x5FCE, "gunship_watchweaponfired" },
    { 0x5FCF, "gunship_watchweaponimpact" },
    { 0x5FD0, "gunship_weaponreload" },
    { 0x5FD1, "gunshipinuse" },
    { 0x5FD2, "gunshipplayer" },
    { 0x5FD3, "gunshipqueue" },
    { 0x5FD4, "gunshop_safehouse_loadout" },
    { 0x5FD5, "guy" },
    { 0x5FD6, "guy_becomes_real_ai" },
    { 0x5FD7, "guy_blowup" },
    { 0x5FD8, "guy_cleanup_vehiclevars" },
    { 0x5FD9, "guy_death" },
    { 0x5FDA, "guy_deathhandle" },
    { 0x5FDB, "guy_deathimate_me" },
    { 0x5FDC, "guy_enter" },
    { 0x5FDD, "guy_fall_loop" },
    { 0x5FDE, "guy_fall_loop_end" },
    { 0x5FDF, "guy_handle" },
    { 0x5FE0, "guy_idle" },
    { 0x5FE1, "guy_man_turret" },
    { 0x5FE2, "guy_resets_goalpos" },
    { 0x5FE3, "guy_reveal" },
    { 0x5FE4, "guy_runtovehicle" },
    { 0x5FE5, "guy_runtovehicle_loaded" },
    { 0x5FE6, "guy_setup_rope" },
    { 0x5FE7, "guy_should_man_turret" },
    { 0x5FE8, "guy_think" },
    { 0x5FE9, "guy_unlink_on_death" },
    { 0x5FEA, "guy_unload" },
    { 0x5FEB, "guy_unload_land" },
    { 0x5FEC, "guy_unload_que" },
    { 0x5FED, "guy_up_stairs_watcher" },
    { 0x5FEE, "guy_vehicle_death" },
    { 0x5FEF, "guy1" },
    { 0x5FF0, "guy2" },
    { 0x5FF1, "guys" },
    { 0x5FF2, "guys_assigned" },
    { 0x5FF3, "guys_exit_garage" },
    { 0x5FF4, "guys_in_place" },
    { 0x5FF5, "guys_react_to_jets" },
    { 0x5FF6, "guys_spawned" },
    { 0x5FF7, "gw_objstruct" },
    { 0x5FF8, "hack_after_manifest_search" },
    { 0x5FF9, "hack_attackers" },
    { 0x5FFA, "hack_damage" },
    { 0x5FFB, "hack_damage_test" },
    { 0x5FFC, "hack_duration" },
    { 0x5FFD, "hack_fail_timer" },
    { 0x5FFE, "hack_health" },
    { 0x5FFF, "hack_init" },
    { 0x6000, "hack_modifier" },
    { 0x6001, "hack_multiplier" },
    { 0x6002, "hack_progress" },
    { 0x6003, "hack_radar_activate" },
    { 0x6004, "hack_radar_hint" },
    { 0x6005, "hack_region" },
    { 0x6006, "hack_relocate" },
    { 0x6007, "hack_setup_a_struct" },
    { 0x6008, "hack_start" },
    { 0x6009, "hack_structs" },
    { 0x600A, "hackable" },
    { 0x600B, "hackedname" },
    { 0x600C, "hackemptyarray" },
    { 0x600D, "hackequipment" },
    { 0x600E, "hacker" },
    { 0x600F, "hackexclusionlist" },
    { 0x6010, "hackfixcameras" },
    { 0x6011, "hacking_init" },
    { 0x6012, "hacking_labels_init" },
    { 0x6013, "hacking_lua_notify" },
    { 0x6014, "hacking_magicgrenade_watcher" },
    { 0x6015, "hacking_objective_time" },
    { 0x6016, "hacking_paused" },
    { 0x6017, "hacking_sfx" },
    { 0x6018, "hacking_ui" },
    { 0x6019, "hackingblockautosave" },
    { 0x601A, "hackingfunc" },
    { 0x601B, "hackingspeed" },
    { 0x601C, "hackingtabledata" },
    { 0x601D, "hackingtotalmeter" },
    { 0x601E, "hackingtotalsteps" },
    { 0x601F, "hackingtotaltime" },
    { 0x6020, "hacks_done" },
    { 0x6021, "hackspottest" },
    { 0x6022, "hadarmor" },
    { 0x6023, "hadir" },
    { 0x6024, "hadir_advance_flank_trigger_wait" },
    { 0x6025, "hadir_ai" },
    { 0x6026, "hadir_beckon_gas_start" },
    { 0x6027, "hadir_beckon_loop" },
    { 0x6028, "hadir_beckon_loop_suspend" },
    { 0x6029, "hadir_body_model" },
    { 0x602A, "hadir_boost_lights" },
    { 0x602B, "hadir_boost_mayhem" },
    { 0x602C, "hadir_boost_nag" },
    { 0x602D, "hadir_boost_nags" },
    { 0x602E, "hadir_call_interact" },
    { 0x602F, "hadir_choking" },
    { 0x6030, "hadir_craw_vo" },
    { 0x6031, "hadir_crawl_dialogue" },
    { 0x6032, "hadir_dad_dies_scene" },
    { 0x6033, "hadir_disable_wait" },
    { 0x6034, "hadir_dof" },
    { 0x6035, "hadir_dragged_away" },
    { 0x6036, "hadir_duck" },
    { 0x6037, "hadir_face_kick" },
    { 0x6038, "hadir_field_start_scene" },
    { 0x6039, "hadir_follow_player" },
    { 0x603A, "hadir_go_to_vehicle" },
    { 0x603B, "hadir_helps_dad_monitor" },
    { 0x603C, "hadir_hero_lights" },
    { 0x603D, "hadir_icon_showing" },
    { 0x603E, "hadir_in_gas" },
    { 0x603F, "hadir_in_shed" },
    { 0x6040, "hadir_interact" },
    { 0x6041, "hadir_landing_clip" },
    { 0x6042, "hadir_line" },
    { 0x6043, "hadir_mayhem_phone" },
    { 0x6044, "hadir_melee_weapon_pickup" },
    { 0x6045, "hadir_melee_weapon_spawn" },
    { 0x6046, "hadir_melee_weapon_spawn_catchup" },
    { 0x6047, "hadir_mourn_father" },
    { 0x6048, "hadir_move_speed_execution" },
    { 0x6049, "hadir_move_speed_gas_exit" },
    { 0x604A, "hadir_move_speed_gas_start" },
    { 0x604B, "hadir_move_to_door" },
    { 0x604C, "hadir_objective_icon" },
    { 0x604D, "hadir_pick_up_loop" },
    { 0x604E, "hadir_poppies_start_anim" },
    { 0x604F, "hadir_procedural_bones" },
    { 0x6050, "hadir_ready_to_cross_street" },
    { 0x6051, "hadir_remove_mask_gesture" },
    { 0x6052, "hadir_russian_wait_flag" },
    { 0x6053, "hadir_scramble_monitor" },
    { 0x6054, "hadir_setgoal" },
    { 0x6055, "hadir_soldier_warning" },
    { 0x6056, "hadir_spawn_func" },
    { 0x6057, "hadir_stair_idle_nag" },
    { 0x6058, "hadir_stayahead_pause_when_enabled" },
    { 0x6059, "hadir_table_clip" },
    { 0x605A, "hadir_tablet_idle_nag" },
    { 0x605B, "hadir_talk_mayhem" },
    { 0x605C, "hadir_talk_monitor" },
    { 0x605D, "hadir_truck_entrance" },
    { 0x605E, "hadir_tunnel_think" },
    { 0x605F, "hadir_vehicle_node_blocker" },
    { 0x6060, "hadir_wakeup_react" },
    { 0x6061, "hadir_window_scene" },
    { 0x6062, "hair_model" },
    { 0x6063, "hairmodel" },
    { 0x6064, "halfcooldown" },
    { 0x6065, "halflength" },
    { 0x6066, "halfsize" },
    { 0x6067, "halftimeroundenddelay" },
    { 0x6068, "halftimetype" },
    { 0x6069, "halfwidth" },
    { 0x606A, "hall_rush_civ_behavior" },
    { 0x606B, "hall_rush_crutch_civs_handler" },
    { 0x606C, "hall_rush_crutch_magic_bullet" },
    { 0x606D, "hall_rush_gunner_immunity_timeout" },
    { 0x606E, "hall_rush_gunner_target_handler" },
    { 0x606F, "hall_rush_gunners" },
    { 0x6070, "hall_rush_initial_civilians_handler" },
    { 0x6071, "hall_rush_initial_civilians_spawn" },
    { 0x6072, "hall_rush_support" },
    { 0x6073, "halligan" },
    { 0x6074, "halligan_breakout" },
    { 0x6075, "halligan_breakout_a" },
    { 0x6076, "halligan_breakout_b" },
    { 0x6077, "halligan_breakout_end" },
    { 0x6078, "halligan_draw" },
    { 0x6079, "halligan_stow" },
    { 0x607A, "halligan_stowed" },
    { 0x607B, "halligan_tag" },
    { 0x607C, "halliganinhand" },
    { 0x607D, "halliganstowed" },
    { 0x607E, "hallway_1f_nag" },
    { 0x607F, "hallway_1f_poi" },
    { 0x6080, "hallway_2f_door_check" },
    { 0x6081, "hallway_exploder_lookat" },
    { 0x6082, "hallway_mh_mg_current_inaccuracy_offset_x" },
    { 0x6083, "hallway_mh_mg_current_inaccuracy_offset_y" },
    { 0x6084, "hallway_mh_mg_current_inaccuracy_offset_z" },
    { 0x6085, "hallway_mh_mg_variance" },
    { 0x6086, "hallway_peak_handler" },
    { 0x6087, "hallway_run_catchup" },
    { 0x6088, "hallway_run_main" },
    { 0x6089, "hallway_run_start" },
    { 0x608A, "hallway_run_start_post_load" },
    { 0x608B, "hallway_scene" },
    { 0x608C, "halt_heli_end_movement" },
    { 0x608D, "handcuffs" },
    { 0x608E, "handle_ai_launcher_death" },
    { 0x608F, "handle_associated_lead_disconnect" },
    { 0x6090, "handle_associated_lead_lookat" },
    { 0x6091, "handle_attached_guys" },
    { 0x6092, "handle_cam_enemy_caret" },
    { 0x6093, "handle_cam_enemy_marking" },
    { 0x6094, "handle_civ_exit_door" },
    { 0x6095, "handle_death_sounds" },
    { 0x6096, "handle_detached_guys_check" },
    { 0x6097, "handle_disable_rotation" },
    { 0x6098, "handle_escalation_increases" },
    { 0x6099, "handle_escalation_on_death" },
    { 0x609A, "handle_healthdrain_from_lowhealth" },
    { 0x609B, "handle_hints_vo" },
    { 0x609C, "handle_hostage_objectives" },
    { 0x609D, "handle_hvt_go_outside" },
    { 0x609E, "handle_identified_ied_to_overwatch_max" },
    { 0x609F, "handle_leads_creation" },
    { 0x60A0, "handle_leads_text" },
    { 0x60A1, "handle_linked_ents" },
    { 0x60A2, "handle_moving_platform_invalid" },
    { 0x60A3, "handle_moving_platform_touch" },
    { 0x60A4, "handle_moving_platforms" },
    { 0x60A5, "handle_pause_wavespawning" },
    { 0x60A6, "handle_players_near_hack_b" },
    { 0x60A7, "handle_remind_hack" },
    { 0x60A8, "handle_scriptable_vfx" },
    { 0x60A9, "handle_search_buildings_vo_nags" },
    { 0x60AA, "handle_selected_ents" },
    { 0x60AB, "handle_set_speed_to_goal" },
    { 0x60AC, "handle_smoke" },
    { 0x60AD, "handle_smuggler_loot_attach" },
    { 0x60AE, "handle_smuggler_loot_drop" },
    { 0x60AF, "handle_starts" },
    { 0x60B0, "handle_stim" },
    { 0x60B1, "handle_unresolved_collision" },
    { 0x60B2, "handle_vehicle_death_type" },
    { 0x60B3, "handle_vfx_on_damage" },
    { 0x60B4, "handle_wavespawner_amount" },
    { 0x60B5, "handleairbornesuper" },
    { 0x60B6, "handleammoonlastshotskill" },
    { 0x60B7, "handleaonperkonkillpassive" },
    { 0x60B8, "handleapdamage" },
    { 0x60B9, "handlebackcrawlnotetracks" },
    { 0x60BA, "handleberserk" },
    { 0x60BB, "handleburndeathmodelswap" },
    { 0x60BC, "handleburndeathvfx" },
    { 0x60BD, "handleburningtodeath" },
    { 0x60BE, "handleburstdelay" },
    { 0x60BF, "handlec130motion" },
    { 0x60C0, "handlecinematicmotionnotetrack" },
    { 0x60C1, "handleclassedit" },
    { 0x60C2, "handlecommonnotetrack" },
    { 0x60C3, "handlecornernotetrack" },
    { 0x60C4, "handlecustomnotetrackhandler" },
    { 0x60C5, "handledamage" },
    { 0x60C6, "handledamagefeedback" },
    { 0x60C7, "handledeath" },
    { 0x60C8, "handledeathcleanup" },
    { 0x60C9, "handledeathdamage" },
    { 0x60CA, "handledestroydamage" },
    { 0x60CB, "handledofnotetrack" },
    { 0x60CC, "handledogfootstepnotetracks" },
    { 0x60CD, "handledooropennotetrack" },
    { 0x60CE, "handledooropenterminate" },
    { 0x60CF, "handledoublekillssuper" },
    { 0x60D0, "handledropclip" },
    { 0x60D1, "handleempdamage" },
    { 0x60D2, "handleemponoff" },
    { 0x60D3, "handleendarena" },
    { 0x60D4, "handleendgamesplash" },
    { 0x60D5, "handleequipmentkills" },
    { 0x60D6, "handleexclusionils" },
    { 0x60D7, "handleexplosivedamage" },
    { 0x60D8, "handlefacegoalnotetrack" },
    { 0x60D9, "handlefacegoalnotetrack_newenemyreaction" },
    { 0x60DA, "handlefinalkill" },
    { 0x60DB, "handlefortified" },
    { 0x60DC, "handlefriendlyfiredamage" },
    { 0x60DD, "handlefriendlyfiredeath" },
    { 0x60DE, "handlegesturenotetrack" },
    { 0x60DF, "handleglobalnotetracks" },
    { 0x60E0, "handlegoreeffect" },
    { 0x60E1, "handlegorepassive" },
    { 0x60E2, "handlegrenadedamage" },
    { 0x60E3, "handleheadshotammopassive" },
    { 0x60E4, "handlehealthonkillpassive" },
    { 0x60E5, "handlehealthregenonkillpassive" },
    { 0x60E6, "handlehitmanpassive" },
    { 0x60E7, "handlehostmigration" },
    { 0x60E8, "handleincomingmissiles" },
    { 0x60E9, "handleincomingstinger" },
    { 0x60EA, "handleinfillocationselection" },
    { 0x60EB, "handleinfilspawnselectend" },
    { 0x60EC, "handleinfilspawnselectstart" },
    { 0x60ED, "handleinfiniteammopassive" },
    { 0x60EE, "handleinlaststanddeath" },
    { 0x60EF, "handlejuggjumpspam" },
    { 0x60F0, "handlejumpteleports" },
    { 0x60F1, "handlekillmodifiers" },
    { 0x60F2, "handlelaststandweapongivedelay" },
    { 0x60F3, "handlemeleeconeexplode" },
    { 0x60F4, "handlemeleedamage" },
    { 0x60F5, "handlemeleekillpassive" },
    { 0x60F6, "handlemeleekills" },
    { 0x60F7, "handlemeleesuper" },
    { 0x60F8, "handlemissiledamage" },
    { 0x60F9, "handlemovespeedonkillpassive" },
    { 0x60FA, "handlemoveto" },
    { 0x60FB, "handlemovetoblended" },
    { 0x60FC, "handlemovingplatforms" },
    { 0x60FD, "handleninjaonlastshot" },
    { 0x60FE, "handlenondeterministicentities" },
    { 0x60FF, "handlenormaldeath" },
    { 0x6100, "handlenormaldeath_sounds" },
    { 0x6101, "handlenotetrack" },
    { 0x6102, "handlenotetrack_vsplayer" },
    { 0x6103, "handleonekillwin" },
    { 0x6104, "handleorientnotetracks" },
    { 0x6105, "handleoutlinesforstreaks" },
    { 0x6106, "handlepassiverefresh" },
    { 0x6107, "handlepassivescrambler" },
    { 0x6108, "handlepassivesonic" },
    { 0x6109, "handlephasecancellation" },
    { 0x610A, "handlepointdecay" },
    { 0x610B, "handlepopoffent" },
    { 0x610C, "handleratvisionburst" },
    { 0x610D, "handlerelicboom" },
    { 0x610E, "handlereliccatch" },
    { 0x610F, "handlereliccollatdamage" },
    { 0x6110, "handlerelicswat" },
    { 0x6111, "handlerespawnselection" },
    { 0x6112, "handlerevivemessage" },
    { 0x6113, "handleriotshieldhits" },
    { 0x6114, "handlescavengerbagpickup" },
    { 0x6115, "handlesecondarypainflag" },
    { 0x6116, "handleshotgundamage" },
    { 0x6117, "handlespectating" },
    { 0x6118, "handlesplashqueue" },
    { 0x6119, "handlesquadspawnabort" },
    { 0x611A, "handlesquadspawnconfirm" },
    { 0x611B, "handlesquadspawncycle" },
    { 0x611C, "handlestationaryturnfacegoalnotetrack" },
    { 0x611D, "handlestrafenotetracks" },
    { 0x611E, "handlesuicidedeath" },
    { 0x611F, "handlesuperearnovertime" },
    { 0x6120, "handleteamchange" },
    { 0x6121, "handleteamchangedeath" },
    { 0x6122, "handletraversealignment" },
    { 0x6123, "handletraversearrivalwarpnotetracks" },
    { 0x6124, "handletraversedeathnotetrack" },
    { 0x6125, "handletraversedrop" },
    { 0x6126, "handletraverselegacynotetracks" },
    { 0x6127, "handletraversenotetracks" },
    { 0x6128, "handletraversewarpnotetracks" },
    { 0x6129, "handleuse" },
    { 0x612A, "handlevehiclerequest" },
    { 0x612B, "handlevisordetonation" },
    { 0x612C, "handlewallrunattachnotetrack" },
    { 0x612D, "handlewarpacrossnotetrack" },
    { 0x612E, "handlewarparrivalnotetrack" },
    { 0x612F, "handlewarpdownendnotetrack" },
    { 0x6130, "handlewarpdownstartnotetrack" },
    { 0x6131, "handlewarpexitstart" },
    { 0x6132, "handlewarpupnotetrack" },
    { 0x6133, "handleweaponchangecallbacksondeath" },
    { 0x6134, "handleweaponstatenotetrack" },
    { 0x6135, "handleweaponstatenotetrackcp" },
    { 0x6136, "handlewiretap" },
    { 0x6137, "handleworlddeath" },
    { 0x6138, "handoffset" },
    { 0x6139, "handsignal" },
    { 0x613A, "handsup_complete" },
    { 0x613B, "hangar_allies_move_up" },
    { 0x613C, "hangar_defend_main" },
    { 0x613D, "hangar_defend_start" },
    { 0x613E, "hangar_defend_vfx_main" },
    { 0x613F, "hangar_door_button" },
    { 0x6140, "hangar_drag_scene" },
    { 0x6141, "hangar_fire_lights" },
    { 0x6142, "hangar_hatch" },
    { 0x6143, "hardcoreinjuredlooopsplayed" },
    { 0x6144, "hardcoremode" },
    { 0x6145, "hardenedaward" },
    { 0x6146, "hardlineactive" },
    { 0x6147, "hardpoint_setneutral" },
    { 0x6148, "hardpointmainloop" },
    { 0x6149, "hardpointtweaks" },
    { 0x614A, "harpoon_impale_additional_func" },
    { 0x614B, "harpoonv1_passive" },
    { 0x614C, "harrier_afterburnerfx" },
    { 0x614D, "harrier_smoke" },
    { 0x614E, "has_aimed_flashbang" },
    { 0x614F, "has_aimed_noisemaker" },
    { 0x6150, "has_alert_icon" },
    { 0x6151, "has_ammo" },
    { 0x6152, "has_antennae" },
    { 0x6153, "has_armor" },
    { 0x6154, "has_attached_props" },
    { 0x6155, "has_attachment" },
    { 0x6156, "has_auto_revive" },
    { 0x6157, "has_backpack" },
    { 0x6158, "has_balanced_personality" },
    { 0x6159, "has_building_upgrade" },
    { 0x615A, "has_ceiling" },
    { 0x615B, "has_cluster_strike" },
    { 0x615C, "has_color" },
    { 0x615D, "has_combat_icon" },
    { 0x615E, "has_critical_target_icon" },
    { 0x615F, "has_crowbar" },
    { 0x6160, "has_current_target" },
    { 0x6161, "has_cursor_hint" },
    { 0x6162, "has_displayed_chair_fail" },
    { 0x6163, "has_dongle" },
    { 0x6164, "has_dont_kill_off_flag" },
    { 0x6165, "has_drawn_attention_recently" },
    { 0x6166, "has_encounter_score_component" },
    { 0x6167, "has_eog_score_component" },
    { 0x6168, "has_explosive_touch" },
    { 0x6169, "has_eye" },
    { 0x616A, "has_fnf_weapon" },
    { 0x616B, "has_fortified_passive" },
    { 0x616C, "has_func_for_aievent" },
    { 0x616D, "has_gl" },
    { 0x616E, "has_hostage_on_board" },
    { 0x616F, "has_hvt" },
    { 0x6170, "has_incendiary_ammo" },
    { 0x6171, "has_infinite_ammo" },
    { 0x6172, "has_instant_revive" },
    { 0x6173, "has_inv_cooldown" },
    { 0x6174, "has_los_to_player" },
    { 0x6175, "has_main_turret" },
    { 0x6176, "has_multiple_lights" },
    { 0x6177, "has_munition" },
    { 0x6178, "has_never_kill_off_flag" },
    { 0x6179, "has_no_ir" },
    { 0x617A, "has_no_real_weapon" },
    { 0x617B, "has_open_case_marker" },
    { 0x617C, "has_override_flag_targets" },
    { 0x617D, "has_override_zone_targets" },
    { 0x617E, "has_picked_up_fuses" },
    { 0x617F, "has_replaced_starting_pistol" },
    { 0x6180, "has_riot_shield" },
    { 0x6181, "has_rockets" },
    { 0x6182, "has_said_cam_switch" },
    { 0x6183, "has_scavenger" },
    { 0x6184, "has_score_component_internal" },
    { 0x6185, "has_script_color" },
    { 0x6186, "has_script_delay2" },
    { 0x6187, "has_script_time_min" },
    { 0x6188, "has_script_wait" },
    { 0x6189, "has_seen_any_player_long_enough" },
    { 0x618A, "has_seen_any_player_long_enough_to_trigger_alert" },
    { 0x618B, "has_seen_any_player_recently" },
    { 0x618C, "has_seen_any_player_recently_watcher" },
    { 0x618D, "has_semtex_on_it" },
    { 0x618E, "has_shotgun" },
    { 0x618F, "has_slayer_ammo" },
    { 0x6190, "has_spawner_chosen_nearby_flag" },
    { 0x6191, "has_special_weapon" },
    { 0x6192, "has_started_thinking" },
    { 0x6193, "has_stealth_meter" },
    { 0x6194, "has_stun_ammo" },
    { 0x6195, "has_tag" },
    { 0x6196, "has_team_armor" },
    { 0x6197, "has_thrown_flashbang" },
    { 0x6198, "has_thrown_noisemaker" },
    { 0x6199, "has_unmatching_deathmodel_rig" },
    { 0x619A, "has_usb" },
    { 0x619B, "has_vehicle_type_exceeded_module_cap" },
    { 0x619C, "has_vehicles" },
    { 0x619D, "has_weapon_variation" },
    { 0x619E, "has_weapon_variation_without_attachments" },
    { 0x619F, "has_zis_soul_key" },
    { 0x61A0, "has_zombie_perk" },
    { 0x61A1, "hasachievement" },
    { 0x61A2, "hasactivesmokegrenade" },
    { 0x61A3, "hasammoinclip" },
    { 0x61A4, "hasanim" },
    { 0x61A5, "hasanim_generic" },
    { 0x61A6, "hasanotherwallrun" },
    { 0x61A7, "hasarenaspawned" },
    { 0x61A8, "hasarmor" },
    { 0x61A9, "hasarrivals" },
    { 0x61AA, "hasatleastammo" },
    { 0x61AB, "hasattachedweapons" },
    { 0x61AC, "hasattachmentconflict" },
    { 0x61AD, "hasattachmentconflictwithweapon" },
    { 0x61AE, "hasattachmenttype" },
    { 0x61AF, "hasbanked" },
    { 0x61B0, "hasbeenhitwithemp" },
    { 0x61B1, "hasbeenjugg" },
    { 0x61B2, "hasbeentracked" },
    { 0x61B3, "hasbeenused" },
    { 0x61B4, "hasbots" },
    { 0x61B5, "haschangedarchetype" },
    { 0x61B6, "haschangedclass" },
    { 0x61B7, "hasclip" },
    { 0x61B8, "hasclusterdata" },
    { 0x61B9, "hascustomnotetrackhandler" },
    { 0x61BA, "hasdeath" },
    { 0x61BB, "hasdied" },
    { 0x61BC, "hasdistdata" },
    { 0x61BD, "hasdomflags" },
    { 0x61BE, "hasdonecombat" },
    { 0x61BF, "hasdonepainbreathloopthislife" },
    { 0x61C0, "hasdroppedlmg" },
    { 0x61C1, "hasenemysightpos" },
    { 0x61C2, "hasequipment" },
    { 0x61C3, "hasequipmentoftype" },
    { 0x61C4, "hasexecution" },
    { 0x61C5, "hasexitedvehicle" },
    { 0x61C6, "hasexits" },
    { 0x61C7, "hasexploded" },
    { 0x61C8, "hasextractionkillstreak" },
    { 0x61C9, "hasgasmask" },
    { 0x61CA, "hasgl3weapon" },
    { 0x61CB, "hasgrenadetimerelapsed" },
    { 0x61CC, "hashandle" },
    { 0x61CD, "hasheadgear" },
    { 0x61CE, "hashealthshield" },
    { 0x61CF, "hasheavyarmor" },
    { 0x61D0, "hasheavyarmorinvulnerability" },
    { 0x61D1, "hashelicopterturret" },
    { 0x61D2, "hashelmet" },
    { 0x61D3, "hasincoming" },
    { 0x61D4, "hasinflictor" },
    { 0x61D5, "hasinitfunc" },
    { 0x61D6, "hasintro" },
    { 0x61D7, "hasjuiced" },
    { 0x61D8, "haskillstreak" },
    { 0x61D9, "hasknife" },
    { 0x61DA, "haslanedata" },
    { 0x61DB, "haslethalequipment" },
    { 0x61DC, "hasleveldata" },
    { 0x61DD, "haslevelveteranaward" },
    { 0x61DE, "haslightarmor" },
    { 0x61DF, "haslos" },
    { 0x61E0, "haslowarmor" },
    { 0x61E1, "hasmaxarmor" },
    { 0x61E2, "hasmaxarmorvests" },
    { 0x61E3, "hasmaxhealth" },
    { 0x61E4, "hasmissionhardenedaward" },
    { 0x61E5, "hasnointeraction" },
    { 0x61E6, "hasnophysics" },
    { 0x61E7, "hasnukeselectks" },
    { 0x61E8, "hasoutro" },
    { 0x61E9, "hasowner" },
    { 0x61EA, "haspain" },
    { 0x61EB, "hasperksprintfire" },
    { 0x61EC, "haspickedupplunderyet" },
    { 0x61ED, "hasplayedidleintro" },
    { 0x61EE, "hasplayedvignetteanim" },
    { 0x61EF, "hasplayerdiedwhileusingkillstreak" },
    { 0x61F0, "hasplayerentattached" },
    { 0x61F1, "haspower" },
    { 0x61F2, "hasprogressbar" },
    { 0x61F3, "hasreact" },
    { 0x61F4, "hasrearguardshield" },
    { 0x61F5, "hasregenfaster" },
    { 0x61F6, "hasrephase" },
    { 0x61F7, "hasrequiredcrafteditemfordestruction" },
    { 0x61F8, "hasrespawntoken" },
    { 0x61F9, "hasriotshield" },
    { 0x61FA, "hasriotshieldequipped" },
    { 0x61FB, "hasroomtofullexposecorner" },
    { 0x61FC, "hasruggedeqp" },
    { 0x61FD, "hasscope" },
    { 0x61FE, "hasshownlaststandicon" },
    { 0x61FF, "hasshownvisdistdataerror" },
    { 0x6200, "hassightdata" },
    { 0x6201, "hassolobuddyboost" },
    { 0x6202, "hasspawned" },
    { 0x6203, "hasspawnradar" },
    { 0x6204, "hasstarted" },
    { 0x6205, "hassuppressableenemy" },
    { 0x6206, "hassuppressedweapons" },
    { 0x6207, "hastag" },
    { 0x6208, "hasthreespawns" },
    { 0x6209, "hastraversed" },
    { 0x620A, "hastripwirechild" },
    { 0x620B, "hasvalidationinfraction" },
    { 0x620C, "hasvehicle" },
    { 0x620D, "hasvisitedgwspawnselection" },
    { 0x620E, "hat" },
    { 0x620F, "hatmodel" },
    { 0x6210, "have_clan_tag" },
    { 0x6211, "have_permanent_perks" },
    { 0x6212, "have_props_spawned" },
    { 0x6213, "have_self_revive" },
    { 0x6214, "have_things_in_lost_and_found" },
    { 0x6215, "havedataformerit" },
    { 0x6216, "haveinvulnerabilityavailable" },
    { 0x6217, "havenothingtoshoot" },
    { 0x6218, "haveselfrevive" },
    { 0x6219, "havespawnedplayers" },
    { 0x621A, "havesquadmemberscompletedmove" },
    { 0x621B, "haywire" },
    { 0x621C, "haze_watcher" },
    { 0x621D, "hb_sensor_used" },
    { 0x621E, "hc_worker_01" },
    { 0x621F, "hc_workers_scene" },
    { 0x6220, "hcrdata" },
    { 0x6221, "head" },
    { 0x6222, "head_center_anim" },
    { 0x6223, "head_icon" },
    { 0x6224, "head_is_exploding" },
    { 0x6225, "head_left_anim" },
    { 0x6226, "head_leftback_anim" },
    { 0x6227, "head_model" },
    { 0x6228, "head_right_anim" },
    { 0x6229, "head_rightback_anim" },
    { 0x622A, "head_shot_dist" },
    { 0x622B, "headed_to_level_3_vo" },
    { 0x622C, "headequiptoggleloop" },
    { 0x622D, "headicon" },
    { 0x622E, "headiconactive" },
    { 0x622F, "headicondeath" },
    { 0x6230, "headicondrawrange" },
    { 0x6231, "headiconents" },
    { 0x6232, "headiconforcapture" },
    { 0x6233, "headiconheight" },
    { 0x6234, "headiconid" },
    { 0x6235, "headiconnaturalrange" },
    { 0x6236, "headiconoffset" },
    { 0x6237, "headiconowneroverride" },
    { 0x6238, "headiconteam" },
    { 0x6239, "headiconteamoverride" },
    { 0x623A, "heading" },
    { 0x623B, "heading_for_tag_pile" },
    { 0x623C, "heading_to_rooftop_check" },
    { 0x623D, "headknob" },
    { 0x623E, "headlights" },
    { 0x623F, "headlook_enabled" },
    { 0x6240, "headlookatoffset" },
    { 0x6241, "headmodel" },
    { 0x6242, "headmodelname" },
    { 0x6243, "headpop" },
    { 0x6244, "headquarters_captured_music" },
    { 0x6245, "headquarters_deactivate_music" },
    { 0x6246, "headquarters_newhq_music" },
    { 0x6247, "headshot" },
    { 0x6248, "headshot_death" },
    { 0x6249, "headshot_reload_check" },
    { 0x624A, "headshot_reload_time" },
    { 0x624B, "headshots" },
    { 0x624C, "headtrack_off" },
    { 0x624D, "headtrack_on" },
    { 0x624E, "headtrack_player_toggle" },
    { 0x624F, "heal_removeondamage" },
    { 0x6250, "heal_removeonplayernotifies" },
    { 0x6251, "healedoverlay" },
    { 0x6252, "healedoverlaydestructor" },
    { 0x6253, "healedoverlayfade" },
    { 0x6254, "healend" },
    { 0x6255, "healer" },
    { 0x6256, "healerperkteammatedestructor" },
    { 0x6257, "healerperkteammatewatcher" },
    { 0x6258, "healhregenthink" },
    { 0x6259, "health_drain" },
    { 0x625A, "health_meter_monitor" },
    { 0x625B, "health_overlay" },
    { 0x625C, "health_remaining" },
    { 0x625D, "health_scalar" },
    { 0x625E, "health_scale" },
    { 0x625F, "healthbarid" },
    { 0x6260, "healthbars" },
    { 0x6261, "healthbox_canusedeployable" },
    { 0x6262, "healthbox_grenadelaunchfunc" },
    { 0x6263, "healthbox_onusedeployable" },
    { 0x6264, "healthbuffer" },
    { 0x6265, "healthdraining_ui_set" },
    { 0x6266, "healthfireengulfrate" },
    { 0x6267, "healthfireinvulseconds" },
    { 0x6268, "healthitems" },
    { 0x6269, "healthoverlaycutoff" },
    { 0x626A, "healthratio" },
    { 0x626B, "healthratioinverse" },
    { 0x626C, "healthregen" },
    { 0x626D, "healthregendelay" },
    { 0x626E, "healthregendelaymax" },
    { 0x626F, "healthregendelaymin" },
    { 0x6270, "healthregendisabled" },
    { 0x6271, "healthregeneration" },
    { 0x6272, "healthregeninit" },
    { 0x6273, "healthregenrate" },
    { 0x6274, "healthregenratemax" },
    { 0x6275, "healthregenratemin" },
    { 0x6276, "healthshield" },
    { 0x6277, "healthshieldmod" },
    { 0x6278, "heap" },
    { 0x6279, "heapinsert" },
    { 0x627A, "heappeek" },
    { 0x627B, "heappop" },
    { 0x627C, "heapsize" },
    { 0x627D, "heard_player" },
    { 0x627E, "heat" },
    { 0x627F, "heat_reload_anim" },
    { 0x6280, "heat_signature_tracker" },
    { 0x6281, "heatlevel" },
    { 0x6282, "heavy_chance" },
    { 0x6283, "heavyarmor" },
    { 0x6284, "heavyarmor_break" },
    { 0x6285, "heavyarmor_getdamagemodifier" },
    { 0x6286, "heavyarmormodifydamage" },
    { 0x6287, "heightforhighcallout" },
    { 0x6288, "heightmapmaxsize" },
    { 0x6289, "heightoffset" },
    { 0x628A, "heirarchytest" },
    { 0x628B, "heldoffhandbreak" },
    { 0x628C, "heldspawner" },
    { 0x628D, "heldspawner_think" },
    { 0x628E, "heli" },
    { 0x628F, "heli_add_mg" },
    { 0x6290, "heli_angle_offset" },
    { 0x6291, "heli_approach_catchup" },
    { 0x6292, "heli_approach_main" },
    { 0x6293, "heli_approach_start" },
    { 0x6294, "heli_attack_catchup" },
    { 0x6295, "heli_attack_fire_progression" },
    { 0x6296, "heli_attack_logic" },
    { 0x6297, "heli_attack_main" },
    { 0x6298, "heli_attack_objective" },
    { 0x6299, "heli_attack_player_heli_return" },
    { 0x629A, "heli_attack_scene" },
    { 0x629B, "heli_attack_start" },
    { 0x629C, "heli_attract_range" },
    { 0x629D, "heli_attract_strength" },
    { 0x629E, "heli_boss_precache" },
    { 0x629F, "heli_can_see_target" },
    { 0x62A0, "heli_can_target" },
    { 0x62A1, "heli_can_target_dist" },
    { 0x62A2, "heli_charlie" },
    { 0x62A3, "heli_check_players" },
    { 0x62A4, "heli_circling_think" },
    { 0x62A5, "heli_civ_ambush_1" },
    { 0x62A6, "heli_cleanup_exfil_area" },
    { 0x62A7, "heli_commander_sfx" },
    { 0x62A8, "heli_corpse_burn" },
    { 0x62A9, "heli_crash" },
    { 0x62AA, "heli_crash_debris_post" },
    { 0x62AB, "heli_crash_debris_post_roof" },
    { 0x62AC, "heli_crash_debris_pre" },
    { 0x62AD, "heli_crash_debris_setup" },
    { 0x62AE, "heli_crash_fire_lights" },
    { 0x62AF, "heli_crash_indirect_zoff" },
    { 0x62B0, "heli_crash_lead" },
    { 0x62B1, "heli_crash_lights" },
    { 0x62B2, "heli_crash_nodes" },
    { 0x62B3, "heli_crash_on_pilot_death" },
    { 0x62B4, "heli_crash_path_loc_setup" },
    { 0x62B5, "heli_crash_swap" },
    { 0x62B6, "heli_crash_timeout" },
    { 0x62B7, "heli_crash_timer" },
    { 0x62B8, "heli_crawl_to_idle" },
    { 0x62B9, "heli_damage_death" },
    { 0x62BA, "heli_damage_monitor" },
    { 0x62BB, "heli_damage_update" },
    { 0x62BC, "heli_damagemonitor" },
    { 0x62BD, "heli_death_monitor" },
    { 0x62BE, "heli_death_thread" },
    { 0x62BF, "heli_debug" },
    { 0x62C0, "heli_default_missiles_off" },
    { 0x62C1, "heli_default_missiles_on" },
    { 0x62C2, "heli_default_target_cleanup" },
    { 0x62C3, "heli_default_target_setup" },
    { 0x62C4, "heli_depart" },
    { 0x62C5, "heli_destroyed" },
    { 0x62C6, "heli_destructible_ceiling_logic" },
    { 0x62C7, "heli_destructible_propane_tank_logic" },
    { 0x62C8, "heli_dmg_sparks" },
    { 0x62C9, "heli_done_unloading" },
    { 0x62CA, "heli_door_open_sfx" },
    { 0x62CB, "heli_down_init" },
    { 0x62CC, "heli_down_precache" },
    { 0x62CD, "heli_down_structs" },
    { 0x62CE, "heli_evade" },
    { 0x62CF, "heli_event_escape" },
    { 0x62D0, "heli_event_hallway_run" },
    { 0x62D1, "heli_event_obj_room" },
    { 0x62D2, "heli_event_stairs_explosion" },
    { 0x62D3, "heli_event_tunnel" },
    { 0x62D4, "heli_existance" },
    { 0x62D5, "heli_explode" },
    { 0x62D6, "heli_fail_time_within_limit" },
    { 0x62D7, "heli_fight_start" },
    { 0x62D8, "heli_final_path" },
    { 0x62D9, "heli_fire_magic_bullet" },
    { 0x62DA, "heli_fire_missile" },
    { 0x62DB, "heli_fire_missiles" },
    { 0x62DC, "heli_fire_rocket_at_building" },
    { 0x62DD, "heli_firelink" },
    { 0x62DE, "heli_fly_loop_path" },
    { 0x62DF, "heli_fly_simple_path" },
    { 0x62E0, "heli_fly_well" },
    { 0x62E1, "heli_force_search" },
    { 0x62E2, "heli_forced_wait" },
    { 0x62E3, "heli_fov_check" },
    { 0x62E4, "heli_gate_molotov" },
    { 0x62E5, "heli_gate_molotov_helper" },
    { 0x62E6, "heli_get_node_origin" },
    { 0x62E7, "heli_get_target" },
    { 0x62E8, "heli_get_target_ai_only" },
    { 0x62E9, "heli_get_target_player_only" },
    { 0x62EA, "heli_getteamforsoundclip" },
    { 0x62EB, "heli_go_search" },
    { 0x62EC, "heli_goal_think" },
    { 0x62ED, "heli_guys" },
    { 0x62EE, "heli_hallway_mover" },
    { 0x62EF, "heli_has_player_target" },
    { 0x62F0, "heli_has_target" },
    { 0x62F1, "heli_headicon" },
    { 0x62F2, "heli_health" },
    { 0x62F3, "heli_help" },
    { 0x62F4, "heli_idle_movement" },
    { 0x62F5, "heli_infil_radio_idle" },
    { 0x62F6, "heli_interactive_think" },
    { 0x62F7, "heli_interior_lights" },
    { 0x62F8, "heli_interior_sfx" },
    { 0x62F9, "heli_intro_anim" },
    { 0x62FA, "heli_intro_anim_unlink_player" },
    { 0x62FB, "heli_intro_scene" },
    { 0x62FC, "heli_intro_vo" },
    { 0x62FD, "heli_is_threatened" },
    { 0x62FE, "heli_kyle_third_person" },
    { 0x62FF, "heli_lastattacker" },
    { 0x6300, "heli_leave" },
    { 0x6301, "heli_leave_nodes" },
    { 0x6302, "heli_leave_on_changeteams" },
    { 0x6303, "heli_leave_on_disconnect" },
    { 0x6304, "heli_leave_on_gameended" },
    { 0x6305, "heli_leave_on_spawned" },
    { 0x6306, "heli_leave_on_timeout" },
    { 0x6307, "heli_letter_boxing" },
    { 0x6308, "heli_light_disable_on_spawn" },
    { 0x6309, "heli_loc" },
    { 0x630A, "heli_logic" },
    { 0x630B, "heli_loop_nodes" },
    { 0x630C, "heli_loop_speed_control" },
    { 0x630D, "heli_maxhealth" },
    { 0x630E, "heli_mg" },
    { 0x630F, "heli_mg_create" },
    { 0x6310, "heli_minigun_override" },
    { 0x6311, "heli_minigun_shoot_til_notify" },
    { 0x6312, "heli_missiles_think" },
    { 0x6313, "heli_mosoleum_flyby_1" },
    { 0x6314, "heli_move" },
    { 0x6315, "heli_move_script" },
    { 0x6316, "heli_move_to_target" },
    { 0x6317, "heli_movement" },
    { 0x6318, "heli_movement_escape" },
    { 0x6319, "heli_movetopos_and_idle" },
    { 0x631A, "heli_murder_player_in_hallway" },
    { 0x631B, "heli_normal_think" },
    { 0x631C, "heli_path" },
    { 0x631D, "heli_path_func" },
    { 0x631E, "heli_pick_node_furthest_from_center" },
    { 0x631F, "heli_pilot" },
    { 0x6320, "heli_pilot_allowed" },
    { 0x6321, "heli_pilot_control_heli_aiming" },
    { 0x6322, "heli_pilot_mesh" },
    { 0x6323, "heli_pilot_missile_radius" },
    { 0x6324, "heli_pilot_monitor_flares" },
    { 0x6325, "heli_pilot_pick_node" },
    { 0x6326, "heli_pilot_setup" },
    { 0x6327, "heli_pilot_waittill_initial_goal" },
    { 0x6328, "heli_player_damage_radius" },
    { 0x6329, "heli_player_prone" },
    { 0x632A, "heli_pos_override_trig" },
    { 0x632B, "heli_precache" },
    { 0x632C, "heli_replenish_health_after_death" },
    { 0x632D, "heli_reset" },
    { 0x632E, "heli_return_spotlight_player_exposed" },
    { 0x632F, "heli_return_spotlight_player_hidden" },
    { 0x6330, "heli_ride_in_fx" },
    { 0x6331, "heli_ride_in_fx_skippable" },
    { 0x6332, "heli_ride_in_vo" },
    { 0x6333, "heli_ride_intro_extras" },
    { 0x6334, "heli_rocket" },
    { 0x6335, "heli_rocket_fire" },
    { 0x6336, "heli_rocket_think_default" },
    { 0x6337, "heli_rocketeer" },
    { 0x6338, "heli_rumble_helper" },
    { 0x6339, "heli_secondary_explosions" },
    { 0x633A, "heli_sfx_shutdown" },
    { 0x633B, "heli_shake_controller" },
    { 0x633C, "heli_shake_door_closed" },
    { 0x633D, "heli_shake_door_open" },
    { 0x633E, "heli_shake_rope" },
    { 0x633F, "heli_shake_spin" },
    { 0x6340, "heli_shake_stop" },
    { 0x6341, "heli_shoot_obj_room" },
    { 0x6342, "heli_shoot_player" },
    { 0x6343, "heli_shoot_think" },
    { 0x6344, "heli_shoots_hallway" },
    { 0x6345, "heli_sniper_allowed" },
    { 0x6346, "heli_sniper_clear_script_goal_on_ride" },
    { 0x6347, "heli_sniper_pick_node" },
    { 0x6348, "heli_sniper_waittill_initial_goal" },
    { 0x6349, "heli_sound" },
    { 0x634A, "heli_sound_handler" },
    { 0x634B, "heli_spawn_alpha" },
    { 0x634C, "heli_spawn_bravo" },
    { 0x634D, "heli_spawn_charlie" },
    { 0x634E, "heli_spin" },
    { 0x634F, "heli_spotlight_aim" },
    { 0x6350, "heli_spotlight_aim_ents_cleanup" },
    { 0x6351, "heli_spotlight_cleanup" },
    { 0x6352, "heli_spotlight_create" },
    { 0x6353, "heli_spotlight_create_default_targets" },
    { 0x6354, "heli_spotlight_damage_death" },
    { 0x6355, "heli_spotlight_destroy_default_targets" },
    { 0x6356, "heli_spotlight_escape" },
    { 0x6357, "heli_spotlight_heli_return" },
    { 0x6358, "heli_spotlight_hunt" },
    { 0x6359, "heli_spotlight_killed_heli_return" },
    { 0x635A, "heli_spotlight_off" },
    { 0x635B, "heli_spotlight_on" },
    { 0x635C, "heli_spotlight_random_targets_off" },
    { 0x635D, "heli_spotlight_random_targets_on" },
    { 0x635E, "heli_spotlight_sweep" },
    { 0x635F, "heli_spotlight_think" },
    { 0x6360, "heli_spotlight_toggle" },
    { 0x6361, "heli_stairwell_1" },
    { 0x6362, "heli_stairwell_2" },
    { 0x6363, "heli_start_nodes" },
    { 0x6364, "heli_stop" },
    { 0x6365, "heli_stop_for_context" },
    { 0x6366, "heli_strafing_run" },
    { 0x6367, "heli_structs_entrances" },
    { 0x6368, "heli_structs_goals" },
    { 0x6369, "heli_structs_paths" },
    { 0x636A, "heli_target_recognition" },
    { 0x636B, "heli_targeting" },
    { 0x636C, "heli_targeting_delay" },
    { 0x636D, "heli_think" },
    { 0x636E, "heli_think_default" },
    { 0x636F, "heli_triggers" },
    { 0x6370, "heli_trip_vehicle" },
    { 0x6371, "heli_try_rockets" },
    { 0x6372, "heli_turretclipsize" },
    { 0x6373, "heli_type" },
    { 0x6374, "heli_types" },
    { 0x6375, "heli_under_fire" },
    { 0x6376, "heli_under_fire_magic_bullet" },
    { 0x6377, "heli_update_shake" },
    { 0x6378, "heli_visual_range" },
    { 0x6379, "heli_volume" },
    { 0x637A, "heli_wait_node" },
    { 0x637B, "heli_waittill_full_or_timeout" },
    { 0x637C, "heli_watchdeath" },
    { 0x637D, "heli_watchempdamage" },
    { 0x637E, "heli_windy_price" },
    { 0x637F, "heli_wreckage" },
    { 0x6380, "heli_wreckage_break" },
    { 0x6381, "heli_wreckage_first_frame" },
    { 0x6382, "heli_wreckage_setup" },
    { 0x6383, "heliattackwarning" },
    { 0x6384, "helicleanupdepotonleaving" },
    { 0x6385, "helicleanupextract" },
    { 0x6386, "heliconfigs" },
    { 0x6387, "helicopter_catchup" },
    { 0x6388, "helicopter_crash_beats" },
    { 0x6389, "helicopter_crash_catchup" },
    { 0x638A, "helicopter_crash_directed" },
    { 0x638B, "helicopter_crash_fall" },
    { 0x638C, "helicopter_crash_fall_price_gun" },
    { 0x638D, "helicopter_crash_fall_relative_to_world" },
    { 0x638E, "helicopter_crash_flavor" },
    { 0x638F, "helicopter_crash_lerp_ap" },
    { 0x6390, "helicopter_crash_locations" },
    { 0x6391, "helicopter_crash_main" },
    { 0x6392, "helicopter_crash_move" },
    { 0x6393, "helicopter_crash_path" },
    { 0x6394, "helicopter_crash_pilot" },
    { 0x6395, "helicopter_crash_rack_focus" },
    { 0x6396, "helicopter_crash_rotate" },
    { 0x6397, "helicopter_crash_start" },
    { 0x6398, "helicopter_crash_vfx" },
    { 0x6399, "helicopter_crash_zigzag" },
    { 0x639A, "helicopter_crawl_catchup" },
    { 0x639B, "helicopter_crawl_main" },
    { 0x639C, "helicopter_crawl_start" },
    { 0x639D, "helicopter_fall_camera_control_locking" },
    { 0x639E, "helicopter_firelinkfunk" },
    { 0x639F, "helicopter_in_air_explosion" },
    { 0x63A0, "helicopter_lerp_crash_anim" },
    { 0x63A1, "helicopter_list" },
    { 0x63A2, "helicopter_main" },
    { 0x63A3, "helicopter_pilot_death_explosion" },
    { 0x63A4, "helicopter_player_fall" },
    { 0x63A5, "helicopter_player_fall_anim" },
    { 0x63A6, "helicopter_predator_target_shader" },
    { 0x63A7, "helicopter_spawn_function_init" },
    { 0x63A8, "helicopter_spin_fail" },
    { 0x63A9, "helicopter_start" },
    { 0x63AA, "helicopter_tree_watcher" },
    { 0x63AB, "helicopter_unloading_watcher" },
    { 0x63AC, "helicopters_controller" },
    { 0x63AD, "helicreateextractvfx" },
    { 0x63AE, "helidepotthink" },
    { 0x63AF, "helidescend" },
    { 0x63B0, "helidialog" },
    { 0x63B1, "helidown_corpse_present" },
    { 0x63B2, "helidown_downed_pilot" },
    { 0x63B3, "helidown_escort_start_func" },
    { 0x63B4, "helidown_event_active" },
    { 0x63B5, "helidown_long_cut_len" },
    { 0x63B6, "helidown_start_func" },
    { 0x63B7, "helidown_start_func_debug" },
    { 0x63B8, "helidown_vip_close_to_exfil_dist_sq" },
    { 0x63B9, "helidronefx" },
    { 0x63BA, "heliendtime" },
    { 0x63BB, "heliextract_used" },
    { 0x63BC, "heliextractplunder" },
    { 0x63BD, "helifollowpath" },
    { 0x63BE, "heligotostartposition" },
    { 0x63BF, "heliheight" },
    { 0x63C0, "heliheightoffset" },
    { 0x63C1, "heliheightoverride" },
    { 0x63C2, "heliinproximity" },
    { 0x63C3, "heliisfacing" },
    { 0x63C4, "helimakedepotwait" },
    { 0x63C5, "helipathmemory" },
    { 0x63C6, "helipilot_endride" },
    { 0x63C7, "helipilot_freezebuffer" },
    { 0x63C8, "helipilot_getcloseststartnode" },
    { 0x63C9, "helipilot_getlinkedstruct" },
    { 0x63CA, "helipilot_leave" },
    { 0x63CB, "helipilot_lightfx" },
    { 0x63CC, "helipilot_setairstartnodes" },
    { 0x63CD, "helipilot_watchads" },
    { 0x63CE, "helipilot_watchdeath" },
    { 0x63CF, "helipilot_watchobjectivecam" },
    { 0x63D0, "helipilot_watchownerloss" },
    { 0x63D1, "helipilot_watchroundend" },
    { 0x63D2, "helipilot_watchtimeout" },
    { 0x63D3, "helipilotsettings" },
    { 0x63D4, "helipilottype" },
    { 0x63D5, "heliremoveoutline" },
    { 0x63D6, "helis" },
    { 0x63D7, "helis_convoy_overhead_1" },
    { 0x63D8, "helis_convoy_overhead_2" },
    { 0x63D9, "helis_convoy_overhead_detonated_1" },
    { 0x63DA, "helis_convoy_overhead_detonated_2" },
    { 0x63DB, "helis_house_stairs_window_1" },
    { 0x63DC, "helis_if_you_look_backwards_1" },
    { 0x63DD, "helis_surround_hospital_1" },
    { 0x63DE, "helis_surround_hospital_2" },
    { 0x63DF, "helis_surround_hospital_3" },
    { 0x63E0, "helithink" },
    { 0x63E1, "helitrip_next_rig_num" },
    { 0x63E2, "helitype" },
    { 0x63E3, "heliusecleanup" },
    { 0x63E4, "heliwatchgameendleave" },
    { 0x63E5, "hell_cannon_intro_scene" },
    { 0x63E6, "hell_cannon_reactions" },
    { 0x63E7, "hellcannon_first_strike" },
    { 0x63E8, "hellcannon_lights" },
    { 0x63E9, "hellfire_count" },
    { 0x63EA, "hellfire_launch_attempt" },
    { 0x63EB, "hellfire_max" },
    { 0x63EC, "hellfire_rocket_launch_sfx" },
    { 0x63ED, "helmet" },
    { 0x63EE, "helmet_clearbroke" },
    { 0x63EF, "helmet_clearhit" },
    { 0x63F0, "helmet_meters" },
    { 0x63F1, "helmet_meters_airlock_in" },
    { 0x63F2, "helmet_meters_airlock_out" },
    { 0x63F3, "helmet_meters_forced_decompress" },
    { 0x63F4, "helmet_meters_init" },
    { 0x63F5, "helmet_meters_normal_ship" },
    { 0x63F6, "helmet_meters_normal_suit" },
    { 0x63F7, "helmet_meters_off" },
    { 0x63F8, "helmet_meters_on" },
    { 0x63F9, "helmet_meters_ramp" },
    { 0x63FA, "helmet_meters_ramp_and_stabilize" },
    { 0x63FB, "helmet_meters_rounding" },
    { 0x63FC, "helmet_meters_set_oxygen" },
    { 0x63FD, "helmet_meters_set_pressure" },
    { 0x63FE, "helmet_meters_set_temperature" },
    { 0x63FF, "helmet_meters_stabilize" },
    { 0x6400, "helmet_setbroke" },
    { 0x6401, "helmet_sethit" },
    { 0x6402, "helmet_wasbroke" },
    { 0x6403, "helmet_washit" },
    { 0x6404, "helmethealth" },
    { 0x6405, "helmetitemtypeforlevel" },
    { 0x6406, "helmetlaunch" },
    { 0x6407, "helmetpop" },
    { 0x6408, "helmetshatterfx" },
    { 0x6409, "helmetsidemodel" },
    { 0x640A, "helmetsubpart" },
    { 0x640B, "helo_alley_wait" },
    { 0x640C, "helo_controller_spawn_func_alley_close" },
    { 0x640D, "helo_controller_spawn_func_alley_far" },
    { 0x640E, "helo_controller_spawn_func_poppies_close" },
    { 0x640F, "helo_controller_spawn_func_poppies_far" },
    { 0x6410, "helo_poppies_wait" },
    { 0x6411, "heloextracttryuse" },
    { 0x6412, "helokills" },
    { 0x6413, "helper_drone_init" },
    { 0x6414, "helperdrone" },
    { 0x6415, "helperdrone_checkmanualpulsetargets" },
    { 0x6416, "helperdrone_deliver" },
    { 0x6417, "helperdrone_destroyongameend" },
    { 0x6418, "helperdrone_disableradar" },
    { 0x6419, "helperdrone_empapplied" },
    { 0x641A, "helperdrone_enableoffhanddelayed" },
    { 0x641B, "helperdrone_enableradar" },
    { 0x641C, "helperdrone_endscramblereffect" },
    { 0x641D, "helperdrone_entaffectedbyscramble" },
    { 0x641E, "helperdrone_followplayer" },
    { 0x641F, "helperdrone_getcurrenthealth" },
    { 0x6420, "helperdrone_getheightoffset" },
    { 0x6421, "helperdrone_getnumdrones" },
    { 0x6422, "helperdrone_getownerlookat" },
    { 0x6423, "helperdrone_getpathend" },
    { 0x6424, "helperdrone_gettargetoffset" },
    { 0x6425, "helperdrone_getthermalswitchplayercommand" },
    { 0x6426, "helperdrone_giveplayerfauxremote" },
    { 0x6427, "helperdrone_guardlocation" },
    { 0x6428, "helperdrone_handleplayerthermalinputchange" },
    { 0x6429, "helperdrone_handleteamvisibility" },
    { 0x642A, "helperdrone_handlethermalswitch" },
    { 0x642B, "helperdrone_handlethermalswitchinternal" },
    { 0x642C, "helperdrone_istargetinreticle" },
    { 0x642D, "helperdrone_leave" },
    { 0x642E, "helperdrone_lockedoncallback" },
    { 0x642F, "helperdrone_lockedonremovedcallback" },
    { 0x6430, "helperdrone_managescramblereffect" },
    { 0x6431, "helperdrone_managescramblerplayerbuff" },
    { 0x6432, "helperdrone_managevisibilityonteamjoin" },
    { 0x6433, "helperdrone_markequipment" },
    { 0x6434, "helperdrone_markkillstreaks" },
    { 0x6435, "helperdrone_marklastposition" },
    { 0x6436, "helperdrone_markplayers" },
    { 0x6437, "helperdrone_markplayers_cp" },
    { 0x6438, "helperdrone_modifydamageresponse" },
    { 0x6439, "helperdrone_modifydamagestates" },
    { 0x643A, "helperdrone_moveintoplace" },
    { 0x643B, "helperdrone_movetoplayer" },
    { 0x643C, "helperdrone_moving_platform_death" },
    { 0x643D, "helperdrone_overwatchplayer" },
    { 0x643E, "helperdrone_pingnearbyenemies" },
    { 0x643F, "helperdrone_play_lightfx" },
    { 0x6440, "helperdrone_returnplayer" },
    { 0x6441, "helperdrone_setscramblerjammed" },
    { 0x6442, "helperdrone_setscramblerplayerbuffs" },
    { 0x6443, "helperdrone_showminimaponspawn" },
    { 0x6444, "helperdrone_spawnnewscrambler" },
    { 0x6445, "helperdrone_startmanualradarpulse" },
    { 0x6446, "helperdrone_stunned" },
    { 0x6447, "helperdrone_takeplayerfauxremote" },
    { 0x6448, "helperdrone_updateheadicononjointeam" },
    { 0x6449, "helperdrone_watchdamage" },
    { 0x644A, "helperdrone_watchearlyexit" },
    { 0x644B, "helperdrone_watchforgoal" },
    { 0x644C, "helperdrone_watchmodeswitch" },
    { 0x644D, "helperdrone_watchnotificationstate" },
    { 0x644E, "helperdrone_watchouterreticlestate" },
    { 0x644F, "helperdrone_watchouterreticletargets" },
    { 0x6450, "helperdrone_watchownerdeath" },
    { 0x6451, "helperdrone_watchownerloss" },
    { 0x6452, "helperdrone_watchownerstatus" },
    { 0x6453, "helperdrone_watchpingedstatus" },
    { 0x6454, "helperdrone_watchpulsedart" },
    { 0x6455, "helperdrone_watchpulsedartdamage" },
    { 0x6456, "helperdrone_watchpulsedartdeath" },
    { 0x6457, "helperdrone_watchpulsedarttimeout" },
    { 0x6458, "helperdrone_watchradarpulse" },
    { 0x6459, "helperdrone_watchradartrigger" },
    { 0x645A, "helperdrone_watchremotescrambledent" },
    { 0x645B, "helperdrone_watchroundend" },
    { 0x645C, "helperdrone_watchscamblereffectdist" },
    { 0x645D, "helperdrone_watchscramblestrength" },
    { 0x645E, "helperdrone_watchshootpulsedart" },
    { 0x645F, "helperdrone_watchtimeout" },
    { 0x6460, "helperdronecreationfailedfx" },
    { 0x6461, "helperdronedestroyed" },
    { 0x6462, "helperdroneexplode" },
    { 0x6463, "helperdronefx" },
    { 0x6464, "helperdronesettings" },
    { 0x6465, "helperdronetype" },
    { 0x6466, "helpresponses" },
    { 0x6467, "henchman" },
    { 0x6468, "henchman_fire_at_player" },
    { 0x6469, "henchman_shove_doorway" },
    { 0x646A, "henchman_shove_moving" },
    { 0x646B, "henchman_spawn_func" },
    { 0x646C, "henchman_start_escort" },
    { 0x646D, "henchman_waterboard_walk" },
    { 0x646E, "henchman_waterboard_walk_shove" },
    { 0x646F, "henchman2" },
    { 0x6470, "henchman3" },
    { 0x6471, "henchmen_final_anim_and_cleanup" },
    { 0x6472, "hero_battlechattteradjustments" },
    { 0x6473, "heroes" },
    { 0x6474, "hi_wait" },
    { 0x6475, "hidden" },
    { 0x6476, "hiddencrouchdetectdist" },
    { 0x6477, "hiddenobjcount" },
    { 0x6478, "hiddenplayercrouchmovedist" },
    { 0x6479, "hiddenplayerpronemovedist" },
    { 0x647A, "hiddenplayerstandmovedist" },
    { 0x647B, "hiddenpronedetectdist" },
    { 0x647C, "hiddenreviveents" },
    { 0x647D, "hiddenstanddetectdist" },
    { 0x647E, "hide_ai_marker_vfx_to_player" },
    { 0x647F, "hide_all_revive_icons" },
    { 0x6480, "hide_apache_forward_hint" },
    { 0x6481, "hide_apache_retreat_hint" },
    { 0x6482, "hide_armory_guns" },
    { 0x6483, "hide_bomb_from_drone" },
    { 0x6484, "hide_bombdetonationkillenemieslogic" },
    { 0x6485, "hide_bombdetonationlogic" },
    { 0x6486, "hide_bottle_monitor" },
    { 0x6487, "hide_brush" },
    { 0x6488, "hide_chopper_guns_hint" },
    { 0x6489, "hide_chopper_hint" },
    { 0x648A, "hide_chopper_rocket_hint" },
    { 0x648B, "hide_chopper_zoom_hint" },
    { 0x648C, "hide_clip_stuff" },
    { 0x648D, "hide_combat_stuff" },
    { 0x648E, "hide_crawl_forward_hint" },
    { 0x648F, "hide_critical_target_icon_to_player" },
    { 0x6490, "hide_defend_scriptables" },
    { 0x6491, "hide_delay" },
    { 0x6492, "hide_door_rotate" },
    { 0x6493, "hide_doorlogic" },
    { 0x6494, "hide_drone_detonate_hint" },
    { 0x6495, "hide_drone_hint" },
    { 0x6496, "hide_drone_sprint_hint" },
    { 0x6497, "hide_during_intro" },
    { 0x6498, "hide_enemieslogic" },
    { 0x6499, "hide_enemy_hvt_get_away_message" },
    { 0x649A, "hide_enemy_mortar_shell" },
    { 0x649B, "hide_ent_array" },
    { 0x649C, "hide_entity" },
    { 0x649D, "hide_ents" },
    { 0x649E, "hide_exploder_models" },
    { 0x649F, "hide_exploder_models_proc" },
    { 0x64A0, "hide_fakeplayer_head" },
    { 0x64A1, "hide_farthest_targetmarker_for_player" },
    { 0x64A2, "hide_flash_bang_hint" },
    { 0x64A3, "hide_gas_shack_window_shadow_brush" },
    { 0x64A4, "hide_getanimationstruct" },
    { 0x64A5, "hide_getdoor" },
    { 0x64A6, "hide_getfarahpath" },
    { 0x64A7, "hide_getlights" },
    { 0x64A8, "hide_hill_weapons" },
    { 0x64A9, "hide_hud_on_death" },
    { 0x64AA, "hide_icon_on_pickup" },
    { 0x64AB, "hide_ied_zone_from_player" },
    { 0x64AC, "hide_interact_vehicle" },
    { 0x64AD, "hide_interaction_trigger_from_others" },
    { 0x64AE, "hide_intro_car" },
    { 0x64AF, "hide_jump_hint" },
    { 0x64B0, "hide_machete" },
    { 0x64B1, "hide_main" },
    { 0x64B2, "hide_mask" },
    { 0x64B3, "hide_middle_enemy_turret" },
    { 0x64B4, "hide_molotov_hint" },
    { 0x64B5, "hide_multiple_brush" },
    { 0x64B6, "hide_names" },
    { 0x64B7, "hide_notsolid" },
    { 0x64B8, "hide_objective_widget" },
    { 0x64B9, "hide_offscreen_shadow" },
    { 0x64BA, "hide_old_tarmac_scriptables" },
    { 0x64BB, "hide_part_list" },
    { 0x64BC, "hide_prompt_knife" },
    { 0x64BD, "hide_scaffolding_mayhem" },
    { 0x64BE, "hide_scriptables_til_flag" },
    { 0x64BF, "hide_shield_mortar_guy" },
    { 0x64C0, "hide_spawnenemies" },
    { 0x64C1, "hide_spawnenemyvehicles" },
    { 0x64C2, "hide_square_civs" },
    { 0x64C3, "hide_start" },
    { 0x64C4, "hide_stealth_meter_from" },
    { 0x64C5, "hide_structdamagetriggerlogic" },
    { 0x64C6, "hide_tarmac_scriptables_until_apache" },
    { 0x64C7, "hide_tarmac_trucks" },
    { 0x64C8, "hide_turret" },
    { 0x64C9, "hide_tutorial" },
    { 0x64CA, "hide_vehicleaccuracylogic" },
    { 0x64CB, "hide_vehicleshootlogic" },
    { 0x64CC, "hide_vehicletargetentitycleanuplogic" },
    { 0x64CD, "hide_vehicletargetlogic" },
    { 0x64CE, "hideactors" },
    { 0x64CF, "hideallambulancesforplayer" },
    { 0x64D0, "hideallambulancesforteam" },
    { 0x64D1, "hideallendzonevisuals" },
    { 0x64D2, "hideammoindex" },
    { 0x64D3, "hideassassinationhud" },
    { 0x64D4, "hidebar" },
    { 0x64D5, "hidebasebrushes" },
    { 0x64D6, "hidebombsitesaftermatchstart" },
    { 0x64D7, "hidebrushes" },
    { 0x64D8, "hidecapturebrush" },
    { 0x64D9, "hidecarryiconongameend" },
    { 0x64DA, "hideeffectsforbroshot" },
    { 0x64DB, "hideelem" },
    { 0x64DC, "hideendzonevisualsforteam" },
    { 0x64DD, "hideenemyfobs" },
    { 0x64DE, "hideenemyhq" },
    { 0x64DF, "hidefromall" },
    { 0x64E0, "hidefxarray" },
    { 0x64E1, "hideheadicon" },
    { 0x64E2, "hideheadicons" },
    { 0x64E3, "hideheldweapon" },
    { 0x64E4, "hidehuddisable" },
    { 0x64E5, "hidehudelementongameend" },
    { 0x64E6, "hidehudenable" },
    { 0x64E7, "hidehudenabled" },
    { 0x64E8, "hideinmenu" },
    { 0x64E9, "hideminimap" },
    { 0x64EA, "hidenukefromeveryone" },
    { 0x64EB, "hidenukefromplayer" },
    { 0x64EC, "hideoccupant" },
    { 0x64ED, "hidepartatdepth" },
    { 0x64EE, "hideplacedmodel" },
    { 0x64EF, "hideplayerspecificbrushes" },
    { 0x64F0, "hidestowedweapon" },
    { 0x64F1, "hidetimerdisplayongameend" },
    { 0x64F2, "hideuielements" },
    { 0x64F3, "hideweaponmagattachment" },
    { 0x64F4, "hideworldiconongameend" },
    { 0x64F5, "hiding" },
    { 0x64F6, "hiding_door_anim_thread" },
    { 0x64F7, "hiding_door_enemy_dead_dialogue" },
    { 0x64F8, "hiding_door_enemy_death_dialogue" },
    { 0x64F9, "hiding_door_make_pushable" },
    { 0x64FA, "hiding_door_model" },
    { 0x64FB, "hiding_spot" },
    { 0x64FC, "hiding_until_bank" },
    { 0x64FD, "high_priority_for" },
    { 0x64FE, "high_threshold" },
    { 0x64FF, "high_tower_guys_cleanup" },
    { 0x6500, "highalpha" },
    { 0x6501, "highestallowedstance" },
    { 0x6502, "highestavgaltitude_evaluate" },
    { 0x6503, "highestinfilname" },
    { 0x6504, "highestinfilscore" },
    { 0x6505, "highestmission_ifnotcheating_set" },
    { 0x6506, "highestspawndistratio" },
    { 0x6507, "highlight_all_ents" },
    { 0x6508, "highlight_current_selection" },
    { 0x6509, "highlight_ent" },
    { 0x650A, "highlight_leads_in_fov_init" },
    { 0x650B, "highlight_leads_in_fov_player" },
    { 0x650C, "highlight_leads_loop" },
    { 0x650D, "highlighted_enemies" },
    { 0x650E, "highlighted_ent" },
    { 0x650F, "highlightent" },
    { 0x6510, "highresgpulightgrid" },
    { 0x6511, "hill_apcs" },
    { 0x6512, "hill_bottom_apc_attack" },
    { 0x6513, "hill_bottom_catchup" },
    { 0x6514, "hill_bottom_main" },
    { 0x6515, "hill_bottom_start" },
    { 0x6516, "hill_dmg_func" },
    { 0x6517, "hill_lot_enemies_seek" },
    { 0x6518, "hill_mid_catchup" },
    { 0x6519, "hill_mid_main" },
    { 0x651A, "hill_mid_move_up_nag" },
    { 0x651B, "hill_mid_spawning" },
    { 0x651C, "hill_mid_start" },
    { 0x651D, "hill_pa_chatter_say" },
    { 0x651E, "hill_pa_say" },
    { 0x651F, "hill_postload" },
    { 0x6520, "hill_preload" },
    { 0x6521, "hill_top_catchup" },
    { 0x6522, "hill_top_main" },
    { 0x6523, "hill_top_start" },
    { 0x6524, "hilltop_heli" },
    { 0x6525, "hinge_side" },
    { 0x6526, "hint" },
    { 0x6527, "hint_alt_fire_swap" },
    { 0x6528, "hint_blackbox_interaction" },
    { 0x6529, "hint_bones" },
    { 0x652A, "hint_boost_vo" },
    { 0x652B, "hint_breakfunc" },
    { 0x652C, "hint_buttons_main" },
    { 0x652D, "hint_buttons_rotation" },
    { 0x652E, "hint_buttons_zoffset" },
    { 0x652F, "hint_crouch" },
    { 0x6530, "hint_delay_until" },
    { 0x6531, "hint_delete_on_trigger" },
    { 0x6532, "hint_delete_on_trigger_waittill" },
    { 0x6533, "hint_dist_scale" },
    { 0x6534, "hint_ent" },
    { 0x6535, "hint_ent_notify_trigger" },
    { 0x6536, "hint_extraction" },
    { 0x6537, "hint_fade" },
    { 0x6538, "hint_func" },
    { 0x6539, "hint_grenade_throw" },
    { 0x653A, "hint_jammer_damage" },
    { 0x653B, "hint_locked_door_think" },
    { 0x653C, "hint_locked_doors_vo" },
    { 0x653D, "hint_mount" },
    { 0x653E, "hint_mount_fx" },
    { 0x653F, "hint_nvg_disable_check" },
    { 0x6540, "hint_nvg_enable_check" },
    { 0x6541, "hint_prompt" },
    { 0x6542, "hint_push_cart_vo" },
    { 0x6543, "hint_shoot_on_ladder" },
    { 0x6544, "hint_stick_get_updated" },
    { 0x6545, "hint_stick_update" },
    { 0x6546, "hint_stop" },
    { 0x6547, "hint_string" },
    { 0x6548, "hint_tether" },
    { 0x6549, "hint_timeout" },
    { 0x654A, "hint_to_move" },
    { 0x654B, "hint_use" },
    { 0x654C, "hint_waittill_trigger" },
    { 0x654D, "hint_weapon_swap" },
    { 0x654E, "hintarms1" },
    { 0x654F, "hintarms2" },
    { 0x6550, "hintarms3" },
    { 0x6551, "hintarms4" },
    { 0x6552, "hintcalltraininteract" },
    { 0x6553, "hintcommslaptop" },
    { 0x6554, "hintdist" },
    { 0x6555, "hintelement" },
    { 0x6556, "hintenter" },
    { 0x6557, "hintexit" },
    { 0x6558, "hintfirepistol" },
    { 0x6559, "hintfirepistolcheck" },
    { 0x655A, "hintfov" },
    { 0x655B, "hintlight" },
    { 0x655C, "hintlightcolor" },
    { 0x655D, "hintlightmodel" },
    { 0x655E, "hintmessage" },
    { 0x655F, "hintmessagedeaththink" },
    { 0x6560, "hintmoraleslaptop" },
    { 0x6561, "hintmoralessignal" },
    { 0x6562, "hintnuke" },
    { 0x6563, "hintobj" },
    { 0x6564, "hintpickup" },
    { 0x6565, "hintprint" },
    { 0x6566, "hintprintbreakout" },
    { 0x6567, "hints" },
    { 0x6568, "hints_vo_visual_send_to" },
    { 0x6569, "hintstiminteract" },
    { 0x656A, "hinttmtylinterrogate" },
    { 0x656B, "hit_surface" },
    { 0x656C, "hit_target_entity_monitor" },
    { 0x656D, "hit_water" },
    { 0x656E, "hitarmorvest" },
    { 0x656F, "hitboxoffset" },
    { 0x6570, "hitbychargedshot" },
    { 0x6571, "hitcount" },
    { 0x6572, "hitdamage" },
    { 0x6573, "hitfflimit" },
    { 0x6574, "hithelmet" },
    { 0x6575, "hitloc" },
    { 0x6576, "hitlocation" },
    { 0x6577, "hitlocdebug" },
    { 0x6578, "hitlocinited" },
    { 0x6579, "hitmankeyexists" },
    { 0x657A, "hitmankills" },
    { 0x657B, "hitmanpassivedeathwatcher" },
    { 0x657C, "hitmarker" },
    { 0x657D, "hitmarkeraudioevents" },
    { 0x657E, "hitmarkerpriorities" },
    { 0x657F, "hitpositions" },
    { 0x6580, "hitrecord" },
    { 0x6581, "hitroundlimit" },
    { 0x6582, "hits" },
    { 0x6583, "hitscorelimit" },
    { 0x6584, "hitsperattack" },
    { 0x6585, "hitsthismag" },
    { 0x6586, "hitsthismag_init" },
    { 0x6587, "hitsthismag_update" },
    { 0x6588, "hitstokill" },
    { 0x6589, "hittimelimit" },
    { 0x658A, "hittypes" },
    { 0x658B, "hitwinlimit" },
    { 0x658C, "hitwithmeleetime" },
    { 0x658D, "hoister" },
    { 0x658E, "hold_count" },
    { 0x658F, "hold_count_check" },
    { 0x6590, "hold_health_on_objectiveicon" },
    { 0x6591, "hold_indefintely" },
    { 0x6592, "hold_lookat" },
    { 0x6593, "holdbeforeshoottime" },
    { 0x6594, "holding" },
    { 0x6595, "holding_gun_game_max_level_weapon" },
    { 0x6596, "holdingbodyhud" },
    { 0x6597, "holdoutphase" },
    { 0x6598, "holdouttext" },
    { 0x6599, "holdteam" },
    { 0x659A, "holdteammatestosquadleader" },
    { 0x659B, "holdtime" },
    { 0x659C, "holster_catchup" },
    { 0x659D, "holster_cleanup_manager" },
    { 0x659E, "holster_dooropenedlogic" },
    { 0x659F, "holster_getanimationstruct" },
    { 0x65A0, "holster_getdoor" },
    { 0x65A1, "holster_getdoorclip" },
    { 0x65A2, "holster_inventory_manager" },
    { 0x65A3, "holster_logic" },
    { 0x65A4, "holster_main" },
    { 0x65A5, "holster_playerholsterlogic" },
    { 0x65A6, "holster_setupdoor" },
    { 0x65A7, "holster_spawnmarketscene" },
    { 0x65A8, "holster_start" },
    { 0x65A9, "holsterallowed" },
    { 0x65AA, "homepos" },
    { 0x65AB, "hometown_flags" },
    { 0x65AC, "hometown_objectives" },
    { 0x65AD, "hometown_print3d_on_me" },
    { 0x65AE, "hometown_stealth" },
    { 0x65AF, "honk_turret_horn" },
    { 0x65B0, "hoopties" },
    { 0x65B1, "hoopty_cp_create" },
    { 0x65B2, "hoopty_cp_createfromstructs" },
    { 0x65B3, "hoopty_cp_delete" },
    { 0x65B4, "hoopty_cp_getspawnstructscallback" },
    { 0x65B5, "hoopty_cp_init" },
    { 0x65B6, "hoopty_cp_initlate" },
    { 0x65B7, "hoopty_cp_initspawning" },
    { 0x65B8, "hoopty_cp_ondeathrespawncallback" },
    { 0x65B9, "hoopty_cp_spawncallback" },
    { 0x65BA, "hoopty_cp_waitandspawn" },
    { 0x65BB, "hoopty_create" },
    { 0x65BC, "hoopty_deathcallback" },
    { 0x65BD, "hoopty_deletenextframe" },
    { 0x65BE, "hoopty_enterend" },
    { 0x65BF, "hoopty_enterendinternal" },
    { 0x65C0, "hoopty_exitend" },
    { 0x65C1, "hoopty_exitendinternal" },
    { 0x65C2, "hoopty_explode" },
    { 0x65C3, "hoopty_getspawnstructscallback" },
    { 0x65C4, "hoopty_init" },
    { 0x65C5, "hoopty_initfx" },
    { 0x65C6, "hoopty_initinteract" },
    { 0x65C7, "hoopty_initlate" },
    { 0x65C8, "hoopty_initoccupancy" },
    { 0x65C9, "hoopty_initspawning" },
    { 0x65CA, "hoopty_mp_create" },
    { 0x65CB, "hoopty_mp_delete" },
    { 0x65CC, "hoopty_mp_getspawnstructscallback" },
    { 0x65CD, "hoopty_mp_init" },
    { 0x65CE, "hoopty_mp_initmines" },
    { 0x65CF, "hoopty_mp_initspawning" },
    { 0x65D0, "hoopty_mp_ondeathrespawncallback" },
    { 0x65D1, "hoopty_mp_spawncallback" },
    { 0x65D2, "hoopty_mp_waitandspawn" },
    { 0x65D3, "hoopty_truck_cp_create" },
    { 0x65D4, "hoopty_truck_cp_createfromstructs" },
    { 0x65D5, "hoopty_truck_cp_delete" },
    { 0x65D6, "hoopty_truck_cp_getspawnstructscallback" },
    { 0x65D7, "hoopty_truck_cp_init" },
    { 0x65D8, "hoopty_truck_cp_initlate" },
    { 0x65D9, "hoopty_truck_cp_initspawning" },
    { 0x65DA, "hoopty_truck_cp_ondeathrespawncallback" },
    { 0x65DB, "hoopty_truck_cp_spawncallback" },
    { 0x65DC, "hoopty_truck_cp_waitandspawn" },
    { 0x65DD, "hoopty_truck_create" },
    { 0x65DE, "hoopty_truck_deathcallback" },
    { 0x65DF, "hoopty_truck_deletenextframe" },
    { 0x65E0, "hoopty_truck_enterend" },
    { 0x65E1, "hoopty_truck_enterendinternal" },
    { 0x65E2, "hoopty_truck_exitend" },
    { 0x65E3, "hoopty_truck_exitendinternal" },
    { 0x65E4, "hoopty_truck_explode" },
    { 0x65E5, "hoopty_truck_getspawnstructscallback" },
    { 0x65E6, "hoopty_truck_init" },
    { 0x65E7, "hoopty_truck_initfx" },
    { 0x65E8, "hoopty_truck_initinteract" },
    { 0x65E9, "hoopty_truck_initlate" },
    { 0x65EA, "hoopty_truck_initoccupancy" },
    { 0x65EB, "hoopty_truck_initspawning" },
    { 0x65EC, "hoopty_truck_mp_create" },
    { 0x65ED, "hoopty_truck_mp_delete" },
    { 0x65EE, "hoopty_truck_mp_getspawnstructscallback" },
    { 0x65EF, "hoopty_truck_mp_init" },
    { 0x65F0, "hoopty_truck_mp_initmines" },
    { 0x65F1, "hoopty_truck_mp_initspawning" },
    { 0x65F2, "hoopty_truck_mp_ondeathrespawncallback" },
    { 0x65F3, "hoopty_truck_mp_spawncallback" },
    { 0x65F4, "hoopty_truck_mp_waitandspawn" },
    { 0x65F5, "hooptytrucks" },
    { 0x65F6, "hospital_dof_monitor" },
    { 0x65F7, "hospital_dof_on" },
    { 0x65F8, "hospital_exterior_vehicle_monitor" },
    { 0x65F9, "hospital_ground_vehicle_movement_sound" },
    { 0x65FA, "hospital_init" },
    { 0x65FB, "hospital_laststand_roof_alive_monitor" },
    { 0x65FC, "hospital_upper_init" },
    { 0x65FD, "hospital_upperfloor_mg_los" },
    { 0x65FE, "host_migration_init" },
    { 0x65FF, "host_spawn_point" },
    { 0x6600, "hostage" },
    { 0x6601, "hostage_1_death_monitor" },
    { 0x6602, "hostage_1_handler" },
    { 0x6603, "hostage_2_handler" },
    { 0x6604, "hostage_3_handler" },
    { 0x6605, "hostage_3f_death" },
    { 0x6606, "hostage_3f_reaction_vo" },
    { 0x6607, "hostage_ai" },
    { 0x6608, "hostage_aliases_exiting" },
    { 0x6609, "hostage_aliases_idles" },
    { 0x660A, "hostage_aliases_release" },
    { 0x660B, "hostage_allow_long_death" },
    { 0x660C, "hostage_building_id" },
    { 0x660D, "hostage_change_extract" },
    { 0x660E, "hostage_cry_idle" },
    { 0x660F, "hostage_cry_release" },
    { 0x6610, "hostage_damage_thread" },
    { 0x6611, "hostage_death" },
    { 0x6612, "hostage_death_counter" },
    { 0x6613, "hostage_death_with_gun" },
    { 0x6614, "hostage_detach_weapon" },
    { 0x6615, "hostage_dialogue" },
    { 0x6616, "hostage_drop" },
    { 0x6617, "hostage_drop_call_back_func" },
    { 0x6618, "hostage_drop_override_data" },
    { 0x6619, "hostage_elbow_hit_wall" },
    { 0x661A, "hostage_enable_rescue" },
    { 0x661B, "hostage_enemy" },
    { 0x661C, "hostage_enemy_dialogue" },
    { 0x661D, "hostage_enemy_engage_dialogue" },
    { 0x661E, "hostage_enemy_fx" },
    { 0x661F, "hostage_enemy_ondeath" },
    { 0x6620, "hostage_enemy_sight" },
    { 0x6621, "hostage_enemy_thread" },
    { 0x6622, "hostage_executed_fail_state" },
    { 0x6623, "hostage_extras" },
    { 0x6624, "hostage_flank_react" },
    { 0x6625, "hostage_flashbang_thread" },
    { 0x6626, "hostage_hit_wall" },
    { 0x6627, "hostage_id" },
    { 0x6628, "hostage_init" },
    { 0x6629, "hostage_keep_goal" },
    { 0x662A, "hostage_kicked_react" },
    { 0x662B, "hostage_kill" },
    { 0x662C, "hostage_killed_fail_state" },
    { 0x662D, "hostage_last_played" },
    { 0x662E, "hostage_laststandlistener" },
    { 0x662F, "hostage_loop_watcher" },
    { 0x6630, "hostage_near_vehicle_monitor" },
    { 0x6631, "hostage_ondeath_remove_linkedents" },
    { 0x6632, "hostage_onuse" },
    { 0x6633, "hostage_onusefunc" },
    { 0x6634, "hostage_pickup" },
    { 0x6635, "hostage_pickup_pos" },
    { 0x6636, "hostage_play_sound_idle" },
    { 0x6637, "hostage_price_idle" },
    { 0x6638, "hostage_rescue_fight" },
    { 0x6639, "hostage_rescue_meatshield" },
    { 0x663A, "hostage_room" },
    { 0x663B, "hostage_saw_player_recently" },
    { 0x663C, "hostage_scene" },
    { 0x663D, "hostage_scene_plr_rumble" },
    { 0x663E, "hostage_seeplayer_frantic" },
    { 0x663F, "hostage_seeplayer_frantic_share" },
    { 0x6640, "hostage_sequence" },
    { 0x6641, "hostage_sequence_lillywhites" },
    { 0x6642, "hostage_turn_to_enemy" },
    { 0x6643, "hostage_watchdrop" },
    { 0x6644, "hostageallydroppedchatterwatcher" },
    { 0x6645, "hostageallydroppedwatcher" },
    { 0x6646, "hostageallygrabbedchatterwatcher" },
    { 0x6647, "hostageallygrabbedwatcher" },
    { 0x6648, "hostageaxisgrabbedwatcher" },
    { 0x6649, "hostagecarried" },
    { 0x664A, "hostagecarrier" },
    { 0x664B, "hostagecarrystates" },
    { 0x664C, "hostagecheckpointent" },
    { 0x664D, "hostagecheckscoring" },
    { 0x664E, "hostagedompoint_onuse" },
    { 0x664F, "hostagedrop" },
    { 0x6650, "hostageexitpoints" },
    { 0x6651, "hostagegoalent" },
    { 0x6652, "hostagehidespots" },
    { 0x6653, "hostagenearbywatcher" },
    { 0x6654, "hostageonuse" },
    { 0x6655, "hostageoutlineid" },
    { 0x6656, "hostages" },
    { 0x6657, "hostages_disablelookat" },
    { 0x6658, "hostages_disablesounds" },
    { 0x6659, "hostages_spawned_triggers" },
    { 0x665A, "hostagespawnpos" },
    { 0x665B, "hostagespawnpushedwatcher" },
    { 0x665C, "hostagespawnwm" },
    { 0x665D, "hostagestates" },
    { 0x665E, "hostagestatuswatcher" },
    { 0x665F, "hostagestoprunning" },
    { 0x6660, "hostagesysteminit" },
    { 0x6661, "hostagethreatwatcher" },
    { 0x6662, "hostforcedend" },
    { 0x6663, "hostidledout" },
    { 0x6664, "hostilemarkerthink" },
    { 0x6665, "hostmigration" },
    { 0x6666, "hostmigration_waitlongdurationwithpause" },
    { 0x6667, "hostmigration_waittillnotifyortimeoutpause" },
    { 0x6668, "hostmigrationconnectwatcher" },
    { 0x6669, "hostmigrationcontrolsfrozen" },
    { 0x666A, "hostmigrationend" },
    { 0x666B, "hostmigrationname" },
    { 0x666C, "hostmigrationreturnedplayercount" },
    { 0x666D, "hostmigrationstart" },
    { 0x666E, "hostmigrationtimer" },
    { 0x666F, "hostmigrationtimerthink" },
    { 0x6670, "hostmigrationtimerthink_internal" },
    { 0x6671, "hostmigrationwait" },
    { 0x6672, "hostmigrationwaitforplayers" },
    { 0x6673, "hostname" },
    { 0x6674, "hotjoin_protection" },
    { 0x6675, "hotjoin_via_ac130" },
    { 0x6676, "hoursawakesincelastupdate" },
    { 0x6677, "house_boss_analytics" },
    { 0x6678, "house_boss_catchup" },
    { 0x6679, "house_boss_main" },
    { 0x667A, "house_boss_skip_fight_hide_intro" },
    { 0x667B, "house_boss_skip_fight_show_intro" },
    { 0x667C, "house_boss_start" },
    { 0x667D, "house_boss_start_vo" },
    { 0x667E, "house_dad_dies_late_save" },
    { 0x667F, "house_enter_catchup" },
    { 0x6680, "house_enter_goliath_kill" },
    { 0x6681, "house_enter_main" },
    { 0x6682, "house_enter_start" },
    { 0x6683, "house_enter_start_vo" },
    { 0x6684, "house_enter_trigger_monitor" },
    { 0x6685, "house_exit_catchup" },
    { 0x6686, "house_exit_main" },
    { 0x6687, "house_exit_skip_boss_fight_catchup" },
    { 0x6688, "house_exit_start" },
    { 0x6689, "house_exit_start_vo" },
    { 0x668A, "house_exterior_dof" },
    { 0x668B, "house_fstop" },
    { 0x668C, "house_intro_deadbolt_model" },
    { 0x668D, "house_intro_phone_farah_model" },
    { 0x668E, "hover_and_shoot_rockets" },
    { 0x668F, "hover_origin" },
    { 0x6690, "hover_states" },
    { 0x6691, "hoverheight" },
    { 0x6692, "hovering" },
    { 0x6693, "hoverjet_airtargetistooclose" },
    { 0x6694, "hoverjet_airtargetiswithinview" },
    { 0x6695, "hoverjet_breakofftarget" },
    { 0x6696, "hoverjet_cleanup" },
    { 0x6697, "hoverjet_crash" },
    { 0x6698, "hoverjet_defendlocation" },
    { 0x6699, "hoverjet_delaymissiletracking" },
    { 0x669A, "hoverjet_delayresetscriptable" },
    { 0x669B, "hoverjet_delaysetscriptable" },
    { 0x669C, "hoverjet_engageairtargets" },
    { 0x669D, "hoverjet_engagegroundtargets" },
    { 0x669E, "hoverjet_explode" },
    { 0x669F, "hoverjet_findcrashposition" },
    { 0x66A0, "hoverjet_findmissiletarget" },
    { 0x66A1, "hoverjet_firemissilescriptable" },
    { 0x66A2, "hoverjet_fireonairtarget" },
    { 0x66A3, "hoverjet_fireongroundtarget" },
    { 0x66A4, "hoverjet_firetrackermissiles" },
    { 0x66A5, "hoverjet_getbestairtarget" },
    { 0x66A6, "hoverjet_getbestgroundtarget" },
    { 0x66A7, "hoverjet_getcorrectheight" },
    { 0x66A8, "hoverjet_getmapselectioninfo" },
    { 0x66A9, "hoverjet_handledeathdamage" },
    { 0x66AA, "hoverjet_handledestroyed" },
    { 0x66AB, "hoverjet_handlemissiledetection" },
    { 0x66AC, "hoverjet_istarget" },
    { 0x66AD, "hoverjet_leave" },
    { 0x66AE, "hoverjet_leaveonownernotify" },
    { 0x66AF, "hoverjet_missilekillcammove" },
    { 0x66B0, "hoverjet_modifydamage" },
    { 0x66B1, "hoverjet_moveawayfromtarget" },
    { 0x66B2, "hoverjet_movetolocation" },
    { 0x66B3, "hoverjet_playapproachfx" },
    { 0x66B4, "hoverjet_playflybyfx" },
    { 0x66B5, "hoverjet_playflyfx" },
    { 0x66B6, "hoverjet_playreturnfx" },
    { 0x66B7, "hoverjet_randomizemovement" },
    { 0x66B8, "hoverjet_setattackpoint" },
    { 0x66B9, "hoverjet_setmissileoffset" },
    { 0x66BA, "hoverjet_spinout" },
    { 0x66BB, "hoverjet_startcombatlogic" },
    { 0x66BC, "hoverjet_tracegroundpoint" },
    { 0x66BD, "hoverjet_turretlookingattarget" },
    { 0x66BE, "hoverjet_watchairtargetdeath" },
    { 0x66BF, "hoverjet_watchforbreakaction" },
    { 0x66C0, "hoverjet_watchfornearmovementgoal" },
    { 0x66C1, "hoverjet_watchforreposition" },
    { 0x66C2, "hoverjet_watchgroundtargetdeathdisconnect" },
    { 0x66C3, "hoverjet_watchlifetime" },
    { 0x66C4, "hoverjet_watchowner" },
    { 0x66C5, "hoverjet_watchtargetlos" },
    { 0x66C6, "hoverjet_watchtargetstatus" },
    { 0x66C7, "hoverjet_watchtargettimeout" },
    { 0x66C8, "hoverjets" },
    { 0x66C9, "hoverlifepack" },
    { 0x66CA, "hp" },
    { 0x66CB, "hp_move_soon" },
    { 0x66CC, "hpcapteam" },
    { 0x66CD, "hpcaptureloop" },
    { 0x66CE, "hpstarttime" },
    { 0x66CF, "hq_captured_music" },
    { 0x66D0, "hq_targets" },
    { 0x66D1, "hqactivatenextzone" },
    { 0x66D2, "hqautodestroytime" },
    { 0x66D3, "hqdestroyedbytimer" },
    { 0x66D4, "hqdestroytime" },
    { 0x66D5, "hqdisttomid" },
    { 0x66D6, "hqmainloop" },
    { 0x66D7, "hqmidpoint" },
    { 0x66D8, "hqrevealtime" },
    { 0x66D9, "hqvecttomid_allies" },
    { 0x66DA, "hqvecttomid_axis" },
    { 0x66DB, "ht_on" },
    { 0x66DC, "hud" },
    { 0x66DD, "hud_attempt_over" },
    { 0x66DE, "hud_besttime_update" },
    { 0x66DF, "hud_bink" },
    { 0x66E0, "hud_controler" },
    { 0x66E1, "hud_damagefeedback" },
    { 0x66E2, "hud_destroy" },
    { 0x66E3, "hud_fade_to_black" },
    { 0x66E4, "hud_fadeovertime" },
    { 0x66E5, "hud_finale_black" },
    { 0x66E6, "hud_fluff_text_message" },
    { 0x66E7, "hud_hitmarker" },
    { 0x66E8, "hud_init" },
    { 0x66E9, "hud_intel_message" },
    { 0x66EA, "hud_inter_round_flow" },
    { 0x66EB, "hud_mantle" },
    { 0x66EC, "hud_moveovertime" },
    { 0x66ED, "hud_objectives" },
    { 0x66EE, "hud_omnvar_change_listener" },
    { 0x66EF, "hud_reward_tiers_tracking" },
    { 0x66F0, "hud_scoring" },
    { 0x66F1, "hud_selector" },
    { 0x66F2, "hud_selector_fade_out" },
    { 0x66F3, "hud_set_reward_tier" },
    { 0x66F4, "hud_stars" },
    { 0x66F5, "hud_think" },
    { 0x66F6, "hud_timer" },
    { 0x66F7, "hud_update_placed_model_count" },
    { 0x66F8, "hud_value" },
    { 0x66F9, "hud_visibility_timer" },
    { 0x66FA, "hudammount" },
    { 0x66FB, "hudavailable" },
    { 0x66FC, "hudbetonplayer" },
    { 0x66FD, "hudbooted" },
    { 0x66FE, "hudelem_count" },
    { 0x66FF, "hudelemdestroy" },
    { 0x6700, "hudelems" },
    { 0x6701, "hudfocusname" },
    { 0x6702, "hudicon" },
    { 0x6703, "hudicontype" },
    { 0x6704, "hudoutline_activate_best_channel" },
    { 0x6705, "hudoutline_activate_channel" },
    { 0x6706, "hudoutline_add_channel" },
    { 0x6707, "hudoutline_add_channel_internal" },
    { 0x6708, "hudoutline_add_child_channel" },
    { 0x6709, "hudoutline_add_child_channel_internal" },
    { 0x670A, "hudoutline_ar_callout" },
    { 0x670B, "hudoutline_ar_disable" },
    { 0x670C, "hudoutline_cctv_settings" },
    { 0x670D, "hudoutline_channel_animation" },
    { 0x670E, "hudoutline_channel_animation_loop" },
    { 0x670F, "hudoutline_channels_init" },
    { 0x6710, "hudoutline_create_entinfo" },
    { 0x6711, "hudoutline_deactivate_channel" },
    { 0x6712, "hudoutline_default_settings" },
    { 0x6713, "hudoutline_disable" },
    { 0x6714, "hudoutline_disable_internal" },
    { 0x6715, "hudoutline_disable_on_death" },
    { 0x6716, "hudoutline_enable" },
    { 0x6717, "hudoutline_enable_internal" },
    { 0x6718, "hudoutline_enable_new" },
    { 0x6719, "hudoutline_force_channel" },
    { 0x671A, "hudoutline_force_channel_internal" },
    { 0x671B, "hudoutline_is_ent_in_channel" },
    { 0x671C, "hudoutline_override_channel_settingsfunc" },
    { 0x671D, "hudoutline_set_channel_settings_delayed" },
    { 0x671E, "hudoutline_update_entinfo" },
    { 0x671F, "hudoutline_vis_enemy" },
    { 0x6720, "hudoutline_vis_enemy_settings" },
    { 0x6721, "hudoutlineasset" },
    { 0x6722, "hudoutlineassetname" },
    { 0x6723, "hudoutlinechannels" },
    { 0x6724, "hudoutlinecurchannel" },
    { 0x6725, "hudoutlineforcedchannels" },
    { 0x6726, "hudoutlinesettings" },
    { 0x6727, "hudoutlineviewmodelenableonnextspawn" },
    { 0x6728, "huds" },
    { 0x6729, "hudsetpoint_func" },
    { 0x672A, "hudstate" },
    { 0x672B, "hudtweaks" },
    { 0x672C, "hull_invulnerable" },
    { 0x672D, "human_team_bot_added" },
    { 0x672E, "humans" },
    { 0x672F, "humvee_add_additional_parts_func" },
    { 0x6730, "humvee_marker_group_id" },
    { 0x6731, "hungry" },
    { 0x6732, "hungryrate" },
    { 0x6733, "hungrystart" },
    { 0x6734, "hunkerstarttime" },
    { 0x6735, "hunt" },
    { 0x6736, "hunt_active_terminate" },
    { 0x6737, "hunt_clearroomdata" },
    { 0x6738, "hunt_cqbtargetupdate" },
    { 0x6739, "hunt_finddoorbetween" },
    { 0x673A, "hunt_getnextclearpos" },
    { 0x673B, "hunt_getpos" },
    { 0x673C, "hunt_human" },
    { 0x673D, "hunt_hunker" },
    { 0x673E, "hunt_hunker_expose" },
    { 0x673F, "hunt_hunker_expose_init" },
    { 0x6740, "hunt_hunker_expose_terminate" },
    { 0x6741, "hunt_hunker_init" },
    { 0x6742, "hunt_hunker_shouldexpose" },
    { 0x6743, "hunt_hunker_terminate" },
    { 0x6744, "hunt_init" },
    { 0x6745, "hunt_initialdelay" },
    { 0x6746, "hunt_initialdelay_init" },
    { 0x6747, "hunt_initialdelay_terminate" },
    { 0x6748, "hunt_isincover" },
    { 0x6749, "hunt_lookaround" },
    { 0x674A, "hunt_lookaround_init" },
    { 0x674B, "hunt_lookaround_terminate" },
    { 0x674C, "hunt_loop" },
    { 0x674D, "hunt_move" },
    { 0x674E, "hunt_move_init" },
    { 0x674F, "hunt_move_terminate" },
    { 0x6750, "hunt_player" },
    { 0x6751, "hunt_player_delayed" },
    { 0x6752, "hunt_region_load" },
    { 0x6753, "hunt_regions" },
    { 0x6754, "hunt_shouldhunker" },
    { 0x6755, "hunt_shouldinvestigateorigin" },
    { 0x6756, "hunt_sidechecks" },
    { 0x6757, "hunt_speed" },
    { 0x6758, "hunt_stealth_group_region_sets" },
    { 0x6759, "hunt_terminate" },
    { 0x675A, "hunt_thread" },
    { 0x675B, "hunt_updateeveryframe" },
    { 0x675C, "hunt_updateregiontoclear" },
    { 0x675D, "hunt_volumes" },
    { 0x675E, "huntassigntoregion" },
    { 0x675F, "huntcomputeaiindependentregionscores" },
    { 0x6760, "huntdecaiassignment" },
    { 0x6761, "hunted_count" },
    { 0x6762, "hunterkillerents" },
    { 0x6763, "hunterkillerids" },
    { 0x6764, "hunterkillerlistenforconnect" },
    { 0x6765, "hunterkillerlistenfordamage" },
    { 0x6766, "hunterkillerlistenfordisconnect" },
    { 0x6767, "hunterkillerlistenforhealth" },
    { 0x6768, "hunterkilleroutlines" },
    { 0x6769, "hunterteam" },
    { 0x676A, "huntgetnextregion" },
    { 0x676B, "hunthunkerlastexposetime" },
    { 0x676C, "huntincaiassignment" },
    { 0x676D, "hunting_groups" },
    { 0x676E, "hunting_player" },
    { 0x676F, "hunttimeout" },
    { 0x6770, "hunttrytoenterregionvolume" },
    { 0x6771, "hunttrytoexitregionvolume" },
    { 0x6772, "huntunassignfromregion" },
    { 0x6773, "hurtbadlywait" },
    { 0x6774, "hurtplayer" },
    { 0x6775, "hurttarget" },
    { 0x6776, "hurttriggers" },
    { 0x6777, "hvi" },
    { 0x6778, "hvi_follow_player_loop" },
    { 0x6779, "hvt_anim_think" },
    { 0x677A, "hvt_ar" },
    { 0x677B, "hvt_bodyguard_vehicle_should_speed_up" },
    { 0x677C, "hvt_bodyguard_vehicles" },
    { 0x677D, "hvt_boss_clean_up_think" },
    { 0x677E, "hvt_boss_combat_think" },
    { 0x677F, "hvt_boss_damage_monitor" },
    { 0x6780, "hvt_boss_do_combat" },
    { 0x6781, "hvt_boss_laser_tag" },
    { 0x6782, "hvt_boss_move_to_target_vertical_offset" },
    { 0x6783, "hvt_boss_mover" },
    { 0x6784, "hvt_boss_mover_face_player_humvee" },
    { 0x6785, "hvt_boss_mover_follow_enemy_hvt_vehicle" },
    { 0x6786, "hvt_breakout_think" },
    { 0x6787, "hvt_combat_start_marker_think" },
    { 0x6788, "hvt_death" },
    { 0x6789, "hvt_death_anim" },
    { 0x678A, "hvt_death_post_interact" },
    { 0x678B, "hvt_death_pre_interact" },
    { 0x678C, "hvt_delete_clip_on_death" },
    { 0x678D, "hvt_die" },
    { 0x678E, "hvt_disable_interact_on_interrogation" },
    { 0x678F, "hvt_elevator_jugg" },
    { 0x6790, "hvt_enable_interact" },
    { 0x6791, "hvt_ent_delete_wm" },
    { 0x6792, "hvt_exit" },
    { 0x6793, "hvt_idle" },
    { 0x6794, "hvt_if_heli_destroyed" },
    { 0x6795, "hvt_in_heli" },
    { 0x6796, "hvt_interact_think" },
    { 0x6797, "hvt_jugg" },
    { 0x6798, "hvt_jugg_skit_spawn_func" },
    { 0x6799, "hvt_jugg_spawn_func" },
    { 0x679A, "hvt_locations" },
    { 0x679B, "hvt_made_it_to_heli" },
    { 0x679C, "hvt_module_struct" },
    { 0x679D, "hvt_obj_num" },
    { 0x679E, "hvt_run_to_heli" },
    { 0x679F, "hvt_skit_notetrack_handler" },
    { 0x67A0, "hvt_snore_think" },
    { 0x67A1, "hvt_structs" },
    { 0x67A2, "hvt_temp_movesideways" },
    { 0x67A3, "hvt_think_func" },
    { 0x67A4, "hvt_trace_contents" },
    { 0x67A5, "hvt_vehicle_weak_spot_damage_monitor" },
    { 0x67A6, "hvt_wait_for_pickup" },
    { 0x67A7, "hvt_waypoint_think" },
    { 0x67A8, "hvt_yelling_anim_think" },
    { 0x67A9, "hvtcapturevalue" },
    { 0x67AA, "hvtcleanup" },
    { 0x67AB, "hvtclearmove" },
    { 0x67AC, "hvtcount" },
    { 0x67AD, "hvtdeathwatcher" },
    { 0x67AE, "hvtdelayedendinvulnerability" },
    { 0x67AF, "hvtent_sethotfunc" },
    { 0x67B0, "hvtkilled" },
    { 0x67B1, "hvtkills" },
    { 0x67B2, "hvtlabel" },
    { 0x67B3, "hvtlocent" },
    { 0x67B4, "hvtmaxtargets" },
    { 0x67B5, "hvtmovetoextractpt" },
    { 0x67B6, "hvtnorevive" },
    { 0x67B7, "hvtreveal" },
    { 0x67B8, "hvts" },
    { 0x67B9, "hvts_identified" },
    { 0x67BA, "hvts_seen" },
    { 0x67BB, "hvtspawnpos" },
    { 0x67BC, "hvtthreatwatcher" },
    { 0x67BD, "hvttriggerholdonuse" },
    { 0x67BE, "hvttriggerholdonusebegin" },
    { 0x67BF, "hvttriggerholdonuseend" },
    { 0x67C0, "hvttriggeroncantuse" },
    { 0x67C1, "hvydamage" },
    { 0x67C2, "hybrid_assist" },
    { 0x67C3, "i_current_state" },
    { 0x67C4, "i_player_shooting_murderhole_monitor_counter" },
    { 0x67C5, "i_previous_state" },
    { 0x67C6, "i_saw_player" },
    { 0x67C7, "i_see_friendly_corpse_watcher" },
    { 0x67C8, "i_see_player_watcher" },
    { 0x67C9, "iamflashed" },
    { 0x67CA, "icon" },
    { 0x67CB, "icon_clean_up_think" },
    { 0x67CC, "icon_death_watcher" },
    { 0x67CD, "icon_spot" },
    { 0x67CE, "icon_update_visibility" },
    { 0x67CF, "iconbombcapture" },
    { 0x67D0, "iconbombdefend" },
    { 0x67D1, "iconcapture" },
    { 0x67D2, "iconcaptureendzone" },
    { 0x67D3, "iconcaptureextract" },
    { 0x67D4, "iconcaptureflag" },
    { 0x67D5, "iconcaptureflag2d" },
    { 0x67D6, "iconcaptureflag3d" },
    { 0x67D7, "iconcontested" },
    { 0x67D8, "iconcontestendzone" },
    { 0x67D9, "iconcontestingextract" },
    { 0x67DA, "icondefend" },
    { 0x67DB, "icondefendendzone" },
    { 0x67DC, "icondefendextract" },
    { 0x67DD, "icondefendflag" },
    { 0x67DE, "icondefendhvt" },
    { 0x67DF, "icondefending" },
    { 0x67E0, "icondefusing" },
    { 0x67E1, "iconenemycontested" },
    { 0x67E2, "iconenemyextract2d" },
    { 0x67E3, "iconenemyextract3d" },
    { 0x67E4, "iconescort" },
    { 0x67E5, "iconescort2d" },
    { 0x67E6, "iconescort3d" },
    { 0x67E7, "iconextract" },
    { 0x67E8, "iconflashpointcontested" },
    { 0x67E9, "iconflashpointenemy" },
    { 0x67EA, "iconflashpointfriendly" },
    { 0x67EB, "iconflashpointneutral" },
    { 0x67EC, "iconfriendlycontested" },
    { 0x67ED, "iconfriendlyextract2d" },
    { 0x67EE, "iconfriendlyextract3d" },
    { 0x67EF, "iconfriendlyzone2d" },
    { 0x67F0, "iconfriendlyzone3d" },
    { 0x67F1, "icongoalflag" },
    { 0x67F2, "iconhqcapture" },
    { 0x67F3, "iconhqcontested" },
    { 0x67F4, "iconhqdefend" },
    { 0x67F5, "iconhqlosing" },
    { 0x67F6, "iconhqneutral" },
    { 0x67F7, "iconhqtaking" },
    { 0x67F8, "iconhqtarget" },
    { 0x67F9, "iconkill" },
    { 0x67FA, "iconkill2d" },
    { 0x67FB, "iconkill3d" },
    { 0x67FC, "iconlabel" },
    { 0x67FD, "iconlocked" },
    { 0x67FE, "iconlosing" },
    { 0x67FF, "iconlosingendzone" },
    { 0x6800, "iconlosingextract" },
    { 0x6801, "iconlosingflag" },
    { 0x6802, "iconname" },
    { 0x6803, "iconneutral" },
    { 0x6804, "iconpickupdefendflag" },
    { 0x6805, "iconpickupflag" },
    { 0x6806, "iconplant" },
    { 0x6807, "iconplanting" },
    { 0x6808, "iconpos" },
    { 0x6809, "iconposref" },
    { 0x680A, "iconpreventextract" },
    { 0x680B, "iconrallypoint" },
    { 0x680C, "iconrallypointheli" },
    { 0x680D, "iconrecover" },
    { 0x680E, "iconresettingflag" },
    { 0x680F, "iconreturnflag" },
    { 0x6810, "iconsize" },
    { 0x6811, "iconstoppingextract" },
    { 0x6812, "icontake" },
    { 0x6813, "icontaking" },
    { 0x6814, "icontakingendzone" },
    { 0x6815, "icontakingextract" },
    { 0x6816, "icontarget" },
    { 0x6817, "iconvisall" },
    { 0x6818, "id" },
    { 0x6819, "idamage" },
    { 0x681A, "ideal" },
    { 0x681B, "ideal_dist" },
    { 0x681C, "identified" },
    { 0x681D, "identified_ieds" },
    { 0x681E, "identifier" },
    { 0x681F, "identify_anim_playing" },
    { 0x6820, "identify_anim_think" },
    { 0x6821, "identify_anim_unlink_player_on_damage" },
    { 0x6822, "idflag" },
    { 0x6823, "idflags" },
    { 0x6824, "idflags_no_armor" },
    { 0x6825, "idflags_no_knockback" },
    { 0x6826, "idflags_no_protection" },
    { 0x6827, "idflags_no_team_protection" },
    { 0x6828, "idflags_passthru" },
    { 0x6829, "idflags_penetration" },
    { 0x682A, "idflags_radius" },
    { 0x682B, "idflags_ricochet" },
    { 0x682C, "idflags_shield_explosive_impact" },
    { 0x682D, "idflags_shield_explosive_impact_huge" },
    { 0x682E, "idflags_shield_explosive_splash" },
    { 0x682F, "idflags_stun" },
    { 0x6830, "idle" },
    { 0x6831, "idle_anim" },
    { 0x6832, "idle_anim_override" },
    { 0x6833, "idle_animations" },
    { 0x6834, "idle_animnode1" },
    { 0x6835, "idle_animnode2" },
    { 0x6836, "idle_animstop" },
    { 0x6837, "idle_at_stairs" },
    { 0x6838, "idle_check" },
    { 0x6839, "idle_combat" },
    { 0x683A, "idle_crouching_phone" },
    { 0x683B, "idle_enter" },
    { 0x683C, "idle_exfilally_loop" },
    { 0x683D, "idle_finished" },
    { 0x683E, "idle_funcs" },
    { 0x683F, "idle_fx" },
    { 0x6840, "idle_guys" },
    { 0x6841, "idle_hunt" },
    { 0x6842, "idle_init" },
    { 0x6843, "idle_monitor" },
    { 0x6844, "idle_on_reach" },
    { 0x6845, "idle_pilot_loop" },
    { 0x6846, "idle_prop" },
    { 0x6847, "idle_target_trigs" },
    { 0x6848, "idle_terminate" },
    { 0x6849, "idle_think" },
    { 0x684A, "idle_twitch" },
    { 0x684B, "idle_update" },
    { 0x684C, "idle_updatecurious" },
    { 0x684D, "idle_updateflashlighttarget" },
    { 0x684E, "idle_updatestyle" },
    { 0x684F, "idleanim" },
    { 0x6850, "idleanime" },
    { 0x6851, "idleanime_b" },
    { 0x6852, "idlecurioustarget" },
    { 0x6853, "idlenode" },
    { 0x6854, "idleoccurrence" },
    { 0x6855, "idlereactanime" },
    { 0x6856, "idleresettime" },
    { 0x6857, "idleset" },
    { 0x6858, "idlespottertime" },
    { 0x6859, "idlestarttime" },
    { 0x685A, "idlestate" },
    { 0x685B, "idletimeout" },
    { 0x685C, "ied_controller" },
    { 0x685D, "ied_controller_activation_monitor" },
    { 0x685E, "ied_damage_monitor" },
    { 0x685F, "ied_enabled" },
    { 0x6860, "ied_explodes" },
    { 0x6861, "ied_explosion_action_func" },
    { 0x6862, "ied_marked_vo_monitor" },
    { 0x6863, "ied_marker_vfxs_non_overwatch" },
    { 0x6864, "ied_pinned_marine_handler" },
    { 0x6865, "ied_should_explode" },
    { 0x6866, "ied_to_alley_nag_handler" },
    { 0x6867, "ied_trigger_monitor" },
    { 0x6868, "ied_triggered_by_friendly_convoy_func" },
    { 0x6869, "ied_triggered_by_players" },
    { 0x686A, "ied_triggered_by_vehicles" },
    { 0x686B, "ied_triggering_tag" },
    { 0x686C, "ied_triggering_tag_to_repair_tag_mapping" },
    { 0x686D, "ied_triggering_tags" },
    { 0x686E, "ied_unique_names" },
    { 0x686F, "ied_vehicle" },
    { 0x6870, "ied_vehicle_sound" },
    { 0x6871, "ied_vehicle_spawner" },
    { 0x6872, "ied_vignette_handler" },
    { 0x6873, "iedcanplaydetonategesture" },
    { 0x6874, "iedcreatecursor" },
    { 0x6875, "iedcursorlogic" },
    { 0x6876, "ieddetonate" },
    { 0x6877, "ieddetonategesture" },
    { 0x6878, "ieddetonationlogic" },
    { 0x6879, "iedfiremain" },
    { 0x687A, "iedplaydetonateeffects" },
    { 0x687B, "iedrace_init" },
    { 0x687C, "iedrace_interaction" },
    { 0x687D, "ifcanseeplayer" },
    { 0x687E, "ifinstealth" },
    { 0x687F, "ifisalive" },
    { 0x6880, "ifselfdestruct" },
    { 0x6881, "ifshoulddosmartobject" },
    { 0x6882, "iftest" },
    { 0x6883, "ignorclutter" },
    { 0x6884, "ignore_all" },
    { 0x6885, "ignore_background_tracers" },
    { 0x6886, "ignore_bullets" },
    { 0x6887, "ignore_cooldown" },
    { 0x6888, "ignore_corpse" },
    { 0x6889, "ignore_disabled" },
    { 0x688A, "ignore_enabled" },
    { 0x688B, "ignore_grenades" },
    { 0x688C, "ignore_player_for_breach" },
    { 0x688D, "ignore_players_not_on_roof" },
    { 0x688E, "ignore_stealth_sight" },
    { 0x688F, "ignore_triggers" },
    { 0x6890, "ignore_until_fob" },
    { 0x6891, "ignore_visibility" },
    { 0x6892, "ignoreaftertime" },
    { 0x6893, "ignoreaimsets" },
    { 0x6894, "ignoreallenemies" },
    { 0x6895, "ignoreallies" },
    { 0x6896, "ignoreanimdeltacheck" },
    { 0x6897, "ignoreburstdelay" },
    { 0x6898, "ignoreclutter" },
    { 0x6899, "ignorecollision" },
    { 0x689A, "ignorecovervalidity" },
    { 0x689B, "ignored_by_attack_heli" },
    { 0x689C, "ignoredamageid" },
    { 0x689D, "ignoredamagesignatures" },
    { 0x689E, "ignoredbycheck" },
    { 0x689F, "ignoreeachother" },
    { 0x68A0, "ignoreentities" },
    { 0x68A1, "ignoreents" },
    { 0x68A2, "ignoreexitwarp" },
    { 0x68A3, "ignorefalldamagetime" },
    { 0x68A4, "ignoregrenadesafetime" },
    { 0x68A5, "ignoreimmune" },
    { 0x68A6, "ignorekdrstats" },
    { 0x68A7, "ignorelist" },
    { 0x68A8, "ignoremarkedents" },
    { 0x68A9, "ignoreme_til_player_sees" },
    { 0x68AA, "ignoremegroups" },
    { 0x68AB, "ignoreplayers" },
    { 0x68AC, "ignorerandombulletdamage_drone_proc" },
    { 0x68AD, "ignoreriotshieldxp" },
    { 0x68AE, "ignorescoring" },
    { 0x68AF, "ignorestomp" },
    { 0x68B0, "ignoretriggerenter" },
    { 0x68B1, "ignoretriggerexit" },
    { 0x68B2, "ignorevehicletypeinstancelimit" },
    { 0x68B3, "ignorevolumes" },
    { 0x68B4, "ignorewash" },
    { 0x68B5, "illumination_flare" },
    { 0x68B6, "illumination_mortar_friendly" },
    { 0x68B7, "illumination_mortars" },
    { 0x68B8, "illumination_mortars_friendly_init" },
    { 0x68B9, "illumination_mortars_init" },
    { 0x68BA, "image" },
    { 0x68BB, "immediate" },
    { 0x68BC, "immediatelevelstartsave" },
    { 0x68BD, "immune_against_repulsor" },
    { 0x68BE, "immune_to_melee_damage" },
    { 0x68BF, "immunetokidnapper" },
    { 0x68C0, "immunityframe" },
    { 0x68C1, "impactincidence" },
    { 0x68C2, "impactinfo" },
    { 0x68C3, "impactsfx" },
    { 0x68C4, "impacttime" },
    { 0x68C5, "impactvfxentitylogic" },
    { 0x68C6, "impactvfxentityparentlogic" },
    { 0x68C7, "impale" },
    { 0x68C8, "impale_cleanup" },
    { 0x68C9, "impale_detachaftertime" },
    { 0x68CA, "impale_effects" },
    { 0x68CB, "impale_endpoint" },
    { 0x68CC, "ims" },
    { 0x68CD, "ims_hint_displayed" },
    { 0x68CE, "in_afterlife_arcade" },
    { 0x68CF, "in_array" },
    { 0x68D0, "in_combat" },
    { 0x68D1, "in_deathsdoor" },
    { 0x68D2, "in_dynolight_trigger" },
    { 0x68D3, "in_goal" },
    { 0x68D4, "in_inclusion_list" },
    { 0x68D5, "in_melee_death" },
    { 0x68D6, "in_player_fov" },
    { 0x68D7, "in_position" },
    { 0x68D8, "in_rain" },
    { 0x68D9, "in_reaper_target_circle" },
    { 0x68DA, "in_region" },
    { 0x68DB, "in_respawn_delay" },
    { 0x68DC, "in_room_check_func" },
    { 0x68DD, "in_screen_center" },
    { 0x68DE, "in_shadow" },
    { 0x68DF, "in_shadow_origin" },
    { 0x68E0, "in_shadow_thread" },
    { 0x68E1, "in_spawnspectator" },
    { 0x68E2, "in_specialist_mode" },
    { 0x68E3, "in_use" },
    { 0x68E4, "in_vr" },
    { 0x68E5, "in_yolo_mode" },
    { 0x68E6, "in_zero_gravity" },
    { 0x68E7, "inactive" },
    { 0x68E8, "inactiveextractions" },
    { 0x68E9, "inactivefunc" },
    { 0x68EA, "inactiveoffhand" },
    { 0x68EB, "inactivevehicles" },
    { 0x68EC, "inairsincelastkill" },
    { 0x68ED, "inanim" },
    { 0x68EE, "inantigrav" },
    { 0x68EF, "inbounds" },
    { 0x68F0, "inboundsfx" },
    { 0x68F1, "inboundvo" },
    { 0x68F2, "inc_bleedout_counts" },
    { 0x68F3, "inc_downed_counts" },
    { 0x68F4, "inc_laststand_record" },
    { 0x68F5, "inc_revived_counts" },
    { 0x68F6, "inc_session_stat" },
    { 0x68F7, "inc_stat" },
    { 0x68F8, "incendiary_attacker_logic" },
    { 0x68F9, "inchopper" },
    { 0x68FA, "incline" },
    { 0x68FB, "include_default_achievements" },
    { 0x68FC, "incombatspeed" },
    { 0x68FD, "incomingallchoppergunners" },
    { 0x68FE, "incomingallchoppersupports" },
    { 0x68FF, "incomingallhoverjets" },
    { 0x6900, "incomingallremotetanks" },
    { 0x6901, "incomingapache" },
    { 0x6902, "incomingchoppergunners" },
    { 0x6903, "incomingchoppersupports" },
    { 0x6904, "incominghelperdrones" },
    { 0x6905, "incominghoverjets" },
    { 0x6906, "incomingmissiles" },
    { 0x6907, "incomingremotetanks" },
    { 0x6908, "incomming_missiles" },
    { 0x6909, "incooldown" },
    { 0x690A, "incorrect_alias" },
    { 0x690B, "incpersstat" },
    { 0x690C, "incplayerrecord" },
    { 0x690D, "incranimaimweight" },
    { 0x690E, "incrankxp" },
    { 0x690F, "increase_attacker_accuracy" },
    { 0x6910, "increase_damage_scalar" },
    { 0x6911, "increase_delayed_spawn_slots" },
    { 0x6912, "increase_escalation_counter" },
    { 0x6913, "increase_lookat_weight" },
    { 0x6914, "increase_max_dist_and_watch_for_point_crossed" },
    { 0x6915, "increase_minimum_escalation_level" },
    { 0x6916, "increase_player_gun_game_level" },
    { 0x6917, "increase_reserved_spawn_slots" },
    { 0x6918, "increase_script_maxdist" },
    { 0x6919, "increase_stealth_meter" },
    { 0x691A, "increase_stealth_meter_when_approaching_corpse" },
    { 0x691B, "increase_super_progress" },
    { 0x691C, "increase_threatbias" },
    { 0x691D, "increase_threatlevel" },
    { 0x691E, "increase_wave_num" },
    { 0x691F, "increase_x" },
    { 0x6920, "increase_x_coordinate" },
    { 0x6921, "increase_x_coordinate_new" },
    { 0x6922, "increase_y" },
    { 0x6923, "increase_y_coordinate" },
    { 0x6924, "increase_y_coordinate_new" },
    { 0x6925, "increase_z" },
    { 0x6926, "increasecritchance" },
    { 0x6927, "increasecurrentstealthvalue" },
    { 0x6928, "increased_melee_damage" },
    { 0x6929, "increased_threatlevel_effects" },
    { 0x692A, "increment_airdrop_requests" },
    { 0x692B, "increment_alias_group_index" },
    { 0x692C, "increment_and_decay_nervousness" },
    { 0x692D, "increment_escalation_level" },
    { 0x692E, "increment_list_offset" },
    { 0x692F, "increment_num_of_quest_piece_completed" },
    { 0x6930, "increment_player_career_doors_opened" },
    { 0x6931, "increment_player_career_downs" },
    { 0x6932, "increment_player_career_explosive_kills" },
    { 0x6933, "increment_player_career_headshot_kills" },
    { 0x6934, "increment_player_career_kills" },
    { 0x6935, "increment_player_career_perks_used" },
    { 0x6936, "increment_player_career_revives" },
    { 0x6937, "increment_player_career_shots_fired" },
    { 0x6938, "increment_player_career_shots_on_target" },
    { 0x6939, "increment_player_career_total_score" },
    { 0x693A, "increment_player_career_total_waves" },
    { 0x693B, "increment_round_number" },
    { 0x693C, "increment_zombiecareerstats" },
    { 0x693D, "incrementalivecount" },
    { 0x693E, "incrementattachmentstat" },
    { 0x693F, "incrementcleanupsstat" },
    { 0x6940, "incrementequipmentammo" },
    { 0x6941, "incrementequipmentslotammo" },
    { 0x6942, "incrementfauxvehiclecount" },
    { 0x6943, "incrementfauxvehiclecountifpossible" },
    { 0x6944, "incrementkillcount" },
    { 0x6945, "incrementleaderboardstat" },
    { 0x6946, "incrementplayersdownedstat" },
    { 0x6947, "incrementrankedreservedhistory" },
    { 0x6948, "incrementweaponstat" },
    { 0x6949, "incvariablestate" },
    { 0x694A, "indarkarea" },
    { 0x694B, "indarkvolume" },
    { 0x694C, "independent_hack_defenses" },
    { 0x694D, "index_is_selected" },
    { 0x694E, "indexflag" },
    { 0x694F, "indicate_start" },
    { 0x6950, "individual_canister_think" },
    { 0x6951, "individual_target_think" },
    { 0x6952, "indonotspawnlootvolume" },
    { 0x6953, "indoor_event_dists" },
    { 0x6954, "indoor_monitor" },
    { 0x6955, "indoor_sfx_think" },
    { 0x6956, "indoor_think" },
    { 0x6957, "indrain" },
    { 0x6958, "inenemybase" },
    { 0x6959, "ineractivecombatmessaging" },
    { 0x695A, "infect_allowsuicide" },
    { 0x695B, "infect_allyrigs" },
    { 0x695C, "infect_awardedfinalsurvivor" },
    { 0x695D, "infect_choosingfirstinfected" },
    { 0x695E, "infect_chosefirstinfected" },
    { 0x695F, "infect_countdowninprogress" },
    { 0x6960, "infect_isbeingchosen" },
    { 0x6961, "infect_loadouts" },
    { 0x6962, "infect_players" },
    { 0x6963, "infect_skipsounds" },
    { 0x6964, "infect_spawnpos" },
    { 0x6965, "infect_teamscores" },
    { 0x6966, "infected_class" },
    { 0x6967, "infectedkillsthislife" },
    { 0x6968, "infectedlethal" },
    { 0x6969, "infectedprimaryweapon" },
    { 0x696A, "infectedrejoined" },
    { 0x696B, "infectedsecondaryweapon" },
    { 0x696C, "infectedsuper" },
    { 0x696D, "infectedtactical" },
    { 0x696E, "infectextratimeperkill" },
    { 0x696F, "infectstreakbonus" },
    { 0x6970, "infil" },
    { 0x6971, "infil_add" },
    { 0x6972, "infil_anim_type" },
    { 0x6973, "infil_car1_catchup" },
    { 0x6974, "infil_car1_main" },
    { 0x6975, "infil_car1_start" },
    { 0x6976, "infil_disabled" },
    { 0x6977, "infil_dog1_watcher" },
    { 0x6978, "infil_dogs" },
    { 0x6979, "infil_ended" },
    { 0x697A, "infil_enemies_attack_logic" },
    { 0x697B, "infil_enemy_combat_logic" },
    { 0x697C, "infil_has_map_config" },
    { 0x697D, "infil_heli" },
    { 0x697E, "infil_heli_alpha" },
    { 0x697F, "infil_heli_bravo" },
    { 0x6980, "infil_heli_cockpit_light" },
    { 0x6981, "infil_heli_damage" },
    { 0x6982, "infil_heli_delete" },
    { 0x6983, "infil_heli_exterior_light" },
    { 0x6984, "infil_heli_fill_light" },
    { 0x6985, "infil_heli_kyle_light" },
    { 0x6986, "infil_heli_lights" },
    { 0x6987, "infil_heli_lights_alpha" },
    { 0x6988, "infil_heli_rim_light" },
    { 0x6989, "infil_heli_setup" },
    { 0x698A, "infil_heli_under_fire_setup" },
    { 0x698B, "infil_heli_under_fire_setup_array" },
    { 0x698C, "infil_in_progress" },
    { 0x698D, "infil_in_progress_buffer" },
    { 0x698E, "infil_init" },
    { 0x698F, "infil_init_spawn_selection" },
    { 0x6990, "infil_is_gamemode" },
    { 0x6991, "infil_is_interactive" },
    { 0x6992, "infil_is_subtype" },
    { 0x6993, "infil_is_type" },
    { 0x6994, "infil_leader" },
    { 0x6995, "infil_lightmeter" },
    { 0x6996, "infil_play_sound_func" },
    { 0x6997, "infil_player_allow" },
    { 0x6998, "infil_player_allow_cp" },
    { 0x6999, "infil_player_array_handler" },
    { 0x699A, "infil_player_rig" },
    { 0x699B, "infil_player_rig_updated" },
    { 0x699C, "infil_radio_idle" },
    { 0x699D, "infil_remove_fov_scale_factor_override" },
    { 0x699E, "infil_remove_fov_user_scale_override" },
    { 0x699F, "infil_rope_sfx" },
    { 0x69A0, "infil_scene_fade_in" },
    { 0x69A1, "infil_setup_ui" },
    { 0x69A2, "infil_show_countdown" },
    { 0x69A3, "infil_spawn_building1_runner" },
    { 0x69A4, "infil_start" },
    { 0x69A5, "infil_struct" },
    { 0x69A6, "infil_vignette_anim_type" },
    { 0x69A7, "infil_visionset" },
    { 0x69A8, "infil_wait_for_all_players" },
    { 0x69A9, "infil_wait_for_players" },
    { 0x69AA, "infilallfadetoblack" },
    { 0x69AB, "infilallfadetowhite" },
    { 0x69AC, "infilanimindex" },
    { 0x69AD, "infilblackoverlay" },
    { 0x69AE, "infilcanusec130" },
    { 0x69AF, "infilcanuseconvoy" },
    { 0x69B0, "infilcanuseheli" },
    { 0x69B1, "infilcanusemap" },
    { 0x69B2, "infilfreefallparachuteaudio" },
    { 0x69B3, "infilheightcompensation" },
    { 0x69B4, "infilhelipartnerref" },
    { 0x69B5, "infilheliplayerref" },
    { 0x69B6, "infilinitonce" },
    { 0x69B7, "infiljumpentsspawned" },
    { 0x69B8, "infillength" },
    { 0x69B9, "infilscore" },
    { 0x69BA, "infilselectionmethod" },
    { 0x69BB, "infilspectatorview" },
    { 0x69BC, "infilstruct" },
    { 0x69BD, "infiltargets" },
    { 0x69BE, "infilthink" },
    { 0x69BF, "infilvotiming" },
    { 0x69C0, "infilweapon" },
    { 0x69C1, "infilwhiteoverlay" },
    { 0x69C2, "infinite_ammo" },
    { 0x69C3, "infinite_drones" },
    { 0x69C4, "infinite_grenades" },
    { 0x69C5, "infinite_reserve_ammo" },
    { 0x69C6, "infinite_reserve_ammo_not_revolver" },
    { 0x69C7, "infiniteammo" },
    { 0x69C8, "infiniteammocounter" },
    { 0x69C9, "infiniteammothread" },
    { 0x69CA, "infiniteammoupdaterate" },
    { 0x69CB, "infinitehold" },
    { 0x69CC, "infiniteloop" },
    { 0x69CD, "infiniteobjectives" },
    { 0x69CE, "inflictor" },
    { 0x69CF, "inflictoragentinfo" },
    { 0x69D0, "influencenodealloccounts" },
    { 0x69D1, "influencepoint_add" },
    { 0x69D2, "influencepoint_cleanupthink" },
    { 0x69D3, "influencepoint_getalloccountfromscripthandle" },
    { 0x69D4, "influencepoint_getcodehandlefromscripthandle" },
    { 0x69D5, "influencepoint_getnewscripthandle" },
    { 0x69D6, "influencepoint_invalidatescripthandlesforcodehandle" },
    { 0x69D7, "influencepoint_isscripthandlevalid" },
    { 0x69D8, "influencepoint_remove" },
    { 0x69D9, "info" },
    { 0x69DA, "info_func" },
    { 0x69DB, "informant" },
    { 0x69DC, "informant_goal" },
    { 0x69DD, "informant_onfirstuse" },
    { 0x69DE, "informant_onuse" },
    { 0x69DF, "informattacking" },
    { 0x69E0, "informed" },
    { 0x69E1, "informincoming" },
    { 0x69E2, "informkillfirm" },
    { 0x69E3, "informreloading" },
    { 0x69E4, "informsuppressed" },
    { 0x69E5, "inframes" },
    { 0x69E6, "infreefall" },
    { 0x69E7, "infriendlybase" },
    { 0x69E8, "infront" },
    { 0x69E9, "ingame_cinematic_loop" },
    { 0x69EA, "ingraceperiod" },
    { 0x69EB, "inhackring" },
    { 0x69EC, "inheliproximity" },
    { 0x69ED, "init_2ndfloor_muzzle_flash" },
    { 0x69EE, "init_ac130_vo" },
    { 0x69EF, "init_agent" },
    { 0x69F0, "init_agent_models_by_weapon" },
    { 0x69F1, "init_aibattlechatter" },
    { 0x69F2, "init_airstrike_flyby_anims" },
    { 0x69F3, "init_airstrike_params" },
    { 0x69F4, "init_airstrike_vo" },
    { 0x69F5, "init_alarm_system" },
    { 0x69F6, "init_all_weapon_upgrades" },
    { 0x69F7, "init_ammoresocklocs" },
    { 0x69F8, "init_analytics" },
    { 0x69F9, "init_and_set_relics" },
    { 0x69FA, "init_anim" },
    { 0x69FB, "init_anim_dog" },
    { 0x69FC, "init_anim_generic_human" },
    { 0x69FD, "init_anim_generic_human_level" },
    { 0x69FE, "init_anim_generic_human_level_civilian_react" },
    { 0x69FF, "init_anim_generic_human_level_civilian_worker" },
    { 0x6A00, "init_anim_generic_human_level_execution" },
    { 0x6A01, "init_anim_player" },
    { 0x6A02, "init_anim_script_model" },
    { 0x6A03, "init_anim_sets" },
    { 0x6A04, "init_anim_vehicles" },
    { 0x6A05, "init_animatedmodels" },
    { 0x6A06, "init_anims" },
    { 0x6A07, "init_anims_generic_human" },
    { 0x6A08, "init_anims_player" },
    { 0x6A09, "init_anims_script_model" },
    { 0x6A0A, "init_anims_scriptables" },
    { 0x6A0B, "init_anims_vehicles" },
    { 0x6A0C, "init_animset_ambush" },
    { 0x6A0D, "init_animset_complete_custom_crouch" },
    { 0x6A0E, "init_animset_complete_custom_stand" },
    { 0x6A0F, "init_animset_cqb_move" },
    { 0x6A10, "init_animset_cqb_stand" },
    { 0x6A11, "init_animset_custom_crouch" },
    { 0x6A12, "init_animset_custom_stand" },
    { 0x6A13, "init_animset_death" },
    { 0x6A14, "init_animset_default_crouch" },
    { 0x6A15, "init_animset_default_prone" },
    { 0x6A16, "init_animset_default_stand" },
    { 0x6A17, "init_animset_flashed" },
    { 0x6A18, "init_animset_heat_reload" },
    { 0x6A19, "init_animset_heat_run_move" },
    { 0x6A1A, "init_animset_heat_stand" },
    { 0x6A1B, "init_animset_pain" },
    { 0x6A1C, "init_animset_pistol_stand" },
    { 0x6A1D, "init_animset_rpg_crouch" },
    { 0x6A1E, "init_animset_rpg_stand" },
    { 0x6A1F, "init_animset_run_move" },
    { 0x6A20, "init_animset_run_n_gun" },
    { 0x6A21, "init_animset_shotgun_crouch" },
    { 0x6A22, "init_animset_shotgun_stand" },
    { 0x6A23, "init_animset_walk_move" },
    { 0x6A24, "init_animsounds" },
    { 0x6A25, "init_animsounds_for_animname" },
    { 0x6A26, "init_apache_chatter" },
    { 0x6A27, "init_apache_vehicleanims" },
    { 0x6A28, "init_audio" },
    { 0x6A29, "init_audio_struct" },
    { 0x6A2A, "init_auto_crouch" },
    { 0x6A2B, "init_b_side_wall" },
    { 0x6A2C, "init_ba_objective" },
    { 0x6A2D, "init_ballistics" },
    { 0x6A2E, "init_bank_interactions" },
    { 0x6A2F, "init_battlechatter" },
    { 0x6A30, "init_bg_tracer_fx" },
    { 0x6A31, "init_binary_puzzle" },
    { 0x6A32, "init_blackbox_interaction" },
    { 0x6A33, "init_block_puzzle_interaction" },
    { 0x6A34, "init_bot_archetypes" },
    { 0x6A35, "init_bot_attachmenttable" },
    { 0x6A36, "init_bot_camotable" },
    { 0x6A37, "init_bot_game_ctf" },
    { 0x6A38, "init_bot_game_demolition" },
    { 0x6A39, "init_bot_game_headquarters" },
    { 0x6A3A, "init_bot_weap_statstable" },
    { 0x6A3B, "init_box_interaction" },
    { 0x6A3C, "init_br_rewards" },
    { 0x6A3D, "init_bravo_gate" },
    { 0x6A3E, "init_breakout" },
    { 0x6A3F, "init_building_flags" },
    { 0x6A40, "init_building_num" },
    { 0x6A41, "init_buttons" },
    { 0x6A42, "init_c6" },
    { 0x6A43, "init_callbacks" },
    { 0x6A44, "init_callout_vo" },
    { 0x6A45, "init_camera_interaction" },
    { 0x6A46, "init_cctv_anims" },
    { 0x6A47, "init_chatter" },
    { 0x6A48, "init_checkin_weapons" },
    { 0x6A49, "init_chopper_lights" },
    { 0x6A4A, "init_chopper_support" },
    { 0x6A4B, "init_chopper_support_vo" },
    { 0x6A4C, "init_chu_fire_lights" },
    { 0x6A4D, "init_civchater_vo" },
    { 0x6A4E, "init_civilian_props" },
    { 0x6A4F, "init_civkill_vo" },
    { 0x6A50, "init_class_changed_values" },
    { 0x6A51, "init_class_table" },
    { 0x6A52, "init_cluster_parent" },
    { 0x6A53, "init_collect_nuclear_core" },
    { 0x6A54, "init_color_grouping" },
    { 0x6A55, "init_colors" },
    { 0x6A56, "init_complete" },
    { 0x6A57, "init_computer_anims" },
    { 0x6A58, "init_consumable_meter" },
    { 0x6A59, "init_consumables" },
    { 0x6A5A, "init_consumables_earned_score" },
    { 0x6A5B, "init_consumables_earned_score_component" },
    { 0x6A5C, "init_consumables_used" },
    { 0x6A5D, "init_coop_escort" },
    { 0x6A5E, "init_core_mp_perks" },
    { 0x6A5F, "init_corner_wall" },
    { 0x6A60, "init_corner_wall_building_b" },
    { 0x6A61, "init_corpse" },
    { 0x6A62, "init_count" },
    { 0x6A63, "init_cp" },
    { 0x6A64, "init_cp_3_doors" },
    { 0x6A65, "init_cp_5_doors" },
    { 0x6A66, "init_cp_hud_message" },
    { 0x6A67, "init_craftingsystem" },
    { 0x6A68, "init_crate_type" },
    { 0x6A69, "init_create_fx" },
    { 0x6A6A, "init_create_script" },
    { 0x6A6B, "init_crosshair" },
    { 0x6A6C, "init_cs_ents" },
    { 0x6A6D, "init_cursor_hint" },
    { 0x6A6E, "init_cutout_anims" },
    { 0x6A6F, "init_damage_callback_data" },
    { 0x6A70, "init_damage_score" },
    { 0x6A71, "init_damage_score_component" },
    { 0x6A72, "init_damageable_start_door" },
    { 0x6A73, "init_deathfx" },
    { 0x6A74, "init_demo" },
    { 0x6A75, "init_destroy_c130" },
    { 0x6A76, "init_destructible" },
    { 0x6A77, "init_destructible_perimeter" },
    { 0x6A78, "init_destructible_roof_walls" },
    { 0x6A79, "init_destruction" },
    { 0x6A7A, "init_dev_hud" },
    { 0x6A7B, "init_dialog_structs" },
    { 0x6A7C, "init_dog" },
    { 0x6A7D, "init_donnas" },
    { 0x6A7E, "init_door_internal" },
    { 0x6A7F, "init_door_state" },
    { 0x6A80, "init_doors" },
    { 0x6A81, "init_drone_strike" },
    { 0x6A82, "init_drone_vo" },
    { 0x6A83, "init_dvars" },
    { 0x6A84, "init_dynolights_state" },
    { 0x6A85, "init_each_perk" },
    { 0x6A86, "init_earthquake" },
    { 0x6A87, "init_earthquake_for_client" },
    { 0x6A88, "init_easter_eggs" },
    { 0x6A89, "init_elevator" },
    { 0x6A8A, "init_elevator_animations" },
    { 0x6A8B, "init_emp_damage_data" },
    { 0x6A8C, "init_encounter" },
    { 0x6A8D, "init_encounter_score_components" },
    { 0x6A8E, "init_encounters" },
    { 0x6A8F, "init_ending_lights" },
    { 0x6A90, "init_enemy_spawner" },
    { 0x6A91, "init_enemy_type_tracking" },
    { 0x6A92, "init_eog_score_components" },
    { 0x6A93, "init_equip_disguise" },
    { 0x6A94, "init_escalation" },
    { 0x6A95, "init_escalation_battlechatter" },
    { 0x6A96, "init_event_distances" },
    { 0x6A97, "init_exfil_anims" },
    { 0x6A98, "init_exfil_plane" },
    { 0x6A99, "init_exploders" },
    { 0x6A9A, "init_exposed_turn_animations" },
    { 0x6A9B, "init_extra_xp" },
    { 0x6A9C, "init_extract_lz" },
    { 0x6A9D, "init_extraction" },
    { 0x6A9E, "init_fallback_triggers" },
    { 0x6A9F, "init_find_hvi" },
    { 0x6AA0, "init_flags" },
    { 0x6AA1, "init_flavorbursts" },
    { 0x6AA2, "init_flicker_and_siren_lights" },
    { 0x6AA3, "init_floor_enemy_info_table" },
    { 0x6AA4, "init_fob" },
    { 0x6AA5, "init_footstep_fx" },
    { 0x6AA6, "init_footsteps" },
    { 0x6AA7, "init_front_wall" },
    { 0x6AA8, "init_func" },
    { 0x6AA9, "init_funcs" },
    { 0x6AAA, "init_function_refs" },
    { 0x6AAB, "init_fx" },
    { 0x6AAC, "init_fx_thread" },
    { 0x6AAD, "init_gamer_profile" },
    { 0x6AAE, "init_gamescore" },
    { 0x6AAF, "init_gameskill" },
    { 0x6AB0, "init_gas_escape_vo" },
    { 0x6AB1, "init_gas_masks" },
    { 0x6AB2, "init_gibbing" },
    { 0x6AB3, "init_glass" },
    { 0x6AB4, "init_global_cp_flags" },
    { 0x6AB5, "init_global_dvars" },
    { 0x6AB6, "init_global_omnvars" },
    { 0x6AB7, "init_global_precache" },
    { 0x6AB8, "init_global_systems" },
    { 0x6AB9, "init_global_variables" },
    { 0x6ABA, "init_glowstick" },
    { 0x6ABB, "init_go_to_the_prison" },
    { 0x6ABC, "init_gravity" },
    { 0x6ABD, "init_graycard" },
    { 0x6ABE, "init_grenade_animations" },
    { 0x6ABF, "init_grounds" },
    { 0x6AC0, "init_groundwarvehicles" },
    { 0x6AC1, "init_gun_checkin" },
    { 0x6AC2, "init_gunship_intro_anims" },
    { 0x6AC3, "init_gunship_vo" },
    { 0x6AC4, "init_hacking_table" },
    { 0x6AC5, "init_hangar_vehicles" },
    { 0x6AC6, "init_headshot_ammo" },
    { 0x6AC7, "init_headshot_super" },
    { 0x6AC8, "init_helicopter" },
    { 0x6AC9, "init_helicopters" },
    { 0x6ACA, "init_help_responses" },
    { 0x6ACB, "init_helper_drone_anim" },
    { 0x6ACC, "init_helper_drone_vo" },
    { 0x6ACD, "init_hints" },
    { 0x6ACE, "init_hit_damage_data" },
    { 0x6ACF, "init_holdout" },
    { 0x6AD0, "init_hostages" },
    { 0x6AD1, "init_hover_jet_anims" },
    { 0x6AD2, "init_hover_jet_vo" },
    { 0x6AD3, "init_huds" },
    { 0x6AD4, "init_human" },
    { 0x6AD5, "init_hunt_regions" },
    { 0x6AD6, "init_infil_plane" },
    { 0x6AD7, "init_intel_pieces" },
    { 0x6AD8, "init_interactions" },
    { 0x6AD9, "init_interrogator" },
    { 0x6ADA, "init_introscreen" },
    { 0x6ADB, "init_jugg_vo" },
    { 0x6ADC, "init_juggernaut_damage_states" },
    { 0x6ADD, "init_kidnapper_combat_loop" },
    { 0x6ADE, "init_kill_tunnel_spawns" },
    { 0x6ADF, "init_lab_lights" },
    { 0x6AE0, "init_land_at_lz" },
    { 0x6AE1, "init_laststand" },
    { 0x6AE2, "init_laststand_anims" },
    { 0x6AE3, "init_level" },
    { 0x6AE4, "init_level_systems" },
    { 0x6AE5, "init_level_variables" },
    { 0x6AE6, "init_light" },
    { 0x6AE7, "init_light_destructable" },
    { 0x6AE8, "init_light_flicker" },
    { 0x6AE9, "init_light_generic_iw7" },
    { 0x6AEA, "init_light_pulse_iw7" },
    { 0x6AEB, "init_light_trig" },
    { 0x6AEC, "init_light_type" },
    { 0x6AED, "init_lighting" },
    { 0x6AEE, "init_lighting_dvars" },
    { 0x6AEF, "init_lights" },
    { 0x6AF0, "init_loadout" },
    { 0x6AF1, "init_local" },
    { 0x6AF2, "init_location" },
    { 0x6AF3, "init_locations" },
    { 0x6AF4, "init_locked_list" },
    { 0x6AF5, "init_lone_patroller" },
    { 0x6AF6, "init_loot" },
    { 0x6AF7, "init_loot_scriptables" },
    { 0x6AF8, "init_low_vent_covers" },
    { 0x6AF9, "init_manipulate_ent" },
    { 0x6AFA, "init_manual_turret_settings" },
    { 0x6AFB, "init_manual_turret_vo" },
    { 0x6AFC, "init_marine_arrays" },
    { 0x6AFD, "init_matchdata" },
    { 0x6AFE, "init_max_yaws" },
    { 0x6AFF, "init_meet_with_informant" },
    { 0x6B00, "init_menu" },
    { 0x6B01, "init_menus" },
    { 0x6B02, "init_mgturretsettings" },
    { 0x6B03, "init_mission_select" },
    { 0x6B04, "init_mission_select_new" },
    { 0x6B05, "init_ml_p1_intel" },
    { 0x6B06, "init_ml_p3_intel" },
    { 0x6B07, "init_ml_p3_intel_2" },
    { 0x6B08, "init_ml_p3_intel_3" },
    { 0x6B09, "init_mocap_ar" },
    { 0x6B0A, "init_mod_damage_data" },
    { 0x6B0B, "init_modern" },
    { 0x6B0C, "init_modular_spawning" },
    { 0x6B0D, "init_modular_spawning_flags" },
    { 0x6B0E, "init_molotov_throw_targets" },
    { 0x6B0F, "init_money_earned_score" },
    { 0x6B10, "init_money_earned_score_component" },
    { 0x6B11, "init_move_transition_arrays" },
    { 0x6B12, "init_mover_candidates" },
    { 0x6B13, "init_moving_turn_animations" },
    { 0x6B14, "init_mp" },
    { 0x6B15, "init_mp_faridah" },
    { 0x6B16, "init_munitions" },
    { 0x6B17, "init_nerf_scalar" },
    { 0x6B18, "init_notetracks_for_animname" },
    { 0x6B19, "init_objective_colors" },
    { 0x6B1A, "init_objectives" },
    { 0x6B1B, "init_onlookers" },
    { 0x6B1C, "init_overwatch" },
    { 0x6B1D, "init_pac_sentry_vo" },
    { 0x6B1E, "init_pain" },
    { 0x6B1F, "init_paratroopers_spawners" },
    { 0x6B20, "init_passive_below_the_belt" },
    { 0x6B21, "init_passive_berserk" },
    { 0x6B22, "init_passive_cold_damage" },
    { 0x6B23, "init_passive_crouch_move_speed" },
    { 0x6B24, "init_passive_double_kill_reload" },
    { 0x6B25, "init_passive_double_kill_super" },
    { 0x6B26, "init_passive_empty_reload_speed" },
    { 0x6B27, "init_passive_fast_melee" },
    { 0x6B28, "init_passive_fortified" },
    { 0x6B29, "init_passive_gore" },
    { 0x6B2A, "init_passive_health_on_kill" },
    { 0x6B2B, "init_passive_health_regen_on_kill" },
    { 0x6B2C, "init_passive_hitman" },
    { 0x6B2D, "init_passive_hunter_killer" },
    { 0x6B2E, "init_passive_increased_scope_breath" },
    { 0x6B2F, "init_passive_infinite_ammo" },
    { 0x6B30, "init_passive_jump_super" },
    { 0x6B31, "init_passive_last_shots_ammo" },
    { 0x6B32, "init_passive_melee_cone_expl" },
    { 0x6B33, "init_passive_melee_kill" },
    { 0x6B34, "init_passive_melee_super" },
    { 0x6B35, "init_passive_minimap_damage" },
    { 0x6B36, "init_passive_miss_refund" },
    { 0x6B37, "init_passive_mode_switch_score" },
    { 0x6B38, "init_passive_move_speed" },
    { 0x6B39, "init_passive_move_speed_on_kill" },
    { 0x6B3A, "init_passive_ninja" },
    { 0x6B3B, "init_passive_nuke" },
    { 0x6B3C, "init_passive_railgun_overload" },
    { 0x6B3D, "init_passive_random_attachment" },
    { 0x6B3E, "init_passive_random_perks" },
    { 0x6B3F, "init_passive_refresh" },
    { 0x6B40, "init_passive_scope_radar" },
    { 0x6B41, "init_passive_score_bonus_kills" },
    { 0x6B42, "init_passive_scorestreak_damage" },
    { 0x6B43, "init_passive_scoutping" },
    { 0x6B44, "init_passive_scrambler" },
    { 0x6B45, "init_passive_sonic" },
    { 0x6B46, "init_passive_visor_detonation" },
    { 0x6B47, "init_passive_wave_struct" },
    { 0x6B48, "init_path" },
    { 0x6B49, "init_perimeter_lights" },
    { 0x6B4A, "init_perktable" },
    { 0x6B4B, "init_personal_ent_zones" },
    { 0x6B4C, "init_personality_camper" },
    { 0x6B4D, "init_personality_default" },
    { 0x6B4E, "init_plane_anims" },
    { 0x6B4F, "init_plant_jammers" },
    { 0x6B50, "init_player" },
    { 0x6B51, "init_player_achievement" },
    { 0x6B52, "init_player_animated_death" },
    { 0x6B53, "init_player_body" },
    { 0x6B54, "init_player_clips" },
    { 0x6B55, "init_player_consumables" },
    { 0x6B56, "init_player_death" },
    { 0x6B57, "init_player_death_monitor" },
    { 0x6B58, "init_player_gameobjects" },
    { 0x6B59, "init_player_monitors" },
    { 0x6B5A, "init_player_rig" },
    { 0x6B5B, "init_player_rig_no_precache" },
    { 0x6B5C, "init_player_rig_script_anims" },
    { 0x6B5D, "init_player_score" },
    { 0x6B5E, "init_player_seated_anims" },
    { 0x6B5F, "init_player_seating_anims" },
    { 0x6B60, "init_player_sessiondata" },
    { 0x6B61, "init_player_suppression" },
    { 0x6B62, "init_playerchatter" },
    { 0x6B63, "init_police_helpresponses" },
    { 0x6B64, "init_pos" },
    { 0x6B65, "init_post_flags" },
    { 0x6B66, "init_postspawns" },
    { 0x6B67, "init_pre_vault_assault" },
    { 0x6B68, "init_pre_wave_spawning" },
    { 0x6B69, "init_precache" },
    { 0x6B6A, "init_price_attic_lights" },
    { 0x6B6B, "init_price_intro_lights" },
    { 0x6B6C, "init_pulse" },
    { 0x6B6D, "init_pvpe" },
    { 0x6B6E, "init_pvpve" },
    { 0x6B6F, "init_quest_system" },
    { 0x6B70, "init_quest_util" },
    { 0x6B71, "init_radar_activate" },
    { 0x6B72, "init_radio_tower" },
    { 0x6B73, "init_rallyvehicles" },
    { 0x6B74, "init_reach_drop_zone" },
    { 0x6B75, "init_reach_lz" },
    { 0x6B76, "init_recover_nuclear_core" },
    { 0x6B77, "init_reflection_probe" },
    { 0x6B78, "init_relic_boom" },
    { 0x6B79, "init_relic_catch" },
    { 0x6B7A, "init_relic_collat_dmg" },
    { 0x6B7B, "init_relic_glasscannon" },
    { 0x6B7C, "init_relic_swat" },
    { 0x6B7D, "init_remote_tank" },
    { 0x6B7E, "init_reset_ai" },
    { 0x6B7F, "init_residence_wall" },
    { 0x6B80, "init_reverb" },
    { 0x6B81, "init_revive_icon_list" },
    { 0x6B82, "init_roof_destruction" },
    { 0x6B83, "init_rumble" },
    { 0x6B84, "init_rumble_for_client" },
    { 0x6B85, "init_safehouse" },
    { 0x6B86, "init_safehouse_return" },
    { 0x6B87, "init_save" },
    { 0x6B88, "init_score_data" },
    { 0x6B89, "init_script" },
    { 0x6B8A, "init_script_brushmodels" },
    { 0x6B8B, "init_script_car_collision" },
    { 0x6B8C, "init_script_friendnames" },
    { 0x6B8D, "init_script_triggers" },
    { 0x6B8E, "init_scriptable_reds" },
    { 0x6B8F, "init_scriptable_trucks" },
    { 0x6B90, "init_scripted_fx" },
    { 0x6B91, "init_selection_and_cursor" },
    { 0x6B92, "init_settings" },
    { 0x6B93, "init_shootable_lanterns" },
    { 0x6B94, "init_shootable_lanterns_internal" },
    { 0x6B95, "init_smartobjects" },
    { 0x6B96, "init_smuggler_loot_interaction" },
    { 0x6B97, "init_snap_to_head" },
    { 0x6B98, "init_sounds" },
    { 0x6B99, "init_sp_flags" },
    { 0x6B9A, "init_spawn_anim_skits" },
    { 0x6B9B, "init_spawn_factors" },
    { 0x6B9C, "init_spawn_radius_check_for_modules" },
    { 0x6B9D, "init_spawn_times" },
    { 0x6B9E, "init_spawn_vars_and_pointers" },
    { 0x6B9F, "init_spawners" },
    { 0x6BA0, "init_spawnfunctions" },
    { 0x6BA1, "init_spawnpoints_from_cover_nodes" },
    { 0x6BA2, "init_squadbattlechatter" },
    { 0x6BA3, "init_squadmanager" },
    { 0x6BA4, "init_squads" },
    { 0x6BA5, "init_starts" },
    { 0x6BA6, "init_stats" },
    { 0x6BA7, "init_stealth" },
    { 0x6BA8, "init_stealth_areas" },
    { 0x6BA9, "init_stealth_volumes" },
    { 0x6BAA, "init_strings" },
    { 0x6BAB, "init_strobe" },
    { 0x6BAC, "init_struct_class" },
    { 0x6BAD, "init_super" },
    { 0x6BAE, "init_super_for_player" },
    { 0x6BAF, "init_tarmac_fire_lights" },
    { 0x6BB0, "init_template_table" },
    { 0x6BB1, "init_threatbias" },
    { 0x6BB2, "init_threatbias_groups" },
    { 0x6BB3, "init_tickets_earned_score" },
    { 0x6BB4, "init_tickets_earned_score_component" },
    { 0x6BB5, "init_timescale" },
    { 0x6BB6, "init_tire_outlines" },
    { 0x6BB7, "init_toma_strike_vo" },
    { 0x6BB8, "init_tool_hud" },
    { 0x6BB9, "init_touching_triggers" },
    { 0x6BBA, "init_towers" },
    { 0x6BBB, "init_train" },
    { 0x6BBC, "init_train_lights" },
    { 0x6BBD, "init_tree_fire_light" },
    { 0x6BBE, "init_trees" },
    { 0x6BBF, "init_trial_patches" },
    { 0x6BC0, "init_trigger_flags" },
    { 0x6BC1, "init_trigger_spawn_groups" },
    { 0x6BC2, "init_trigger_spawns" },
    { 0x6BC3, "init_tripwires" },
    { 0x6BC4, "init_turret_lifetime_shot_count" },
    { 0x6BC5, "init_tutorial_message_array" },
    { 0x6BC6, "init_uav_cp" },
    { 0x6BC7, "init_uav_mp" },
    { 0x6BC8, "init_upgrade_weapon" },
    { 0x6BC9, "init_useprompt_interactions" },
    { 0x6BCA, "init_utility_triggers" },
    { 0x6BCB, "init_vault_assault" },
    { 0x6BCC, "init_vault_assault_crypto" },
    { 0x6BCD, "init_vault_assault_cut" },
    { 0x6BCE, "init_vault_assault_rooftop" },
    { 0x6BCF, "init_vault_assault_rooftop_call_exfil" },
    { 0x6BD0, "init_vault_assault_rooftop_defend" },
    { 0x6BD1, "init_vault_assault_rooftop_exfil" },
    { 0x6BD2, "init_vault_assault_rooftop_heli" },
    { 0x6BD3, "init_vault_assault_vault" },
    { 0x6BD4, "init_vault_assault_vault_fake_end" },
    { 0x6BD5, "init_vault_door" },
    { 0x6BD6, "init_vehicle" },
    { 0x6BD7, "init_vehicle_heavy_destruction" },
    { 0x6BD8, "init_vehicle_interact" },
    { 0x6BD9, "init_vehicle_omnvars" },
    { 0x6BDA, "init_vehicle_repair_anims" },
    { 0x6BDB, "init_vehicle_spawn_funcs" },
    { 0x6BDC, "init_vehicle_spawning" },
    { 0x6BDD, "init_vehicles" },
    { 0x6BDE, "init_vehicles_after_flags" },
    { 0x6BDF, "init_vehicles_thread" },
    { 0x6BE0, "init_vfx" },
    { 0x6BE1, "init_vision" },
    { 0x6BE2, "init_visionsetnight" },
    { 0x6BE3, "init_vo_system" },
    { 0x6BE4, "init_waits" },
    { 0x6BE5, "init_wall_state" },
    { 0x6BE6, "init_wave_settings" },
    { 0x6BE7, "init_wave_spawning" },
    { 0x6BE8, "init_wave_spawning_module" },
    { 0x6BE9, "init_wave_spawning_module_proc" },
    { 0x6BEA, "init_wave_spawning_module_secondary" },
    { 0x6BEB, "init_weapon_and_player_analytics" },
    { 0x6BEC, "init_weapon_rank_events" },
    { 0x6BED, "init_weapon_upgrade" },
    { 0x6BEE, "init_weapon_upgrade_for_player" },
    { 0x6BEF, "init_wileys" },
    { 0x6BF0, "init_wind" },
    { 0x6BF1, "init_wind_at_point" },
    { 0x6BF2, "init_window" },
    { 0x6BF3, "init_zombie_scoring" },
    { 0x6BF4, "initaarawardlist" },
    { 0x6BF5, "initadvancetoenemy" },
    { 0x6BF6, "initagentlevelvariables" },
    { 0x6BF7, "initagentscriptvariables" },
    { 0x6BF8, "initaimlimits" },
    { 0x6BF9, "initandstartvosystem" },
    { 0x6BFA, "initanim" },
    { 0x6BFB, "initanimcallbacks" },
    { 0x6BFC, "initanims" },
    { 0x6BFD, "initanimspeedthresholds_civilian" },
    { 0x6BFE, "initanimspeedthresholds_juggernaut" },
    { 0x6BFF, "initanimspeedthresholds_soldier" },
    { 0x6C00, "initanimteddoor" },
    { 0x6C01, "initanimtree" },
    { 0x6C02, "initanimvars" },
    { 0x6C03, "initarbitraryuptriggers" },
    { 0x6C04, "initarmcratedata" },
    { 0x6C05, "initarmcratedatalate" },
    { 0x6C06, "initarms1" },
    { 0x6C07, "initarms2" },
    { 0x6C08, "initarms3" },
    { 0x6C09, "initarms4" },
    { 0x6C0A, "initarmsraceobj" },
    { 0x6C0B, "initarrays" },
    { 0x6C0C, "initassisttrackers" },
    { 0x6C0D, "initawards" },
    { 0x6C0E, "initballtimer" },
    { 0x6C0F, "initbaseaward" },
    { 0x6C10, "initbasemidmatchaward" },
    { 0x6C11, "initbattlechatter" },
    { 0x6C12, "initbattleroyalecratedata" },
    { 0x6C13, "initbattleroyaleloadoutcratedata" },
    { 0x6C14, "initbestscorestatstable" },
    { 0x6C15, "initbloodoverlay" },
    { 0x6C16, "initbombs" },
    { 0x6C17, "initbombsitespawns" },
    { 0x6C18, "initbotlevelvariables" },
    { 0x6C19, "initbotmapextents" },
    { 0x6C1A, "initbreachpoint" },
    { 0x6C1B, "initbroshot" },
    { 0x6C1C, "initbroshotfx" },
    { 0x6C1D, "initbufferedstats" },
    { 0x6C1E, "initcalltraininteract" },
    { 0x6C1F, "initcameras" },
    { 0x6C20, "initchangestance" },
    { 0x6C21, "initcircle" },
    { 0x6C22, "initcivilian" },
    { 0x6C23, "initclientdvars" },
    { 0x6C24, "initclientdvarssplitscreenspecific" },
    { 0x6C25, "initcombatfunctions" },
    { 0x6C26, "initcombatfunctions_mp" },
    { 0x6C27, "initcommslaptop" },
    { 0x6C28, "initconfig" },
    { 0x6C29, "initcontact" },
    { 0x6C2A, "initcover" },
    { 0x6C2B, "initcoverbb" },
    { 0x6C2C, "initcoverexposenoenemy" },
    { 0x6C2D, "initcparmsraceemptycrate" },
    { 0x6C2E, "initcpcratedata" },
    { 0x6C2F, "initcploadoutcratedata" },
    { 0x6C30, "initcpvosystem" },
    { 0x6C31, "initcratedata" },
    { 0x6C32, "initcratedropdata" },
    { 0x6C33, "initcredits" },
    { 0x6C34, "initcreditsstruct" },
    { 0x6C35, "initdamageoverlay" },
    { 0x6C36, "initdeaths" },
    { 0x6C37, "initdeathsdooroverlaypulse" },
    { 0x6C38, "initdeathvfx" },
    { 0x6C39, "initdefaulthvtmodel" },
    { 0x6C3A, "initdefaultoperatorskins" },
    { 0x6C3B, "initdefaultsettings" },
    { 0x6C3C, "initdestructables" },
    { 0x6C3D, "initdeveloperdvars" },
    { 0x6C3E, "initdragonsbreathpainfxhack" },
    { 0x6C3F, "initdropbagsystem" },
    { 0x6C40, "initdropzonekillstreakcratedata" },
    { 0x6C41, "inited" },
    { 0x6C42, "initeffects" },
    { 0x6C43, "initendzoneent" },
    { 0x6C44, "initendzoneents" },
    { 0x6C45, "initexpose" },
    { 0x6C46, "initfacialanims" },
    { 0x6C47, "initfinalkillcam" },
    { 0x6C48, "initfiredamageoverlay" },
    { 0x6C49, "initfirefxrumbleent" },
    { 0x6C4A, "initfirepainoverlay" },
    { 0x6C4B, "initfiresfxdrone" },
    { 0x6C4C, "initfiresfxfire" },
    { 0x6C4D, "initfiresfxsmolder" },
    { 0x6C4E, "initfirevfxent" },
    { 0x6C4F, "initflag" },
    { 0x6C50, "initflags" },
    { 0x6C51, "initfrontline" },
    { 0x6C52, "initfx" },
    { 0x6C53, "initgameflags" },
    { 0x6C54, "initgate" },
    { 0x6C55, "initgesture" },
    { 0x6C56, "initgestures" },
    { 0x6C57, "initglobals" },
    { 0x6C58, "initgrenadeoffsets" },
    { 0x6C59, "initgrenades" },
    { 0x6C5A, "initgrenadethrowanims" },
    { 0x6C5B, "initgroup" },
    { 0x6C5C, "initgulag" },
    { 0x6C5D, "initheli" },
    { 0x6C5E, "inithide" },
    { 0x6C5F, "inithidetimers" },
    { 0x6C60, "inithud" },
    { 0x6C61, "inithuntregiondata" },
    { 0x6C62, "inithvtmodel" },
    { 0x6C63, "initial_bomb_location" },
    { 0x6C64, "initial_bomb_location_nearest_node" },
    { 0x6C65, "initial_bomb_pickup_time" },
    { 0x6C66, "initial_guard_logic" },
    { 0x6C67, "initial_intensity" },
    { 0x6C68, "initial_loadout" },
    { 0x6C69, "initial_loadout_init" },
    { 0x6C6A, "initial_loadout_manager" },
    { 0x6C6B, "initial_loadout_weapon" },
    { 0x6C6C, "initial_pickup_wait_time" },
    { 0x6C6D, "initial_spawn_time" },
    { 0x6C6E, "initial_up" },
    { 0x6C6F, "initialcovergunblockedbywalltime" },
    { 0x6C70, "initialinvestigatetime" },
    { 0x6C71, "initialize" },
    { 0x6C72, "initialize_alarm_box" },
    { 0x6C73, "initialize_as_veh_spawner" },
    { 0x6C74, "initialize_ball_role" },
    { 0x6C75, "initialize_blended_interaction_anims" },
    { 0x6C76, "initialize_blending_actor" },
    { 0x6C77, "initialize_character_group" },
    { 0x6C78, "initialize_group_lookat" },
    { 0x6C79, "initialize_intel" },
    { 0x6C7A, "initialize_path_node_placement" },
    { 0x6C7B, "initialize_player_team_slot_assignment" },
    { 0x6C7C, "initialize_radio" },
    { 0x6C7D, "initialize_role" },
    { 0x6C7E, "initialize_sd_role" },
    { 0x6C7F, "initialize_transition_array" },
    { 0x6C80, "initialize_wave_spawn_modules" },
    { 0x6C81, "initializearmorvalue" },
    { 0x6C82, "initialized" },
    { 0x6C83, "initialized_gameobject_vars" },
    { 0x6C84, "initializedynamiclzs" },
    { 0x6C85, "initializefixedlzs" },
    { 0x6C86, "initializematchrecording" },
    { 0x6C87, "initializematchrules" },
    { 0x6C88, "initializeobjective" },
    { 0x6C89, "initializeobjectives" },
    { 0x6C8A, "initializetagpathvariables" },
    { 0x6C8B, "initializetweakableoverrides" },
    { 0x6C8C, "initializeweaponpickups" },
    { 0x6C8D, "initialorg" },
    { 0x6C8E, "initialpatrolpoint" },
    { 0x6C8F, "initialplayer" },
    { 0x6C90, "initialprimaryweapon" },
    { 0x6C91, "initialsecondaryweapon" },
    { 0x6C92, "initialstate" },
    { 0x6C93, "initialtrigger" },
    { 0x6C94, "initialtriggerthink" },
    { 0x6C95, "initialvelocity" },
    { 0x6C96, "initiated" },
    { 0x6C97, "initinfillocationselectionhandlers" },
    { 0x6C98, "initinputtypewatcher" },
    { 0x6C99, "inititems" },
    { 0x6C9A, "initjugg" },
    { 0x6C9B, "initjuggcratesetupents" },
    { 0x6C9C, "initkillstreak" },
    { 0x6C9D, "initkillstreakcratedata" },
    { 0x6C9E, "initkillstreakcratedatalate" },
    { 0x6C9F, "initkillstreakdata" },
    { 0x6CA0, "initkilltriggerspawn" },
    { 0x6CA1, "initksbonuscrates" },
    { 0x6CA2, "initlaststand" },
    { 0x6CA3, "initlaunchchunkoperatorskins" },
    { 0x6CA4, "initlauncherlogic" },
    { 0x6CA5, "initleanplayerstats" },
    { 0x6CA6, "initlevelface" },
    { 0x6CA7, "initlevelflags" },
    { 0x6CA8, "initlevelvars" },
    { 0x6CA9, "initlinkednodes" },
    { 0x6CAA, "initlocalizedcredits" },
    { 0x6CAB, "initlongdeathgrenadepull" },
    { 0x6CAC, "initlook" },
    { 0x6CAD, "initloot" },
    { 0x6CAE, "initlootcaches" },
    { 0x6CAF, "initmarker" },
    { 0x6CB0, "initmeleeaction" },
    { 0x6CB1, "initmeleecharges" },
    { 0x6CB2, "initmeleefunctions" },
    { 0x6CB3, "initmeritdata" },
    { 0x6CB4, "initmidmatchaward" },
    { 0x6CB5, "initmidmatchawards" },
    { 0x6CB6, "initmines" },
    { 0x6CB7, "initmissilelauncherusage" },
    { 0x6CB8, "initmonitoradstime" },
    { 0x6CB9, "initmorales_1" },
    { 0x6CBA, "initmorales_2" },
    { 0x6CBB, "initmorales_3" },
    { 0x6CBC, "initmorales_4" },
    { 0x6CBD, "initmorales_5" },
    { 0x6CBE, "initmorales_6" },
    { 0x6CBF, "initmoralesfastloadobj" },
    { 0x6CC0, "initmoraleshackobj" },
    { 0x6CC1, "initmoralesholdoutobj" },
    { 0x6CC2, "initmoraleshvtmodel" },
    { 0x6CC3, "initmoralesinfilobj" },
    { 0x6CC4, "initmoraleslaptop" },
    { 0x6CC5, "initmoralesrescueobj" },
    { 0x6CC6, "initmoralessignal" },
    { 0x6CC7, "initmoralessignalobj" },
    { 0x6CC8, "initmoralesslowloadobj" },
    { 0x6CC9, "initmovestartstoptransitions" },
    { 0x6CCA, "initmovestrafeloop" },
    { 0x6CCB, "initmovestrafeloopnew" },
    { 0x6CCC, "initnightvisionheadoverrides" },
    { 0x6CCD, "initnodeyaw" },
    { 0x6CCE, "initnodeyaw_dev" },
    { 0x6CCF, "initnodeyaw_rebel" },
    { 0x6CD0, "initnodeyaw_soldier" },
    { 0x6CD1, "initnuke" },
    { 0x6CD2, "initnukeobjectivelocations" },
    { 0x6CD3, "initobjective1" },
    { 0x6CD4, "initobjective2" },
    { 0x6CD5, "initobjective3" },
    { 0x6CD6, "initobjectivecam" },
    { 0x6CD7, "initobjectivehud" },
    { 0x6CD8, "initobjectiveicons" },
    { 0x6CD9, "initobjicons" },
    { 0x6CDA, "initobjspawners" },
    { 0x6CDB, "initoob" },
    { 0x6CDC, "initoperatorcustomization" },
    { 0x6CDD, "initoutlineoccluders" },
    { 0x6CDE, "initoverheadcameras" },
    { 0x6CDF, "initpainfx" },
    { 0x6CE0, "initparachutedvars" },
    { 0x6CE1, "initpatrolpoints" },
    { 0x6CE2, "initpayloadobj" },
    { 0x6CE3, "initperkdvars" },
    { 0x6CE4, "initperks" },
    { 0x6CE5, "initperktable" },
    { 0x6CE6, "initpersstat" },
    { 0x6CE7, "initpet" },
    { 0x6CE8, "initpickupcleanupmonitor" },
    { 0x6CE9, "initpickupusability" },
    { 0x6CEA, "initplayer" },
    { 0x6CEB, "initplayerarena" },
    { 0x6CEC, "initplayerclass" },
    { 0x6CED, "initplayerdamage" },
    { 0x6CEE, "initplayerdamagefunctions" },
    { 0x6CEF, "initplayerdefaultsettings" },
    { 0x6CF0, "initplayerdvars" },
    { 0x6CF1, "initplayerentflags" },
    { 0x6CF2, "initplayerfocus" },
    { 0x6CF3, "initplayerjail" },
    { 0x6CF4, "initplayernotifies" },
    { 0x6CF5, "initplayeromnvars" },
    { 0x6CF6, "initplayerperks" },
    { 0x6CF7, "initplayerprecache" },
    { 0x6CF8, "initplayerprestige" },
    { 0x6CF9, "initplayerscriptvariables" },
    { 0x6CFA, "initplayersessionstats" },
    { 0x6CFB, "initplayerstats" },
    { 0x6CFC, "initplayervfx" },
    { 0x6CFD, "initplayerviewblender" },
    { 0x6CFE, "initplundercratedata" },
    { 0x6CFF, "initprestige" },
    { 0x6D00, "initpropaganda" },
    { 0x6D01, "initreload" },
    { 0x6D02, "initridekillstreak" },
    { 0x6D03, "initridekillstreak_internal" },
    { 0x6D04, "initriotshield" },
    { 0x6D05, "initroles" },
    { 0x6D06, "initrugbyents" },
    { 0x6D07, "initrules" },
    { 0x6D08, "initsandbox" },
    { 0x6D09, "initschoolmgturret" },
    { 0x6D0A, "initscoredata" },
    { 0x6D0B, "initscriptable" },
    { 0x6D0C, "initscriptablepart" },
    { 0x6D0D, "initscriptedhelidropanims" },
    { 0x6D0E, "initscriptedhelidropdata" },
    { 0x6D0F, "initscriptedhelidropvehicleanims" },
    { 0x6D10, "initsegmentstats" },
    { 0x6D11, "initshoot" },
    { 0x6D12, "initslidemonitor" },
    { 0x6D13, "initspawnarea" },
    { 0x6D14, "initspawnexclusionpois" },
    { 0x6D15, "initspawnpointvalues" },
    { 0x6D16, "initspawns" },
    { 0x6D17, "initspecatatorcameras" },
    { 0x6D18, "initspecialistkillstreaks" },
    { 0x6D19, "initsquaddata" },
    { 0x6D1A, "initstancetracking" },
    { 0x6D1B, "initstatemachineforpoitype" },
    { 0x6D1C, "initstatusdialog" },
    { 0x6D1D, "initstatusdialogonplayer" },
    { 0x6D1E, "initstealthfuncsmp" },
    { 0x6D1F, "initstealthfunctions" },
    { 0x6D20, "initstealthfunctionssp" },
    { 0x6D21, "initstealthmp" },
    { 0x6D22, "initstiminteract" },
    { 0x6D23, "initstingerusage" },
    { 0x6D24, "initsuperdvars" },
    { 0x6D25, "initsurvivaltime" },
    { 0x6D26, "inittablets" },
    { 0x6D27, "inittankspawns" },
    { 0x6D28, "inittankspawnsplaced" },
    { 0x6D29, "inittestclientlatent" },
    { 0x6D2A, "initthrowgrenade" },
    { 0x6D2B, "inittmtylinterrogate" },
    { 0x6D2C, "inittmtylobj" },
    { 0x6D2D, "inittripwireanims" },
    { 0x6D2E, "inittripwirestaticmodel" },
    { 0x6D2F, "initturrets" },
    { 0x6D30, "initvehiclespawnvolume" },
    { 0x6D31, "initvelocity" },
    { 0x6D32, "initviewblenderstruct" },
    { 0x6D33, "initwaypointbackgrounds" },
    { 0x6D34, "initwaypointicons" },
    { 0x6D35, "initweapon" },
    { 0x6D36, "initweaponarray" },
    { 0x6D37, "initweaponmap" },
    { 0x6D38, "initwindowtraverse" },
    { 0x6D39, "injured_actor_death" },
    { 0x6D3A, "injured_actors" },
    { 0x6D3B, "injured_civilian_reactions" },
    { 0x6D3C, "injured_dmg_death_logic" },
    { 0x6D3D, "injured_loop_single_death" },
    { 0x6D3E, "injured_loop_vignette" },
    { 0x6D3F, "injured_vignettes" },
    { 0x6D40, "inlaststand" },
    { 0x6D41, "inlmgstate" },
    { 0x6D42, "inlosid" },
    { 0x6D43, "inmhccam" },
    { 0x6D44, "inmoralesholdout" },
    { 0x6D45, "inmotionlight" },
    { 0x6D46, "innards" },
    { 0x6D47, "innocent_damage_thread" },
    { 0x6D48, "inobjectiveot" },
    { 0x6D49, "inot" },
    { 0x6D4A, "inovertime" },
    { 0x6D4B, "inparachute" },
    { 0x6D4C, "inplunderlivelobby" },
    { 0x6D4D, "inpotgkillcam" },
    { 0x6D4E, "inprogress" },
    { 0x6D4F, "input" },
    { 0x6D50, "input_has_happened" },
    { 0x6D51, "input_loop" },
    { 0x6D52, "input_reactive_radius" },
    { 0x6D53, "inputthread" },
    { 0x6D54, "inradzone" },
    { 0x6D55, "inrespawnc130" },
    { 0x6D56, "inreticledistssqr" },
    { 0x6D57, "inreticlesortedids" },
    { 0x6D58, "insert_effect" },
    { 0x6D59, "insert_index" },
    { 0x6D5A, "insertbypriority" },
    { 0x6D5B, "inside_gap_nag" },
    { 0x6D5C, "inside_plane" },
    { 0x6D5D, "inside_shaft_trig" },
    { 0x6D5E, "inside_volume" },
    { 0x6D5F, "insidestingerreticlelocked" },
    { 0x6D60, "insidestingerreticlelockoverride" },
    { 0x6D61, "insidestingerreticlenolock" },
    { 0x6D62, "inspawncamera" },
    { 0x6D63, "inspawnselection" },
    { 0x6D64, "inspect_dead_russians" },
    { 0x6D65, "insta_kill" },
    { 0x6D66, "instakillimmune" },
    { 0x6D67, "instancedata" },
    { 0x6D68, "instancelimitmessages" },
    { 0x6D69, "instancelimits" },
    { 0x6D6A, "instances" },
    { 0x6D6B, "instancesbyref" },
    { 0x6D6C, "instant_revive" },
    { 0x6D6D, "instantclassswapallowed" },
    { 0x6D6E, "instantexplode" },
    { 0x6D6F, "instantly_promote_nearest_friendly" },
    { 0x6D70, "instantly_promote_nearest_friendly_with_classname" },
    { 0x6D71, "instantly_set_color_from_array" },
    { 0x6D72, "instantly_set_color_from_array_with_classname" },
    { 0x6D73, "instructions_flag" },
    { 0x6D74, "insure_player_does_not_set_forcecolor_twice_in_one_frame" },
    { 0x6D75, "int_min" },
    { 0x6D76, "int_to_stealth_state" },
    { 0x6D77, "int_vips" },
    { 0x6D78, "int_vips_struct" },
    { 0x6D79, "intel_counter" },
    { 0x6D7A, "intel_dismiss_request" },
    { 0x6D7B, "intel_drop_chance_inc" },
    { 0x6D7C, "intel_drop_func" },
    { 0x6D7D, "intel_drop_num" },
    { 0x6D7E, "intel_dropper" },
    { 0x6D7F, "intel_drops" },
    { 0x6D80, "intel_feedback" },
    { 0x6D81, "intel_headicons" },
    { 0x6D82, "intel_init" },
    { 0x6D83, "intel_items" },
    { 0x6D84, "intel_level" },
    { 0x6D85, "intel_think" },
    { 0x6D86, "intel_upload_text" },
    { 0x6D87, "intel_waypoint_request" },
    { 0x6D88, "intended_target" },
    { 0x6D89, "intensity_01" },
    { 0x6D8A, "intensity_02" },
    { 0x6D8B, "intensity_heat" },
    { 0x6D8C, "intensity_inc" },
    { 0x6D8D, "intensity_ir" },
    { 0x6D8E, "interact" },
    { 0x6D8F, "interact_disabled" },
    { 0x6D90, "interact_door_dopusheffects" },
    { 0x6D91, "interact_door_get_endpoint" },
    { 0x6D92, "interact_door_isplayerfacing" },
    { 0x6D93, "interact_door_ispushentclose" },
    { 0x6D94, "interact_door_setup" },
    { 0x6D95, "interact_entry_anim" },
    { 0x6D96, "interact_getanim" },
    { 0x6D97, "interact_give_control_back" },
    { 0x6D98, "interact_interior_door_hack" },
    { 0x6D99, "interact_interior_door_open" },
    { 0x6D9A, "interact_interior_door_open_remove" },
    { 0x6D9B, "interact_offset" },
    { 0x6D9C, "interact_on_boss_body_timer" },
    { 0x6D9D, "interact_vehicle" },
    { 0x6D9E, "interact_vehicle_animate_door" },
    { 0x6D9F, "interact_vehicle_delete_ground_ref_ent" },
    { 0x6DA0, "interact_vehicle_doors_inactive" },
    { 0x6DA1, "interact_vehicle_doors_state" },
    { 0x6DA2, "interact_vehicle_duck_toggle" },
    { 0x6DA3, "interact_vehicle_inside" },
    { 0x6DA4, "interact_vehicle_mantle_hint" },
    { 0x6DA5, "interact_vehicle_mantle_hint_active" },
    { 0x6DA6, "interact_vehicle_movement" },
    { 0x6DA7, "interact_vehicle_spawn_cover_node" },
    { 0x6DA8, "interactablefinished" },
    { 0x6DA9, "interactables" },
    { 0x6DAA, "interactableterminate" },
    { 0x6DAB, "interactdata" },
    { 0x6DAC, "interacted_with_laptop" },
    { 0x6DAD, "interactendtimes" },
    { 0x6DAE, "interactid" },
    { 0x6DAF, "interaction" },
    { 0x6DB0, "interaction_cooldown" },
    { 0x6DB1, "interaction_cooldown_timer" },
    { 0x6DB2, "interaction_disable_on_exit" },
    { 0x6DB3, "interaction_end" },
    { 0x6DB4, "interaction_end_cheap" },
    { 0x6DB5, "interaction_fail_internal" },
    { 0x6DB6, "interaction_follow_process" },
    { 0x6DB7, "interaction_handle" },
    { 0x6DB8, "interaction_hintstrings" },
    { 0x6DB9, "interaction_immediate_process" },
    { 0x6DBA, "interaction_is_atm" },
    { 0x6DBB, "interaction_is_button_mash" },
    { 0x6DBC, "interaction_is_chess_piece" },
    { 0x6DBD, "interaction_is_chi_door" },
    { 0x6DBE, "interaction_is_crafting_station" },
    { 0x6DBF, "interaction_is_door_buy" },
    { 0x6DC0, "interaction_is_fortune_teller" },
    { 0x6DC1, "interaction_is_grenade_wall_buy" },
    { 0x6DC2, "interaction_is_perk" },
    { 0x6DC3, "interaction_is_pvpve_weapon_pickup" },
    { 0x6DC4, "interaction_is_special_door_buy" },
    { 0x6DC5, "interaction_is_ticket_buy" },
    { 0x6DC6, "interaction_is_trap" },
    { 0x6DC7, "interaction_is_valid" },
    { 0x6DC8, "interaction_is_weapon_buy" },
    { 0x6DC9, "interaction_is_weapon_pickup" },
    { 0x6DCA, "interaction_is_weapon_upgrade" },
    { 0x6DCB, "interaction_is_window_entrance" },
    { 0x6DCC, "interaction_manager" },
    { 0x6DCD, "interaction_manager_init" },
    { 0x6DCE, "interaction_name" },
    { 0x6DCF, "interaction_pain" },
    { 0x6DD0, "interaction_pain_listener" },
    { 0x6DD1, "interaction_post_activate_delay" },
    { 0x6DD2, "interaction_post_activate_update" },
    { 0x6DD3, "interaction_post_activate_update_func" },
    { 0x6DD4, "interaction_process" },
    { 0x6DD5, "interaction_process_blended" },
    { 0x6DD6, "interaction_process_for_states" },
    { 0x6DD7, "interaction_purchase_weapon" },
    { 0x6DD8, "interaction_reboot_timer" },
    { 0x6DD9, "interaction_set_anim_movement" },
    { 0x6DDA, "interaction_setups_array" },
    { 0x6DDB, "interaction_show_fail_reason" },
    { 0x6DDC, "interaction_sound_monitor" },
    { 0x6DDD, "interaction_trigger" },
    { 0x6DDE, "interaction_trigger_properties" },
    { 0x6DDF, "interaction_trigger_properties_func" },
    { 0x6DE0, "interaction_upgrade_weapon" },
    { 0x6DE1, "interaction_use_think" },
    { 0x6DE2, "interaction_waiting_on_power" },
    { 0x6DE3, "interaction1" },
    { 0x6DE4, "interaction2" },
    { 0x6DE5, "interaction3" },
    { 0x6DE6, "interaction4" },
    { 0x6DE7, "interactionanimlength" },
    { 0x6DE8, "interactionhasactivation" },
    { 0x6DE9, "interactionready" },
    { 0x6DEA, "interactions" },
    { 0x6DEB, "interactions_disabled" },
    { 0x6DEC, "interactionstruct" },
    { 0x6DED, "interactiontriggers" },
    { 0x6DEE, "interactive_addusedcallback" },
    { 0x6DEF, "interactive_addusedcallbacktoentity" },
    { 0x6DF0, "interactive_door_force_open" },
    { 0x6DF1, "interactive_door_lock_one_side" },
    { 0x6DF2, "interactive_doors" },
    { 0x6DF3, "interactive_double_door_force_open" },
    { 0x6DF4, "interactive_landanim" },
    { 0x6DF5, "interactive_number" },
    { 0x6DF6, "interactive_removeusedcallbackfromentity" },
    { 0x6DF7, "interactive_takeoffanim" },
    { 0x6DF8, "interactive_type" },
    { 0x6DF9, "interactive_used_func_id" },
    { 0x6DFA, "interactive_used_funcs" },
    { 0x6DFB, "interactive_used_funcs_unique_id" },
    { 0x6DFC, "interactivecombat" },
    { 0x6DFD, "interactivecombatduration" },
    { 0x6DFE, "interactivecombatmessaging" },
    { 0x6DFF, "interactiveelement" },
    { 0x6E00, "interactiveinfil" },
    { 0x6E01, "interactiveinfilstart" },
    { 0x6E02, "interactiveinfilthink" },
    { 0x6E03, "interactiveinfilwindow" },
    { 0x6E04, "interactivekeypairs" },
    { 0x6E05, "interactives" },
    { 0x6E06, "interactives_drawdebuglinefortime" },
    { 0x6E07, "interacts" },
    { 0x6E08, "interactsquads" },
    { 0x6E09, "interactstate" },
    { 0x6E0A, "interactswithgivenoobtrigger" },
    { 0x6E0B, "interactswithoobtriggers" },
    { 0x6E0C, "interactteam" },
    { 0x6E0D, "interactteams" },
    { 0x6E0E, "interacttimedvar" },
    { 0x6E0F, "interacttimes" },
    { 0x6E10, "interacttype" },
    { 0x6E11, "interactuseobj" },
    { 0x6E12, "intercept_mode_get_target_in_circle_omnvar_value" },
    { 0x6E13, "interceptor_missile" },
    { 0x6E14, "interceptor_missile_death_monitor" },
    { 0x6E15, "interceptor_missile_explodes_with_target" },
    { 0x6E16, "interceptor_missile_objective_id" },
    { 0x6E17, "interceptor_missiles" },
    { 0x6E18, "interior" },
    { 0x6E19, "interior_dof_monitor" },
    { 0x6E1A, "interior_enemy_watcher" },
    { 0x6E1B, "interior_price_settings" },
    { 0x6E1C, "interior_sfx" },
    { 0x6E1D, "interior_volumes" },
    { 0x6E1E, "interiorlight" },
    { 0x6E1F, "interiorlights" },
    { 0x6E20, "interiors_init" },
    { 0x6E21, "intermissionfunc" },
    { 0x6E22, "internal_aim_at_laser_tracker" },
    { 0x6E23, "internal_aim_occlusion_override" },
    { 0x6E24, "internal_civglancedownpath" },
    { 0x6E25, "internal_create_debug_data" },
    { 0x6E26, "internal_entitytolookat" },
    { 0x6E27, "internal_hint_toggle_use_by_angles" },
    { 0x6E28, "internal_magic_gun_track_target" },
    { 0x6E29, "internal_mg_forward" },
    { 0x6E2A, "internal_mg_left_vector" },
    { 0x6E2B, "internal_move_scripted_door" },
    { 0x6E2C, "internal_pack_default_trace" },
    { 0x6E2D, "internal_play_overwatch_vo" },
    { 0x6E2E, "internal_reclaimworldid" },
    { 0x6E2F, "internal_useholdthinkloop" },
    { 0x6E30, "internal_wait_for_any_flag_or_time_elapses" },
    { 0x6E31, "interrogate_guy" },
    { 0x6E32, "interrogating" },
    { 0x6E33, "interrogation" },
    { 0x6E34, "interrogation_abandon_handler" },
    { 0x6E35, "interrogation_abandon_outro" },
    { 0x6E36, "interrogation_abandon_price_nag" },
    { 0x6E37, "interrogation_actor_setup" },
    { 0x6E38, "interrogation_anim_setup" },
    { 0x6E39, "interrogation_anim_think" },
    { 0x6E3A, "interrogation_chair_anim_setup" },
    { 0x6E3B, "interrogation_cine_letterboxing" },
    { 0x6E3C, "interrogation_cine_skip" },
    { 0x6E3D, "interrogation_cine_start" },
    { 0x6E3E, "interrogation_disengage" },
    { 0x6E3F, "interrogation_dof_settings" },
    { 0x6E40, "interrogation_door_anim_setup" },
    { 0x6E41, "interrogation_end" },
    { 0x6E42, "interrogation_family_escort" },
    { 0x6E43, "interrogation_init" },
    { 0x6E44, "interrogation_intro" },
    { 0x6E45, "interrogation_intro_camera" },
    { 0x6E46, "interrogation_intro_catchup" },
    { 0x6E47, "interrogation_intro_init" },
    { 0x6E48, "interrogation_intro_start" },
    { 0x6E49, "interrogation_main" },
    { 0x6E4A, "interrogation_outro_blackoverlay_delay" },
    { 0x6E4B, "interrogation_outro_camera" },
    { 0x6E4C, "interrogation_outro_dialogue" },
    { 0x6E4D, "interrogation_outro_dof" },
    { 0x6E4E, "interrogation_phase_dry_fire" },
    { 0x6E4F, "interrogation_phase_final" },
    { 0x6E50, "interrogation_phase_revolver" },
    { 0x6E51, "interrogation_remove_fov_user_scale" },
    { 0x6E52, "interrogation_revolver_start" },
    { 0x6E53, "interrogation_rig_disable" },
    { 0x6E54, "interrogation_rig_disable_instant" },
    { 0x6E55, "interrogation_rig_enable" },
    { 0x6E56, "interrogation_room_catchup" },
    { 0x6E57, "interrogation_room_door_close" },
    { 0x6E58, "interrogation_room_door_open" },
    { 0x6E59, "interrogation_room_start" },
    { 0x6E5A, "interrogation_room_vo_pause_monitor" },
    { 0x6E5B, "interrogation_setup" },
    { 0x6E5C, "interrogation_stp_main" },
    { 0x6E5D, "interrogation_van_light_on" },
    { 0x6E5E, "interrogation_welcome_note" },
    { 0x6E5F, "interrogationdoor" },
    { 0x6E60, "interrogator" },
    { 0x6E61, "interrogator_dmg_think" },
    { 0x6E62, "interrogator_should_hunt" },
    { 0x6E63, "interrogator_stealth_filter" },
    { 0x6E64, "interrupt_anime" },
    { 0x6E65, "interrupt_current_vo" },
    { 0x6E66, "interrupt_first_frame" },
    { 0x6E67, "interrupt_marine_vo" },
    { 0x6E68, "interrupt_sound" },
    { 0x6E69, "interrupt_vo" },
    { 0x6E6A, "interruptable" },
    { 0x6E6B, "interruptabletaunts" },
    { 0x6E6C, "interruptblocker" },
    { 0x6E6D, "interrupted" },
    { 0x6E6E, "interruptedent" },
    { 0x6E6F, "interrupter" },
    { 0x6E70, "interruptnotify" },
    { 0x6E71, "interruptrepeatcount" },
    { 0x6E72, "interupted" },
    { 0x6E73, "intialvalueisvalid" },
    { 0x6E74, "intimetobeat" },
    { 0x6E75, "intimidate_setup" },
    { 0x6E76, "intransit" },
    { 0x6E77, "intro" },
    { 0x6E78, "intro_actors_to_idle" },
    { 0x6E79, "intro_alley_aq_handler" },
    { 0x6E7A, "intro_alley_aq_setup" },
    { 0x6E7B, "intro_alley_guard_setup" },
    { 0x6E7C, "intro_anim_force_stop" },
    { 0x6E7D, "intro_animatedpropscleanuplogic" },
    { 0x6E7E, "intro_animation" },
    { 0x6E7F, "intro_animnode" },
    { 0x6E80, "intro_anims_allies" },
    { 0x6E81, "intro_anims_car2" },
    { 0x6E82, "intro_anims_car2_scene" },
    { 0x6E83, "intro_anims_non_ai" },
    { 0x6E84, "intro_anims_standoff" },
    { 0x6E85, "intro_back_alley_enforcer_setup" },
    { 0x6E86, "intro_background_traffic" },
    { 0x6E87, "intro_bus" },
    { 0x6E88, "intro_camera_handler" },
    { 0x6E89, "intro_camera_letterbox_end" },
    { 0x6E8A, "intro_car" },
    { 0x6E8B, "intro_car_anims" },
    { 0x6E8C, "intro_car1_anims" },
    { 0x6E8D, "intro_car1_version1" },
    { 0x6E8E, "intro_car1_version2" },
    { 0x6E8F, "intro_car2_anims" },
    { 0x6E90, "intro_cars" },
    { 0x6E91, "intro_cars_extra" },
    { 0x6E92, "intro_catchup" },
    { 0x6E93, "intro_checks" },
    { 0x6E94, "intro_chopper" },
    { 0x6E95, "intro_civ_alterations" },
    { 0x6E96, "intro_civ_anims" },
    { 0x6E97, "intro_civ_background" },
    { 0x6E98, "intro_civ_background_idle" },
    { 0x6E99, "intro_civ_oneoff" },
    { 0x6E9A, "intro_civ_post_anims" },
    { 0x6E9B, "intro_civ_post_setup" },
    { 0x6E9C, "intro_civ_setup" },
    { 0x6E9D, "intro_civs" },
    { 0x6E9E, "intro_convoy_vfx" },
    { 0x6E9F, "intro_dialogue" },
    { 0x6EA0, "intro_dialogue_handler" },
    { 0x6EA1, "intro_dialoguejokesectionalogic" },
    { 0x6EA2, "intro_dialoguejokesectionblogic" },
    { 0x6EA3, "intro_dofcar" },
    { 0x6EA4, "intro_dofnear" },
    { 0x6EA5, "intro_doftruck" },
    { 0x6EA6, "intro_driver_handler" },
    { 0x6EA7, "intro_end" },
    { 0x6EA8, "intro_ents" },
    { 0x6EA9, "intro_ents_add" },
    { 0x6EAA, "intro_fake_player_handler" },
    { 0x6EAB, "intro_farah_handler" },
    { 0x6EAC, "intro_flarelogic" },
    { 0x6EAD, "intro_flareturnon" },
    { 0x6EAE, "intro_fovlerp" },
    { 0x6EAF, "intro_gate_disable_sprint" },
    { 0x6EB0, "intro_gate_handler" },
    { 0x6EB1, "intro_gateguy_handler" },
    { 0x6EB2, "intro_gesture" },
    { 0x6EB3, "intro_getanimatedallies" },
    { 0x6EB4, "intro_getanimatedfarahscope" },
    { 0x6EB5, "intro_getanimatedhadirsniper" },
    { 0x6EB6, "intro_getanimationstruct" },
    { 0x6EB7, "intro_getbomb" },
    { 0x6EB8, "intro_getcinderblockanimations" },
    { 0x6EB9, "intro_getflare" },
    { 0x6EBA, "intro_getstairscrateanimations" },
    { 0x6EBB, "intro_griggs_handler" },
    { 0x6EBC, "intro_hadir_handler" },
    { 0x6EBD, "intro_hadirscenelogic" },
    { 0x6EBE, "intro_helicopter_1" },
    { 0x6EBF, "intro_helicopter_2" },
    { 0x6EC0, "intro_helicopter_3" },
    { 0x6EC1, "intro_helicopter_flyby" },
    { 0x6EC2, "intro_helicopter_init" },
    { 0x6EC3, "intro_hidebody" },
    { 0x6EC4, "intro_hidehead" },
    { 0x6EC5, "intro_letterbox_removal" },
    { 0x6EC6, "intro_lights" },
    { 0x6EC7, "intro_lights_cleanup" },
    { 0x6EC8, "intro_lights_setup_omni" },
    { 0x6EC9, "intro_london_bink" },
    { 0x6ECA, "intro_main" },
    { 0x6ECB, "intro_marine_poi_handler" },
    { 0x6ECC, "intro_marine01_handler" },
    { 0x6ECD, "intro_marine02_handler" },
    { 0x6ECE, "intro_marine03_handler" },
    { 0x6ECF, "intro_mortar_tube" },
    { 0x6ED0, "intro_movie" },
    { 0x6ED1, "intro_music" },
    { 0x6ED2, "intro_offset" },
    { 0x6ED3, "intro_origin" },
    { 0x6ED4, "intro_phone_peek" },
    { 0x6ED5, "intro_plankanimationscenecratelogic" },
    { 0x6ED6, "intro_plankanimationscenelogic" },
    { 0x6ED7, "intro_playerspeedscalinglogic" },
    { 0x6ED8, "intro_remove_fov_scale_factor_override" },
    { 0x6ED9, "intro_remove_fov_user_scale" },
    { 0x6EDA, "intro_roof_peek" },
    { 0x6EDB, "intro_scene_bink" },
    { 0x6EDC, "intro_scene_binocs" },
    { 0x6EDD, "intro_scene_butcher_aq" },
    { 0x6EDE, "intro_scene_camera" },
    { 0x6EDF, "intro_scene_end" },
    { 0x6EE0, "intro_scene_end_skip" },
    { 0x6EE1, "intro_scene_fake_player" },
    { 0x6EE2, "intro_scene_guncase" },
    { 0x6EE3, "intro_scene_mayhem" },
    { 0x6EE4, "intro_scene_nikolai" },
    { 0x6EE5, "intro_scene_player" },
    { 0x6EE6, "intro_scene_price" },
    { 0x6EE7, "intro_scene_skip" },
    { 0x6EE8, "intro_scene_truck_sound" },
    { 0x6EE9, "intro_scenealogic" },
    { 0x6EEA, "intro_sceneblogic" },
    { 0x6EEB, "intro_sceneclogic" },
    { 0x6EEC, "intro_screen" },
    { 0x6EED, "intro_screen_create" },
    { 0x6EEE, "intro_screen_custom_func" },
    { 0x6EEF, "intro_screen_delay" },
    { 0x6EF0, "intro_screen_wait" },
    { 0x6EF1, "intro_setup" },
    { 0x6EF2, "intro_setupanimatedfarahscope" },
    { 0x6EF3, "intro_setvolumetricdepth" },
    { 0x6EF4, "intro_skip_monitor" },
    { 0x6EF5, "intro_slamzoom" },
    { 0x6EF6, "intro_sledge_put_away" },
    { 0x6EF7, "intro_spawnanimatedcinderblockallies" },
    { 0x6EF8, "intro_spawnanimatedphoneally" },
    { 0x6EF9, "intro_spawnanimatedstairsally" },
    { 0x6EFA, "intro_spawnbomb" },
    { 0x6EFB, "intro_spawnflare" },
    { 0x6EFC, "intro_stairsanimationscenelogic" },
    { 0x6EFD, "intro_stairsanimationwaittillscene" },
    { 0x6EFE, "intro_stakeout_dmg_trig_monitor" },
    { 0x6EFF, "intro_stakeout_door_clip" },
    { 0x6F00, "intro_stakeout_enemy_monitor" },
    { 0x6F01, "intro_stakeout_fire_weapon_check" },
    { 0x6F02, "intro_stakeout_holster_weapon_check" },
    { 0x6F03, "intro_stakeout_kitchen_clip" },
    { 0x6F04, "intro_stakeout_landing_clip" },
    { 0x6F05, "intro_stakeout_main" },
    { 0x6F06, "intro_stakeout_player_movement" },
    { 0x6F07, "intro_stakeout_player_muzzle_discipline" },
    { 0x6F08, "intro_stakeout_stairs_clip" },
    { 0x6F09, "intro_stakeout_swap_butcher_vehicle" },
    { 0x6F0A, "intro_stakeout_wait_swap_butcher_vehicle" },
    { 0x6F0B, "intro_stakeout_weapon_select" },
    { 0x6F0C, "intro_stakeout_window_monitor" },
    { 0x6F0D, "intro_standoff" },
    { 0x6F0E, "intro_standoff_nag" },
    { 0x6F0F, "intro_start" },
    { 0x6F10, "intro_started" },
    { 0x6F11, "intro_stop_car_if_too_close" },
    { 0x6F12, "intro_street_lamps" },
    { 0x6F13, "intro_street_marine_group_a_advance_scene" },
    { 0x6F14, "intro_street_marine_group_b_advance_scene" },
    { 0x6F15, "intro_street_marine_group_c_advance_scene" },
    { 0x6F16, "intro_street_player_movement" },
    { 0x6F17, "intro_technical" },
    { 0x6F18, "intro_tripwire_defused_monitor" },
    { 0x6F19, "intro_truck_anims" },
    { 0x6F1A, "intro_truck_fx" },
    { 0x6F1B, "intro_truck_handler" },
    { 0x6F1C, "intro_truck_treadfx_handler" },
    { 0x6F1D, "intro_velocity" },
    { 0x6F1E, "intro_vo_civs" },
    { 0x6F1F, "intro_windows" },
    { 0x6F20, "introdoorbreachmarines" },
    { 0x6F21, "intromodel" },
    { 0x6F22, "intronode" },
    { 0x6F23, "introscreen" },
    { 0x6F24, "introscreen_corner_line" },
    { 0x6F25, "introscreen_delayed" },
    { 0x6F26, "introscreen_done" },
    { 0x6F27, "introscreen_overlay" },
    { 0x6F28, "introscreen_text_func" },
    { 0x6F29, "introsequence" },
    { 0x6F2A, "introsequence_marinewinner" },
    { 0x6F2B, "introsequence_opforwinner" },
    { 0x6F2C, "introsunangles" },
    { 0x6F2D, "introtag" },
    { 0x6F2E, "introvisionset" },
    { 0x6F2F, "intvar" },
    { 0x6F30, "inuse" },
    { 0x6F31, "inuseby" },
    { 0x6F32, "invalid" },
    { 0x6F33, "invalid_drop_weapons" },
    { 0x6F34, "invalid_gameobject_mover" },
    { 0x6F35, "invalid_gesture_weapon" },
    { 0x6F36, "invalid_path_points" },
    { 0x6F37, "invalid_spawn_volume_array" },
    { 0x6F38, "invalidattachmentwarning" },
    { 0x6F39, "invaliditems" },
    { 0x6F3A, "invalidparentoverridecallback" },
    { 0x6F3B, "invehicle" },
    { 0x6F3C, "inventory_array" },
    { 0x6F3D, "inventory_nag" },
    { 0x6F3E, "inventoryweapon" },
    { 0x6F3F, "inverted_pop_up" },
    { 0x6F40, "investgate_entity" },
    { 0x6F41, "investigate_entity" },
    { 0x6F42, "investigate_fusebox" },
    { 0x6F43, "investigate_getcorpseoffsetpos" },
    { 0x6F44, "investigate_getinitialpos" },
    { 0x6F45, "investigate_getuninvestigatedpos" },
    { 0x6F46, "investigate_init" },
    { 0x6F47, "investigate_lookaround" },
    { 0x6F48, "investigate_lookaround_init" },
    { 0x6F49, "investigate_lookaround_terminate" },
    { 0x6F4A, "investigate_move" },
    { 0x6F4B, "investigate_move_init" },
    { 0x6F4C, "investigate_move_setaimtarget" },
    { 0x6F4D, "investigate_move_terminate" },
    { 0x6F4E, "investigate_move_updateaimtarget" },
    { 0x6F4F, "investigate_oil_fire" },
    { 0x6F50, "investigate_point" },
    { 0x6F51, "investigate_pos" },
    { 0x6F52, "investigate_sanitycheckinitialpos" },
    { 0x6F53, "investigate_setreaction" },
    { 0x6F54, "investigate_setupruntocorpse" },
    { 0x6F55, "investigate_severity" },
    { 0x6F56, "investigate_shouldfacedecentdirectionwhenidle" },
    { 0x6F57, "investigate_someone_using_bomb_update" },
    { 0x6F58, "investigate_targetedlookaround" },
    { 0x6F59, "investigate_terminate" },
    { 0x6F5A, "investigate_updateeveryframe" },
    { 0x6F5B, "investigate_use_think" },
    { 0x6F5C, "investigate_volumes" },
    { 0x6F5D, "investigatealias" },
    { 0x6F5E, "investigatecallin" },
    { 0x6F5F, "investigateendtime" },
    { 0x6F60, "investigateevent" },
    { 0x6F61, "investigateevent_time" },
    { 0x6F62, "investigatemaxtime" },
    { 0x6F63, "investigatemintime" },
    { 0x6F64, "investigateoriginguy" },
    { 0x6F65, "investigatepoints" },
    { 0x6F66, "investigating" },
    { 0x6F67, "investigating_friendly_corpse" },
    { 0x6F68, "investigators" },
    { 0x6F69, "invisibleoutlineid" },
    { 0x6F6A, "invulnerabilityframe" },
    { 0x6F6B, "invulnerable" },
    { 0x6F6C, "invultime_deathshieldduration" },
    { 0x6F6D, "invultime_ondamage" },
    { 0x6F6E, "invultime_ondamagemax" },
    { 0x6F6F, "invultime_ondamagemin" },
    { 0x6F70, "invultime_onshield" },
    { 0x6F71, "invultime_postshield" },
    { 0x6F72, "invultime_preshield" },
    { 0x6F73, "ips_to_mph" },
    { 0x6F74, "irish_luck_choose_random_consumable" },
    { 0x6F75, "irish_luck_consumables" },
    { 0x6F76, "irish_luck_consumables_gotten" },
    { 0x6F77, "is_above_player_in_shaft" },
    { 0x6F78, "is_action_slot_weapon_allowed" },
    { 0x6F79, "is_active_chained_oil_fire" },
    { 0x6F7A, "is_ads_allowed" },
    { 0x6F7B, "is_afflicted" },
    { 0x6F7C, "is_after_start" },
    { 0x6F7D, "is_agent_in_group" },
    { 0x6F7E, "is_agent_scripted" },
    { 0x6F7F, "is_aimed_at_enemy" },
    { 0x6F80, "is_aimed_at_target" },
    { 0x6F81, "is_aiming" },
    { 0x6F82, "is_aimming_at_enemy" },
    { 0x6F83, "is_aimming_forward" },
    { 0x6F84, "is_alien_agent" },
    { 0x6F85, "is_allowed_to_be_flashed" },
    { 0x6F86, "is_allowed_to_be_stunned" },
    { 0x6F87, "is_always_on_group" },
    { 0x6F88, "is_ambient_idle_struct" },
    { 0x6F89, "is_ambient_scene" },
    { 0x6F8A, "is_anim_enemy_engaging_player" },
    { 0x6F8B, "is_antigrav_float_allowed" },
    { 0x6F8C, "is_arc_death" },
    { 0x6F8D, "is_arcane_attachment" },
    { 0x6F8E, "is_armor_allowed" },
    { 0x6F8F, "is_armored" },
    { 0x6F90, "is_auto_brush_entity" },
    { 0x6F91, "is_autoreload_allowed" },
    { 0x6F92, "is_b_better_defender" },
    { 0x6F93, "is_bad_path" },
    { 0x6F94, "is_being_revived" },
    { 0x6F95, "is_blocking_tank" },
    { 0x6F96, "is_bomb_planted_on" },
    { 0x6F97, "is_burning" },
    { 0x6F98, "is_capturing_current_headquarters" },
    { 0x6F99, "is_capturing_zone" },
    { 0x6F9A, "is_casual_mode" },
    { 0x6F9B, "is_cg_drawcrosshair_allowed" },
    { 0x6F9C, "is_cheap" },
    { 0x6F9D, "is_chem_burning" },
    { 0x6F9E, "is_cinematic_motion_allowed" },
    { 0x6F9F, "is_civilian" },
    { 0x6FA0, "is_clear_in_front" },
    { 0x6FA1, "is_clientmatchdata_data" },
    { 0x6FA2, "is_clientmatchdata_struct" },
    { 0x6FA3, "is_clip_nosight" },
    { 0x6FA4, "is_cloaking" },
    { 0x6FA5, "is_close_to_player_z" },
    { 0x6FA6, "is_cluster_spawner_ideal_distance" },
    { 0x6FA7, "is_coaster_zombie" },
    { 0x6FA8, "is_codxp" },
    { 0x6FA9, "is_collected" },
    { 0x6FAA, "is_combat_cooled_down" },
    { 0x6FAB, "is_command_bound" },
    { 0x6FAC, "is_completed" },
    { 0x6FAD, "is_consumable_active" },
    { 0x6FAE, "is_controlled" },
    { 0x6FAF, "is_controlling_uav" },
    { 0x6FB0, "is_convoy" },
    { 0x6FB1, "is_correct_bomb_id" },
    { 0x6FB2, "is_cough_gesture_allowed" },
    { 0x6FB3, "is_crafted_trap_damage" },
    { 0x6FB4, "is_crate_use_allowed" },
    { 0x6FB5, "is_createfx_type" },
    { 0x6FB6, "is_critical_ai_target" },
    { 0x6FB7, "is_crouch_allowed" },
    { 0x6FB8, "is_cs_model" },
    { 0x6FB9, "is_cs_trigger" },
    { 0x6FBA, "is_cut" },
    { 0x6FBB, "is_damagefeedback_enabled" },
    { 0x6FBC, "is_dark" },
    { 0x6FBD, "is_daylight_savings" },
    { 0x6FBE, "is_dead_or_dying" },
    { 0x6FBF, "is_dead_sentient" },
    { 0x6FC0, "is_death_allowed" },
    { 0x6FC1, "is_deathsdoor_audio_enabled" },
    { 0x6FC2, "is_deck" },
    { 0x6FC3, "is_default_attachment" },
    { 0x6FC4, "is_default_start" },
    { 0x6FC5, "is_defusing" },
    { 0x6FC6, "is_demo" },
    { 0x6FC7, "is_demo_python_anime" },
    { 0x6FC8, "is_detonated" },
    { 0x6FC9, "is_dialogue_on_cooldown" },
    { 0x6FCA, "is_different_target" },
    { 0x6FCB, "is_divisible_by" },
    { 0x6FCC, "is_dof_script_enabled" },
    { 0x6FCD, "is_doing_infil" },
    { 0x6FCE, "is_door_already_open" },
    { 0x6FCF, "is_door_spawn" },
    { 0x6FD0, "is_double_door" },
    { 0x6FD1, "is_doublejump_allowed" },
    { 0x6FD2, "is_electrified" },
    { 0x6FD3, "is_elite_attack" },
    { 0x6FD4, "is_emp_damage" },
    { 0x6FD5, "is_emp_weapon" },
    { 0x6FD6, "is_empd" },
    { 0x6FD7, "is_empty_or_none" },
    { 0x6FD8, "is_empty_string" },
    { 0x6FD9, "is_enemy_highest_score" },
    { 0x6FDA, "is_enemy_onscreen" },
    { 0x6FDB, "is_enforcer_target" },
    { 0x6FDC, "is_enforcer_threatened" },
    { 0x6FDD, "is_ent_filtered_out" },
    { 0x6FDE, "is_ent_or_struct" },
    { 0x6FDF, "is_equal" },
    { 0x6FE0, "is_equipment_slot_allowed" },
    { 0x6FE1, "is_event_active" },
    { 0x6FE2, "is_event_completed" },
    { 0x6FE3, "is_event_repeating" },
    { 0x6FE4, "is_explosive_damage" },
    { 0x6FE5, "is_explosive_kill" },
    { 0x6FE6, "is_explosivedamage" },
    { 0x6FE7, "is_eye_tracking" },
    { 0x6FE8, "is_fact_str" },
    { 0x6FE9, "is_fakeactor" },
    { 0x6FEA, "is_fakeactor_node" },
    { 0x6FEB, "is_fast_traveling" },
    { 0x6FEC, "is_fire_allowed" },
    { 0x6FED, "is_first_start" },
    { 0x6FEE, "is_first_vehicle_in_convoy" },
    { 0x6FEF, "is_flare_on_ground" },
    { 0x6FF0, "is_flash_weapon" },
    { 0x6FF1, "is_flashbang" },
    { 0x6FF2, "is_flir_vision_on" },
    { 0x6FF3, "is_footstep_react" },
    { 0x6FF4, "is_frantic" },
    { 0x6FF5, "is_friendly_damage" },
    { 0x6FF6, "is_friendly_dmg" },
    { 0x6FF7, "is_friendly_fire" },
    { 0x6FF8, "is_friendlyfire_event" },
    { 0x6FF9, "is_from_animsound" },
    { 0x6FFA, "is_gas" },
    { 0x6FFB, "is_goal_reached_func" },
    { 0x6FFC, "is_goal_volume_ahead_of_vehicle_to_push" },
    { 0x6FFD, "is_godmode" },
    { 0x6FFE, "is_goon" },
    { 0x6FFF, "is_grenade_near_cursor_hint" },
    { 0x7000, "is_group_active" },
    { 0x7001, "is_group_dead" },
    { 0x7002, "is_gun_raised" },
    { 0x7003, "is_hands_allowed" },
    { 0x7004, "is_hardcore_mode" },
    { 0x7005, "is_head_tracking" },
    { 0x7006, "is_health_regen_allowed" },
    { 0x7007, "is_heirarchy_good" },
    { 0x7008, "is_helmet_spawn" },
    { 0x7009, "is_hero_player_within_reticle" },
    { 0x700A, "is_hidden_from_heli" },
    { 0x700B, "is_higher_priority" },
    { 0x700C, "is_hive_explosion" },
    { 0x700D, "is_holding_deployable" },
    { 0x700E, "is_holding_pistol" },
    { 0x700F, "is_human" },
    { 0x7010, "is_idle" },
    { 0x7011, "is_ied_identified" },
    { 0x7012, "is_ignore_claimed" },
    { 0x7013, "is_in_active_volume" },
    { 0x7014, "is_in_adjacent_volume" },
    { 0x7015, "is_in_antigrav_grenade" },
    { 0x7016, "is_in_array" },
    { 0x7017, "is_in_callable_location" },
    { 0x7018, "is_in_combat" },
    { 0x7019, "is_in_combat_volume" },
    { 0x701A, "is_in_pap" },
    { 0x701B, "is_incompatible_weapon" },
    { 0x701C, "is_indoor_map" },
    { 0x701D, "is_indoors" },
    { 0x701E, "is_indoors_vehicleignored" },
    { 0x701F, "is_input_allowed_internal" },
    { 0x7020, "is_interact_node" },
    { 0x7021, "is_interact_struct" },
    { 0x7022, "is_interaction" },
    { 0x7023, "is_invulnerable_from_ai" },
    { 0x7024, "is_jugg_dead" },
    { 0x7025, "is_juggernaut_aitype" },
    { 0x7026, "is_jump_allowed" },
    { 0x7027, "is_killed_by_kill_trigger" },
    { 0x7028, "is_killstreak_weapon" },
    { 0x7029, "is_killstreaks_allowed" },
    { 0x702A, "is_ladder_placement_allowed" },
    { 0x702B, "is_last_none_player_vehicle_in_convoy" },
    { 0x702C, "is_lastlevel" },
    { 0x702D, "is_launcher" },
    { 0x702E, "is_lean_allowed" },
    { 0x702F, "is_left_door" },
    { 0x7030, "is_level_escalation_sufficient" },
    { 0x7031, "is_light" },
    { 0x7032, "is_light_entity" },
    { 0x7033, "is_lightswitch" },
    { 0x7034, "is_linked_struct" },
    { 0x7035, "is_linked_to_target" },
    { 0x7036, "is_locked" },
    { 0x7037, "is_looking_at" },
    { 0x7038, "is_looking_at_range" },
    { 0x7039, "is_mantle_allowed" },
    { 0x703A, "is_map_using_locales_only" },
    { 0x703B, "is_matchdata_struct" },
    { 0x703C, "is_melee_allowed" },
    { 0x703D, "is_melee_weapon" },
    { 0x703E, "is_mod_attachment" },
    { 0x703F, "is_molotov_barrel" },
    { 0x7040, "is_mount_side_allowed" },
    { 0x7041, "is_mount_top_allowed" },
    { 0x7042, "is_moving" },
    { 0x7043, "is_mp" },
    { 0x7044, "is_my_group_an_active_module" },
    { 0x7045, "is_near" },
    { 0x7046, "is_near_long_death_pos" },
    { 0x7047, "is_new_target" },
    { 0x7048, "is_new_weapon" },
    { 0x7049, "is_no_game_start" },
    { 0x704A, "is_no_nerf" },
    { 0x704B, "is_no_squad" },
    { 0x704C, "is_normal_upright" },
    { 0x704D, "is_not_safe_from_smoke" },
    { 0x704E, "is_nvg_allowed" },
    { 0x704F, "is_nvg_off" },
    { 0x7050, "is_nvg_on" },
    { 0x7051, "is_objective_active" },
    { 0x7052, "is_obstacle_in_way" },
    { 0x7053, "is_offhand_primary_weapons_allowed" },
    { 0x7054, "is_offhand_secondary_weapons_allowed" },
    { 0x7055, "is_offhand_shield_weapons_allowed" },
    { 0x7056, "is_offhand_weapons_allowed" },
    { 0x7057, "is_on_platform" },
    { 0x7058, "is_on_technical_path" },
    { 0x7059, "is_one_hit_melee_victim_allowed" },
    { 0x705A, "is_outlined_from_scoperadar" },
    { 0x705B, "is_p_ent" },
    { 0x705C, "is_pacifist" },
    { 0x705D, "is_pap_attachment" },
    { 0x705E, "is_pap_camo" },
    { 0x705F, "is_part_swapped" },
    { 0x7060, "is_partial" },
    { 0x7061, "is_passive" },
    { 0x7062, "is_patroller" },
    { 0x7063, "is_performing_sequential_scene" },
    { 0x7064, "is_perk_attachment" },
    { 0x7065, "is_permitted_guided_interaction" },
    { 0x7066, "is_place_clear" },
    { 0x7067, "is_planting" },
    { 0x7068, "is_player" },
    { 0x7069, "is_player_allowed_to_airdrop" },
    { 0x706A, "is_player_care_package_owner" },
    { 0x706B, "is_player_carrying_special_item" },
    { 0x706C, "is_player_gamepad_enabled" },
    { 0x706D, "is_player_looking_at" },
    { 0x706E, "is_player_looking_at_camera" },
    { 0x706F, "is_player_looking_at_interact" },
    { 0x7070, "is_player_looking_towards_cart" },
    { 0x7071, "is_player_moving_forward" },
    { 0x7072, "is_player_on_ladder_with_distance_check" },
    { 0x7073, "is_player_part_exposed_to_enemy_turret" },
    { 0x7074, "is_player_part_exposed_to_sniper" },
    { 0x7075, "is_player_playing_dialogue" },
    { 0x7076, "is_player_pushing_stick" },
    { 0x7077, "is_player_using_snakecam" },
    { 0x7078, "is_playing" },
    { 0x7079, "is_playing_alert_music" },
    { 0x707A, "is_playing_pain_breathing_sfx" },
    { 0x707B, "is_playing_random_idle" },
    { 0x707C, "is_playing_reaction" },
    { 0x707D, "is_point_in_any_volume" },
    { 0x707E, "is_point_in_front" },
    { 0x707F, "is_point_on_right" },
    { 0x7080, "is_police" },
    { 0x7081, "is_pos_in_front" },
    { 0x7082, "is_pos_vo_source" },
    { 0x7083, "is_position_in_group" },
    { 0x7084, "is_precalculated_entrance" },
    { 0x7085, "is_primary_equipment_button_down" },
    { 0x7086, "is_primary_equipment_in_use" },
    { 0x7087, "is_primary_melee_weapon" },
    { 0x7088, "is_prone_allowed" },
    { 0x7089, "is_protecting_current_headquarters" },
    { 0x708A, "is_protecting_flag" },
    { 0x708B, "is_protecting_zone" },
    { 0x708C, "is_pushed" },
    { 0x708D, "is_pushing_vehicle" },
    { 0x708E, "is_putting_on_disguise" },
    { 0x708F, "is_pyramid_spawner" },
    { 0x7090, "is_queue_at_max" },
    { 0x7091, "is_ramming" },
    { 0x7092, "is_red_barrel" },
    { 0x7093, "is_relative_target" },
    { 0x7094, "is_relative_threatened" },
    { 0x7095, "is_relics_enabled" },
    { 0x7096, "is_reload_allowed" },
    { 0x7097, "is_reserved" },
    { 0x7098, "is_respawn_loc_near_alive_enemies" },
    { 0x7099, "is_respawn_loc_near_available_players" },
    { 0x709A, "is_ricochet_damage" },
    { 0x709B, "is_rider" },
    { 0x709C, "is_riding_vehicle" },
    { 0x709D, "is_right_door" },
    { 0x709E, "is_roomtype_valid" },
    { 0x709F, "is_same_group" },
    { 0x70A0, "is_scoring_disabled" },
    { 0x70A1, "is_script_weapon_switch_allowed" },
    { 0x70A2, "is_scriptable_heirarchy_good" },
    { 0x70A3, "is_scripted_agent" },
    { 0x70A4, "is_secondary_equipment_button_down" },
    { 0x70A5, "is_secondary_equipment_in_use" },
    { 0x70A6, "is_segmented_health_regen_disabled" },
    { 0x70A7, "is_self_detonating" },
    { 0x70A8, "is_shellshock_allowed" },
    { 0x70A9, "is_shooting" },
    { 0x70AA, "is_showing_stealth_meter_to" },
    { 0x70AB, "is_skeleton" },
    { 0x70AC, "is_slide_allowed" },
    { 0x70AD, "is_snipe_kill" },
    { 0x70AE, "is_soldier_agent" },
    { 0x70AF, "is_spawner" },
    { 0x70B0, "is_spawner_disabled" },
    { 0x70B1, "is_spawner_ideal_distance" },
    { 0x70B2, "is_spawner_initialized" },
    { 0x70B3, "is_spawner_towards_objective" },
    { 0x70B4, "is_spawnid_a_less_than_b" },
    { 0x70B5, "is_speaking" },
    { 0x70B6, "is_specified_unittype" },
    { 0x70B7, "is_spitter_gas" },
    { 0x70B8, "is_spitter_spit" },
    { 0x70B9, "is_spot_taken" },
    { 0x70BA, "is_sprint_allowed" },
    { 0x70BB, "is_stand_allowed" },
    { 0x70BC, "is_standing" },
    { 0x70BD, "is_state_interact_struct" },
    { 0x70BE, "is_state_interaction" },
    { 0x70BF, "is_stealthy" },
    { 0x70C0, "is_stick_kill_allowed" },
    { 0x70C1, "is_struct_in_front_of_me" },
    { 0x70C2, "is_struct_perk_machine" },
    { 0x70C3, "is_suicide_bomber" },
    { 0x70C4, "is_supers_allowed" },
    { 0x70C5, "is_tactical" },
    { 0x70C6, "is_talking" },
    { 0x70C7, "is_target" },
    { 0x70C8, "is_target_goal_valid" },
    { 0x70C9, "is_target_in_view" },
    { 0x70CA, "is_technical_rider" },
    { 0x70CB, "is_technical_stopped" },
    { 0x70CC, "is_this_a_valid_node" },
    { 0x70CD, "is_too_dense" },
    { 0x70CE, "is_torso_tracking" },
    { 0x70CF, "is_touching_any" },
    { 0x70D0, "is_tower_touching_trigger" },
    { 0x70D1, "is_transient_createart_enabled" },
    { 0x70D2, "is_trap" },
    { 0x70D3, "is_trip_defused" },
    { 0x70D4, "is_true" },
    { 0x70D5, "is_true_print" },
    { 0x70D6, "is_turned" },
    { 0x70D7, "is_unlocked" },
    { 0x70D8, "is_upgrade_enabled" },
    { 0x70D9, "is_upright" },
    { 0x70DA, "is_usability_allowed" },
    { 0x70DB, "is_using_behaviortree" },
    { 0x70DC, "is_using_blackhornet" },
    { 0x70DD, "is_using_extinction_tokens" },
    { 0x70DE, "is_using_flashlight" },
    { 0x70DF, "is_using_forcegoal_radius" },
    { 0x70E0, "is_using_gl" },
    { 0x70E1, "is_using_nvg" },
    { 0x70E2, "is_using_stamina" },
    { 0x70E3, "is_valid_achievement" },
    { 0x70E4, "is_valid_clientside_exploder_name" },
    { 0x70E5, "is_valid_give_type" },
    { 0x70E6, "is_valid_perk" },
    { 0x70E7, "is_valid_player" },
    { 0x70E8, "is_valid_respawn_spawnpoint" },
    { 0x70E9, "is_valid_rule" },
    { 0x70EA, "is_valid_weapon_hit" },
    { 0x70EB, "is_van" },
    { 0x70EC, "is_vehicle_spawner_ideal_distance" },
    { 0x70ED, "is_vehicle_spawnpoint" },
    { 0x70EE, "is_vehicle_use_allowed" },
    { 0x70EF, "is_visible" },
    { 0x70F0, "is_visible_to_player" },
    { 0x70F1, "is_vo_bucket" },
    { 0x70F2, "is_vo_line" },
    { 0x70F3, "is_vo_system_busy" },
    { 0x70F4, "is_vo_system_paused" },
    { 0x70F5, "is_vo_system_playing" },
    { 0x70F6, "is_wallrun_allowed" },
    { 0x70F7, "is_weapon_allowed" },
    { 0x70F8, "is_weapon_first_raise_anims_allowed" },
    { 0x70F9, "is_weapon_pickup_allowed" },
    { 0x70FA, "is_weapon_purchase_disabled" },
    { 0x70FB, "is_weapon_scanning_allowed" },
    { 0x70FC, "is_weapon_switch_allowed" },
    { 0x70FD, "is_weapon_switch_clip_allowed" },
    { 0x70FE, "is_weapon_unlocked" },
    { 0x70FF, "is_wearing_armor" },
    { 0x7100, "is_weight_a_less_than_b" },
    { 0x7101, "is_yelling" },
    { 0x7102, "is_zombie_agent" },
    { 0x7103, "is3d" },
    { 0x7104, "isac130" },
    { 0x7105, "isactivated" },
    { 0x7106, "isactive" },
    { 0x7107, "isactorwallrunning" },
    { 0x7108, "isadestructable" },
    { 0x7109, "isads" },
    { 0x710A, "isaffectedbyblindeye" },
    { 0x710B, "isagent" },
    { 0x710C, "isagentvip" },
    { 0x710D, "isaigameparticipant" },
    { 0x710E, "isaimedataimtarget" },
    { 0x710F, "isaimedsomewhatatenemy" },
    { 0x7110, "isaiming" },
    { 0x7111, "isaimingatreticle" },
    { 0x7112, "isairdenied" },
    { 0x7113, "isairdrop" },
    { 0x7114, "isairdropmarker" },
    { 0x7115, "isairkillstreak" },
    { 0x7116, "isairplane" },
    { 0x7117, "isairplane_internal" },
    { 0x7118, "isairstrikekillstreak" },
    { 0x7119, "isaiteamparticipant" },
    { 0x711A, "isalientrapturret" },
    { 0x711B, "isalienturret" },
    { 0x711C, "isalive" },
    { 0x711D, "isalliedcountryid" },
    { 0x711E, "isalliedmilitarycountryid" },
    { 0x711F, "isally" },
    { 0x7120, "isalternatemode" },
    { 0x7121, "isaltmodeweapon" },
    { 0x7122, "isalwayscoverexposed" },
    { 0x7123, "isambientspawningpaused" },
    { 0x7124, "isammo" },
    { 0x7125, "isanimating" },
    { 0x7126, "isanimblocked" },
    { 0x7127, "isanimdeltaallowed" },
    { 0x7128, "isanymlgmatch" },
    { 0x7129, "isanymonitoredweaponswitchinprogress" },
    { 0x712A, "isanyonealive" },
    { 0x712B, "isanyreliableweaponswitchinprogress" },
    { 0x712C, "isapache" },
    { 0x712D, "isapctooclosetomine" },
    { 0x712E, "isarchetype" },
    { 0x712F, "isarena" },
    { 0x7130, "isarenamap" },
    { 0x7131, "isarmcrate" },
    { 0x7132, "isarmor" },
    { 0x7133, "isarmorbetterthanequipped" },
    { 0x7134, "isarmorplate" },
    { 0x7135, "isarrivaltype" },
    { 0x7136, "isarrivaltypecivilian" },
    { 0x7137, "isasniper" },
    { 0x7138, "isassaultdronekillstreak" },
    { 0x7139, "isassaultkillstreak" },
    { 0x713A, "isatcovernode" },
    { 0x713B, "isattachmentsniperscopedefault" },
    { 0x713C, "isattachmentsniperscopedefaulttokenized" },
    { 0x713D, "isattacker" },
    { 0x713E, "isattackerwithindist" },
    { 0x713F, "isattacking" },
    { 0x7140, "isaxeweapon" },
    { 0x7141, "isbackkill" },
    { 0x7142, "isbadspawn" },
    { 0x7143, "isballdronekillstreak" },
    { 0x7144, "isballweapon" },
    { 0x7145, "isbarrel" },
    { 0x7146, "isbashing" },
    { 0x7147, "isbehindmeleevictim" },
    { 0x7148, "isbeingcaptured" },
    { 0x7149, "isbeingmarked" },
    { 0x714A, "isbeingused" },
    { 0x714B, "isblinded" },
    { 0x714C, "isbombcarrier" },
    { 0x714D, "isbombgametype" },
    { 0x714E, "isbombmode" },
    { 0x714F, "isbombplantweapon" },
    { 0x7150, "isbombsiteweapon" },
    { 0x7151, "isbonus" },
    { 0x7152, "isboosted" },
    { 0x7153, "isboredofnode" },
    { 0x7154, "isbountyevent" },
    { 0x7155, "isbradley" },
    { 0x7156, "isbreachableinit" },
    { 0x7157, "isbreaching" },
    { 0x7158, "isbulletdamage" },
    { 0x7159, "isbulletweapon" },
    { 0x715A, "isburning" },
    { 0x715B, "isbuttonmash" },
    { 0x715C, "iscacmeleeweapon" },
    { 0x715D, "iscacprimaryorsecondary" },
    { 0x715E, "iscacprimaryweapon" },
    { 0x715F, "iscacsecondaryweapon" },
    { 0x7160, "iscallouttypeconcat" },
    { 0x7161, "iscallouttypeqa" },
    { 0x7162, "iscallouttypereport" },
    { 0x7163, "iscapturegametype" },
    { 0x7164, "iscapturing" },
    { 0x7165, "iscapturingcrate" },
    { 0x7166, "iscarepackage" },
    { 0x7167, "iscarrygametype" },
    { 0x7168, "iscarrying" },
    { 0x7169, "iscarrykillstreak" },
    { 0x716A, "ischangingweapon" },
    { 0x716B, "ischargetoreadycomplete" },
    { 0x716C, "ischeckingadsmarking" },
    { 0x716D, "ischilled" },
    { 0x716E, "ischoppergunner" },
    { 0x716F, "iscivilian" },
    { 0x7170, "isclasschoiceallowed" },
    { 0x7171, "iscloseinouterradius" },
    { 0x7172, "isclosetogoal" },
    { 0x7173, "isclusterstrike" },
    { 0x7174, "iscombating" },
    { 0x7175, "iscombatpathnode" },
    { 0x7176, "iscombatscriptnode" },
    { 0x7177, "iscomplete" },
    { 0x7178, "iscompletednaturally" },
    { 0x7179, "iscompletelydead" },
    { 0x717A, "isconfirmed" },
    { 0x717B, "isconsumableitem" },
    { 0x717C, "iscontrolled" },
    { 0x717D, "iscontrollingproxyagent" },
    { 0x717E, "iscooked" },
    { 0x717F, "iscorempgametype" },
    { 0x7180, "iscosmeticitem" },
    { 0x7181, "iscoverblockedbywall" },
    { 0x7182, "iscovercrouch" },
    { 0x7183, "iscoverinvalidagainstenemy" },
    { 0x7184, "iscoverleft_crouch" },
    { 0x7185, "iscoverleft_stand" },
    { 0x7186, "iscovermultiswitchrequested" },
    { 0x7187, "iscovernodetype" },
    { 0x7188, "iscovernodevalid" },
    { 0x7189, "iscoverright_crouch" },
    { 0x718A, "iscoverright_stand" },
    { 0x718B, "iscoverstand" },
    { 0x718C, "iscoversuppressed" },
    { 0x718D, "iscovervalid" },
    { 0x718E, "iscovervalidforlmg" },
    { 0x718F, "iscp" },
    { 0x7190, "iscqbwalking" },
    { 0x7191, "iscqbwalkingorfacingenemy" },
    { 0x7192, "iscrashing" },
    { 0x7193, "iscrawldeltaallowed" },
    { 0x7194, "iscriticaldamage" },
    { 0x7195, "isctf" },
    { 0x7196, "iscurrentspectatetarget" },
    { 0x7197, "iscurrentweapon" },
    { 0x7198, "iscustomweapon" },
    { 0x7199, "isdamagelocation_back" },
    { 0x719A, "isdamagelocation_head" },
    { 0x719B, "isdamagelocation_larm" },
    { 0x719C, "isdamagelocation_larmcrouch" },
    { 0x719D, "isdamagelocation_lleg" },
    { 0x719E, "isdamagelocation_rarm" },
    { 0x719F, "isdamagelocation_rleg" },
    { 0x71A0, "isdamagelocation_torso" },
    { 0x71A1, "isdamagelocation_torsocovercrouch" },
    { 0x71A2, "isdamageweapon" },
    { 0x71A3, "isdaylightsavings" },
    { 0x71A4, "isdead" },
    { 0x71A5, "isdeafened" },
    { 0x71A6, "isdeathfromabove" },
    { 0x71A7, "isdeathmachine" },
    { 0x71A8, "isdebuffedbyweapon" },
    { 0x71A9, "isdebuffedbyweaponandplayer" },
    { 0x71AA, "isdefender" },
    { 0x71AB, "isdefending" },
    { 0x71AC, "isdefusing" },
    { 0x71AD, "isdeploying" },
    { 0x71AE, "isdepot" },
    { 0x71AF, "isdeserteagle" },
    { 0x71B0, "isdestroyed" },
    { 0x71B1, "isdestructibleweapon" },
    { 0x71B2, "isdevelopmentspawningofbotclient" },
    { 0x71B3, "isdirectunderbarrelhit" },
    { 0x71B4, "isdisabled" },
    { 0x71B5, "isdistantinouterradius" },
    { 0x71B6, "isdoingambush" },
    { 0x71B7, "isdoingsplash" },
    { 0x71B8, "isdonewithsearchmove" },
    { 0x71B9, "isdoublejumpanimdone" },
    { 0x71BA, "isdowned" },
    { 0x71BB, "isdriving" },
    { 0x71BC, "isdronepackage" },
    { 0x71BD, "isdroppableweapon" },
    { 0x71BE, "isducking" },
    { 0x71BF, "isdummyarmcrate" },
    { 0x71C0, "isdynamicspawn" },
    { 0x71C1, "iseitherofusalreadyinmelee" },
    { 0x71C2, "isempd" },
    { 0x71C3, "isempty" },
    { 0x71C4, "isenemy" },
    { 0x71C5, "isenemyinfrontofme" },
    { 0x71C6, "isenemyingeneraldirection" },
    { 0x71C7, "isenemyinlowcover" },
    { 0x71C8, "isenemynearby" },
    { 0x71C9, "isenemyrightofme" },
    { 0x71CA, "isenemyvisiblefromexposed" },
    { 0x71CB, "isenergyweapon" },
    { 0x71CC, "isentasoldier" },
    { 0x71CD, "isentignoredbyme" },
    { 0x71CE, "isentireteamvalid" },
    { 0x71CF, "isentitycarepackage" },
    { 0x71D0, "isentitydoor" },
    { 0x71D1, "isentitymarked" },
    { 0x71D2, "isentitypickup" },
    { 0x71D3, "isentityvehicle" },
    { 0x71D4, "isentityweapon" },
    { 0x71D5, "isentnotabomber" },
    { 0x71D6, "isenvironmentalinflictor" },
    { 0x71D7, "isenvironmentweapon" },
    { 0x71D8, "isequipment" },
    { 0x71D9, "isequipmentlethal" },
    { 0x71DA, "isequipmentprimary" },
    { 0x71DB, "isequipmentsecondary" },
    { 0x71DC, "isequipmenttactical" },
    { 0x71DD, "isevading" },
    { 0x71DE, "iseventcalloutsplash" },
    { 0x71DF, "isexcluded" },
    { 0x71E0, "isexiting" },
    { 0x71E1, "isexplosiveantikillstreakweapon" },
    { 0x71E2, "isexplosivedamage" },
    { 0x71E3, "isexplosivedangeroustoplayer" },
    { 0x71E4, "isexplosivemissile" },
    { 0x71E5, "isexposed" },
    { 0x71E6, "isexposed_crouch" },
    { 0x71E7, "isexposed_prone" },
    { 0x71E8, "isfacialstateallowed" },
    { 0x71E9, "isfacing" },
    { 0x71EA, "isfacingenemy" },
    { 0x71EB, "isfactorinuse" },
    { 0x71EC, "isfactorregistered" },
    { 0x71ED, "isfactorscriptonly" },
    { 0x71EE, "isfallback" },
    { 0x71EF, "isfallbackspawn" },
    { 0x71F0, "isfauxdeath" },
    { 0x71F1, "isfemale" },
    { 0x71F2, "isfightready" },
    { 0x71F3, "isfiltered" },
    { 0x71F4, "isfireteam" },
    { 0x71F5, "isfirstround" },
    { 0x71F6, "isfistsonly" },
    { 0x71F7, "isfistweapon" },
    { 0x71F8, "isfixednodeinbadplaceandshouldcrouch" },
    { 0x71F9, "isflagexcluded" },
    { 0x71FA, "isflashbanged" },
    { 0x71FB, "isflashed" },
    { 0x71FC, "isflashgrenadedamage" },
    { 0x71FD, "isflashing" },
    { 0x71FE, "isflyingkillstreak" },
    { 0x71FF, "isfmjdamage" },
    { 0x7200, "isforcedlaststand" },
    { 0x7201, "isforcesaving" },
    { 0x7202, "isforcingspecificlongdeath" },
    { 0x7203, "isforgefreezeweapon" },
    { 0x7204, "isfriendly" },
    { 0x7205, "isfriendlyfire" },
    { 0x7206, "isfriendlyteam" },
    { 0x7207, "isfriendlytobox" },
    { 0x7208, "isfriendlytosentry" },
    { 0x7209, "isfrozen" },
    { 0x720A, "isfull" },
    { 0x720B, "isfullsoldier" },
    { 0x720C, "isgamemodeweapon" },
    { 0x720D, "isgameparticipant" },
    { 0x720E, "isgameplayteam" },
    { 0x720F, "isgasmask" },
    { 0x7210, "isgesture" },
    { 0x7211, "isgimme" },
    { 0x7212, "isgl3weapon" },
    { 0x7213, "isgraverobberattachment" },
    { 0x7214, "isgrenadedeployable" },
    { 0x7215, "isgrenadeinrange" },
    { 0x7216, "isgrind" },
    { 0x7217, "isgroundspawner" },
    { 0x7218, "isgungame" },
    { 0x7219, "isgungameloadouts" },
    { 0x721A, "isgunship" },
    { 0x721B, "ishacked" },
    { 0x721C, "ishacking" },
    { 0x721D, "ishacknode" },
    { 0x721E, "ishackweapon" },
    { 0x721F, "ishandle" },
    { 0x7220, "ishardpoint" },
    { 0x7221, "isheadless" },
    { 0x7222, "isheadshot" },
    { 0x7223, "ishealitem" },
    { 0x7224, "ishealthboosted" },
    { 0x7225, "ishealthregendisabled" },
    { 0x7226, "isheli" },
    { 0x7227, "ishelicopter" },
    { 0x7228, "ishelicopter_internal" },
    { 0x7229, "ishelicopterfull" },
    { 0x722A, "ishelikillstreak" },
    { 0x722B, "ishelistruct" },
    { 0x722C, "ishelmet" },
    { 0x722D, "ishelmetpopenabled" },
    { 0x722E, "ishidden" },
    { 0x722F, "ishighdamageweapon" },
    { 0x7230, "ishighestscoringplayertied" },
    { 0x7231, "ishighladder" },
    { 0x7232, "ishighnode" },
    { 0x7233, "isholdingdeployablebox" },
    { 0x7234, "isholdinggrenade" },
    { 0x7235, "isholidayweapon" },
    { 0x7236, "isholidayweaponusingdefaultscope" },
    { 0x7237, "ishome" },
    { 0x7238, "ishorde" },
    { 0x7239, "ishovering" },
    { 0x723A, "ishumanplayer" },
    { 0x723B, "ishuntedplayerabletobekidnapped" },
    { 0x723C, "ishunting" },
    { 0x723D, "ishvt" },
    { 0x723E, "ishvtqualified" },
    { 0x723F, "isidle" },
    { 0x7240, "isidlecurious" },
    { 0x7241, "isidlescriptedanim" },
    { 0x7242, "isignoremeenabled" },
    { 0x7243, "isinarbitraryup" },
    { 0x7244, "isinarray" },
    { 0x7245, "isinbound" },
    { 0x7246, "isinboundingspere" },
    { 0x7247, "isincombat" },
    { 0x7248, "isincontact" },
    { 0x7249, "isincover" },
    { 0x724A, "isindetectrange" },
    { 0x724B, "isindoor" },
    { 0x724C, "isinfected" },
    { 0x724D, "isinfilgameplayteam" },
    { 0x724E, "isinfiniteammoenabled" },
    { 0x724F, "isinitialinfected" },
    { 0x7250, "isinkillcam" },
    { 0x7251, "isinlight" },
    { 0x7252, "isinmarkingrange" },
    { 0x7253, "isinouterradius" },
    { 0x7254, "isinposition" },
    { 0x7255, "isinregion" },
    { 0x7256, "isinremotenodeploy" },
    { 0x7257, "isinset" },
    { 0x7258, "isinshockhold" },
    { 0x7259, "isinside" },
    { 0x725A, "isinsquad" },
    { 0x725B, "isinuse" },
    { 0x725C, "isinvalidzone" },
    { 0x725D, "isinvehicle" },
    { 0x725E, "isinventoryprimaryweapon" },
    { 0x725F, "isinvestigating" },
    { 0x7260, "isinzone" },
    { 0x7261, "isitemfull" },
    { 0x7262, "isitemslotopen" },
    { 0x7263, "isjackalenemyindoors" },
    { 0x7264, "isjailbreak" },
    { 0x7265, "isjailknife" },
    { 0x7266, "isjuggernaut" },
    { 0x7267, "isjuggernautdef" },
    { 0x7268, "isjuggernautgl" },
    { 0x7269, "isjuggernautlevelcustom" },
    { 0x726A, "isjuggernautmaniac" },
    { 0x726B, "isjuggernautrecon" },
    { 0x726C, "isjuggmodejuggernaut" },
    { 0x726D, "isjuiced" },
    { 0x726E, "isjumpmaster" },
    { 0x726F, "iskilled" },
    { 0x7270, "iskillstreak" },
    { 0x7271, "iskillstreakaffectedbyemp" },
    { 0x7272, "iskillstreakaffectedbyobb" },
    { 0x7273, "iskillstreakblockedforbots" },
    { 0x7274, "iskillstreakcalloutsplash" },
    { 0x7275, "iskillstreakdenied" },
    { 0x7276, "iskillstreakitem" },
    { 0x7277, "iskillstreakkillevent" },
    { 0x7278, "iskillstreaklockonable" },
    { 0x7279, "iskillstreakvisibleforcodcaster" },
    { 0x727A, "iskillstreakweapon" },
    { 0x727B, "isknifeonly" },
    { 0x727C, "isknownenemyinradius_tmp" },
    { 0x727D, "islandmark" },
    { 0x727E, "islaptoptimeoutkillstreak" },
    { 0x727F, "islargemap" },
    { 0x7280, "islastcircle" },
    { 0x7281, "islastnode" },
    { 0x7282, "islaststandenabled" },
    { 0x7283, "islastwinbytwo" },
    { 0x7284, "islauncherdirectimpactdamage" },
    { 0x7285, "isleaderboardsupportedmode" },
    { 0x7286, "islean" },
    { 0x7287, "isleaving" },
    { 0x7288, "isleft2d" },
    { 0x7289, "islethalmeleeweapon" },
    { 0x728A, "islevelweapon" },
    { 0x728B, "islifelimited" },
    { 0x728C, "islightweightsoldier" },
    { 0x728D, "islittlebirdkillstreak" },
    { 0x728E, "islocationmarked" },
    { 0x728F, "islockedinkidnapanim" },
    { 0x7290, "islockedon" },
    { 0x7291, "islockedonto" },
    { 0x7292, "islockonlauncher" },
    { 0x7293, "islongrangeai" },
    { 0x7294, "islookatonly" },
    { 0x7295, "islowerbodyshot" },
    { 0x7296, "islowonammo" },
    { 0x7297, "islowthrowsafe" },
    { 0x7298, "ismanagerthreadthinking" },
    { 0x7299, "ismapselectkillstreak" },
    { 0x729A, "ismark2weapon" },
    { 0x729B, "ismarked" },
    { 0x729C, "ismarkedtarget" },
    { 0x729D, "ismatchpending" },
    { 0x729E, "ismatchstartprotected" },
    { 0x729F, "ismeleeallowed" },
    { 0x72A0, "ismeleedamage" },
    { 0x72A1, "ismeleedefaultweapon" },
    { 0x72A2, "ismeleeenabled" },
    { 0x72A3, "ismeleeonly" },
    { 0x72A4, "ismeleerangevalid" },
    { 0x72A5, "ismeleevalid" },
    { 0x72A6, "ismeleevalid_common" },
    { 0x72A7, "ismembersaying" },
    { 0x72A8, "ismeritunlocked" },
    { 0x72A9, "ismicroturret" },
    { 0x72AA, "ismlgmatch" },
    { 0x72AB, "ismlgprivatematch" },
    { 0x72AC, "ismlgsystemlink" },
    { 0x72AD, "ismoddedroundgame" },
    { 0x72AE, "ismoveright" },
    { 0x72AF, "ismoving" },
    { 0x72B0, "ismp" },
    { 0x72B1, "ismp_init" },
    { 0x72B2, "ismultiplicative" },
    { 0x72B3, "ismusicenabled" },
    { 0x72B4, "isnavmeshkillstreak" },
    { 0x72B5, "isnavpointaccesiblefrombehinddoor" },
    { 0x72B6, "isnightmap" },
    { 0x72B7, "isnmlactive" },
    { 0x72B8, "isnode3d" },
    { 0x72B9, "isnodecover3d" },
    { 0x72BA, "isnodecovercrouch" },
    { 0x72BB, "isnodecovercrouchtype" },
    { 0x72BC, "isnodecoverleft" },
    { 0x72BD, "isnodecoverorconceal" },
    { 0x72BE, "isnodecoverright" },
    { 0x72BF, "isnodeexposed3d" },
    { 0x72C0, "isnoneweaponinflictor" },
    { 0x72C1, "isnormallastweapon" },
    { 0x72C2, "isnormalloadouts" },
    { 0x72C3, "isnotdoingwallruntransition" },
    { 0x72C4, "isnotinvehicle" },
    { 0x72C5, "isnotleanthreadmode" },
    { 0x72C6, "isnukekill" },
    { 0x72C7, "isnumberandgreaterthanzero" },
    { 0x72C8, "isnumbermultipleof" },
    { 0x72C9, "isobjectivebased" },
    { 0x72CA, "isobjectivecontested" },
    { 0x72CB, "isobjectivegametype" },
    { 0x72CC, "isobjectiveindanger" },
    { 0x72CD, "isoccupiedbylmg" },
    { 0x72CE, "isofficer" },
    { 0x72CF, "isonanystairs" },
    { 0x72D0, "isonemanarmymenu" },
    { 0x72D1, "isoneshotdamage" },
    { 0x72D2, "isoneteamleft" },
    { 0x72D3, "isonobjective" },
    { 0x72D4, "isonornearstairs" },
    { 0x72D5, "isoob" },
    { 0x72D6, "isoobimmune" },
    { 0x72D7, "isopeningdoor" },
    { 0x72D8, "isoperationmerit" },
    { 0x72D9, "isotherplayersnearpoint" },
    { 0x72DA, "isovertimesupportedgametype" },
    { 0x72DB, "isownercarepakage" },
    { 0x72DC, "ispainted" },
    { 0x72DD, "ispainweaponsizelarge" },
    { 0x72DE, "isparachutegametype" },
    { 0x72DF, "ispartdismembered" },
    { 0x72E0, "ispartiallysuppressedwrapper" },
    { 0x72E1, "ispassive" },
    { 0x72E2, "ispathdataavailable" },
    { 0x72E3, "ispatrolpointstyle" },
    { 0x72E4, "ispayloadstunned" },
    { 0x72E5, "isperformingmaneuver" },
    { 0x72E6, "isperk_adsmarked" },
    { 0x72E7, "isperkinloadout" },
    { 0x72E8, "isperkpointpickup" },
    { 0x72E9, "ispickedupgrenadetype" },
    { 0x72EA, "ispickedupweapon" },
    { 0x72EB, "ispickuploadouts" },
    { 0x72EC, "ispickupstackable" },
    { 0x72ED, "ispickupweapon" },
    { 0x72EE, "ispiloted" },
    { 0x72EF, "isplaced" },
    { 0x72F0, "isplantedequipment" },
    { 0x72F1, "isplanting" },
    { 0x72F2, "isplayer" },
    { 0x72F3, "isplayerabletobekidnapped" },
    { 0x72F4, "isplayerads" },
    { 0x72F5, "isplayerallowedforspawnlogic" },
    { 0x72F6, "isplayerffaenemy" },
    { 0x72F7, "isplayerfocus" },
    { 0x72F8, "isplayeringulag" },
    { 0x72F9, "isplayerkillstreak" },
    { 0x72FA, "isplayerlinked" },
    { 0x72FB, "isplayernearme" },
    { 0x72FC, "isplayernearsmartobject" },
    { 0x72FD, "isplayeronenemyteam" },
    { 0x72FE, "isplayeroutsideofanybombsite" },
    { 0x72FF, "isplayeroutsideofcurbombsite" },
    { 0x7300, "isplayerproxyagent" },
    { 0x7301, "isplayersniperhit" },
    { 0x7302, "isplayerstatwritable" },
    { 0x7303, "isplayertargettedbyotherturrets" },
    { 0x7304, "isplayertimer" },
    { 0x7305, "isplayerusing" },
    { 0x7306, "isplayerusingbox" },
    { 0x7307, "isplayervalid" },
    { 0x7308, "isplayervisible" },
    { 0x7309, "isplayerweaponatmaxxp" },
    { 0x730A, "isplaying" },
    { 0x730B, "isplayingexitanim" },
    { 0x730C, "isplayingpushsound" },
    { 0x730D, "isplayingsolo" },
    { 0x730E, "isplunder" },
    { 0x730F, "isplunderextract" },
    { 0x7310, "ispointinbounds" },
    { 0x7311, "ispointinboundsfallback" },
    { 0x7312, "ispointincurrentsafecircle" },
    { 0x7313, "ispointinlane" },
    { 0x7314, "ispointinoutofbounds" },
    { 0x7315, "ispointinsafebounds" },
    { 0x7316, "ispointnearpilot" },
    { 0x7317, "ispoweritem" },
    { 0x7318, "ispowersbuttonpressed" },
    { 0x7319, "ispowerweapon" },
    { 0x731A, "ispreppinggrenade" },
    { 0x731B, "ispreviewbuild" },
    { 0x731C, "isprimaryweapon" },
    { 0x731D, "ispristine" },
    { 0x731E, "isprojectiledamage" },
    { 0x731F, "isprojectilekillstreak" },
    { 0x7320, "isprotectedbyaxeblock" },
    { 0x7321, "isprotectedbyriotshield" },
    { 0x7322, "isradardrone" },
    { 0x7323, "isradarhelicopter" },
    { 0x7324, "isradioline" },
    { 0x7325, "isragdollzerog" },
    { 0x7326, "israllypoint" },
    { 0x7327, "israllypointvehicle" },
    { 0x7328, "isrambo" },
    { 0x7329, "israndomalphafiveloadouts" },
    { 0x732A, "israndomalphafourloadouts" },
    { 0x732B, "israndomalphaloadouts" },
    { 0x732C, "israndomalphaoneloadouts" },
    { 0x732D, "israndomalphathreeloadouts" },
    { 0x732E, "israndomalphatwoloadouts" },
    { 0x732F, "israndomloadouts" },
    { 0x7330, "israndompreviewloadouts" },
    { 0x7331, "isready" },
    { 0x7332, "isreadytofire" },
    { 0x7333, "isrealismenabled" },
    { 0x7334, "isreallyalive" },
    { 0x7335, "isrebel" },
    { 0x7336, "isrecoilreducingweapon" },
    { 0x7337, "isreconmarked" },
    { 0x7338, "isrecordingenabled" },
    { 0x7339, "isrefloot" },
    { 0x733A, "isregistered" },
    { 0x733B, "isregisteredevent" },
    { 0x733C, "isrelativeteam" },
    { 0x733D, "isreliablyswitchingtoweapon" },
    { 0x733E, "isreloading" },
    { 0x733F, "isremotekillstreak" },
    { 0x7340, "isremotekillstreakweapon" },
    { 0x7341, "isrepairing" },
    { 0x7342, "isresetting" },
    { 0x7343, "isresourcekillstreak" },
    { 0x7344, "isrespawn" },
    { 0x7345, "isreturningtosafehouse" },
    { 0x7346, "isreviveenabled" },
    { 0x7347, "isrevivetrigger" },
    { 0x7348, "isreviving" },
    { 0x7349, "isridekillstreak" },
    { 0x734A, "isriotshield" },
    { 0x734B, "isriotshield_parachute" },
    { 0x734C, "isroundbased" },
    { 0x734D, "isrunning" },
    { 0x734E, "isrunningtovehicle" },
    { 0x734F, "isrvsgungameloadouts" },
    { 0x7350, "issaloonstyle" },
    { 0x7351, "issameoffhandtype" },
    { 0x7352, "issameteam" },
    { 0x7353, "isscanning" },
    { 0x7354, "isscoreboosting" },
    { 0x7355, "isscoretobeatrulegametype" },
    { 0x7356, "isscoring" },
    { 0x7357, "isscoringdisabled" },
    { 0x7358, "isscramblerdrone" },
    { 0x7359, "isscripted" },
    { 0x735A, "isscriptedalive" },
    { 0x735B, "isscriptonly" },
    { 0x735C, "issdshiphackmap" },
    { 0x735D, "isselectableattachment" },
    { 0x735E, "isselectableweapon" },
    { 0x735F, "isselectingspawn" },
    { 0x7360, "isselfdestruct" },
    { 0x7361, "issentient" },
    { 0x7362, "issentry" },
    { 0x7363, "issentrygun" },
    { 0x7364, "issetup" },
    { 0x7365, "issharedfuncdefined" },
    { 0x7366, "isshocked" },
    { 0x7367, "isshooting" },
    { 0x7368, "isshotgun" },
    { 0x7369, "isshotgunai" },
    { 0x736A, "isshown" },
    { 0x736B, "isshrapnelsource" },
    { 0x736C, "issilenced" },
    { 0x736D, "issimultaneouskillenabled" },
    { 0x736E, "issinglehitweapon" },
    { 0x736F, "issingleshot" },
    { 0x7370, "isskeetshooter" },
    { 0x7371, "issliding" },
    { 0x7372, "issmallmissile" },
    { 0x7373, "issmartobjectwithinrange" },
    { 0x7374, "issniper" },
    { 0x7375, "issniperconverging" },
    { 0x7376, "issniperlaseron" },
    { 0x7377, "issniperrifle" },
    { 0x7378, "issoldier" },
    { 0x7379, "issp" },
    { 0x737A, "isspawndangerzonealive" },
    { 0x737B, "isspawnprotected" },
    { 0x737C, "isspawnselectionenabled" },
    { 0x737D, "isspeakerinrange" },
    { 0x737E, "isspeaking" },
    { 0x737F, "isspeakingbc" },
    { 0x7380, "isspeakingfailsafe" },
    { 0x7381, "isspecialcrafteditem" },
    { 0x7382, "isspecialdeath" },
    { 0x7383, "isspecialist" },
    { 0x7384, "isspecialistkillstreak" },
    { 0x7385, "isspecialmeleeweapon" },
    { 0x7386, "isspecialpain" },
    { 0x7387, "isspeedwithincombatrange" },
    { 0x7388, "isspeedwithincombatrangeextended" },
    { 0x7389, "isspeedwithincqbrange" },
    { 0x738A, "isspeedwithinsprintrange" },
    { 0x738B, "isspidergrenade" },
    { 0x738C, "issquad" },
    { 0x738D, "issquadleader" },
    { 0x738E, "issquadmateindanger" },
    { 0x738F, "issquadmode" },
    { 0x7390, "issquadonlycrate" },
    { 0x7391, "issquadspawnable" },
    { 0x7392, "isstale" },
    { 0x7393, "isstatelocked" },
    { 0x7394, "isstatwritable_internal" },
    { 0x7395, "issteeldragon" },
    { 0x7396, "isstillvalidtarget" },
    { 0x7397, "isstrstart" },
    { 0x7398, "isstuck" },
    { 0x7399, "isstuckdamage" },
    { 0x739A, "isstuckdamagekill" },
    { 0x739B, "isstunned" },
    { 0x739C, "isstunnedorblinded" },
    { 0x739D, "issue_color_order_to_ai" },
    { 0x739E, "issue_leave_node_order_to_ai_and_get_ai" },
    { 0x739F, "issuper" },
    { 0x73A0, "issupercharging" },
    { 0x73A1, "issuperdamagesource" },
    { 0x73A2, "issuperdisabled" },
    { 0x73A3, "issuperexpended" },
    { 0x73A4, "issuperinuse" },
    { 0x73A5, "issuperpickup" },
    { 0x73A6, "issuperready" },
    { 0x73A7, "issupertrophy" },
    { 0x73A8, "issuperweapon" },
    { 0x73A9, "issuperweapondisabled" },
    { 0x73AA, "issupportdronekillstreak" },
    { 0x73AB, "issupporthelo" },
    { 0x73AC, "issupportkillstreak" },
    { 0x73AD, "issuppressedwrapper" },
    { 0x73AE, "issurvivorkill" },
    { 0x73AF, "issuspended" },
    { 0x73B0, "isswitchingteams" },
    { 0x73B1, "isswitchingtoweaponwithmonitoring" },
    { 0x73B2, "issystemfinalized" },
    { 0x73B3, "istacops" },
    { 0x73B4, "istactical" },
    { 0x73B5, "istacticaldamage" },
    { 0x73B6, "istakingdamage" },
    { 0x73B7, "istarget" },
    { 0x73B8, "istargetinreticle" },
    { 0x73B9, "istargetmarked" },
    { 0x73BA, "isteam" },
    { 0x73BB, "isteamless" },
    { 0x73BC, "isteamparticipant" },
    { 0x73BD, "isteamreviveenabled" },
    { 0x73BE, "isteamsaying" },
    { 0x73BF, "isteamspeaking" },
    { 0x73C0, "isteamswitchbalanced" },
    { 0x73C1, "isteamtouching" },
    { 0x73C2, "isteamvalid" },
    { 0x73C3, "isteleportenabled" },
    { 0x73C4, "isthermalenabled" },
    { 0x73C5, "isthrowingknife" },
    { 0x73C6, "isthrown" },
    { 0x73C7, "istimetobeatrulegametype" },
    { 0x73C8, "istimetobeatvalid" },
    { 0x73C9, "istimeup" },
    { 0x73CA, "istogglescope" },
    { 0x73CB, "istokenpickup" },
    { 0x73CC, "istorsoshot" },
    { 0x73CD, "istorsouppershot" },
    { 0x73CE, "istouchingboundsnullify" },
    { 0x73CF, "istouchingboundstrigger" },
    { 0x73D0, "istouchingoobtrigger" },
    { 0x73D1, "istouchingstancetrigger" },
    { 0x73D2, "istrap" },
    { 0x73D3, "istraversaltransitionsupported" },
    { 0x73D4, "istraversing" },
    { 0x73D5, "istripwire" },
    { 0x73D6, "istripwirestruct" },
    { 0x73D7, "istripwiretrapstruct" },
    { 0x73D8, "istruckfull" },
    { 0x73D9, "isttlosdataavailable" },
    { 0x73DA, "isturret" },
    { 0x73DB, "isturretkillstreak" },
    { 0x73DC, "istwomode" },
    { 0x73DD, "isuav" },
    { 0x73DE, "isuavactiveforteam" },
    { 0x73DF, "isuavkillstreak" },
    { 0x73E0, "isunoccupied" },
    { 0x73E1, "isupperbodyshot" },
    { 0x73E2, "isusable" },
    { 0x73E3, "isusing" },
    { 0x73E4, "isusingcamera" },
    { 0x73E5, "isusingchoppergunner" },
    { 0x73E6, "isusingdefaultclass" },
    { 0x73E7, "isusinggunship" },
    { 0x73E8, "isusinginfilselection" },
    { 0x73E9, "isusingobject" },
    { 0x73EA, "isusingpickupmonitor" },
    { 0x73EB, "isusingprimary" },
    { 0x73EC, "isusingremote" },
    { 0x73ED, "isusingremotetank" },
    { 0x73EE, "isusingsamevoice" },
    { 0x73EF, "isusingsecondary" },
    { 0x73F0, "isusingshotgun" },
    { 0x73F1, "isusingsidearm" },
    { 0x73F2, "isusingspawnmapcamera" },
    { 0x73F3, "isusingsupercard" },
    { 0x73F4, "isusingtacopsmapcamera" },
    { 0x73F5, "isusingvanguard" },
    { 0x73F6, "isutility" },
    { 0x73F7, "isutilityitemequipped" },
    { 0x73F8, "isvalid" },
    { 0x73F9, "isvalidbarreldamage" },
    { 0x73FA, "isvalidbestweapon" },
    { 0x73FB, "isvalidclass" },
    { 0x73FC, "isvalidclient" },
    { 0x73FD, "isvaliddroppedweapon" },
    { 0x73FE, "isvalidevent" },
    { 0x73FF, "isvalidffatarget" },
    { 0x7400, "isvalidpeekoutdir" },
    { 0x7401, "isvalidplayer" },
    { 0x7402, "isvalidplayerevent" },
    { 0x7403, "isvalidrevivetriggerspawnposition" },
    { 0x7404, "isvalidteamtarget" },
    { 0x7405, "isvalidthrowingknifekill" },
    { 0x7406, "isvalidweapon" },
    { 0x7407, "isvalidzombieweapon" },
    { 0x7408, "isvariabledefined" },
    { 0x7409, "isvehicle" },
    { 0x740A, "isvehicleattached" },
    { 0x740B, "isvehicledestroyed" },
    { 0x740C, "isvehicleexitrequested" },
    { 0x740D, "isvehicleweapon" },
    { 0x740E, "isvest" },
    { 0x740F, "isvip" },
    { 0x7410, "iswaitingtoentergulag" },
    { 0x7411, "iswallcast" },
    { 0x7412, "iswatchingcodcasterball" },
    { 0x7413, "isweapon" },
    { 0x7414, "isweaponepic" },
    { 0x7415, "isweaponfacingenemy" },
    { 0x7416, "isweaponfromcrate" },
    { 0x7417, "isweaponinitialized" },
    { 0x7418, "isweaponitem" },
    { 0x7419, "isweaponmerit" },
    { 0x741A, "isweaponpickup" },
    { 0x741B, "isweaponpickupitem" },
    { 0x741C, "iswegameplatform" },
    { 0x741D, "iswhizbydetected" },
    { 0x741E, "iswinbytworulegametype" },
    { 0x741F, "iswinningteam" },
    { 0x7420, "iswithinfov" },
    { 0x7421, "isworweapon" },
    { 0x7422, "iszombie" },
    { 0x7423, "item_add_func" },
    { 0x7424, "item_count" },
    { 0x7425, "item_drop_func" },
    { 0x7426, "item_handleownerdisconnect" },
    { 0x7427, "item_models" },
    { 0x7428, "item_oncarrierdeath" },
    { 0x7429, "item_oncarrierdisconnect" },
    { 0x742A, "item_ongameended" },
    { 0x742B, "item_outline_weapon_monitor" },
    { 0x742C, "item_pickup" },
    { 0x742D, "item_pos_array" },
    { 0x742E, "item_timeout" },
    { 0x742F, "item_type" },
    { 0x7430, "itemignored" },
    { 0x7431, "iteminits" },
    { 0x7432, "itemkills" },
    { 0x7433, "itemlist" },
    { 0x7434, "itempicked" },
    { 0x7435, "itemremoveammofromaltmodes" },
    { 0x7436, "itemreplaced" },
    { 0x7437, "items" },
    { 0x7438, "itemsdropped" },
    { 0x7439, "itemtype" },
    { 0x743A, "itemuses" },
    { 0x743B, "itemworldplaced" },
    { 0x743C, "iterate_building_num" },
    { 0x743D, "iterate_objs" },
    { 0x743E, "iw7_ship_hack_add_bombzone_node" },
    { 0x743F, "iwsignatureposition" },
    { 0x7440, "jackal" },
    { 0x7441, "jackal_incoming" },
    { 0x7442, "jackalcanseeenemy" },
    { 0x7443, "jackalcanseelocation" },
    { 0x7444, "jackalcrash" },
    { 0x7445, "jackaldelete" },
    { 0x7446, "jackaldestroyed" },
    { 0x7447, "jackalexplode" },
    { 0x7448, "jackalfindclosestenemy" },
    { 0x7449, "jackalfindfirstopenpoint" },
    { 0x744A, "jackalgettargets" },
    { 0x744B, "jackalleave" },
    { 0x744C, "jackalmovetoenemy" },
    { 0x744D, "jackalmovetolocation" },
    { 0x744E, "jackals" },
    { 0x744F, "jackaltimer" },
    { 0x7450, "jackpot_tag" },
    { 0x7451, "jackpot_targetfx" },
    { 0x7452, "jackpot_zone" },
    { 0x7453, "jackpotpileicon" },
    { 0x7454, "jackpotpileobjid" },
    { 0x7455, "jailbreaktimerwait" },
    { 0x7456, "jailed" },
    { 0x7457, "jailedplayers" },
    { 0x7458, "jailknife" },
    { 0x7459, "jailknifestuck" },
    { 0x745A, "jailspawncounter" },
    { 0x745B, "jailspawns" },
    { 0x745C, "jammer_hitmarkers" },
    { 0x745D, "jammer_relocate" },
    { 0x745E, "javelin" },
    { 0x745F, "javelin_checktargetstillheld" },
    { 0x7460, "javelin_deathwatcher" },
    { 0x7461, "javelin_dof" },
    { 0x7462, "javelin_enterstate" },
    { 0x7463, "javelin_eyetraceforward" },
    { 0x7464, "javelin_firestateenter" },
    { 0x7465, "javelin_firestateexit" },
    { 0x7466, "javelin_firestateupdate" },
    { 0x7467, "javelin_getqueuedstate" },
    { 0x7468, "javelin_getvehicleoffset" },
    { 0x7469, "javelin_hidenormalhud" },
    { 0x746A, "javelin_holdstateenter" },
    { 0x746B, "javelin_holdstateexit" },
    { 0x746C, "javelin_holdstateupdate" },
    { 0x746D, "javelin_init" },
    { 0x746E, "javelin_looplocalseeksound" },
    { 0x746F, "javelin_offstateenter" },
    { 0x7470, "javelin_offstateexit" },
    { 0x7471, "javelin_offstateupdate" },
    { 0x7472, "javelin_preupdate" },
    { 0x7473, "javelin_queuestate" },
    { 0x7474, "javelin_reset" },
    { 0x7475, "javelin_scanforvehicletarget" },
    { 0x7476, "javelin_scanningstateenter" },
    { 0x7477, "javelin_scanningstateupdate" },
    { 0x7478, "javelin_setuistate" },
    { 0x7479, "javelin_shouldjavelinthink" },
    { 0x747A, "javelin_softsighttest" },
    { 0x747B, "javelin_targetpointtooclose" },
    { 0x747C, "javelin_think" },
    { 0x747D, "javelin_tooclosestateenter" },
    { 0x747E, "javelin_tooclosestateupdate" },
    { 0x747F, "javelin_vehiclelocksighttest" },
    { 0x7480, "javelinfired" },
    { 0x7481, "javelinlocationtargeted" },
    { 0x7482, "javelinusageloop" },
    { 0x7483, "jchestorg" },
    { 0x7484, "jdam_earthquake" },
    { 0x7485, "jeep_cp_create" },
    { 0x7486, "jeep_cp_createfromstructs" },
    { 0x7487, "jeep_cp_delete" },
    { 0x7488, "jeep_cp_getspawnstructscallback" },
    { 0x7489, "jeep_cp_init" },
    { 0x748A, "jeep_cp_initlate" },
    { 0x748B, "jeep_cp_initspawning" },
    { 0x748C, "jeep_cp_ondeathrespawncallback" },
    { 0x748D, "jeep_cp_spawncallback" },
    { 0x748E, "jeep_cp_waitandspawn" },
    { 0x748F, "jeep_create" },
    { 0x7490, "jeep_deathcallback" },
    { 0x7491, "jeep_deletenextframe" },
    { 0x7492, "jeep_enterend" },
    { 0x7493, "jeep_enterendinternal" },
    { 0x7494, "jeep_exitend" },
    { 0x7495, "jeep_exitendinternal" },
    { 0x7496, "jeep_explode" },
    { 0x7497, "jeep_getspawnstructscallback" },
    { 0x7498, "jeep_init" },
    { 0x7499, "jeep_initfx" },
    { 0x749A, "jeep_initinteract" },
    { 0x749B, "jeep_initlate" },
    { 0x749C, "jeep_initoccupancy" },
    { 0x749D, "jeep_initspawning" },
    { 0x749E, "jeep_mp_create" },
    { 0x749F, "jeep_mp_delete" },
    { 0x74A0, "jeep_mp_getspawnstructscallback" },
    { 0x74A1, "jeep_mp_init" },
    { 0x74A2, "jeep_mp_initmines" },
    { 0x74A3, "jeep_mp_initspawning" },
    { 0x74A4, "jeep_mp_ondeathrespawncallback" },
    { 0x74A5, "jeep_mp_spawncallback" },
    { 0x74A6, "jeep_mp_waitandspawn" },
    { 0x74A7, "jeeps" },
    { 0x74A8, "jerrycan" },
    { 0x74A9, "jet_fly" },
    { 0x74AA, "jetpackmodel" },
    { 0x74AB, "jets_dialoguelogic" },
    { 0x74AC, "jets_drop_phosphorus" },
    { 0x74AD, "jets_getvehiclespawners" },
    { 0x74AE, "jets_main" },
    { 0x74AF, "jets_sfxlogic" },
    { 0x74B0, "jets_spawnvehicle" },
    { 0x74B1, "jets_start" },
    { 0x74B2, "jets_vehiclelogic" },
    { 0x74B3, "jku_arrow" },
    { 0x74B4, "jku_point" },
    { 0x74B5, "join_module_group" },
    { 0x74B6, "joinedinprogress" },
    { 0x74B7, "joining_team" },
    { 0x74B8, "joinsquad" },
    { 0x74B9, "jug_behavior" },
    { 0x74BA, "jug_spawn_think" },
    { 0x74BB, "jugg_allegiance" },
    { 0x74BC, "jugg_allies" },
    { 0x74BD, "jugg_allowactionset" },
    { 0x74BE, "jugg_anim_monitor_dist" },
    { 0x74BF, "jugg_anim_monitor_dmg" },
    { 0x74C0, "jugg_attackers" },
    { 0x74C1, "jugg_available" },
    { 0x74C2, "jugg_can_see_player" },
    { 0x74C3, "jugg_canresolvestance" },
    { 0x74C4, "jugg_cantriggerjuggernaut" },
    { 0x74C5, "jugg_combat_nags" },
    { 0x74C6, "jugg_cowbell" },
    { 0x74C7, "jugg_createconfig" },
    { 0x74C8, "jugg_currjugg" },
    { 0x74C9, "jugg_dam_state_change" },
    { 0x74CA, "jugg_damage_watcher_internal" },
    { 0x74CB, "jugg_death_func" },
    { 0x74CC, "jugg_death_watcher_internal" },
    { 0x74CD, "jugg_decrementfauxvehiclecount" },
    { 0x74CE, "jugg_detonator" },
    { 0x74CF, "jugg_disableoverlay" },
    { 0x74D0, "jugg_dmg_modifier" },
    { 0x74D1, "jugg_dropcratefromscriptedheli" },
    { 0x74D2, "jugg_enableoverlay" },
    { 0x74D3, "jugg_enemy_watcher" },
    { 0x74D4, "jugg_getdefaultclassstruct" },
    { 0x74D5, "jugg_getjuggmodels" },
    { 0x74D6, "jugg_getmovespeedscalar" },
    { 0x74D7, "jugg_goal" },
    { 0x74D8, "jugg_handlestancechange" },
    { 0x74D9, "jugg_health" },
    { 0x74DA, "jugg_hide_logic" },
    { 0x74DB, "jugg_hold" },
    { 0x74DC, "jugg_hold_loop" },
    { 0x74DD, "jugg_incrementfauxvehiclecount" },
    { 0x74DE, "jugg_init" },
    { 0x74DF, "jugg_initconfig" },
    { 0x74E0, "jugg_leveldata" },
    { 0x74E1, "jugg_makejuggernaut" },
    { 0x74E2, "jugg_makejuggernautcallback" },
    { 0x74E3, "jugg_music" },
    { 0x74E4, "jugg_needtochangestance" },
    { 0x74E5, "jugg_obj_pos" },
    { 0x74E6, "jugg_patroll_logic" },
    { 0x74E7, "jugg_playoperatoruseline" },
    { 0x74E8, "jugg_rebel_respawn" },
    { 0x74E9, "jugg_registeractionset" },
    { 0x74EA, "jugg_registeronplayerspawncallback" },
    { 0x74EB, "jugg_removejuggernaut" },
    { 0x74EC, "jugg_restoremodel" },
    { 0x74ED, "jugg_setmodel" },
    { 0x74EE, "jugg_showerrormessage" },
    { 0x74EF, "jugg_sight_check" },
    { 0x74F0, "jugg_state_init" },
    { 0x74F1, "jugg_stop_anim_monitor" },
    { 0x74F2, "jugg_teamplayercardsplash" },
    { 0x74F3, "jugg_toggleallows" },
    { 0x74F4, "jugg_updatemovespeedscale" },
    { 0x74F5, "jugg_watcher" },
    { 0x74F6, "jugg_watchfordamage" },
    { 0x74F7, "jugg_watchfordeath" },
    { 0x74F8, "jugg_watchfordisconnect" },
    { 0x74F9, "jugg_watchforgameend" },
    { 0x74FA, "jugg_watchforoverlayexecutiontoggle" },
    { 0x74FB, "jugg_watchmusictoggle" },
    { 0x74FC, "jugg_watchoverlaydamagestates" },
    { 0x74FD, "jugg_watchpickup" },
    { 0x74FE, "juggconfig" },
    { 0x74FF, "juggcontext" },
    { 0x7500, "juggcratecleanup" },
    { 0x7501, "juggcratemanageuse" },
    { 0x7502, "juggcrateobjid" },
    { 0x7503, "juggcrates" },
    { 0x7504, "juggcratesetups" },
    { 0x7505, "juggcratespawnpos" },
    { 0x7506, "juggcrateused" },
    { 0x7507, "juggcratewatchstopuseprogress" },
    { 0x7508, "juggcratewatchusecompleted" },
    { 0x7509, "juggcratewatchuseprogress" },
    { 0x750A, "juggernaut" },
    { 0x750B, "juggernaut_1" },
    { 0x750C, "juggernaut_add_fov_user_scale_override" },
    { 0x750D, "juggernaut_allies_cleanup" },
    { 0x750E, "juggernaut_allies_setup" },
    { 0x750F, "juggernaut_catchup" },
    { 0x7510, "juggernaut_damage" },
    { 0x7511, "juggernaut_death_callout_vo" },
    { 0x7512, "juggernaut_debug" },
    { 0x7513, "juggernaut_dof" },
    { 0x7514, "juggernaut_door_anims" },
    { 0x7515, "juggernaut_fake_door_cursor_hint" },
    { 0x7516, "juggernaut_finish_vision_restore" },
    { 0x7517, "juggernaut_fire_suppression" },
    { 0x7518, "juggernaut_fire_suppression_logic" },
    { 0x7519, "juggernaut_fire_suppression_setup" },
    { 0x751A, "juggernaut_fx" },
    { 0x751B, "juggernaut_getenemy" },
    { 0x751C, "juggernaut_getstopdist" },
    { 0x751D, "juggernaut_getwalkdist" },
    { 0x751E, "juggernaut_init" },
    { 0x751F, "juggernaut_initialized" },
    { 0x7520, "juggernaut_intro_fx" },
    { 0x7521, "juggernaut_intro_scene" },
    { 0x7522, "juggernaut_isspecialweapon" },
    { 0x7523, "juggernaut_lighting" },
    { 0x7524, "juggernaut_lighting_setup" },
    { 0x7525, "juggernaut_lookforplayers" },
    { 0x7526, "juggernaut_lookforplayertime" },
    { 0x7527, "juggernaut_main" },
    { 0x7528, "juggernaut_move" },
    { 0x7529, "juggernaut_moveinit" },
    { 0x752A, "juggernaut_moveterminate" },
    { 0x752B, "juggernaut_next_alert_time" },
    { 0x752C, "juggernaut_pain" },
    { 0x752D, "juggernaut_pain_cooldown" },
    { 0x752E, "juggernaut_player_adjustment" },
    { 0x752F, "juggernaut_player_fired" },
    { 0x7530, "juggernaut_post_death_cleanup" },
    { 0x7531, "juggernaut_remove_fov_user_scale_override" },
    { 0x7532, "juggernaut_save" },
    { 0x7533, "juggernaut_scene_setup" },
    { 0x7534, "juggernaut_shouldmove" },
    { 0x7535, "juggernaut_sound_when_close" },
    { 0x7536, "juggernaut_spawn" },
    { 0x7537, "juggernaut_start" },
    { 0x7538, "juggernaut_updateeveryframe_noncombat" },
    { 0x7539, "juggernaut_updatestance" },
    { 0x753A, "juggernaut_vision_obstructed" },
    { 0x753B, "juggernaut_vision_restored" },
    { 0x753C, "juggernaut_watch_pain" },
    { 0x753D, "juggernautacceleration" },
    { 0x753E, "juggernautcanseeenemydelaymax" },
    { 0x753F, "juggernautcanseeenemydelaymin" },
    { 0x7540, "juggernautdisablemovebehavior" },
    { 0x7541, "juggernautfn0" },
    { 0x7542, "juggernautfn1" },
    { 0x7543, "juggernautfn2" },
    { 0x7544, "juggernautfn3" },
    { 0x7545, "juggernautforcewalk" },
    { 0x7546, "juggernautgoalradius" },
    { 0x7547, "juggernautlastmeleetime" },
    { 0x7548, "juggernautpaintime" },
    { 0x7549, "juggernautrundelaymax" },
    { 0x754A, "juggernautrundelaymin" },
    { 0x754B, "juggernauts" },
    { 0x754C, "juggernautsounds" },
    { 0x754D, "juggernautspeedthreholdsinitialized" },
    { 0x754E, "juggernautstopdistance" },
    { 0x754F, "juggernautvisionobscured" },
    { 0x7550, "juggernautvisionobscuredstopdistance" },
    { 0x7551, "juggernautvisionobscuredwalkdist" },
    { 0x7552, "juggernautwalkdist" },
    { 0x7553, "juggernautweaponpickedup" },
    { 0x7554, "jugghealth" },
    { 0x7555, "juggksglobals" },
    { 0x7556, "juggobjid" },
    { 0x7557, "juggoverlay" },
    { 0x7558, "juggoverlaystate" },
    { 0x7559, "juggoverlaystatelabel" },
    { 0x755A, "juggremover" },
    { 0x755B, "juggspawnbehavior" },
    { 0x755C, "juggswitchtime" },
    { 0x755D, "juicedicon" },
    { 0x755E, "juicedtimer" },
    { 0x755F, "jump" },
    { 0x7560, "jump_interact" },
    { 0x7561, "jump_interact_remove" },
    { 0x7562, "jump_over_ent_origin" },
    { 0x7563, "jump_over_offset" },
    { 0x7564, "jump_over_position" },
    { 0x7565, "jump_technical_dudes" },
    { 0x7566, "jump_watcher" },
    { 0x7567, "jumpcur" },
    { 0x7568, "jumpdone" },
    { 0x7569, "jumpdown_cameradofsettings" },
    { 0x756A, "jumpdown_reach_idle" },
    { 0x756B, "jumper_dmg_detect" },
    { 0x756C, "jumpheight" },
    { 0x756D, "jumplistener" },
    { 0x756E, "jumpout" },
    { 0x756F, "jumpslots" },
    { 0x7570, "jumpspot" },
    { 0x7571, "jumptoanywherebutherespawns" },
    { 0x7572, "jumptype" },
    { 0x7573, "junks" },
    { 0x7574, "kamikaze" },
    { 0x7575, "kargorgis_wh01_model" },
    { 0x7576, "katanacamokillcount" },
    { 0x7577, "kb_locked" },
    { 0x7578, "keep_circling_around_vehicle" },
    { 0x7579, "keep_firing" },
    { 0x757A, "keep_firing_turret" },
    { 0x757B, "keep_focus_on_vehicle" },
    { 0x757C, "keep_following_target_while_remain_height" },
    { 0x757D, "keep_following_vehicle" },
    { 0x757E, "keep_from_crushing_players" },
    { 0x757F, "keep_heli_in_place" },
    { 0x7580, "keep_moving" },
    { 0x7581, "keep_perks" },
    { 0x7582, "keep_player_near_location" },
    { 0x7583, "keep_player_on_ground" },
    { 0x7584, "keep_players_from_using_ascender" },
    { 0x7585, "keep_rotating" },
    { 0x7586, "keep_sending_enemies_to_kill_hack" },
    { 0x7587, "keep_smuggler_loot_on_death" },
    { 0x7588, "keep_up_nag_counter" },
    { 0x7589, "keep_up_nags" },
    { 0x758A, "keepcarryweapon" },
    { 0x758B, "keepiconpositioned" },
    { 0x758C, "keepinmap" },
    { 0x758D, "keeppositioned" },
    { 0x758E, "keepprogress" },
    { 0x758F, "keepstealthoncontextmelee" },
    { 0x7590, "keepweapons" },
    { 0x7591, "keepweaponsloaded" },
    { 0x7592, "key" },
    { 0x7593, "key_card" },
    { 0x7594, "key_card_acquired" },
    { 0x7595, "key_card_activate" },
    { 0x7596, "key_card_headicon" },
    { 0x7597, "key_card_hint" },
    { 0x7598, "key_dof" },
    { 0x7599, "key_use_think" },
    { 0x759A, "keycard" },
    { 0x759B, "keyobject" },
    { 0x759C, "keypad_interact" },
    { 0x759D, "keypad_unlock" },
    { 0x759E, "keys" },
    { 0x759F, "kick_afk_check" },
    { 0x75A0, "kick_for_inactivity" },
    { 0x75A1, "kick_player_queue" },
    { 0x75A2, "kick_player_queue_loop" },
    { 0x75A3, "kickanyremainingplayers" },
    { 0x75A4, "kickedfromc130" },
    { 0x75A5, "kickifdontspawn" },
    { 0x75A6, "kickoff_cinematic_settings" },
    { 0x75A7, "kickoff_setup" },
    { 0x75A8, "kickoffneutralbradleyspawnsdom" },
    { 0x75A9, "kickoffneutralbradleyspawnstdm" },
    { 0x75AA, "kickoffstart" },
    { 0x75AB, "kickout" },
    { 0x75AC, "kickwait" },
    { 0x75AD, "kickwhenoutofbounds" },
    { 0x75AE, "kid" },
    { 0x75AF, "kid_ran" },
    { 0x75B0, "kidnap_black_screen" },
    { 0x75B1, "kidnap_by_knife" },
    { 0x75B2, "kidnap_mover" },
    { 0x75B3, "kidnap_return_loc" },
    { 0x75B4, "kidnap_wid" },
    { 0x75B5, "kidnapper" },
    { 0x75B6, "kidnapper_after_spawn_func" },
    { 0x75B7, "kidnapper_clean_up" },
    { 0x75B8, "kidnapper_disguise_think" },
    { 0x75B9, "kidnapper_enable_execute" },
    { 0x75BA, "kidnapper_laststand_hero_watcher" },
    { 0x75BB, "kidnapper_monitor" },
    { 0x75BC, "kidnapper_target_player" },
    { 0x75BD, "kidnapper_target_think" },
    { 0x75BE, "kidnapper_toggle_monitor" },
    { 0x75BF, "kill" },
    { 0x75C0, "kill_agent_when_in_water" },
    { 0x75C1, "kill_all_c130_links" },
    { 0x75C2, "kill_all_players" },
    { 0x75C3, "kill_all_zombies" },
    { 0x75C4, "kill_and_delete_quietly" },
    { 0x75C5, "kill_aq_for_shootout_anim" },
    { 0x75C6, "kill_array_of_ai" },
    { 0x75C7, "kill_b1_guy" },
    { 0x75C8, "kill_barkov" },
    { 0x75C9, "kill_border_triggers" },
    { 0x75CA, "kill_cam_behavior_default" },
    { 0x75CB, "kill_cam_behavior_low" },
    { 0x75CC, "kill_cam_behavior_spin" },
    { 0x75CD, "kill_cellphone_guy" },
    { 0x75CE, "kill_chickens" },
    { 0x75CF, "kill_chopper_hint" },
    { 0x75D0, "kill_civs_til_player_sees_me" },
    { 0x75D1, "kill_color_replacements" },
    { 0x75D2, "kill_convoy_all" },
    { 0x75D3, "kill_convoy_all_safe" },
    { 0x75D4, "kill_dad" },
    { 0x75D5, "kill_deathflag" },
    { 0x75D6, "kill_deathflag_proc" },
    { 0x75D7, "kill_drone_out_of_bounds" },
    { 0x75D8, "kill_em_all" },
    { 0x75D9, "kill_enemy" },
    { 0x75DA, "kill_everyone_ending" },
    { 0x75DB, "kill_exploder" },
    { 0x75DC, "kill_flashlight" },
    { 0x75DD, "kill_flashlight_fx" },
    { 0x75DE, "kill_flip_gun_shoot_remove_fov_scale_override" },
    { 0x75DF, "kill_flir_footstep_fx" },
    { 0x75E0, "kill_flood_spawner" },
    { 0x75E1, "kill_fob_ladders" },
    { 0x75E2, "kill_fx_thread" },
    { 0x75E3, "kill_hadir" },
    { 0x75E4, "kill_hadir_gesture_loop" },
    { 0x75E5, "kill_heli" },
    { 0x75E6, "kill_heli_logic" },
    { 0x75E7, "kill_lights" },
    { 0x75E8, "kill_locations_achievement_check" },
    { 0x75E9, "kill_main_truck" },
    { 0x75EA, "kill_me_after_timeout" },
    { 0x75EB, "kill_me_no_anim" },
    { 0x75EC, "kill_me_on_gap_approach" },
    { 0x75ED, "kill_me_ragdoll" },
    { 0x75EE, "kill_me_ragdoll_nosound" },
    { 0x75EF, "kill_mortar_target" },
    { 0x75F0, "kill_nearby_ai_enemies" },
    { 0x75F1, "kill_objects" },
    { 0x75F2, "kill_off_enemies" },
    { 0x75F3, "kill_off_lobby_aq" },
    { 0x75F4, "kill_off_rpg_guy" },
    { 0x75F5, "kill_off_sort" },
    { 0x75F6, "kill_off_time_override" },
    { 0x75F7, "kill_off_when_station_reached" },
    { 0x75F8, "kill_oilfire" },
    { 0x75F9, "kill_on_countdown_timer" },
    { 0x75FA, "kill_on_damage" },
    { 0x75FB, "kill_partner_altdeath" },
    { 0x75FC, "kill_perimeter_lights" },
    { 0x75FD, "kill_pilot_on_bleedout" },
    { 0x75FE, "kill_player" },
    { 0x75FF, "kill_player_if_hostage_taker_still_alive" },
    { 0x7600, "kill_players" },
    { 0x7601, "kill_quietly" },
    { 0x7602, "kill_reward_func" },
    { 0x7603, "kill_spawner" },
    { 0x7604, "kill_spawnernum" },
    { 0x7605, "kill_target" },
    { 0x7606, "kill_the_tank" },
    { 0x7607, "kill_the_window" },
    { 0x7608, "kill_tower_ladders" },
    { 0x7609, "kill_traversal_test_guy" },
    { 0x760A, "kill_tree_light" },
    { 0x760B, "kill_trigger" },
    { 0x760C, "kill_trigger_event_processed" },
    { 0x760D, "kill_trigger_event_was_processed" },
    { 0x760E, "kill_truck_riders" },
    { 0x760F, "kill_with_extra_xp_passive" },
    { 0x7610, "kill_wrapper" },
    { 0x7611, "killaftertime" },
    { 0x7612, "killagent" },
    { 0x7613, "killcam" },
    { 0x7614, "killcamcleanup" },
    { 0x7615, "killcament" },
    { 0x7616, "killcamentityindex" },
    { 0x7617, "killcamentitystarttime" },
    { 0x7618, "killcamentnum" },
    { 0x7619, "killcamentstickstolookatent" },
    { 0x761A, "killcamentstickstovictim" },
    { 0x761B, "killcamlength" },
    { 0x761C, "killcamlookatentityindex" },
    { 0x761D, "killcammiscitems" },
    { 0x761E, "killcamoffset" },
    { 0x761F, "killcamwatchtime" },
    { 0x7620, "killcount" },
    { 0x7621, "killcountthislife" },
    { 0x7622, "killdog" },
    { 0x7623, "killed_by_killer" },
    { 0x7624, "killed_early" },
    { 0x7625, "killedby" },
    { 0x7626, "killedbyweapon" },
    { 0x7627, "killedkillstreak" },
    { 0x7628, "killedplayer" },
    { 0x7629, "killedplayernotifysys" },
    { 0x762A, "killedplayers" },
    { 0x762B, "killedplayerwithsuperweapon" },
    { 0x762C, "killedself" },
    { 0x762D, "killeventqueue" },
    { 0x762E, "killeventtextpopup" },
    { 0x762F, "killhardpointvfx" },
    { 0x7630, "killing_time" },
    { 0x7631, "killingattacker" },
    { 0x7632, "killkidnappedplayer" },
    { 0x7633, "killme" },
    { 0x7634, "killminimapicon" },
    { 0x7635, "killnearbyzombies" },
    { 0x7636, "killofftime" },
    { 0x7637, "killoneshot" },
    { 0x7638, "killoutlineid" },
    { 0x7639, "killplayer" },
    { 0x763A, "killproxy" },
    { 0x763B, "killremainingagents" },
    { 0x763C, "killrepulsorvictim" },
    { 0x763D, "kills10nodeaths_evaluate" },
    { 0x763E, "killscharge" },
    { 0x763F, "killself" },
    { 0x7640, "killsequence" },
    { 0x7641, "killsequencemarinesdata" },
    { 0x7642, "killsequenceopfordata" },
    { 0x7643, "killshouldaddtokillstreak" },
    { 0x7644, "killsinaframecount" },
    { 0x7645, "killsoundondeath" },
    { 0x7646, "killspawn_groups" },
    { 0x7647, "killspawner" },
    { 0x7648, "killsperweapon" },
    { 0x7649, "killsperweaponlog" },
    { 0x764A, "killsthislife" },
    { 0x764B, "killstoearnnukeselect" },
    { 0x764C, "killstreak_backup_enemies" },
    { 0x764D, "killstreak_botcanuse" },
    { 0x764E, "killstreak_botfunc" },
    { 0x764F, "killstreak_botparm" },
    { 0x7650, "killstreak_chopper_main" },
    { 0x7651, "killstreak_chopper_start" },
    { 0x7652, "killstreak_createdangerzone" },
    { 0x7653, "killstreak_createobjective" },
    { 0x7654, "killstreak_death_callback" },
    { 0x7655, "killstreak_destroydangerzone" },
    { 0x7656, "killstreak_global_bp_exists_for" },
    { 0x7657, "killstreak_info" },
    { 0x7658, "killstreak_init" },
    { 0x7659, "killstreak_laststand_func" },
    { 0x765A, "killstreak_make_vehicle" },
    { 0x765B, "killstreak_post_mod_damage_callback" },
    { 0x765C, "killstreak_pre_mod_damage_callback" },
    { 0x765D, "killstreak_restorenvgstate" },
    { 0x765E, "killstreak_retreat" },
    { 0x765F, "killstreak_rpg_guys" },
    { 0x7660, "killstreak_rpg_guys_timeout" },
    { 0x7661, "killstreak_savenvgstate" },
    { 0x7662, "killstreak_set_death_callback" },
    { 0x7663, "killstreak_set_post_mod_damage_callback" },
    { 0x7664, "killstreak_set_pre_mod_damage_callback" },
    { 0x7665, "killstreak_spawnuniversaldangerzone" },
    { 0x7666, "killstreak_vehicle_callback_init" },
    { 0x7667, "killstreak_visbilityomnvarlist" },
    { 0x7668, "killstreakactivatedtime" },
    { 0x7669, "killstreakbeginusefunc" },
    { 0x766A, "killstreakcanbeusedatroundstart" },
    { 0x766B, "killstreakcharge" },
    { 0x766C, "killstreakclearcallback" },
    { 0x766D, "killstreakcrateactivatecallback" },
    { 0x766E, "killstreakcratecapturecallback" },
    { 0x766F, "killstreakdamaged" },
    { 0x7670, "killstreakdamagefilter" },
    { 0x7671, "killstreakdeploystartbcfunc" },
    { 0x7672, "killstreakdestroyed" },
    { 0x7673, "killstreakentercallback" },
    { 0x7674, "killstreakents" },
    { 0x7675, "killstreakexitcallback" },
    { 0x7676, "killstreakfinishusefunc" },
    { 0x7677, "killstreakglobals" },
    { 0x7678, "killstreakhit" },
    { 0x7679, "killstreakitems" },
    { 0x767A, "killstreakkilled" },
    { 0x767B, "killstreaklaststand" },
    { 0x767C, "killstreaklist" },
    { 0x767D, "killstreaklockedon" },
    { 0x767E, "killstreakmodel" },
    { 0x767F, "killstreakonteamchange" },
    { 0x7680, "killstreakoutoftimecallback" },
    { 0x7681, "killstreakqueue" },
    { 0x7682, "killstreakregisteroobcallbacks" },
    { 0x7683, "killstreakrounddelay" },
    { 0x7684, "killstreaks_array" },
    { 0x7685, "killstreakselectionwatcher" },
    { 0x7686, "killstreaksetups" },
    { 0x7687, "killstreakspawnshielddelayms" },
    { 0x7688, "killstreaktierlist" },
    { 0x7689, "killstreaktriggeredfunc" },
    { 0x768A, "killstreaktype" },
    { 0x768B, "killstreakweaponmap" },
    { 0x768C, "killswithitem" },
    { 0x768D, "killtriggerloop" },
    { 0x768E, "killtriggerspawnlocs" },
    { 0x768F, "killweaponarray" },
    { 0x7690, "killwrapper" },
    { 0x7691, "kinetic_pulse_fx" },
    { 0x7692, "kineticpulse_hint_displayed" },
    { 0x7693, "kitchen" },
    { 0x7694, "kitchen_ambush" },
    { 0x7695, "kitchen_aq_ambusher_fallback" },
    { 0x7696, "kitchen_aq_ambusher_magicbullet" },
    { 0x7697, "kitchen_aq_shoots_down_stairs" },
    { 0x7698, "kitchen_bravo_combat_thread" },
    { 0x7699, "kitchen_bravo_death_react" },
    { 0x769A, "kitchen_catchup" },
    { 0x769B, "kitchen_death_anime" },
    { 0x769C, "kitchen_dialogue" },
    { 0x769D, "kitchen_door_disconnect_paths" },
    { 0x769E, "kitchen_enter_init" },
    { 0x769F, "kitchen_girl_death" },
    { 0x76A0, "kitchen_girl_death_dialogue" },
    { 0x76A1, "kitchen_guy" },
    { 0x76A2, "kitchen_magicbullet" },
    { 0x76A3, "kitchen_main" },
    { 0x76A4, "kitchen_mantle_thread" },
    { 0x76A5, "kitchen_no_react" },
    { 0x76A6, "kitchen_open_door" },
    { 0x76A7, "kitchen_player_clip" },
    { 0x76A8, "kitchen_player_deployed_ladder" },
    { 0x76A9, "kitchen_player_top_of_ladder_failsafe" },
    { 0x76AA, "kitchen_react" },
    { 0x76AB, "kitchen_scene_speedup" },
    { 0x76AC, "kitchen_sequence" },
    { 0x76AD, "kitchen_smoke_handler" },
    { 0x76AE, "kitchen_smoke_monitor" },
    { 0x76AF, "kitchen_start" },
    { 0x76B0, "kitchen_takedown" },
    { 0x76B1, "kitchen_takedown_door" },
    { 0x76B2, "kitchen_takedown_girl" },
    { 0x76B3, "kitchen_toggle_containment" },
    { 0x76B4, "kitchen_use_deathanim" },
    { 0x76B5, "kitchen_use_deathanim_hold" },
    { 0x76B6, "kitchen_use_deathanim_laying" },
    { 0x76B7, "kitchen_use_deathanim_laying_bravo" },
    { 0x76B8, "kitchen_use_deathanim_tie" },
    { 0x76B9, "kitspawn" },
    { 0x76BA, "kittohintstring" },
    { 0x76BB, "kittoicon" },
    { 0x76BC, "kittype" },
    { 0x76BD, "kleenex_popup" },
    { 0x76BE, "knife" },
    { 0x76BF, "knife_trigger" },
    { 0x76C0, "knifespawnpos" },
    { 0x76C1, "knifeteleownerinvalid" },
    { 0x76C2, "knivesperminute" },
    { 0x76C3, "knock_off_check" },
    { 0x76C4, "knockdownanime" },
    { 0x76C5, "knocked_out" },
    { 0x76C6, "knockout_manager" },
    { 0x76C7, "ko_alias" },
    { 0x76C8, "kothextraprimaryspawnpoints" },
    { 0x76C9, "kothhillrotation" },
    { 0x76CA, "kothmode" },
    { 0x76CB, "ks_airsuperiority_handleincoming" },
    { 0x76CC, "ks_airsuperiority_monitorproximity" },
    { 0x76CD, "ks_laserguidedmissile_handleincoming" },
    { 0x76CE, "ks_laserguidedmissile_monitorproximity" },
    { 0x76CF, "ks_manualflares_handleincoming" },
    { 0x76D0, "ks_manualflares_monitorproximity" },
    { 0x76D1, "ks_manualflares_watchuse" },
    { 0x76D2, "ks_setup_manual_flares" },
    { 0x76D3, "ks_vehicles" },
    { 0x76D4, "ks_watch_death_stop_sound" },
    { 0x76D5, "kscallbackinitcomplete" },
    { 0x76D6, "kscapturestrings" },
    { 0x76D7, "ksdeathcallback" },
    { 0x76D8, "kspostmoddamagecallback" },
    { 0x76D9, "kspremoddamagecallback" },
    { 0x76DA, "ksrerollstrings" },
    { 0x76DB, "ksweights" },
    { 0x76DC, "kung_fu_mode" },
    { 0x76DD, "kung_fu_vo" },
    { 0x76DE, "kung_fu_vo_wait" },
    { 0x76DF, "kungfu_style" },
    { 0x76E0, "kyle" },
    { 0x76E1, "kyle_ai" },
    { 0x76E2, "kyle_dialog_struct" },
    { 0x76E3, "kyle_line" },
    { 0x76E4, "kyle_loadout" },
    { 0x76E5, "kyle_logic_thread" },
    { 0x76E6, "kyle_poi" },
    { 0x76E7, "kyle_swap" },
    { 0x76E8, "kyleb_ai" },
    { 0x76E9, "kyledrone" },
    { 0x76EA, "kyledrone_extras" },
    { 0x76EB, "lab_ambush_catchup" },
    { 0x76EC, "lab_ambush_main" },
    { 0x76ED, "lab_ambush_start" },
    { 0x76EE, "lab_civ_vo" },
    { 0x76EF, "lab_civs_logic" },
    { 0x76F0, "lab_door_init" },
    { 0x76F1, "lab_door_move" },
    { 0x76F2, "lab_door_prompt" },
    { 0x76F3, "lab_door_prompt_internal" },
    { 0x76F4, "lab_drone_setup" },
    { 0x76F5, "lab_ending_bink" },
    { 0x76F6, "lab_entrance_catchup" },
    { 0x76F7, "lab_entrance_dialog" },
    { 0x76F8, "lab_entrance_door" },
    { 0x76F9, "lab_entrance_main" },
    { 0x76FA, "lab_entrance_start" },
    { 0x76FB, "lab_halligan_anim" },
    { 0x76FC, "lab_jumpdown_catchup" },
    { 0x76FD, "lab_jumpdown_main" },
    { 0x76FE, "lab_jumpdown_start" },
    { 0x76FF, "lab_nag_called" },
    { 0x7700, "lab_obj_remove" },
    { 0x7701, "lab_objectives" },
    { 0x7702, "lab_starts" },
    { 0x7703, "lab_victims_move_to_door" },
    { 0x7704, "label_rebels" },
    { 0x7705, "label_settings" },
    { 0x7706, "labelid" },
    { 0x7707, "labprisoners" },
    { 0x7708, "labprisonersbackground" },
    { 0x7709, "labvictim1" },
    { 0x770A, "labvictim2" },
    { 0x770B, "labvictim3" },
    { 0x770C, "labvictim4" },
    { 0x770D, "labvictim5" },
    { 0x770E, "labvictim6" },
    { 0x770F, "labvictim7" },
    { 0x7710, "ladder" },
    { 0x7711, "ladder_activate_func" },
    { 0x7712, "ladder_corpse" },
    { 0x7713, "ladder_hint_func" },
    { 0x7714, "ladder_init_func" },
    { 0x7715, "ladder_unusable_thread" },
    { 0x7716, "ladderdeathsthisweapon" },
    { 0x7717, "ladderexecutionblocked" },
    { 0x7718, "ladderindex" },
    { 0x7719, "ladderkillsthisweapon" },
    { 0x771A, "ladderpistol" },
    { 0x771B, "ladderpreviewmodel" },
    { 0x771C, "laddertracking" },
    { 0x771D, "ladderweapon" },
    { 0x771E, "lagged_position" },
    { 0x771F, "land_at_airport" },
    { 0x7720, "landanims" },
    { 0x7721, "landed" },
    { 0x7722, "landed_players" },
    { 0x7723, "landing_pos_array" },
    { 0x7724, "landing_spot" },
    { 0x7725, "landingzones_active" },
    { 0x7726, "landmark" },
    { 0x7727, "landmarks" },
    { 0x7728, "landmine_active" },
    { 0x7729, "landmine_disabled" },
    { 0x772A, "landmine_run_on_player" },
    { 0x772B, "landmine_think" },
    { 0x772C, "landmine_trig" },
    { 0x772D, "lane" },
    { 0x772E, "lane_1_obj_struct" },
    { 0x772F, "lane_2_obj_struct" },
    { 0x7730, "lane_3_obj_struct" },
    { 0x7731, "lanemask" },
    { 0x7732, "lanes" },
    { 0x7733, "lanetriggers" },
    { 0x7734, "lanter_fire_damage" },
    { 0x7735, "lantern_fire" },
    { 0x7736, "lantern_fire_trigger" },
    { 0x7737, "lantern_listener" },
    { 0x7738, "lanterns" },
    { 0x7739, "laptop" },
    { 0x773A, "laptop_use_think" },
    { 0x773B, "laptopactive" },
    { 0x773C, "laptopinfo" },
    { 0x773D, "laptopinteractions" },
    { 0x773E, "laptoploc" },
    { 0x773F, "large_transport_cp_create" },
    { 0x7740, "large_transport_cp_createfromstructs" },
    { 0x7741, "large_transport_cp_delete" },
    { 0x7742, "large_transport_cp_getspawnstructscallback" },
    { 0x7743, "large_transport_cp_init" },
    { 0x7744, "large_transport_cp_initlate" },
    { 0x7745, "large_transport_cp_initspawning" },
    { 0x7746, "large_transport_cp_ondeathrespawncallback" },
    { 0x7747, "large_transport_cp_spawncallback" },
    { 0x7748, "large_transport_cp_waitandspawn" },
    { 0x7749, "large_transport_create" },
    { 0x774A, "large_transport_deathcallback" },
    { 0x774B, "large_transport_deletenextframe" },
    { 0x774C, "large_transport_enterend" },
    { 0x774D, "large_transport_enterendinternal" },
    { 0x774E, "large_transport_exitend" },
    { 0x774F, "large_transport_exitendinternal" },
    { 0x7750, "large_transport_explode" },
    { 0x7751, "large_transport_getspawnstructscallback" },
    { 0x7752, "large_transport_init" },
    { 0x7753, "large_transport_initfx" },
    { 0x7754, "large_transport_initinteract" },
    { 0x7755, "large_transport_initlate" },
    { 0x7756, "large_transport_initoccupancy" },
    { 0x7757, "large_transport_initspawning" },
    { 0x7758, "large_transport_mp_create" },
    { 0x7759, "large_transport_mp_delete" },
    { 0x775A, "large_transport_mp_getspawnstructscallback" },
    { 0x775B, "large_transport_mp_init" },
    { 0x775C, "large_transport_mp_initmines" },
    { 0x775D, "large_transport_mp_initspawning" },
    { 0x775E, "large_transport_mp_ondeathrespawncallback" },
    { 0x775F, "large_transport_mp_spawncallback" },
    { 0x7760, "large_transport_mp_waitandspawn" },
    { 0x7761, "largemap" },
    { 0x7762, "largeprojectiledamage" },
    { 0x7763, "largescale" },
    { 0x7764, "largestep" },
    { 0x7765, "largetransports" },
    { 0x7766, "largevehicleexplosion" },
    { 0x7767, "laser" },
    { 0x7768, "laser_complete_enter" },
    { 0x7769, "laser_complete_handler" },
    { 0x776A, "laser_discipline" },
    { 0x776B, "laser_discipline_kill" },
    { 0x776C, "laser_end_ent" },
    { 0x776D, "laser_ent_clean_up_monitor" },
    { 0x776E, "laser_idle_enter" },
    { 0x776F, "laser_idle_update" },
    { 0x7770, "laser_init" },
    { 0x7771, "laser_init_simple" },
    { 0x7772, "laser_move_to_enter" },
    { 0x7773, "laser_move_to_handler" },
    { 0x7774, "laser_move_to_update" },
    { 0x7775, "laser_off_enter" },
    { 0x7776, "laser_off_update" },
    { 0x7777, "laser_on" },
    { 0x7778, "laser_on_then_delete" },
    { 0x7779, "laser_player_instructions" },
    { 0x777A, "laser_start_ent" },
    { 0x777B, "laser_state" },
    { 0x777C, "laser_targeting" },
    { 0x777D, "laser_track_enter" },
    { 0x777E, "laser_track_handler" },
    { 0x777F, "laser_track_update" },
    { 0x7780, "laser_window_trap_hint_displayed" },
    { 0x7781, "laseroff_func" },
    { 0x7782, "laseron" },
    { 0x7783, "laseron_func" },
    { 0x7784, "last" },
    { 0x7785, "last_actor" },
    { 0x7786, "last_ai_spawn_anim" },
    { 0x7787, "last_aim_callout_time" },
    { 0x7788, "last_angles" },
    { 0x7789, "last_anim_time" },
    { 0x778A, "last_anim_time_check" },
    { 0x778B, "last_atk_bomber_death_time" },
    { 0x778C, "last_beam_time" },
    { 0x778D, "last_bomb_location" },
    { 0x778E, "last_callout_time" },
    { 0x778F, "last_center_nagged" },
    { 0x7790, "last_chair_nag_time" },
    { 0x7791, "last_command" },
    { 0x7792, "last_damage_type" },
    { 0x7793, "last_damaged_by" },
    { 0x7794, "last_damaged_time" },
    { 0x7795, "last_death_pos" },
    { 0x7796, "last_displayed_ent" },
    { 0x7797, "last_dmg_hint_time" },
    { 0x7798, "last_dmg_player" },
    { 0x7799, "last_drawn" },
    { 0x779A, "last_enemy_sight_time" },
    { 0x779B, "last_enemy_sighting_position" },
    { 0x779C, "last_finished" },
    { 0x779D, "last_flash_explode_time" },
    { 0x779E, "last_global_badplace_time" },
    { 0x779F, "last_goal" },
    { 0x77A0, "last_goalradius" },
    { 0x77A1, "last_good_pos" },
    { 0x77A2, "last_helidown_loc" },
    { 0x77A3, "last_hill_enemies_dead" },
    { 0x77A4, "last_hit_target" },
    { 0x77A5, "last_horn_time" },
    { 0x77A6, "last_hostage_death_position" },
    { 0x77A7, "last_in_danger_time" },
    { 0x77A8, "last_infected_class" },
    { 0x77A9, "last_infected_hiding_loc" },
    { 0x77AA, "last_infected_hiding_time" },
    { 0x77AB, "last_interaction_point" },
    { 0x77AC, "last_interior_callout_time" },
    { 0x77AD, "last_investigation_time" },
    { 0x77AE, "last_jumped_time" },
    { 0x77AF, "last_kill_attempt_time" },
    { 0x77B0, "last_killtag_tactical_goal_pos" },
    { 0x77B1, "last_large_rod_target" },
    { 0x77B2, "last_large_rod_time" },
    { 0x77B3, "last_line" },
    { 0x77B4, "last_loot_drop" },
    { 0x77B5, "last_losing_flag_react" },
    { 0x77B6, "last_melee_ti_check" },
    { 0x77B7, "last_misile_fire_time" },
    { 0x77B8, "last_molotov_explode_time" },
    { 0x77B9, "last_motion_time" },
    { 0x77BA, "last_nag_alias" },
    { 0x77BB, "last_nag_pos" },
    { 0x77BC, "last_nag_time" },
    { 0x77BD, "last_nonsuppressed_warning_time" },
    { 0x77BE, "last_overwatch_vo_time" },
    { 0x77BF, "last_owner_stance" },
    { 0x77C0, "last_plane" },
    { 0x77C1, "last_played" },
    { 0x77C2, "last_player" },
    { 0x77C3, "last_player_reaction_time" },
    { 0x77C4, "last_player_seen" },
    { 0x77C5, "last_pos" },
    { 0x77C6, "last_powers_dropped" },
    { 0x77C7, "last_queue_time" },
    { 0x77C8, "last_revive_fail_time" },
    { 0x77C9, "last_rocket_time" },
    { 0x77CA, "last_said" },
    { 0x77CB, "last_seen_time_override" },
    { 0x77CC, "last_selected_entity_has_changed" },
    { 0x77CD, "last_sentry" },
    { 0x77CE, "last_set_goalent" },
    { 0x77CF, "last_set_goalnode" },
    { 0x77D0, "last_set_goalpos" },
    { 0x77D1, "last_severity_time" },
    { 0x77D2, "last_shot_by_mg" },
    { 0x77D3, "last_sight_updater" },
    { 0x77D4, "last_sound_time" },
    { 0x77D5, "last_spawn_time" },
    { 0x77D6, "last_spawned_vehicle" },
    { 0x77D7, "last_speed_set_time" },
    { 0x77D8, "last_spot" },
    { 0x77D9, "last_spotted_vo" },
    { 0x77DA, "last_stab_time" },
    { 0x77DB, "last_stand_hud_update" },
    { 0x77DC, "last_stand_pistol" },
    { 0x77DD, "last_stand_state" },
    { 0x77DE, "last_stand_weapons" },
    { 0x77DF, "last_tag_pile_location" },
    { 0x77E0, "last_tag_pile_time" },
    { 0x77E1, "last_taunt_sfx" },
    { 0x77E2, "last_threat_debug" },
    { 0x77E3, "last_time_jumped_for_tag" },
    { 0x77E4, "last_time_secured" },
    { 0x77E5, "last_used_time" },
    { 0x77E6, "last_valid_weapon" },
    { 0x77E7, "last_warned_weapon" },
    { 0x77E8, "last_wave_num" },
    { 0x77E9, "last_wave_ref" },
    { 0x77EA, "last_wave_time" },
    { 0x77EB, "last_weapon" },
    { 0x77EC, "last_weapon_aim_time" },
    { 0x77ED, "last_weapon_fire_pos" },
    { 0x77EE, "last_weapon_fire_time" },
    { 0x77EF, "last_weapon_nag" },
    { 0x77F0, "last_x" },
    { 0x77F1, "last_y" },
    { 0x77F2, "lastaction" },
    { 0x77F3, "lastactivatedcameraobject" },
    { 0x77F4, "lastactivatetime" },
    { 0x77F5, "lastadsstarttime" },
    { 0x77F6, "lastadvancetoenemyattacker" },
    { 0x77F7, "lastadvancetoenemydest" },
    { 0x77F8, "lastadvancetoenemysrc" },
    { 0x77F9, "lastadvancetoenemytime" },
    { 0x77FA, "lastaliassaid" },
    { 0x77FB, "lastanim" },
    { 0x77FC, "lastannouncetime" },
    { 0x77FD, "lastarchetypeinfo" },
    { 0x77FE, "lastarchivetime" },
    { 0x77FF, "lastattackedshieldplayer" },
    { 0x7800, "lastattackedshieldtime" },
    { 0x7801, "lastattackedtime" },
    { 0x7802, "lastattackplayertime" },
    { 0x7803, "lastautosavetime" },
    { 0x7804, "lastbadspawntime" },
    { 0x7805, "lastblockedbywallchecktime" },
    { 0x7806, "lastbombplanttime" },
    { 0x7807, "lastbounty" },
    { 0x7808, "lastbucket" },
    { 0x7809, "lastburntime" },
    { 0x780A, "lastcacweaponobj" },
    { 0x780B, "lastcaptime" },
    { 0x780C, "lastcaptureteam" },
    { 0x780D, "lastcarexplosiondamagelocation" },
    { 0x780E, "lastcarexplosionlocation" },
    { 0x780F, "lastcarexplosionrange" },
    { 0x7810, "lastcarexplosiontime" },
    { 0x7811, "lastcarrier" },
    { 0x7812, "lastcarrierscored" },
    { 0x7813, "lastcarrierteam" },
    { 0x7814, "lastchosenscreenprinttime" },
    { 0x7815, "lastcircletick" },
    { 0x7816, "lastclaimteam" },
    { 0x7817, "lastclaimtime" },
    { 0x7818, "lastclass" },
    { 0x7819, "lastcolorforced" },
    { 0x781A, "lastconfirmedpos" },
    { 0x781B, "lastcontact" },
    { 0x781C, "lastcovernode" },
    { 0x781D, "lastdamagedtime" },
    { 0x781E, "lastdamagetime" },
    { 0x781F, "lastdamagewasfromenemy" },
    { 0x7820, "lastdeathangles" },
    { 0x7821, "lastdeathpos" },
    { 0x7822, "lastdirection" },
    { 0x7823, "lastdiretionalbloodtime" },
    { 0x7824, "lastdooropentime" },
    { 0x7825, "lastdroppableweapon" },
    { 0x7826, "lastdroppableweaponobj" },
    { 0x7827, "lastdroppedarmortime" },
    { 0x7828, "lastdynolightcleantime" },
    { 0x7829, "lastencounter" },
    { 0x782A, "lastenemybulletdamagetime" },
    { 0x782B, "lastenemydmgtime" },
    { 0x782C, "lastenemykilltime" },
    { 0x782D, "lastenemypos" },
    { 0x782E, "lastenemysightposold" },
    { 0x782F, "lastenemysightposselforigin" },
    { 0x7830, "lastenemysighttime" },
    { 0x7831, "lastenemytime" },
    { 0x7832, "lastephemeraleventrespondedtime" },
    { 0x7833, "lastevaccopterdeployed" },
    { 0x7834, "lasteventtime" },
    { 0x7835, "lastfailedmeleechargetarget" },
    { 0x7836, "lastfinishtime" },
    { 0x7837, "lastfiredtime" },
    { 0x7838, "lastfiretime" },
    { 0x7839, "lastfraggrenadetoplayerstart" },
    { 0x783A, "lastframe_boss_mask" },
    { 0x783B, "lastframetargetposition" },
    { 0x783C, "lastgarageexplosion" },
    { 0x783D, "lastgastouchtime" },
    { 0x783E, "lastgesturetime" },
    { 0x783F, "lastgrenadelandednearplayertime" },
    { 0x7840, "lastgrenadesuicidetime" },
    { 0x7841, "lastgrenadethrowchecktime" },
    { 0x7842, "lastgrenadethrowtime" },
    { 0x7843, "lastgrenadetime" },
    { 0x7844, "lastgroundtype" },
    { 0x7845, "lastgrunttime" },
    { 0x7846, "lastgunpromotiontime" },
    { 0x7847, "lastgunrankincreasetime" },
    { 0x7848, "lastheadicondeath" },
    { 0x7849, "lastheadicondeathent" },
    { 0x784A, "lasthealth" },
    { 0x784B, "lasthelidialogtime" },
    { 0x784C, "lasthheadicondeathent" },
    { 0x784D, "lasthheadicondeathentforenemy" },
    { 0x784E, "lasthingechange" },
    { 0x784F, "lasthitmarkerpriority" },
    { 0x7850, "lasthitmarkertime" },
    { 0x7851, "lasthittime" },
    { 0x7852, "lastidle" },
    { 0x7853, "lastinairkilltime" },
    { 0x7854, "lastindex" },
    { 0x7855, "lastinsmoketime" },
    { 0x7856, "lastinvestigatedtime" },
    { 0x7857, "lastjuggpositions" },
    { 0x7858, "lastkillalertsoundtime" },
    { 0x7859, "lastkilldogtime" },
    { 0x785A, "lastkillearner" },
    { 0x785B, "lastkilledby" },
    { 0x785C, "lastkilledplayer" },
    { 0x785D, "lastkillsplash" },
    { 0x785E, "lastkilltime" },
    { 0x785F, "lastkillvictimpos" },
    { 0x7860, "lastknownmissileangles" },
    { 0x7861, "lastknownmissilepos" },
    { 0x7862, "lastknownposatstart" },
    { 0x7863, "lastknownposition" },
    { 0x7864, "lastknowntrace" },
    { 0x7865, "lastlegitimateattacker" },
    { 0x7866, "lastlighttime" },
    { 0x7867, "lastloottime" },
    { 0x7868, "lastlzwarning" },
    { 0x7869, "lastmatchdatakillstreakindex" },
    { 0x786A, "lastmatchdatarigtrait" },
    { 0x786B, "lastmissedenemy" },
    { 0x786C, "lastmissilefired" },
    { 0x786D, "lastmoveheadcommenttime" },
    { 0x786E, "lastmultikilltime" },
    { 0x786F, "lastnag" },
    { 0x7870, "lastnamesaid" },
    { 0x7871, "lastnamesaidtime" },
    { 0x7872, "lastnamesaidtimeout" },
    { 0x7873, "lastnode" },
    { 0x7874, "lastnonuseweapon" },
    { 0x7875, "lastnormalweaponobj" },
    { 0x7876, "lastoilfiretime" },
    { 0x7877, "lastorigin" },
    { 0x7878, "lastpaintime" },
    { 0x7879, "lastpassdir" },
    { 0x787A, "lastpassivenukeactivation" },
    { 0x787B, "lastpathnodewarningtime" },
    { 0x787C, "lastplayedtime" },
    { 0x787D, "lastplayernamecalltime" },
    { 0x787E, "lastplayersighted" },
    { 0x787F, "lastplayerwins" },
    { 0x7880, "lastprogressteam" },
    { 0x7881, "lastprojectiledamagetime" },
    { 0x7882, "lastpushtime" },
    { 0x7883, "lastradiotransmission" },
    { 0x7884, "lastrecordingstarttime" },
    { 0x7885, "lastreloadstarttime" },
    { 0x7886, "lastreloadtime" },
    { 0x7887, "lastrocketdmgtime" },
    { 0x7888, "lastsavetime" },
    { 0x7889, "lastscore" },
    { 0x788A, "lastscorestatustime" },
    { 0x788B, "lastselfvotime" },
    { 0x788C, "lastsfxplayedtime" },
    { 0x788D, "lastshocktime" },
    { 0x788E, "lastshoottime" },
    { 0x788F, "lastshotfiredtime" },
    { 0x7890, "lastshottime" },
    { 0x7891, "lastshrapneltime" },
    { 0x7892, "lastsightposwatch" },
    { 0x7893, "lastsitreptime" },
    { 0x7894, "lastslowprocessframe" },
    { 0x7895, "lastsmokefired" },
    { 0x7896, "lastsnapshotgrenadetime" },
    { 0x7897, "lastsoldierspawned" },
    { 0x7898, "lastspawnednoisemaker" },
    { 0x7899, "lastspawnpoint" },
    { 0x789A, "lastspawnteam" },
    { 0x789B, "lastspawntime" },
    { 0x789C, "lastspoketime" },
    { 0x789D, "lastsquattime" },
    { 0x789E, "laststance" },
    { 0x789F, "laststancechangetime" },
    { 0x78A0, "laststancetimes" },
    { 0x78A1, "laststand_bypassed" },
    { 0x78A2, "laststand_currency_penalty_amount_func" },
    { 0x78A3, "laststand_enter_gamemodespecificaction" },
    { 0x78A4, "laststand_enter_levelspecificaction" },
    { 0x78A5, "laststand_exit_gamemodespecificaction" },
    { 0x78A6, "laststand_record" },
    { 0x78A7, "laststandactionset" },
    { 0x78A8, "laststandcurrencypenaltyamount" },
    { 0x78A9, "laststandheal_beginuse" },
    { 0x78AA, "laststandheal_drainsupermeter" },
    { 0x78AB, "laststandheal_gethealthperframe" },
    { 0x78AC, "laststandheal_hassuperweapon" },
    { 0x78AD, "laststandheal_onrespawn" },
    { 0x78AE, "laststandheal_onset" },
    { 0x78AF, "laststandheal_setinactivewhendone" },
    { 0x78B0, "laststandheal_think" },
    { 0x78B1, "laststandheal_unset" },
    { 0x78B2, "laststandheal_watchrespawn" },
    { 0x78B3, "laststandhealbeginuse" },
    { 0x78B4, "laststandhealisactive" },
    { 0x78B5, "laststandhealonset" },
    { 0x78B6, "laststandhealth" },
    { 0x78B7, "laststandhealunset" },
    { 0x78B8, "laststanding" },
    { 0x78B9, "laststandinvulnignorefunc" },
    { 0x78BA, "laststandinvulntime" },
    { 0x78BB, "laststandkill" },
    { 0x78BC, "laststandkillteamifdown" },
    { 0x78BD, "laststandlistener" },
    { 0x78BE, "laststandmonitor" },
    { 0x78BF, "laststandmoveawayfromvehicles" },
    { 0x78C0, "laststandnumber" },
    { 0x78C1, "laststandoldweapon" },
    { 0x78C2, "laststandoldweaponobj" },
    { 0x78C3, "laststandrequiresmelee" },
    { 0x78C4, "laststandreviveent" },
    { 0x78C5, "laststandreviveents" },
    { 0x78C6, "laststandrevivehealth" },
    { 0x78C7, "laststandrevivetimer" },
    { 0x78C8, "laststandsuicidetimer" },
    { 0x78C9, "laststandthink" },
    { 0x78CA, "laststandtimer" },
    { 0x78CB, "laststandusetime" },
    { 0x78CC, "laststandwaittillrevivebyteammate" },
    { 0x78CD, "laststandweaponcallback" },
    { 0x78CE, "laststate" },
    { 0x78CF, "laststealthtime" },
    { 0x78D0, "lasttangent" },
    { 0x78D1, "lasttargethitinaframe" },
    { 0x78D2, "lasttargetlocked" },
    { 0x78D3, "lastteabagtime" },
    { 0x78D4, "lastteamkillearners" },
    { 0x78D5, "lastteamkilltimes" },
    { 0x78D6, "lastteamspawnpoints" },
    { 0x78D7, "lastteamspeaktime" },
    { 0x78D8, "lastteamspokentime" },
    { 0x78D9, "lastteamstatustime" },
    { 0x78DA, "lastteamthreatcallout" },
    { 0x78DB, "lastteamthreatcallouttime" },
    { 0x78DC, "lasttimedamaged" },
    { 0x78DD, "lasttimefired" },
    { 0x78DE, "lasttimekidnapped" },
    { 0x78DF, "lasttimereachedscriptgoal" },
    { 0x78E0, "lasttimesawkidnapper" },
    { 0x78E1, "lasttorsoanim" },
    { 0x78E2, "lasttouchedplatform" },
    { 0x78E3, "lasttrackingdialogtime" },
    { 0x78E4, "lasttriptime" },
    { 0x78E5, "lasttripwiredefusedtime" },
    { 0x78E6, "lastupdatetime" },
    { 0x78E7, "lastupdatetimedelta" },
    { 0x78E8, "lastusednode" },
    { 0x78E9, "lastusedoffhandtime" },
    { 0x78EA, "lastusedoffhandweapon" },
    { 0x78EB, "lastusedtime" },
    { 0x78EC, "lastusedweapon" },
    { 0x78ED, "lastusedweaponisalt" },
    { 0x78EE, "lastusedwindowalias" },
    { 0x78EF, "lastuserangles" },
    { 0x78F0, "lastuserpos" },
    { 0x78F1, "lastusetime" },
    { 0x78F2, "lastvalidpassdir" },
    { 0x78F3, "lastvalidpassorg" },
    { 0x78F4, "lastvalue" },
    { 0x78F5, "lastvectotarget" },
    { 0x78F6, "lastvehicleseatchangetime" },
    { 0x78F7, "lastvisionsetthermal" },
    { 0x78F8, "lastwave" },
    { 0x78F9, "lastweapon" },
    { 0x78FA, "lastweaponchangetime" },
    { 0x78FB, "lastweaponfiredtime" },
    { 0x78FC, "lastweaponobj" },
    { 0x78FD, "lastweaponpickuptime" },
    { 0x78FE, "lastweaponrespawn" },
    { 0x78FF, "lastweaponused" },
    { 0x7900, "lastwhizbytime" },
    { 0x7901, "lastwinner" },
    { 0x7902, "late_foyer_save" },
    { 0x7903, "latejointeamkitobjective" },
    { 0x7904, "latespawnplayer" },
    { 0x7905, "latestalias" },
    { 0x7906, "latestanimendtime" },
    { 0x7907, "latestendtime" },
    { 0x7908, "launch_ac130_strikes_at_location" },
    { 0x7909, "launch_ac130_strikes_at_player" },
    { 0x790A, "launch_airstrikes_at_position" },
    { 0x790B, "launch_barrel_away" },
    { 0x790C, "launch_custom_gl_projectile" },
    { 0x790D, "launch_evac_box" },
    { 0x790E, "launch_illumination_flare" },
    { 0x790F, "launch_mask" },
    { 0x7910, "launch_mortar" },
    { 0x7911, "launch_player_from_boss" },
    { 0x7912, "launch_player_physics" },
    { 0x7913, "launch_push_player" },
    { 0x7914, "launch_push_player2" },
    { 0x7915, "launch_respawn_functionality_for_players" },
    { 0x7916, "launchbrnukes" },
    { 0x7917, "launchc4grenade" },
    { 0x7918, "launchchunk" },
    { 0x7919, "launchchunkbotspawning" },
    { 0x791A, "launchchunkcustomizationindex" },
    { 0x791B, "launchchunkfreespawn" },
    { 0x791C, "launchchunkskins" },
    { 0x791D, "launchconcertinabomb" },
    { 0x791E, "launcher_write_clipboard" },
    { 0x791F, "launchexplosivetiplogic" },
    { 0x7920, "launchheight" },
    { 0x7921, "launchmolotov" },
    { 0x7922, "launchshield" },
    { 0x7923, "launchstickytimedgrenade" },
    { 0x7924, "launchthermite" },
    { 0x7925, "launchtime" },
    { 0x7926, "launchuav" },
    { 0x7927, "launchvfx" },
    { 0x7928, "lavalamp_hint_displayed" },
    { 0x7929, "lb_attack_runs" },
    { 0x792A, "lb_gunner" },
    { 0x792B, "lb_infil_catchup" },
    { 0x792C, "lb_infil_start" },
    { 0x792D, "lb_mg_50cal" },
    { 0x792E, "lb_mg_50cal_sound" },
    { 0x792F, "lb_pilot_death" },
    { 0x7930, "lb_pilot_init" },
    { 0x7931, "lb_player_update_stat" },
    { 0x7932, "lb_unload_catchup" },
    { 0x7933, "lb_unload_start" },
    { 0x7934, "lbcolor" },
    { 0x7935, "lbexplode" },
    { 0x7936, "lbonkilled" },
    { 0x7937, "lbravo_get_length" },
    { 0x7938, "lbravo_infil_radio_idle" },
    { 0x7939, "lbravo_infil_spawn_blackscreen_func" },
    { 0x793A, "lbravo_init" },
    { 0x793B, "lbravo_se_2" },
    { 0x793C, "lbravo_se_3" },
    { 0x793D, "lbravo_spawn" },
    { 0x793E, "lbsniper" },
    { 0x793F, "lbspin" },
    { 0x7940, "le" },
    { 0x7941, "lead_debug_show" },
    { 0x7942, "lead_use_think" },
    { 0x7943, "leader" },
    { 0x7944, "leader_index" },
    { 0x7945, "leaderafterspawnfunc" },
    { 0x7946, "leaderboardstartvalues" },
    { 0x7947, "leaderdialog" },
    { 0x7948, "leaderdialogonplayer" },
    { 0x7949, "leaderdialogonplayer_internal" },
    { 0x794A, "leaderdialogonplayers" },
    { 0x794B, "leadergroup" },
    { 0x794C, "leadersinterrogated" },
    { 0x794D, "leaderskilledprematurely" },
    { 0x794E, "leaderwaitformelee" },
    { 0x794F, "leaderwaittobealone" },
    { 0x7950, "leading_veh" },
    { 0x7951, "leadpositionent" },
    { 0x7952, "lean_table_check" },
    { 0x7953, "lean_wall_check" },
    { 0x7954, "leanasitturns" },
    { 0x7955, "leaninit" },
    { 0x7956, "leanthread" },
    { 0x7957, "leave_and_end_game" },
    { 0x7958, "leave_apache_no_player" },
    { 0x7959, "leave_cinematiclogic" },
    { 0x795A, "leave_corpse_for_others_to_see" },
    { 0x795B, "leave_exit_add_fov_user_scale_override" },
    { 0x795C, "leave_farahreachlogic" },
    { 0x795D, "leave_farahstealthbrokenlogic" },
    { 0x795E, "leave_gun_and_run_to_new_spot" },
    { 0x795F, "leave_hangar_vo" },
    { 0x7960, "leave_if_vip_dies" },
    { 0x7961, "leave_main" },
    { 0x7962, "leave_path_for_spline_path" },
    { 0x7963, "leave_start" },
    { 0x7964, "leave_unloadlogic" },
    { 0x7965, "leavecasualkiller" },
    { 0x7966, "leaveplane" },
    { 0x7967, "leavequestlocale" },
    { 0x7968, "leavesquad" },
    { 0x7969, "leaveweaponsdefaultfunc" },
    { 0x796A, "leaving" },
    { 0x796B, "leaving_area_dialogue_monitor" },
    { 0x796C, "leaving_team" },
    { 0x796D, "left_anim" },
    { 0x796E, "left_back_passenger" },
    { 0x796F, "left_bound" },
    { 0x7970, "left_color_node" },
    { 0x7971, "left_crash_kill_squad" },
    { 0x7972, "left_crash_kill_squad_civs" },
    { 0x7973, "left_crash_kill_squad_terry" },
    { 0x7974, "left_dir" },
    { 0x7975, "left_ent" },
    { 0x7976, "left_flank" },
    { 0x7977, "left_flank_trip_defuse_spawns_surprise_door_guy" },
    { 0x7978, "left_guy" },
    { 0x7979, "left_path_avoidance" },
    { 0x797A, "left_path_nav_obstacle" },
    { 0x797B, "left_side" },
    { 0x797C, "left_side_cleanup" },
    { 0x797D, "left_side_cop_driver" },
    { 0x797E, "left_side_crash_terries" },
    { 0x797F, "left_side_crash_terry_logic" },
    { 0x7980, "left_side_kill_squad" },
    { 0x7981, "left_side_kill_squad_terry" },
    { 0x7982, "left_side_street_runners" },
    { 0x7983, "left_side_terry_dmg" },
    { 0x7984, "left_stick_movement" },
    { 0x7985, "left_turret_wait_between_spawn" },
    { 0x7986, "left_underground_attacker_awareness" },
    { 0x7987, "left_underground_bad_guy_death_reacts" },
    { 0x7988, "left_underground_civ" },
    { 0x7989, "left_underground_civ_dmg_func" },
    { 0x798A, "left_underground_hero_cop" },
    { 0x798B, "left_underground_rescue" },
    { 0x798C, "left_vindia_infil_start_targetname_array" },
    { 0x798D, "left_vindia_infil_start_targetname_array_index" },
    { 0x798E, "leftarmdismembered" },
    { 0x798F, "leftback_anim" },
    { 0x7990, "leftchains" },
    { 0x7991, "leftclip" },
    { 0x7992, "leftcornernagindex" },
    { 0x7993, "leftexitgate1" },
    { 0x7994, "leftexitgate2" },
    { 0x7995, "leftextents" },
    { 0x7996, "leftplantang" },
    { 0x7997, "leftplantorg" },
    { 0x7998, "leftplayspace" },
    { 0x7999, "leftpoint" },
    { 0x799A, "leftside_carcrash" },
    { 0x799B, "leftweaponent" },
    { 0x799C, "leftwindow" },
    { 0x799D, "leftwingfxent" },
    { 0x799E, "legacy" },
    { 0x799F, "legacy_set_being_subdued" },
    { 0x79A0, "legendary" },
    { 0x79A1, "leghit" },
    { 0x79A2, "length" },
    { 0x79A3, "lerp" },
    { 0x79A4, "lerp_angle_during_price_grab" },
    { 0x79A5, "lerp_attic_player_viewangle" },
    { 0x79A6, "lerp_blur" },
    { 0x79A7, "lerp_camera_anchor" },
    { 0x79A8, "lerp_float" },
    { 0x79A9, "lerp_fov_over_dist" },
    { 0x79AA, "lerp_fov_over_distance_trigger" },
    { 0x79AB, "lerp_fraction" },
    { 0x79AC, "lerp_hudoutline_occlusion" },
    { 0x79AD, "lerp_intensity" },
    { 0x79AE, "lerp_light_setting" },
    { 0x79AF, "lerp_light_setting_bpg" },
    { 0x79B0, "lerp_omnvar" },
    { 0x79B1, "lerp_omnvarint" },
    { 0x79B2, "lerp_plane_vector" },
    { 0x79B3, "lerp_player_speed_scale" },
    { 0x79B4, "lerp_playerspeed_fov_in_alley" },
    { 0x79B5, "lerp_playerspeed_fov_on_ladder" },
    { 0x79B6, "lerp_saveddvar" },
    { 0x79B7, "lerp_sun_and_vision" },
    { 0x79B8, "lerp_sunintensity" },
    { 0x79B9, "lerp_sunintensity_internal" },
    { 0x79BA, "lerp_sunsamplesizenear_overtime" },
    { 0x79BB, "lerp_time_in" },
    { 0x79BC, "lerp_time_out" },
    { 0x79BD, "lerp_value" },
    { 0x79BE, "lerp_value_charge_explosion" },
    { 0x79BF, "lerp_value_fill" },
    { 0x79C0, "lerp_value_heli_crash" },
    { 0x79C1, "lerp_value_light_buried_mom" },
    { 0x79C2, "lerp_value_rim" },
    { 0x79C3, "lerp_value_up" },
    { 0x79C4, "lerp_value_up_key" },
    { 0x79C5, "lerp_value_up_laptop" },
    { 0x79C6, "lerp_value_up_rim" },
    { 0x79C7, "lerp_woods_sunlight" },
    { 0x79C8, "lerpalleysunshadow" },
    { 0x79C9, "lerpdeathsdoorpulsenorm" },
    { 0x79CA, "lerped" },
    { 0x79CB, "lerpingreactivefoliage" },
    { 0x79CC, "lerplightcolor" },
    { 0x79CD, "lerplightintensity" },
    { 0x79CE, "lerplightradius" },
    { 0x79CF, "lerpoutfireintensity" },
    { 0x79D0, "lerpto" },
    { 0x79D1, "let_player_rappel" },
    { 0x79D2, "lethaldamage_func" },
    { 0x79D3, "lethaldelay" },
    { 0x79D4, "lethaldelayendtime" },
    { 0x79D5, "lethaldelaypassed" },
    { 0x79D6, "lethaldelaystarttime" },
    { 0x79D7, "lethalequipmentdamagemod" },
    { 0x79D8, "lethalitems" },
    { 0x79D9, "lethaltype" },
    { 0x79DA, "level_addguardsalertedfunction" },
    { 0x79DB, "level_addmissionnarrativeobjective" },
    { 0x79DC, "level_alertguardsinentitygroupvolumes" },
    { 0x79DD, "level_allguardsdead" },
    { 0x79DE, "level_anims_generic_human" },
    { 0x79DF, "level_anims_player" },
    { 0x79E0, "level_anims_script_model" },
    { 0x79E1, "level_anims_vehicles" },
    { 0x79E2, "level_array" },
    { 0x79E3, "level_badplacestructsinit" },
    { 0x79E4, "level_ballisticsniperammointeractlogic" },
    { 0x79E5, "level_ballisticsniperammopickuplogic" },
    { 0x79E6, "level_ballisticsniperammowaypointlogic" },
    { 0x79E7, "level_barkovgetspeakerlineindex" },
    { 0x79E8, "level_barkovsetspeakerlineindex" },
    { 0x79E9, "level_barkovspeakerinit" },
    { 0x79EA, "level_barkovspeakerplayloopingdialogue" },
    { 0x79EB, "level_barkovspeakersgetdialoguelines" },
    { 0x79EC, "level_barkovspeakersplaydialogue" },
    { 0x79ED, "level_cageddogdeathlogic" },
    { 0x79EE, "level_cageddogfarahhintdialogue" },
    { 0x79EF, "level_cageddoglogic" },
    { 0x79F0, "level_cansightweapon" },
    { 0x79F1, "level_cansilenceweapon" },
    { 0x79F2, "level_cinematictelevisiondamagelogic" },
    { 0x79F3, "level_cinematictelevisionsgetdialoguelines" },
    { 0x79F4, "level_cinematictelevisionsplaydialogueline" },
    { 0x79F5, "level_cinematictelevisionsstandby" },
    { 0x79F6, "level_civilianplayerreactlogic" },
    { 0x79F7, "level_civilianstealthbrokenlogic" },
    { 0x79F8, "level_civilianunloaderspawncinderblock" },
    { 0x79F9, "level_civilianworkeralertedlogic" },
    { 0x79FA, "level_civilianworkerdeletedcinderblocklogic" },
    { 0x79FB, "level_civilianworkerdropoffcinderblock" },
    { 0x79FC, "level_civilianworkerexchangecinderblock" },
    { 0x79FD, "level_civilianworkergivecinderblock" },
    { 0x79FE, "level_civilianworkerlogic" },
    { 0x79FF, "level_civilianworkerpickupcinderblock" },
    { 0x7A00, "level_civilianworkertakebreaklogic" },
    { 0x7A01, "level_civilianworkerunloadercinderblockplayerpickuplogic" },
    { 0x7A02, "level_civilianworkerunloaderclearcinderblock" },
    { 0x7A03, "level_civilianworkerunloaderdeathcinderblocklogic" },
    { 0x7A04, "level_civilianworkerunloaderlogic" },
    { 0x7A05, "level_cleanupieds" },
    { 0x7A06, "level_closebunkerouterdoor" },
    { 0x7A07, "level_combo" },
    { 0x7A08, "level_compound_setup" },
    { 0x7A09, "level_deletepreviousobjective" },
    { 0x7A0A, "level_deletereservedobjectives" },
    { 0x7A0B, "level_disablefriendlyfire" },
    { 0x7A0C, "level_droneambientmovementlogic" },
    { 0x7A0D, "level_droneambientspawnmanager" },
    { 0x7A0E, "level_dronespawn" },
    { 0x7A0F, "level_dronespawnvehicle" },
    { 0x7A10, "level_dronevehiclepropellerlogic" },
    { 0x7A11, "level_enablefriendlyfire" },
    { 0x7A12, "level_end_save" },
    { 0x7A13, "level_endallguardlogic" },
    { 0x7A14, "level_endallguardproximitylogic" },
    { 0x7A15, "level_enemyassaulttownlogic" },
    { 0x7A16, "level_enemyassaulttownmolotovhintlogic" },
    { 0x7A17, "level_executioncleanupscenelogic" },
    { 0x7A18, "level_executiongetanimatedcivilians" },
    { 0x7A19, "level_executiongetanimatedenemies" },
    { 0x7A1A, "level_executiongetanimationstruct" },
    { 0x7A1B, "level_executionguardanimationfightlogic" },
    { 0x7A1C, "level_executionscenealogic" },
    { 0x7A1D, "level_executionsceneblogic" },
    { 0x7A1E, "level_executionsceneclogic" },
    { 0x7A1F, "level_executionsetupscenelogic" },
    { 0x7A20, "level_executionspawnanimatedcivilians" },
    { 0x7A21, "level_executionspawnanimatedenemies" },
    { 0x7A22, "level_fade_time" },
    { 0x7A23, "level_fadein" },
    { 0x7A24, "level_farahaibackpackon" },
    { 0x7A25, "level_farahbackpackoff" },
    { 0x7A26, "level_farahdisguisedisable" },
    { 0x7A27, "level_farahdisguiseenable" },
    { 0x7A28, "level_farahgetstayaheadnaglines" },
    { 0x7A29, "level_farahgiveweapon" },
    { 0x7A2A, "level_farahkeydetachearlylogic" },
    { 0x7A2B, "level_farahknifedetachearlylogic" },
    { 0x7A2C, "level_farahpathmovingfunction" },
    { 0x7A2D, "level_farahplayerfollowfunction" },
    { 0x7A2E, "level_farahstealthbrokenpathlogic" },
    { 0x7A2F, "level_farahthrowingknifekillenemy" },
    { 0x7A30, "level_farahthrowingknifekillenemycleanuplogic" },
    { 0x7A31, "level_farahthrowingknifemovetoenemy" },
    { 0x7A32, "level_farahturntocivilian" },
    { 0x7A33, "level_farahturntosoldier" },
    { 0x7A34, "level_flareaigoallogic" },
    { 0x7A35, "level_flareailogic" },
    { 0x7A36, "level_flareatrestmonitor" },
    { 0x7A37, "level_flarecantimeout" },
    { 0x7A38, "level_flaregetworldplaced" },
    { 0x7A39, "level_flareinit" },
    { 0x7A3A, "level_flareofftriggerlogic" },
    { 0x7A3B, "level_flaresetcantimeout" },
    { 0x7A3C, "level_flaretimeoutlogic" },
    { 0x7A3D, "level_flareturnoff" },
    { 0x7A3E, "level_flareworldplacedenable" },
    { 0x7A3F, "level_getalertedgroupvolumes" },
    { 0x7A40, "level_getalertedguards" },
    { 0x7A41, "level_getallguards" },
    { 0x7A42, "level_getarmenspawner" },
    { 0x7A43, "level_getbarkov" },
    { 0x7A44, "level_getbarkovspeakers" },
    { 0x7A45, "level_getbarkovspeakersubtractvolumes" },
    { 0x7A46, "level_getbunkerouterdoor" },
    { 0x7A47, "level_getbunkervolume" },
    { 0x7A48, "level_getcinematictelevisions" },
    { 0x7A49, "level_getcivilians" },
    { 0x7A4A, "level_getcivilianworkerclassnameletter" },
    { 0x7A4B, "level_getcustomdeathhintindex" },
    { 0x7A4C, "level_getcustomoverridedeathhintindex" },
    { 0x7A4D, "level_getdrones" },
    { 0x7A4E, "level_getentitytouchinggroupvolumes" },
    { 0x7A4F, "level_getfarah" },
    { 0x7A50, "level_getfarahanimatedbackpack" },
    { 0x7A51, "level_getfarahspawner" },
    { 0x7A52, "level_getfarahtownnode" },
    { 0x7A53, "level_getflag" },
    { 0x7A54, "level_getflareofftriggers" },
    { 0x7A55, "level_getflares" },
    { 0x7A56, "level_getguardforcethreatvolumes" },
    { 0x7A57, "level_getguardgroupvolumes" },
    { 0x7A58, "level_getguardplayerhiddenvolumes" },
    { 0x7A59, "level_getguards" },
    { 0x7A5A, "level_getguardsingroupvolumes" },
    { 0x7A5B, "level_getguardsinstantdetectplayerhiddenvolumes" },
    { 0x7A5C, "level_gethadir" },
    { 0x7A5D, "level_gethadirspawner" },
    { 0x7A5E, "level_gethadirtruck" },
    { 0x7A5F, "level_gethadirtruckboard" },
    { 0x7A60, "level_getheroes" },
    { 0x7A61, "level_gethighestguardwarningindex" },
    { 0x7A62, "level_getieds" },
    { 0x7A63, "level_getoilpump" },
    { 0x7A64, "level_getplayersilencerinteracts" },
    { 0x7A65, "level_getplayerweapontosight" },
    { 0x7A66, "level_getplayerweapontosilence" },
    { 0x7A67, "level_getredshirtgoalamount" },
    { 0x7A68, "level_getredshirts" },
    { 0x7A69, "level_getredshirtspawners" },
    { 0x7A6A, "level_getsafehousecustomdeathhintindex" },
    { 0x7A6B, "level_gettownanimationstruct" },
    { 0x7A6C, "level_gettowncovernodes" },
    { 0x7A6D, "level_gettowninnerenemygoalvolume" },
    { 0x7A6E, "level_gettownouterenemygoalvolume" },
    { 0x7A6F, "level_gettownrooftoptriggers" },
    { 0x7A70, "level_getuncle" },
    { 0x7A71, "level_giveplayersilencer" },
    { 0x7A72, "level_giveplayersilencerfirstraiselogic" },
    { 0x7A73, "level_giveplayerweaponsight" },
    { 0x7A74, "level_groupvolumealertedsfxlogic" },
    { 0x7A75, "level_guardactionfight" },
    { 0x7A76, "level_guardactionlook" },
    { 0x7A77, "level_guardactionmelee" },
    { 0x7A78, "level_guardactionsuspicious" },
    { 0x7A79, "level_guardactionthreat" },
    { 0x7A7A, "level_guardactionthreatanimationlogic" },
    { 0x7A7B, "level_guardaddai" },
    { 0x7A7C, "level_guardaddalertedai" },
    { 0x7A7D, "level_guardaddalertedcivilian" },
    { 0x7A7E, "level_guardaddcivilian" },
    { 0x7A7F, "level_guardallalertedcivilianslogic" },
    { 0x7A80, "level_guardarenearbyguardsathigherwarning" },
    { 0x7A81, "level_guardassignweapon" },
    { 0x7A82, "level_guardcanseeplayerdrawnweapon" },
    { 0x7A83, "level_guardcanseeplayergrenadethrowing" },
    { 0x7A84, "level_guardcanseeplayerprone" },
    { 0x7A85, "level_guardcivilianalertedlogic" },
    { 0x7A86, "level_guardciviliandeathalertnearbycivilians" },
    { 0x7A87, "level_guardciviliandeathalertnearbyguards" },
    { 0x7A88, "level_guardciviliandeathalertotherslogic" },
    { 0x7A89, "level_guardcivilianlogic" },
    { 0x7A8A, "level_guardcleanupanimationoriginlogic" },
    { 0x7A8B, "level_guardcleanupwarningsoundondeathlogic" },
    { 0x7A8C, "level_guardclearallalerted" },
    { 0x7A8D, "level_guardclearcorpses" },
    { 0x7A8E, "level_guardcorpsedetectlogic" },
    { 0x7A8F, "level_guarddamagelogic" },
    { 0x7A90, "level_guarddeathalertotherslogic" },
    { 0x7A91, "level_guarddoggrowllogic" },
    { 0x7A92, "level_guardfight" },
    { 0x7A93, "level_guardfightalertguardslogic" },
    { 0x7A94, "level_guardfightalertnearbycivilians" },
    { 0x7A95, "level_guardfightalertnearbycivilianslogic" },
    { 0x7A96, "level_guardfightalertnearbyguards" },
    { 0x7A97, "level_guardfightlines" },
    { 0x7A98, "level_guardfightmusiclogic" },
    { 0x7A99, "level_guardfightshowsightblockerclipslogic" },
    { 0x7A9A, "level_guardfightvolumealertcivilianslogic" },
    { 0x7A9B, "level_guardgetalertedcivilians" },
    { 0x7A9C, "level_guardgetcivilianalertedanimation" },
    { 0x7A9D, "level_guardgetcivilianalertedanimations" },
    { 0x7A9E, "level_guardgetcivilians" },
    { 0x7A9F, "level_guardgetciviliansingroupvolumes" },
    { 0x7AA0, "level_guardgetcorpselines" },
    { 0x7AA1, "level_guardgetcorpses" },
    { 0x7AA2, "level_guardgetdamagelines" },
    { 0x7AA3, "level_guardgetfightlines" },
    { 0x7AA4, "level_guardgetguardswithinwarningsharerange" },
    { 0x7AA5, "level_guardgethighestwarningguardwithinwarningsharerange" },
    { 0x7AA6, "level_guardgetholesightblockerclips" },
    { 0x7AA7, "level_guardgetlabordriverthreatlines" },
    { 0x7AA8, "level_guardgetlaughlines" },
    { 0x7AA9, "level_guardgetmeleelines" },
    { 0x7AAA, "level_guardgetplayerpronelines" },
    { 0x7AAB, "level_guardgetreactionanimations" },
    { 0x7AAC, "level_guardgetseenplayeractgoofylines" },
    { 0x7AAD, "level_guardgetseenplayermeleelines" },
    { 0x7AAE, "level_guardgetthreatlines" },
    { 0x7AAF, "level_guardgetwhizbylines" },
    { 0x7AB0, "level_guardhideholesightblockerclips" },
    { 0x7AB1, "level_guardinit" },
    { 0x7AB2, "level_guardinstantdetectcanseeplayer" },
    { 0x7AB3, "level_guardisalerted" },
    { 0x7AB4, "level_guardisentitytouchinganygroupvolume" },
    { 0x7AB5, "level_guardislabordriver" },
    { 0x7AB6, "level_guardisplayerinhiddenvolume" },
    { 0x7AB7, "level_guardlogic" },
    { 0x7AB8, "level_guardmeleedalertotherslogic" },
    { 0x7AB9, "level_guardplaydialogue" },
    { 0x7ABA, "level_guardplayerfightvolumecheck" },
    { 0x7ABB, "level_guardplayergrenadethrowcleanupsoundlogic" },
    { 0x7ABC, "level_guardplayergrenadethrowinglogic" },
    { 0x7ABD, "level_guardplayerinmeleerange" },
    { 0x7ABE, "level_guardplayerproximitycooldownwarning" },
    { 0x7ABF, "level_guardplayerproximityforcemelee" },
    { 0x7AC0, "level_guardplayerproximityforcethreat" },
    { 0x7AC1, "level_guardplayerproximityinwarninglogic" },
    { 0x7AC2, "level_guardplayerproximitylogic" },
    { 0x7AC3, "level_guardplayerproximityshouldcooldownwarning" },
    { 0x7AC4, "level_guardplayerproximityshouldforcemelee" },
    { 0x7AC5, "level_guardplayerproximityshouldforcethreat" },
    { 0x7AC6, "level_guardplayerproximityshouldincreasewarning" },
    { 0x7AC7, "level_guardplayerthrewoffhandlogic" },
    { 0x7AC8, "level_guardplayerthrownoffhandalertlogic" },
    { 0x7AC9, "level_guardplayerunsilencedshotlogic" },
    { 0x7ACA, "level_guardplayerweapondrawncleanupsoundlogic" },
    { 0x7ACB, "level_guardplayerweapondrawnlogic" },
    { 0x7ACC, "level_guardproximityforcetohigherwarning" },
    { 0x7ACD, "level_guardproximityincreasewarning" },
    { 0x7ACE, "level_guardreactdamagelogic" },
    { 0x7ACF, "level_guardreactlogic" },
    { 0x7AD0, "level_guardremoveai" },
    { 0x7AD1, "level_guardremovecivilian" },
    { 0x7AD2, "level_guardsalertedclearstealthflaglogic" },
    { 0x7AD3, "level_guardsalertedfarahlogic" },
    { 0x7AD4, "level_guardsawplayergrenadealertlogic" },
    { 0x7AD5, "level_guardseenplayerjumpeffectslogic" },
    { 0x7AD6, "level_guardseenplayerjumplogic" },
    { 0x7AD7, "level_guardseenplayermeleeeffectslogic" },
    { 0x7AD8, "level_guardseenplayermeleelogic" },
    { 0x7AD9, "level_guardseenplayerpronelogic" },
    { 0x7ADA, "level_guardseeplayergrenadethrowlogic" },
    { 0x7ADB, "level_guardsendinstantdetectedlogic" },
    { 0x7ADC, "level_guardsetallalerted" },
    { 0x7ADD, "level_guardsetcivilianalertedanimation" },
    { 0x7ADE, "level_guardshootalertotherslogic" },
    { 0x7ADF, "level_guardshowholesightblockerclips" },
    { 0x7AE0, "level_guardsinstantlydetectplayerlogic" },
    { 0x7AE1, "level_guardspawncorpsestruct" },
    { 0x7AE2, "level_guardwhizbylogic" },
    { 0x7AE3, "level_hadirattachgasmask" },
    { 0x7AE4, "level_has_chyron" },
    { 0x7AE5, "level_has_start_points" },
    { 0x7AE6, "level_hellcannonfire" },
    { 0x7AE7, "level_hellcannonimpactlogic" },
    { 0x7AE8, "level_hellcannonmovetank" },
    { 0x7AE9, "level_inits" },
    { 0x7AEA, "level_isaiguard" },
    { 0x7AEB, "level_isgroupnamevolumealerted" },
    { 0x7AEC, "level_isgroupvolumealerted" },
    { 0x7AED, "level_isguardanimated" },
    { 0x7AEE, "level_isguardinforcethreatvolume" },
    { 0x7AEF, "level_module_struct" },
    { 0x7AF0, "level_notify" },
    { 0x7AF1, "level_notifylevelonenemycount" },
    { 0x7AF2, "level_notifylevelonenemydeathcount" },
    { 0x7AF3, "level_notifylevelonplayershotcount" },
    { 0x7AF4, "level_object" },
    { 0x7AF5, "level_objectiveadd" },
    { 0x7AF6, "level_objectivecreatefollowai" },
    { 0x7AF7, "level_objectivegetindex" },
    { 0x7AF8, "level_objectivegetpreviousindex" },
    { 0x7AF9, "level_objectivegetreservedstartindex" },
    { 0x7AFA, "level_objectiveincrementindex" },
    { 0x7AFB, "level_objectiveinit" },
    { 0x7AFC, "level_objectivesetindex" },
    { 0x7AFD, "level_offhandpickupinteractlogic" },
    { 0x7AFE, "level_offhandpickupsinit" },
    { 0x7AFF, "level_openbunkerouterdoor" },
    { 0x7B00, "level_playersightinteractunusablelogic" },
    { 0x7B01, "level_playersilencerinteractlogic" },
    { 0x7B02, "level_playersilencerinteractunusablelogic" },
    { 0x7B03, "level_playersilencerpickupsinit" },
    { 0x7B04, "level_playertouchingbarkovspeakersubtractvolume" },
    { 0x7B05, "level_posterstructslogic" },
    { 0x7B06, "level_redbarreldeathlogic" },
    { 0x7B07, "level_redbarreldistantlogic" },
    { 0x7B08, "level_redshirtcloseronscreen" },
    { 0x7B09, "level_redshirtgetclosestonscreen" },
    { 0x7B0A, "level_redshirtgetpossiblegoalnodes" },
    { 0x7B0B, "level_redshirtgetpossiblegoalnodesinheight" },
    { 0x7B0C, "level_redshirtmagicbulletshieldlogic" },
    { 0x7B0D, "level_redshirtshouldmove" },
    { 0x7B0E, "level_redshirtslogic" },
    { 0x7B0F, "level_resetguardlogic" },
    { 0x7B10, "level_sandstormfxlogic" },
    { 0x7B11, "level_setclearalertedgroupnamevolumes" },
    { 0x7B12, "level_setcustomdeathhintindex" },
    { 0x7B13, "level_setcustomoverridedeathhintindex" },
    { 0x7B14, "level_setendofscripting" },
    { 0x7B15, "level_setfailonfriendlyfire" },
    { 0x7B16, "level_setflag" },
    { 0x7B17, "level_setgroupvolumesalerted" },
    { 0x7B18, "level_setgroupvolumesalertedbygroupname" },
    { 0x7B19, "level_setredshirtgoalamount" },
    { 0x7B1A, "level_settle_time_get" },
    { 0x7B1B, "level_settle_time_wait" },
    { 0x7B1C, "level_setupoilpump" },
    { 0x7B1D, "level_sightpickupinteractlogic" },
    { 0x7B1E, "level_sightpickupsinit" },
    { 0x7B1F, "level_sirenofflogic" },
    { 0x7B20, "level_sirenonlogic" },
    { 0x7B21, "level_spawnalexstruct" },
    { 0x7B22, "level_spawnarmen" },
    { 0x7B23, "level_spawnbarkov" },
    { 0x7B24, "level_spawncivilianfarah" },
    { 0x7B25, "level_spawnfarah" },
    { 0x7B26, "level_spawnfarahanimatedbackpack" },
    { 0x7B27, "level_spawnflare" },
    { 0x7B28, "level_spawnhadir" },
    { 0x7B29, "level_spawnhadirtruck" },
    { 0x7B2A, "level_spawnredshirtfromspawner" },
    { 0x7B2B, "level_spawnredshirts" },
    { 0x7B2C, "level_spawnsoldierfarah" },
    { 0x7B2D, "level_spawnstaticflare" },
    { 0x7B2E, "level_spawnuncle" },
    { 0x7B2F, "level_specific_bot_targets" },
    { 0x7B30, "level_specific_dof" },
    { 0x7B31, "level_specific_player_interaction_monitor" },
    { 0x7B32, "level_specific_vo_callouts" },
    { 0x7B33, "level_specific_wait_for_interaction_triggered" },
    { 0x7B34, "level_teleportguard" },
    { 0x7B35, "level_trigger_should_abort" },
    { 0x7B36, "level_trigger_should_abort_melee" },
    { 0x7B37, "level_trigger_should_abort_ranged" },
    { 0x7B38, "level_tunnel_setup" },
    { 0x7B39, "level_turnknifeintooffhandpickup" },
    { 0x7B3A, "level_vfx" },
    { 0x7B3B, "level_vo_equipment_backpack" },
    { 0x7B3C, "level_waittillplayerclearedalertedguards" },
    { 0x7B3D, "levelflag" },
    { 0x7B3E, "levelflagclear" },
    { 0x7B3F, "levelflaginit" },
    { 0x7B40, "levelflags" },
    { 0x7B41, "levelflagset" },
    { 0x7B42, "levelflagwait" },
    { 0x7B43, "levelflagwaitopen" },
    { 0x7B44, "levelobjectives_init" },
    { 0x7B45, "levelprogressioncomplete" },
    { 0x7B46, "levelregisterobjectives" },
    { 0x7B47, "levels" },
    { 0x7B48, "lever" },
    { 0x7B49, "lgvdensity" },
    { 0x7B4A, "lgvmerge" },
    { 0x7B4B, "lgvmergesuffix" },
    { 0x7B4C, "lgvthin" },
    { 0x7B4D, "lgvthinpush" },
    { 0x7B4E, "lgvthinshrink" },
    { 0x7B4F, "lgvthinstable" },
    { 0x7B50, "life" },
    { 0x7B51, "life_left" },
    { 0x7B52, "life_link_active" },
    { 0x7B53, "life_linked" },
    { 0x7B54, "life_range_high" },
    { 0x7B55, "life_range_low" },
    { 0x7B56, "lifeboostactive" },
    { 0x7B57, "lifeid" },
    { 0x7B58, "lifelimitedallyonuse" },
    { 0x7B59, "lifelimitedenemyonuse" },
    { 0x7B5A, "lifepackoutlines" },
    { 0x7B5B, "lifepackowner" },
    { 0x7B5C, "lifespan" },
    { 0x7B5D, "lifetime" },
    { 0x7B5E, "lifetime_shot_count" },
    { 0x7B5F, "light_back_left_dead" },
    { 0x7B60, "light_back_right_dead" },
    { 0x7B61, "light_buried_mom" },
    { 0x7B62, "light_car_back" },
    { 0x7B63, "light_car_fill" },
    { 0x7B64, "light_car_rim" },
    { 0x7B65, "light_debug_draw" },
    { 0x7B66, "light_debug_print3d" },
    { 0x7B67, "light_debug_thread" },
    { 0x7B68, "light_dvars" },
    { 0x7B69, "light_enemies_separated" },
    { 0x7B6A, "light_enemy_deathfunc" },
    { 0x7B6B, "light_enemy_spawn_func" },
    { 0x7B6C, "light_enemy_stealth_filter" },
    { 0x7B6D, "light_entrance_gate" },
    { 0x7B6E, "light_flicker_loop" },
    { 0x7B6F, "light_flicker_on_off_loop" },
    { 0x7B70, "light_flicker_proc" },
    { 0x7B71, "light_front_high" },
    { 0x7B72, "light_front_left_dead" },
    { 0x7B73, "light_front_low" },
    { 0x7B74, "light_front_right_dead" },
    { 0x7B75, "light_lerp" },
    { 0x7B76, "light_meter_hint" },
    { 0x7B77, "light_meter_hud" },
    { 0x7B78, "light_model" },
    { 0x7B79, "light_not_destroyed" },
    { 0x7B7A, "light_on_touching" },
    { 0x7B7B, "light_pulse" },
    { 0x7B7C, "light_pulse_loop" },
    { 0x7B7D, "light_pulse_on_off_loop" },
    { 0x7B7E, "light_pulse_proc_iw7" },
    { 0x7B7F, "light_tank_activate" },
    { 0x7B80, "light_tank_adjustdriverturretammo" },
    { 0x7B81, "light_tank_adjustmissileammo" },
    { 0x7B82, "light_tank_adjustsmokeammo" },
    { 0x7B83, "light_tank_airdrop" },
    { 0x7B84, "light_tank_airdropinternal" },
    { 0x7B85, "light_tank_autodestruct" },
    { 0x7B86, "light_tank_canautodestruct" },
    { 0x7B87, "light_tank_cantimeout" },
    { 0x7B88, "light_tank_cantimeoutfromempty" },
    { 0x7B89, "light_tank_cantimeoutinternal" },
    { 0x7B8A, "light_tank_capture" },
    { 0x7B8B, "light_tank_cleardamagefeedbackforplayer" },
    { 0x7B8C, "light_tank_clearheavydamagefeedbackplayer" },
    { 0x7B8D, "light_tank_clearlightdamagefeedbackplayer" },
    { 0x7B8E, "light_tank_copyspawndata" },
    { 0x7B8F, "light_tank_cp_create" },
    { 0x7B90, "light_tank_cp_createfromstructs" },
    { 0x7B91, "light_tank_cp_delete" },
    { 0x7B92, "light_tank_cp_getspawnstructscallback" },
    { 0x7B93, "light_tank_cp_init" },
    { 0x7B94, "light_tank_cp_initdamage" },
    { 0x7B95, "light_tank_cp_initlate" },
    { 0x7B96, "light_tank_cp_initspawning" },
    { 0x7B97, "light_tank_cp_ondeathrespawncallback" },
    { 0x7B98, "light_tank_cp_onentervehicle" },
    { 0x7B99, "light_tank_cp_onexitvehicle" },
    { 0x7B9A, "light_tank_cp_spawncallback" },
    { 0x7B9B, "light_tank_cp_waitandspawn" },
    { 0x7B9C, "light_tank_create" },
    { 0x7B9D, "light_tank_createdriverturret" },
    { 0x7B9E, "light_tank_creategunnerturret" },
    { 0x7B9F, "light_tank_createheadicon" },
    { 0x7BA0, "light_tank_createobjective" },
    { 0x7BA1, "light_tank_deathcallback" },
    { 0x7BA2, "light_tank_deletenextframe" },
    { 0x7BA3, "light_tank_destroyheadicon" },
    { 0x7BA4, "light_tank_destroyobjective" },
    { 0x7BA5, "light_tank_detachvehiclefromairdropsequence" },
    { 0x7BA6, "light_tank_driverturretreload" },
    { 0x7BA7, "light_tank_endcapture" },
    { 0x7BA8, "light_tank_endmissilefireplayerfx" },
    { 0x7BA9, "light_tank_enterend" },
    { 0x7BAA, "light_tank_enterendinternal" },
    { 0x7BAB, "light_tank_enterstart" },
    { 0x7BAC, "light_tank_exitend" },
    { 0x7BAD, "light_tank_exitendinternal" },
    { 0x7BAE, "light_tank_explode" },
    { 0x7BAF, "light_tank_firemissile" },
    { 0x7BB0, "light_tank_firesmoke" },
    { 0x7BB1, "light_tank_firesmokeinternal" },
    { 0x7BB2, "light_tank_flippedendcallback" },
    { 0x7BB3, "light_tank_getdesiredspawnpositionfromplayer" },
    { 0x7BB4, "light_tank_getdropspawn" },
    { 0x7BB5, "light_tank_getdropspawnangles" },
    { 0x7BB6, "light_tank_getheadiconteam" },
    { 0x7BB7, "light_tank_getleveldata" },
    { 0x7BB8, "light_tank_getspawnstructscallback" },
    { 0x7BB9, "light_tank_hasdropspawns" },
    { 0x7BBA, "light_tank_heavydamagefeedbackforplayer" },
    { 0x7BBB, "light_tank_init" },
    { 0x7BBC, "light_tank_initentranceanimations" },
    { 0x7BBD, "light_tank_initfx" },
    { 0x7BBE, "light_tank_initializespawndata" },
    { 0x7BBF, "light_tank_initinteract" },
    { 0x7BC0, "light_tank_initlate" },
    { 0x7BC1, "light_tank_initoccupancy" },
    { 0x7BC2, "light_tank_initspawning" },
    { 0x7BC3, "light_tank_initspawns" },
    { 0x7BC4, "light_tank_initvehicleentranceanimations" },
    { 0x7BC5, "light_tank_initvo" },
    { 0x7BC6, "light_tank_land" },
    { 0x7BC7, "light_tank_lightdamagefeedbackforplayer" },
    { 0x7BC8, "light_tank_monitor" },
    { 0x7BC9, "light_tank_monitordrivermissilefire" },
    { 0x7BCA, "light_tank_monitordriversmokefire" },
    { 0x7BCB, "light_tank_monitordriverturretfire" },
    { 0x7BCC, "light_tank_monitordriverturretreload" },
    { 0x7BCD, "light_tank_monitorotherentdisconnect" },
    { 0x7BCE, "light_tank_monitorotherentjoined" },
    { 0x7BCF, "light_tank_mp_activate" },
    { 0x7BD0, "light_tank_mp_cankeepcapturing" },
    { 0x7BD1, "light_tank_mp_canstartcapture" },
    { 0x7BD2, "light_tank_mp_create" },
    { 0x7BD3, "light_tank_mp_createkillcament" },
    { 0x7BD4, "light_tank_mp_createothercaptureobject" },
    { 0x7BD5, "light_tank_mp_createownercaptureobject" },
    { 0x7BD6, "light_tank_mp_death" },
    { 0x7BD7, "light_tank_mp_delete" },
    { 0x7BD8, "light_tank_mp_deletecaptureobject" },
    { 0x7BD9, "light_tank_mp_deletecaptureobjects" },
    { 0x7BDA, "light_tank_mp_deletekillcament" },
    { 0x7BDB, "light_tank_mp_endcapture" },
    { 0x7BDC, "light_tank_mp_filterdropspawns" },
    { 0x7BDD, "light_tank_mp_getdropspawnignorelist" },
    { 0x7BDE, "light_tank_mp_getspawnstructscallback" },
    { 0x7BDF, "light_tank_mp_init" },
    { 0x7BE0, "light_tank_mp_initcapture" },
    { 0x7BE1, "light_tank_mp_initdamage" },
    { 0x7BE2, "light_tank_mp_initlate" },
    { 0x7BE3, "light_tank_mp_initmines" },
    { 0x7BE4, "light_tank_mp_initspawning" },
    { 0x7BE5, "light_tank_mp_monitorcaptureinternal" },
    { 0x7BE6, "light_tank_mp_monitorkillcament" },
    { 0x7BE7, "light_tank_mp_monitorothercapture" },
    { 0x7BE8, "light_tank_mp_monitorothercapturevisibility" },
    { 0x7BE9, "light_tank_mp_monitorownercapture" },
    { 0x7BEA, "light_tank_mp_monitorownercapturevisibility" },
    { 0x7BEB, "light_tank_mp_ondeathrespawncallback" },
    { 0x7BEC, "light_tank_mp_playerstartcapture" },
    { 0x7BED, "light_tank_mp_playerstopcapture" },
    { 0x7BEE, "light_tank_mp_setupcaptureobject" },
    { 0x7BEF, "light_tank_mp_shouldawardattacker" },
    { 0x7BF0, "light_tank_mp_spawncallback" },
    { 0x7BF1, "light_tank_mp_startcapture" },
    { 0x7BF2, "light_tank_mp_waitandspawn" },
    { 0x7BF3, "light_tank_place" },
    { 0x7BF4, "light_tank_playerisdriverandcanmissilelock" },
    { 0x7BF5, "light_tank_playmissilefireplayerfx" },
    { 0x7BF6, "light_tank_postmoddamagecallback" },
    { 0x7BF7, "light_tank_premoddamagecallback" },
    { 0x7BF8, "light_tank_reenter" },
    { 0x7BF9, "light_tank_setteamotherent" },
    { 0x7BFA, "light_tank_shouldautodestructfromdamage" },
    { 0x7BFB, "light_tank_spawn" },
    { 0x7BFC, "light_tank_startcapture" },
    { 0x7BFD, "light_tank_startfreefall" },
    { 0x7BFE, "light_tank_startmovefeedbackforplayer" },
    { 0x7BFF, "light_tank_stopexhaust" },
    { 0x7C00, "light_tank_stopmovefeedbackforplayer" },
    { 0x7C01, "light_tank_stoptreaddust" },
    { 0x7C02, "light_tank_supported" },
    { 0x7C03, "light_tank_timeout" },
    { 0x7C04, "light_tank_tryuse" },
    { 0x7C05, "light_tank_tryusefromstruct" },
    { 0x7C06, "light_tank_turretdustkickup" },
    { 0x7C07, "light_tank_updateautodestructui" },
    { 0x7C08, "light_tank_updatechassisanglesui" },
    { 0x7C09, "light_tank_updatedamagefeedback" },
    { 0x7C0A, "light_tank_updatedriverturretammoui" },
    { 0x7C0B, "light_tank_updateemptytimeout" },
    { 0x7C0C, "light_tank_updateexhaust" },
    { 0x7C0D, "light_tank_updateheadicon" },
    { 0x7C0E, "light_tank_updateheadiconforplayer" },
    { 0x7C0F, "light_tank_updateheadiconforplayeronjointeam" },
    { 0x7C10, "light_tank_updateheadiconimage" },
    { 0x7C11, "light_tank_updateheadiconowner" },
    { 0x7C12, "light_tank_updateheadiconteam" },
    { 0x7C13, "light_tank_updatemissileammoui" },
    { 0x7C14, "light_tank_updatemovefeedback" },
    { 0x7C15, "light_tank_updateowner" },
    { 0x7C16, "light_tank_updateplayeromnvarsonenter" },
    { 0x7C17, "light_tank_updatesmokeammoui" },
    { 0x7C18, "light_tank_updateteam" },
    { 0x7C19, "light_tank_updatetimeout" },
    { 0x7C1A, "light_tank_updatetimeoutui" },
    { 0x7C1B, "light_tank_updatetreaddust" },
    { 0x7C1C, "light_tank_updateturretanglesui" },
    { 0x7C1D, "light_the_fire_vo" },
    { 0x7C1E, "light_think" },
    { 0x7C1F, "light_toggle_loop" },
    { 0x7C20, "light_turn_off" },
    { 0x7C21, "light_turn_on" },
    { 0x7C22, "light_tut_light_watcher" },
    { 0x7C23, "light_tutorial_catchup" },
    { 0x7C24, "light_tutorial_events_watcher" },
    { 0x7C25, "light_tutorial_main" },
    { 0x7C26, "light_tutorial_start" },
    { 0x7C27, "light_type" },
    { 0x7C28, "lightarmor_lightarmor_disabled" },
    { 0x7C29, "lightarmor_modifydamage" },
    { 0x7C2A, "lightarmor_monitordeath" },
    { 0x7C2B, "lightarmor_set" },
    { 0x7C2C, "lightarmor_setfx" },
    { 0x7C2D, "lightarmor_unset" },
    { 0x7C2E, "lightarmor_updatehud" },
    { 0x7C2F, "lightarmorhp" },
    { 0x7C30, "lightback" },
    { 0x7C31, "lightbar_off" },
    { 0x7C32, "lightbar_on" },
    { 0x7C33, "lightbarstructs" },
    { 0x7C34, "lightfront" },
    { 0x7C35, "lightfxent" },
    { 0x7C36, "lightfxfunc" },
    { 0x7C37, "lightfxtag" },
    { 0x7C38, "lighting_alley_gas_attack_start" },
    { 0x7C39, "lighting_alley_to_apartments" },
    { 0x7C3A, "lighting_apartments_to_canal" },
    { 0x7C3B, "lighting_bunker" },
    { 0x7C3C, "lighting_bunker_start" },
    { 0x7C3D, "lighting_buried_carried_common" },
    { 0x7C3E, "lighting_buried_start" },
    { 0x7C3F, "lighting_canal_to_cafe" },
    { 0x7C40, "lighting_carried_start" },
    { 0x7C41, "lighting_disguise" },
    { 0x7C42, "lighting_dof_bunker" },
    { 0x7C43, "lighting_escape" },
    { 0x7C44, "lighting_flags" },
    { 0x7C45, "lighting_gas_progression" },
    { 0x7C46, "lighting_gas_start" },
    { 0x7C47, "lighting_get_bunker_lights" },
    { 0x7C48, "lighting_hero_leave" },
    { 0x7C49, "lighting_holster" },
    { 0x7C4A, "lighting_house_character" },
    { 0x7C4B, "lighting_house_enter_start" },
    { 0x7C4C, "lighting_house_exit_character" },
    { 0x7C4D, "lighting_in_apartments" },
    { 0x7C4E, "lighting_in_cafe" },
    { 0x7C4F, "lighting_interrogation" },
    { 0x7C50, "lighting_interrogation_intro_cinematic" },
    { 0x7C51, "lighting_interrogation_outro" },
    { 0x7C52, "lighting_interrogation_room" },
    { 0x7C53, "lighting_intro" },
    { 0x7C54, "lighting_intro_dof" },
    { 0x7C55, "lighting_leave" },
    { 0x7C56, "lighting_mansion_fire_1" },
    { 0x7C57, "lighting_mansion_fire_2" },
    { 0x7C58, "lighting_pistol_start" },
    { 0x7C59, "lighting_poppies_drive_start" },
    { 0x7C5A, "lighting_pre_alley_to_apartments" },
    { 0x7C5B, "lighting_setup_dvars" },
    { 0x7C5C, "lighting_setup_lights" },
    { 0x7C5D, "lighting_tunnel" },
    { 0x7C5E, "lighting_tunnels" },
    { 0x7C5F, "lighting_tunnels_dof" },
    { 0x7C60, "lightmapcount" },
    { 0x7C61, "lightmapcount_ng" },
    { 0x7C62, "lightmapscale" },
    { 0x7C63, "lightmapsize" },
    { 0x7C64, "lightmeter" },
    { 0x7C65, "lightmeter_lastcheckpos" },
    { 0x7C66, "lightmeter_lastchecktime" },
    { 0x7C67, "lightmeter_lerp_lightmeter" },
    { 0x7C68, "lightmeterdelay" },
    { 0x7C69, "lightoffroutine" },
    { 0x7C6A, "lightonroutine" },
    { 0x7C6B, "lightoverride" },
    { 0x7C6C, "lightpos" },
    { 0x7C6D, "lightreaction_lightorigin" },
    { 0x7C6E, "lightreaction_requesttime" },
    { 0x7C6F, "lights" },
    { 0x7C70, "lights_delayfxforframe" },
    { 0x7C71, "lights_lerp_off" },
    { 0x7C72, "lights_model_swap" },
    { 0x7C73, "lights_off" },
    { 0x7C74, "lights_off_internal" },
    { 0x7C75, "lights_off_thread" },
    { 0x7C76, "lights_on" },
    { 0x7C77, "lights_on_3f" },
    { 0x7C78, "lights_on_internal" },
    { 0x7C79, "lights_out_alarm_off" },
    { 0x7C7A, "lights_out_vo_seq" },
    { 0x7C7B, "lights_shot_01" },
    { 0x7C7C, "lights_shot_02" },
    { 0x7C7D, "lights_shot_02_reset" },
    { 0x7C7E, "lights_turn_off" },
    { 0x7C7F, "lights_turn_on" },
    { 0x7C80, "lightson" },
    { 0x7C81, "lightsource" },
    { 0x7C82, "lightsout_achievement_think" },
    { 0x7C83, "lightsout_targets" },
    { 0x7C84, "lightswitch_death_watcher" },
    { 0x7C85, "lightswitch_disable" },
    { 0x7C86, "lightswitch_disable_interact" },
    { 0x7C87, "lightswitch_enable_interact" },
    { 0x7C88, "lightswitch_init" },
    { 0x7C89, "lightswitch_interact_func" },
    { 0x7C8A, "lightswitch_interact_manager" },
    { 0x7C8B, "lightswitch_onoff" },
    { 0x7C8C, "lightswitch_postload_state_init" },
    { 0x7C8D, "lightswitch_send_stealth_event" },
    { 0x7C8E, "lightswitch_toggle" },
    { 0x7C8F, "lightswitch_toggle_debounce" },
    { 0x7C90, "lightswitch_trigger_notify" },
    { 0x7C91, "lightswitch_update_children" },
    { 0x7C92, "lightswitchinteraction" },
    { 0x7C93, "lighttag" },
    { 0x7C94, "lighttank" },
    { 0x7C95, "lighttankmovefeedbackenabled" },
    { 0x7C96, "lighttanks" },
    { 0x7C97, "lighttarget" },
    { 0x7C98, "lighttargetname" },
    { 0x7C99, "lightvalues" },
    { 0x7C9A, "lightweightscalar" },
    { 0x7C9B, "lilly_actor_dmg_func" },
    { 0x7C9C, "lilly_civ_reaction" },
    { 0x7C9D, "lilly_civ_shot" },
    { 0x7C9E, "lilly_entrance_draw" },
    { 0x7C9F, "lilly_terry" },
    { 0x7CA0, "lilly_white_kill" },
    { 0x7CA1, "lilly_white_time_out" },
    { 0x7CA2, "lillywhites_civs" },
    { 0x7CA3, "lillywhites_internal" },
    { 0x7CA4, "limit" },
    { 0x7CA5, "limit_dropped_weapons" },
    { 0x7CA6, "limitdecimalplaces" },
    { 0x7CA7, "limitstealthturning" },
    { 0x7CA8, "limpdownpct" },
    { 0x7CA9, "limpent" },
    { 0x7CAA, "limpmaxpitch" },
    { 0x7CAB, "limpmaxroll" },
    { 0x7CAC, "limpsteptime" },
    { 0x7CAD, "limpuppct" },
    { 0x7CAE, "line_debug" },
    { 0x7CAF, "line_interect_sphere" },
    { 0x7CB0, "line_on_ent" },
    { 0x7CB1, "line_queue" },
    { 0x7CB2, "line_to_plane_intersection" },
    { 0x7CB3, "linelengthsq" },
    { 0x7CB4, "lines" },
    { 0x7CB5, "linesegment" },
    { 0x7CB6, "link_aim_to" },
    { 0x7CB7, "link_driver" },
    { 0x7CB8, "link_org" },
    { 0x7CB9, "link_player_and_move" },
    { 0x7CBA, "link_player_to_arms" },
    { 0x7CBB, "link_player_to_rappel_scene" },
    { 0x7CBC, "link_player_to_rig" },
    { 0x7CBD, "link_player_to_rig_free_look" },
    { 0x7CBE, "link_player_to_rig_keep_weapon" },
    { 0x7CBF, "link_player_to_set_rig" },
    { 0x7CC0, "link_to_ambush_sniper_mover" },
    { 0x7CC1, "link_to_barkov" },
    { 0x7CC2, "link_to_rpg_enemy_mover" },
    { 0x7CC3, "link_to_sittag" },
    { 0x7CC4, "link_to_turret_enemy_mover" },
    { 0x7CC5, "linkcameratoball" },
    { 0x7CC6, "linkdoubledoors" },
    { 0x7CC7, "linked" },
    { 0x7CC8, "linked_bomb_id" },
    { 0x7CC9, "linked_ents" },
    { 0x7CCA, "linked_lights" },
    { 0x7CCB, "linked_to_coaster" },
    { 0x7CCC, "linked_to_player" },
    { 0x7CCD, "linked_wire_position_marker" },
    { 0x7CCE, "linkedaniments" },
    { 0x7CCF, "linkedent" },
    { 0x7CD0, "linkedents" },
    { 0x7CD1, "linkednodes_hinge" },
    { 0x7CD2, "linkednodes_knob" },
    { 0x7CD3, "linkedpents" },
    { 0x7CD4, "linkedsmartobjects" },
    { 0x7CD5, "linkedtovehicle" },
    { 0x7CD6, "linkparent" },
    { 0x7CD7, "linkparents" },
    { 0x7CD8, "linkplayertofarrah" },
    { 0x7CD9, "linktoblend" },
    { 0x7CDA, "linktoenabledflag" },
    { 0x7CDB, "linktoent" },
    { 0x7CDC, "linktoplayer" },
    { 0x7CDD, "linktoplayer_fire_chains" },
    { 0x7CDE, "linktovehicle" },
    { 0x7CDF, "list" },
    { 0x7CE0, "list_menu" },
    { 0x7CE1, "listaitypes" },
    { 0x7CE2, "listen_for" },
    { 0x7CE3, "listen_for_blocked_path" },
    { 0x7CE4, "listen_for_custom_proj_dvar" },
    { 0x7CE5, "listen_for_enemy_alert" },
    { 0x7CE6, "listen_for_exfil" },
    { 0x7CE7, "listen_for_exfil_heli_ready_to_land" },
    { 0x7CE8, "listen_for_super_triggered" },
    { 0x7CE9, "listen_to_hack_damage" },
    { 0x7CEA, "listencalloutremove" },
    { 0x7CEB, "listencancelberserk" },
    { 0x7CEC, "listendisconnectspotted" },
    { 0x7CED, "listenepictauntscriptablecancel" },
    { 0x7CEE, "listenforcapture" },
    { 0x7CEF, "listenforcapturekill" },
    { 0x7CF0, "listenforcinematicreplaydumpcmd" },
    { 0x7CF1, "listenforfirecomplete" },
    { 0x7CF2, "listenforheadequiptogggle" },
    { 0x7CF3, "listenforjumpmasterclaimluanotify" },
    { 0x7CF4, "listenforkill" },
    { 0x7CF5, "listenfortaunt" },
    { 0x7CF6, "listenfortauntinput" },
    { 0x7CF7, "listening_for_blocked_path" },
    { 0x7CF8, "listenjump" },
    { 0x7CF9, "listenkick" },
    { 0x7CFA, "listenkillstreakaction" },
    { 0x7CFB, "listhasattachment" },
    { 0x7CFC, "listoffoundturrets" },
    { 0x7CFD, "lit_models" },
    { 0x7CFE, "little_bird_cp_create" },
    { 0x7CFF, "little_bird_cp_createfromstructs" },
    { 0x7D00, "little_bird_cp_delete" },
    { 0x7D01, "little_bird_cp_getspawnstructscallback" },
    { 0x7D02, "little_bird_cp_init" },
    { 0x7D03, "little_bird_cp_initlate" },
    { 0x7D04, "little_bird_cp_initspawning" },
    { 0x7D05, "little_bird_cp_ondeathrespawncallback" },
    { 0x7D06, "little_bird_cp_onentervehicle" },
    { 0x7D07, "little_bird_cp_onexitvehicle" },
    { 0x7D08, "little_bird_cp_spawncallback" },
    { 0x7D09, "little_bird_cp_waitandspawn" },
    { 0x7D0A, "little_bird_create" },
    { 0x7D0B, "little_bird_creategunnerturret" },
    { 0x7D0C, "little_bird_deathcallback" },
    { 0x7D0D, "little_bird_deletenextframe" },
    { 0x7D0E, "little_bird_dmg_func" },
    { 0x7D0F, "little_bird_enterend" },
    { 0x7D10, "little_bird_enterendinternal" },
    { 0x7D11, "little_bird_enterstart" },
    { 0x7D12, "little_bird_exitend" },
    { 0x7D13, "little_bird_exitendinternal" },
    { 0x7D14, "little_bird_explode" },
    { 0x7D15, "little_bird_getspawnstructscallback" },
    { 0x7D16, "little_bird_givegunnerturret" },
    { 0x7D17, "little_bird_givetakegunnerturrettimeout" },
    { 0x7D18, "little_bird_init" },
    { 0x7D19, "little_bird_initfx" },
    { 0x7D1A, "little_bird_initinteract" },
    { 0x7D1B, "little_bird_initlate" },
    { 0x7D1C, "little_bird_initoccupancy" },
    { 0x7D1D, "little_bird_initspawning" },
    { 0x7D1E, "little_bird_mp_create" },
    { 0x7D1F, "little_bird_mp_delete" },
    { 0x7D20, "little_bird_mp_getspawnstructscallback" },
    { 0x7D21, "little_bird_mp_init" },
    { 0x7D22, "little_bird_mp_initspawning" },
    { 0x7D23, "little_bird_mp_ondeathrespawncallback" },
    { 0x7D24, "little_bird_mp_spawncallback" },
    { 0x7D25, "little_bird_mp_waitandspawn" },
    { 0x7D26, "little_bird_reenter" },
    { 0x7D27, "little_bird_spawnfunc" },
    { 0x7D28, "little_bird_takegunnerturret" },
    { 0x7D29, "littlebird_bulletdamage" },
    { 0x7D2A, "littlebird_damage_function" },
    { 0x7D2B, "littlebird_turrets_think" },
    { 0x7D2C, "littlebirdbankplunder" },
    { 0x7D2D, "littlebirdcrash" },
    { 0x7D2E, "littlebirddelete" },
    { 0x7D2F, "littlebirddescendtoextraction" },
    { 0x7D30, "littlebirddestroyed" },
    { 0x7D31, "littlebirde_getout_unlinks" },
    { 0x7D32, "littlebirdexplode" },
    { 0x7D33, "littlebirdleave" },
    { 0x7D34, "littlebirds" },
    { 0x7D35, "littlebirdstoreplunder" },
    { 0x7D36, "livelobbymatchstarttimer" },
    { 0x7D37, "livelobbyrestart" },
    { 0x7D38, "livelobbyroundendwait" },
    { 0x7D39, "livelobbystartcode" },
    { 0x7D3A, "living_ai_prethink" },
    { 0x7D3B, "lmapblurpass" },
    { 0x7D3C, "lmg_aim_1" },
    { 0x7D3D, "lmg_aim_2" },
    { 0x7D3E, "lmg_aim_3" },
    { 0x7D3F, "lmg_aim_4" },
    { 0x7D40, "lmg_aim_6" },
    { 0x7D41, "lmg_aim_7" },
    { 0x7D42, "lmg_aim_8" },
    { 0x7D43, "lmg_aim_9" },
    { 0x7D44, "lmg_aim_state" },
    { 0x7D45, "lmg_to_door" },
    { 0x7D46, "lmg_weapons_array" },
    { 0x7D47, "lmg_zero" },
    { 0x7D48, "lo_wait" },
    { 0x7D49, "load" },
    { 0x7D4A, "load_ai" },
    { 0x7D4B, "load_ai_goddriver" },
    { 0x7D4C, "load_all_wind" },
    { 0x7D4D, "load_binks" },
    { 0x7D4E, "load_cctv_transient" },
    { 0x7D4F, "load_combat0" },
    { 0x7D50, "load_combat0_loop" },
    { 0x7D51, "load_combat1" },
    { 0x7D52, "load_combat1_loop" },
    { 0x7D53, "load_combat2" },
    { 0x7D54, "load_combat2_loop" },
    { 0x7D55, "load_combat3" },
    { 0x7D56, "load_combat3_loop" },
    { 0x7D57, "load_combat4" },
    { 0x7D58, "load_combat4_loop" },
    { 0x7D59, "load_compound_anims_end_transient" },
    { 0x7D5A, "load_compound_transient" },
    { 0x7D5B, "load_debug_particles" },
    { 0x7D5C, "load_fx" },
    { 0x7D5D, "load_gametype_scripts_for_scriptdev" },
    { 0x7D5E, "load_hunt0" },
    { 0x7D5F, "load_hunt0_loop" },
    { 0x7D60, "load_hunt1" },
    { 0x7D61, "load_hunt1_loop" },
    { 0x7D62, "load_hunt2" },
    { 0x7D63, "load_hunt2_loop" },
    { 0x7D64, "load_hunt3" },
    { 0x7D65, "load_hunt3_loop" },
    { 0x7D66, "load_hunt4" },
    { 0x7D67, "load_hunt4_loop" },
    { 0x7D68, "load_hvt" },
    { 0x7D69, "load_lost0" },
    { 0x7D6A, "load_lost1" },
    { 0x7D6B, "load_lost2" },
    { 0x7D6C, "load_lost3" },
    { 0x7D6D, "load_lost4" },
    { 0x7D6E, "load_mechanics" },
    { 0x7D6F, "load_new_map" },
    { 0x7D70, "load_new_map_func" },
    { 0x7D71, "load_noise_father_reaction" },
    { 0x7D72, "load_noise_res_initial_reactions" },
    { 0x7D73, "load_noise_res_nags" },
    { 0x7D74, "load_noise0" },
    { 0x7D75, "load_noise1" },
    { 0x7D76, "load_noise1_res_reactions" },
    { 0x7D77, "load_noise2" },
    { 0x7D78, "load_noise3" },
    { 0x7D79, "load_noise4" },
    { 0x7D7A, "load_queue" },
    { 0x7D7B, "load_relic_catch_params" },
    { 0x7D7C, "load_relic_combos_from_table" },
    { 0x7D7D, "load_relics_from_playerdata" },
    { 0x7D7E, "load_relics_via_dvar" },
    { 0x7D7F, "load_ru1_killed_combat" },
    { 0x7D80, "load_ru1_killed_distract" },
    { 0x7D81, "load_ru1_killed_hunt" },
    { 0x7D82, "load_ru1_killed_lost" },
    { 0x7D83, "load_ru1_killed_spotted" },
    { 0x7D84, "load_ru1_pistol_shot_at" },
    { 0x7D85, "load_ru1_unspotted_pistol_idle_distract" },
    { 0x7D86, "load_ru2_killed_combat" },
    { 0x7D87, "load_ru2_killed_distract" },
    { 0x7D88, "load_ru2_killed_hunt" },
    { 0x7D89, "load_ru2_killed_lost" },
    { 0x7D8A, "load_ru2_killed_spotted" },
    { 0x7D8B, "load_ru2_pistol_shot_at" },
    { 0x7D8C, "load_ru2_unspotted_pistol_idle_distract" },
    { 0x7D8D, "load_rubble_civ1_2_phone_convo_01" },
    { 0x7D8E, "load_rubble_dad_yells_01" },
    { 0x7D8F, "load_rubble_farah_efforts" },
    { 0x7D90, "load_rubble_res1_calming_01" },
    { 0x7D91, "load_rubble_res1_yells_01" },
    { 0x7D92, "load_rubble_res1_yells_02" },
    { 0x7D93, "load_rubble_res1_yells_03" },
    { 0x7D94, "load_rubble_res2_yells_01" },
    { 0x7D95, "load_rubble_res2_yells_02" },
    { 0x7D96, "load_rubble_res2_yells_03" },
    { 0x7D97, "load_rubble_res3_yells_01" },
    { 0x7D98, "load_rubble_res3_yells_02" },
    { 0x7D99, "load_rubble_res3_yells_03" },
    { 0x7D9A, "load_rubble_res4_5_getwater_01" },
    { 0x7D9B, "load_rubble_res6_7_getrope_01" },
    { 0x7D9C, "load_scriptable_garage_door" },
    { 0x7D9D, "load_spotted0" },
    { 0x7D9E, "load_spotted1" },
    { 0x7D9F, "load_spotted2" },
    { 0x7DA0, "load_spotted3" },
    { 0x7DA1, "load_spotted4" },
    { 0x7DA2, "load_stealth_values_from_table" },
    { 0x7DA3, "load_surface_speed_vfx" },
    { 0x7DA4, "load_systems" },
    { 0x7DA5, "load_unharmed_pistol_combat_distract" },
    { 0x7DA6, "load_unharmed_pistol_fight_combat" },
    { 0x7DA7, "load_unharmed_pistol_fight_hunt" },
    { 0x7DA8, "load_unharmed_pistol_fight_lost" },
    { 0x7DA9, "load_unharmed_pistol_fight_spotted" },
    { 0x7DAA, "load_unharmed_pistol_hunt_distract" },
    { 0x7DAB, "load_unharmed_pistol_hunt_distract_end" },
    { 0x7DAC, "load_unharmed_pistol_hunt_distract_end_followup" },
    { 0x7DAD, "load_unharmed_pistol_idle_distract_end" },
    { 0x7DAE, "load_vfx" },
    { 0x7DAF, "load_wind" },
    { 0x7DB0, "loadassociatedkillstreakweapons" },
    { 0x7DB1, "loaded_weapons" },
    { 0x7DB2, "loadeventtable" },
    { 0x7DB3, "loadfromstructfn" },
    { 0x7DB4, "loadgamemodestatmap" },
    { 0x7DB5, "loadglobalfx" },
    { 0x7DB6, "loading_kids_into_trucks_scene" },
    { 0x7DB7, "loadingplayers" },
    { 0x7DB8, "loadout" },
    { 0x7DB9, "loadout_change_activate" },
    { 0x7DBA, "loadout_change_hint" },
    { 0x7DBB, "loadout_changed_flag" },
    { 0x7DBC, "loadout_clearperks" },
    { 0x7DBD, "loadout_clearplayer" },
    { 0x7DBE, "loadout_clearweapons" },
    { 0x7DBF, "loadout_editcachedclassstruct" },
    { 0x7DC0, "loadout_emptycacheofloadout" },
    { 0x7DC1, "loadout_forcearchetype" },
    { 0x7DC2, "loadout_gamemodeloadoutchanged" },
    { 0x7DC3, "loadout_getclassstruct" },
    { 0x7DC4, "loadout_getclassteam" },
    { 0x7DC5, "loadout_getclasstype" },
    { 0x7DC6, "loadout_getorbuildclassstruct" },
    { 0x7DC7, "loadout_getplayerstreaktype" },
    { 0x7DC8, "loadout_giveperk" },
    { 0x7DC9, "loadout_giveprimaryweapon" },
    { 0x7DCA, "loadout_givesecondaryweapon" },
    { 0x7DCB, "loadout_in_progress" },
    { 0x7DCC, "loadout_logloadout" },
    { 0x7DCD, "loadout_lognewlygivenloadout" },
    { 0x7DCE, "loadout_removeperk" },
    { 0x7DCF, "loadout_retry_completed" },
    { 0x7DD0, "loadout_updateabilities" },
    { 0x7DD1, "loadout_updateclass" },
    { 0x7DD2, "loadout_updateclasscallback" },
    { 0x7DD3, "loadout_updateclasscustom" },
    { 0x7DD4, "loadout_updateclassdefault" },
    { 0x7DD5, "loadout_updateclassfinalweapons" },
    { 0x7DD6, "loadout_updateclassfistweapons" },
    { 0x7DD7, "loadout_updateclassgamemode" },
    { 0x7DD8, "loadout_updateclassteam" },
    { 0x7DD9, "loadout_updatefieldupgrades" },
    { 0x7DDA, "loadout_updatehasnvg" },
    { 0x7DDB, "loadout_updateplayer" },
    { 0x7DDC, "loadout_updateplayeraccessory" },
    { 0x7DDD, "loadout_updateplayeractionslots" },
    { 0x7DDE, "loadout_updateplayerarchetype" },
    { 0x7DDF, "loadout_updateplayerequipment" },
    { 0x7DE0, "loadout_updateplayerexecution" },
    { 0x7DE1, "loadout_updateplayergesture" },
    { 0x7DE2, "loadout_updateplayerkillstreaks" },
    { 0x7DE3, "loadout_updateplayernvgs" },
    { 0x7DE4, "loadout_updateplayerperks" },
    { 0x7DE5, "loadout_updateplayerstreaktype" },
    { 0x7DE6, "loadout_updateplayersuper" },
    { 0x7DE7, "loadout_updateplayerweapons" },
    { 0x7DE8, "loadout_updatestreaktype" },
    { 0x7DE9, "loadout_updateweapondependentsettigns" },
    { 0x7DEA, "loadout_validateclass" },
    { 0x7DEB, "loadout_weapons" },
    { 0x7DEC, "loadoutaccessorydata" },
    { 0x7DED, "loadoutaccessorylogic" },
    { 0x7DEE, "loadoutaccessoryweapon" },
    { 0x7DEF, "loadoutarchetype" },
    { 0x7DF0, "loadoutchangeround" },
    { 0x7DF1, "loadoutcomplete" },
    { 0x7DF2, "loadoutequipmentprimary" },
    { 0x7DF3, "loadoutequipmentsecondary" },
    { 0x7DF4, "loadoutexecution" },
    { 0x7DF5, "loadoutextraequipmentprimary" },
    { 0x7DF6, "loadoutextraequipmentsecondary" },
    { 0x7DF7, "loadoutextraperks" },
    { 0x7DF8, "loadoutextrapowerprimary" },
    { 0x7DF9, "loadoutextrapowersecondary" },
    { 0x7DFA, "loadoutfieldupgrade1" },
    { 0x7DFB, "loadoutfieldupgrade2" },
    { 0x7DFC, "loadoutgesture" },
    { 0x7DFD, "loadouthasnvg" },
    { 0x7DFE, "loadoutindex" },
    { 0x7DFF, "loadoutkillstreak1" },
    { 0x7E00, "loadoutkillstreak2" },
    { 0x7E01, "loadoutkillstreak3" },
    { 0x7E02, "loadoutmeleeslot" },
    { 0x7E03, "loadoutperkoffhand" },
    { 0x7E04, "loadoutperks" },
    { 0x7E05, "loadoutperksfromgamemode" },
    { 0x7E06, "loadoutpowerprimary" },
    { 0x7E07, "loadoutpowersecondary" },
    { 0x7E08, "loadoutprimary" },
    { 0x7E09, "loadoutprimaryattachmentids" },
    { 0x7E0A, "loadoutprimaryattachments" },
    { 0x7E0B, "loadoutprimarycamo" },
    { 0x7E0C, "loadoutprimarycosmeticattachment" },
    { 0x7E0D, "loadoutprimaryfullname" },
    { 0x7E0E, "loadoutprimarylootitemid" },
    { 0x7E0F, "loadoutprimaryobject" },
    { 0x7E10, "loadoutprimarypaintjobid" },
    { 0x7E11, "loadoutprimaryreticle" },
    { 0x7E12, "loadoutprimarystickers" },
    { 0x7E13, "loadoutprimaryvariantid" },
    { 0x7E14, "loadoutprimaryweaponstickers" },
    { 0x7E15, "loadoutrigtrait" },
    { 0x7E16, "loadouts" },
    { 0x7E17, "loadoutsecondary" },
    { 0x7E18, "loadoutsecondaryattachmentids" },
    { 0x7E19, "loadoutsecondaryattachments" },
    { 0x7E1A, "loadoutsecondarycamo" },
    { 0x7E1B, "loadoutsecondarycosmeticattachment" },
    { 0x7E1C, "loadoutsecondaryfullname" },
    { 0x7E1D, "loadoutsecondarylootitemid" },
    { 0x7E1E, "loadoutsecondaryobject" },
    { 0x7E1F, "loadoutsecondaryreticle" },
    { 0x7E20, "loadoutsecondarystickers" },
    { 0x7E21, "loadoutsecondaryvariantid" },
    { 0x7E22, "loadoutsecondaryweaponstickers" },
    { 0x7E23, "loadoutsgroup" },
    { 0x7E24, "loadoutstandardperks" },
    { 0x7E25, "loadoutstreaksfilled" },
    { 0x7E26, "loadoutstreaktype" },
    { 0x7E27, "loadoutsuper" },
    { 0x7E28, "loadoutusingspecialist" },
    { 0x7E29, "loadoutvalues" },
    { 0x7E2A, "loadoutweapongiven" },
    { 0x7E2B, "loadplayerassets" },
    { 0x7E2C, "loadpointstable" },
    { 0x7E2D, "loadspawnlogicweights" },
    { 0x7E2E, "loadsupertable" },
    { 0x7E2F, "loadtable" },
    { 0x7E30, "loadvfx" },
    { 0x7E31, "loadweaponranktable" },
    { 0x7E32, "loadweapons" },
    { 0x7E33, "lobby_aq_alive_count_monitor" },
    { 0x7E34, "lobby_aq_door_guard" },
    { 0x7E35, "lobby_aq_make_vulnerable" },
    { 0x7E36, "lobby_breach_aq_rush" },
    { 0x7E37, "lobby_breach_civ_rush" },
    { 0x7E38, "lobby_catchup" },
    { 0x7E39, "lobby_dialogue_manager" },
    { 0x7E3A, "lobby_enemy_watcher" },
    { 0x7E3B, "lobby_main" },
    { 0x7E3C, "lobby_start" },
    { 0x7E3D, "lobbyteamselectenabled" },
    { 0x7E3E, "loc" },
    { 0x7E3F, "loc_array" },
    { 0x7E40, "loc_exposed_to_enemy_sniper" },
    { 0x7E41, "loc_exposed_to_enemy_turret" },
    { 0x7E42, "local" },
    { 0x7E43, "local_array" },
    { 0x7E44, "local_combo" },
    { 0x7E45, "local_init" },
    { 0x7E46, "local_object" },
    { 0x7E47, "local_waittill_any_return" },
    { 0x7E48, "locale" },
    { 0x7E49, "locale_5" },
    { 0x7E4A, "locale_type" },
    { 0x7E4B, "localeid" },
    { 0x7E4C, "localetriggers" },
    { 0x7E4D, "localizeammonamehack" },
    { 0x7E4E, "location" },
    { 0x7E4F, "location_add_last_callout_time" },
    { 0x7E50, "location_called_out_ever" },
    { 0x7E51, "location_called_out_recently" },
    { 0x7E52, "location_get_last_callout_time" },
    { 0x7E53, "locationaliases" },
    { 0x7E54, "locationangles" },
    { 0x7E55, "locationlastcallouttimes" },
    { 0x7E56, "locationmarked" },
    { 0x7E57, "locationmarking_structeqp" },
    { 0x7E58, "locationmarking_structveh" },
    { 0x7E59, "locationorigin" },
    { 0x7E5A, "locations" },
    { 0x7E5B, "locations_to_investigate" },
    { 0x7E5C, "locationselectionfunc" },
    { 0x7E5D, "lock" },
    { 0x7E5E, "lock_boost_nags" },
    { 0x7E5F, "lock_camera_on_vehicle_until_moving_camera" },
    { 0x7E60, "lock_door" },
    { 0x7E61, "lock_duration_before_firing" },
    { 0x7E62, "lock_in_death_anim" },
    { 0x7E63, "lock_on_progress" },
    { 0x7E64, "lock_player_headtracking_off" },
    { 0x7E65, "lock_pry_efforts" },
    { 0x7E66, "lock_pry_nags" },
    { 0x7E67, "lock_spawner_for_awhile" },
    { 0x7E68, "lock_to_ground" },
    { 0x7E69, "lockaction" },
    { 0x7E6A, "lockdoor" },
    { 0x7E6B, "locked" },
    { 0x7E6C, "locked_behind_interaction" },
    { 0x7E6D, "locked_on_cruise_missiles" },
    { 0x7E6E, "locked_target" },
    { 0x7E6F, "lockedforai" },
    { 0x7E70, "lockedlist" },
    { 0x7E71, "lockedmeleehealth" },
    { 0x7E72, "lockedoncallback" },
    { 0x7E73, "lockedonremovedcallback" },
    { 0x7E74, "lockedtarget" },
    { 0x7E75, "lockedtotarget" },
    { 0x7E76, "lockersceneclip" },
    { 0x7E77, "locklight" },
    { 0x7E78, "lockmonitor" },
    { 0x7E79, "lockonlaunchers_gettargetarray" },
    { 0x7E7A, "lockonlaunchers_gettargetvehiclerefs" },
    { 0x7E7B, "lockonoverrideduration" },
    { 0x7E7C, "lockontargetmarkergroup" },
    { 0x7E7D, "lockontargets" },
    { 0x7E7E, "lockplayerforremoteuavlaunch" },
    { 0x7E7F, "lockprompt" },
    { 0x7E80, "locksetspeed" },
    { 0x7E81, "lockstarttime" },
    { 0x7E82, "lockstrength" },
    { 0x7E83, "locktimeruntilcap" },
    { 0x7E84, "lockupdatingicons" },
    { 0x7E85, "locname" },
    { 0x7E86, "lodcullscale" },
    { 0x7E87, "log_blackbox" },
    { 0x7E88, "log_card_data" },
    { 0x7E89, "log_clientmatchdata" },
    { 0x7E8A, "log_event" },
    { 0x7E8B, "log_explosive_kills" },
    { 0x7E8C, "log_headshots_data" },
    { 0x7E8D, "log_matchdata" },
    { 0x7E8E, "log_matchdata_at_game_end" },
    { 0x7E8F, "log_weapons_data" },
    { 0x7E90, "logallplayerposthink" },
    { 0x7E91, "logattachmentstat" },
    { 0x7E92, "logattacker" },
    { 0x7E93, "logattackerkillevent" },
    { 0x7E94, "logattackerkillstreak" },
    { 0x7E95, "logattackers" },
    { 0x7E96, "logaward" },
    { 0x7E97, "logbadspawn" },
    { 0x7E98, "logchallenge" },
    { 0x7E99, "logcodefrontlineupdate" },
    { 0x7E9A, "logevent_assist" },
    { 0x7E9B, "logevent_awardgained" },
    { 0x7E9C, "logevent_explosion" },
    { 0x7E9D, "logevent_fieldupgradeactivated" },
    { 0x7E9E, "logevent_fieldupgradeearned" },
    { 0x7E9F, "logevent_fieldupgradeexpired" },
    { 0x7EA0, "logevent_frontlineupdate" },
    { 0x7EA1, "logevent_gameobject" },
    { 0x7EA2, "logevent_givempweaponxp" },
    { 0x7EA3, "logevent_giveplayerxp" },
    { 0x7EA4, "logevent_killstreakactivated" },
    { 0x7EA5, "logevent_killstreakavailable" },
    { 0x7EA6, "logevent_killstreakearned" },
    { 0x7EA7, "logevent_killstreakexpired" },
    { 0x7EA8, "logevent_message" },
    { 0x7EA9, "logevent_minimapcorners" },
    { 0x7EAA, "logevent_nvgtoggled" },
    { 0x7EAB, "logevent_path" },
    { 0x7EAC, "logevent_playerconnected" },
    { 0x7EAD, "logevent_playerdeath" },
    { 0x7EAE, "logevent_playerhealed" },
    { 0x7EAF, "logevent_playerkill" },
    { 0x7EB0, "logevent_playerspawn" },
    { 0x7EB1, "logevent_powerused" },
    { 0x7EB2, "logevent_reportgamescore" },
    { 0x7EB3, "logevent_reportstreakscore" },
    { 0x7EB4, "logevent_reportsuperscore" },
    { 0x7EB5, "logevent_scoreupdate" },
    { 0x7EB6, "logevent_sendplayerindexdata" },
    { 0x7EB7, "logevent_spawnpointupdate" },
    { 0x7EB8, "logevent_superearned" },
    { 0x7EB9, "logevent_superended" },
    { 0x7EBA, "logevent_tag" },
    { 0x7EBB, "logeventflag" },
    { 0x7EBC, "logextraspawn" },
    { 0x7EBD, "logextraspawninfothink" },
    { 0x7EBE, "logfinalstats" },
    { 0x7EBF, "logfrontlinetomatchrecording" },
    { 0x7EC0, "loggameevent" },
    { 0x7EC1, "loggedstate" },
    { 0x7EC2, "loggrenadedata" },
    { 0x7EC3, "logicvariantid" },
    { 0x7EC4, "logid" },
    { 0x7EC5, "logids" },
    { 0x7EC6, "loginckillchain" },
    { 0x7EC7, "loginitialspawnposition" },
    { 0x7EC8, "loginitialstats" },
    { 0x7EC9, "logkillsconfirmed" },
    { 0x7ECA, "logkillsdenied" },
    { 0x7ECB, "logkillstreakavailableevent" },
    { 0x7ECC, "logkillstreakevent" },
    { 0x7ECD, "logmatchtags" },
    { 0x7ECE, "logmultikill" },
    { 0x7ECF, "logoperatorsandskins" },
    { 0x7ED0, "logplayerdata" },
    { 0x7ED1, "logplayerdeath" },
    { 0x7ED2, "logplayerlife" },
    { 0x7ED3, "logplayers" },
    { 0x7ED4, "logplayerxp" },
    { 0x7ED5, "logscoreevent" },
    { 0x7ED6, "logspawndisabled" },
    { 0x7ED7, "logspawnpointsightupdate" },
    { 0x7ED8, "logstartingloadout" },
    { 0x7ED9, "logsupercommoneventdata" },
    { 0x7EDA, "logteamselection" },
    { 0x7EDB, "logvictimkillevent" },
    { 0x7EDC, "logweaponstat" },
    { 0x7EDD, "logxpscoreearnedinlife" },
    { 0x7EDE, "long_death_barkov" },
    { 0x7EDF, "long_low_health" },
    { 0x7EE0, "long_range_laser_ent_think" },
    { 0x7EE1, "long_range_laser_vfx_think" },
    { 0x7EE2, "longdeathanims" },
    { 0x7EE3, "longdeathdirectionalfunc" },
    { 0x7EE4, "longdeathfinal" },
    { 0x7EE5, "longdeathfinalgrenade" },
    { 0x7EE6, "longdeathgrenadepullnotetrackhandler" },
    { 0x7EE7, "longdeathidlesingleloop" },
    { 0x7EE8, "longdeathkillme" },
    { 0x7EE9, "longdeathmercyfinal" },
    { 0x7EEA, "longdeathnoncombat" },
    { 0x7EEB, "longdeathshouldshoot" },
    { 0x7EEC, "longdeathstarting" },
    { 0x7EED, "longdeathwithsidearm" },
    { 0x7EEE, "longdialoguecooldown" },
    { 0x7EEF, "longer_spawn_delay" },
    { 0x7EF0, "longestexposedapproachdist" },
    { 0x7EF1, "longregentime" },
    { 0x7EF2, "longshot" },
    { 0x7EF3, "look_ahead_point" },
    { 0x7EF4, "look_ahead_value" },
    { 0x7EF5, "look_at_and_outline_enemies" },
    { 0x7EF6, "look_at_damage_trigger" },
    { 0x7EF7, "look_at_ent" },
    { 0x7EF8, "look_at_ent_list" },
    { 0x7EF9, "look_at_jets" },
    { 0x7EFA, "look_at_player_3f" },
    { 0x7EFB, "look_at_player_start" },
    { 0x7EFC, "look_at_until" },
    { 0x7EFD, "look_check" },
    { 0x7EFE, "look_leftright_anim" },
    { 0x7EFF, "look_pos" },
    { 0x7F00, "look_updown_anim" },
    { 0x7F01, "lookahead_value" },
    { 0x7F02, "lookandaimdownpathdist" },
    { 0x7F03, "lookat_allowed" },
    { 0x7F04, "lookat_anims" },
    { 0x7F05, "lookat_aquired" },
    { 0x7F06, "lookat_brother_vo" },
    { 0x7F07, "lookat_delay" },
    { 0x7F08, "lookat_enabled" },
    { 0x7F09, "lookat_last" },
    { 0x7F0A, "lookat_nearby_players" },
    { 0x7F0B, "lookat_players" },
    { 0x7F0C, "lookat_random" },
    { 0x7F0D, "lookat_random_animloop_ender" },
    { 0x7F0E, "lookat_random_lite" },
    { 0x7F0F, "lookatatrnode" },
    { 0x7F10, "lookatduration" },
    { 0x7F11, "lookatentities" },
    { 0x7F12, "lookatentity" },
    { 0x7F13, "lookatplayerupdate" },
    { 0x7F14, "lookatpos" },
    { 0x7F15, "lookatstateoverride" },
    { 0x7F16, "lookback_scene_safe" },
    { 0x7F17, "lookback_start_audio_timeout" },
    { 0x7F18, "lookback_timeout_based_on_stance" },
    { 0x7F19, "lookcontrolsfrozen" },
    { 0x7F1A, "lookdelay" },
    { 0x7F1B, "lookdownpathdist" },
    { 0x7F1C, "lookduration" },
    { 0x7F1D, "lookforbettercover" },
    { 0x7F1E, "lookforbettercover_internal" },
    { 0x7F1F, "lookforbettercoverduetowallblock" },
    { 0x7F20, "lookforboundingoverwatchcover" },
    { 0x7F21, "lookforinitialcover" },
    { 0x7F22, "looking_at_different_wire" },
    { 0x7F23, "looking_at_entity" },
    { 0x7F24, "looking_at_wire" },
    { 0x7F25, "looking_up" },
    { 0x7F26, "lookingatent" },
    { 0x7F27, "lookorgs" },
    { 0x7F28, "lookout_getfarahnode" },
    { 0x7F29, "lookout_getvehicles" },
    { 0x7F2A, "lookout_main" },
    { 0x7F2B, "lookout_moveupladderlogic" },
    { 0x7F2C, "lookout_playerladderspeedscalinglogic" },
    { 0x7F2D, "lookout_playerspeedscalinglogic" },
    { 0x7F2E, "lookout_spawnvehicleriders" },
    { 0x7F2F, "lookout_spawnvehicles" },
    { 0x7F30, "lookout_start" },
    { 0x7F31, "lookout_teleportvehicletosplineend" },
    { 0x7F32, "lookout_vehicledeathlogic" },
    { 0x7F33, "lookout_vehicleenemydamagelogic" },
    { 0x7F34, "lookout_vehicleenemylogic" },
    { 0x7F35, "lookout_vehiclelogic" },
    { 0x7F36, "lookout_vehicleofflogic" },
    { 0x7F37, "looktimestarted" },
    { 0x7F38, "lookupanim" },
    { 0x7F39, "lookupanimarray" },
    { 0x7F3A, "lookupcurrentoperator" },
    { 0x7F3B, "lookupcurrentoperatorskin" },
    { 0x7F3C, "lookupdeathquote" },
    { 0x7F3D, "lookupotheroperator" },
    { 0x7F3E, "lookuppowerslot" },
    { 0x7F3F, "lookupvariantref" },
    { 0x7F40, "loop_anim" },
    { 0x7F41, "loop_control" },
    { 0x7F42, "loop_fx_on_vehicle_tag" },
    { 0x7F43, "loop_fx_sound" },
    { 0x7F44, "loop_fx_sound_interval" },
    { 0x7F45, "loop_fx_sound_interval_with_angles" },
    { 0x7F46, "loop_fx_sound_with_angles" },
    { 0x7F47, "loop_node" },
    { 0x7F48, "loop_or_anim" },
    { 0x7F49, "loop_or_delete" },
    { 0x7F4A, "loop_path" },
    { 0x7F4B, "loop_sound" },
    { 0x7F4C, "loop_sound_delete" },
    { 0x7F4D, "loop_sparks_vfx_on_enemy_hvt_vehicle" },
    { 0x7F4E, "loop_time" },
    { 0x7F4F, "loopanim" },
    { 0x7F50, "loopanimationentity" },
    { 0x7F51, "loopanimfortime" },
    { 0x7F52, "loopcount" },
    { 0x7F53, "looped" },
    { 0x7F54, "loopendernotified" },
    { 0x7F55, "loopendtime" },
    { 0x7F56, "looper" },
    { 0x7F57, "loopfunc" },
    { 0x7F58, "loopfx" },
    { 0x7F59, "loopfxstop" },
    { 0x7F5A, "loopfxthread" },
    { 0x7F5B, "loopidlesurrenderanimation" },
    { 0x7F5C, "looping_idle_animation" },
    { 0x7F5D, "loopingcoughaudio" },
    { 0x7F5E, "loopingcoughaudioissupressed" },
    { 0x7F5F, "loopingcoughaudiosupression" },
    { 0x7F60, "loopingsettingsanimationfunc" },
    { 0x7F61, "looplocallocksound" },
    { 0x7F62, "looplocalseeksound" },
    { 0x7F63, "loopmissilelauncherlockedfeedback" },
    { 0x7F64, "loopmissilelauncherlockingfeedback" },
    { 0x7F65, "loops" },
    { 0x7F66, "loopsound_ent" },
    { 0x7F67, "loopspectatorlocations" },
    { 0x7F68, "loopstingerlockedfeedback" },
    { 0x7F69, "loopstingerlockingfeedback" },
    { 0x7F6A, "looptriggeredeffect" },
    { 0x7F6B, "loopwaitanim" },
    { 0x7F6C, "looselinkto" },
    { 0x7F6D, "looselinktoend" },
    { 0x7F6E, "loot" },
    { 0x7F6F, "loot_create" },
    { 0x7F70, "loot_create_gunshop" },
    { 0x7F71, "loot_drop_check_func" },
    { 0x7F72, "loot_func" },
    { 0x7F73, "loot_marked" },
    { 0x7F74, "loot_pickup" },
    { 0x7F75, "loot_think" },
    { 0x7F76, "loot_type" },
    { 0x7F77, "lootammo" },
    { 0x7F78, "lootarmor" },
    { 0x7F79, "lootcaches" },
    { 0x7F7A, "lootcacheused" },
    { 0x7F7B, "looted_by" },
    { 0x7F7C, "lootforcearmordrop" },
    { 0x7F7D, "lootfunc" },
    { 0x7F7E, "lootfuncandnotification" },
    { 0x7F7F, "lootmarkerthink" },
    { 0x7F80, "lootnearbyitems" },
    { 0x7F81, "lootoffhand" },
    { 0x7F82, "lootoffhandhack" },
    { 0x7F83, "lootpassivesstructs" },
    { 0x7F84, "lootused" },
    { 0x7F85, "lootweaponcache" },
    { 0x7F86, "lootweaponrefs" },
    { 0x7F87, "los" },
    { 0x7F88, "los_req" },
    { 0x7F89, "loscheckoffset" },
    { 0x7F8A, "losersinteractable" },
    { 0x7F8B, "losfov" },
    { 0x7F8C, "lost" },
    { 0x7F8D, "lost_and_found_ent" },
    { 0x7F8E, "lost_and_found_primary_count" },
    { 0x7F8F, "lost_and_found_spot" },
    { 0x7F90, "lost_player" },
    { 0x7F91, "lostlocktime" },
    { 0x7F92, "lostsightlinetime" },
    { 0x7F93, "losttargettime" },
    { 0x7F94, "lotus_bomber_logic" },
    { 0x7F95, "lotus_bomber_track" },
    { 0x7F96, "lotus_decho_audio" },
    { 0x7F97, "low_cover_combat_areas" },
    { 0x7F98, "low_cover_combat_setup" },
    { 0x7F99, "low_entry" },
    { 0x7F9A, "low_threshold" },
    { 0x7F9B, "lowalpha" },
    { 0x7F9C, "lowarmorthreshold" },
    { 0x7F9D, "lowcovervolume" },
    { 0x7F9E, "lower_door" },
    { 0x7F9F, "lower_door_geo" },
    { 0x7FA0, "lower_floors_scriptables" },
    { 0x7FA1, "lower_level_jugg_properties" },
    { 0x7FA2, "lower_level_plane_combat_start" },
    { 0x7FA3, "lower_team_move_courtyard" },
    { 0x7FA4, "lower_weapon_damage" },
    { 0x7FA5, "loweredreacquiredtime" },
    { 0x7FA6, "lowerlimitcornersights" },
    { 0x7FA7, "lowerlimitfullsights" },
    { 0x7FA8, "lowermessage" },
    { 0x7FA9, "lowermessagefont" },
    { 0x7FAA, "lowermessages" },
    { 0x7FAB, "lowermessagethink" },
    { 0x7FAC, "lowertextfontsize" },
    { 0x7FAD, "lowertexty" },
    { 0x7FAE, "lowertextyalign" },
    { 0x7FAF, "lowertimer" },
    { 0x7FB0, "lowestavgaltitude_evaluate" },
    { 0x7FB1, "lowestcoverstanddeployposeis" },
    { 0x7FB2, "lowestgameskill" },
    { 0x7FB3, "lowventcovers" },
    { 0x7FB4, "lpcfeaturegated" },
    { 0x7FB5, "ls_anims_init" },
    { 0x7FB6, "ls_sunfill" },
    { 0x7FB7, "ls_sunfill2" },
    { 0x7FB8, "lt" },
    { 0x7FB9, "lt_attic_start" },
    { 0x7FBA, "lt_backyard_intro_start" },
    { 0x7FBB, "lt_backyard_start" },
    { 0x7FBC, "lt_ceiling" },
    { 0x7FBD, "lt_charge_explosion_02" },
    { 0x7FBE, "lt_dining_room_start" },
    { 0x7FBF, "lt_embassy_roof_start" },
    { 0x7FC0, "lt_end_fill1" },
    { 0x7FC1, "lt_end_fill2" },
    { 0x7FC2, "lt_end_fill3" },
    { 0x7FC3, "lt_end_key" },
    { 0x7FC4, "lt_end_rim" },
    { 0x7FC5, "lt_end_rim1" },
    { 0x7FC6, "lt_end_rimvol" },
    { 0x7FC7, "lt_escape_start" },
    { 0x7FC8, "lt_fill_farah" },
    { 0x7FC9, "lt_fourth_floor_start" },
    { 0x7FCA, "lt_garage_keycard" },
    { 0x7FCB, "lt_infil_helicopter_start" },
    { 0x7FCC, "lt_interior_main_start" },
    { 0x7FCD, "lt_intro_fill" },
    { 0x7FCE, "lt_intro_rim2" },
    { 0x7FCF, "lt_kitchen_start" },
    { 0x7FD0, "lt_price_attic_key" },
    { 0x7FD1, "lt_price_attic_laptop" },
    { 0x7FD2, "lt_price_attic_rim" },
    { 0x7FD3, "lt_room" },
    { 0x7FD4, "lt_safehouse_mic" },
    { 0x7FD5, "lt_saferoom_wolf_off" },
    { 0x7FD6, "lt_saferoom_wolf_on" },
    { 0x7FD7, "lt_second_floor_start" },
    { 0x7FD8, "lt_stairtrain1_start" },
    { 0x7FD9, "lt_stairtrain2_start" },
    { 0x7FDA, "lt_stairtrain3_start" },
    { 0x7FDB, "lt_start_fill" },
    { 0x7FDC, "lt_start_key" },
    { 0x7FDD, "lt_third_floor_start" },
    { 0x7FDE, "lt_truck_crash_start" },
    { 0x7FDF, "lt_tunnel_fill" },
    { 0x7FE0, "lt_tunnel_fill_farah" },
    { 0x7FE1, "lt_tunnel_fill_hadir" },
    { 0x7FE2, "lt_tunnel_omni" },
    { 0x7FE3, "lt_wall" },
    { 0x7FE4, "lt_windowfill" },
    { 0x7FE5, "lua_objective_complete" },
    { 0x7FE6, "lua_objective_incomplete" },
    { 0x7FE7, "lua_progress_bar_think" },
    { 0x7FE8, "lua_progress_bar_think_loop" },
    { 0x7FE9, "lua_string_index" },
    { 0x7FEA, "luahud" },
    { 0x7FEB, "lui_callbacks" },
    { 0x7FEC, "lui_registercallback" },
    { 0x7FED, "luinotifylistener" },
    { 0x7FEE, "luinotifywatcherforcpsystems" },
    { 0x7FEF, "lumber_danger_path_taken" },
    { 0x7FF0, "lvgmerge" },
    { 0x7FF1, "lvgthinpush" },
    { 0x7FF2, "lvgthinstable" },
    { 0x7FF3, "lvl" },
    { 0x7FF4, "lz" },
    { 0x7FF5, "lz_struct" },
    { 0x7FF6, "m_bfiring" },
    { 0x7FF7, "machete_struct" },
    { 0x7FF8, "made_sound" },
    { 0x7FF9, "madeavailabletime" },
    { 0x7FFA, "madedamageable" },
    { 0x7FFB, "mag" },
    { 0x7FFC, "mag_array" },
    { 0x7FFD, "mag_size" },
    { 0x7FFE, "magcount" },
    { 0x7FFF, "magic_bullet_death_detection" },
    { 0x8000, "magic_bullet_safe" },
    { 0x8001, "magic_bullet_shield" },
    { 0x8002, "magic_bullet_volley" },
    { 0x8003, "magic_clip_fix" },
    { 0x8004, "magic_distance" },
    { 0x8005, "magic_flare_launch" },
    { 0x8006, "magic_flash_enemy_vo" },
    { 0x8007, "magic_grenade_chance" },
    { 0x8008, "magic_grenade_launch_think" },
    { 0x8009, "magic_grenade_toss" },
    { 0x800A, "magic_grenades" },
    { 0x800B, "magic_gun_clear_target" },
    { 0x800C, "magic_gun_create_weapon" },
    { 0x800D, "magic_gun_delete" },
    { 0x800E, "magic_gun_fire" },
    { 0x800F, "magic_gun_search_around_ent" },
    { 0x8010, "magic_gun_set_target" },
    { 0x8011, "magic_gun_set_tracking_speed" },
    { 0x8012, "magic_gun_stop_firing" },
    { 0x8013, "magic_gun_stop_search_around" },
    { 0x8014, "magic_gun_stop_tracking" },
    { 0x8015, "magic_gun_track_ent" },
    { 0x8016, "magic_heli_fire" },
    { 0x8017, "magic_heli_fire_target" },
    { 0x8018, "magic_heli_squibs" },
    { 0x8019, "magic_molotov_fake_think" },
    { 0x801A, "magic_molotov_think" },
    { 0x801B, "magic_rpg_trig" },
    { 0x801C, "magic_smoke_launch" },
    { 0x801D, "magic_weapons" },
    { 0x801E, "magicbullet_burst" },
    { 0x801F, "magicbullets_at_window" },
    { 0x8020, "magicreloadwhenreachenemy" },
    { 0x8021, "main_basement" },
    { 0x8022, "main_basement_tunnel" },
    { 0x8023, "main_breached_gate" },
    { 0x8024, "main_cast_dialog_actor_check" },
    { 0x8025, "main_coldopen_bink" },
    { 0x8026, "main_collapse" },
    { 0x8027, "main_comp_1f" },
    { 0x8028, "main_comp_2f" },
    { 0x8029, "main_comp_3f" },
    { 0x802A, "main_door_nag" },
    { 0x802B, "main_downstairs" },
    { 0x802C, "main_driver" },
    { 0x802D, "main_intro" },
    { 0x802E, "main_lb_infil" },
    { 0x802F, "main_lb_unload" },
    { 0x8030, "main_mine" },
    { 0x8031, "main_mp" },
    { 0x8032, "main_passenger" },
    { 0x8033, "main_reunion" },
    { 0x8034, "main_shaft" },
    { 0x8035, "main_storage" },
    { 0x8036, "main_storage_oil" },
    { 0x8037, "main_storage_split" },
    { 0x8038, "main_tea_room" },
    { 0x8039, "main_thread" },
    { 0x803A, "main_truck" },
    { 0x803B, "main_truck_compromise" },
    { 0x803C, "main_turrets" },
    { 0x803D, "main_vehicle_interact" },
    { 0x803E, "main_wolf" },
    { 0x803F, "maindoor" },
    { 0x8040, "maindoor_damage_watcher" },
    { 0x8041, "maindoorcleanup" },
    { 0x8042, "mainpiece" },
    { 0x8043, "maintacops" },
    { 0x8044, "maintacopsinit" },
    { 0x8045, "maintacopspostinit" },
    { 0x8046, "maintain_speed_with_player_vehicle" },
    { 0x8047, "mainturret" },
    { 0x8048, "mainturret_attack" },
    { 0x8049, "mainturret_idle" },
    { 0x804A, "mainturretchild" },
    { 0x804B, "mainturretinit" },
    { 0x804C, "mainturretoff" },
    { 0x804D, "mainturreton" },
    { 0x804E, "maintvdestructibles" },
    { 0x804F, "majoritycapprogress" },
    { 0x8050, "make_ac130_drone_config" },
    { 0x8051, "make_ai_normal" },
    { 0x8052, "make_ai_story_only" },
    { 0x8053, "make_ai_usable" },
    { 0x8054, "make_alias_group" },
    { 0x8055, "make_allied" },
    { 0x8056, "make_array" },
    { 0x8057, "make_bulletdrop_weapon" },
    { 0x8058, "make_camera_anchor" },
    { 0x8059, "make_camera_point" },
    { 0x805A, "make_civ_usable" },
    { 0x805B, "make_civs_flee" },
    { 0x805C, "make_collection_config" },
    { 0x805D, "make_combat_icon_on_at" },
    { 0x805E, "make_critical_target_icon_on_ai" },
    { 0x805F, "make_cruise_missile" },
    { 0x8060, "make_cruise_missile_target_ent" },
    { 0x8061, "make_cruise_missile_warhead" },
    { 0x8062, "make_cruise_missile_warhead_target_ent" },
    { 0x8063, "make_debris" },
    { 0x8064, "make_discrete_trigger" },
    { 0x8065, "make_enemies_ignore_you" },
    { 0x8066, "make_entity_sentient_cp" },
    { 0x8067, "make_entity_sentient_mp" },
    { 0x8068, "make_fake_character_model" },
    { 0x8069, "make_false_positive_dots" },
    { 0x806A, "make_guys_leave_truck" },
    { 0x806B, "make_hostage_drop_override_data" },
    { 0x806C, "make_hostage_extract_objective" },
    { 0x806D, "make_hostage_usable" },
    { 0x806E, "make_hvi_usable" },
    { 0x806F, "make_incendiary_shottie" },
    { 0x8070, "make_informant_usable" },
    { 0x8071, "make_interceptor_missile_target_anchor" },
    { 0x8072, "make_light_flicker" },
    { 0x8073, "make_light_pulse" },
    { 0x8074, "make_picc_sniper_weapon" },
    { 0x8075, "make_player_and_price_non_story" },
    { 0x8076, "make_player_and_price_story_only" },
    { 0x8077, "make_price_ar" },
    { 0x8078, "make_price_pistol" },
    { 0x8079, "make_price_rifle" },
    { 0x807A, "make_randomized_slot_index_list" },
    { 0x807B, "make_real_ai_think" },
    { 0x807C, "make_reaper_drone" },
    { 0x807D, "make_reaper_missile_target_ent" },
    { 0x807E, "make_room_and_activate_trigger" },
    { 0x807F, "make_room_for_ai" },
    { 0x8080, "make_scout_config" },
    { 0x8081, "make_scout_detonate_config" },
    { 0x8082, "make_script_model_civ" },
    { 0x8083, "make_script_model_civ_child" },
    { 0x8084, "make_script_model_civ_child_female" },
    { 0x8085, "make_script_model_civ_female" },
    { 0x8086, "make_script_model_civ_wh" },
    { 0x8087, "make_script_model_russian" },
    { 0x8088, "make_sniper_bullet" },
    { 0x8089, "make_stealth_meter_on_ai" },
    { 0x808A, "make_suicide_truck" },
    { 0x808B, "make_tag_origin" },
    { 0x808C, "make_team_and_slot_number_struct" },
    { 0x808D, "make_team_id_one_team_and_slot_number_struct" },
    { 0x808E, "make_team_id_zero_team_and_slot_number_struct" },
    { 0x808F, "make_traindoors_outlines_disabled_ks" },
    { 0x8090, "make_turret_lmg_config" },
    { 0x8091, "make_turret_minigun_config" },
    { 0x8092, "make_turret_sniper_config" },
    { 0x8093, "make_turret_wheelson_config" },
    { 0x8094, "make_vehicle_seat" },
    { 0x8095, "make_visible_notsolid" },
    { 0x8096, "make_visible_to_missile_defense_player" },
    { 0x8097, "make_weapon" },
    { 0x8098, "make_weapon_and_attach" },
    { 0x8099, "make_weapon_model" },
    { 0x809A, "make_weapon_random" },
    { 0x809B, "make_weapon_special" },
    { 0x809C, "makeac130flyaway" },
    { 0x809D, "makeallies" },
    { 0x809E, "makeallplayerstatsreadonly" },
    { 0x809F, "makeallplayerstatswritable" },
    { 0x80A0, "makearray" },
    { 0x80A1, "makebrowinner" },
    { 0x80A2, "makec130pathparamsstruct" },
    { 0x80A3, "makechopperseatplayerusable" },
    { 0x80A4, "makechopperseatteamusable" },
    { 0x80A5, "makecranked" },
    { 0x80A6, "makecrateunusable" },
    { 0x80A7, "makecrateusable" },
    { 0x80A8, "makedamageable" },
    { 0x80A9, "makeenemyusable" },
    { 0x80AA, "makeenterexittrigger" },
    { 0x80AB, "makeexecuteentity" },
    { 0x80AC, "makeexplosivetargetablebyai" },
    { 0x80AD, "makeexplosiveunusable" },
    { 0x80AE, "makeexplosiveunusuabletag" },
    { 0x80AF, "makeexplosiveusable" },
    { 0x80B0, "makeexplosiveusableinternal" },
    { 0x80B1, "makeexplosiveusabletag" },
    { 0x80B2, "makehelipath" },
    { 0x80B3, "makehelitype" },
    { 0x80B4, "makeitemfromcrate" },
    { 0x80B5, "makeitemfromequipname" },
    { 0x80B6, "makeitemsfromcrate" },
    { 0x80B7, "makejailknifeatprisonspawn" },
    { 0x80B8, "makekillcamdata" },
    { 0x80B9, "makekillstreakavailable" },
    { 0x80BA, "makelaststandinvuln" },
    { 0x80BB, "makelzextractionvisuals" },
    { 0x80BC, "makenewpod" },
    { 0x80BD, "makepathparamsstruct" },
    { 0x80BE, "makepathstruct" },
    { 0x80BF, "makepersonalweaponfromcrate" },
    { 0x80C0, "makeplayercranked" },
    { 0x80C1, "makeplayerstatgroupreadonly" },
    { 0x80C2, "makeplayerstatgroupwritable" },
    { 0x80C3, "makeplayerstatreadonly" },
    { 0x80C4, "makeplayerstatwritable" },
    { 0x80C5, "makeradioactive" },
    { 0x80C6, "makeradioinactive" },
    { 0x80C7, "makerallypoint" },
    { 0x80C8, "makereviveentity" },
    { 0x80C9, "makereviveicon" },
    { 0x80CA, "makereviveiconentity" },
    { 0x80CB, "makereviveteamusable" },
    { 0x80CC, "makesafehouseclipsolid" },
    { 0x80CD, "makesolid" },
    { 0x80CE, "maketeamusable" },
    { 0x80CF, "maketerrorists" },
    { 0x80D0, "makeweaponfromcrate" },
    { 0x80D1, "manage_fake_health" },
    { 0x80D2, "manage_oscillation" },
    { 0x80D3, "managebus" },
    { 0x80D4, "managec130spawns" },
    { 0x80D5, "managecurprogress" },
    { 0x80D6, "managedroppedents" },
    { 0x80D7, "managefists" },
    { 0x80D8, "managegate" },
    { 0x80D9, "manageheadicons" },
    { 0x80DA, "manageinteractivecombattargets" },
    { 0x80DB, "manageinteractiveslowmo" },
    { 0x80DC, "managelightbarstack" },
    { 0x80DD, "managelink" },
    { 0x80DE, "manageoutlineactive" },
    { 0x80DF, "manageoutlinecleanup" },
    { 0x80E0, "manageoutlines" },
    { 0x80E1, "manageoutlineswatchplayersaddedtojail" },
    { 0x80E2, "manageovertimestate" },
    { 0x80E3, "manageplayerindarkvolume" },
    { 0x80E4, "manageplayerregen" },
    { 0x80E5, "manageposarray" },
    { 0x80E6, "managepowerbuttonuse" },
    { 0x80E7, "manager_thread" },
    { 0x80E8, "managereloadammo" },
    { 0x80E9, "managespawnprotection" },
    { 0x80EA, "managespotteromnvars" },
    { 0x80EB, "managesquadcameraposition" },
    { 0x80EC, "manageswitchhintlight" },
    { 0x80ED, "managetimeout" },
    { 0x80EE, "manageuseweapon" },
    { 0x80EF, "managevehiclecameraposition" },
    { 0x80F0, "manageweaponstartingammo" },
    { 0x80F1, "manipulate_createfx_ents" },
    { 0x80F2, "manipulate_ent_cleanup" },
    { 0x80F3, "manipulate_ent_death_think" },
    { 0x80F4, "manipulate_ent_setup" },
    { 0x80F5, "manpile_monitor" },
    { 0x80F6, "manpile_monitor_core_loop" },
    { 0x80F7, "manpile_monitor_cull_fov" },
    { 0x80F8, "manpile_monitor_cull_ideal" },
    { 0x80F9, "manpile_monitor_cull_urgent" },
    { 0x80FA, "manpile_monitor_cull_weapons" },
    { 0x80FB, "manpile_monitor_flush_all" },
    { 0x80FC, "manpile_monitor_initialize" },
    { 0x80FD, "manpile_monitor_print" },
    { 0x80FE, "manpile_monitor_reset_fov" },
    { 0x80FF, "mansion_escalation_guys" },
    { 0x8100, "mansion_escalation_spawn_think" },
    { 0x8101, "mansion_escalation_spawnfunc" },
    { 0x8102, "mansion_lights_off_audio" },
    { 0x8103, "mansion_waypoint_cleanup" },
    { 0x8104, "mansion_waypoint_think" },
    { 0x8105, "mantle" },
    { 0x8106, "mantle_give_viewlook" },
    { 0x8107, "mantle_over_wall" },
    { 0x8108, "mantleangles" },
    { 0x8109, "mantlecur" },
    { 0x810A, "mantleoffset" },
    { 0x810B, "manual_linkto" },
    { 0x810C, "manual_revive_location" },
    { 0x810D, "manual_shooting_logic" },
    { 0x810E, "manual_target" },
    { 0x810F, "manual_think" },
    { 0x8110, "manual_turret_createhintobject" },
    { 0x8111, "manual_turret_equipment_wrapper" },
    { 0x8112, "manual_turret_getenemyplayers" },
    { 0x8113, "manual_turret_gettargetmarker" },
    { 0x8114, "manual_turret_monitordamage" },
    { 0x8115, "manualdropthink" },
    { 0x8116, "manualinitbattlechatter" },
    { 0x8117, "manuallyjoiningkillstreak" },
    { 0x8118, "manualoverridewindmaterial" },
    { 0x8119, "manualpickuptrigger" },
    { 0x811A, "manualreviveinspec" },
    { 0x811B, "manualspeed" },
    { 0x811C, "manualtarget" },
    { 0x811D, "manualturret_addtooutlinelist" },
    { 0x811E, "manualturret_applyoverlay" },
    { 0x811F, "manualturret_create" },
    { 0x8120, "manualturret_delaydeletemarker" },
    { 0x8121, "manualturret_delayplacementinstructions" },
    { 0x8122, "manualturret_delayscriptabledelete" },
    { 0x8123, "manualturret_disablecrouchprone" },
    { 0x8124, "manualturret_disableenemyoutlines" },
    { 0x8125, "manualturret_disablefire" },
    { 0x8126, "manualturret_disableplayerdismantleonconnect" },
    { 0x8127, "manualturret_disableplayerpickuponconnect" },
    { 0x8128, "manualturret_disableplayeruseonconnect" },
    { 0x8129, "manualturret_disownonaction" },
    { 0x812A, "manualturret_enableenemyoutlineafterprotection" },
    { 0x812B, "manualturret_enableenemyoutlines" },
    { 0x812C, "manualturret_enableenemyoutlinesonconnect" },
    { 0x812D, "manualturret_endplayeruse" },
    { 0x812E, "manualturret_endturretonplayer" },
    { 0x812F, "manualturret_endturretuseonkill" },
    { 0x8130, "manualturret_endturretusewatch" },
    { 0x8131, "manualturret_handledeathdamage" },
    { 0x8132, "manualturret_makealltriggersusable" },
    { 0x8133, "manualturret_modifydamage" },
    { 0x8134, "manualturret_removefromoutlinelist" },
    { 0x8135, "manualturret_removeoutlineondeath" },
    { 0x8136, "manualturret_removeoverlay" },
    { 0x8137, "manualturret_restoreoutlineonspawn" },
    { 0x8138, "manualturret_setcarried" },
    { 0x8139, "manualturret_setinactive" },
    { 0x813A, "manualturret_setplaced" },
    { 0x813B, "manualturret_setturretmodel" },
    { 0x813C, "manualturret_switchbacklastweapon" },
    { 0x813D, "manualturret_toggleallowactions" },
    { 0x813E, "manualturret_watchammotracker" },
    { 0x813F, "manualturret_watchdamage" },
    { 0x8140, "manualturret_watchdeath" },
    { 0x8141, "manualturret_watchdelayedpickup" },
    { 0x8142, "manualturret_watchdismantle" },
    { 0x8143, "manualturret_watchdisown" },
    { 0x8144, "manualturret_watchpickup" },
    { 0x8145, "manualturret_watchplacement" },
    { 0x8146, "manualturret_watchplayerangles" },
    { 0x8147, "manualturret_watchtimeout" },
    { 0x8148, "manualturret_watchuse" },
    { 0x8149, "map_check" },
    { 0x814A, "map_ent_index" },
    { 0x814B, "map_extents" },
    { 0x814C, "map_height" },
    { 0x814D, "map_interaction_func" },
    { 0x814E, "map_is_early_in_the_game" },
    { 0x814F, "map_width" },
    { 0x8150, "mapangleindextonumpad" },
    { 0x8151, "mapbasedobjectiverules" },
    { 0x8152, "mapboundrycorners" },
    { 0x8153, "mapbounds" },
    { 0x8154, "mapcenter" },
    { 0x8155, "mapcircle" },
    { 0x8156, "mapconfigexists" },
    { 0x8157, "mapconfigs" },
    { 0x8158, "mapcornercenter" },
    { 0x8159, "mapcorners" },
    { 0x815A, "mapcornervector" },
    { 0x815B, "mapcustombotkillstreakfunc" },
    { 0x815C, "mapcustomkillstreakfunc" },
    { 0x815D, "mapequipmentweaponforref" },
    { 0x815E, "mapmarkermodeenabled" },
    { 0x815F, "mapname" },
    { 0x8160, "mapobjectiveicon" },
    { 0x8161, "mappatchborders" },
    { 0x8162, "mappedtargetsarray" },
    { 0x8163, "mappointinfo" },
    { 0x8164, "mappositions" },
    { 0x8165, "mapsafecorners" },
    { 0x8166, "mapselectdircounter" },
    { 0x8167, "mapselectpickcounter" },
    { 0x8168, "mapsize" },
    { 0x8169, "mapsupportsbasejumping" },
    { 0x816A, "mapweapon" },
    { 0x816B, "marine_advance_faketarget_shoot_handler" },
    { 0x816C, "marine_advance_with_util" },
    { 0x816D, "marine_aim_at_door" },
    { 0x816E, "marine_airstrike_bombing_run" },
    { 0x816F, "marine_airstrike_group" },
    { 0x8170, "marine_airstrike_rumble" },
    { 0x8171, "marine_airstrike_single" },
    { 0x8172, "marine_bedroom_clear_handler" },
    { 0x8173, "marine_callsign_generate_list_init" },
    { 0x8174, "marine_callsign_picker" },
    { 0x8175, "marine_clear_callsign_on_death" },
    { 0x8176, "marine_cowabunga_advance" },
    { 0x8177, "marine_cowabunga_advance_to_goal" },
    { 0x8178, "marine_demeanor_control" },
    { 0x8179, "marine_dialog_struct" },
    { 0x817A, "marine_disarm_nag" },
    { 0x817B, "marine_flood_spawner_think" },
    { 0x817C, "marine_groundfloor_room_clearing_manager" },
    { 0x817D, "marine_house_color_handler" },
    { 0x817E, "marine_mg_dialogue" },
    { 0x817F, "marine_mghouse_stackup" },
    { 0x8180, "marine_path_util" },
    { 0x8181, "marine_pre_ied_disable_pushable" },
    { 0x8182, "marine_pre_ied_disable_pushable_manager" },
    { 0x8183, "marine_retreat_advance" },
    { 0x8184, "marine_rooftop_reach_and_idle" },
    { 0x8185, "marine_room_clear_node" },
    { 0x8186, "marine_set_pacifist" },
    { 0x8187, "marine_stairwell_respawn_monitor" },
    { 0x8188, "marine_teleport_handler" },
    { 0x8189, "marine01_check_if_in_position" },
    { 0x818A, "marine02_check_if_in_position" },
    { 0x818B, "marine03_check_if_in_position" },
    { 0x818C, "marines_autosave" },
    { 0x818D, "marines_autosave_thread" },
    { 0x818E, "marines_background_init" },
    { 0x818F, "marines_breach" },
    { 0x8190, "marines_catchup_to_building" },
    { 0x8191, "marines_checkpoint_forcespawn_allies" },
    { 0x8192, "marines_end_mission" },
    { 0x8193, "marines_group_a_movement_to_alley" },
    { 0x8194, "marines_group_b_movement_to_alley" },
    { 0x8195, "marines_intro_glanceback" },
    { 0x8196, "marines_lookatentity" },
    { 0x8197, "marines_los_checks" },
    { 0x8198, "marines_movement_to_ied" },
    { 0x8199, "marines_objectives" },
    { 0x819A, "marines_player_setup" },
    { 0x819B, "marines_precache" },
    { 0x819C, "marines_push_to_house_handler" },
    { 0x819D, "marines_snakecam_exit_clear" },
    { 0x819E, "marines_snakecam_exit_cleared" },
    { 0x819F, "marines_starts" },
    { 0x81A0, "marines_stoplookat" },
    { 0x81A1, "marines_transients" },
    { 0x81A2, "marines_tripwire_defused_tracker" },
    { 0x81A3, "marines_tripwire_detonation_tracker" },
    { 0x81A4, "marines_tripwire_monitor" },
    { 0x81A5, "marines_wolf_takedown_cleared" },
    { 0x81A6, "marines_wolf_takedown_hint_clear" },
    { 0x81A7, "marines_wolf_tripwire_cleared" },
    { 0x81A8, "marines_wolf_tripwire_hint_clear" },
    { 0x81A9, "mark_ai" },
    { 0x81AA, "mark_all_civs" },
    { 0x81AB, "mark_completed" },
    { 0x81AC, "mark_cruise_missile_as_locked_on" },
    { 0x81AD, "mark_dangerous_nodes" },
    { 0x81AE, "mark_detonate_targets" },
    { 0x81AF, "mark_emp_effects" },
    { 0x81B0, "mark_enemies" },
    { 0x81B1, "mark_enemies_snapshot" },
    { 0x81B2, "mark_enemy_as_identified" },
    { 0x81B3, "mark_event_active" },
    { 0x81B4, "mark_event_completed" },
    { 0x81B5, "mark_group_as_killable" },
    { 0x81B6, "mark_heli" },
    { 0x81B7, "mark_hero_as_kidnapper_target" },
    { 0x81B8, "mark_ied_as_identified" },
    { 0x81B9, "mark_ied_controller_as_identified" },
    { 0x81BA, "mark_laser_end_ent" },
    { 0x81BB, "mark_never_remove" },
    { 0x81BC, "mark_objective_failed" },
    { 0x81BD, "mark_player_as_sniper_target" },
    { 0x81BE, "mark_seen_this_player_this_frame" },
    { 0x81BF, "mark_selected_terrorist_respawner" },
    { 0x81C0, "mark_speaker" },
    { 0x81C1, "mark_vehicle_as_friendly_target_group" },
    { 0x81C2, "mark_vehicles" },
    { 0x81C3, "markasrelaysource" },
    { 0x81C4, "markassixthsensesource" },
    { 0x81C5, "markdangerzoneonminimap" },
    { 0x81C6, "marked_by_hybrid" },
    { 0x81C7, "marked_by_overwatch" },
    { 0x81C8, "marked_by_overwatch_scan" },
    { 0x81C9, "marked_critical_enemy_ai" },
    { 0x81CA, "marked_enemies" },
    { 0x81CB, "marked_enemy_ai" },
    { 0x81CC, "marked_ents" },
    { 0x81CD, "marked_for_challenge" },
    { 0x81CE, "marked_for_death" },
    { 0x81CF, "marked_shared_fate_fnf" },
    { 0x81D0, "markedbyboomperk" },
    { 0x81D1, "markedentindex" },
    { 0x81D2, "markedentities_think" },
    { 0x81D3, "markedentitieslifeindicices" },
    { 0x81D4, "markedents" },
    { 0x81D5, "markedentsinqueue" },
    { 0x81D6, "markedfortoma" },
    { 0x81D7, "markedomnvar" },
    { 0x81D8, "markedplayers" },
    { 0x81D9, "markeduioff" },
    { 0x81DA, "markeduion" },
    { 0x81DB, "markempsignatures" },
    { 0x81DC, "markenemytarget" },
    { 0x81DD, "markent" },
    { 0x81DE, "markent_getclassperkicon" },
    { 0x81DF, "markent_gettargetmarkergroup" },
    { 0x81E0, "markent_getweaponicon" },
    { 0x81E1, "markent_watchmarkingentstatus" },
    { 0x81E2, "markent_watchmarkingentstatus_cp" },
    { 0x81E3, "markent_watchtargetstatus" },
    { 0x81E4, "markequipment_monitorlook" },
    { 0x81E5, "markequipment_updatestate" },
    { 0x81E6, "markequipmentstate" },
    { 0x81E7, "marker" },
    { 0x81E8, "marker_vfx" },
    { 0x81E9, "marker_watchdisownedtimeout" },
    { 0x81EA, "marker_watchdisownedtimeoutinternal" },
    { 0x81EB, "markeractivate" },
    { 0x81EC, "markerid" },
    { 0x81ED, "markerowner" },
    { 0x81EE, "markerthrown" },
    { 0x81EF, "market_animatedscenecivilianlogic" },
    { 0x81F0, "market_animatedscenedialoguelogic" },
    { 0x81F1, "market_animatedsceneenemylogic" },
    { 0x81F2, "market_animatedscenelogic" },
    { 0x81F3, "market_barkovspeakerlogic" },
    { 0x81F4, "market_bullyciviliandamagelogic" },
    { 0x81F5, "market_bullydamageanimationcleanup" },
    { 0x81F6, "market_bullydialoguelogic" },
    { 0x81F7, "market_bullyentitydeletedcleanup" },
    { 0x81F8, "market_bullyscenelogic" },
    { 0x81F9, "market_dialoguelogic" },
    { 0x81FA, "market_farahlogic" },
    { 0x81FB, "market_farahstayaheadlogic" },
    { 0x81FC, "market_getanimatedcivilians" },
    { 0x81FD, "market_getanimatedenemies" },
    { 0x81FE, "market_getanimationstruct" },
    { 0x81FF, "market_getcivilians" },
    { 0x8200, "market_getenemies" },
    { 0x8201, "market_getenemyspawners" },
    { 0x8202, "market_getfarahpath" },
    { 0x8203, "market_getinteriortrigger" },
    { 0x8204, "market_guarddogthreatlogic" },
    { 0x8205, "market_guardsalertedfarahlogic" },
    { 0x8206, "market_interiorsceneaudiologic" },
    { 0x8207, "market_interiorscenedialoguelogic" },
    { 0x8208, "market_interiorsceneenemyanimationlogic" },
    { 0x8209, "market_interiorscenelogic" },
    { 0x820A, "market_main" },
    { 0x820B, "market_setupconstructionscenelogic" },
    { 0x820C, "market_spawnanimatedcivilians" },
    { 0x820D, "market_spawnanimatedenemies" },
    { 0x820E, "market_spawnbullycivilian" },
    { 0x820F, "market_spawnbullyenemy" },
    { 0x8210, "market_spawncivilians" },
    { 0x8211, "market_spawnenemies" },
    { 0x8212, "market_start" },
    { 0x8213, "market_wallalogic" },
    { 0x8214, "markflash" },
    { 0x8215, "markfordetete" },
    { 0x8216, "markgameended" },
    { 0x8217, "markingent" },
    { 0x8218, "markingtarget" },
    { 0x8219, "markingtime" },
    { 0x821A, "marklocation" },
    { 0x821B, "marklocation_watchmarkentstatus" },
    { 0x821C, "marktarget_execute" },
    { 0x821D, "marktarget_init" },
    { 0x821E, "marktarget_run" },
    { 0x821F, "marktargetlaser" },
    { 0x8220, "markupascenderstruct" },
    { 0x8221, "markupdateheadicon" },
    { 0x8222, "markupdateheadiconallplayers" },
    { 0x8223, "markworldposition" },
    { 0x8224, "mars" },
    { 0x8225, "mask" },
    { 0x8226, "mask_anim" },
    { 0x8227, "mask_death_function" },
    { 0x8228, "mask_exploders_in_volume" },
    { 0x8229, "mask_fail_function" },
    { 0x822A, "mask_in_hand" },
    { 0x822B, "mask_init" },
    { 0x822C, "mask_interactives_in_volumes" },
    { 0x822D, "mask_is_on" },
    { 0x822E, "mask_remove_fade" },
    { 0x822F, "mask_remove_helo_react" },
    { 0x8230, "masked_exploder" },
    { 0x8231, "maskobjectivetoplayerssquad" },
    { 0x8232, "maskomnvar" },
    { 0x8233, "mass_execution_a" },
    { 0x8234, "mass_execution_b" },
    { 0x8235, "master" },
    { 0x8236, "masterdoorratescale" },
    { 0x8237, "masterswitches" },
    { 0x8238, "match_end_delay" },
    { 0x8239, "matchbonus" },
    { 0x823A, "matchbrushestozones" },
    { 0x823B, "matchcountdowntime" },
    { 0x823C, "matchdata" },
    { 0x823D, "matchdata_data_type" },
    { 0x823E, "matchdata_struct" },
    { 0x823F, "matchdataattachmentstatsenabled" },
    { 0x8240, "matchdatalifeindex" },
    { 0x8241, "matchendingsoonleaderdialog" },
    { 0x8242, "matches" },
    { 0x8243, "matchexposednodeorientation" },
    { 0x8244, "matchforfeittimer" },
    { 0x8245, "matchforfeittimer_internal" },
    { 0x8246, "matchfxexploder" },
    { 0x8247, "matchmakinggame" },
    { 0x8248, "matchmakingmatch" },
    { 0x8249, "matchreceventcountline" },
    { 0x824A, "matchrecevents" },
    { 0x824B, "matchrecording_dump" },
    { 0x824C, "matchrecording_eventcharmap" },
    { 0x824D, "matchrecording_frontlinelogid" },
    { 0x824E, "matchrecording_generateid" },
    { 0x824F, "matchrecording_getfileheaderarray" },
    { 0x8250, "matchrecording_getrecordingtype" },
    { 0x8251, "matchrecording_glog_addheader" },
    { 0x8252, "matchrecording_glog_dump" },
    { 0x8253, "matchrecording_inceventlinecount" },
    { 0x8254, "matchrecording_init" },
    { 0x8255, "matchrecording_isenabled" },
    { 0x8256, "matchrecording_logallplayerposthink" },
    { 0x8257, "matchrecording_logevent" },
    { 0x8258, "matchrecording_logeventmsg" },
    { 0x8259, "matchrecording_logeventplayername" },
    { 0x825A, "matchrecording_loggameendstats" },
    { 0x825B, "matchrecording_onplayerconnect" },
    { 0x825C, "matchrecording_scriptdata_dump" },
    { 0x825D, "matchrecording_scriptdata_openfileaddheader" },
    { 0x825E, "matchrecording_scriptdata_openfileappend" },
    { 0x825F, "matchrecording_scriptdata_openfilewrite" },
    { 0x8260, "matchrecording_teammap" },
    { 0x8261, "matchrecording_type" },
    { 0x8262, "matchrecording_usereventthink" },
    { 0x8263, "matchrecording_validaterecordingtype" },
    { 0x8264, "matchrecording_vehiclecleanupthink" },
    { 0x8265, "matchrecording_vehicletrackingthink" },
    { 0x8266, "matchrecording_vehiclewatcher" },
    { 0x8267, "matchrules_allowcustomclasses" },
    { 0x8268, "matchrules_damagemultiplier" },
    { 0x8269, "matchrules_droptime" },
    { 0x826A, "matchrules_enemyflagradar" },
    { 0x826B, "matchrules_randomize" },
    { 0x826C, "matchrules_switchteamdisabled" },
    { 0x826D, "matchrules_vampirism" },
    { 0x826E, "matchstarttimer" },
    { 0x826F, "matchstarttimer_internal" },
    { 0x8270, "matchstarttimerperplayer_internal" },
    { 0x8271, "matchstarttimerskip" },
    { 0x8272, "matchstarttimerwaitforplayers" },
    { 0x8273, "matchstats" },
    { 0x8274, "material_swap" },
    { 0x8275, "material1" },
    { 0x8276, "material2" },
    { 0x8277, "material3" },
    { 0x8278, "material4" },
    { 0x8279, "math_getchance" },
    { 0x827A, "math_pointoncircle" },
    { 0x827B, "math_pointonellipse" },
    { 0x827C, "math_pointonlemniscate" },
    { 0x827D, "max_agents_override" },
    { 0x827E, "max_ai" },
    { 0x827F, "max_angle_horiz" },
    { 0x8280, "max_angle_vert" },
    { 0x8281, "max_concurrent_player_count" },
    { 0x8282, "max_count" },
    { 0x8283, "max_deaths" },
    { 0x8284, "max_delay" },
    { 0x8285, "max_detection_sq" },
    { 0x8286, "max_dir_fails" },
    { 0x8287, "max_drones" },
    { 0x8288, "max_duration" },
    { 0x8289, "max_dynamic_spawners" },
    { 0x828A, "max_effort_effect" },
    { 0x828B, "max_effort_ratio" },
    { 0x828C, "max_elite" },
    { 0x828D, "max_enemies" },
    { 0x828E, "max_enemy_count" },
    { 0x828F, "max_entries" },
    { 0x8290, "max_fake_health" },
    { 0x8291, "max_fakeactors" },
    { 0x8292, "max_gun_game_level" },
    { 0x8293, "max_gun_game_weapon_name" },
    { 0x8294, "max_health" },
    { 0x8295, "max_health_cap" },
    { 0x8296, "max_heavy" },
    { 0x8297, "max_in_group" },
    { 0x8298, "max_intensity" },
    { 0x8299, "max_nav_offset" },
    { 0x829A, "max_num" },
    { 0x829B, "max_pap_func" },
    { 0x829C, "max_player_distance" },
    { 0x829D, "max_plays" },
    { 0x829E, "max_randomness" },
    { 0x829F, "max_relevant_spawn_dist" },
    { 0x82A0, "max_self_revive_machine_use" },
    { 0x82A1, "max_shaft_level_index" },
    { 0x82A2, "max_size" },
    { 0x82A3, "max_sniper_burst_delay_time" },
    { 0x82A4, "max_spawn_dist_sq" },
    { 0x82A5, "max_speed" },
    { 0x82A6, "max_static_spawned_enemies" },
    { 0x82A7, "max_suicide_bombers" },
    { 0x82A8, "max_technical_health" },
    { 0x82A9, "max_times" },
    { 0x82AA, "max_wait" },
    { 0x82AB, "max_wait_between_repeat" },
    { 0x82AC, "max_wait_for_infil" },
    { 0x82AD, "max_wait_for_infil_to_start" },
    { 0x82AE, "max_warnings" },
    { 0x82AF, "max_x" },
    { 0x82B0, "max_y" },
    { 0x82B1, "max_yaw_left" },
    { 0x82B2, "max_yaw_right" },
    { 0x82B3, "max_z" },
    { 0x82B4, "maxactivations" },
    { 0x82B5, "maxactivationsalt" },
    { 0x82B6, "maxalertdelay" },
    { 0x82B7, "maxalertlevel" },
    { 0x82B8, "maxallowedteamkills" },
    { 0x82B9, "maxallymarines" },
    { 0x82BA, "maxalpha" },
    { 0x82BB, "maxamount" },
    { 0x82BC, "maxanglecheckpitchdelta" },
    { 0x82BD, "maxanglecheckyawdelta" },
    { 0x82BE, "maxangledot" },
    { 0x82BF, "maxcasts" },
    { 0x82C0, "maxcharges" },
    { 0x82C1, "maxclients" },
    { 0x82C2, "maxcombatdist" },
    { 0x82C3, "maxcount" },
    { 0x82C4, "maxcounts" },
    { 0x82C5, "maxcurrency" },
    { 0x82C6, "maxdeaths" },
    { 0x82C7, "maxdirections" },
    { 0x82C8, "maxdist" },
    { 0x82C9, "maxdistance" },
    { 0x82CA, "maxdistancecallout" },
    { 0x82CB, "maxdistancesq" },
    { 0x82CC, "maxemissive" },
    { 0x82CD, "maxenemysightfraction" },
    { 0x82CE, "maxents" },
    { 0x82CF, "maxescalationvalue" },
    { 0x82D0, "maxfails" },
    { 0x82D1, "maxflashbangtime" },
    { 0x82D2, "maxfocusdist" },
    { 0x82D3, "maxfontscale" },
    { 0x82D4, "maxgameevents" },
    { 0x82D5, "maxgamemodes" },
    { 0x82D6, "maxgamemodescorehistory" },
    { 0x82D7, "maxheight" },
    { 0x82D8, "maxhqtanks" },
    { 0x82D9, "maximum" },
    { 0x82DA, "maximum_in_fov" },
    { 0x82DB, "maximum_weapons" },
    { 0x82DC, "maxinstancecount" },
    { 0x82DD, "maxjumpingenemysightfraction" },
    { 0x82DE, "maxjumpsightvalue" },
    { 0x82DF, "maxkillcamdelay" },
    { 0x82E0, "maxkillstreaks" },
    { 0x82E1, "maxkillstreaksavailable" },
    { 0x82E2, "maxlife" },
    { 0x82E3, "maxlightstopsperframe" },
    { 0x82E4, "maxlives" },
    { 0x82E5, "maxlogclients" },
    { 0x82E6, "maxmove" },
    { 0x82E7, "maxmovespeedsqr" },
    { 0x82E8, "maxnamelength" },
    { 0x82E9, "maxnumawardsperplayer" },
    { 0x82EA, "maxnumchallengesperplayer" },
    { 0x82EB, "maxperplayerexplosives" },
    { 0x82EC, "maxplayercount" },
    { 0x82ED, "maxplayerdist" },
    { 0x82EE, "maxplayers" },
    { 0x82EF, "maxplayerspawninfluencedistsquared" },
    { 0x82F0, "maxplayerspeeddist" },
    { 0x82F1, "maxqueue" },
    { 0x82F2, "maxrank" },
    { 0x82F3, "maxrolls" },
    { 0x82F4, "maxscale" },
    { 0x82F5, "maxshotinterval" },
    { 0x82F6, "maxsightvalue" },
    { 0x82F7, "maxspawndisttohomebase" },
    { 0x82F8, "maxspeakers" },
    { 0x82F9, "maxspeed" },
    { 0x82FA, "maxspreadshotsperframe" },
    { 0x82FB, "maxsquadsize" },
    { 0x82FC, "maxsquadwait" },
    { 0x82FD, "maxsupersactivated" },
    { 0x82FE, "maxsupersavailable" },
    { 0x82FF, "maxsupersexpired" },
    { 0x8300, "maxtags" },
    { 0x8301, "maxteamsize" },
    { 0x8302, "maxthreat" },
    { 0x8303, "maxthreat_enemy" },
    { 0x8304, "maxtime" },
    { 0x8305, "maxtracktime" },
    { 0x8306, "maxturn" },
    { 0x8307, "maxuses" },
    { 0x8308, "maxvehiclecount" },
    { 0x8309, "maxvehiclesallowed" },
    { 0x830A, "maxvests" },
    { 0x830B, "maxvisibility_shouldupdate" },
    { 0x830C, "maxvisibility_thread" },
    { 0x830D, "maxvisibiltyupdate_disabled" },
    { 0x830E, "maxweaponranks" },
    { 0x830F, "maxxp" },
    { 0x8310, "maxzdiff" },
    { 0x8311, "maydolaststand" },
    { 0x8312, "maydoupwardsdeath" },
    { 0x8313, "mayhem_end" },
    { 0x8314, "mayhem_start" },
    { 0x8315, "mayonlydie" },
    { 0x8316, "mayprocessmerits" },
    { 0x8317, "mayshoot" },
    { 0x8318, "mayshootwhilemoving" },
    { 0x8319, "mayspawn" },
    { 0x831A, "maythrowdoublegrenade" },
    { 0x831B, "mb_init" },
    { 0x831C, "mbsource1" },
    { 0x831D, "mbsource2" },
    { 0x831E, "md_vo" },
    { 0x831F, "mdl_allow_damage_jammers" },
    { 0x8320, "meansofdeath" },
    { 0x8321, "measure" },
    { 0x8322, "measure_origin" },
    { 0x8323, "med_effort_effect" },
    { 0x8324, "med_effort_ratio" },
    { 0x8325, "med_transport_cp_create" },
    { 0x8326, "med_transport_cp_createfromstructs" },
    { 0x8327, "med_transport_cp_delete" },
    { 0x8328, "med_transport_cp_getspawnstructscallback" },
    { 0x8329, "med_transport_cp_init" },
    { 0x832A, "med_transport_cp_initlate" },
    { 0x832B, "med_transport_cp_initspawning" },
    { 0x832C, "med_transport_cp_ondeathrespawncallback" },
    { 0x832D, "med_transport_cp_spawncallback" },
    { 0x832E, "med_transport_cp_waitandspawn" },
    { 0x832F, "med_transport_create" },
    { 0x8330, "med_transport_deathcallback" },
    { 0x8331, "med_transport_deletenextframe" },
    { 0x8332, "med_transport_enterend" },
    { 0x8333, "med_transport_enterendinternal" },
    { 0x8334, "med_transport_exitend" },
    { 0x8335, "med_transport_exitendinternal" },
    { 0x8336, "med_transport_explode" },
    { 0x8337, "med_transport_getspawnstructscallback" },
    { 0x8338, "med_transport_init" },
    { 0x8339, "med_transport_initfx" },
    { 0x833A, "med_transport_initinteract" },
    { 0x833B, "med_transport_initlate" },
    { 0x833C, "med_transport_initoccupancy" },
    { 0x833D, "med_transport_initspawning" },
    { 0x833E, "med_transport_mp_create" },
    { 0x833F, "med_transport_mp_delete" },
    { 0x8340, "med_transport_mp_getspawnstructscallback" },
    { 0x8341, "med_transport_mp_init" },
    { 0x8342, "med_transport_mp_initmines" },
    { 0x8343, "med_transport_mp_initspawning" },
    { 0x8344, "med_transport_mp_ondeathrespawncallback" },
    { 0x8345, "med_transport_mp_spawncallback" },
    { 0x8346, "med_transport_mp_waitandspawn" },
    { 0x8347, "medic_health_regen" },
    { 0x8348, "medic_regenerate_health_once" },
    { 0x8349, "medic_regeneration" },
    { 0x834A, "medic_speed_buff" },
    { 0x834B, "medtransports" },
    { 0x834C, "medusa_hint_displayed" },
    { 0x834D, "meet_price" },
    { 0x834E, "meet_sas_catchup" },
    { 0x834F, "meet_sas_flags" },
    { 0x8350, "meet_sas_main" },
    { 0x8351, "meet_sas_start" },
    { 0x8352, "meetsasref" },
    { 0x8353, "megabankbonus" },
    { 0x8354, "megabankbonusks" },
    { 0x8355, "megabanklimit" },
    { 0x8356, "melee" },
    { 0x8357, "melee_animation_when_close_to_hack" },
    { 0x8358, "melee_arms" },
    { 0x8359, "melee_calcsyncdirection" },
    { 0x835A, "melee_chargecomplete" },
    { 0x835B, "melee_chargerequested" },
    { 0x835C, "melee_checktimer" },
    { 0x835D, "melee_damage_trigger" },
    { 0x835E, "melee_decide_winner" },
    { 0x835F, "melee_destroy" },
    { 0x8360, "melee_distance_check" },
    { 0x8361, "melee_droppedweaponrestore" },
    { 0x8362, "melee_enemy" },
    { 0x8363, "melee_enemy_new_node_time" },
    { 0x8364, "melee_enemy_node" },
    { 0x8365, "melee_finalcleanup" },
    { 0x8366, "melee_handlenotetracks" },
    { 0x8367, "melee_hint_break" },
    { 0x8368, "melee_init" },
    { 0x8369, "melee_ischargecomplete" },
    { 0x836A, "melee_off" },
    { 0x836B, "melee_requestcharge" },
    { 0x836C, "melee_scalar" },
    { 0x836D, "melee_self_at_same_node_time" },
    { 0x836E, "melee_self_new_node_time" },
    { 0x836F, "melee_self_node" },
    { 0x8370, "melee_setmeleetimer" },
    { 0x8371, "melee_setup" },
    { 0x8372, "melee_shouldabort" },
    { 0x8373, "melee_shouldabortcharge" },
    { 0x8374, "melee_shouldlosersurvive" },
    { 0x8375, "melee_shouldstop" },
    { 0x8376, "melee_steal" },
    { 0x8377, "melee_strength_timer" },
    { 0x8378, "melee_synced_setup" },
    { 0x8379, "melee_to_nudge_car" },
    { 0x837A, "melee_unlink" },
    { 0x837B, "melee_validatepoints" },
    { 0x837C, "melee_waitfordroppedweapon" },
    { 0x837D, "melee_weapon" },
    { 0x837E, "melee_weapon_safe_gesture" },
    { 0x837F, "meleeactorboundsradius" },
    { 0x8380, "meleeallowoffground" },
    { 0x8381, "meleeallowvsshieldedplayer" },
    { 0x8382, "meleealwasywin" },
    { 0x8383, "meleealwayswin" },
    { 0x8384, "meleeanim" },
    { 0x8385, "meleeanimalias" },
    { 0x8386, "meleebashmaxdistsq" },
    { 0x8387, "meleecansteal" },
    { 0x8388, "meleecharge_failed_badpath" },
    { 0x8389, "meleecharge_init" },
    { 0x838A, "meleecharge_justtriedthis" },
    { 0x838B, "meleecharge_shouldabort" },
    { 0x838C, "meleecharge_terminate" },
    { 0x838D, "meleecharge_update" },
    { 0x838E, "meleechargedistreloadmultiplier" },
    { 0x838F, "meleechargeintervals" },
    { 0x8390, "meleechargeplayerintervals" },
    { 0x8391, "meleechargeplayertimers" },
    { 0x8392, "meleechargetimers" },
    { 0x8393, "meleecount" },
    { 0x8394, "meleecountered" },
    { 0x8395, "meleecounteredfailed" },
    { 0x8396, "meleecounterhint" },
    { 0x8397, "meleedamageoverride" },
    { 0x8398, "meleedeathhandler" },
    { 0x8399, "meleedofroutine" },
    { 0x839A, "meleegetattackercardinaldirection" },
    { 0x839B, "meleegrab_common" },
    { 0x839C, "meleegrab_counterhint" },
    { 0x839D, "meleegrab_counterinput" },
    { 0x839E, "meleegrab_ksweapon_used" },
    { 0x839F, "meleegrab_slowmo" },
    { 0x83A0, "meleehintshow" },
    { 0x83A1, "meleeignorefinalzdiff" },
    { 0x83A2, "meleeignoreplayerstance" },
    { 0x83A3, "meleeignoretimer" },
    { 0x83A4, "meleekill" },
    { 0x83A5, "meleeorigin" },
    { 0x83A6, "meleerangesq" },
    { 0x83A7, "meleerequestedcharge_target" },
    { 0x83A8, "meleerequestedcharge_targetposition" },
    { 0x83A9, "meleerequestedcomplete" },
    { 0x83AA, "meleerequestedtarget" },
    { 0x83AB, "meleeset" },
    { 0x83AC, "meleestagger" },
    { 0x83AD, "meleestagger_anglesviewattack" },
    { 0x83AE, "meleestate" },
    { 0x83AF, "meleestatename" },
    { 0x83B0, "meleestopattackdistsq" },
    { 0x83B1, "meleestrength" },
    { 0x83B2, "meleetargetallowedoffmeshdistsq" },
    { 0x83B3, "meleetryhard" },
    { 0x83B4, "meleevsplayer_init" },
    { 0x83B5, "meleevsplayer_terminate" },
    { 0x83B6, "meleevsplayer_update" },
    { 0x83B7, "memberaddfuncs" },
    { 0x83B8, "memberaddstrings" },
    { 0x83B9, "membercount" },
    { 0x83BA, "memberdeathwaiter" },
    { 0x83BB, "memberremovefuncs" },
    { 0x83BC, "memberremovestrings" },
    { 0x83BD, "members" },
    { 0x83BE, "menu" },
    { 0x83BF, "menu_add_options" },
    { 0x83C0, "menu_background" },
    { 0x83C1, "menu_change_selected_fx" },
    { 0x83C2, "menu_create" },
    { 0x83C3, "menu_create_select" },
    { 0x83C4, "menu_current_selection" },
    { 0x83C5, "menu_cursor" },
    { 0x83C6, "menu_cursor_resetpos" },
    { 0x83C7, "menu_default" },
    { 0x83C8, "menu_exists" },
    { 0x83C9, "menu_fx_creation" },
    { 0x83CA, "menu_fx_option_set" },
    { 0x83CB, "menu_get_selected" },
    { 0x83CC, "menu_get_selected_optionsvalue" },
    { 0x83CD, "menu_get_selected_text" },
    { 0x83CE, "menu_goalradius_dec" },
    { 0x83CF, "menu_goalradius_inc" },
    { 0x83D0, "menu_highlight" },
    { 0x83D1, "menu_input" },
    { 0x83D2, "menu_list_selected" },
    { 0x83D3, "menu_name" },
    { 0x83D4, "menu_none" },
    { 0x83D5, "menu_select_by_name" },
    { 0x83D6, "menu_sys" },
    { 0x83D7, "menuclass" },
    { 0x83D8, "menunone" },
    { 0x83D9, "menuperkparsetable" },
    { 0x83DA, "menuperks" },
    { 0x83DB, "menurigperkparsetable" },
    { 0x83DC, "menurigperks" },
    { 0x83DD, "menus" },
    { 0x83DE, "menuspectator" },
    { 0x83DF, "mercyenabled" },
    { 0x83E0, "mercytransitionenabled" },
    { 0x83E1, "mergeclusterlist" },
    { 0x83E2, "merit_rewardval" },
    { 0x83E3, "merit_scoreval" },
    { 0x83E4, "merit_targetval" },
    { 0x83E5, "meritcallbacks" },
    { 0x83E6, "meritdata" },
    { 0x83E7, "meritinfo" },
    { 0x83E8, "meritscompleted" },
    { 0x83E9, "mesh" },
    { 0x83EA, "message" },
    { 0x83EB, "messageplayer" },
    { 0x83EC, "messageref" },
    { 0x83ED, "messageteam" },
    { 0x83EE, "metal" },
    { 0x83EF, "metal_detectors" },
    { 0x83F0, "meter_fill_up" },
    { 0x83F1, "meth" },
    { 0x83F2, "meth_patch" },
    { 0x83F3, "mg" },
    { 0x83F4, "mg_alley_intro_script_shot" },
    { 0x83F5, "mg_animmg" },
    { 0x83F6, "mg_autosave" },
    { 0x83F7, "mg_breach_no_pistol" },
    { 0x83F8, "mg_cleanup" },
    { 0x83F9, "mg_damage_nag" },
    { 0x83FA, "mg_damage_nag_manager" },
    { 0x83FB, "mg_damage_nag_total" },
    { 0x83FC, "mg_damage_owner" },
    { 0x83FD, "mg_damage_smoke_nag_mghall" },
    { 0x83FE, "mg_damage_smoke_nag_streets" },
    { 0x83FF, "mg_door_bashed_monitor" },
    { 0x8400, "mg_door_left" },
    { 0x8401, "mg_door_right" },
    { 0x8402, "mg_doors" },
    { 0x8403, "mg_doors_bashed_monitor" },
    { 0x8404, "mg_double_doors_handler" },
    { 0x8405, "mg_entry_callout_handler" },
    { 0x8406, "mg_get_los_score" },
    { 0x8407, "mg_get_z_offset" },
    { 0x8408, "mg_gunner" },
    { 0x8409, "mg_gunner_death_notify" },
    { 0x840A, "mg_gunner_team" },
    { 0x840B, "mg_guy_shared_behavior" },
    { 0x840C, "mg_guys_final_volume" },
    { 0x840D, "mg_hall_after_closet_ignoreme_handler" },
    { 0x840E, "mg_hall_after_closet_reinforcement_handler" },
    { 0x840F, "mg_hall_ally_blindfire" },
    { 0x8410, "mg_hall_ally_blindfire_handler" },
    { 0x8411, "mg_hall_ally_color_assign" },
    { 0x8412, "mg_hall_ally_color_trigger_deleter" },
    { 0x8413, "mg_hall_aq_killoff" },
    { 0x8414, "mg_hall_break_windows" },
    { 0x8415, "mg_hall_breakable_door_remove_interact" },
    { 0x8416, "mg_hall_catchup" },
    { 0x8417, "mg_hall_cleanup" },
    { 0x8418, "mg_hall_cleared_vo_done" },
    { 0x8419, "mg_hall_closet_magic_bullets" },
    { 0x841A, "mg_hall_closet_spawn_handler" },
    { 0x841B, "mg_hall_damage_nag_monitor" },
    { 0x841C, "mg_hall_flank_cover_trigger_handler" },
    { 0x841D, "mg_hall_griggs_smoke_vo_done" },
    { 0x841E, "mg_hall_gunner_alert_monitor" },
    { 0x841F, "mg_hall_gunner_alert_proximity_monitor" },
    { 0x8420, "mg_hall_gunner_death_monitor" },
    { 0x8421, "mg_hall_gunner_idle_anim" },
    { 0x8422, "mg_hall_gunner_reaction_animations" },
    { 0x8423, "mg_hall_main" },
    { 0x8424, "mg_hall_marine_spawner_handler" },
    { 0x8425, "mg_hall_reinforcement_handler" },
    { 0x8426, "mg_hall_reinforcement_handler_right_side" },
    { 0x8427, "mg_hall_rpg_monitor" },
    { 0x8428, "mg_hall_rusher_handler" },
    { 0x8429, "mg_hall_shouter_handler" },
    { 0x842A, "mg_hall_sign_magic_bullets" },
    { 0x842B, "mg_hall_snakecam_marine_monitor" },
    { 0x842C, "mg_hall_start" },
    { 0x842D, "mg_hall_tripwire_handler" },
    { 0x842E, "mg_house_gunner_1" },
    { 0x842F, "mg_house_gunner_1_init" },
    { 0x8430, "mg_house_gunner_2" },
    { 0x8431, "mg_house_gunner_2_init" },
    { 0x8432, "mg_house_patroller" },
    { 0x8433, "mg_house_patroller_init" },
    { 0x8434, "mg_house_windowguy" },
    { 0x8435, "mg_house_windowguy_init" },
    { 0x8436, "mg_ignore_check" },
    { 0x8437, "mg_intro_sequence_mg_hall" },
    { 0x8438, "mg_intro_sequence_streets" },
    { 0x8439, "mg_intro_sequence_streets_endon_monitor" },
    { 0x843A, "mg_intro_sequence_streets_thread" },
    { 0x843B, "mg_lerp" },
    { 0x843C, "mg_reload" },
    { 0x843D, "mg_rotation" },
    { 0x843E, "mg_shoot" },
    { 0x843F, "mg_shoot_behavior" },
    { 0x8440, "mg_shoot_scriptables" },
    { 0x8441, "mg_smoke_monitor" },
    { 0x8442, "mg_smoked" },
    { 0x8443, "mg_sprint_trigger_monitor" },
    { 0x8444, "mg_start_shooting_monitor" },
    { 0x8445, "mg_streets_intro" },
    { 0x8446, "mg_suppressed" },
    { 0x8447, "mg_switch_targets" },
    { 0x8448, "mg_target_actual_manager" },
    { 0x8449, "mg_target_dummy" },
    { 0x844A, "mg_target_ent_manager" },
    { 0x844B, "mg_target_other" },
    { 0x844C, "mg_target_player" },
    { 0x844D, "mg_team_alert_monitor" },
    { 0x844E, "mg_team_destination_handler" },
    { 0x844F, "mg_tracer" },
    { 0x8450, "mg_z_offset" },
    { 0x8451, "mg42" },
    { 0x8452, "mg42_enabled" },
    { 0x8453, "mg42_firing" },
    { 0x8454, "mg42_gunner_manual_think" },
    { 0x8455, "mg42_gunner_think" },
    { 0x8456, "mg42_setdifficulty" },
    { 0x8457, "mg42_suppressionfire" },
    { 0x8458, "mg42_target_drones" },
    { 0x8459, "mg42_think" },
    { 0x845A, "mg42_trigger" },
    { 0x845B, "mg42badplace_maxtime" },
    { 0x845C, "mg42badplace_mintime" },
    { 0x845D, "mg42pain" },
    { 0x845E, "mgbursttimemax" },
    { 0x845F, "mgbursttimemin" },
    { 0x8460, "mghouse_tripwire_monitor" },
    { 0x8461, "mginit" },
    { 0x8462, "mgoff" },
    { 0x8463, "mgon" },
    { 0x8464, "mgturret" },
    { 0x8465, "mgturret_auto" },
    { 0x8466, "mgturret_disablelinkedturretangles" },
    { 0x8467, "mgturret_enablelinkedturretangles" },
    { 0x8468, "mgturretinfo" },
    { 0x8469, "mgturretleft" },
    { 0x846A, "mgturretmodelbase" },
    { 0x846B, "mgturretmodelbasealt" },
    { 0x846C, "mgturretright" },
    { 0x846D, "mgturretsettings" },
    { 0x846E, "mh_building_door" },
    { 0x846F, "mh_building_door_handler" },
    { 0x8470, "mh_civilian_cleanup" },
    { 0x8471, "mh_encounter_handler" },
    { 0x8472, "mh_hallway_monitor" },
    { 0x8473, "mh_house_exit_door_blocker_block_path" },
    { 0x8474, "mh_house_exit_door_blocker_clear_path" },
    { 0x8475, "mh_rendevous_dialogue" },
    { 0x8476, "mhc_escape_ents_array" },
    { 0x8477, "mi8_get_length" },
    { 0x8478, "mi8_init" },
    { 0x8479, "mi8_spawn" },
    { 0x847A, "microturret_hint_displayed" },
    { 0x847B, "microturrets" },
    { 0x847C, "mid_bridge_start_struct_index" },
    { 0x847D, "middle_breadcrumb_guy" },
    { 0x847E, "middle_reading_place_front_door_enemies" },
    { 0x847F, "middle_road_civ_runner" },
    { 0x8480, "middle_road_civ_runners" },
    { 0x8481, "midfieldscore" },
    { 0x8482, "midpoint" },
    { 0x8483, "midpointobjectiveindex" },
    { 0x8484, "midpt" },
    { 0x8485, "migrationcapturereset" },
    { 0x8486, "milbase_manifest_vo" },
    { 0x8487, "min_alert_level_duration" },
    { 0x8488, "min_ammo" },
    { 0x8489, "min_count" },
    { 0x848A, "min_delay" },
    { 0x848B, "min_effort_effect" },
    { 0x848C, "min_effort_ratio" },
    { 0x848D, "min_elite" },
    { 0x848E, "min_escalation_level_override" },
    { 0x848F, "min_health_cap" },
    { 0x8490, "min_heavy" },
    { 0x8491, "min_intensity" },
    { 0x8492, "min_num_bots_assaulting_first_flag" },
    { 0x8493, "min_range_max_amp" },
    { 0x8494, "min_size" },
    { 0x8495, "min_sniper_burst_delay_time" },
    { 0x8496, "min_spawn_requested" },
    { 0x8497, "min_speed" },
    { 0x8498, "min_time_in_room" },
    { 0x8499, "min_wait" },
    { 0x849A, "min_wait_between_repeat" },
    { 0x849B, "mindia_infil_start_targetname_array" },
    { 0x849C, "mindia_infil_start_targetname_array_index" },
    { 0x849D, "mindia8_customunloadfunc" },
    { 0x849E, "mindia8_spawnaifunc" },
    { 0x849F, "mindia8_unload" },
    { 0x84A0, "mindia8_unloadinterruptfunc" },
    { 0x84A1, "mindistance" },
    { 0x84A2, "mindistancecallout" },
    { 0x84A3, "mindistancesq" },
    { 0x84A4, "mindistsquared" },
    { 0x84A5, "mine" },
    { 0x84A6, "mine_beacon" },
    { 0x84A7, "mine_cart_debug" },
    { 0x84A8, "mine_carts" },
    { 0x84A9, "mine_catchup" },
    { 0x84AA, "mine_damage_override" },
    { 0x84AB, "mine_drone_marker_vfx" },
    { 0x84AC, "mine_drone_out_of_range" },
    { 0x84AD, "mine_explode" },
    { 0x84AE, "mine_launch" },
    { 0x84AF, "mine_patroller" },
    { 0x84B0, "mine_push_barrel" },
    { 0x84B1, "mine_responder" },
    { 0x84B2, "mine_responder_calling_out" },
    { 0x84B3, "mine_spin" },
    { 0x84B4, "mine_start" },
    { 0x84B5, "minebounce" },
    { 0x84B6, "minedamagehalfheight" },
    { 0x84B7, "minedamagemax" },
    { 0x84B8, "minedamagemin" },
    { 0x84B9, "minedamagemonitor" },
    { 0x84BA, "minedamageradius" },
    { 0x84BB, "minedata" },
    { 0x84BC, "minedeletetrigger" },
    { 0x84BD, "minedestroyed" },
    { 0x84BE, "minedetectiongraceperiod" },
    { 0x84BF, "minedetectionheight" },
    { 0x84C0, "minedetectionradius" },
    { 0x84C1, "mineexplodeonnotify" },
    { 0x84C2, "minefield" },
    { 0x84C3, "minefield_kill" },
    { 0x84C4, "minefield_think" },
    { 0x84C5, "minefields" },
    { 0x84C6, "minegettwohitthreshold" },
    { 0x84C7, "mineproximitytrigger" },
    { 0x84C8, "mines" },
    { 0x84C9, "mines_backtrack_clip" },
    { 0x84CA, "mines_backtrack_trig" },
    { 0x84CB, "mines_bridge_collapse" },
    { 0x84CC, "mines_enter_vo" },
    { 0x84CD, "mines_lantern_think" },
    { 0x84CE, "mines_oilpush_scene" },
    { 0x84CF, "mines_player_pistol_upgrade_monitor" },
    { 0x84D0, "mines_push_cart_checkpoint" },
    { 0x84D1, "mines_second_collapse" },
    { 0x84D2, "mines_setup" },
    { 0x84D3, "mineselfdestruct" },
    { 0x84D4, "mineselfdestructtime" },
    { 0x84D5, "minesensorbounce" },
    { 0x84D6, "mineshaft_martyr_oil_fire" },
    { 0x84D7, "mineshaft_shared_oil_fire" },
    { 0x84D8, "mineshaft_shared_oil_fire_on" },
    { 0x84D9, "minethrown" },
    { 0x84DA, "minetriggerdata" },
    { 0x84DB, "minetriggers" },
    { 0x84DC, "mineused" },
    { 0x84DD, "minexposedgrenadedist" },
    { 0x84DE, "minexposedmolotovdist" },
    { 0x84DF, "minidletime" },
    { 0x84E0, "minigun" },
    { 0x84E1, "minigun_ai_target_cleanup" },
    { 0x84E2, "minigun_fire" },
    { 0x84E3, "minigun_spindown" },
    { 0x84E4, "minigun_spindown_sound" },
    { 0x84E5, "minigunprevweaponobject" },
    { 0x84E6, "minigunsspinning" },
    { 0x84E7, "minigunweapon" },
    { 0x84E8, "minimap_image" },
    { 0x84E9, "minimap_objective_add" },
    { 0x84EA, "minimap_objective_icon" },
    { 0x84EB, "minimap_objective_onentity" },
    { 0x84EC, "minimap_objective_onentitywithrotation" },
    { 0x84ED, "minimap_objective_pin_global" },
    { 0x84EE, "minimap_objective_pin_player" },
    { 0x84EF, "minimap_objective_pin_team" },
    { 0x84F0, "minimap_objective_player" },
    { 0x84F1, "minimap_objective_playerenemyteam" },
    { 0x84F2, "minimap_objective_playermask_hidefrom" },
    { 0x84F3, "minimap_objective_playermask_hidefromall" },
    { 0x84F4, "minimap_objective_playermask_showto" },
    { 0x84F5, "minimap_objective_playermask_showtoall" },
    { 0x84F6, "minimap_objective_playerteam" },
    { 0x84F7, "minimap_objective_position" },
    { 0x84F8, "minimap_objective_setbackground" },
    { 0x84F9, "minimap_objective_setzoffset" },
    { 0x84FA, "minimap_objective_state" },
    { 0x84FB, "minimap_objective_team" },
    { 0x84FC, "minimap_objective_team_addtomask" },
    { 0x84FD, "minimap_objective_team_removefrommask" },
    { 0x84FE, "minimap_objective_unpin_player" },
    { 0x84FF, "minimap_objective_unpin_team" },
    { 0x8500, "minimapcornertargetname" },
    { 0x8501, "minimapheight" },
    { 0x8502, "minimapicon" },
    { 0x8503, "minimapiconactive" },
    { 0x8504, "minimapid" },
    { 0x8505, "minimapobjidpool" },
    { 0x8506, "minimaponbydefault" },
    { 0x8507, "minimaporigin" },
    { 0x8508, "minimapplayer" },
    { 0x8509, "minimapstatetracker" },
    { 0x850A, "miniprevweaponobject" },
    { 0x850B, "minpainvalue" },
    { 0x850C, "minplayerdist" },
    { 0x850D, "minplayerspeeddist" },
    { 0x850E, "minpriority" },
    { 0x850F, "minradius" },
    { 0x8510, "minrangedarkness" },
    { 0x8511, "minrequirements" },
    { 0x8512, "minscale" },
    { 0x8513, "minshotinterval" },
    { 0x8514, "minspeed" },
    { 0x8515, "minspeedsq" },
    { 0x8516, "mintime" },
    { 0x8517, "mintracktime" },
    { 0x8518, "minus" },
    { 0x8519, "minvehicles" },
    { 0x851A, "minxp" },
    { 0x851B, "mirror_left_dead" },
    { 0x851C, "mirror_right_dead" },
    { 0x851D, "miscmessagebitflipper" },
    { 0x851E, "miss_player" },
    { 0x851F, "miss_player_in_the_back" },
    { 0x8520, "miss_rpg_enemy_think" },
    { 0x8521, "miss_rpg_watch_for_player_convoy" },
    { 0x8522, "missed_time_penalty" },
    { 0x8523, "missile" },
    { 0x8524, "missile_anchor_clean_up_think" },
    { 0x8525, "missile_array" },
    { 0x8526, "missile_deathwait" },
    { 0x8527, "missile_defense_camera_anchor" },
    { 0x8528, "missile_defense_camera_focus_think" },
    { 0x8529, "missile_defense_fire_interceptor_missiles" },
    { 0x852A, "missile_defense_lock_on_cruise_missile_think" },
    { 0x852B, "missile_earthquake" },
    { 0x852C, "missile_earthquakerumble" },
    { 0x852D, "missile_explode_quakes" },
    { 0x852E, "missile_find_ground_target" },
    { 0x852F, "missile_get_desired_angles_to_target" },
    { 0x8530, "missile_get_distance_to_target" },
    { 0x8531, "missile_hit_target" },
    { 0x8532, "missile_impact_rumble" },
    { 0x8533, "missile_isincoming" },
    { 0x8534, "missile_laser_tags" },
    { 0x8535, "missile_logic" },
    { 0x8536, "missile_settargetandflightmode" },
    { 0x8537, "missileattractor" },
    { 0x8538, "missileattractorent" },
    { 0x8539, "missilebooston" },
    { 0x853A, "missileburstfire" },
    { 0x853B, "missileexplcounter" },
    { 0x853C, "missileeyes" },
    { 0x853D, "missilefired" },
    { 0x853E, "missilefireside" },
    { 0x853F, "missilelastangle" },
    { 0x8540, "missilelastpos" },
    { 0x8541, "missilelauncher_finalizelock" },
    { 0x8542, "missilelauncherlockstarttime" },
    { 0x8543, "missilelauncherlostsightlinetime" },
    { 0x8544, "missilelauncherstage" },
    { 0x8545, "missilelaunchertarget" },
    { 0x8546, "missilelauncherusage" },
    { 0x8547, "missilelauncherusageloop" },
    { 0x8548, "missilelauncheruseentered" },
    { 0x8549, "missilelosetarget" },
    { 0x854A, "missileremotelaunchhorz" },
    { 0x854B, "missileremotelaunchtargetdist" },
    { 0x854C, "missileremotelaunchvert" },
    { 0x854D, "missiles" },
    { 0x854E, "missilesleft" },
    { 0x854F, "missilewhizby" },
    { 0x8550, "missing_ru_soldier" },
    { 0x8551, "missingstub" },
    { 0x8552, "mission_complete" },
    { 0x8553, "mission_diffstring_ifnotcheating_set" },
    { 0x8554, "mission_fail" },
    { 0x8555, "mission_fail_func" },
    { 0x8556, "mission_failed" },
    { 0x8557, "mission_failed_icon_cleanup" },
    { 0x8558, "mission_jumpto_debug" },
    { 0x8559, "mission_select" },
    { 0x855A, "mission_select_armsdealer" },
    { 0x855B, "mission_select_landlord" },
    { 0x855C, "mission_select_s11_1" },
    { 0x855D, "mission_select_think" },
    { 0x855E, "mission_select_think_new" },
    { 0x855F, "mission_success" },
    { 0x8560, "missionend" },
    { 0x8561, "missionfail" },
    { 0x8562, "missionfailed" },
    { 0x8563, "missionfailedwrapper" },
    { 0x8564, "missionsettings" },
    { 0x8565, "missionstarttime" },
    { 0x8566, "missle" },
    { 0x8567, "missplayer" },
    { 0x8568, "missrefundwatcher" },
    { 0x8569, "misstime" },
    { 0x856A, "misstimeconstant" },
    { 0x856B, "misstimedebounce" },
    { 0x856C, "misstimedistancefactor" },
    { 0x856D, "ml_p1_intel_area" },
    { 0x856E, "ml_p1_intel_drop" },
    { 0x856F, "ml_p1_intel_locs" },
    { 0x8570, "ml_p1_obj_loc" },
    { 0x8571, "ml_p1_obj_spawners" },
    { 0x8572, "ml_p1_objectives_registered" },
    { 0x8573, "ml_p2_doors" },
    { 0x8574, "ml_p2_doors_clip" },
    { 0x8575, "ml_p2_get_heli_start" },
    { 0x8576, "ml_p2_interrogate" },
    { 0x8577, "ml_p2_objectives_registered" },
    { 0x8578, "ml_p3_objectives_registered" },
    { 0x8579, "mlp1_obj_func" },
    { 0x857A, "mlp2_1_start" },
    { 0x857B, "mlp2_2_start" },
    { 0x857C, "mlp2_3_mnu_start" },
    { 0x857D, "mlp2_3_start" },
    { 0x857E, "mlp2_debug_start" },
    { 0x857F, "mlp2_group" },
    { 0x8580, "mlp2_mnu_start" },
    { 0x8581, "mlp2_obj_func" },
    { 0x8582, "mlp2_observe_start" },
    { 0x8583, "mlp2_roof_group" },
    { 0x8584, "mlp2_sh1_trig" },
    { 0x8585, "mlp2_sh2_trig" },
    { 0x8586, "mlp2_sh3_trig" },
    { 0x8587, "mlp2_truck_guy" },
    { 0x8588, "mlp2_vehicles" },
    { 0x8589, "mlp3_obj_func" },
    { 0x858A, "mobilearmoryplundercost" },
    { 0x858B, "mod" },
    { 0x858C, "moddamage" },
    { 0x858D, "mode" },
    { 0x858E, "modecontrolledvehiclespawningonly" },
    { 0x858F, "model_created" },
    { 0x8590, "model_name" },
    { 0x8591, "model_off" },
    { 0x8592, "model_spot" },
    { 0x8593, "model_swap_gate" },
    { 0x8594, "modelbad" },
    { 0x8595, "modelbase" },
    { 0x8596, "modelbasealt" },
    { 0x8597, "modelbasecover" },
    { 0x8598, "modelbaseground" },
    { 0x8599, "modelbombsquad" },
    { 0x859A, "modeldestroyed" },
    { 0x859B, "modeldestroyedcover" },
    { 0x859C, "modeldestroyedground" },
    { 0x859D, "modeldummy" },
    { 0x859E, "modelgood" },
    { 0x859F, "modelindex" },
    { 0x85A0, "modelnames" },
    { 0x85A1, "modelplacement" },
    { 0x85A2, "modelplacementfailed" },
    { 0x85A3, "models" },
    { 0x85A4, "models_lit" },
    { 0x85A5, "models_on" },
    { 0x85A6, "models_unlit" },
    { 0x85A7, "modelscale" },
    { 0x85A8, "modelusesprefab" },
    { 0x85A9, "modeonlaststandfunc" },
    { 0x85AA, "modeonspawnplayer" },
    { 0x85AB, "modeonsuicidedeath" },
    { 0x85AC, "modeonteamchangedeath" },
    { 0x85AD, "modeshoulddofauxdeathfunc" },
    { 0x85AE, "modespecificparachutecompletecb" },
    { 0x85AF, "modestatmap" },
    { 0x85B0, "modestatsenabled" },
    { 0x85B1, "modified_enter_combat" },
    { 0x85B2, "modifiedbombzones" },
    { 0x85B3, "modifieddefendcheck" },
    { 0x85B4, "modifieddefendradiussetup" },
    { 0x85B5, "modifiedspawnpoints" },
    { 0x85B6, "modifiers" },
    { 0x85B7, "modify_apache_lifetime" },
    { 0x85B8, "modify_moveplaybackrate_together" },
    { 0x85B9, "modify_player_speed" },
    { 0x85BA, "modify_rate" },
    { 0x85BB, "modifyblastshieldperk" },
    { 0x85BC, "modifybombzonecollision" },
    { 0x85BD, "modifydamage" },
    { 0x85BE, "modifydamagegeneral" },
    { 0x85BF, "modifyjailknifedamage" },
    { 0x85C0, "modifyplayerdamage" },
    { 0x85C1, "modifyplayerdamage_relics" },
    { 0x85C2, "modifystatgroupwritability" },
    { 0x85C3, "modifystatwritability" },
    { 0x85C4, "modifysuperequipmentdamage" },
    { 0x85C5, "modifyteamdata" },
    { 0x85C6, "modifyunifiedpoints" },
    { 0x85C7, "modifyunifiedpointscallback" },
    { 0x85C8, "modifyweapon" },
    { 0x85C9, "modular_spawning_debug_init" },
    { 0x85CA, "module_always_attempt_killoff" },
    { 0x85CB, "module_disables_spawners_until_owner_death" },
    { 0x85CC, "module_group_id" },
    { 0x85CD, "module_init_funcs" },
    { 0x85CE, "module_run_func_after_notify" },
    { 0x85CF, "module_vehicles" },
    { 0x85D0, "module_wave_spawn" },
    { 0x85D1, "moduleid" },
    { 0x85D2, "modulespawngroups" },
    { 0x85D3, "moloachievementvictims" },
    { 0x85D4, "molotov" },
    { 0x85D5, "molotov_begin_fx" },
    { 0x85D6, "molotov_branch_create_forward_tendril_cone" },
    { 0x85D7, "molotov_branch_create_forward_tendril_radial" },
    { 0x85D8, "molotov_branch_create_left_tendril_cone" },
    { 0x85D9, "molotov_branch_create_pool" },
    { 0x85DA, "molotov_branch_create_right_tendril_cone" },
    { 0x85DB, "molotov_branch_create_sub_branch" },
    { 0x85DC, "molotov_branch_create_tendril_radial" },
    { 0x85DD, "molotov_branch_is_complete" },
    { 0x85DE, "molotov_branch_register_cast" },
    { 0x85DF, "molotov_burn_for_time" },
    { 0x85E0, "molotov_burn_sfx" },
    { 0x85E1, "molotov_burning_corpstable_func" },
    { 0x85E2, "molotov_burning_source_is_valid" },
    { 0x85E3, "molotov_cleanup" },
    { 0x85E4, "molotov_cleanup_burn_source" },
    { 0x85E5, "molotov_cleanup_burning" },
    { 0x85E6, "molotov_cleanup_burning_on_death" },
    { 0x85E7, "molotov_cleanup_burning_on_game_end" },
    { 0x85E8, "molotov_cleanup_grenade" },
    { 0x85E9, "molotov_cleanup_pool_trigger" },
    { 0x85EA, "molotov_cleanup_pool_trigger_end_early" },
    { 0x85EB, "molotov_clear_burning" },
    { 0x85EC, "molotov_create_branch" },
    { 0x85ED, "molotov_create_pool" },
    { 0x85EE, "molotov_create_pool_trigger" },
    { 0x85EF, "molotov_create_shared_data" },
    { 0x85F0, "molotov_end_fx" },
    { 0x85F1, "molotov_fake_light" },
    { 0x85F2, "molotov_fire_ab_light_flicker" },
    { 0x85F3, "molotov_fire_ab_light_off" },
    { 0x85F4, "molotov_fire_ab_light_on" },
    { 0x85F5, "molotov_fire_sfx" },
    { 0x85F6, "molotov_fx_race_death" },
    { 0x85F7, "molotov_fx_race_grenade_fired" },
    { 0x85F8, "molotov_fx_race_held_offhand_break" },
    { 0x85F9, "molotov_fx_race_pullback" },
    { 0x85FA, "molotov_fx_race_super_started" },
    { 0x85FB, "molotov_fx_race_taken" },
    { 0x85FC, "molotov_get_burning_info" },
    { 0x85FD, "molotov_get_burning_source" },
    { 0x85FE, "molotov_get_cast_contents" },
    { 0x85FF, "molotov_get_cast_data" },
    { 0x8600, "molotov_get_cast_dir" },
    { 0x8601, "molotov_get_cast_dist" },
    { 0x8602, "molotov_get_next_burning_id" },
    { 0x8603, "molotov_get_pool_data" },
    { 0x8604, "molotov_guy_death_watcher" },
    { 0x8605, "molotov_hint_flash" },
    { 0x8606, "molotov_init" },
    { 0x8607, "molotov_init_cast_data" },
    { 0x8608, "molotov_init_pool_data" },
    { 0x8609, "molotov_init_pool_mask" },
    { 0x860A, "molotov_is_burning" },
    { 0x860B, "molotov_left_tendril_mod_angles" },
    { 0x860C, "molotov_notify" },
    { 0x860D, "molotov_on_give" },
    { 0x860E, "molotov_on_player_damaged" },
    { 0x860F, "molotov_on_take" },
    { 0x8610, "molotov_play_burning_fx" },
    { 0x8611, "molotov_pool_end" },
    { 0x8612, "molotov_pool_start" },
    { 0x8613, "molotov_pool_update_scriptable" },
    { 0x8614, "molotov_rebuild_angles_up_forward" },
    { 0x8615, "molotov_rebuild_angles_up_right" },
    { 0x8616, "molotov_refill_hide" },
    { 0x8617, "molotov_refill_show" },
    { 0x8618, "molotov_right_tendril_mod_angles" },
    { 0x8619, "molotov_rotate_angles_about_up" },
    { 0x861A, "molotov_shared_data_can_cast_this_frame" },
    { 0x861B, "molotov_shared_data_is_complete" },
    { 0x861C, "molotov_shared_data_register_cast" },
    { 0x861D, "molotov_shared_data_register_ent" },
    { 0x861E, "molotov_simulate_impact" },
    { 0x861F, "molotov_spark_trig" },
    { 0x8620, "molotov_start_branch" },
    { 0x8621, "molotov_start_burning" },
    { 0x8622, "molotov_stop_burning" },
    { 0x8623, "molotov_stop_burning_fx" },
    { 0x8624, "molotov_stuck" },
    { 0x8625, "molotov_stuck_player" },
    { 0x8626, "molotov_take" },
    { 0x8627, "molotov_tendril_mod_angles_radial" },
    { 0x8628, "molotov_throw_spots" },
    { 0x8629, "molotov_throw_targets" },
    { 0x862A, "molotov_throw_watcher" },
    { 0x862B, "molotov_throwers" },
    { 0x862C, "molotov_update_burning" },
    { 0x862D, "molotov_used" },
    { 0x862E, "molotov_watch_fx" },
    { 0x862F, "molotov_watch_pool" },
    { 0x8630, "molotov_watch_pool_explosion_extinguish" },
    { 0x8631, "molotov_watch_pool_trigger_enter" },
    { 0x8632, "molotov_watch_pool_trigger_exit" },
    { 0x8633, "molotovbadplace" },
    { 0x8634, "molotovburnenemy" },
    { 0x8635, "molotovburnscriptablevehicle" },
    { 0x8636, "molotovburnvehicle" },
    { 0x8637, "molotovdata" },
    { 0x8638, "molotovexplode" },
    { 0x8639, "molotovfiremain" },
    { 0x863A, "molotovrefilltriggerthink" },
    { 0x863B, "molotovs" },
    { 0x863C, "molotovs_damage_hvts" },
    { 0x863D, "molotovviewmodelfiremanager" },
    { 0x863E, "moltovgetai" },
    { 0x863F, "moltovgetscriptables" },
    { 0x8640, "moltovgetvehicles" },
    { 0x8641, "moltovrefillthink" },
    { 0x8642, "mom" },
    { 0x8643, "momdeathreact_anime" },
    { 0x8644, "momentum" },
    { 0x8645, "momentum_endaftermax" },
    { 0x8646, "momentum_monitordamage" },
    { 0x8647, "momentum_monitormovement" },
    { 0x8648, "momentumspeedincrease" },
    { 0x8649, "monitor_ai_in_danger" },
    { 0x864A, "monitor_ai_movement_vol" },
    { 0x864B, "monitor_ball_carrier" },
    { 0x864C, "monitor_bombzone_control" },
    { 0x864D, "monitor_callbutton" },
    { 0x864E, "monitor_cart_directional_push" },
    { 0x864F, "monitor_cautious_approach_dangerous_locations" },
    { 0x8650, "monitor_cautious_approach_early_out" },
    { 0x8651, "monitor_cover_damage" },
    { 0x8652, "monitor_damage_thread" },
    { 0x8653, "monitor_defend_player" },
    { 0x8654, "monitor_defuse" },
    { 0x8655, "monitor_distance_from_starting_street" },
    { 0x8656, "monitor_door_push" },
    { 0x8657, "monitor_enemies_enter_perimeter" },
    { 0x8658, "monitor_enemy_been_seen" },
    { 0x8659, "monitor_enemy_dangerous_killstreak" },
    { 0x865A, "monitor_flag_control" },
    { 0x865B, "monitor_flag_ownership" },
    { 0x865C, "monitor_flag_status" },
    { 0x865D, "monitor_grenade_fire" },
    { 0x865E, "monitor_hallway_mh_mg_los" },
    { 0x865F, "monitor_hvt_pickup" },
    { 0x8660, "monitor_interact_delay" },
    { 0x8661, "monitor_lookat_ent" },
    { 0x8662, "monitor_no_colors" },
    { 0x8663, "monitor_node_visible" },
    { 0x8664, "monitor_num_players" },
    { 0x8665, "monitor_odin_marker" },
    { 0x8666, "monitor_oilfire" },
    { 0x8667, "monitor_open_completely" },
    { 0x8668, "monitor_pause_spawning" },
    { 0x8669, "monitor_player_death" },
    { 0x866A, "monitor_player_deaths" },
    { 0x866B, "monitor_player_in_danger" },
    { 0x866C, "monitor_player_jump" },
    { 0x866D, "monitor_player_movement" },
    { 0x866E, "monitor_player_moves" },
    { 0x866F, "monitor_player_past_loc" },
    { 0x8670, "monitor_setup" },
    { 0x8671, "monitor_smoke" },
    { 0x8672, "monitor_smoke_grenade" },
    { 0x8673, "monitor_smoke_grenades" },
    { 0x8674, "monitor_spotterscope_equipped" },
    { 0x8675, "monitor_spotterscope_nvg" },
    { 0x8676, "monitor_tripwire_defuse" },
    { 0x8677, "monitor_wave_cooldown" },
    { 0x8678, "monitor_wave_spawning" },
    { 0x8679, "monitor_weapon_fire" },
    { 0x867A, "monitor_weapons" },
    { 0x867B, "monitor_zone_control" },
    { 0x867C, "monitoradd" },
    { 0x867D, "monitoradstime" },
    { 0x867E, "monitorarriveoverdestination" },
    { 0x867F, "monitorboost" },
    { 0x8680, "monitorbreachmelee" },
    { 0x8681, "monitorcontextualcallout" },
    { 0x8682, "monitorcratejacking" },
    { 0x8683, "monitordamage" },
    { 0x8684, "monitordamageend" },
    { 0x8685, "monitordamageoneshot" },
    { 0x8686, "monitordeath" },
    { 0x8687, "monitordisconnect" },
    { 0x8688, "monitordisownedequipment" },
    { 0x8689, "monitordisownedgrenade" },
    { 0x868A, "monitordisownkillstreaks" },
    { 0x868B, "monitorflash" },
    { 0x868C, "monitorgameend" },
    { 0x868D, "monitorgamepadswitch" },
    { 0x868E, "monitorgulag" },
    { 0x868F, "monitorhealed" },
    { 0x8690, "monitorjointeam" },
    { 0x8691, "monitorjumpmasterclaim" },
    { 0x8692, "monitorlauncherspawnedgrenades" },
    { 0x8693, "monitorlockedtarget" },
    { 0x8694, "monitormeleeoverlay" },
    { 0x8695, "monitormoraleswaypoint" },
    { 0x8696, "monitorobjectivecamera" },
    { 0x8697, "monitoroutofboundsdistortion" },
    { 0x8698, "monitorowner" },
    { 0x8699, "monitorownerstatus" },
    { 0x869A, "monitorplacement" },
    { 0x869B, "monitorplayers" },
    { 0x869C, "monitorreduceregendelayonobjective" },
    { 0x869D, "monitorreload" },
    { 0x869E, "monitorsentient" },
    { 0x869F, "monitorsharpfocus" },
    { 0x86A0, "monitorsmokeactive" },
    { 0x86A1, "monitorspectatorassignments" },
    { 0x86A2, "monitorsquadmovement" },
    { 0x86A3, "monitorsquads" },
    { 0x86A4, "monitorsquadspectator" },
    { 0x86A5, "monitorsurvivaltime" },
    { 0x86A6, "monitortaguse" },
    { 0x86A7, "monitortimeout" },
    { 0x86A8, "monitortimeoutupdate" },
    { 0x86A9, "monitoruseweaponfiring" },
    { 0x86AA, "monitorvotekick" },
    { 0x86AB, "monitorweaponchange" },
    { 0x86AC, "monitorweaponfire" },
    { 0x86AD, "monitorweaponpickup" },
    { 0x86AE, "monitorweaponswitch" },
    { 0x86AF, "monitorzawarenesslevel" },
    { 0x86B0, "montior_chopperkilling_player" },
    { 0x86B1, "montior_player_fov" },
    { 0x86B2, "morales_guard_post_func" },
    { 0x86B3, "morales_laptop_int_struct" },
    { 0x86B4, "morales_signal_struct" },
    { 0x86B5, "moralesholdoutmagicgrenadewatcher" },
    { 0x86B6, "moraleshostage" },
    { 0x86B7, "moraleswid" },
    { 0x86B8, "more_crying" },
    { 0x86B9, "more_populated_bombzone" },
    { 0x86BA, "more_team_id_zero_slot_available" },
    { 0x86BB, "more_team_one_slot_available" },
    { 0x86BC, "mortal_in_player_view" },
    { 0x86BD, "mortar_anim" },
    { 0x86BE, "mortar_building_attack_lighting" },
    { 0x86BF, "mortar_building_doors" },
    { 0x86C0, "mortar_door_magic_bullet" },
    { 0x86C1, "mortar_enemies_temp_disable_molotovs" },
    { 0x86C2, "mortar_enemy_death_watcher" },
    { 0x86C3, "mortar_guy_breakout" },
    { 0x86C4, "mortar_guy_bullet_shield" },
    { 0x86C5, "mortar_guy_mortar_death" },
    { 0x86C6, "mortar_house_boost" },
    { 0x86C7, "mortar_house_boost_interact_door" },
    { 0x86C8, "mortar_house_boost_vo" },
    { 0x86C9, "mortar_house_fridge" },
    { 0x86CA, "mortar_house_guys" },
    { 0x86CB, "mortar_house_guys_behavior" },
    { 0x86CC, "mortar_house_kitchen_lookat" },
    { 0x86CD, "mortar_house_vo" },
    { 0x86CE, "mortar_launch_player_effect" },
    { 0x86CF, "mortar_launch_think" },
    { 0x86D0, "mortar_launcher_init" },
    { 0x86D1, "mortar_locations_watcher" },
    { 0x86D2, "mortar_moment" },
    { 0x86D3, "mortar_moment_painters_light" },
    { 0x86D4, "mortar_ondeathcleanup" },
    { 0x86D5, "mortar_roof_deadly" },
    { 0x86D6, "mortar_round_delay_time" },
    { 0x86D7, "mortar_rounds_pacing" },
    { 0x86D8, "mortar_targetting" },
    { 0x86D9, "mortar_teams" },
    { 0x86DA, "mortar_test" },
    { 0x86DB, "mortar_think" },
    { 0x86DC, "mortar_tube_collapse" },
    { 0x86DD, "mortar_vo_ints" },
    { 0x86DE, "mortar_wave_settings" },
    { 0x86DF, "mortar_window_guy" },
    { 0x86E0, "mortarlauncher_createhintobject" },
    { 0x86E1, "mortars_createwaitstruct" },
    { 0x86E2, "mortars_dialoguefeedbacklogic" },
    { 0x86E3, "mortars_dialoguewarningslogic" },
    { 0x86E4, "mortars_dowaitstruct" },
    { 0x86E5, "mortars_enemiesanimationlogic" },
    { 0x86E6, "mortars_enemieslogic" },
    { 0x86E7, "mortars_enemieswaittillalerted" },
    { 0x86E8, "mortars_enemyreactlogic" },
    { 0x86E9, "mortars_explodemortarprojectile" },
    { 0x86EA, "mortars_explodemortarsfx" },
    { 0x86EB, "mortars_farahdialoguehints" },
    { 0x86EC, "mortars_firemortarprojectile" },
    { 0x86ED, "mortars_getenemies" },
    { 0x86EE, "mortars_getmodels" },
    { 0x86EF, "mortars_main" },
    { 0x86F0, "mortars_modellogic" },
    { 0x86F1, "mortars_mortarinairflaglogic" },
    { 0x86F2, "mortars_mortarspawninglogic" },
    { 0x86F3, "mortars_playerspottedlogic" },
    { 0x86F4, "mortars_start" },
    { 0x86F5, "mortartarget" },
    { 0x86F6, "mostkillsleastdeaths_evaluate" },
    { 0x86F7, "mostkillslongeststreak_evaluate" },
    { 0x86F8, "mostkillsmostheadshots_evaluate" },
    { 0x86F9, "mostnumtouching" },
    { 0x86FA, "mostnumtouchingteam" },
    { 0x86FB, "motion_blur" },
    { 0x86FC, "motion_blur_disable" },
    { 0x86FD, "motion_blur_enable" },
    { 0x86FE, "motion_trigger" },
    { 0x86FF, "motionblur" },
    { 0x8700, "motionblurtest" },
    { 0x8701, "motiondetectioncooldown" },
    { 0x8702, "motiondetectionproc" },
    { 0x8703, "motiondetectionstatus" },
    { 0x8704, "motiondetectors" },
    { 0x8705, "motionwarp_getworldifydata" },
    { 0x8706, "motionwarp_localizedata" },
    { 0x8707, "motionwarpwithnotetracks" },
    { 0x8708, "motionwarpwithtimes" },
    { 0x8709, "mount_tutorial_time" },
    { 0x870A, "mountmantlemodel" },
    { 0x870B, "mourn_dad_monitor" },
    { 0x870C, "move_actor_tointeractionposition" },
    { 0x870D, "move_aim_along_spline" },
    { 0x870E, "move_aim_to" },
    { 0x870F, "move_aim_to_enemy" },
    { 0x8710, "move_all_fx" },
    { 0x8711, "move_away_from_vehicles" },
    { 0x8712, "move_backward_enter" },
    { 0x8713, "move_backward_exit" },
    { 0x8714, "move_barkov" },
    { 0x8715, "move_barkov_closer" },
    { 0x8716, "move_bots_from_team_to_team" },
    { 0x8717, "move_check" },
    { 0x8718, "move_cursor_near_identified_ied" },
    { 0x8719, "move_dynamic_doors_undermap" },
    { 0x871A, "move_elevator" },
    { 0x871B, "move_enforcer_fake_target" },
    { 0x871C, "move_ent_function" },
    { 0x871D, "move_forward_enter" },
    { 0x871E, "move_forward_exit" },
    { 0x871F, "move_goal_ent" },
    { 0x8720, "move_goal_ent_towards_objective" },
    { 0x8721, "move_hole_clip" },
    { 0x8722, "move_juggs_in_elevator" },
    { 0x8723, "move_lab_allies" },
    { 0x8724, "move_left_enter" },
    { 0x8725, "move_left_exit" },
    { 0x8726, "move_list_menu" },
    { 0x8727, "move_machete_table" },
    { 0x8728, "move_marine_spawner_to_mh" },
    { 0x8729, "move_marker_to_heli" },
    { 0x872A, "move_message_think" },
    { 0x872B, "move_objective_spot_around" },
    { 0x872C, "move_objective_to_hvt" },
    { 0x872D, "move_origin" },
    { 0x872E, "move_override" },
    { 0x872F, "move_pct" },
    { 0x8730, "move_plane" },
    { 0x8731, "move_player_from_under_heli" },
    { 0x8732, "move_price" },
    { 0x8733, "move_right_enter" },
    { 0x8734, "move_right_exit" },
    { 0x8735, "move_rumble_towards_player" },
    { 0x8736, "move_scale" },
    { 0x8737, "move_scene" },
    { 0x8738, "move_selection_to_cursor" },
    { 0x8739, "move_slower" },
    { 0x873A, "move_speed" },
    { 0x873B, "move_speed_monitor" },
    { 0x873C, "move_speed_reset" },
    { 0x873D, "move_speed_scalar" },
    { 0x873E, "move_speed_scale" },
    { 0x873F, "move_stairwell_blocker" },
    { 0x8740, "move_target" },
    { 0x8741, "move_target_pos_to_new_turrets_visibility" },
    { 0x8742, "move_target_think" },
    { 0x8743, "move_terrorist_respawn_camera" },
    { 0x8744, "move_the_door" },
    { 0x8745, "move_think" },
    { 0x8746, "move_to_and_delete" },
    { 0x8747, "move_to_arrive_then_idle" },
    { 0x8748, "move_to_arrive_then_idle_with_path" },
    { 0x8749, "move_to_blue_background" },
    { 0x874A, "move_to_blue_background_side_on" },
    { 0x874B, "move_to_breach" },
    { 0x874C, "move_to_closest_interaction" },
    { 0x874D, "move_to_entrance_new" },
    { 0x874E, "move_to_grey_background" },
    { 0x874F, "move_to_grey_background_side_on" },
    { 0x8750, "move_to_lab_node" },
    { 0x8751, "move_to_point_with_angles" },
    { 0x8752, "move_to_window" },
    { 0x8753, "move_train_along_struct_path" },
    { 0x8754, "move_transition_arrays" },
    { 0x8755, "move_trigger" },
    { 0x8756, "move_up_to_roof" },
    { 0x8757, "move_use_turret" },
    { 0x8758, "move_weapon_to_loc" },
    { 0x8759, "move_when_enemy_hides" },
    { 0x875A, "move_with_rate" },
    { 0x875B, "moveagenttospawnerpos" },
    { 0x875C, "moveanddamagepoint" },
    { 0x875D, "moveanimset" },
    { 0x875E, "moveballtoplayer" },
    { 0x875F, "movebattlechatter_helper" },
    { 0x8760, "movebombcase" },
    { 0x8761, "movecameratomappos" },
    { 0x8762, "movecameratorevivepos" },
    { 0x8763, "moved_by_player" },
    { 0x8764, "movedist" },
    { 0x8765, "movedoffguardlocation" },
    { 0x8766, "movedtovehicle" },
    { 0x8767, "movedurationmax" },
    { 0x8768, "movedurationmin" },
    { 0x8769, "moveforward" },
    { 0x876A, "moveinterval" },
    { 0x876B, "movelength" },
    { 0x876C, "movement" },
    { 0x876D, "movement_dialog" },
    { 0x876E, "movement_open_door" },
    { 0x876F, "movement_open_door_and_close" },
    { 0x8770, "movementdisabled" },
    { 0x8771, "movementgunposeoverride" },
    { 0x8772, "movementmachine" },
    { 0x8773, "movementstate" },
    { 0x8774, "movemortar" },
    { 0x8775, "movenotificationup" },
    { 0x8776, "moveonpath" },
    { 0x8777, "moveorigin" },
    { 0x8778, "movepentstostructs" },
    { 0x8779, "moveplaybackrate" },
    { 0x877A, "moveplayerperpendicularly" },
    { 0x877B, "mover" },
    { 0x877C, "mover_candidates" },
    { 0x877D, "mover_clean_up" },
    { 0x877E, "mover_ends" },
    { 0x877F, "mover_suicide" },
    { 0x8780, "moverdoesnotkill" },
    { 0x8781, "movers" },
    { 0x8782, "movespeed" },
    { 0x8783, "movespeed_get_func" },
    { 0x8784, "movespeed_set_func" },
    { 0x8785, "movespeedscalar" },
    { 0x8786, "movespeedscale" },
    { 0x8787, "movespeedscaler" },
    { 0x8788, "movespeedscales" },
    { 0x8789, "movestartbattlechatter" },
    { 0x878A, "movestrafeloop" },
    { 0x878B, "movestrafeloopnew" },
    { 0x878C, "movetime" },
    { 0x878D, "moveto_2f_vo" },
    { 0x878E, "moveto_compound" },
    { 0x878F, "moveto_floor" },
    { 0x8790, "moveto_intro_anim" },
    { 0x8791, "moveto_midway" },
    { 0x8792, "moveto_rotateto" },
    { 0x8793, "moveto_rotateto_speed" },
    { 0x8794, "moveto_unbreachable_door" },
    { 0x8795, "moveto_volume_think" },
    { 0x8796, "moveto_volume_vehiclespline" },
    { 0x8797, "movetocovernode" },
    { 0x8798, "movetocovernodestarttime" },
    { 0x8799, "movetonodeovertime" },
    { 0x879A, "movetospawncamera" },
    { 0x879B, "movetospawncamerainitial" },
    { 0x879C, "movetovehicle" },
    { 0x879D, "movetovehicle_init" },
    { 0x879E, "movetovehicle_terminate" },
    { 0x879F, "movetransitionrate" },
    { 0x87A0, "movetypeisnotcasual" },
    { 0x87A1, "moveup_1f_hallway" },
    { 0x87A2, "moveviewmult" },
    { 0x87A3, "movewalkandtalk" },
    { 0x87A4, "movezoneaftertime" },
    { 0x87A5, "moving" },
    { 0x87A6, "moving_backward" },
    { 0x87A7, "moving_forward" },
    { 0x87A8, "moving_platform" },
    { 0x87A9, "moving_platform_empty_func" },
    { 0x87AA, "moving_respawn_camera" },
    { 0x87AB, "moving_target_mover" },
    { 0x87AC, "moving_target_reset" },
    { 0x87AD, "moving_target_think" },
    { 0x87AE, "movingc130" },
    { 0x87AF, "movingplatformdetonate" },
    { 0x87B0, "mower_hint_displayed" },
    { 0x87B1, "mp_anim_handle_notetrack" },
    { 0x87B2, "mp_callouts" },
    { 0x87B3, "mp_createfx" },
    { 0x87B4, "mp_entity_handle_notetrack" },
    { 0x87B5, "mp_infil_umike_exit_jump_land_sfx" },
    { 0x87B6, "mp_infil_umike_exit_npc_step_sfx" },
    { 0x87B7, "mp_infil_umike_exit_suspension_creak" },
    { 0x87B8, "mp_notetrack_prefix_handler" },
    { 0x87B9, "mpbuildweaponname" },
    { 0x87BA, "mph_to_ips" },
    { 0x87BB, "mph_travel_time" },
    { 0x87BC, "mphtoips" },
    { 0x87BD, "mpingamelootdrop" },
    { 0x87BE, "mpod1" },
    { 0x87BF, "mpod2" },
    { 0x87C0, "mpplayerallowcrateuse" },
    { 0x87C1, "mpstreaksysteminfo" },
    { 0x87C2, "mpsuperpreviousweapon" },
    { 0x87C3, "msg" },
    { 0x87C4, "mt_getprogress" },
    { 0x87C5, "mt_getstate" },
    { 0x87C6, "mt_gettarget" },
    { 0x87C7, "mt_kills" },
    { 0x87C8, "mt_setprogress" },
    { 0x87C9, "mt_setstate" },
    { 0x87CA, "mugger_add_extra_tag" },
    { 0x87CB, "mugger_bank_limit" },
    { 0x87CC, "mugger_bank_tags" },
    { 0x87CD, "mugger_check_muggernaut" },
    { 0x87CE, "mugger_delayed_banking" },
    { 0x87CF, "mugger_dropzones" },
    { 0x87D0, "mugger_extra_tags" },
    { 0x87D1, "mugger_first_unused_or_oldest_extra_tag" },
    { 0x87D2, "mugger_fx" },
    { 0x87D3, "mugger_fx_playing" },
    { 0x87D4, "mugger_go_to_tag_pile" },
    { 0x87D5, "mugger_init_tags" },
    { 0x87D6, "mugger_jackpot_abort_after_time" },
    { 0x87D7, "mugger_jackpot_cleanup" },
    { 0x87D8, "mugger_jackpot_drop" },
    { 0x87D9, "mugger_jackpot_fx" },
    { 0x87DA, "mugger_jackpot_fx_cleanup" },
    { 0x87DB, "mugger_jackpot_limit" },
    { 0x87DC, "mugger_jackpot_num_tags" },
    { 0x87DD, "mugger_jackpot_pile_notify" },
    { 0x87DE, "mugger_jackpot_pile_notify_cleanup" },
    { 0x87DF, "mugger_jackpot_run" },
    { 0x87E0, "mugger_jackpot_tags_spawned" },
    { 0x87E1, "mugger_jackpot_tags_unspawned" },
    { 0x87E2, "mugger_jackpot_text" },
    { 0x87E3, "mugger_jackpot_timer" },
    { 0x87E4, "mugger_jackpot_wait_sec" },
    { 0x87E5, "mugger_jackpot_watch" },
    { 0x87E6, "mugger_last_mega_drop" },
    { 0x87E7, "mugger_max_extra_tags" },
    { 0x87E8, "mugger_min_spawn_dist_sq" },
    { 0x87E9, "mugger_monitor_remote_uav_pickups" },
    { 0x87EA, "mugger_monitor_tank_pickups" },
    { 0x87EB, "mugger_muggernaut_muggings_needed" },
    { 0x87EC, "mugger_muggernaut_window" },
    { 0x87ED, "mugger_pick_up_tag" },
    { 0x87EE, "mugger_pile_icon_remove" },
    { 0x87EF, "mugger_scorelimit" },
    { 0x87F0, "mugger_tag_pickup_wait" },
    { 0x87F1, "mugger_tag_pile_notify" },
    { 0x87F2, "mugger_tag_temp_spawn" },
    { 0x87F3, "mugger_targetfxid" },
    { 0x87F4, "mugger_throwing_knife_mug_frac" },
    { 0x87F5, "mugger_timelimit" },
    { 0x87F6, "muggercratethink" },
    { 0x87F7, "muggings" },
    { 0x87F8, "mul" },
    { 0x87F9, "mule_weapon" },
    { 0x87FA, "mult_1" },
    { 0x87FB, "mult_2" },
    { 0x87FC, "mult_3" },
    { 0x87FD, "mult_4" },
    { 0x87FE, "multiarena" },
    { 0x87FF, "multiarg" },
    { 0x8800, "multibomb" },
    { 0x8801, "multikill" },
    { 0x8802, "multiple_helis" },
    { 0x8803, "multiplicativedamagemodifierignorefuncs" },
    { 0x8804, "multiplicativedamagemodifiers" },
    { 0x8805, "multiteambased" },
    { 0x8806, "mun_test_monitor" },
    { 0x8807, "munition_slots" },
    { 0x8808, "munition_slots_full" },
    { 0x8809, "munition_splash_supress" },
    { 0x880A, "munitions_in_playerdata" },
    { 0x880B, "munitions_table_data" },
    { 0x880C, "munitionsnotifications" },
    { 0x880D, "murderhole_1_manager" },
    { 0x880E, "murderhole_bldg_door_retreat" },
    { 0x880F, "murderhole_breach_catchup" },
    { 0x8810, "murderhole_breach_clear_griggs_smokes" },
    { 0x8811, "murderhole_breach_main" },
    { 0x8812, "murderhole_breach_start" },
    { 0x8813, "murderhole_catchup" },
    { 0x8814, "murderhole_clean_up_corpses" },
    { 0x8815, "murderhole_dof_on" },
    { 0x8816, "murderhole_enemies" },
    { 0x8817, "murderhole_enemy_behavior" },
    { 0x8818, "murderhole_enemy_cleanup" },
    { 0x8819, "murderhole_enemy_counter" },
    { 0x881A, "murderhole_house_dead_mom" },
    { 0x881B, "murderhole_main" },
    { 0x881C, "murderhole_start" },
    { 0x881D, "mus_barkov_intel" },
    { 0x881E, "mus_barkov_intro" },
    { 0x881F, "mus_barkov_shoot_prisoner" },
    { 0x8820, "mus_barkov_spare_prisoner" },
    { 0x8821, "mus_barkov_stab" },
    { 0x8822, "mus_beadvised" },
    { 0x8823, "mus_bomb_placed" },
    { 0x8824, "mus_bomb_planted" },
    { 0x8825, "mus_cctv" },
    { 0x8826, "mus_chopper_done" },
    { 0x8827, "mus_cockpit_finale" },
    { 0x8828, "mus_courtyard_endmusic" },
    { 0x8829, "mus_discover_russians" },
    { 0x882A, "mus_enforcer_door" },
    { 0x882B, "mus_enforcer_hit" },
    { 0x882C, "mus_enforcer_interact" },
    { 0x882D, "mus_ethnic_battle" },
    { 0x882E, "mus_exterior_battle_stop" },
    { 0x882F, "mus_factory_exit_battle" },
    { 0x8830, "mus_factory_rescue" },
    { 0x8831, "mus_far_free_sisters" },
    { 0x8832, "mus_far_open_vent" },
    { 0x8833, "mus_far_sewer_crawl" },
    { 0x8834, "mus_far_sister_infil" },
    { 0x8835, "mus_farah_final_speech" },
    { 0x8836, "mus_forest_overlook" },
    { 0x8837, "mus_garage" },
    { 0x8838, "mus_get_to_wolf" },
    { 0x8839, "mus_hadir_discover" },
    { 0x883A, "mus_heli_stairs" },
    { 0x883B, "mus_infil" },
    { 0x883C, "mus_intro_torture" },
    { 0x883D, "mus_intro_walkntalk" },
    { 0x883E, "mus_kyle_dryfire" },
    { 0x883F, "mus_kyle_leave" },
    { 0x8840, "mus_kyle_pointgun" },
    { 0x8841, "mus_lights_out" },
    { 0x8842, "mus_lightsout" },
    { 0x8843, "mus_meet_sas" },
    { 0x8844, "mus_mghall_clear" },
    { 0x8845, "mus_outside_door_breach" },
    { 0x8846, "mus_overlook_hot" },
    { 0x8847, "mus_price_intro" },
    { 0x8848, "mus_railyard_combat" },
    { 0x8849, "mus_retreat" },
    { 0x884A, "mus_retreat_cont" },
    { 0x884B, "mus_rooftop_traverse" },
    { 0x884C, "mus_safehouse_leave" },
    { 0x884D, "mus_saferoom" },
    { 0x884E, "mus_save_hadir" },
    { 0x884F, "mus_shaft" },
    { 0x8850, "mus_snakecam_enter" },
    { 0x8851, "mus_truck_leave" },
    { 0x8852, "mus_tunnel_discover" },
    { 0x8853, "mus_tunnels_crawl" },
    { 0x8854, "mus_tunnels_intro" },
    { 0x8855, "mus_waterboard_int" },
    { 0x8856, "mus_wolf_captured" },
    { 0x8857, "mus_wolf_killed" },
    { 0x8858, "music_array" },
    { 0x8859, "music_clear_4th_floor" },
    { 0x885A, "music_ent" },
    { 0x885B, "music_hvt_num" },
    { 0x885C, "music_last_stealth_cue" },
    { 0x885D, "music_post_rappel_stop_after_a_while" },
    { 0x885E, "music_post_rappel_waiting" },
    { 0x885F, "music_style" },
    { 0x8860, "music_transition" },
    { 0x8861, "musiccontroller" },
    { 0x8862, "musicenabled" },
    { 0x8863, "musiclength" },
    { 0x8864, "musicplaying" },
    { 0x8865, "mustchangestance" },
    { 0x8866, "mustmaintainclaim" },
    { 0x8867, "mutations" },
    { 0x8868, "muzzleflashoverride" },
    { 0x8869, "muzzlepoint" },
    { 0x886A, "mvparray" },
    { 0x886B, "mwlogo" },
    { 0x886C, "mx_price_door" },
    { 0x886D, "my_current_node_delays" },
    { 0x886E, "my_spawner" },
    { 0x886F, "my_tank_node" },
    { 0x8870, "mydeathaccidental" },
    { 0x8871, "mydeathanime" },
    { 0x8872, "mydeathanimebool" },
    { 0x8873, "myfloodspawner" },
    { 0x8874, "myfov" },
    { 0x8875, "mygrenadecooldownelapsed" },
    { 0x8876, "n" },
    { 0x8877, "n2" },
    { 0x8878, "n3" },
    { 0x8879, "nade_line" },
    { 0x887A, "nade_trigger_think" },
    { 0x887B, "nade_triggers_init" },
    { 0x887C, "nadia" },
    { 0x887D, "nag" },
    { 0x887E, "nag_anim" },
    { 0x887F, "nag_anims" },
    { 0x8880, "nag_count" },
    { 0x8881, "nag_dialogue" },
    { 0x8882, "nag_dialogue_random" },
    { 0x8883, "nag_door_cut" },
    { 0x8884, "nag_enter_armory" },
    { 0x8885, "nag_enter_b1" },
    { 0x8886, "nag_enter_b1_internal" },
    { 0x8887, "nag_exfil_tutorial" },
    { 0x8888, "nag_get_downstairs" },
    { 0x8889, "nag_get_in_bank" },
    { 0x888A, "nag_get_to_foyer" },
    { 0x888B, "nag_group_create" },
    { 0x888C, "nag_group_getalias" },
    { 0x888D, "nag_id" },
    { 0x888E, "nag_internal" },
    { 0x888F, "nag_interval" },
    { 0x8890, "nag_keys_collect_vo" },
    { 0x8891, "nag_kill_hiltop_heli" },
    { 0x8892, "nag_look_at_bus_scene" },
    { 0x8893, "nag_near_wall" },
    { 0x8894, "nag_player_for_laptop" },
    { 0x8895, "nag_say" },
    { 0x8896, "nag_say_with_hadir" },
    { 0x8897, "nag_storage_mg_nest_vo" },
    { 0x8898, "nag_system" },
    { 0x8899, "nag_time_delay" },
    { 0x889A, "nag_timer" },
    { 0x889B, "nag_vault_search" },
    { 0x889C, "nag_vo" },
    { 0x889D, "nag_vo_handler" },
    { 0x889E, "nag_vo_never_play_again" },
    { 0x889F, "nag_wait" },
    { 0x88A0, "nag_while_near" },
    { 0x88A1, "nags" },
    { 0x88A2, "nags_before_increase" },
    { 0x88A3, "nags_til_notify" },
    { 0x88A4, "nagtill" },
    { 0x88A5, "nagtill_custom" },
    { 0x88A6, "nagtill_delayed" },
    { 0x88A7, "nagtill_distance" },
    { 0x88A8, "nagtill_open" },
    { 0x88A9, "nagtill_open_delayed" },
    { 0x88AA, "nagtill_or_timeout" },
    { 0x88AB, "nagtime" },
    { 0x88AC, "nakeddrop" },
    { 0x88AD, "name_complete" },
    { 0x88AE, "name_hide" },
    { 0x88AF, "name_hide_array" },
    { 0x88B0, "name_show" },
    { 0x88B1, "name_show_array" },
    { 0x88B2, "nameindex" },
    { 0x88B3, "nameplatemanagement" },
    { 0x88B4, "names" },
    { 0x88B5, "namesaidrecently" },
    { 0x88B6, "nationalityokformoveorder" },
    { 0x88B7, "nationalityokformoveordernoncombat" },
    { 0x88B8, "nationalityusescallsigns" },
    { 0x88B9, "nationalityusessurnames" },
    { 0x88BA, "native_wait" },
    { 0x88BB, "nav_bad_place_truck_path" },
    { 0x88BC, "nav_gotopos" },
    { 0x88BD, "nav_lastupdateangle" },
    { 0x88BE, "nav_lastupdatetime" },
    { 0x88BF, "nav_obstacle" },
    { 0x88C0, "nav_repulsors" },
    { 0x88C1, "navbarhideenemies" },
    { 0x88C2, "navbarhideshots" },
    { 0x88C3, "navmeshpos" },
    { 0x88C4, "navmodifer" },
    { 0x88C5, "navmodifier" },
    { 0x88C6, "navobs" },
    { 0x88C7, "navobs2" },
    { 0x88C8, "navobstacle" },
    { 0x88C9, "navobstaclebounds" },
    { 0x88CA, "navobstacleid" },
    { 0x88CB, "navobstacleupdatedistsqr" },
    { 0x88CC, "ne" },
    { 0x88CD, "near_equipment_func" },
    { 0x88CE, "near_hvt" },
    { 0x88CF, "near_ied_zone_warning_monitor" },
    { 0x88D0, "nearblur" },
    { 0x88D1, "nearby_interaction_running" },
    { 0x88D2, "nearby_player_detonate_monitor" },
    { 0x88D3, "nearby_players" },
    { 0x88D4, "nearby_shot_monitor" },
    { 0x88D5, "nearbyplayer" },
    { 0x88D6, "nearbyposarray" },
    { 0x88D7, "nearbysnakecams" },
    { 0x88D8, "nearendfactor" },
    { 0x88D9, "nearest_node" },
    { 0x88DA, "nearest_node_for_camping" },
    { 0x88DB, "nearest_nodes" },
    { 0x88DC, "nearest_point_on_pathgrid" },
    { 0x88DD, "nearest_points" },
    { 0x88DE, "nearestrevivenodepos" },
    { 0x88DF, "nearexploderthink" },
    { 0x88E0, "nearstartfactor" },
    { 0x88E1, "neartrackthink" },
    { 0x88E2, "needle_noise" },
    { 0x88E3, "needrecalculategoodshootpos" },
    { 0x88E4, "needrecalculatesuppressspot" },
    { 0x88E5, "needs_to_evade" },
    { 0x88E6, "needsbuttontorespawn" },
    { 0x88E7, "needsprecaching" },
    { 0x88E8, "needstorechamber" },
    { 0x88E9, "needsupdate" },
    { 0x88EA, "needtoplayintro" },
    { 0x88EB, "needtoreload" },
    { 0x88EC, "needtoturn" },
    { 0x88ED, "needtoturn3d" },
    { 0x88EE, "needtoturnforexit" },
    { 0x88EF, "needtoturnformelee" },
    { 0x88F0, "needtoturntofacepath" },
    { 0x88F1, "needtoturntosmartobject" },
    { 0x88F2, "neighbor_dad" },
    { 0x88F3, "neighbordad_mayhem" },
    { 0x88F4, "neighbors" },
    { 0x88F5, "neil" },
    { 0x88F6, "nerf_already_activated" },
    { 0x88F7, "nerf_based_on_selection" },
    { 0x88F8, "nerf_list" },
    { 0x88F9, "nerf_scalars" },
    { 0x88FA, "nervousness" },
    { 0x88FB, "nets" },
    { 0x88FC, "neutralbrush" },
    { 0x88FD, "neutralflagfx" },
    { 0x88FE, "neutralhardpointfx" },
    { 0x88FF, "neutralized" },
    { 0x8900, "neutralizing" },
    { 0x8901, "neutralzonebrushes" },
    { 0x8902, "never_kill_off" },
    { 0x8903, "never_stop_investigating" },
    { 0x8904, "neverenablecqb" },
    { 0x8905, "neverforcesnipermissenemy" },
    { 0x8906, "neverlean" },
    { 0x8907, "neversprintforvariation" },
    { 0x8908, "neverstopmonitoringflash" },
    { 0x8909, "nevertimeout" },
    { 0x890A, "neveruseagain" },
    { 0x890B, "new" },
    { 0x890C, "new_color_being_set" },
    { 0x890D, "new_force_color_being_set" },
    { 0x890E, "new_goal_listener" },
    { 0x890F, "new_goal_time" },
    { 0x8910, "new_jugg_enemy" },
    { 0x8911, "new_position" },
    { 0x8912, "new_position_while_animating_watcher" },
    { 0x8913, "new_sequence_carried_anim" },
    { 0x8914, "new_target_dist" },
    { 0x8915, "new_tool_hud" },
    { 0x8916, "new_tool_hudelem" },
    { 0x8917, "newdomflag" },
    { 0x8918, "newhudimage" },
    { 0x8919, "newprimarygun" },
    { 0x891A, "newscriptcursor" },
    { 0x891B, "newscripthud" },
    { 0x891C, "newtarget" },
    { 0x891D, "newtargetmessage" },
    { 0x891E, "newtonsmethod" },
    { 0x891F, "newweaponname" },
    { 0x8920, "next" },
    { 0x8921, "next_airdrop_time" },
    { 0x8922, "next_board_to_repair_func" },
    { 0x8923, "next_button" },
    { 0x8924, "next_chance" },
    { 0x8925, "next_dmg_sound" },
    { 0x8926, "next_equipment_time" },
    { 0x8927, "next_false_positive_bank_index" },
    { 0x8928, "next_flag_hide_time" },
    { 0x8929, "next_game_update_time" },
    { 0x892A, "next_goal_time" },
    { 0x892B, "next_hack_update_time" },
    { 0x892C, "next_heli_spawn" },
    { 0x892D, "next_hint_time" },
    { 0x892E, "next_index" },
    { 0x892F, "next_inventory_flash" },
    { 0x8930, "next_maxmoney_hint_time" },
    { 0x8931, "next_mine_drone_out_of_range_vo_time" },
    { 0x8932, "next_node" },
    { 0x8933, "next_pain_vo_time" },
    { 0x8934, "next_play_time" },
    { 0x8935, "next_reactive_time" },
    { 0x8936, "next_rig_num" },
    { 0x8937, "next_role" },
    { 0x8938, "next_scriptable_vo_time" },
    { 0x8939, "next_snipe_try_time" },
    { 0x893A, "next_sniper_glint_time" },
    { 0x893B, "next_sound_time" },
    { 0x893C, "next_sound_wait" },
    { 0x893D, "next_strat_level_check" },
    { 0x893E, "next_target_switch_time" },
    { 0x893F, "next_time_check_tags" },
    { 0x8940, "next_time_hunt_carrier" },
    { 0x8941, "next_time_switch_defusers" },
    { 0x8942, "next_twitch_time" },
    { 0x8943, "next_warning_message_time" },
    { 0x8944, "next_warning_message_time_hvt_getting_away" },
    { 0x8945, "next_wave" },
    { 0x8946, "nextaimtarget" },
    { 0x8947, "nextbalconydeathtime" },
    { 0x8948, "nextcasheffecttime" },
    { 0x8949, "nextcircleendorigin" },
    { 0x894A, "nextcircleendradius" },
    { 0x894B, "nextcircleendtime" },
    { 0x894C, "nextcirclestarttime" },
    { 0x894D, "nextcornergrenadedeathtime" },
    { 0x894E, "nextcorpsechecktime" },
    { 0x894F, "nextcoverchecktime" },
    { 0x8950, "nextcrawlingpaintime" },
    { 0x8951, "nextcrawlingpaintimefromlegdamage" },
    { 0x8952, "nextdeathid" },
    { 0x8953, "nextdialogue" },
    { 0x8954, "nexteventid" },
    { 0x8955, "nextfiretime" },
    { 0x8956, "nextflickertime" },
    { 0x8957, "nextfootstepcreak" },
    { 0x8958, "nextforcedgroupmovementtime" },
    { 0x8959, "nextgrenadedamagedialog" },
    { 0x895A, "nextgrenadedrop" },
    { 0x895B, "nextgrenadetrytime" },
    { 0x895C, "nextgroup" },
    { 0x895D, "nexthittime" },
    { 0x895E, "nextid" },
    { 0x895F, "nextitem" },
    { 0x8960, "nextjuggtimeout" },
    { 0x8961, "nextkillstreakgoal" },
    { 0x8962, "nextlongdeathshoottime" },
    { 0x8963, "nextmayshuffletime" },
    { 0x8964, "nextmeleeattacksound" },
    { 0x8965, "nextmeleechargesound" },
    { 0x8966, "nextmeleechecktime" },
    { 0x8967, "nextmissiletag" },
    { 0x8968, "nextmission" },
    { 0x8969, "nextmission_exit_time" },
    { 0x896A, "nextmission_internal" },
    { 0x896B, "nextmission_preload" },
    { 0x896C, "nextmission_preload_internal" },
    { 0x896D, "nextmission_primeloadbink" },
    { 0x896E, "nextmission_primeloadbink_internal" },
    { 0x896F, "nextmission_wrapper" },
    { 0x8970, "nextnode" },
    { 0x8971, "nextobjectid" },
    { 0x8972, "nextobjective" },
    { 0x8973, "nextoneshotid" },
    { 0x8974, "nextorigin" },
    { 0x8975, "nextpassiverefreshkills" },
    { 0x8976, "nextplayerid" },
    { 0x8977, "nextpoi" },
    { 0x8978, "nextpoint" },
    { 0x8979, "nextposidx" },
    { 0x897A, "nextpossibleblindfiretime" },
    { 0x897B, "nextpostime" },
    { 0x897C, "nextprojectilenearbydialog" },
    { 0x897D, "nextradarpingtime" },
    { 0x897E, "nextradius" },
    { 0x897F, "nextroundisfinalround" },
    { 0x8980, "nextroundismatchpoint" },
    { 0x8981, "nextsave_buffer" },
    { 0x8982, "nextsaytime" },
    { 0x8983, "nextsaytimes" },
    { 0x8984, "nextsceneid" },
    { 0x8985, "nextshotinterval" },
    { 0x8986, "nextspawntobeinstrumented" },
    { 0x8987, "nextsplash" },
    { 0x8988, "nextsplashlistindex" },
    { 0x8989, "nextsquadmergechecktime" },
    { 0x898A, "nextsquadmovementtime" },
    { 0x898B, "nextsteps" },
    { 0x898C, "nextstreakcost" },
    { 0x898D, "nextstylecheck" },
    { 0x898E, "nextstylecheckdist" },
    { 0x898F, "nextstylecheckinterval" },
    { 0x8990, "nextstylechecktime" },
    { 0x8991, "nexttick" },
    { 0x8992, "nexttime" },
    { 0x8993, "nexttrackframe" },
    { 0x8994, "nexttypesaytimes" },
    { 0x8995, "nextupdatetime" },
    { 0x8996, "nextusepress" },
    { 0x8997, "nextusetime" },
    { 0x8998, "nextval" },
    { 0x8999, "nightmap" },
    { 0x899A, "nightvision_override" },
    { 0x899B, "nightvision_override_callback" },
    { 0x899C, "nik_van_init" },
    { 0x899D, "nikolai" },
    { 0x899E, "nikolai_acquire_intro_vo" },
    { 0x899F, "nikolai_car_nags" },
    { 0x89A0, "nikolai_dialog_struct" },
    { 0x89A1, "nikolai_escort_nags" },
    { 0x89A2, "nikolai_intro_handler" },
    { 0x89A3, "nikolai_intro_nags" },
    { 0x89A4, "nikolai_nag_handler" },
    { 0x89A5, "nikolai_van" },
    { 0x89A6, "nikolai_van_anim_setup" },
    { 0x89A7, "nikolaivan" },
    { 0x89A8, "ninebangdoempdamage" },
    { 0x89A9, "ninebangexplodewaiter" },
    { 0x89AA, "ninebangticks" },
    { 0x89AB, "nml_proto" },
    { 0x89AC, "no_abilities" },
    { 0x89AD, "no_ac130_timeout" },
    { 0x89AE, "no_agent_spawn" },
    { 0x89AF, "no_allowdeath" },
    { 0x89B0, "no_attractor" },
    { 0x89B1, "no_bash" },
    { 0x89B2, "no_breath_fx" },
    { 0x89B3, "no_civ_ff_penalty" },
    { 0x89B4, "no_class" },
    { 0x89B5, "no_collide" },
    { 0x89B6, "no_control" },
    { 0x89B7, "no_crouch_or_prone_think_for_player" },
    { 0x89B8, "no_deployables" },
    { 0x89B9, "no_edges" },
    { 0x89BA, "no_fallback" },
    { 0x89BB, "no_friendly_fire_explosive_damage" },
    { 0x89BC, "no_friendly_fire_fail" },
    { 0x89BD, "no_friendly_fire_splash_damage" },
    { 0x89BE, "no_fuse" },
    { 0x89BF, "no_gb_lockon" },
    { 0x89C0, "no_grenades_near_hvt" },
    { 0x89C1, "no_handle_ajar" },
    { 0x89C2, "no_intel_drops" },
    { 0x89C3, "no_lua" },
    { 0x89C4, "no_more_pain" },
    { 0x89C5, "no_moving_platfrom_death" },
    { 0x89C6, "no_moving_platfrom_unlink" },
    { 0x89C7, "no_moving_unresolved_collisions" },
    { 0x89C8, "no_node_to_go_to" },
    { 0x89C9, "no_nodes" },
    { 0x89CA, "no_open_interact" },
    { 0x89CB, "no_outline" },
    { 0x89CC, "no_pain_sound" },
    { 0x89CD, "no_pap_camos" },
    { 0x89CE, "no_physics_collide" },
    { 0x89CF, "no_pistol_switch" },
    { 0x89D0, "no_player" },
    { 0x89D1, "no_point_defined" },
    { 0x89D2, "no_power_cooldowns" },
    { 0x89D3, "no_prone_for_player" },
    { 0x89D4, "no_rblur" },
    { 0x89D5, "no_react" },
    { 0x89D6, "no_reorient" },
    { 0x89D7, "no_rider_death" },
    { 0x89D8, "no_rushin" },
    { 0x89D9, "no_scriptable" },
    { 0x89DA, "no_seeker" },
    { 0x89DB, "no_slowmo" },
    { 0x89DC, "no_static_shadows" },
    { 0x89DD, "no_tarp" },
    { 0x89DE, "no_team_outlines" },
    { 0x89DF, "no_treads" },
    { 0x89E0, "no_vehicle_getoutanim" },
    { 0x89E1, "no_vehicle_ragdoll" },
    { 0x89E2, "no_weapon_fired_notify" },
    { 0x89E3, "no_weapon_sound" },
    { 0x89E4, "noachievement" },
    { 0x89E5, "noactivation" },
    { 0x89E6, "noalternates" },
    { 0x89E7, "noanim_deployturret" },
    { 0x89E8, "noargs" },
    { 0x89E9, "noarmor" },
    { 0x89EA, "nobroshot" },
    { 0x89EB, "nobuddyspawns" },
    { 0x89EC, "nocarryobject" },
    { 0x89ED, "nocircle" },
    { 0x89EE, "nocorpse" },
    { 0x89EF, "nocorpsedelete" },
    { 0x89F0, "nod_gesture" },
    { 0x89F1, "nodamage" },
    { 0x89F2, "node_ambushing_from" },
    { 0x89F3, "node_anim_reach_idle" },
    { 0x89F4, "node_claimed" },
    { 0x89F5, "node_closest_to_defend_center" },
    { 0x89F6, "node_creation_angle_frac" },
    { 0x89F7, "node_creation_trace_dist" },
    { 0x89F8, "node_creation_trace_index" },
    { 0x89F9, "node_creation_traces" },
    { 0x89FA, "node_display_debug" },
    { 0x89FB, "node_fields_after_goal" },
    { 0x89FC, "node_fields_after_goal_and_wait" },
    { 0x89FD, "node_fields_pre_goal" },
    { 0x89FE, "node_flag_triggered" },
    { 0x89FF, "node_flag_triggered_cleanup" },
    { 0x8A00, "node_has_radius" },
    { 0x8A01, "node_is_on_path_from_labels" },
    { 0x8A02, "node_is_valid_outside_for_vanguard" },
    { 0x8A03, "node_passes_nav_and_geo_validation" },
    { 0x8A04, "node_path" },
    { 0x8A05, "node_spawner_init" },
    { 0x8A06, "node_type" },
    { 0x8A07, "node_wait" },
    { 0x8A08, "node_within_fov" },
    { 0x8A09, "node_within_use_radius_of_crate" },
    { 0x8A0A, "nodeath" },
    { 0x8A0B, "nodeathsfrombehind_evaluate" },
    { 0x8A0C, "nodeend" },
    { 0x8A0D, "nodeexposedpitches" },
    { 0x8A0E, "nodeexposedyaws" },
    { 0x8A0F, "nodefaultweapon" },
    { 0x8A10, "nodeidle" },
    { 0x8A11, "nodeiscoverexposed3dtype" },
    { 0x8A12, "nodeiscoverstand3dtype" },
    { 0x8A13, "nodeleanpitches" },
    { 0x8A14, "nodeleanyaws" },
    { 0x8A15, "nodeoffsets" },
    { 0x8A16, "nodeoverleanpitches" },
    { 0x8A17, "nodes" },
    { 0x8A18, "nodes_flag_triggered" },
    { 0x8A19, "nodescore" },
    { 0x8A1A, "nodeshouldfaceangles" },
    { 0x8A1B, "nodeyaws" },
    { 0x8A1C, "nodroneweaponsound" },
    { 0x8A1D, "nodrop" },
    { 0x8A1E, "nodropgrenade" },
    { 0x8A1F, "nofacialfiller" },
    { 0x8A20, "nofailontimeout" },
    { 0x8A21, "nofallanim" },
    { 0x8A22, "noflashlight" },
    { 0x8A23, "nofour" },
    { 0x8A24, "nofriendlytags" },
    { 0x8A25, "nogib" },
    { 0x8A26, "nogravityragdoll" },
    { 0x8A27, "nogrenadethrow" },
    { 0x8A28, "nohelmetpop" },
    { 0x8A29, "nohint" },
    { 0x8A2A, "noise" },
    { 0x8A2B, "noisemakerfiremain" },
    { 0x8A2C, "noisemakersdisablecursors" },
    { 0x8A2D, "noisemakersenablecursors" },
    { 0x8A2E, "noisemakerwaitpickup" },
    { 0x8A2F, "nojip" },
    { 0x8A30, "nokill10deaths_evaluate" },
    { 0x8A31, "nokillnodeath_evaluate" },
    { 0x8A32, "nokillswithdeath_evaluate" },
    { 0x8A33, "nolightfx" },
    { 0x8A34, "noloot" },
    { 0x8A35, "nomortar" },
    { 0x8A36, "non_gesture_death_anim" },
    { 0x8A37, "non_hall_3f_cleared_vo" },
    { 0x8A38, "non_player_add_attacker_data" },
    { 0x8A39, "non_player_add_ignore_damage_signature" },
    { 0x8A3A, "non_player_clear_attacker_data" },
    { 0x8A3B, "non_player_clear_ignore_damage_signatures" },
    { 0x8A3C, "non_player_get_attacker_data" },
    { 0x8A3D, "non_player_log_attacker_data" },
    { 0x8A3E, "non_player_remove_ignore_damage_signature" },
    { 0x8A3F, "non_player_should_ignore_damage" },
    { 0x8A40, "non_player_should_ignore_damage_signature" },
    { 0x8A41, "non_sync_bomb_defusal" },
    { 0x8A42, "nonanimatedpositions" },
    { 0x8A43, "nonfauxspawnsetup" },
    { 0x8A44, "nonobjective_requestobjectiveid" },
    { 0x8A45, "nonobjective_returnobjectiveid" },
    { 0x8A46, "nonvectorlength" },
    { 0x8A47, "nonvehicle" },
    { 0x8A48, "noobjective" },
    { 0x8A49, "noop" },
    { 0x8A4A, "nopathnodes" },
    { 0x8A4B, "nopickuptime" },
    { 0x8A4C, "noragdoll" },
    { 0x8A4D, "noragdollents" },
    { 0x8A4E, "noreact" },
    { 0x8A4F, "norestoreweaponsdefaultfunc" },
    { 0x8A50, "norewardiconintro" },
    { 0x8A51, "normal_friendly_fire_penalty" },
    { 0x8A52, "normal_mode_activation_funcs" },
    { 0x8A53, "normal_revive_time" },
    { 0x8A54, "normalize_carried_angles" },
    { 0x8A55, "normalize_compare" },
    { 0x8A56, "normalize_script_friendname" },
    { 0x8A57, "normalize_value" },
    { 0x8A58, "normalizecompassdirection" },
    { 0x8A59, "normalized_cos_wave" },
    { 0x8A5A, "normalized_distance" },
    { 0x8A5B, "normalized_float_smooth_in" },
    { 0x8A5C, "normalized_float_smooth_out" },
    { 0x8A5D, "normalized_float_smoth_in_out" },
    { 0x8A5E, "normalized_kill" },
    { 0x8A5F, "normalized_parabola" },
    { 0x8A60, "normalized_sin_wave" },
    { 0x8A61, "normalized_starttime" },
    { 0x8A62, "normalized_to_decay_clamps" },
    { 0x8A63, "normalized_to_growth_clamps" },
    { 0x8A64, "northeast_carcrash" },
    { 0x8A65, "noscopeoutlinesetnotifs" },
    { 0x8A66, "noscopeoutlineunsetnotifs" },
    { 0x8A67, "noscriptable" },
    { 0x8A68, "noself_array_call" },
    { 0x8A69, "noself_delaycall" },
    { 0x8A6A, "noself_delaycall_proc" },
    { 0x8A6B, "noself_func" },
    { 0x8A6C, "noself_func_return" },
    { 0x8A6D, "noshooting" },
    { 0x8A6E, "nosighttime" },
    { 0x8A6F, "nosquad" },
    { 0x8A70, "nostuckdamagekill" },
    { 0x8A71, "nosuspensemusic" },
    { 0x8A72, "not_closing" },
    { 0x8A73, "not_compromised" },
    { 0x8A74, "not_opening" },
    { 0x8A75, "notanksquish" },
    { 0x8A76, "note_attach" },
    { 0x8A77, "note_track_start_fx_on_tag" },
    { 0x8A78, "note_track_start_sound" },
    { 0x8A79, "note_track_stop_efx_on_tag" },
    { 0x8A7A, "note_track_swap_to_efx" },
    { 0x8A7B, "note_track_trace_to_efx" },
    { 0x8A7C, "notehandler_deploylmg" },
    { 0x8A7D, "noteleport" },
    { 0x8A7E, "notes" },
    { 0x8A7F, "notetrack" },
    { 0x8A80, "notetrack_civ_killed" },
    { 0x8A81, "notetrack_effect" },
    { 0x8A82, "notetrack_handler" },
    { 0x8A83, "notetrack_listener_cattleprod_shock_player" },
    { 0x8A84, "notetrack_listener_close_cell_doors" },
    { 0x8A85, "notetrack_listener_close_cellblock_door" },
    { 0x8A86, "notetrack_listener_disable_spring_cam" },
    { 0x8A87, "notetrack_listener_enable_spring_cam" },
    { 0x8A88, "notetrack_listener_open_cell_doors" },
    { 0x8A89, "notetrack_listener_open_cellblock_door" },
    { 0x8A8A, "notetrack_listener_unshackle" },
    { 0x8A8B, "notetrack_mission_failed_vo_disable" },
    { 0x8A8C, "notetrack_mission_failed_vo_enable" },
    { 0x8A8D, "notetrack_model_attach" },
    { 0x8A8E, "notetrack_model_clear" },
    { 0x8A8F, "notetrack_model_translate" },
    { 0x8A90, "notetrack_nag" },
    { 0x8A91, "notetrack_prefix_handler" },
    { 0x8A92, "notetrack_prefix_handler_common" },
    { 0x8A93, "notetrack_prefix_handler_mp" },
    { 0x8A94, "notetrack_prefix_handler_sp" },
    { 0x8A95, "notetrack_timeout" },
    { 0x8A96, "notetrack_vo" },
    { 0x8A97, "notetrack_vo_disable" },
    { 0x8A98, "notetrack_vo_enable" },
    { 0x8A99, "notetrack_wait" },
    { 0x8A9A, "notetrack_watcher" },
    { 0x8A9B, "notetrackalertnessaiming" },
    { 0x8A9C, "notetrackalertnessalert" },
    { 0x8A9D, "notetrackalertnesscasual" },
    { 0x8A9E, "notetrackbodyfall" },
    { 0x8A9F, "notetrackcodemove" },
    { 0x8AA0, "notetrackcoverposerequest" },
    { 0x8AA1, "notetrackdropclip" },
    { 0x8AA2, "notetrackfaceenemy" },
    { 0x8AA3, "notetrackfacialangry" },
    { 0x8AA4, "notetrackfacialcheer" },
    { 0x8AA5, "notetrackfacialdeath" },
    { 0x8AA6, "notetrackfacialgasdeath" },
    { 0x8AA7, "notetrackfacialhappy" },
    { 0x8AA8, "notetrackfacialidle" },
    { 0x8AA9, "notetrackfacialpain" },
    { 0x8AAA, "notetrackfacialrun" },
    { 0x8AAB, "notetrackfacialscared" },
    { 0x8AAC, "notetrackfacialtalk" },
    { 0x8AAD, "notetrackfingerposeoffleft" },
    { 0x8AAE, "notetrackfingerposeoffright" },
    { 0x8AAF, "notetrackfingerposeonleft" },
    { 0x8AB0, "notetrackfingerposeonright" },
    { 0x8AB1, "notetrackfire" },
    { 0x8AB2, "notetrackfirespray" },
    { 0x8AB3, "notetrackfootscrape" },
    { 0x8AB4, "notetrackfootstep" },
    { 0x8AB5, "notetrackgravity" },
    { 0x8AB6, "notetrackgundrop" },
    { 0x8AB7, "notetrackgunhand" },
    { 0x8AB8, "notetrackguntoback" },
    { 0x8AB9, "notetrackguntochest" },
    { 0x8ABA, "notetrackguntoright" },
    { 0x8ABB, "notetrackhandle" },
    { 0x8ABC, "notetrackhandstep" },
    { 0x8ABD, "notetrackhelmetpop" },
    { 0x8ABE, "notetrackhtoff" },
    { 0x8ABF, "notetrackhton0" },
    { 0x8AC0, "notetrackhton1" },
    { 0x8AC1, "notetrackland" },
    { 0x8AC2, "notetracklaser" },
    { 0x8AC3, "notetrackloadshell" },
    { 0x8AC4, "notetrackmayhemstarted" },
    { 0x8AC5, "notetrackmissionfailedvo" },
    { 0x8AC6, "notetrackmovement" },
    { 0x8AC7, "notetrackmovementgunposeoverride" },
    { 0x8AC8, "notetrackmovementrun" },
    { 0x8AC9, "notetrackmovementstop" },
    { 0x8ACA, "notetrackmovementwalk" },
    { 0x8ACB, "notetrackpistolpickup" },
    { 0x8ACC, "notetrackpistolputaway" },
    { 0x8ACD, "notetrackpistolrechamber" },
    { 0x8ACE, "notetrackposeback" },
    { 0x8ACF, "notetrackposecrawl" },
    { 0x8AD0, "notetrackposecrouch" },
    { 0x8AD1, "notetrackposeprone" },
    { 0x8AD2, "notetrackposestand" },
    { 0x8AD3, "notetrackragdollblendend" },
    { 0x8AD4, "notetrackragdollblendinit" },
    { 0x8AD5, "notetrackragdollblendrootanim" },
    { 0x8AD6, "notetrackragdollblendrootragdoll" },
    { 0x8AD7, "notetrackragdollblendstart" },
    { 0x8AD8, "notetrackrefillclip" },
    { 0x8AD9, "notetrackrocketlauncherammoattach" },
    { 0x8ADA, "notetracks" },
    { 0x8ADB, "notetrackstartragdoll" },
    { 0x8ADC, "notetrackstopanim" },
    { 0x8ADD, "notetrackvisorlower" },
    { 0x8ADE, "notetrackvisorlower_instant" },
    { 0x8ADF, "notetrackvisorpricelower_instant" },
    { 0x8AE0, "notetrackvisorpriceraise_instant" },
    { 0x8AE1, "notetrackvisorraise" },
    { 0x8AE2, "notetrackvisorraise_clear" },
    { 0x8AE3, "notetrackvisorraise_instant" },
    { 0x8AE4, "notetrackvo" },
    { 0x8AE5, "noteworthy" },
    { 0x8AE6, "notfirsttime" },
    { 0x8AE7, "nothreat" },
    { 0x8AE8, "notificationdisplayandfade" },
    { 0x8AE9, "notificationpulse" },
    { 0x8AEA, "notifications" },
    { 0x8AEB, "notifiedtimesup" },
    { 0x8AEC, "notifies" },
    { 0x8AED, "notify_after_time" },
    { 0x8AEE, "notify_all_groups_in_module" },
    { 0x8AEF, "notify_apache_ai_kill" },
    { 0x8AF0, "notify_building_breach" },
    { 0x8AF1, "notify_death_to_group" },
    { 0x8AF2, "notify_delay" },
    { 0x8AF3, "notify_disable" },
    { 0x8AF4, "notify_enable" },
    { 0x8AF5, "notify_end_of_anim" },
    { 0x8AF6, "notify_enemy_bots_bomb_used" },
    { 0x8AF7, "notify_enemy_team_bomb_used" },
    { 0x8AF8, "notify_enter_tunnel" },
    { 0x8AF9, "notify_if_player_can_see_me" },
    { 0x8AFA, "notify_if_teleport_clear" },
    { 0x8AFB, "notify_moving_platform_invalid" },
    { 0x8AFC, "notify_nearby_casual_killers" },
    { 0x8AFD, "notify_nearby_enemies" },
    { 0x8AFE, "notify_on_damage" },
    { 0x8AFF, "notify_on_end" },
    { 0x8B00, "notify_on_killed_by_apache" },
    { 0x8B01, "notify_on_lookat_dad" },
    { 0x8B02, "notify_on_trip_defused" },
    { 0x8B03, "notify_on_vip_death" },
    { 0x8B04, "notify_on_whizby" },
    { 0x8B05, "notify_others_in_group" },
    { 0x8B06, "notify_queue" },
    { 0x8B07, "notify_self_nag" },
    { 0x8B08, "notify_start" },
    { 0x8B09, "notify_started_nag" },
    { 0x8B0A, "notify_stop" },
    { 0x8B0B, "notify_system_to_grab_next_vo_from_queue" },
    { 0x8B0C, "notify_timeup_consumable" },
    { 0x8B0D, "notify_trigger_on_death" },
    { 0x8B0E, "notify_used_consumable" },
    { 0x8B0F, "notify_when_group_ends" },
    { 0x8B10, "notify_when_player_nearby" },
    { 0x8B11, "notify_when_player_shot_on_ladder" },
    { 0x8B12, "notify_when_tag_aborted" },
    { 0x8B13, "notify_when_tag_picked_up" },
    { 0x8B14, "notify_when_tag_picked_up_or_unavailable" },
    { 0x8B15, "notify_whizby_from_player" },
    { 0x8B16, "notify_within_distance" },
    { 0x8B17, "notifyafkofselection" },
    { 0x8B18, "notifyafterframeend" },
    { 0x8B19, "notifyaftertime" },
    { 0x8B1A, "notifyangles" },
    { 0x8B1B, "notifyarmorgesturecomplete" },
    { 0x8B1C, "notifyconnecting" },
    { 0x8B1D, "notifycounter" },
    { 0x8B1E, "notifydamage" },
    { 0x8B1F, "notifydamagenotdone" },
    { 0x8B20, "notifydeath" },
    { 0x8B21, "notifydeathdelayed" },
    { 0x8B22, "notifydown" },
    { 0x8B23, "notifyentities" },
    { 0x8B24, "notifyentity" },
    { 0x8B25, "notifygrenadepickup" },
    { 0x8B26, "notifyhit" },
    { 0x8B27, "notifykilledplayer" },
    { 0x8B28, "notifymessage" },
    { 0x8B29, "notifyname" },
    { 0x8B2A, "notifynormal" },
    { 0x8B2B, "notifyondelete" },
    { 0x8B2C, "notifyonplayercommandbetting" },
    { 0x8B2D, "notifyorigin" },
    { 0x8B2E, "notifyplayers" },
    { 0x8B2F, "notifyplayerscore" },
    { 0x8B30, "notifypowerduration" },
    { 0x8B31, "notifyradius" },
    { 0x8B32, "notifyremoveoutlines" },
    { 0x8B33, "notifyreviveregen" },
    { 0x8B34, "notifystartaim" },
    { 0x8B35, "notifystring" },
    { 0x8B36, "notifyteam" },
    { 0x8B37, "notifytoendmark" },
    { 0x8B38, "notifyuiofpickedupweapon" },
    { 0x8B39, "notifyup" },
    { 0x8B3A, "notifyupdateplantedequipment" },
    { 0x8B3B, "notifywhentauntstimedout" },
    { 0x8B3C, "notshouldidlebark" },
    { 0x8B3D, "notshouldstartarrival" },
    { 0x8B3E, "notsolid" },
    { 0x8B3F, "notthrown" },
    { 0x8B40, "notti" },
    { 0x8B41, "noturnanims" },
    { 0x8B42, "notusableafterownerchange" },
    { 0x8B43, "notusableforjoiningplayers" },
    { 0x8B44, "nousebar" },
    { 0x8B45, "nousekillstreak" },
    { 0x8B46, "novolumetric" },
    { 0x8B47, "nowaypoint" },
    { 0x8B48, "noweapondropallowedtrigger" },
    { 0x8B49, "noweaponfalloff" },
    { 0x8B4A, "noweaponsonstart" },
    { 0x8B4B, "nowhizby" },
    { 0x8B4C, "nozonetriggers" },
    { 0x8B4D, "npc_revive_available" },
    { 0x8B4E, "npcid" },
    { 0x8B4F, "npcidtracker" },
    { 0x8B50, "npicon" },
    { 0x8B51, "nt_test" },
    { 0x8B52, "nuclear_core" },
    { 0x8B53, "nuclear_core_carrier" },
    { 0x8B54, "nuclear_core_delete_after_timeout" },
    { 0x8B55, "nuclear_core_interaction" },
    { 0x8B56, "nuclear_crate" },
    { 0x8B57, "nuclear_crate_interaction" },
    { 0x8B58, "nuclearcorepickedup" },
    { 0x8B59, "nuke" },
    { 0x8B5A, "nuke_adjustexplosiondof" },
    { 0x8B5B, "nuke_atomizebody" },
    { 0x8B5C, "nuke_cankill" },
    { 0x8B5D, "nuke_cankilleverything" },
    { 0x8B5E, "nuke_cleartimer" },
    { 0x8B5F, "nuke_clockobject" },
    { 0x8B60, "nuke_createradiationzone" },
    { 0x8B61, "nuke_death" },
    { 0x8B62, "nuke_delayendgame" },
    { 0x8B63, "nuke_delaythread" },
    { 0x8B64, "nuke_destroyactiveobjects" },
    { 0x8B65, "nuke_dof" },
    { 0x8B66, "nuke_earthquake" },
    { 0x8B67, "nuke_expl_struct" },
    { 0x8B68, "nuke_explosion" },
    { 0x8B69, "nuke_explosionpos" },
    { 0x8B6A, "nuke_fadeflashvision" },
    { 0x8B6B, "nuke_finalizelocationnuke" },
    { 0x8B6C, "nuke_findunobstructedfiringinfo" },
    { 0x8B6D, "nuke_inflictor" },
    { 0x8B6E, "nuke_interactions" },
    { 0x8B6F, "nuke_isplayerinradzone" },
    { 0x8B70, "nuke_launchmissile" },
    { 0x8B71, "nuke_missile" },
    { 0x8B72, "nuke_playrollingdeathfx" },
    { 0x8B73, "nuke_playshockwaveearthquake" },
    { 0x8B74, "nuke_radzones_think" },
    { 0x8B75, "nuke_registerradzone" },
    { 0x8B76, "nuke_removeradzone" },
    { 0x8B77, "nuke_setaftermathvision" },
    { 0x8B78, "nuke_setvisionforplayer" },
    { 0x8B79, "nuke_slowmo" },
    { 0x8B7A, "nuke_start" },
    { 0x8B7B, "nuke_startexplosionaudio" },
    { 0x8B7C, "nuke_startlaunchsequence" },
    { 0x8B7D, "nuke_startmissileflightaudio" },
    { 0x8B7E, "nuke_startnukedeathfx" },
    { 0x8B7F, "nuke_startnukedeathfx_chooselocationversion" },
    { 0x8B80, "nuke_startprelaunchalarm" },
    { 0x8B81, "nuke_starttimer" },
    { 0x8B82, "nuke_updateuitimers" },
    { 0x8B83, "nuke_updatevisiononhostmigration" },
    { 0x8B84, "nuke_vision" },
    { 0x8B85, "nuke_warnenemiesnukeincoming" },
    { 0x8B86, "nuke_watchownerdisconnect" },
    { 0x8B87, "nukecancel" },
    { 0x8B88, "nukecharge" },
    { 0x8B89, "nuked" },
    { 0x8B8A, "nukedangerzones" },
    { 0x8B8B, "nukedeathvisionfunc" },
    { 0x8B8C, "nukedetonated" },
    { 0x8B8D, "nukeexplodetimer" },
    { 0x8B8E, "nukeflash" },
    { 0x8B8F, "nukegameover" },
    { 0x8B90, "nukegoalpoint" },
    { 0x8B91, "nukeincoming" },
    { 0x8B92, "nukeinfo" },
    { 0x8B93, "nukeinteraction" },
    { 0x8B94, "nukelaunchtimer" },
    { 0x8B95, "nukepoints" },
    { 0x8B96, "nukeprogress" },
    { 0x8B97, "nukeselectactive" },
    { 0x8B98, "nukeselectgimmewatcher" },
    { 0x8B99, "nukespoted" },
    { 0x8B9A, "nukespotted" },
    { 0x8B9B, "nuketype" },
    { 0x8B9C, "nukeused" },
    { 0x8B9D, "nukevisioninprogress" },
    { 0x8B9E, "nukevisionset" },
    { 0x8B9F, "null_catchup" },
    { 0x8BA0, "nulldamagecheck" },
    { 0x8BA1, "nullownerdamagefunc" },
    { 0x8BA2, "num" },
    { 0x8BA3, "num_charges_to_plant" },
    { 0x8BA4, "num_fails" },
    { 0x8BA5, "num_guys" },
    { 0x8BA6, "num_healthpacks" },
    { 0x8BA7, "num_missiles" },
    { 0x8BA8, "num_of_bomb_defused" },
    { 0x8BA9, "num_of_concrete_blocks" },
    { 0x8BAA, "num_of_ied_hit" },
    { 0x8BAB, "num_of_player_ready_to_infil" },
    { 0x8BAC, "num_of_plays" },
    { 0x8BAD, "num_of_quest_pieces_completed" },
    { 0x8BAE, "num_players_checked_in" },
    { 0x8BAF, "num_script_models" },
    { 0x8BB0, "num_secondary_objectives_active" },
    { 0x8BB1, "num_shots_left" },
    { 0x8BB2, "num_side_objectives_active" },
    { 0x8BB3, "num_sniper_covering_me" },
    { 0x8BB4, "num_snipers_covering_me" },
    { 0x8BB5, "num_time_getting_to_corpse" },
    { 0x8BB6, "num_waves" },
    { 0x8BB7, "numadditionalprimaries" },
    { 0x8BB8, "numagents" },
    { 0x8BB9, "numareas" },
    { 0x8BBA, "number" },
    { 0x8BBB, "number_of_games_played" },
    { 0x8BBC, "number_of_players_in_plane" },
    { 0x8BBD, "numbermapobjs" },
    { 0x8BBE, "numcaps" },
    { 0x8BBF, "numchevrons" },
    { 0x8BC0, "numcrates" },
    { 0x8BC1, "numcrawls" },
    { 0x8BC2, "numdeathsuntilcornergrenadedeath" },
    { 0x8BC3, "numdeathsuntilcrawlingpain" },
    { 0x8BC4, "numendgame" },
    { 0x8BC5, "numenemyvoices" },
    { 0x8BC6, "numextractpointsavailable" },
    { 0x8BC7, "numfails" },
    { 0x8BC8, "numflagsscoreonkill" },
    { 0x8BC9, "numflares" },
    { 0x8BCA, "numfriendlyfemalevoices" },
    { 0x8BCB, "numfriendlyvoices" },
    { 0x8BCC, "numgametypereservedobjectives" },
    { 0x8BCD, "numgrabs" },
    { 0x8BCE, "numgrenadesinprogresstowardsplayer" },
    { 0x8BCF, "numhqtanks_allies" },
    { 0x8BD0, "numhqtanks_axis" },
    { 0x8BD1, "numinitialinfected" },
    { 0x8BD2, "numitems" },
    { 0x8BD3, "numkills" },
    { 0x8BD4, "numknives" },
    { 0x8BD5, "numleadersinterrogated" },
    { 0x8BD6, "numlifelimited" },
    { 0x8BD7, "numlosingplayers" },
    { 0x8BD8, "nummistclusters" },
    { 0x8BD9, "numplayers" },
    { 0x8BDA, "numplayerswaitingtoenterkillcam" },
    { 0x8BDB, "numplayerswaitingtospawn" },
    { 0x8BDC, "numrevives" },
    { 0x8BDD, "numspeakers" },
    { 0x8BDE, "numthinkfuncs" },
    { 0x8BDF, "numtouching" },
    { 0x8BE0, "numtouchrequired" },
    { 0x8BE1, "numtouchrequireduse" },
    { 0x8BE2, "numuses" },
    { 0x8BE3, "numwinningplayers" },
    { 0x8BE4, "nvals" },
    { 0x8BE5, "nvg" },
    { 0x8BE6, "nvg_ai" },
    { 0x8BE7, "nvg_ai_init" },
    { 0x8BE8, "nvg_death_cleanup" },
    { 0x8BE9, "nvg_death_hint" },
    { 0x8BEA, "nvg_exterior_monitor" },
    { 0x8BEB, "nvg_eyelights_thread" },
    { 0x8BEC, "nvg_flir_off" },
    { 0x8BED, "nvg_flir_on" },
    { 0x8BEE, "nvg_get3rdpersondownmodel" },
    { 0x8BEF, "nvg_get3rdpersonupmodel" },
    { 0x8BF0, "nvg_goggles" },
    { 0x8BF1, "nvg_hint_display" },
    { 0x8BF2, "nvg_init" },
    { 0x8BF3, "nvg_mb_off" },
    { 0x8BF4, "nvg_mb_on" },
    { 0x8BF5, "nvg_monitor" },
    { 0x8BF6, "nvg_off_fx" },
    { 0x8BF7, "nvg_off_hint" },
    { 0x8BF8, "nvg_on" },
    { 0x8BF9, "nvg_on_fx" },
    { 0x8BFA, "nvg_on_hint" },
    { 0x8BFB, "nvg_overblown_hint" },
    { 0x8BFC, "nvg_update3rdperson" },
    { 0x8BFD, "nvg_vision_power" },
    { 0x8BFE, "nvg_was_on" },
    { 0x8BFF, "nvg3rdpersonmodel" },
    { 0x8C00, "nvgheadoverrides" },
    { 0x8C01, "nvghintnotify" },
    { 0x8C02, "nvglights" },
    { 0x8C03, "nvgmodel_off" },
    { 0x8C04, "nvgmodel_on" },
    { 0x8C05, "nvgs_on" },
    { 0x8C06, "nx1_hint_display" },
    { 0x8C07, "obfuscateobjectiveposition" },
    { 0x8C08, "obj" },
    { 0x8C09, "obj_ac130_player" },
    { 0x8C0A, "obj_alarm" },
    { 0x8C0B, "obj_allow_call_train" },
    { 0x8C0C, "obj_allow_fulton" },
    { 0x8C0D, "obj_bb_recovery" },
    { 0x8C0E, "obj_building_hostages_1" },
    { 0x8C0F, "obj_building_hostages_2" },
    { 0x8C10, "obj_building_hostages_3" },
    { 0x8C11, "obj_building_hostages_4" },
    { 0x8C12, "obj_building_hostages_5" },
    { 0x8C13, "obj_building_hostages_6" },
    { 0x8C14, "obj_buildings_looked_at" },
    { 0x8C15, "obj_cache_def" },
    { 0x8C16, "obj_cache_num" },
    { 0x8C17, "obj_caches_foundlead" },
    { 0x8C18, "obj_caches_foundleadtime" },
    { 0x8C19, "obj_call_train_count" },
    { 0x8C1A, "obj_called_train" },
    { 0x8C1B, "obj_can_call_train" },
    { 0x8C1C, "obj_comms_start" },
    { 0x8C1D, "obj_continue_fulton_extraction" },
    { 0x8C1E, "obj_current_barrels_scanned" },
    { 0x8C1F, "obj_def_cur_time" },
    { 0x8C20, "obj_def_time" },
    { 0x8C21, "obj_default_beat" },
    { 0x8C22, "obj_default_end" },
    { 0x8C23, "obj_default_init" },
    { 0x8C24, "obj_default_start" },
    { 0x8C25, "obj_door" },
    { 0x8C26, "obj_door_destroy" },
    { 0x8C27, "obj_door_interact" },
    { 0x8C28, "obj_door_setup" },
    { 0x8C29, "obj_enemy_incoming_vo" },
    { 0x8C2A, "obj_exploding_train" },
    { 0x8C2B, "obj_found_lead_here_vo" },
    { 0x8C2C, "obj_got_extract" },
    { 0x8C2D, "obj_hud_text_leadstotal" },
    { 0x8C2E, "obj_hud_text_type" },
    { 0x8C2F, "obj_hvt_spawn_struct" },
    { 0x8C30, "obj_index" },
    { 0x8C31, "obj_keys_nags" },
    { 0x8C32, "obj_last_hostage_vo" },
    { 0x8C33, "obj_leads_found" },
    { 0x8C34, "obj_leads_found_good" },
    { 0x8C35, "obj_leads_found_reg" },
    { 0x8C36, "obj_leads_hint_timer" },
    { 0x8C37, "obj_leads_models" },
    { 0x8C38, "obj_leads_total_size" },
    { 0x8C39, "obj_leads_type" },
    { 0x8C3A, "obj_maj_advance_end" },
    { 0x8C3B, "obj_maj_advance_init" },
    { 0x8C3C, "obj_maj_advance_start" },
    { 0x8C3D, "obj_maj_approach_end" },
    { 0x8C3E, "obj_maj_approach_init" },
    { 0x8C3F, "obj_maj_approach_start" },
    { 0x8C40, "obj_maj_bombdefuse_end" },
    { 0x8C41, "obj_maj_bombdefuse_init" },
    { 0x8C42, "obj_maj_bombdefuse_start" },
    { 0x8C43, "obj_maj_cache_end" },
    { 0x8C44, "obj_maj_cache_init" },
    { 0x8C45, "obj_maj_cache_start" },
    { 0x8C46, "obj_maj_call_train_end" },
    { 0x8C47, "obj_maj_call_train_init" },
    { 0x8C48, "obj_maj_call_train_start" },
    { 0x8C49, "obj_maj_comms_end" },
    { 0x8C4A, "obj_maj_comms_init" },
    { 0x8C4B, "obj_maj_comms_start" },
    { 0x8C4C, "obj_maj_defend_end" },
    { 0x8C4D, "obj_maj_defend_init" },
    { 0x8C4E, "obj_maj_defend_start" },
    { 0x8C4F, "obj_maj_defense_end" },
    { 0x8C50, "obj_maj_defense_init" },
    { 0x8C51, "obj_maj_defense_start" },
    { 0x8C52, "obj_maj_exit_end" },
    { 0x8C53, "obj_maj_exit_init" },
    { 0x8C54, "obj_maj_exit_start" },
    { 0x8C55, "obj_maj_extract_end" },
    { 0x8C56, "obj_maj_extract_init" },
    { 0x8C57, "obj_maj_extract_start" },
    { 0x8C58, "obj_maj_extraction_end" },
    { 0x8C59, "obj_maj_extraction_init" },
    { 0x8C5A, "obj_maj_extraction_start" },
    { 0x8C5B, "obj_maj_find_keys_end" },
    { 0x8C5C, "obj_maj_find_keys_init" },
    { 0x8C5D, "obj_maj_find_keys_start" },
    { 0x8C5E, "obj_maj_grab_end" },
    { 0x8C5F, "obj_maj_grab_init" },
    { 0x8C60, "obj_maj_grab_start" },
    { 0x8C61, "obj_maj_hackinterrupt_end" },
    { 0x8C62, "obj_maj_hackinterrupt_init" },
    { 0x8C63, "obj_maj_hackinterrupt_start" },
    { 0x8C64, "obj_maj_intro_end" },
    { 0x8C65, "obj_maj_intro_init" },
    { 0x8C66, "obj_maj_intro_start" },
    { 0x8C67, "obj_maj_investigatesignal_end" },
    { 0x8C68, "obj_maj_investigatesignal_init" },
    { 0x8C69, "obj_maj_investigatesignal_start" },
    { 0x8C6A, "obj_maj_leads_end" },
    { 0x8C6B, "obj_maj_leads_init" },
    { 0x8C6C, "obj_maj_leads_start" },
    { 0x8C6D, "obj_maj_open_train_end" },
    { 0x8C6E, "obj_maj_open_train_init" },
    { 0x8C6F, "obj_maj_open_train_start" },
    { 0x8C70, "obj_maj_rescue_end" },
    { 0x8C71, "obj_maj_rescue_init" },
    { 0x8C72, "obj_maj_rescue_start" },
    { 0x8C73, "obj_maj_secure_end" },
    { 0x8C74, "obj_maj_secure_init" },
    { 0x8C75, "obj_maj_secure_start" },
    { 0x8C76, "obj_maj_secure_tower_end" },
    { 0x8C77, "obj_maj_secure_tower_init" },
    { 0x8C78, "obj_maj_secure_tower_start" },
    { 0x8C79, "obj_maj_take_apache_end" },
    { 0x8C7A, "obj_maj_take_apache_init" },
    { 0x8C7B, "obj_maj_take_apache_start" },
    { 0x8C7C, "obj_maj_wait_train_end" },
    { 0x8C7D, "obj_maj_wait_train_init" },
    { 0x8C7E, "obj_maj_wait_train_start" },
    { 0x8C7F, "obj_max_barrels_scan" },
    { 0x8C80, "obj_overwatch_cars_remaining" },
    { 0x8C81, "obj_overwatch_coll_type" },
    { 0x8C82, "obj_players_fultoning" },
    { 0x8C83, "obj_pos" },
    { 0x8C84, "obj_reserved_juggs" },
    { 0x8C85, "obj_room_attack_cowbell" },
    { 0x8C86, "obj_room_catchup" },
    { 0x8C87, "obj_room_explosion" },
    { 0x8C88, "obj_room_fov_change" },
    { 0x8C89, "obj_room_main" },
    { 0x8C8A, "obj_room_scene" },
    { 0x8C8B, "obj_room_start" },
    { 0x8C8C, "obj_scr_anim" },
    { 0x8C8D, "obj_scr_animname" },
    { 0x8C8E, "obj_search_nag" },
    { 0x8C8F, "obj_secure_building_start1" },
    { 0x8C90, "obj_secure_building_start2" },
    { 0x8C91, "obj_secure_building_start3" },
    { 0x8C92, "obj_selected_id" },
    { 0x8C93, "obj_stop_searching_vo" },
    { 0x8C94, "obj_structs" },
    { 0x8C95, "obj_take_loot" },
    { 0x8C96, "obj_train_stopped" },
    { 0x8C97, "obj_tugofwar_civ_hvt" },
    { 0x8C98, "obj_used_extract_num" },
    { 0x8C99, "obj_used_stim" },
    { 0x8C9A, "obja" },
    { 0x8C9B, "objb" },
    { 0x8C9C, "objbreadcrumbs" },
    { 0x8C9D, "objc" },
    { 0x8C9E, "object" },
    { 0x8C9F, "objectgroupcost" },
    { 0x8CA0, "objective" },
    { 0x8CA1, "objective_add" },
    { 0x8CA2, "objective_add_location_entity" },
    { 0x8CA3, "objective_add_location_position" },
    { 0x8CA4, "objective_add_objective" },
    { 0x8CA5, "objective_add_structpos" },
    { 0x8CA6, "objective_array" },
    { 0x8CA7, "objective_clear_structpos" },
    { 0x8CA8, "objective_complete" },
    { 0x8CA9, "objective_control" },
    { 0x8CAA, "objective_convoy_init" },
    { 0x8CAB, "objective_convoy_start" },
    { 0x8CAC, "objective_enforcer_los" },
    { 0x8CAD, "objective_exists" },
    { 0x8CAE, "objective_heli_down_start" },
    { 0x8CAF, "objective_hide_player_progress" },
    { 0x8CB0, "objective_hide_team_progress" },
    { 0x8CB1, "objective_hospital_snakecam_wolf_marker_manager" },
    { 0x8CB2, "objective_icon_attach_to_center_vehicle" },
    { 0x8CB3, "objective_icon_override" },
    { 0x8CB4, "objective_icon_show" },
    { 0x8CB5, "objective_icon_show_health" },
    { 0x8CB6, "objective_icon_show_label" },
    { 0x8CB7, "objective_id" },
    { 0x8CB8, "objective_location_trigger" },
    { 0x8CB9, "objective_location_watcher" },
    { 0x8CBA, "objective_manageobjectivesintrovisibility" },
    { 0x8CBB, "objective_manager" },
    { 0x8CBC, "objective_manager_defend" },
    { 0x8CBD, "objective_mask_showtoenemyteam" },
    { 0x8CBE, "objective_mask_showtoplayerteam" },
    { 0x8CBF, "objective_nuke" },
    { 0x8CC0, "objective_oncontested" },
    { 0x8CC1, "objective_onpinnedstate" },
    { 0x8CC2, "objective_onuncontested" },
    { 0x8CC3, "objective_onunpinnedstate" },
    { 0x8CC4, "objective_onuse" },
    { 0x8CC5, "objective_onusebegin" },
    { 0x8CC6, "objective_onuseend" },
    { 0x8CC7, "objective_onuseupdate" },
    { 0x8CC8, "objective_pin_global" },
    { 0x8CC9, "objective_pin_player" },
    { 0x8CCA, "objective_pin_team" },
    { 0x8CCB, "objective_playermask_addshowplayer" },
    { 0x8CCC, "objective_playermask_hidefrom" },
    { 0x8CCD, "objective_playermask_hidefromall" },
    { 0x8CCE, "objective_playermask_showtoall" },
    { 0x8CCF, "objective_playermask_single" },
    { 0x8CD0, "objective_quick_add" },
    { 0x8CD1, "objective_radius" },
    { 0x8CD2, "objective_remove" },
    { 0x8CD3, "objective_remove_all_locations" },
    { 0x8CD4, "objective_remove_location" },
    { 0x8CD5, "objective_set_description" },
    { 0x8CD6, "objective_set_icon" },
    { 0x8CD7, "objective_set_label" },
    { 0x8CD8, "objective_set_on_entity" },
    { 0x8CD9, "objective_set_play_intro" },
    { 0x8CDA, "objective_set_play_outro" },
    { 0x8CDB, "objective_set_position" },
    { 0x8CDC, "objective_set_progress" },
    { 0x8CDD, "objective_set_progress_client" },
    { 0x8CDE, "objective_set_progress_team" },
    { 0x8CDF, "objective_set_pulsate" },
    { 0x8CE0, "objective_set_show_distance" },
    { 0x8CE1, "objective_set_show_progress" },
    { 0x8CE2, "objective_set_state" },
    { 0x8CE3, "objective_set_z_offset" },
    { 0x8CE4, "objective_show_player_progress" },
    { 0x8CE5, "objective_show_progress" },
    { 0x8CE6, "objective_show_team_progress" },
    { 0x8CE7, "objective_skip_check" },
    { 0x8CE8, "objective_teammask_addtomask" },
    { 0x8CE9, "objective_teammask_removefrommask" },
    { 0x8CEA, "objective_teammask_single" },
    { 0x8CEB, "objective_test" },
    { 0x8CEC, "objective_trigger_handler" },
    { 0x8CED, "objective_tutorial_hint_check" },
    { 0x8CEE, "objective_unpin_player" },
    { 0x8CEF, "objective_unpin_team" },
    { 0x8CF0, "objective_update" },
    { 0x8CF1, "objective_update_internal" },
    { 0x8CF2, "objective_wolf_los" },
    { 0x8CF3, "objectivebased" },
    { 0x8CF4, "objectivedebug" },
    { 0x8CF5, "objectivedestroyed" },
    { 0x8CF6, "objectiveent" },
    { 0x8CF7, "objectiveiconid" },
    { 0x8CF8, "objectiveidpool" },
    { 0x8CF9, "objectiveindex" },
    { 0x8CFA, "objectiveindexes" },
    { 0x8CFB, "objectivekey" },
    { 0x8CFC, "objectivename" },
    { 0x8CFD, "objectiveonvisuals" },
    { 0x8CFE, "objectiveonvisualsoffset3d" },
    { 0x8CFF, "objectiveregistration" },
    { 0x8D00, "objectives" },
    { 0x8D01, "objectives_init" },
    { 0x8D02, "objectives_table" },
    { 0x8D03, "objectivescaler" },
    { 0x8D04, "objectivescorecharge" },
    { 0x8D05, "objectiveselector" },
    { 0x8D06, "objectiveselectorsetup" },
    { 0x8D07, "objectivesetorder" },
    { 0x8D08, "objectivesettings" },
    { 0x8D09, "objectivesetup" },
    { 0x8D0A, "objectivesfunc" },
    { 0x8D0B, "objectivesmatrixtable" },
    { 0x8D0C, "objectivestabledata" },
    { 0x8D0D, "objectivestruct" },
    { 0x8D0E, "objectivesupdatedisplay" },
    { 0x8D0F, "objectivetypes" },
    { 0x8D10, "objectivewmdthink" },
    { 0x8D11, "objects" },
    { 0x8D12, "objects_picked" },
    { 0x8D13, "objent" },
    { 0x8D14, "objicon" },
    { 0x8D15, "objiconent" },
    { 0x8D16, "objiconid" },
    { 0x8D17, "objiconscolor" },
    { 0x8D18, "objid" },
    { 0x8D19, "objidfriendly" },
    { 0x8D1A, "objidnum" },
    { 0x8D1B, "objidnumenemy" },
    { 0x8D1C, "objidnumfriend" },
    { 0x8D1D, "objidpingenemy" },
    { 0x8D1E, "objidpingfriendly" },
    { 0x8D1F, "objindex" },
    { 0x8D20, "objkey" },
    { 0x8D21, "objmodifier" },
    { 0x8D22, "objname" },
    { 0x8D23, "objnum" },
    { 0x8D24, "objpingdelay" },
    { 0x8D25, "objplant" },
    { 0x8D26, "objplanta" },
    { 0x8D27, "objplantb" },
    { 0x8D28, "objplantc" },
    { 0x8D29, "objpoint_alpha_default" },
    { 0x8D2A, "objpointnames" },
    { 0x8D2B, "objpoints" },
    { 0x8D2C, "objpointscale" },
    { 0x8D2D, "objpointsize" },
    { 0x8D2E, "objstruct" },
    { 0x8D2F, "objvisall" },
    { 0x8D30, "objweapon" },
    { 0x8D31, "observe_contacts" },
    { 0x8D32, "obstacle_id" },
    { 0x8D33, "obstacle_in_way" },
    { 0x8D34, "occluder" },
    { 0x8D35, "occupancy" },
    { 0x8D36, "occupants" },
    { 0x8D37, "occupantsreserving" },
    { 0x8D38, "occupied" },
    { 0x8D39, "occupiedlanemasks" },
    { 0x8D3A, "occupies_colorcode" },
    { 0x8D3B, "odin" },
    { 0x8D3C, "odin_airdropusetime" },
    { 0x8D3D, "odin_assault_get_target" },
    { 0x8D3E, "odin_assault_perform_action" },
    { 0x8D3F, "odin_flash_radius" },
    { 0x8D40, "odin_juggernautusetime" },
    { 0x8D41, "odin_large_rod_radius" },
    { 0x8D42, "odin_largerodusetime" },
    { 0x8D43, "odin_last_predict_position_time" },
    { 0x8D44, "odin_marking_flash_radius_max" },
    { 0x8D45, "odin_marking_flash_radius_min" },
    { 0x8D46, "odin_markingusetime" },
    { 0x8D47, "odin_predicted_loc_for_player" },
    { 0x8D48, "odin_predicted_loc_time_for_player" },
    { 0x8D49, "odin_small_rod_radius" },
    { 0x8D4A, "odin_smallrodusetime" },
    { 0x8D4B, "odin_smokeusetime" },
    { 0x8D4C, "odin_support_get_target" },
    { 0x8D4D, "odin_support_perform_action" },
    { 0x8D4E, "odintype" },
    { 0x8D4F, "off_func" },
    { 0x8D50, "off_the_roof_nags" },
    { 0x8D51, "offhand_box_setup" },
    { 0x8D52, "offhand_box_think" },
    { 0x8D53, "offhand_boxes" },
    { 0x8D54, "offhand_count" },
    { 0x8D55, "offhand_explode_monitor" },
    { 0x8D56, "offhand_is_dangerous" },
    { 0x8D57, "offhand_swap_return_new_ammo_count" },
    { 0x8D58, "offhandfiremanager" },
    { 0x8D59, "offhandisprecached" },
    { 0x8D5A, "offhandprecache" },
    { 0x8D5B, "offhandprecachefuncs" },
    { 0x8D5C, "offhandproviderthread" },
    { 0x8D5D, "offhandremove" },
    { 0x8D5E, "offhands" },
    { 0x8D5F, "offhands_list" },
    { 0x8D60, "offhandshield" },
    { 0x8D61, "offhandswap" },
    { 0x8D62, "office_branch_allies" },
    { 0x8D63, "office_branch_player" },
    { 0x8D64, "office_exit_scene" },
    { 0x8D65, "office_props" },
    { 0x8D66, "office_side_vo_1" },
    { 0x8D67, "office_side_vo_2" },
    { 0x8D68, "office_side_vo_3" },
    { 0x8D69, "office_walla_1" },
    { 0x8D6A, "office_walla_2" },
    { 0x8D6B, "officercount" },
    { 0x8D6C, "officers" },
    { 0x8D6D, "officerwaiter" },
    { 0x8D6E, "offices" },
    { 0x8D6F, "offices_avoid_civs" },
    { 0x8D70, "offices_catchup" },
    { 0x8D71, "offices_chaos_civs" },
    { 0x8D72, "offices_civ_count" },
    { 0x8D73, "offices_dialog" },
    { 0x8D74, "offices_door" },
    { 0x8D75, "offices_door_dialog" },
    { 0x8D76, "offices_fail_check" },
    { 0x8D77, "offices_fake_door_prompt" },
    { 0x8D78, "offices_goal_dialog" },
    { 0x8D79, "offices_idle_only_civ" },
    { 0x8D7A, "offices_individual_prop" },
    { 0x8D7B, "offices_keyguy" },
    { 0x8D7C, "offices_main" },
    { 0x8D7D, "offices_manager" },
    { 0x8D7E, "offices_movement_farah" },
    { 0x8D7F, "offices_movement_rebel_1" },
    { 0x8D80, "offices_movement_rebel_2" },
    { 0x8D81, "offices_postload" },
    { 0x8D82, "offices_preload" },
    { 0x8D83, "offices_props" },
    { 0x8D84, "offices_screens" },
    { 0x8D85, "offices_scriptables" },
    { 0x8D86, "offices_setup_door" },
    { 0x8D87, "offices_stairwell_door" },
    { 0x8D88, "offices_stairwell_door_vo" },
    { 0x8D89, "offices_start" },
    { 0x8D8A, "offloaded" },
    { 0x8D8B, "offset" },
    { 0x8D8C, "offset_ang" },
    { 0x8D8D, "offset_fix" },
    { 0x8D8E, "offset_tag" },
    { 0x8D8F, "offset3d" },
    { 0x8D90, "offsets" },
    { 0x8D91, "offsettime" },
    { 0x8D92, "offsettoorigin" },
    { 0x8D93, "og" },
    { 0x8D94, "og_advancetoenemysettings" },
    { 0x8D95, "og_anglelerprate" },
    { 0x8D96, "og_angles" },
    { 0x8D97, "og_attackeraccuracy" },
    { 0x8D98, "og_baseaccuracy" },
    { 0x8D99, "og_callsign" },
    { 0x8D9A, "og_color_fixednode" },
    { 0x8D9B, "og_deathanim" },
    { 0x8D9C, "og_dontdropweapon" },
    { 0x8D9D, "og_downaimlimit" },
    { 0x8D9E, "og_goalheight" },
    { 0x8D9F, "og_goalradius" },
    { 0x8DA0, "og_hatmodel" },
    { 0x8DA1, "og_headmodel" },
    { 0x8DA2, "og_health" },
    { 0x8DA3, "og_health_regen_delay" },
    { 0x8DA4, "og_health_regen_rate" },
    { 0x8DA5, "og_health_value" },
    { 0x8DA6, "og_intensity" },
    { 0x8DA7, "og_ks_spot" },
    { 0x8DA8, "og_leftaimlimit" },
    { 0x8DA9, "og_maxhealth" },
    { 0x8DAA, "og_maxsightdistsqr" },
    { 0x8DAB, "og_maxsightdistsqrd" },
    { 0x8DAC, "og_maxvis" },
    { 0x8DAD, "og_model" },
    { 0x8DAE, "og_name" },
    { 0x8DAF, "og_origin" },
    { 0x8DB0, "og_pitchmax" },
    { 0x8DB1, "og_pitchmin" },
    { 0x8DB2, "og_position" },
    { 0x8DB3, "og_radius" },
    { 0x8DB4, "og_rightaimlimit" },
    { 0x8DB5, "og_rot" },
    { 0x8DB6, "og_rotation" },
    { 0x8DB7, "og_scale" },
    { 0x8DB8, "og_script_accuracy" },
    { 0x8DB9, "og_script_animname" },
    { 0x8DBA, "og_script_attackeraccuracy" },
    { 0x8DBB, "og_script_bcdialog" },
    { 0x8DBC, "og_script_bulletshield" },
    { 0x8DBD, "og_script_danger_react" },
    { 0x8DBE, "og_script_deathflag" },
    { 0x8DBF, "og_script_deathtime" },
    { 0x8DC0, "og_script_demeanor" },
    { 0x8DC1, "og_script_diequietly" },
    { 0x8DC2, "og_script_dontshootwhilemoving" },
    { 0x8DC3, "og_script_faceenemydist" },
    { 0x8DC4, "og_script_favoriteenemy" },
    { 0x8DC5, "og_script_fightdist" },
    { 0x8DC6, "og_script_fixednode" },
    { 0x8DC7, "og_script_forcecolor" },
    { 0x8DC8, "og_script_function" },
    { 0x8DC9, "og_script_goalvolume" },
    { 0x8DCA, "og_script_ignore_suppression" },
    { 0x8DCB, "og_script_ignoreall" },
    { 0x8DCC, "og_script_ignoreme" },
    { 0x8DCD, "og_script_laser" },
    { 0x8DCE, "og_script_longdeath" },
    { 0x8DCF, "og_script_maxdist" },
    { 0x8DD0, "og_script_no_reorient" },
    { 0x8DD1, "og_script_no_seeker" },
    { 0x8DD2, "og_script_nobloodpool" },
    { 0x8DD3, "og_script_nodrop" },
    { 0x8DD4, "og_script_noragdoll" },
    { 0x8DD5, "og_script_nosurprise" },
    { 0x8DD6, "og_script_offhands" },
    { 0x8DD7, "og_script_pacifist" },
    { 0x8DD8, "og_script_sightrange" },
    { 0x8DD9, "og_script_startinghealth" },
    { 0x8DDA, "og_script_startrunning" },
    { 0x8DDB, "og_script_stealthgroup" },
    { 0x8DDC, "og_script_threatbiasgroup" },
    { 0x8DDD, "og_sidearm" },
    { 0x8DDE, "og_spawner_angles" },
    { 0x8DDF, "og_spawner_origin" },
    { 0x8DE0, "og_stance" },
    { 0x8DE1, "og_stealth_funcs" },
    { 0x8DE2, "og_target" },
    { 0x8DE3, "og_turnrate" },
    { 0x8DE4, "og_upaimlimit" },
    { 0x8DE5, "og_weapon" },
    { 0x8DE6, "og_yawmax" },
    { 0x8DE7, "og_yawmin" },
    { 0x8DE8, "og_zplanes" },
    { 0x8DE9, "ogorigin" },
    { 0x8DEA, "ogplayerweapon" },
    { 0x8DEB, "ogstance" },
    { 0x8DEC, "ogsunintensity" },
    { 0x8DED, "ogval" },
    { 0x8DEE, "ohpallowuseonplayerdeath" },
    { 0x8DEF, "ohpcleanupnotificationondeath" },
    { 0x8DF0, "ohpequipmentfillednotification" },
    { 0x8DF1, "ohpequipmentrefills" },
    { 0x8DF2, "oil_barrel" },
    { 0x8DF3, "oil_barrel_death" },
    { 0x8DF4, "oil_barrel_init" },
    { 0x8DF5, "oil_fire_fumes" },
    { 0x8DF6, "oil_fire_watch_for_player_grenades" },
    { 0x8DF7, "oil_fires" },
    { 0x8DF8, "oil_fires_init" },
    { 0x8DF9, "oil_get_barrels" },
    { 0x8DFA, "oil_gulgs" },
    { 0x8DFB, "oil_pusher_drop_pistol" },
    { 0x8DFC, "oil_pusher_wakeup_on_prox" },
    { 0x8DFD, "oil_pusher_wakeup_think" },
    { 0x8DFE, "oil_pusher1_anim" },
    { 0x8DFF, "oil_pusher1_post_anim_behavior" },
    { 0x8E00, "oil_pusher2_anim" },
    { 0x8E01, "oil_pusher2_escape" },
    { 0x8E02, "oil_pusher2_martyr" },
    { 0x8E03, "oil_pusher2_post_anim_behavior" },
    { 0x8E04, "oilbarrelshoulddie" },
    { 0x8E05, "oilfire_break_navmesh" },
    { 0x8E06, "oilfire_cleanup_corpses" },
    { 0x8E07, "oilfire_collapse" },
    { 0x8E08, "oilfire_death_hint" },
    { 0x8E09, "oilfire_enabled" },
    { 0x8E0A, "oilfire_initial_ignition" },
    { 0x8E0B, "oilfire_kill_player_if_stuck_in_geo_swap" },
    { 0x8E0C, "oilfire_monitor_ai_burn" },
    { 0x8E0D, "oilfire_monitor_burnables" },
    { 0x8E0E, "oilfire_remove_lanterns" },
    { 0x8E0F, "oilfire_run" },
    { 0x8E10, "oilfire_setup" },
    { 0x8E11, "oilfire_setup_individual" },
    { 0x8E12, "oilfire_think" },
    { 0x8E13, "oilfire_watch_for_molotov" },
    { 0x8E14, "oilfires" },
    { 0x8E15, "oilimpactlife" },
    { 0x8E16, "old_armor_scalar" },
    { 0x8E17, "old_attackeraccuracy" },
    { 0x8E18, "old_buildweapon" },
    { 0x8E19, "old_buildweaponmap" },
    { 0x8E1A, "old_color" },
    { 0x8E1B, "old_demeanoroverride" },
    { 0x8E1C, "old_disablearrivals" },
    { 0x8E1D, "old_doavoidanceblocking" },
    { 0x8E1E, "old_forcecolor" },
    { 0x8E1F, "old_loadout_updateclasscustom" },
    { 0x8E20, "old_mpbuildweaponmap" },
    { 0x8E21, "old_pathrandompercent" },
    { 0x8E22, "old_rebels" },
    { 0x8E23, "old_recoil_scale" },
    { 0x8E24, "old_revive_time_scalar" },
    { 0x8E25, "old_root" },
    { 0x8E26, "old_script_delay" },
    { 0x8E27, "old_script_delay_max" },
    { 0x8E28, "old_script_delay_min" },
    { 0x8E29, "old_speed" },
    { 0x8E2A, "old_threat_bias_group" },
    { 0x8E2B, "old_view_kick" },
    { 0x8E2C, "old_visionset" },
    { 0x8E2D, "old_walkdist" },
    { 0x8E2E, "old_walkdistfacingmotion" },
    { 0x8E2F, "old_weapon" },
    { 0x8E30, "oldconvergencetime" },
    { 0x8E31, "oldfightdist" },
    { 0x8E32, "oldgoalradius" },
    { 0x8E33, "oldgrenadeammo" },
    { 0x8E34, "oldgrenadeweapon" },
    { 0x8E35, "oldgrenawareness" },
    { 0x8E36, "oldhead" },
    { 0x8E37, "oldhealthregen" },
    { 0x8E38, "oldmaxdist" },
    { 0x8E39, "oldmaxsight" },
    { 0x8E3A, "oldmaxsightdistsqrd" },
    { 0x8E3B, "oldpathenemyfightdist" },
    { 0x8E3C, "oldpathenemylookahead" },
    { 0x8E3D, "oldperks" },
    { 0x8E3E, "oldposition" },
    { 0x8E3F, "oldprimarygun" },
    { 0x8E40, "oldradius" },
    { 0x8E41, "oldtouchlist" },
    { 0x8E42, "omausebar" },
    { 0x8E43, "omnvar" },
    { 0x8E44, "omnvarnames" },
    { 0x8E45, "on" },
    { 0x8E46, "on_agent_generic_damaged" },
    { 0x8E47, "on_agent_player_damaged" },
    { 0x8E48, "on_agent_player_killed" },
    { 0x8E49, "on_bot_killed" },
    { 0x8E4A, "on_cooldown" },
    { 0x8E4B, "on_func" },
    { 0x8E4C, "on_humanoid_agent_killed_common" },
    { 0x8E4D, "on_last_pathing_array" },
    { 0x8E4E, "on_off_time" },
    { 0x8E4F, "on_path_from" },
    { 0x8E50, "on_path_grid" },
    { 0x8E51, "on_player_connect" },
    { 0x8E52, "on_player_disconnect" },
    { 0x8E53, "on_see_3f_struct" },
    { 0x8E54, "on_spawn_terrorist_player" },
    { 0x8E55, "on_terry_death" },
    { 0x8E56, "on_the_same_team" },
    { 0x8E57, "on_trigger_actions" },
    { 0x8E58, "on_zombie_agent_killed_common" },
    { 0x8E59, "onactivateobjective" },
    { 0x8E5A, "onarmorykioskpurchase" },
    { 0x8E5B, "onassist" },
    { 0x8E5C, "onattackdelegate" },
    { 0x8E5D, "onatv" },
    { 0x8E5E, "onback" },
    { 0x8E5F, "onbegincarrying" },
    { 0x8E60, "onbeginnewmode" },
    { 0x8E61, "onbeginuse" },
    { 0x8E62, "onbleedout" },
    { 0x8E63, "onbombexploded" },
    { 0x8E64, "onbombzoneobjectivecomplete" },
    { 0x8E65, "oncancel" },
    { 0x8E66, "oncanceldelegate" },
    { 0x8E67, "oncantuse" },
    { 0x8E68, "oncarried" },
    { 0x8E69, "oncarrieddelegate" },
    { 0x8E6A, "oncarrierdeath" },
    { 0x8E6B, "onchopper" },
    { 0x8E6C, "onclasschoicecallback" },
    { 0x8E6D, "onclasseditcallback" },
    { 0x8E6E, "oncommonnormaldeath" },
    { 0x8E6F, "oncommonsuicidedeath" },
    { 0x8E70, "oncommonteamchangedeath" },
    { 0x8E71, "oncompletedfunc" },
    { 0x8E72, "oncontested" },
    { 0x8E73, "oncranked" },
    { 0x8E74, "oncrankedassist" },
    { 0x8E75, "oncrankedkill" },
    { 0x8E76, "oncrateactivated" },
    { 0x8E77, "oncratecaptured" },
    { 0x8E78, "oncratedestroyed" },
    { 0x8E79, "oncratedrop" },
    { 0x8E7A, "oncreatedelegate" },
    { 0x8E7B, "ondamagecallbacks" },
    { 0x8E7C, "ondamagecallbackthread" },
    { 0x8E7D, "ondamagerelics" },
    { 0x8E7E, "ondamageweaponpassives" },
    { 0x8E7F, "ondeactivedelegate" },
    { 0x8E80, "ondeadevent" },
    { 0x8E81, "ondeath" },
    { 0x8E82, "ondeath_clearscriptedanim" },
    { 0x8E83, "ondeathdelegate" },
    { 0x8E84, "ondeathfinalhit" },
    { 0x8E85, "ondeathordisconnect" },
    { 0x8E86, "ondeathrespawn" },
    { 0x8E87, "ondebugbeatfunc" },
    { 0x8E88, "ondebugstartfunc" },
    { 0x8E89, "ondelivercallback" },
    { 0x8E8A, "ondelivered" },
    { 0x8E8B, "ondeploycallback" },
    { 0x8E8C, "ondeployfinished" },
    { 0x8E8D, "ondeploystart" },
    { 0x8E8E, "ondestroyedbytrophy" },
    { 0x8E8F, "ondestroyeddelegate" },
    { 0x8E90, "ondetonateexplosive" },
    { 0x8E91, "ondisableobjective" },
    { 0x8E92, "ondisconnect" },
    { 0x8E93, "ondisconnecteventcallbacks" },
    { 0x8E94, "ondompointobjectivecomplete" },
    { 0x8E95, "ondrop" },
    { 0x8E96, "ondropfn" },
    { 0x8E97, "one_bomb_is_defused" },
    { 0x8E98, "one_time_use" },
    { 0x8E99, "onearg" },
    { 0x8E9A, "onecaptureperplayer" },
    { 0x8E9B, "onekillwin" },
    { 0x8E9C, "onemanarmyweaponchangetracker" },
    { 0x8E9D, "onenableobjective" },
    { 0x8E9E, "onenduse" },
    { 0x8E9F, "onenemy" },
    { 0x8EA0, "onenter" },
    { 0x8EA1, "onenteranimstate" },
    { 0x8EA2, "onenterdeathsdoor" },
    { 0x8EA3, "onenteroob" },
    { 0x8EA4, "onenteroobsuppressiontrigger" },
    { 0x8EA5, "onenteroobtrigger" },
    { 0x8EA6, "oneoverfactor" },
    { 0x8EA7, "onequipmentfired" },
    { 0x8EA8, "onequipmentplanted" },
    { 0x8EA9, "onequipmenttaken" },
    { 0x8EAA, "oneshotcallbacks" },
    { 0x8EAB, "oneshotfxthread" },
    { 0x8EAC, "oneusespawns" },
    { 0x8EAD, "onexfilfinish" },
    { 0x8EAE, "onexfilfinishedcallback" },
    { 0x8EAF, "onexfilkilled" },
    { 0x8EB0, "onexfilkilledcallback" },
    { 0x8EB1, "onexfilstart" },
    { 0x8EB2, "onexfilstarted" },
    { 0x8EB3, "onexfilsuccess" },
    { 0x8EB4, "onexfiltimelimit" },
    { 0x8EB5, "onexit" },
    { 0x8EB6, "onexitcommon" },
    { 0x8EB7, "onexitdeathsdoor" },
    { 0x8EB8, "onexitoob" },
    { 0x8EB9, "onexitoobsupressiontrigger" },
    { 0x8EBA, "onexitoobtrigger" },
    { 0x8EBB, "onexplodefunc" },
    { 0x8EBC, "onexplodesfx" },
    { 0x8EBD, "onexplodevfx" },
    { 0x8EBE, "onfinaldeathcallback" },
    { 0x8EBF, "onfinaldeathdropgrenade" },
    { 0x8EC0, "onfinalsurvivor" },
    { 0x8EC1, "onfire" },
    { 0x8EC2, "onfire_fx" },
    { 0x8EC3, "onflag_restore_intensity" },
    { 0x8EC4, "onflagcapture" },
    { 0x8EC5, "onflybycompletedelegate" },
    { 0x8EC6, "onforfeit" },
    { 0x8EC7, "onfreeplayerconnect" },
    { 0x8EC8, "onfullhealth" },
    { 0x8EC9, "ongameended" },
    { 0x8ECA, "ongasgrenadeimpact" },
    { 0x8ECB, "ongrenadeuse" },
    { 0x8ECC, "onhalftime" },
    { 0x8ECD, "onhelikilled" },
    { 0x8ECE, "onhelisniper" },
    { 0x8ECF, "onhighlight" },
    { 0x8ED0, "onhostmigration" },
    { 0x8ED1, "onjoinedspectators" },
    { 0x8ED2, "onjoinedteam" },
    { 0x8ED3, "onjoinsquadcallbacks" },
    { 0x8ED4, "onjointeamblinkinglight" },
    { 0x8ED5, "onjointeamcallbacks" },
    { 0x8ED6, "onjuggernaut" },
    { 0x8ED7, "onjuggernautend" },
    { 0x8ED8, "onjuggproximityscore" },
    { 0x8ED9, "onkill" },
    { 0x8EDA, "onkilled" },
    { 0x8EDB, "onkillrelics" },
    { 0x8EDC, "onkillstreakbeginuse" },
    { 0x8EDD, "onkillstreakdamaged" },
    { 0x8EDE, "onkillstreakdeploy" },
    { 0x8EDF, "onkillstreakdisowned" },
    { 0x8EE0, "onkillstreakfinishuse" },
    { 0x8EE1, "onkillstreakkilled" },
    { 0x8EE2, "onkillstreaksplashshown" },
    { 0x8EE3, "onkillstreaktriggered" },
    { 0x8EE4, "onkillweaponpassives" },
    { 0x8EE5, "onlastalive" },
    { 0x8EE6, "onlaunchsfx" },
    { 0x8EE7, "onleavegamecallback" },
    { 0x8EE8, "onlethalequipmentplanted" },
    { 0x8EE9, "onlevelload" },
    { 0x8EEA, "onlinegame" },
    { 0x8EEB, "onlinestatsenabled" },
    { 0x8EEC, "onlooker" },
    { 0x8EED, "onlooker_vo" },
    { 0x8EEE, "onlooker_vo_thread" },
    { 0x8EEF, "onluieventcallbacks" },
    { 0x8EF0, "only_allowable_tactical_goals" },
    { 0x8EF1, "only_local" },
    { 0x8EF2, "only_one_player" },
    { 0x8EF3, "only_use_weapon" },
    { 0x8EF4, "onlydroneused" },
    { 0x8EF5, "onlyfirendlyfire" },
    { 0x8EF6, "onlyhelmetpopondeath" },
    { 0x8EF7, "onlylocal" },
    { 0x8EF8, "onlyroundoverride" },
    { 0x8EF9, "onmatchstart" },
    { 0x8EFA, "onmovingplatformcollision" },
    { 0x8EFB, "onmovingplatformdeath" },
    { 0x8EFC, "onmunitionboxused" },
    { 0x8EFD, "onnormaldeath" },
    { 0x8EFE, "onobjectdelivered" },
    { 0x8EFF, "onobjectdrop" },
    { 0x8F00, "onobjectivecomplete" },
    { 0x8F01, "onobjectpickup" },
    { 0x8F02, "onobjectreset" },
    { 0x8F03, "onobstruction" },
    { 0x8F04, "onoffmodelswap" },
    { 0x8F05, "ononeleftevent" },
    { 0x8F06, "onooboutoftime" },
    { 0x8F07, "onownerdisconnect" },
    { 0x8F08, "onpatrol" },
    { 0x8F09, "onpatrolpath" },
    { 0x8F0A, "onphaseend" },
    { 0x8F0B, "onpickup" },
    { 0x8F0C, "onpickupfailed" },
    { 0x8F0D, "onpickupfailfn" },
    { 0x8F0E, "onpickupfn" },
    { 0x8F0F, "onpinnedstate" },
    { 0x8F10, "onplaced" },
    { 0x8F11, "onplaceddelegate" },
    { 0x8F12, "onplayerchangeteams" },
    { 0x8F13, "onplayerconnect" },
    { 0x8F14, "onplayerconnect_cphudmessage" },
    { 0x8F15, "onplayerconnectaudioinit" },
    { 0x8F16, "onplayerconnectcommon" },
    { 0x8F17, "onplayerconnected" },
    { 0x8F18, "onplayerconnecting" },
    { 0x8F19, "onplayerconnectrunonce" },
    { 0x8F1A, "onplayerdamaged" },
    { 0x8F1B, "onplayerdisconnect" },
    { 0x8F1C, "onplayerdisconnectcommon" },
    { 0x8F1D, "onplayerdisconnectinfil" },
    { 0x8F1E, "onplayeremped" },
    { 0x8F1F, "onplayerjoinedspectators" },
    { 0x8F20, "onplayerjoinedteam" },
    { 0x8F21, "onplayerjoinsquad" },
    { 0x8F22, "onplayerjointeam" },
    { 0x8F23, "onplayerjointeamcommon" },
    { 0x8F24, "onplayerkillassist" },
    { 0x8F25, "onplayerkilled" },
    { 0x8F26, "onplayerkilledcommon" },
    { 0x8F27, "onplayerprojectiledamage_thread" },
    { 0x8F28, "onplayerscore" },
    { 0x8F29, "onplayerspawn" },
    { 0x8F2A, "onplayerspawncallbacks" },
    { 0x8F2B, "onplayerspawned" },
    { 0x8F2C, "onplayerspawneddevguisetup" },
    { 0x8F2D, "onplayerspawnedinfil" },
    { 0x8F2E, "onplayerspawnedweaponpassives" },
    { 0x8F2F, "onplayerteamrevive" },
    { 0x8F30, "onpotgrecordingstopped" },
    { 0x8F31, "onprecachegametype" },
    { 0x8F32, "onprematchdone" },
    { 0x8F33, "onprematchstarted" },
    { 0x8F34, "onradiocapture" },
    { 0x8F35, "onradiodestroy" },
    { 0x8F36, "onrecordingstarted" },
    { 0x8F37, "onrecordingstopped" },
    { 0x8F38, "onreset" },
    { 0x8F39, "onresetend" },
    { 0x8F3A, "onresetfn" },
    { 0x8F3B, "onresetstart" },
    { 0x8F3C, "onrespawndelay" },
    { 0x8F3D, "onrevive" },
    { 0x8F3E, "onrevivepickupevent" },
    { 0x8F3F, "onrotatingvehicleturret" },
    { 0x8F40, "onroundend" },
    { 0x8F41, "onroundended" },
    { 0x8F42, "onroundswitch" },
    { 0x8F43, "onscorelimit" },
    { 0x8F44, "onselect" },
    { 0x8F45, "onsixfriendlytracking" },
    { 0x8F46, "onslide" },
    { 0x8F47, "onsniperabouttofire" },
    { 0x8F48, "onsniperfired" },
    { 0x8F49, "onsnowmobile" },
    { 0x8F4A, "onspawn" },
    { 0x8F4B, "onspawnfinished" },
    { 0x8F4C, "onspawnfunc" },
    { 0x8F4D, "onspawnloot" },
    { 0x8F4E, "onspawnplayer" },
    { 0x8F4F, "onspawnplayercommon" },
    { 0x8F50, "onspawnspectator" },
    { 0x8F51, "onspecialistkillstreakavailable" },
    { 0x8F52, "onspectatingclient" },
    { 0x8F53, "onspectatingmlgcamera" },
    { 0x8F54, "onsquadeliminated" },
    { 0x8F55, "onstartgametype" },
    { 0x8F56, "onsuccessfulhit" },
    { 0x8F57, "onsuccessfulstreakactivation" },
    { 0x8F58, "onsuicidedeath" },
    { 0x8F59, "onsurvivorseliminated" },
    { 0x8F5A, "ontacticalequipmentplanted" },
    { 0x8F5B, "ontagpickupevent" },
    { 0x8F5C, "onteamchangecallback" },
    { 0x8F5D, "onteamchangedeath" },
    { 0x8F5E, "onteamscore" },
    { 0x8F5F, "onteamselection" },
    { 0x8F60, "ontimelimit" },
    { 0x8F61, "ontimelimitdeadevent" },
    { 0x8F62, "ontimelimitgraceperiod" },
    { 0x8F63, "ontimelimitot" },
    { 0x8F64, "ontriggeredfunc" },
    { 0x8F65, "ontriggeredsfx" },
    { 0x8F66, "onuncontested" },
    { 0x8F67, "onunoccupied" },
    { 0x8F68, "onunpinnedstate" },
    { 0x8F69, "onupdate" },
    { 0x8F6A, "onuse" },
    { 0x8F6B, "onuseanimplaying" },
    { 0x8F6C, "onusecallback" },
    { 0x8F6D, "onusecallbacks" },
    { 0x8F6E, "onusecompleted" },
    { 0x8F6F, "onusedeployable" },
    { 0x8F70, "onuseplantobject" },
    { 0x8F71, "onusesfx" },
    { 0x8F72, "onuseupdate" },
    { 0x8F73, "onuseweaponpassives" },
    { 0x8F74, "onvehicleemped" },
    { 0x8F75, "onversusdone" },
    { 0x8F76, "onweapondamage" },
    { 0x8F77, "onweaponfired" },
    { 0x8F78, "onxpevent" },
    { 0x8F79, "oob" },
    { 0x8F7A, "oob_enabled" },
    { 0x8F7B, "oobdata" },
    { 0x8F7C, "oobendtime" },
    { 0x8F7D, "oobimmunity" },
    { 0x8F7E, "oobref" },
    { 0x8F7F, "oobsupressiontriggers" },
    { 0x8F80, "oobtimeleft" },
    { 0x8F81, "oobtriggers" },
    { 0x8F82, "oobtriggertype" },
    { 0x8F83, "open" },
    { 0x8F84, "open_1f_hallway_door" },
    { 0x8F85, "open_1f_runner_door" },
    { 0x8F86, "open_2f_data_door" },
    { 0x8F87, "open_and_write_to_paths_map" },
    { 0x8F88, "open_ang" },
    { 0x8F89, "open_angles" },
    { 0x8F8A, "open_big_doors" },
    { 0x8F8B, "open_blockade_gates" },
    { 0x8F8C, "open_bomb_case" },
    { 0x8F8D, "open_bomb_case_common" },
    { 0x8F8E, "open_bus_doors" },
    { 0x8F8F, "open_case_marker" },
    { 0x8F90, "open_case_marker_as_use_entity" },
    { 0x8F91, "open_case_marker_ent" },
    { 0x8F92, "open_complete" },
    { 0x8F93, "open_completely" },
    { 0x8F94, "open_door" },
    { 0x8F95, "open_door_catchup" },
    { 0x8F96, "open_door_main" },
    { 0x8F97, "open_door_start" },
    { 0x8F98, "open_elevator_doors" },
    { 0x8F99, "open_elevator_doors_roof" },
    { 0x8F9A, "open_facility_exit" },
    { 0x8F9B, "open_goalradius_on_player_sight" },
    { 0x8F9C, "open_inner_doors" },
    { 0x8F9D, "open_interrupt" },
    { 0x8F9E, "open_left" },
    { 0x8F9F, "open_lines" },
    { 0x8FA0, "open_loadout_menu" },
    { 0x8FA1, "open_main_door" },
    { 0x8FA2, "open_outer_doors" },
    { 0x8FA3, "open_plane_doors" },
    { 0x8FA4, "open_plane_doors_anim" },
    { 0x8FA5, "open_pos" },
    { 0x8FA6, "open_roof_doors" },
    { 0x8FA7, "open_safehouse_door" },
    { 0x8FA8, "open_scriptable_door_monitor" },
    { 0x8FA9, "open_scripted_door" },
    { 0x8FAA, "open_side_gate" },
    { 0x8FAB, "open_stairwell_doors" },
    { 0x8FAC, "open_struct" },
    { 0x8FAD, "open_struct_logic" },
    { 0x8FAE, "open_time" },
    { 0x8FAF, "open_up_fov" },
    { 0x8FB0, "open_upper_cell_door" },
    { 0x8FB1, "open_vault_door" },
    { 0x8FB2, "open_vault_gate" },
    { 0x8FB3, "open_vent_cover" },
    { 0x8FB4, "openccw" },
    { 0x8FB5, "opendoor_notehandler" },
    { 0x8FB6, "opendooratreasonabletime" },
    { 0x8FB7, "opendooratreasonabletime_waitforabort" },
    { 0x8FB8, "opened" },
    { 0x8FB9, "opener" },
    { 0x8FBA, "openers" },
    { 0x8FBB, "opening_actors_to_idle" },
    { 0x8FBC, "openinteract" },
    { 0x8FBD, "openmonitor" },
    { 0x8FBE, "operate_garage" },
    { 0x8FBF, "operationscompleted" },
    { 0x8FC0, "operationsmaxed" },
    { 0x8FC1, "operator" },
    { 0x8FC2, "operatorcustomization" },
    { 0x8FC3, "operatordialogonplayer" },
    { 0x8FC4, "operatorref" },
    { 0x8FC5, "operatorskinindex" },
    { 0x8FC6, "opposite_struct" },
    { 0x8FC7, "opticattachmentbasenames" },
    { 0x8FC8, "optimizationdvars" },
    { 0x8FC9, "optional_prop" },
    { 0x8FCA, "optional_scripted_struct" },
    { 0x8FCB, "optional_stealth_handler" },
    { 0x8FCC, "optional_struct" },
    { 0x8FCD, "optionalfootprinteffectfunction" },
    { 0x8FCE, "optionalfootprinteffects" },
    { 0x8FCF, "optionalnumber" },
    { 0x8FD0, "optionalstepeffectfunction" },
    { 0x8FD1, "optionalstepeffects" },
    { 0x8FD2, "optionalstepeffectsmallfunction" },
    { 0x8FD3, "optionalstepeffectssmall" },
    { 0x8FD4, "options" },
    { 0x8FD5, "optionsvalue" },
    { 0x8FD6, "opweaponsarray" },
    { 0x8FD7, "orbitcam" },
    { 0x8FD8, "orcapoints" },
    { 0x8FD9, "orderaction" },
    { 0x8FDA, "orderdisplace" },
    { 0x8FDB, "ordermove" },
    { 0x8FDC, "orderto" },
    { 0x8FDD, "org" },
    { 0x8FDE, "org2" },
    { 0x8FDF, "orghealth" },
    { 0x8FE0, "orgorg" },
    { 0x8FE1, "orient_model" },
    { 0x8FE2, "orientation" },
    { 0x8FE3, "orientblocksbasedonsequence" },
    { 0x8FE4, "orientdefaulttofrontline" },
    { 0x8FE5, "orientdefaulttomapcenterusingmapcorners" },
    { 0x8FE6, "orientedboxpoints" },
    { 0x8FE7, "orientmeleevictim" },
    { 0x8FE8, "orienttoplayeryrot" },
    { 0x8FE9, "orig_alpha" },
    { 0x8FEA, "orig_health" },
    { 0x8FEB, "orig_max_participation" },
    { 0x8FEC, "orig_player_participation" },
    { 0x8FED, "origin_counter" },
    { 0x8FEE, "origin_ent" },
    { 0x8FEF, "origin_intensity" },
    { 0x8FF0, "origin_is_valid_for_vanguard" },
    { 0x8FF1, "origin_last" },
    { 0x8FF2, "origin_max_dirs" },
    { 0x8FF3, "origin_prev" },
    { 0x8FF4, "origin_velocity" },
    { 0x8FF5, "origin_velocity_time" },
    { 0x8FF6, "origin2" },
    { 0x8FF7, "original_angles" },
    { 0x8FF8, "original_attacker" },
    { 0x8FF9, "original_baseaccuracy" },
    { 0x8FFA, "original_body_model" },
    { 0x8FFB, "original_data" },
    { 0x8FFC, "original_intensity" },
    { 0x8FFD, "original_origin" },
    { 0x8FFE, "originalangles" },
    { 0x8FFF, "originalintensity" },
    { 0x9000, "originalmodel" },
    { 0x9001, "originalorigin" },
    { 0x9002, "originalowner" },
    { 0x9003, "originalpos" },
    { 0x9004, "originheightoffset" },
    { 0x9005, "originlink" },
    { 0x9006, "origins" },
    { 0x9007, "origviewmodel" },
    { 0x9008, "osa_distance" },
    { 0x9009, "osa_percentile" },
    { 0x900A, "other_blocker_vehicles_exist" },
    { 0x900B, "other_bodyguard_vehicles_exist" },
    { 0x900C, "othercaptureobject" },
    { 0x900D, "otherdoor" },
    { 0x900E, "otherteam" },
    { 0x900F, "otherusehintstring" },
    { 0x9010, "otherusetime" },
    { 0x9011, "otspawned" },
    { 0x9012, "ottimecontested" },
    { 0x9013, "out_of_order" },
    { 0x9014, "outboundflightanim" },
    { 0x9015, "outboundsfx" },
    { 0x9016, "outcome" },
    { 0x9017, "outcomenotify" },
    { 0x9018, "outdoor_only_maxs" },
    { 0x9019, "outdoor_only_mins" },
    { 0x901A, "outdoor_think" },
    { 0x901B, "outdoor_time" },
    { 0x901C, "outeranimnode" },
    { 0x901D, "outercrates" },
    { 0x901E, "outframes" },
    { 0x901F, "outline" },
    { 0x9020, "outline_array_insert" },
    { 0x9021, "outline_crate_in_hud" },
    { 0x9022, "outline_enemeies" },
    { 0x9023, "outline_enemy_ai_for_overwatch" },
    { 0x9024, "outline_fade_alpha_for_index" },
    { 0x9025, "outline_fade_alpha_for_index_internal" },
    { 0x9026, "outline_init" },
    { 0x9027, "outline_monitor_think" },
    { 0x9028, "outline_ping" },
    { 0x9029, "outline_weapon_watch_list" },
    { 0x902A, "outlineaddplayertoexistingallandteamoutlines" },
    { 0x902B, "outlineaddplayertoexistingsquadoutlines" },
    { 0x902C, "outlineaddplayertoexistingteamoutlines" },
    { 0x902D, "outlineaddtogloballist" },
    { 0x902E, "outlinecalloutsource" },
    { 0x902F, "outlinecatchplayerdisconnect" },
    { 0x9030, "outlined" },
    { 0x9031, "outlinedenemies" },
    { 0x9032, "outlinedent" },
    { 0x9033, "outlinedents" },
    { 0x9034, "outlinedid" },
    { 0x9035, "outlinedisable" },
    { 0x9036, "outlinedisableinternal" },
    { 0x9037, "outlinedisableinternalall" },
    { 0x9038, "outlinedplayers" },
    { 0x9039, "outlineenableforall" },
    { 0x903A, "outlineenableforplayer" },
    { 0x903B, "outlineenableforsquad" },
    { 0x903C, "outlineenableforteam" },
    { 0x903D, "outlineenableinternal" },
    { 0x903E, "outlineenemyplayers" },
    { 0x903F, "outlineenemyplayerslaunchchunk" },
    { 0x9040, "outlineent" },
    { 0x9041, "outlineents" },
    { 0x9042, "outlineequipmentforowner" },
    { 0x9043, "outlineequipmentwatchplayerprox" },
    { 0x9044, "outlinefriendly_apply" },
    { 0x9045, "outlinefriendly_remove" },
    { 0x9046, "outlinegenerateuniqueid" },
    { 0x9047, "outlinegethighestinfoforplayer" },
    { 0x9048, "outlinegethighestpriorityid" },
    { 0x9049, "outlinehelper_disableentityoutline" },
    { 0x904A, "outlinehelper_enableentityoutline" },
    { 0x904B, "outlinehelper_getallplayers" },
    { 0x904C, "outlinehelper_updateentityoutline" },
    { 0x904D, "outlinehelper_validplayer" },
    { 0x904E, "outlinehelper_verifydata" },
    { 0x904F, "outlineid" },
    { 0x9050, "outlineiddowatch" },
    { 0x9051, "outlineidenemy" },
    { 0x9052, "outlineidfriend" },
    { 0x9053, "outlineids" },
    { 0x9054, "outlineidspending" },
    { 0x9055, "outlineidswatchpending" },
    { 0x9056, "outlinekillstreaks_enablemarksafterprematch" },
    { 0x9057, "outlineoccluded" },
    { 0x9058, "outlineoccluders" },
    { 0x9059, "outlineoccludersid" },
    { 0x905A, "outlineonplayerdisconnect" },
    { 0x905B, "outlineonplayerjoinedsquad" },
    { 0x905C, "outlineonplayerjoinedsquad_onfirstspawn" },
    { 0x905D, "outlineonplayerjoinedteam" },
    { 0x905E, "outlineonplayerjoinedteam_onfirstspawn" },
    { 0x905F, "outlineplayerbydistance" },
    { 0x9060, "outlineprioritygroupmap" },
    { 0x9061, "outlinerefresh" },
    { 0x9062, "outlinerefreshinternal" },
    { 0x9063, "outlinerefreshpending" },
    { 0x9064, "outlineremovefromgloballist" },
    { 0x9065, "outlineremoveplayerfromvisibletoarrays" },
    { 0x9066, "outlines" },
    { 0x9067, "outlinesquad_apply" },
    { 0x9068, "outlinesquad_remove" },
    { 0x9069, "outlinesuperequipment" },
    { 0x906A, "outlinesuperequipmentforplayer" },
    { 0x906B, "outlinesuperequipmentforteam" },
    { 0x906C, "outlinetime" },
    { 0x906D, "outlinewatcher" },
    { 0x906E, "outlinewatchplayerprox" },
    { 0x906F, "outofbounds" },
    { 0x9070, "outofbounds_failthread" },
    { 0x9071, "outofboundscooldown" },
    { 0x9072, "outofboundstime" },
    { 0x9073, "outofboundstimeminefield" },
    { 0x9074, "outofboundstimerestricted" },
    { 0x9075, "outofboundstriggerpatches" },
    { 0x9076, "outofboundstriggers" },
    { 0x9077, "outofrangefunc" },
    { 0x9078, "outoftimecallbacks" },
    { 0x9079, "outro" },
    { 0x907A, "outro_letterbox" },
    { 0x907B, "outside" },
    { 0x907C, "outside_spawner_cleanup" },
    { 0x907D, "outside_zones" },
    { 0x907E, "outsideheli" },
    { 0x907F, "over_damped_move_to" },
    { 0x9080, "over_damped_move_to_thread" },
    { 0x9081, "overchargeviewkickscale" },
    { 0x9082, "overcook_func" },
    { 0x9083, "overhead_heli_flyby" },
    { 0x9084, "overheated" },
    { 0x9085, "overheattime" },
    { 0x9086, "overlay" },
    { 0x9087, "overlay_clear" },
    { 0x9088, "overlook_group_spawn_func" },
    { 0x9089, "overlook_interact" },
    { 0x908A, "overlook_patrol_animate" },
    { 0x908B, "overlook_suv_behavior" },
    { 0x908C, "overlook_suv_comment" },
    { 0x908D, "overlook_truck_behavior" },
    { 0x908E, "overlookdoor" },
    { 0x908F, "overlookenemies" },
    { 0x9090, "overlookpatrol1" },
    { 0x9091, "overlookpatrol2" },
    { 0x9092, "overlooksuv" },
    { 0x9093, "overlooktruck" },
    { 0x9094, "overlookvehicle" },
    { 0x9095, "override_ambush_vehicle_ai_loadout" },
    { 0x9096, "override_bc_playername" },
    { 0x9097, "override_box_moving_platform_death" },
    { 0x9098, "override_class_function" },
    { 0x9099, "override_corpse_detect_dist" },
    { 0x909A, "override_corpse_found_dist" },
    { 0x909B, "override_corpse_sight_dist" },
    { 0x909C, "override_crawl_death_anims" },
    { 0x909D, "override_damage_auto_range" },
    { 0x909E, "override_damage_sight_range" },
    { 0x909F, "override_find_camp_node" },
    { 0x90A0, "override_move_with_purpose" },
    { 0x90A1, "override_nvg_with_extraction_on_dpad" },
    { 0x90A2, "override_passive_wave_spawning_spawners" },
    { 0x90A3, "override_spawn_scoring_for_module_struct" },
    { 0x90A4, "override_spawner_aitypes" },
    { 0x90A5, "override_unresolved_collision" },
    { 0x90A6, "override_vehicle_fx" },
    { 0x90A7, "overridebroslot" },
    { 0x90A8, "overridecapturestring" },
    { 0x90A9, "overridecovercrouchnodetype" },
    { 0x90AA, "overridecrateusetime" },
    { 0x90AB, "overridedeathreset" },
    { 0x90AC, "overrideheadicon" },
    { 0x90AD, "overridehintstring" },
    { 0x90AE, "overrideingraceperiod" },
    { 0x90AF, "overridekillstreakcrateweight" },
    { 0x90B0, "overrideminimapicon" },
    { 0x90B1, "overridenextstep" },
    { 0x90B2, "overrideprogressteam" },
    { 0x90B3, "overrider" },
    { 0x90B4, "overridererollstring" },
    { 0x90B5, "overriderig" },
    { 0x90B6, "overrides" },
    { 0x90B7, "overridesupportsreroll" },
    { 0x90B8, "overridetaunt" },
    { 0x90B9, "overridetimelimitclock" },
    { 0x90BA, "overridevelocity" },
    { 0x90BB, "overrideviewkickscale" },
    { 0x90BC, "overrideviewkickscalepistol" },
    { 0x90BD, "overrideviewkickscalesniper" },
    { 0x90BE, "overridevisionsetnightforlevel" },
    { 0x90BF, "overridewarningindex" },
    { 0x90C0, "overridewatchdvars" },
    { 0x90C1, "overrideweapon" },
    { 0x90C2, "overrideweaponspeed_speedscale" },
    { 0x90C3, "overrun_gate_mob" },
    { 0x90C4, "overshoot_next_node" },
    { 0x90C5, "overtime" },
    { 0x90C6, "overtimescorewinoverride" },
    { 0x90C7, "overtimethread" },
    { 0x90C8, "overtimetotal" },
    { 0x90C9, "overwatch" },
    { 0x90CA, "overwatch_aim_callout_think" },
    { 0x90CB, "overwatch_boss" },
    { 0x90CC, "overwatch_camera_point" },
    { 0x90CD, "overwatch_camera_zoom_max_delta" },
    { 0x90CE, "overwatch_cleanup" },
    { 0x90CF, "overwatch_control_up_offset" },
    { 0x90D0, "overwatch_disengage_think" },
    { 0x90D1, "overwatch_door_locked_think" },
    { 0x90D2, "overwatch_emp_free" },
    { 0x90D3, "overwatch_emp_high" },
    { 0x90D4, "overwatch_emp_low" },
    { 0x90D5, "overwatch_enemy_callout_think" },
    { 0x90D6, "overwatch_fusebox_callout_think" },
    { 0x90D7, "overwatch_get_target_in_circle_omnvar_value" },
    { 0x90D8, "overwatch_hvt_callout_think" },
    { 0x90D9, "overwatch_hvt_nag_think" },
    { 0x90DA, "overwatch_hvt_sight_callout_think" },
    { 0x90DB, "overwatch_init" },
    { 0x90DC, "overwatch_interaction" },
    { 0x90DD, "overwatch_interior_think" },
    { 0x90DE, "overwatch_kill_callout_think" },
    { 0x90DF, "overwatch_landmark_callout_think" },
    { 0x90E0, "overwatch_noteworthy_init" },
    { 0x90E1, "overwatch_noteworthy_priority" },
    { 0x90E2, "overwatch_obj_nag_think" },
    { 0x90E3, "overwatch_radar_control" },
    { 0x90E4, "overwatch_radio_think" },
    { 0x90E5, "overwatch_request_end" },
    { 0x90E6, "overwatch_request_types" },
    { 0x90E7, "overwatch_requests" },
    { 0x90E8, "overwatch_screen_transition" },
    { 0x90E9, "overwatch_setup" },
    { 0x90EA, "overwatch_sniper_assist_think" },
    { 0x90EB, "overwatch_stance_think" },
    { 0x90EC, "overwatch_tanks" },
    { 0x90ED, "overwatch_target_marker_group_id" },
    { 0x90EE, "overwatch_transition_screen" },
    { 0x90EF, "ownercaptureobject" },
    { 0x90F0, "ownerdamageenabled" },
    { 0x90F1, "ownerdisconnectcleanup" },
    { 0x90F2, "ownerdisconnected" },
    { 0x90F3, "ownerhintstring" },
    { 0x90F4, "ownerid" },
    { 0x90F5, "ownerinstancelimitmessages" },
    { 0x90F6, "ownerinstancelimits" },
    { 0x90F7, "ownerinvisible" },
    { 0x90F8, "ownerjoinedteam" },
    { 0x90F9, "ownermonitor" },
    { 0x90FA, "owners" },
    { 0x90FB, "ownersattacker" },
    { 0x90FC, "ownerteam" },
    { 0x90FD, "ownerteamcaps" },
    { 0x90FE, "ownerteamid" },
    { 0x90FF, "ownertrigger" },
    { 0x9100, "ownerusehintstring" },
    { 0x9101, "ownerusetime" },
    { 0x9102, "ownervehicle" },
    { 0x9103, "ownthenight_achievement_think" },
    { 0x9104, "ownthenight_deathcount" },
    { 0x9105, "ownthenight_spawner_think" },
    { 0x9106, "ownthenight_spawners" },
    { 0x9107, "p_ent_skip_fov" },
    { 0x9108, "p_ent_snake_cam" },
    { 0x9109, "p_ent_zones" },
    { 0x910A, "p_mover" },
    { 0x910B, "p1" },
    { 0x910C, "p1_intel_after_spawn_func" },
    { 0x910D, "p1_intel_death_func" },
    { 0x910E, "p2" },
    { 0x910F, "p3" },
    { 0x9110, "p4" },
    { 0x9111, "pacifist_override" },
    { 0x9112, "pacify_allies" },
    { 0x9113, "pack" },
    { 0x9114, "packdamagedata" },
    { 0x9115, "packstatintoextrainfo" },
    { 0x9116, "pacsentrybeginuse" },
    { 0x9117, "padding" },
    { 0x9118, "page" },
    { 0x9119, "paidout" },
    { 0x911A, "pain_can_use_handler" },
    { 0x911B, "pain_management" },
    { 0x911C, "pain_protection" },
    { 0x911D, "pain_protection_check" },
    { 0x911E, "pain_setflaggedanimknob" },
    { 0x911F, "pain_setflaggedanimknoballrestart" },
    { 0x9120, "pain_setflaggedanimknobrestart" },
    { 0x9121, "pain_test" },
    { 0x9122, "pain_threshold_watcher" },
    { 0x9123, "pain_vo" },
    { 0x9124, "painai" },
    { 0x9125, "painanimfaceenemy" },
    { 0x9126, "painattacker" },
    { 0x9127, "painbreathloopsplayed" },
    { 0x9128, "paincanend" },
    { 0x9129, "paindamage" },
    { 0x912A, "paindeathnotify" },
    { 0x912B, "painhandler" },
    { 0x912C, "paininternal" },
    { 0x912D, "painloc" },
    { 0x912E, "painoldturnrate" },
    { 0x912F, "painonstairs" },
    { 0x9130, "painpitchdifftolerance" },
    { 0x9131, "painsize" },
    { 0x9132, "painsound" },
    { 0x9133, "paintadd" },
    { 0x9134, "painted" },
    { 0x9135, "painter_clean_me" },
    { 0x9136, "painter_init" },
    { 0x9137, "painter_initvars" },
    { 0x9138, "painter_max" },
    { 0x9139, "painter_player" },
    { 0x913A, "painter_startgroup" },
    { 0x913B, "paintime" },
    { 0x913C, "painvision_replacement" },
    { 0x913D, "painyawdiffclosedistsq" },
    { 0x913E, "painyawdiffclosetolerance" },
    { 0x913F, "painyawdifffartolerance" },
    { 0x9140, "palfa_lights_thread" },
    { 0x9141, "pallet_light_lerps" },
    { 0x9142, "pallet_lights" },
    { 0x9143, "pallet_scriptables" },
    { 0x9144, "pallet_smash" },
    { 0x9145, "palm_tree_swap" },
    { 0x9146, "palm_tree_swap_02" },
    { 0x9147, "palm_trees" },
    { 0x9148, "palm_trees_init" },
    { 0x9149, "palmtree_notify_delay" },
    { 0x914A, "panelwidth" },
    { 0x914B, "pap" },
    { 0x914C, "pap_1_camo" },
    { 0x914D, "pap_2_camo" },
    { 0x914E, "pap_firsttime" },
    { 0x914F, "pap_gesture" },
    { 0x9150, "pap_gesture_anim" },
    { 0x9151, "pap_max" },
    { 0x9152, "pap_room_func" },
    { 0x9153, "pap_unlocked" },
    { 0x9154, "paping_weapon" },
    { 0x9155, "parachute" },
    { 0x9156, "parachute_audio" },
    { 0x9157, "parachute_idle" },
    { 0x9158, "parachute_idle_internal" },
    { 0x9159, "parachute_land_origin" },
    { 0x915A, "parachute_move" },
    { 0x915B, "parachute_weapon" },
    { 0x915C, "parachuteautoopen" },
    { 0x915D, "parachutecomplete" },
    { 0x915E, "parachutecompletecb" },
    { 0x915F, "parachutecompletedefault" },
    { 0x9160, "parachutedamagemonitor" },
    { 0x9161, "parachuteendtime" },
    { 0x9162, "parachuteinitfinished" },
    { 0x9163, "parachutemidairdeathwatcher" },
    { 0x9164, "parachuteopencb" },
    { 0x9165, "parachuteopendefault" },
    { 0x9166, "parachuterestoreweaponscb" },
    { 0x9167, "parachutetakeweaponscb" },
    { 0x9168, "parachuteupdater" },
    { 0x9169, "parachutewatchimpact" },
    { 0x916A, "parachuting" },
    { 0x916B, "param" },
    { 0x916C, "param1" },
    { 0x916D, "param2" },
    { 0x916E, "param3" },
    { 0x916F, "param4" },
    { 0x9170, "param5" },
    { 0x9171, "param6" },
    { 0x9172, "param7" },
    { 0x9173, "param8" },
    { 0x9174, "paramreflist" },
    { 0x9175, "params" },
    { 0x9176, "params_default" },
    { 0x9177, "paratrooper_logic" },
    { 0x9178, "paratrooper_spawnfunc" },
    { 0x9179, "paratroopers_allowed" },
    { 0x917A, "parent" },
    { 0x917B, "parent_bombpuzzle" },
    { 0x917C, "parent_menu" },
    { 0x917D, "parent_spawner_disable_after_count" },
    { 0x917E, "parent_struct" },
    { 0x917F, "parent_wire" },
    { 0x9180, "parentchannel" },
    { 0x9181, "parentencounter" },
    { 0x9182, "parentgroup" },
    { 0x9183, "parentspawnstruct" },
    { 0x9184, "parentstate" },
    { 0x9185, "parentstruct" },
    { 0x9186, "parenttag" },
    { 0x9187, "parenttripwires" },
    { 0x9188, "parm1" },
    { 0x9189, "parm2" },
    { 0x918A, "parm3" },
    { 0x918B, "parm4" },
    { 0x918C, "parms" },
    { 0x918D, "parse_consumables_table" },
    { 0x918E, "parse_eog_tracking_table" },
    { 0x918F, "parse_noteworthy_values" },
    { 0x9190, "parse_vo_table" },
    { 0x9191, "parse_weapons_table" },
    { 0x9192, "parseattachdefaulttoidmap" },
    { 0x9193, "parsed" },
    { 0x9194, "parseflagassignmentstring" },
    { 0x9195, "parsehackingtable" },
    { 0x9196, "parsehelipathlength" },
    { 0x9197, "parselocationaliases" },
    { 0x9198, "parseobjectivestable" },
    { 0x9199, "parsepathlength" },
    { 0x919A, "parserelicstable" },
    { 0x919B, "parsestreaktable" },
    { 0x919C, "part" },
    { 0x919D, "part_main" },
    { 0x919E, "parthealth" },
    { 0x919F, "partialgestureplaying" },
    { 0x91A0, "participants" },
    { 0x91A1, "participation" },
    { 0x91A2, "participation_point_cap" },
    { 0x91A3, "participation_point_flattenovertime" },
    { 0x91A4, "partindex" },
    { 0x91A5, "partnames" },
    { 0x91A6, "partnamesview" },
    { 0x91A7, "partner" },
    { 0x91A8, "partnerheli" },
    { 0x91A9, "parts" },
    { 0x91AA, "parts_map" },
    { 0x91AB, "pass" },
    { 0x91AC, "pass_dialoguelogic" },
    { 0x91AD, "pass_dot" },
    { 0x91AE, "pass_enemiesdialoguelogic" },
    { 0x91AF, "pass_enemieslogic" },
    { 0x91B0, "pass_enemydoglogic" },
    { 0x91B1, "pass_farahpathlogic" },
    { 0x91B2, "pass_icon" },
    { 0x91B3, "pass_icon_offset" },
    { 0x91B4, "pass_main" },
    { 0x91B5, "pass_or_throw_active" },
    { 0x91B6, "pass_spawnenemies" },
    { 0x91B7, "pass_start" },
    { 0x91B8, "pass_target" },
    { 0x91B9, "pass_vehicleslogic" },
    { 0x91BA, "passed" },
    { 0x91BB, "passed_2" },
    { 0x91BC, "passed_all_sky_traces" },
    { 0x91BD, "passed_kill_off_time_checks" },
    { 0x91BE, "passenger" },
    { 0x91BF, "passenger_2_turret_func" },
    { 0x91C0, "passenger_shooting" },
    { 0x91C1, "passengers" },
    { 0x91C2, "passes_forward_check" },
    { 0x91C3, "passive_kill_off_ai" },
    { 0x91C4, "passive_kill_off_loop" },
    { 0x91C5, "passive_melee_kill_damage" },
    { 0x91C6, "passive_regen_on_kill_count" },
    { 0x91C7, "passive_visor_detonation_activate" },
    { 0x91C8, "passive_wave_settings" },
    { 0x91C9, "passivedeathwatcher" },
    { 0x91CA, "passiveindex" },
    { 0x91CB, "passivemap" },
    { 0x91CC, "passivenukekillcount" },
    { 0x91CD, "passiveparsetable" },
    { 0x91CE, "passiverandomperkskillcount" },
    { 0x91CF, "passives" },
    { 0x91D0, "passivestringref" },
    { 0x91D1, "passiveuses" },
    { 0x91D2, "passivevalues" },
    { 0x91D3, "passoutthreshold" },
    { 0x91D4, "passouttime" },
    { 0x91D5, "passplayer" },
    { 0x91D6, "passtargetent" },
    { 0x91D7, "passtargetoutlineid" },
    { 0x91D8, "passtime" },
    { 0x91D9, "past_loc_think" },
    { 0x91DA, "past_locs" },
    { 0x91DB, "paste_ents" },
    { 0x91DC, "pastmarkedentindex" },
    { 0x91DD, "pastmarkedents" },
    { 0x91DE, "patch_far" },
    { 0x91DF, "patch_far_notify" },
    { 0x91E0, "patch_new" },
    { 0x91E1, "patch_new2" },
    { 0x91E2, "patch_new3" },
    { 0x91E3, "patch_new4" },
    { 0x91E4, "patch_wait" },
    { 0x91E5, "patch_wait_frameend" },
    { 0x91E6, "patch_weapons_on_rack" },
    { 0x91E7, "path" },
    { 0x91E8, "path_claimed" },
    { 0x91E9, "path_gobbler" },
    { 0x91EA, "path_jitter" },
    { 0x91EB, "path_node_debug_info" },
    { 0x91EC, "path_node_table" },
    { 0x91ED, "path_nodes" },
    { 0x91EE, "path_points" },
    { 0x91EF, "path_positions" },
    { 0x91F0, "path_start_points" },
    { 0x91F1, "path_think" },
    { 0x91F2, "path_vector" },
    { 0x91F3, "patharray" },
    { 0x91F4, "patharrayindex" },
    { 0x91F5, "pathdataavailable" },
    { 0x91F6, "pathdir" },
    { 0x91F7, "pathduration" },
    { 0x91F8, "pathgoal" },
    { 0x91F9, "pathing_array" },
    { 0x91FA, "pathing_arrays" },
    { 0x91FB, "pathing_index" },
    { 0x91FC, "pathpoints" },
    { 0x91FD, "pathrandompercent_reset" },
    { 0x91FE, "pathrandompercent_set" },
    { 0x91FF, "pathrandompercent_zero" },
    { 0x9200, "paths" },
    { 0x9201, "pathsdisconnected" },
    { 0x9202, "pathstart" },
    { 0x9203, "patrol_chooseanim_custom" },
    { 0x9204, "patrol_chooseidlereact" },
    { 0x9205, "patrol_choosestationaryturnanim" },
    { 0x9206, "patrol_custom_face_angle" },
    { 0x9207, "patrol_enemy_watcher" },
    { 0x9208, "patrol_finisharrival" },
    { 0x9209, "patrol_flag_wait" },
    { 0x920A, "patrol_getcustomfunc" },
    { 0x920B, "patrol_getstationaryturnangle" },
    { 0x920C, "patrol_hascustomanim" },
    { 0x920D, "patrol_hasflashlightout" },
    { 0x920E, "patrol_idle_callcustomcallback" },
    { 0x920F, "patrol_idle_cleanup" },
    { 0x9210, "patrol_idle_custom_cleanup" },
    { 0x9211, "patrol_idle_custom_init" },
    { 0x9212, "patrol_idle_getnotehandler" },
    { 0x9213, "patrol_idle_init" },
    { 0x9214, "patrol_idle_istype" },
    { 0x9215, "patrol_idle_setupreaction" },
    { 0x9216, "patrol_idle_shouldabort" },
    { 0x9217, "patrol_idle_shouldreact" },
    { 0x9218, "patrol_idle_shouldsittingabort" },
    { 0x9219, "patrol_idlesitting_checkforcoverarrivalcomplete" },
    { 0x921A, "patrol_iscustomanimdefaultvalue" },
    { 0x921B, "patrol_isidlecurious" },
    { 0x921C, "patrol_isnotidlecurious" },
    { 0x921D, "patrol_magicflashlightdetach" },
    { 0x921E, "patrol_magicflashlighton" },
    { 0x921F, "patrol_moveplaybackrate" },
    { 0x9220, "patrol_movetransition_check" },
    { 0x9221, "patrol_needtostopforpath" },
    { 0x9222, "patrol_needtoturntohuntlookaround" },
    { 0x9223, "patrol_notehandler_cellphone" },
    { 0x9224, "patrol_notehandler_drinking" },
    { 0x9225, "patrol_notehandler_smoking" },
    { 0x9226, "patrol_nothasflashlightout" },
    { 0x9227, "patrol_notshouldinvestigatelookaround" },
    { 0x9228, "patrol_one_go" },
    { 0x9229, "patrol_path" },
    { 0x922A, "patrol_playanim" },
    { 0x922B, "patrol_playanim_idle" },
    { 0x922C, "patrol_playanim_idlecurious" },
    { 0x922D, "patrol_playanim_idlecurious_facelastknownhelper" },
    { 0x922E, "patrol_playanim_idlestationaryturn" },
    { 0x922F, "patrol_playanim_pulloutflashlight" },
    { 0x9230, "patrol_playanim_randomrate" },
    { 0x9231, "patrol_playdeathanim_sitting" },
    { 0x9232, "patrol_playidle_custom_terminate" },
    { 0x9233, "patrol_playidleend" },
    { 0x9234, "patrol_playidleend_custom" },
    { 0x9235, "patrol_playidleintro" },
    { 0x9236, "patrol_playidleintro_custom" },
    { 0x9237, "patrol_playidleloop" },
    { 0x9238, "patrol_playidleloop_custom" },
    { 0x9239, "patrol_playidlereact" },
    { 0x923A, "patrol_playidlereact_custom" },
    { 0x923B, "patrol_playidlesittingloop" },
    { 0x923C, "patrol_playidlesittingloop_cellphone" },
    { 0x923D, "patrol_playidlesittingloop_cleanup" },
    { 0x923E, "patrol_playidlesittingloop_laptop" },
    { 0x923F, "patrol_playidlesittingloop_pistolclean" },
    { 0x9240, "patrol_playidlesittingloop_prop_cleanup" },
    { 0x9241, "patrol_playidlesittingloop_sleeping" },
    { 0x9242, "patrol_playidlesittingloop_sleeping_cleanup" },
    { 0x9243, "patrol_playidlesittingreact" },
    { 0x9244, "patrol_prop_cleanup" },
    { 0x9245, "patrol_prop_delete" },
    { 0x9246, "patrol_prop_waitfordelete" },
    { 0x9247, "patrol_radius" },
    { 0x9248, "patrol_react_last" },
    { 0x9249, "patrol_react_magnitude" },
    { 0x924A, "patrol_react_pos" },
    { 0x924B, "patrol_react_time" },
    { 0x924C, "patrol_reactendswithmove" },
    { 0x924D, "patrol_return_offset" },
    { 0x924E, "patrol_shouldarrival_examine" },
    { 0x924F, "patrol_shouldcombatrereact" },
    { 0x9250, "patrol_shoulddostationaryturn" },
    { 0x9251, "patrol_shouldidleanim" },
    { 0x9252, "patrol_shouldinvestigatelookaround" },
    { 0x9253, "patrol_shouldpulloutflashlight" },
    { 0x9254, "patrol_shouldputawayflashlight" },
    { 0x9255, "patrol_shouldreact" },
    { 0x9256, "patrol_shouldusehuntexit" },
    { 0x9257, "patrol_smoking_blowsmoke" },
    { 0x9258, "patrol_smoking_cleanup" },
    { 0x9259, "patrol_spawn_func" },
    { 0x925A, "patrol_state" },
    { 0x925B, "patrol_state_text_handler" },
    { 0x925C, "patrol_stationaryturnfixupthread" },
    { 0x925D, "patrol_stop" },
    { 0x925E, "patrol_using_cover_nodes" },
    { 0x925F, "patrolfield" },
    { 0x9260, "patroller_final_vol" },
    { 0x9261, "patrolparams" },
    { 0x9262, "patrolreact_terminate" },
    { 0x9263, "patrolscore" },
    { 0x9264, "patrolshouldstop" },
    { 0x9265, "patroltarget" },
    { 0x9266, "pause_all_other_groups" },
    { 0x9267, "pause_between_vo" },
    { 0x9268, "pause_chatter" },
    { 0x9269, "pause_count" },
    { 0x926A, "pause_flag_monitor" },
    { 0x926B, "pause_globalthreat_timer" },
    { 0x926C, "pause_group_by_group_name" },
    { 0x926D, "pause_group_by_id" },
    { 0x926E, "pause_hacking" },
    { 0x926F, "pause_nag_vo" },
    { 0x9270, "pause_remind" },
    { 0x9271, "pause_reminders" },
    { 0x9272, "pause_spawner_scoring" },
    { 0x9273, "pause_time" },
    { 0x9274, "pause_timer" },
    { 0x9275, "pause_turbulence" },
    { 0x9276, "pause_vo_system" },
    { 0x9277, "pauseballtimer" },
    { 0x9278, "pausecountdowntimer" },
    { 0x9279, "paused" },
    { 0x927A, "pauseeffect" },
    { 0x927B, "pauseexploder" },
    { 0x927C, "pausemax" },
    { 0x927D, "pausemenu_think" },
    { 0x927E, "pausemin" },
    { 0x927F, "pausescoring" },
    { 0x9280, "pausesuperpointsovertime" },
    { 0x9281, "pausetacopscounter" },
    { 0x9282, "pausetacopstime" },
    { 0x9283, "pausetacopstimer" },
    { 0x9284, "pausetacopstimestarted" },
    { 0x9285, "pausetimer" },
    { 0x9286, "pausetimerecord" },
    { 0x9287, "pausing_bot_connect_monitor" },
    { 0x9288, "pavelowmadeselectionvo" },
    { 0x9289, "payloadspawnsets" },
    { 0x928A, "payoutbet" },
    { 0x928B, "payoutremainingbets" },
    { 0x928C, "pc_force_fov" },
    { 0x928D, "peeklooktimer_canstarttime" },
    { 0x928E, "pelletdmg" },
    { 0x928F, "pendingarchiverequest" },
    { 0x9290, "pentadvanced" },
    { 0x9291, "pentadvancedoptions" },
    { 0x9292, "pentdelaysetmodel" },
    { 0x9293, "pentmodel" },
    { 0x9294, "pentparams" },
    { 0x9295, "pentparamsdefined" },
    { 0x9296, "pentskipfov" },
    { 0x9297, "pep_talk_breakout" },
    { 0x9298, "pep_talk_reach_and_idle" },
    { 0x9299, "peptalk_counter" },
    { 0x929A, "per_regen_amount" },
    { 0x929B, "perfect_player_info" },
    { 0x929C, "perfectenemyinfo" },
    { 0x929D, "perferred_crash_location" },
    { 0x929E, "perform_courtyard_breach" },
    { 0x929F, "perform_state_change" },
    { 0x92A0, "performfailsafeinfil" },
    { 0x92A1, "performoperation" },
    { 0x92A2, "perimeter_light_ondeath" },
    { 0x92A3, "period_max" },
    { 0x92A4, "period_min" },
    { 0x92A5, "periodic_ac130_strikes" },
    { 0x92A6, "periodic_airstrikes" },
    { 0x92A7, "periph_traffic" },
    { 0x92A8, "periph_vehicle_driver" },
    { 0x92A9, "periph_vehicle_driver_delete_handler" },
    { 0x92AA, "periph_vehicle_loop_new" },
    { 0x92AB, "perk" },
    { 0x92AC, "perk_adsmarktarget_check" },
    { 0x92AD, "perk_adsmarktarget_confirmtargetandmark" },
    { 0x92AE, "perk_adsmarktarget_think" },
    { 0x92AF, "perk_adstargetmark_disconnectcleanupthink" },
    { 0x92B0, "perk_data" },
    { 0x92B1, "perk_doorsense_othersideofdoorcheck" },
    { 0x92B2, "perk_doorsense_outlinedoor" },
    { 0x92B3, "perk_doorsense_outlineenemies" },
    { 0x92B4, "perk_doorsense_trackoutlinedisable" },
    { 0x92B5, "perk_doorsensethink" },
    { 0x92B6, "perk_getbulletdamagescalar" },
    { 0x92B7, "perk_getexplosivedamagescalar" },
    { 0x92B8, "perk_getmaxhealth" },
    { 0x92B9, "perk_getmeleescalar" },
    { 0x92BA, "perk_getmovespeedscalar" },
    { 0x92BB, "perk_getoffhandcount" },
    { 0x92BC, "perk_getrevivedamagescalar" },
    { 0x92BD, "perk_getrevivetimescalar" },
    { 0x92BE, "perk_init" },
    { 0x92BF, "perk_trackadsmarktargetoutline" },
    { 0x92C0, "perk_type" },
    { 0x92C1, "perkdata" },
    { 0x92C2, "perkengineer_manageminimap" },
    { 0x92C3, "perkengineerset" },
    { 0x92C4, "perkfuncs" },
    { 0x92C5, "perkicon" },
    { 0x92C6, "perklevel" },
    { 0x92C7, "perkname" },
    { 0x92C8, "perkoutlined" },
    { 0x92C9, "perkoutlinekillstreaksset" },
    { 0x92CA, "perkpackage_awardperkpackageupgrade" },
    { 0x92CB, "perkpackage_checkifready" },
    { 0x92CC, "perkpackage_forceusesuper" },
    { 0x92CD, "perkpackage_getfirstfieldupgrade" },
    { 0x92CE, "perkpackage_getperkicon" },
    { 0x92CF, "perkpackage_getsecondfieldupgrade" },
    { 0x92D0, "perkpackage_givedebug" },
    { 0x92D1, "perkpackage_giveimmediate" },
    { 0x92D2, "perkpackage_initperkpackages" },
    { 0x92D3, "perkpackage_initpersdata" },
    { 0x92D4, "perkpackage_isreadytoupgrade" },
    { 0x92D5, "perkpackage_openselect" },
    { 0x92D6, "perkpackage_reset" },
    { 0x92D7, "perkpackage_setstate" },
    { 0x92D8, "perkpackage_updateifchanged" },
    { 0x92D9, "perkpackage_waitforsupercanceled" },
    { 0x92DA, "perkpackage_waitforsuperfinish" },
    { 0x92DB, "perkpackage_waitforsuperfinishinternal" },
    { 0x92DC, "perkpackagedata" },
    { 0x92DD, "perkpackagelist" },
    { 0x92DE, "perkpackagemenu_canactivatesuper" },
    { 0x92DF, "perkpackagemenu_closeinputthink" },
    { 0x92E0, "perkpackagemenu_disableoffhanduse" },
    { 0x92E1, "perkpackagemenu_menuthink" },
    { 0x92E2, "perkpackagemenu_openmenu" },
    { 0x92E3, "perkpointsonkill" },
    { 0x92E4, "perkpointspercentageplayersalive" },
    { 0x92E5, "perkpointspickup" },
    { 0x92E6, "perkrechargeequipmentplayers" },
    { 0x92E7, "perkref" },
    { 0x92E8, "perks" },
    { 0x92E9, "perksblocked" },
    { 0x92EA, "perksbyid" },
    { 0x92EB, "perksenabled" },
    { 0x92EC, "perksetfuncs" },
    { 0x92ED, "perksperkname" },
    { 0x92EE, "perktable" },
    { 0x92EF, "perktable_add" },
    { 0x92F0, "perktable_costs" },
    { 0x92F1, "perkunsetfuncs" },
    { 0x92F2, "perkusedeathtracker" },
    { 0x92F3, "perkwatcher" },
    { 0x92F4, "perkweaponlaseroffforswitchstart" },
    { 0x92F5, "perkweaponlaseron" },
    { 0x92F6, "permanent" },
    { 0x92F7, "permanent_notify_handler" },
    { 0x92F8, "permanentnotifyhandlers" },
    { 0x92F9, "permcapturethresholds" },
    { 0x92FA, "permhidden" },
    { 0x92FB, "permute" },
    { 0x92FC, "pers_init" },
    { 0x92FD, "persbombtimer" },
    { 0x92FE, "persclear_stats" },
    { 0x92FF, "persincrement_weaponstats" },
    { 0x9300, "persistence_weaponstats" },
    { 0x9301, "persistent" },
    { 0x9302, "persistentbombtimer" },
    { 0x9303, "persistentcallbacks" },
    { 0x9304, "persistentdatainfo" },
    { 0x9305, "persistentdebugline" },
    { 0x9306, "persistentdomtimer" },
    { 0x9307, "persistentrelics" },
    { 0x9308, "perslog_attachmentstats" },
    { 0x9309, "perslog_weaponstats" },
    { 0x930A, "personal_ent_zones" },
    { 0x930B, "personal_score_component_name" },
    { 0x930C, "personalcoldbreath" },
    { 0x930D, "personalcoldbreathspawner" },
    { 0x930E, "personalcoldbreathstop" },
    { 0x930F, "personalcraftingmaterialslist" },
    { 0x9310, "personalents" },
    { 0x9311, "personality" },
    { 0x9312, "personality_init_function" },
    { 0x9313, "personality_update_function" },
    { 0x9314, "personalitymanuallyset" },
    { 0x9315, "personalradaractive" },
    { 0x9316, "personalscenenode" },
    { 0x9317, "personalscore" },
    { 0x9318, "personalweaponfullname" },
    { 0x9319, "pet" },
    { 0x931A, "petconsts" },
    { 0x931B, "petdie" },
    { 0x931C, "petwatch" },
    { 0x931D, "phase" },
    { 0x931E, "phaseshift_hint_displayed" },
    { 0x931F, "phasespeedmod" },
    { 0x9320, "phasetime" },
    { 0x9321, "phj_spawners_trigger" },
    { 0x9322, "phone_kid_idle_cage02_model" },
    { 0x9323, "phone_kid_idle_child01_model" },
    { 0x9324, "phone_kid_idle_child02_model" },
    { 0x9325, "phone_kid_idle_child03_model" },
    { 0x9326, "phone_sfx" },
    { 0x9327, "phone_sfx_idle" },
    { 0x9328, "phone_table_interact" },
    { 0x9329, "phosphorus_aim" },
    { 0x932A, "phosphorus_run_react" },
    { 0x932B, "photo_index" },
    { 0x932C, "photosetup" },
    { 0x932D, "phys_amp_max" },
    { 0x932E, "phys_amp_normal" },
    { 0x932F, "phys_barrel_radius" },
    { 0x9330, "phys_barrels" },
    { 0x9331, "phys_contents" },
    { 0x9332, "phys_sound_func" },
    { 0x9333, "physasset" },
    { 0x9334, "physicallybased" },
    { 0x9335, "physics_impact_watch" },
    { 0x9336, "physics_test" },
    { 0x9337, "physicsactivated" },
    { 0x9338, "physicsjolt_proximity" },
    { 0x9339, "physicssphereforce" },
    { 0x933A, "physicssphereradius" },
    { 0x933B, "picc_spawn_ai" },
    { 0x933C, "piccadilly" },
    { 0x933D, "piccadilly_cansave" },
    { 0x933E, "piccadilly_finished" },
    { 0x933F, "piccadilly_spawnstruct" },
    { 0x9340, "piccadilly_weapons" },
    { 0x9341, "pick_aitype" },
    { 0x9342, "pick_ball_carrier" },
    { 0x9343, "pick_death" },
    { 0x9344, "pick_nag_anim" },
    { 0x9345, "pick_random_animset" },
    { 0x9346, "pick_tree_anim" },
    { 0x9347, "pick_up_armor_vest" },
    { 0x9348, "pickandsetforceweapon" },
    { 0x9349, "pickdefaultoperatorskin" },
    { 0x934A, "pickedup" },
    { 0x934B, "pickedupbyplayer" },
    { 0x934C, "pickflagtospawn" },
    { 0x934D, "picklane" },
    { 0x934E, "picklaunchchunkoperatorskin" },
    { 0x934F, "picknewrandomcustomclass" },
    { 0x9350, "pickoverridearchetype" },
    { 0x9351, "pickradiotospawn" },
    { 0x9352, "pickrandomnonvehiclespawn" },
    { 0x9353, "pickup_disabled" },
    { 0x9354, "pickup_fake_cpapa" },
    { 0x9355, "pickup_gun" },
    { 0x9356, "pickup_stunstick" },
    { 0x9357, "pickup_trig" },
    { 0x9358, "pickup_truck_cp_create" },
    { 0x9359, "pickup_truck_cp_createfromstructs" },
    { 0x935A, "pickup_truck_cp_delete" },
    { 0x935B, "pickup_truck_cp_getspawnstructscallback" },
    { 0x935C, "pickup_truck_cp_init" },
    { 0x935D, "pickup_truck_cp_initlate" },
    { 0x935E, "pickup_truck_cp_initspawning" },
    { 0x935F, "pickup_truck_cp_ondeathrespawncallback" },
    { 0x9360, "pickup_truck_cp_spawncallback" },
    { 0x9361, "pickup_truck_cp_waitandspawn" },
    { 0x9362, "pickup_truck_create" },
    { 0x9363, "pickup_truck_deathcallback" },
    { 0x9364, "pickup_truck_deletenextframe" },
    { 0x9365, "pickup_truck_enterend" },
    { 0x9366, "pickup_truck_enterendinternal" },
    { 0x9367, "pickup_truck_exitend" },
    { 0x9368, "pickup_truck_exitendinternal" },
    { 0x9369, "pickup_truck_explode" },
    { 0x936A, "pickup_truck_getspawnstructscallback" },
    { 0x936B, "pickup_truck_init" },
    { 0x936C, "pickup_truck_initfx" },
    { 0x936D, "pickup_truck_initinteract" },
    { 0x936E, "pickup_truck_initlate" },
    { 0x936F, "pickup_truck_initoccupancy" },
    { 0x9370, "pickup_truck_initspawning" },
    { 0x9371, "pickup_truck_mp_create" },
    { 0x9372, "pickup_truck_mp_delete" },
    { 0x9373, "pickup_truck_mp_getspawnstructscallback" },
    { 0x9374, "pickup_truck_mp_init" },
    { 0x9375, "pickup_truck_mp_initmines" },
    { 0x9376, "pickup_truck_mp_initspawning" },
    { 0x9377, "pickup_truck_mp_ondeathrespawncallback" },
    { 0x9378, "pickup_truck_mp_spawncallback" },
    { 0x9379, "pickup_truck_mp_waitandspawn" },
    { 0x937A, "pickup_uses_origin" },
    { 0x937B, "pickupcleanupmonitor" },
    { 0x937C, "pickupenabled" },
    { 0x937D, "pickupent" },
    { 0x937E, "pickupfunc" },
    { 0x937F, "pickuphintstring" },
    { 0x9380, "pickupicon" },
    { 0x9381, "pickupissameasequipmentslot" },
    { 0x9382, "pickupitemintoinventory" },
    { 0x9383, "pickupobjectdelay" },
    { 0x9384, "pickuptime" },
    { 0x9385, "pickuptimeout" },
    { 0x9386, "pickuptrucks" },
    { 0x9387, "pickupweaponhandler" },
    { 0x9388, "pickviptospawn" },
    { 0x9389, "pictureweapons" },
    { 0x938A, "piece_use" },
    { 0x938B, "pieces" },
    { 0x938C, "pilot" },
    { 0x938D, "pilot_apache" },
    { 0x938E, "pilot_apache_camera_shake" },
    { 0x938F, "pilot_apache_camera_transition" },
    { 0x9390, "pilot_apache_camera_transition_out" },
    { 0x9391, "pilot_apache_datapad_transition" },
    { 0x9392, "pilot_apache_handle_missile_fire" },
    { 0x9393, "pilot_apache_handle_thermal_switch" },
    { 0x9394, "pilot_apache_missile_reloader" },
    { 0x9395, "pilot_damage_thread" },
    { 0x9396, "pilot_death_watcher" },
    { 0x9397, "pilot_dialog_struct" },
    { 0x9398, "pilot_killed" },
    { 0x9399, "pilot_pickup_from_cockpit" },
    { 0x939A, "pilot_rescue_objective_think" },
    { 0x939B, "pilot_wait_for_rescue" },
    { 0x939C, "pilotkill_watcher" },
    { 0x939D, "pindia_positions_override_func" },
    { 0x939E, "ping_current_objective" },
    { 0x939F, "ping_enemy_and_player_for_duration" },
    { 0x93A0, "pinged" },
    { 0x93A1, "pingobjidnum" },
    { 0x93A2, "pingplayers" },
    { 0x93A3, "pinned_marine" },
    { 0x93A4, "pinnedobjid" },
    { 0x93A5, "pinobj" },
    { 0x93A6, "pinobjiconontriggertouch" },
    { 0x93A7, "pintoscreenedge" },
    { 0x93A8, "pip" },
    { 0x93A9, "pip_close" },
    { 0x93AA, "pip_dialogue" },
    { 0x93AB, "pip_init" },
    { 0x93AC, "pip_is_active" },
    { 0x93AD, "pip_on_ent" },
    { 0x93AE, "pip_visionset" },
    { 0x93AF, "pip_vo" },
    { 0x93B0, "pipe_dying_boy" },
    { 0x93B1, "pipebombfiremain" },
    { 0x93B2, "pipes_bomb" },
    { 0x93B3, "pipes_bomb_add_fov_user_scale_override" },
    { 0x93B4, "pipes_dialog" },
    { 0x93B5, "pipes_fake_sniper_fire" },
    { 0x93B6, "pipes_hallway_catchup" },
    { 0x93B7, "pipes_hallway_main" },
    { 0x93B8, "pipes_hallway_start" },
    { 0x93B9, "pipes_hero_light_init" },
    { 0x93BA, "pipes_hero_light_rig_setup" },
    { 0x93BB, "pipes_hero_light_setup" },
    { 0x93BC, "pipes_jumpdown_catchup" },
    { 0x93BD, "pipes_jumpdown_lights_init" },
    { 0x93BE, "pipes_jumpdown_main" },
    { 0x93BF, "pipes_jumpdown_scene" },
    { 0x93C0, "pipes_jumpdown_start" },
    { 0x93C1, "pipes_last_enemies" },
    { 0x93C2, "pipes_moments_setup" },
    { 0x93C3, "pipes_outdoor_catchup" },
    { 0x93C4, "pipes_outdoor_main" },
    { 0x93C5, "pipes_outdoor_postload" },
    { 0x93C6, "pipes_outdoor_preload" },
    { 0x93C7, "pipes_outdoor_start" },
    { 0x93C8, "pipes_sniper_setup" },
    { 0x93C9, "pipes_to_hallway" },
    { 0x93CA, "pistol_can_save" },
    { 0x93CB, "pistol_catchup" },
    { 0x93CC, "pistol_enemies" },
    { 0x93CD, "pistol_enemies_dead" },
    { 0x93CE, "pistol_enemies_has_lost_enemy" },
    { 0x93CF, "pistol_enemies_number" },
    { 0x93D0, "pistol_enemies_setup_stealth" },
    { 0x93D1, "pistol_enemies_spawn" },
    { 0x93D2, "pistol_enemies_spawn_func" },
    { 0x93D3, "pistol_enemy_01_ai" },
    { 0x93D4, "pistol_enemy_02_ai" },
    { 0x93D5, "pistol_enemy_combat_think" },
    { 0x93D6, "pistol_enemy_deaths" },
    { 0x93D7, "pistol_enemy_deaths_time" },
    { 0x93D8, "pistol_fight_death_monitor" },
    { 0x93D9, "pistol_fight_start_monitor" },
    { 0x93DA, "pistol_fight_vo" },
    { 0x93DB, "pistol_fired_check" },
    { 0x93DC, "pistol_intro_anim_node" },
    { 0x93DD, "pistol_intro_anim_node_truck" },
    { 0x93DE, "pistol_intro_anim_node_truck01" },
    { 0x93DF, "pistol_main" },
    { 0x93E0, "pistol_physics_hack" },
    { 0x93E1, "pistol_picked_up" },
    { 0x93E2, "pistol_pickup_check" },
    { 0x93E3, "pistol_pickup_monitor" },
    { 0x93E4, "pistol_skip_fight" },
    { 0x93E5, "pistol_start" },
    { 0x93E6, "pistol_start_vo" },
    { 0x93E7, "pistol_vo" },
    { 0x93E8, "pistol_vo_sources" },
    { 0x93E9, "pistol_weapon_interact" },
    { 0x93EA, "pistol_weapon_interact_b" },
    { 0x93EB, "pistol_weapon_user" },
    { 0x93EC, "pistol_weapons_array" },
    { 0x93ED, "pistolarray" },
    { 0x93EE, "pistolcombatspeedscalar" },
    { 0x93EF, "pistols_only" },
    { 0x93F0, "pitch" },
    { 0x93F1, "pitch_up_cap_adjust" },
    { 0x93F2, "pitch_up_reset" },
    { 0x93F3, "pitch_up_set" },
    { 0x93F4, "pitch_up_think" },
    { 0x93F5, "pitchdelta" },
    { 0x93F6, "pitchmax" },
    { 0x93F7, "pitchmin" },
    { 0x93F8, "pitchturnthreshold" },
    { 0x93F9, "pivot" },
    { 0x93FA, "pivot_ent" },
    { 0x93FB, "pivoting" },
    { 0x93FC, "pivots" },
    { 0x93FD, "pkg_id" },
    { 0x93FE, "pkg_id_lbl" },
    { 0x93FF, "pkg_ids" },
    { 0x9400, "pkg_lbl" },
    { 0x9401, "place_bomb_in_the_vehicle" },
    { 0x9402, "place_each_soldier_on_truck" },
    { 0x9403, "place_finale_trees" },
    { 0x9404, "place_heli_over_player" },
    { 0x9405, "place_path_node_from_lookat" },
    { 0x9406, "place_path_nodes" },
    { 0x9407, "place_path_nodes_within_box" },
    { 0x9408, "place_path_nodes_within_radius" },
    { 0x9409, "place_weapon_at_unclaimed_struct" },
    { 0x940A, "place_weapon_on" },
    { 0x940B, "placeableconfigs" },
    { 0x940C, "placecancelablestring" },
    { 0x940D, "placecrate" },
    { 0x940E, "placed_alien_fuses" },
    { 0x940F, "placed_c4_train" },
    { 0x9410, "placed_crafted_traps" },
    { 0x9411, "placedclosevol" },
    { 0x9412, "placedladder" },
    { 0x9413, "placedompoint" },
    { 0x9414, "placedsentries" },
    { 0x9415, "placedsfx" },
    { 0x9416, "placedspawners" },
    { 0x9417, "placeequipmentfailed" },
    { 0x9418, "placeequipmentfailedcleanup" },
    { 0x9419, "placeequipmentfailedinit" },
    { 0x941A, "placeflag" },
    { 0x941B, "placeheight" },
    { 0x941C, "placehinton" },
    { 0x941D, "placekillstreakcrate" },
    { 0x941E, "placeladder" },
    { 0x941F, "placement" },
    { 0x9420, "placementheighttolerance" },
    { 0x9421, "placementhintstring" },
    { 0x9422, "placementhudelements" },
    { 0x9423, "placementmode" },
    { 0x9424, "placementmodel" },
    { 0x9425, "placementoffsetz" },
    { 0x9426, "placementorigin" },
    { 0x9427, "placementradius" },
    { 0x9428, "placeplcrate" },
    { 0x9429, "placepoint" },
    { 0x942A, "placestring" },
    { 0x942B, "placeuplinkgoal" },
    { 0x942C, "placeweaponon" },
    { 0x942D, "placing_bomb_interaction_use_monitor" },
    { 0x942E, "placing_bomb_interactions" },
    { 0x942F, "placingitemstreakname" },
    { 0x9430, "plane_landed_idle" },
    { 0x9431, "plane_patrol_watcher" },
    { 0x9432, "plane_seats" },
    { 0x9433, "plane_takeoff_from_airport" },
    { 0x9434, "planecleanup" },
    { 0x9435, "planeconfigs" },
    { 0x9436, "planemodel" },
    { 0x9437, "planemove" },
    { 0x9438, "planerespawn" },
    { 0x9439, "planes" },
    { 0x943A, "planes_ready" },
    { 0x943B, "planes_thread" },
    { 0x943C, "planespawn" },
    { 0x943D, "planet" },
    { 0x943E, "plant" },
    { 0x943F, "plant_animatedstairscivilianworkerlogic" },
    { 0x9440, "plant_barkovspeakerlogic" },
    { 0x9441, "plant_bomb" },
    { 0x9442, "plant_cinematictelevisionstandbylogic" },
    { 0x9443, "plant_clamp_angles" },
    { 0x9444, "plant_constructionpuzzlelogic" },
    { 0x9445, "plant_conversationdialoguelogic" },
    { 0x9446, "plant_deletelinkedailogic" },
    { 0x9447, "plant_deletelinkedaitriggerlogic" },
    { 0x9448, "plant_deletelinkedaitriggerslogic" },
    { 0x9449, "plant_dialoguelogic" },
    { 0x944A, "plant_entryguarddialoguelogic" },
    { 0x944B, "plant_entryguarddialoguestructdeathlogic" },
    { 0x944C, "plant_entryguarddialoguestructentrylogic" },
    { 0x944D, "plant_farahinstructionslogic" },
    { 0x944E, "plant_farahshootguarddialoguelogic" },
    { 0x944F, "plant_farahshootguardtriggerslogic" },
    { 0x9450, "plant_farahstealthbrokenlogic" },
    { 0x9451, "plant_getieds" },
    { 0x9452, "plant_getplayersilencerinteracts" },
    { 0x9453, "plant_getstairenemy" },
    { 0x9454, "plant_ied_add_fov_user_scale_override" },
    { 0x9455, "plant_ied_remove_fov_user_scale_override" },
    { 0x9456, "plant_iedlogic" },
    { 0x9457, "plant_introdialoguelogic" },
    { 0x9458, "plant_killextraenemies" },
    { 0x9459, "plant_main" },
    { 0x945A, "plant_pathblockersclear" },
    { 0x945B, "plant_playerattargettriggerdialoguelogic" },
    { 0x945C, "plant_sandboxlogic" },
    { 0x945D, "plant_secondfloordialoguelogic" },
    { 0x945E, "plant_spawncivilianworkers" },
    { 0x945F, "plant_spawnied" },
    { 0x9460, "plant_spawniedinteractonvehicle" },
    { 0x9461, "plant_spot" },
    { 0x9462, "plant_stairenemyalexresponselogic" },
    { 0x9463, "plant_stairenemylogic" },
    { 0x9464, "plant_start" },
    { 0x9465, "plant_updateobjectivelocation" },
    { 0x9466, "plant_visionlogic" },
    { 0x9467, "plant_watch_stuck" },
    { 0x9468, "plant_watch_stuck_calculate" },
    { 0x9469, "plant_watch_stuck_notify" },
    { 0x946A, "plant_watch_stuck_timeout" },
    { 0x946B, "plantbreach" },
    { 0x946C, "plantbreachc4" },
    { 0x946D, "plantbreachweapon" },
    { 0x946E, "planted" },
    { 0x946F, "planted_explosive" },
    { 0x9470, "plantedbomb" },
    { 0x9471, "plantedhackedequip" },
    { 0x9472, "plantedkey" },
    { 0x9473, "plantedlethalequip" },
    { 0x9474, "plantedsuperequip" },
    { 0x9475, "plantedtacticalequip" },
    { 0x9476, "plantmaxdistbelowownerfeet" },
    { 0x9477, "plantmaxroll" },
    { 0x9478, "plantmaxtime" },
    { 0x9479, "plantmindistbeloweye" },
    { 0x947A, "plantmindisteyetofeet" },
    { 0x947B, "plantnormalcos" },
    { 0x947C, "plantobjstr" },
    { 0x947D, "plantoffsetz" },
    { 0x947E, "plantscharge" },
    { 0x947F, "planttime" },
    { 0x9480, "plate" },
    { 0x9481, "play_2f_data_anim" },
    { 0x9482, "play_addtive_head_anim" },
    { 0x9483, "play_ai_skit" },
    { 0x9484, "play_airdrop_crate" },
    { 0x9485, "play_alarm_pos" },
    { 0x9486, "play_alert_music_to_players" },
    { 0x9487, "play_alex_anim" },
    { 0x9488, "play_alpha_bink" },
    { 0x9489, "play_ambient_idle_scene" },
    { 0x948A, "play_ambient_idle_scene_single" },
    { 0x948B, "play_ambush_sniper_muzzle_vfx" },
    { 0x948C, "play_and_hold_anim" },
    { 0x948D, "play_anim_and_delete" },
    { 0x948E, "play_anim_and_then_last_frame" },
    { 0x948F, "play_anim_and_then_loop" },
    { 0x9490, "play_anim_and_then_loop_with_nags" },
    { 0x9491, "play_anim_check" },
    { 0x9492, "play_anim_sequence" },
    { 0x9493, "play_anim_shared_vo" },
    { 0x9494, "play_anim_think" },
    { 0x9495, "play_anim_vo" },
    { 0x9496, "play_anim_vo_sequential" },
    { 0x9497, "play_animation_on_channel" },
    { 0x9498, "play_animation_on_channel_loop" },
    { 0x9499, "play_approach_tripwire_building" },
    { 0x949A, "play_armor_sfx" },
    { 0x949B, "play_basic_pain_overlay" },
    { 0x949C, "play_bed_exit" },
    { 0x949D, "play_bink_video" },
    { 0x949E, "play_bink_video_internal" },
    { 0x949F, "play_blended_interaction_anims" },
    { 0x94A0, "play_blood_pool" },
    { 0x94A1, "play_bonus_time_sound" },
    { 0x94A2, "play_breach_dialogues" },
    { 0x94A3, "play_bullet_impact_vfx" },
    { 0x94A4, "play_button_sound" },
    { 0x94A5, "play_c4_anims" },
    { 0x94A6, "play_cam_rumble_once" },
    { 0x94A7, "play_cargo_c4_nags" },
    { 0x94A8, "play_cargo_intro" },
    { 0x94A9, "play_cargo_train_stopped" },
    { 0x94AA, "play_chute_land_anim" },
    { 0x94AB, "play_cloud_vfx" },
    { 0x94AC, "play_combat_interaction" },
    { 0x94AD, "play_combat_music_to_players" },
    { 0x94AE, "play_commander_response" },
    { 0x94AF, "play_consumable_activate_sound" },
    { 0x94B0, "play_convoy_hostage_save_vo" },
    { 0x94B1, "play_convoy_hostage_vo" },
    { 0x94B2, "play_coop_vehicle_race_successs" },
    { 0x94B3, "play_cp_comment_vo" },
    { 0x94B4, "play_crate_vfx" },
    { 0x94B5, "play_deathfx_convoy" },
    { 0x94B6, "play_decel_effects" },
    { 0x94B7, "play_defender_death" },
    { 0x94B8, "play_dialogue" },
    { 0x94B9, "play_disarm_operator_vo" },
    { 0x94BA, "play_dom_capture_sfx" },
    { 0x94BB, "play_dooropener_kill" },
    { 0x94BC, "play_doors_open_nags" },
    { 0x94BD, "play_effort_sound" },
    { 0x94BE, "play_emp_scramble" },
    { 0x94BF, "play_ending_bink" },
    { 0x94C0, "play_enemy_incoming" },
    { 0x94C1, "play_enemy_radio_beep" },
    { 0x94C2, "play_enemy_radio_chat" },
    { 0x94C3, "play_escort_pain_vo" },
    { 0x94C4, "play_exfil_dialogues" },
    { 0x94C5, "play_explosion_post_impale" },
    { 0x94C6, "play_extract_2mins" },
    { 0x94C7, "play_extract_reminders" },
    { 0x94C8, "play_final_key_vo" },
    { 0x94C9, "play_find_lead" },
    { 0x94CA, "play_find_lead_good" },
    { 0x94CB, "play_fire_system_sound" },
    { 0x94CC, "play_fire_system_sound_loop" },
    { 0x94CD, "play_flashlight_fx" },
    { 0x94CE, "play_flir_footstep_fx" },
    { 0x94CF, "play_footstep_sound" },
    { 0x94D0, "play_found_enough_leads" },
    { 0x94D1, "play_fx" },
    { 0x94D2, "play_fx_with_entity" },
    { 0x94D3, "play_fxlighting_fx" },
    { 0x94D4, "play_generic_react" },
    { 0x94D5, "play_gesture_reaction" },
    { 0x94D6, "play_gesture_reaction_anim" },
    { 0x94D7, "play_gesture_reaction_loop" },
    { 0x94D8, "play_gesture_reaction_set" },
    { 0x94D9, "play_get_on_heli_nags" },
    { 0x94DA, "play_giveup_after_time" },
    { 0x94DB, "play_grenade_reaction_dialog" },
    { 0x94DC, "play_group_acknowledgement" },
    { 0x94DD, "play_group_gesture_performance" },
    { 0x94DE, "play_group_gesture_reaction" },
    { 0x94DF, "play_group_looping_acknowledgements" },
    { 0x94E0, "play_group_single_anim_into_idle_anim" },
    { 0x94E1, "play_group_single_anim_into_kill" },
    { 0x94E2, "play_grunt" },
    { 0x94E3, "play_hack_alarms" },
    { 0x94E4, "play_hack_allieswin_vo" },
    { 0x94E5, "play_hack_fail_vo" },
    { 0x94E6, "play_hack_missed_vo" },
    { 0x94E7, "play_hack_progress_vo" },
    { 0x94E8, "play_hack_vo" },
    { 0x94E9, "play_hacking_started" },
    { 0x94EA, "play_hacking_vo_intro" },
    { 0x94EB, "play_hacks_interact_vo" },
    { 0x94EC, "play_hadir_stab_cheer" },
    { 0x94ED, "play_heli_scene" },
    { 0x94EE, "play_helicopter_vo" },
    { 0x94EF, "play_hostage_dead_vo" },
    { 0x94F0, "play_hostage_fulton_capture_vo" },
    { 0x94F1, "play_hostage_fulton_vo" },
    { 0x94F2, "play_house_explo" },
    { 0x94F3, "play_impact_fx_on_players" },
    { 0x94F4, "play_informant_vo_at_goal" },
    { 0x94F5, "play_intel_pickup_vo" },
    { 0x94F6, "play_interaction" },
    { 0x94F7, "play_interaction_anim" },
    { 0x94F8, "play_interaction_blended" },
    { 0x94F9, "play_interaction_endidle" },
    { 0x94FA, "play_interaction_gesture" },
    { 0x94FB, "play_interaction_immediate" },
    { 0x94FC, "play_interaction_simple" },
    { 0x94FD, "play_interaction_unknowntype" },
    { 0x94FE, "play_interaction_vo" },
    { 0x94FF, "play_interaction_with_states" },
    { 0x9500, "play_intro" },
    { 0x9501, "play_intro_animation" },
    { 0x9502, "play_intro_texts" },
    { 0x9503, "play_intro_vo" },
    { 0x9504, "play_intro2_vo" },
    { 0x9505, "play_investigation_done" },
    { 0x9506, "play_jammer_destroyed_vo" },
    { 0x9507, "play_jammer_returning_vo" },
    { 0x9508, "play_jet_look" },
    { 0x9509, "play_keys_intro_vo" },
    { 0x950A, "play_keys_vo" },
    { 0x950B, "play_kill_heli_nags" },
    { 0x950C, "play_laststand_scripted_anim" },
    { 0x950D, "play_light_fx_on_door" },
    { 0x950E, "play_line_and_rotate" },
    { 0x950F, "play_line_no_rotate" },
    { 0x9510, "play_lines_at_goal" },
    { 0x9511, "play_loop_sound_on_entity" },
    { 0x9512, "play_loop_sound_on_entity_with_pitch" },
    { 0x9513, "play_loop_sound_on_tag" },
    { 0x9514, "play_looping_acknowlegdements" },
    { 0x9515, "play_looping_breath_sound" },
    { 0x9516, "play_looping_skit_anim" },
    { 0x9517, "play_looping_sound_on_ent" },
    { 0x9518, "play_loopsound_in_space" },
    { 0x9519, "play_lost_health_vo" },
    { 0x951A, "play_mark_barrel_vo" },
    { 0x951B, "play_marker_vfx_on_enemy_players" },
    { 0x951C, "play_marker_vfx_on_friendly_player" },
    { 0x951D, "play_marker_vfx_on_friendly_players" },
    { 0x951E, "play_mask_remove" },
    { 0x951F, "play_mayhem_animation" },
    { 0x9520, "play_mhc_plane_escape_skit" },
    { 0x9521, "play_mission_complete" },
    { 0x9522, "play_mission_complete_vo" },
    { 0x9523, "play_mission_end_vo" },
    { 0x9524, "play_movie" },
    { 0x9525, "play_mp_sound" },
    { 0x9526, "play_multi_anim" },
    { 0x9527, "play_nag_hack_vo" },
    { 0x9528, "play_new_convoy_vo" },
    { 0x9529, "play_new_idle" },
    { 0x952A, "play_new_tread_vfx" },
    { 0x952B, "play_note_anim_vo" },
    { 0x952C, "play_origin" },
    { 0x952D, "play_out_intro" },
    { 0x952E, "play_outro_vo" },
    { 0x952F, "play_overwatch_vo" },
    { 0x9530, "play_pain_photo" },
    { 0x9531, "play_player_follow_truck" },
    { 0x9532, "play_projectile_nearby_dialog" },
    { 0x9533, "play_question_nag" },
    { 0x9534, "play_quick_reaction" },
    { 0x9535, "play_random_idles" },
    { 0x9536, "play_random_sound_in_space" },
    { 0x9537, "play_rappel_intro_anim" },
    { 0x9538, "play_reactive_fx" },
    { 0x9539, "play_reminder_anim_distance" },
    { 0x953A, "play_rescue_anim" },
    { 0x953B, "play_rescuer_nags" },
    { 0x953C, "play_rescuer_reaction01" },
    { 0x953D, "play_rescuer_reaction02" },
    { 0x953E, "play_revive_gesture" },
    { 0x953F, "play_running_anim" },
    { 0x9540, "play_running_anim_internal" },
    { 0x9541, "play_scene_safe" },
    { 0x9542, "play_scriptable_car_with_notetracks" },
    { 0x9543, "play_scripted_anim" },
    { 0x9544, "play_searched_buildings_vo" },
    { 0x9545, "play_searching_new_convoy_vo" },
    { 0x9546, "play_seat_animation" },
    { 0x9547, "play_seating_anim" },
    { 0x9548, "play_seating_anim_and_exit" },
    { 0x9549, "play_secure_barrel_vo" },
    { 0x954A, "play_shoot_tires_vo" },
    { 0x954B, "play_silent_acknowledgement" },
    { 0x954C, "play_single_acknowledgement" },
    { 0x954D, "play_single_anim" },
    { 0x954E, "play_single_anim_into_idle_anim" },
    { 0x954F, "play_single_anim_into_kill" },
    { 0x9550, "play_single_anim_last_frame" },
    { 0x9551, "play_single_anim_player" },
    { 0x9552, "play_single_anim_then_move_to" },
    { 0x9553, "play_single_skit_anim" },
    { 0x9554, "play_sitting_loop" },
    { 0x9555, "play_skippable_cinematic" },
    { 0x9556, "play_smart_basic_group_interaction" },
    { 0x9557, "play_smart_basic_interaction" },
    { 0x9558, "play_smart_dialog_if_exists" },
    { 0x9559, "play_smart_interaction" },
    { 0x955A, "play_smart_silent_interaction" },
    { 0x955B, "play_smart_simple_interaction" },
    { 0x955C, "play_smart_simple_silent_interaction" },
    { 0x955D, "play_smart_vo_interrupt" },
    { 0x955E, "play_smoke_start_sounds" },
    { 0x955F, "play_smoke_vfx_on_tires" },
    { 0x9560, "play_smoke_vfx_on_vehicle" },
    { 0x9561, "play_snd_on_tag" },
    { 0x9562, "play_sniper_glint_on_ambush_sniper" },
    { 0x9563, "play_solo_vo" },
    { 0x9564, "play_sound_at_viewheight" },
    { 0x9565, "play_sound_at_viewheightmp" },
    { 0x9566, "play_sound_in_space" },
    { 0x9567, "play_sound_in_space_no_combat" },
    { 0x9568, "play_sound_in_space_with_angles" },
    { 0x9569, "play_sound_on_entity" },
    { 0x956A, "play_sound_on_tag" },
    { 0x956B, "play_sound_on_tag_endon_death" },
    { 0x956C, "play_sound_safe" },
    { 0x956D, "play_spin_down_sfx" },
    { 0x956E, "play_spin_up_sfx" },
    { 0x956F, "play_spit" },
    { 0x9570, "play_spitter_pain_overlay" },
    { 0x9571, "play_start_hunting_vo" },
    { 0x9572, "play_state_based_interaction" },
    { 0x9573, "play_stealth_broken_vo" },
    { 0x9574, "play_stealth_vo" },
    { 0x9575, "play_stealth_vo_alias" },
    { 0x9576, "play_struct_fx" },
    { 0x9577, "play_tailgate_sfx" },
    { 0x9578, "play_takephoto_anim" },
    { 0x9579, "play_terrorist_respawn_music" },
    { 0x957A, "play_then_delete" },
    { 0x957B, "play_time_monitor" },
    { 0x957C, "play_timerstart_vo" },
    { 0x957D, "play_tread_vfx_think" },
    { 0x957E, "play_tree_animation" },
    { 0x957F, "play_tree_animation_internal" },
    { 0x9580, "play_truck_anim" },
    { 0x9581, "play_turbulence_fx" },
    { 0x9582, "play_vehicle_anim" },
    { 0x9583, "play_vfx_between_points_marked" },
    { 0x9584, "play_vfx_on_repair_part" },
    { 0x9585, "play_vo" },
    { 0x9586, "play_vo_bucket" },
    { 0x9587, "play_vo_bucket_looping" },
    { 0x9588, "play_vo_delay" },
    { 0x9589, "play_vo_for_trap_kills" },
    { 0x958A, "play_vo_line" },
    { 0x958B, "play_vo_line_delayed" },
    { 0x958C, "play_vo_on_all_players" },
    { 0x958D, "play_vo_on_intel_drop" },
    { 0x958E, "play_vo_on_player" },
    { 0x958F, "play_vo_on_stuff_pickup" },
    { 0x9590, "play_vo_system" },
    { 0x9591, "play_vo_to_all" },
    { 0x9592, "play_vo_to_player" },
    { 0x9593, "play_vo_when_near" },
    { 0x9594, "play_waitfor_ai_drop_vo" },
    { 0x9595, "play_weapon_purchase_vo" },
    { 0x9596, "play_win_vo" },
    { 0x9597, "play_wolf_vo_on_this_speaker" },
    { 0x9598, "play_wolf_vo_speaker_debug" },
    { 0x9599, "playac130infilanim" },
    { 0x959A, "playac130infilloopanims" },
    { 0x959B, "playaliasoverradio" },
    { 0x959C, "playanim" },
    { 0x959D, "playanim_arrival" },
    { 0x959E, "playanim_arrival_cleanup" },
    { 0x959F, "playanim_arrival_handlestandevent" },
    { 0x95A0, "playanim_arriveatvehicle" },
    { 0x95A1, "playanim_bark" },
    { 0x95A2, "playanim_bomberdeath" },
    { 0x95A3, "playanim_bombermoveloop" },
    { 0x95A4, "playanim_burning" },
    { 0x95A5, "playanim_deploylmg" },
    { 0x95A6, "playanim_deployturret" },
    { 0x95A7, "playanim_dismountlmg" },
    { 0x95A8, "playanim_dismountturret" },
    { 0x95A9, "playanim_droplmg" },
    { 0x95AA, "playanim_entervehicle" },
    { 0x95AB, "playanim_exit" },
    { 0x95AC, "playanim_exitvehicle" },
    { 0x95AD, "playanim_explode" },
    { 0x95AE, "playanim_flashed" },
    { 0x95AF, "playanim_flashed_internal" },
    { 0x95B0, "playanim_growltrack" },
    { 0x95B1, "playanim_headtrack" },
    { 0x95B2, "playanim_idle" },
    { 0x95B3, "playanim_monitorflashrestart" },
    { 0x95B4, "playanim_newenemyreaction" },
    { 0x95B5, "playanim_opendoor" },
    { 0x95B6, "playanim_patrolreact" },
    { 0x95B7, "playanim_patrolreact_internal" },
    { 0x95B8, "playanim_pushed" },
    { 0x95B9, "playanim_stairs" },
    { 0x95BA, "playanim_strafeaimchange" },
    { 0x95BB, "playanim_strafearrival" },
    { 0x95BC, "playanim_strafearrive" },
    { 0x95BD, "playanim_strafearrive_cleanup" },
    { 0x95BE, "playanim_strafereverse" },
    { 0x95BF, "playanim_strafereverse_donotetracks" },
    { 0x95C0, "playanim_strafestart" },
    { 0x95C1, "playanim_stumble" },
    { 0x95C2, "playanim_throwgrenade" },
    { 0x95C3, "playanim_throwgrenade_cleanup" },
    { 0x95C4, "playanim_vehicle" },
    { 0x95C5, "playanim_vehicledeath" },
    { 0x95C6, "playanim_vehicleidle" },
    { 0x95C7, "playanim_vehiclereload" },
    { 0x95C8, "playanim_waitforpathclear" },
    { 0x95C9, "playanim_waitforpathset" },
    { 0x95CA, "playanim_weaponswitch" },
    { 0x95CB, "playanim_zeroarrival" },
    { 0x95CC, "playanim_zeroarrival_cleanup" },
    { 0x95CD, "playanimandusegoalweight" },
    { 0x95CE, "playanimfortime" },
    { 0x95CF, "playanimnatratefortime" },
    { 0x95D0, "playanimnatrateuntilnotetrack" },
    { 0x95D1, "playanimnatrateuntilnotetrack_safe" },
    { 0x95D2, "playanimnfortime" },
    { 0x95D3, "playanimnuntilnotetrack" },
    { 0x95D4, "playanimnuntilnotetrack_safe" },
    { 0x95D5, "playanimnwithnotetracksfortime" },
    { 0x95D6, "playanimnwithnotetracksfortime_helper" },
    { 0x95D7, "playanimuntilnotetrack" },
    { 0x95D8, "playanimwithsound" },
    { 0x95D9, "playannouncerbattlechatter" },
    { 0x95DA, "playantigravcleanup" },
    { 0x95DB, "playantigravfall" },
    { 0x95DC, "playantigravfloatidle" },
    { 0x95DD, "playantigravrise" },
    { 0x95DE, "playbackendtime" },
    { 0x95DF, "playbackstarttime" },
    { 0x95E0, "playbalconydeathanim" },
    { 0x95E1, "playbattlechatter" },
    { 0x95E2, "playbcanim" },
    { 0x95E3, "playbeamfx" },
    { 0x95E4, "playcapturesound" },
    { 0x95E5, "playcoveranim" },
    { 0x95E6, "playcoveranim_droprpg" },
    { 0x95E7, "playcoveranim_gesture" },
    { 0x95E8, "playcoveranim_throwgrenade" },
    { 0x95E9, "playcoveranim_throwgrenade_cleanup" },
    { 0x95EA, "playcoveraniminternal" },
    { 0x95EB, "playcoveranimloop" },
    { 0x95EC, "playcoveranimloop3d" },
    { 0x95ED, "playcovercrouchlmg" },
    { 0x95EE, "playcoverpainanim" },
    { 0x95EF, "playcoverpainanimwithadditives" },
    { 0x95F0, "playcrawlflipover" },
    { 0x95F1, "playcrawlingpaintransition" },
    { 0x95F2, "playcreditlines" },
    { 0x95F3, "playcredits" },
    { 0x95F4, "playcustomevent" },
    { 0x95F5, "playdamageefx" },
    { 0x95F6, "playdeathanim" },
    { 0x95F7, "playdeathanim_melee_ragdolldelayed" },
    { 0x95F8, "playdeathfx" },
    { 0x95F9, "playdeathsound" },
    { 0x95FA, "playdeathsoundinlaststand" },
    { 0x95FB, "playdeatomizefx" },
    { 0x95FC, "playdlightfx" },
    { 0x95FD, "playdoublejumpfinishanim" },
    { 0x95FE, "playdoublejumpmantle" },
    { 0x95FF, "playdoublejumpmantleorvault" },
    { 0x9600, "playdoublejumptraversal" },
    { 0x9601, "playdoublejumpvault" },
    { 0x9602, "playdyingbackidle" },
    { 0x9603, "playdyingbackshoot" },
    { 0x9604, "playdyingcrawl" },
    { 0x9605, "playdyingcrawlback" },
    { 0x9606, "played" },
    { 0x9607, "played_convoy_vo" },
    { 0x9608, "playedmatchendingsoon" },
    { 0x9609, "playedstartingmusic" },
    { 0x960A, "playendofmatchtransition" },
    { 0x960B, "playepicbroshotsound" },
    { 0x960C, "player_action_disabled" },
    { 0x960D, "player_adsed" },
    { 0x960E, "player_adsed_monitor" },
    { 0x960F, "player_ai_fill" },
    { 0x9610, "player_aim_at_think" },
    { 0x9611, "player_aim_target" },
    { 0x9612, "player_aiming_at" },
    { 0x9613, "player_aiming_at_2d" },
    { 0x9614, "player_aimingtowardsenemy" },
    { 0x9615, "player_allyfriendnamelogic" },
    { 0x9616, "player_anims" },
    { 0x9617, "player_apply_local_view_position" },
    { 0x9618, "player_apply_local_view_rotation" },
    { 0x9619, "player_apply_local_weap_position" },
    { 0x961A, "player_apply_local_weap_rotation" },
    { 0x961B, "player_approach_tunnel" },
    { 0x961C, "player_attacker_accuracy" },
    { 0x961D, "player_attempt_say_foundlead" },
    { 0x961E, "player_battlechatter_check_for_crate_pickups" },
    { 0x961F, "player_battlechatter_cooldown_control" },
    { 0x9620, "player_battlechatter_event_clear" },
    { 0x9621, "player_battlechatter_generic_event_check" },
    { 0x9622, "player_battlechatter_off" },
    { 0x9623, "player_battlechatter_off_thread" },
    { 0x9624, "player_battlechatter_on" },
    { 0x9625, "player_battlechatter_on_thread" },
    { 0x9626, "player_bedroom_clear_handler" },
    { 0x9627, "player_behind_hadir_watcher" },
    { 0x9628, "player_behind_tank_think" },
    { 0x9629, "player_behind_tank_think_internal" },
    { 0x962A, "player_being_tracked_in_stealth" },
    { 0x962B, "player_best_time" },
    { 0x962C, "player_black_screen" },
    { 0x962D, "player_bleed_out_func" },
    { 0x962E, "player_bob_scale_set" },
    { 0x962F, "player_body" },
    { 0x9630, "player_bomb_init" },
    { 0x9631, "player_breath_context" },
    { 0x9632, "player_bump_management" },
    { 0x9633, "player_burn_death_overlay" },
    { 0x9634, "player_button_press_think" },
    { 0x9635, "player_call_out_ceiling_guy_on_damage" },
    { 0x9636, "player_cam_enable" },
    { 0x9637, "player_camera_moving_logic" },
    { 0x9638, "player_can_see_ai" },
    { 0x9639, "player_can_see_an_enemy" },
    { 0x963A, "player_can_see_p_ent" },
    { 0x963B, "player_can_take_sniper_damage" },
    { 0x963C, "player_cansee_buddy_down_flashed" },
    { 0x963D, "player_car_enter" },
    { 0x963E, "player_carried_anim" },
    { 0x963F, "player_carrydebuff" },
    { 0x9640, "player_casualty_vo" },
    { 0x9641, "player_character_index" },
    { 0x9642, "player_character_info" },
    { 0x9643, "player_character_num" },
    { 0x9644, "player_cinderblockcreateinteract" },
    { 0x9645, "player_cinderblockdropaudiologic" },
    { 0x9646, "player_cinderblockdroplogic" },
    { 0x9647, "player_cinderblockgetpickups" },
    { 0x9648, "player_cinderblockgive" },
    { 0x9649, "player_cinderblockinit" },
    { 0x964A, "player_cinderblockinteractdisplaylogic" },
    { 0x964B, "player_cinderblockkillinteractlogic" },
    { 0x964C, "player_cinderblockladderlogic" },
    { 0x964D, "player_cinderblockplayerpickuplogic" },
    { 0x964E, "player_cinematic_motion_override" },
    { 0x964F, "player_cinematic_swap" },
    { 0x9650, "player_cleanupongameended" },
    { 0x9651, "player_cleanuponteamchange" },
    { 0x9652, "player_clear_armory_nag" },
    { 0x9653, "player_clear_of_truck_watcher" },
    { 0x9654, "player_clear_pass_target" },
    { 0x9655, "player_clear_truck_nag" },
    { 0x9656, "player_clip" },
    { 0x9657, "player_clip_thread" },
    { 0x9658, "player_color_node" },
    { 0x9659, "player_connect_monitor" },
    { 0x965A, "player_controller_push_along_vehicle" },
    { 0x965B, "player_count" },
    { 0x965C, "player_count_left" },
    { 0x965D, "player_covertrigger" },
    { 0x965E, "player_covertype" },
    { 0x965F, "player_crouched" },
    { 0x9660, "player_damage_based_on_dist" },
    { 0x9661, "player_damage_thread" },
    { 0x9662, "player_death_animation_enabled" },
    { 0x9663, "player_death_override" },
    { 0x9664, "player_death_refs" },
    { 0x9665, "player_defuse_anim" },
    { 0x9666, "player_delete_ball_goal_fx" },
    { 0x9667, "player_delete_flag_goal_fx" },
    { 0x9668, "player_demeanor_monitor" },
    { 0x9669, "player_dialogue" },
    { 0x966A, "player_dialogue_clear_stack" },
    { 0x966B, "player_dialogue_emitter" },
    { 0x966C, "player_dialogue_gesture" },
    { 0x966D, "player_dialogue_interrupt" },
    { 0x966E, "player_dialogue_stop" },
    { 0x966F, "player_dialogue_struct" },
    { 0x9670, "player_did_slide" },
    { 0x9671, "player_die_from_smoke_inhalation" },
    { 0x9672, "player_die_from_smoke_inhalation_thread" },
    { 0x9673, "player_died_during_course" },
    { 0x9674, "player_died_recently" },
    { 0x9675, "player_died_recently_degrades" },
    { 0x9676, "player_disconnect" },
    { 0x9677, "player_disguisebottomanimatelogic" },
    { 0x9678, "player_disguiseon" },
    { 0x9679, "player_disguisetopanimatelogic" },
    { 0x967A, "player_dist_check" },
    { 0x967B, "player_do_black_screen" },
    { 0x967C, "player_dodronecooldown" },
    { 0x967D, "player_doesweapondrawallynames" },
    { 0x967E, "player_door_gesture" },
    { 0x967F, "player_door_wedge" },
    { 0x9680, "player_drivingtank" },
    { 0x9681, "player_drone_damage" },
    { 0x9682, "player_dronecancellogic" },
    { 0x9683, "player_dronecleanuplogic" },
    { 0x9684, "player_dronecontrollogic" },
    { 0x9685, "player_dronecontrolmanager" },
    { 0x9686, "player_dronecooldown" },
    { 0x9687, "player_dronedebugenabled" },
    { 0x9688, "player_dronedebugline" },
    { 0x9689, "player_dronegetstartstructs" },
    { 0x968A, "player_droneinit" },
    { 0x968B, "player_dronelogic" },
    { 0x968C, "player_dronemodel" },
    { 0x968D, "player_dronespawn" },
    { 0x968E, "player_dronespawnlogic" },
    { 0x968F, "player_dronespawnoverlaycancellogic" },
    { 0x9690, "player_droneusenags" },
    { 0x9691, "player_droneusereminder" },
    { 0x9692, "player_dronevisionsetfade" },
    { 0x9693, "player_drop_to_ground" },
    { 0x9694, "player_dropballisticsweaponinteractlogic" },
    { 0x9695, "player_dropballisticsweaponlogic" },
    { 0x9696, "player_early_shot_watcher" },
    { 0x9697, "player_end_death_logic" },
    { 0x9698, "player_enter_ambush_sniper_fire_sequence" },
    { 0x9699, "player_enters_poolhouse" },
    { 0x969A, "player_equip_nvg" },
    { 0x969B, "player_exfil_think" },
    { 0x969C, "player_exit_ambush_sniper_fire_sequence" },
    { 0x969D, "player_exit_deathsdoor" },
    { 0x969E, "player_exit_monitor" },
    { 0x969F, "player_expose_to_sniper_long_enough" },
    { 0x96A0, "player_exposure_data" },
    { 0x96A1, "player_failed_context_melee" },
    { 0x96A2, "player_fell_watcher" },
    { 0x96A3, "player_fire_check" },
    { 0x96A4, "player_fire_thread" },
    { 0x96A5, "player_fired" },
    { 0x96A6, "player_fired_recently_delay" },
    { 0x96A7, "player_flarecanloopgesture" },
    { 0x96A8, "player_flarecanthrow" },
    { 0x96A9, "player_flarecantimeout" },
    { 0x96AA, "player_flarecanturnoff" },
    { 0x96AB, "player_flarecanuse" },
    { 0x96AC, "player_flareconditionalpickup" },
    { 0x96AD, "player_flaregetautomaticignitehint" },
    { 0x96AE, "player_flaregetofftriggers" },
    { 0x96AF, "player_flaregetremainingtime" },
    { 0x96B0, "player_flaregive" },
    { 0x96B1, "player_flarehidemodellogic" },
    { 0x96B2, "player_flareloopgesturelogic" },
    { 0x96B3, "player_flareofftriggerlogic" },
    { 0x96B4, "player_flarepickuplogic" },
    { 0x96B5, "player_flarepickupsingle" },
    { 0x96B6, "player_flaresetammo" },
    { 0x96B7, "player_flaresetautomaticignitehint" },
    { 0x96B8, "player_flaresetcanthrow" },
    { 0x96B9, "player_flaresetcantimeout" },
    { 0x96BA, "player_flaresetcanturnoff" },
    { 0x96BB, "player_flaresetcanuse" },
    { 0x96BC, "player_flaresetremainingtime" },
    { 0x96BD, "player_flareshouldhidemodel" },
    { 0x96BE, "player_flarestealthdetectlogic" },
    { 0x96BF, "player_flaretake" },
    { 0x96C0, "player_flarethrow" },
    { 0x96C1, "player_flaretimeout" },
    { 0x96C2, "player_flaretogglelogic" },
    { 0x96C3, "player_flareturnoff" },
    { 0x96C4, "player_flareturnon" },
    { 0x96C5, "player_flareturnvfxoff" },
    { 0x96C6, "player_flareturnvfxon" },
    { 0x96C7, "player_flashlight_maxvis_hack" },
    { 0x96C8, "player_focus_counter" },
    { 0x96C9, "player_found_a_weapon" },
    { 0x96CA, "player_fov_80_instant" },
    { 0x96CB, "player_fov_change" },
    { 0x96CC, "player_fov_default_2" },
    { 0x96CD, "player_fov_think" },
    { 0x96CE, "player_free_look" },
    { 0x96CF, "player_free_spot" },
    { 0x96D0, "player_friendlyfire_addreactionevent" },
    { 0x96D1, "player_friendlyfire_waiter" },
    { 0x96D2, "player_friendlyfire_waiter_damage" },
    { 0x96D3, "player_friendlyfirecheckpoints" },
    { 0x96D4, "player_fullads" },
    { 0x96D5, "player_fulton_sounds" },
    { 0x96D6, "player_gas_mask" },
    { 0x96D7, "player_gesture_cellphone_call" },
    { 0x96D8, "player_gesture_cellphone_show" },
    { 0x96D9, "player_gesture_combat" },
    { 0x96DA, "player_gesture_force" },
    { 0x96DB, "player_gesture_noncombat" },
    { 0x96DC, "player_gestures_input_disable" },
    { 0x96DD, "player_gestures_input_enable" },
    { 0x96DE, "player_gestures_prone_getup_think" },
    { 0x96DF, "player_get_closest_point" },
    { 0x96E0, "player_get_closest_point_static" },
    { 0x96E1, "player_getballisticsweaponobject" },
    { 0x96E2, "player_getclosestsilencedweapon" },
    { 0x96E3, "player_getdroppedsniper" },
    { 0x96E4, "player_getflag" },
    { 0x96E5, "player_getflareammo" },
    { 0x96E6, "player_getflareweapons" },
    { 0x96E7, "player_getmaxflareammo" },
    { 0x96E8, "player_getoffhandsecondaryweaponobject" },
    { 0x96E9, "player_getout" },
    { 0x96EA, "player_getout_sound" },
    { 0x96EB, "player_getout_sound_end" },
    { 0x96EC, "player_getout_sound_loop" },
    { 0x96ED, "player_getpistolweaponobject" },
    { 0x96EE, "player_getprimaryweaponname" },
    { 0x96EF, "player_getprimaryweaponobject" },
    { 0x96F0, "player_getrig" },
    { 0x96F1, "player_getsecondaryweaponobject" },
    { 0x96F2, "player_getsilencedpistolweaponobject" },
    { 0x96F3, "player_gettouchingtownrooftoptrigger" },
    { 0x96F4, "player_give_gg_loadout" },
    { 0x96F5, "player_give_gunless_loadout" },
    { 0x96F6, "player_giveachievement_wrapper" },
    { 0x96F7, "player_giveballisticsweapon" },
    { 0x96F8, "player_givefullloadout" },
    { 0x96F9, "player_givegunlessweapon" },
    { 0x96FA, "player_giveholsteredloadout" },
    { 0x96FB, "player_givemolotovweapon" },
    { 0x96FC, "player_givepistolloadout" },
    { 0x96FD, "player_giveprimaryoffhandweapon" },
    { 0x96FE, "player_giveprimaryweapon" },
    { 0x96FF, "player_giverpgweapon" },
    { 0x9700, "player_givesecondaryoffhandweapon" },
    { 0x9701, "player_givesecondaryweapon" },
    { 0x9702, "player_givesecondaryweaponloadout" },
    { 0x9703, "player_givesilencedpistolloadout" },
    { 0x9704, "player_givesilencedsecondaryweaponloadout" },
    { 0x9705, "player_glance" },
    { 0x9706, "player_going_loud" },
    { 0x9707, "player_gone_hot_think" },
    { 0x9708, "player_got_dad_dies_save" },
    { 0x9709, "player_grabs_hostage" },
    { 0x970A, "player_grace_period" },
    { 0x970B, "player_green_beam" },
    { 0x970C, "player_grenade_check" },
    { 0x970D, "player_grenade_check_dieout" },
    { 0x970E, "player_grenade_fire_thread" },
    { 0x970F, "player_grenade_killed_civ" },
    { 0x9710, "player_guardsalertedspeedlogic" },
    { 0x9711, "player_gun_pickup" },
    { 0x9712, "player_has_base_weapon" },
    { 0x9713, "player_has_enough_currency" },
    { 0x9714, "player_has_equipment" },
    { 0x9715, "player_has_pistol" },
    { 0x9716, "player_has_silencer" },
    { 0x9717, "player_has_special_ammo" },
    { 0x9718, "player_has_unlocked_stored_equipment_slots" },
    { 0x9719, "player_has_weapon" },
    { 0x971A, "player_hasflareequipment" },
    { 0x971B, "player_hassilencedweapon" },
    { 0x971C, "player_have_armor" },
    { 0x971D, "player_have_full_armor" },
    { 0x971E, "player_health_difficulty_thread" },
    { 0x971F, "player_health_packets" },
    { 0x9720, "player_heartbeat" },
    { 0x9721, "player_heli" },
    { 0x9722, "player_hit_watcher" },
    { 0x9723, "player_holding_flare_only" },
    { 0x9724, "player_holdingballisticsweapon" },
    { 0x9725, "player_holdingcinderblockweapon" },
    { 0x9726, "player_holdingemptyweapon" },
    { 0x9727, "player_holdingholsteredweapon" },
    { 0x9728, "player_holdingpistolweapon" },
    { 0x9729, "player_holdingsilencedweapon" },
    { 0x972A, "player_holsterweaponcleanupweaponswitch" },
    { 0x972B, "player_holsterweaponlogic" },
    { 0x972C, "player_hotjoin" },
    { 0x972D, "player_humvee" },
    { 0x972E, "player_humvee_is_within_combar_range" },
    { 0x972F, "player_humvee_speed" },
    { 0x9730, "player_humvee_withn_explosion_range" },
    { 0x9731, "player_idle" },
    { 0x9732, "player_impulse_from_origin" },
    { 0x9733, "player_in_area_check" },
    { 0x9734, "player_in_armory_watcher" },
    { 0x9735, "player_in_b1_watcher" },
    { 0x9736, "player_in_concealment_area" },
    { 0x9737, "player_in_intercept_mode" },
    { 0x9738, "player_in_laststand" },
    { 0x9739, "player_in_party" },
    { 0x973A, "player_in_region" },
    { 0x973B, "player_in_safehouse" },
    { 0x973C, "player_in_trigger" },
    { 0x973D, "player_in_vehicle" },
    { 0x973E, "player_in_zerog" },
    { 0x973F, "player_infil_end" },
    { 0x9740, "player_info" },
    { 0x9741, "player_init" },
    { 0x9742, "player_init_damageshield" },
    { 0x9743, "player_init_func" },
    { 0x9744, "player_init_health_regen" },
    { 0x9745, "player_init_invulnerability" },
    { 0x9746, "player_init_laststand_func" },
    { 0x9747, "player_input_watcher" },
    { 0x9748, "player_interacted_on_body" },
    { 0x9749, "player_interaction_monitor" },
    { 0x974A, "player_interaction_weapon_switch_monitor" },
    { 0x974B, "player_interactive_think" },
    { 0x974C, "player_interrogation_speed_setup" },
    { 0x974D, "player_intro_speed" },
    { 0x974E, "player_intro_speed_lerp" },
    { 0x974F, "player_is_ahead_of_me" },
    { 0x9750, "player_is_aiming_at_bus_scene" },
    { 0x9751, "player_is_aiming_with_rocket" },
    { 0x9752, "player_is_close_watcher" },
    { 0x9753, "player_is_exposed_to_sniper" },
    { 0x9754, "player_is_facing_away_from_vehicle_to_push" },
    { 0x9755, "player_is_facing_vehicle_to_push" },
    { 0x9756, "player_is_good_missile_target" },
    { 0x9757, "player_is_in_jackal" },
    { 0x9758, "player_is_in_killzone" },
    { 0x9759, "player_is_kidnapper" },
    { 0x975A, "player_is_near_live_offhand" },
    { 0x975B, "player_is_near_vehicle_to_push" },
    { 0x975C, "player_is_outofbounds" },
    { 0x975D, "player_is_safe_from_smoke" },
    { 0x975E, "player_is_sniping" },
    { 0x975F, "player_is_sprinting_at_me" },
    { 0x9760, "player_is_suicide_bomber" },
    { 0x9761, "player_is_terrorist" },
    { 0x9762, "player_is_terrorist_func" },
    { 0x9763, "player_is_trying_to_exit_camera" },
    { 0x9764, "player_is_trying_to_shoot_me" },
    { 0x9765, "player_is_trying_to_snipe_me" },
    { 0x9766, "player_isdriving" },
    { 0x9767, "player_isenemyturretinproximity" },
    { 0x9768, "player_isenemyturretnotinproximity" },
    { 0x9769, "player_isholdingspecialflareweapon" },
    { 0x976A, "player_isholsterallowed" },
    { 0x976B, "player_isprone" },
    { 0x976C, "player_jackal" },
    { 0x976D, "player_join_infil" },
    { 0x976E, "player_join_infil_cp" },
    { 0x976F, "player_joined_update_pass_target_hudoutline" },
    { 0x9770, "player_jugg_fight" },
    { 0x9771, "player_kill_triggers" },
    { 0x9772, "player_ladder_aid" },
    { 0x9773, "player_ladder_ease" },
    { 0x9774, "player_ladder_pistol" },
    { 0x9775, "player_last_death_pos" },
    { 0x9776, "player_launch_mortar" },
    { 0x9777, "player_lb" },
    { 0x9778, "player_lbravo_infil_think" },
    { 0x9779, "player_leaves_house_early" },
    { 0x977A, "player_leaves_volume_watcher" },
    { 0x977B, "player_legs" },
    { 0x977C, "player_limp" },
    { 0x977D, "player_limp_step" },
    { 0x977E, "player_listen_for_exfil" },
    { 0x977F, "player_loadout" },
    { 0x9780, "player_lock_look_1_second" },
    { 0x9781, "player_lock_look_2_second" },
    { 0x9782, "player_lock_look_instant" },
    { 0x9783, "player_looking_at" },
    { 0x9784, "player_looking_at_wire_think" },
    { 0x9785, "player_looking_away_from_mayhem_watcher" },
    { 0x9786, "player_looking_down_street_watcher" },
    { 0x9787, "player_lua_progressbar" },
    { 0x9788, "player_magic_speed" },
    { 0x9789, "player_maintainmaxweaponcountlogic" },
    { 0x978A, "player_mi8_infil_think" },
    { 0x978B, "player_monitor" },
    { 0x978C, "player_monitor_death" },
    { 0x978D, "player_most_recently_saw" },
    { 0x978E, "player_movement_state" },
    { 0x978F, "player_mover_clean_up_monitor" },
    { 0x9790, "player_moves" },
    { 0x9791, "player_movespeed" },
    { 0x9792, "player_moving_camera" },
    { 0x9793, "player_moving_respawn_camera" },
    { 0x9794, "player_moving_toward" },
    { 0x9795, "player_nades" },
    { 0x9796, "player_name_called_recently" },
    { 0x9797, "player_nearby_listener" },
    { 0x9798, "player_no_pickup_time" },
    { 0x9799, "player_normal_think" },
    { 0x979A, "player_notes_1f_civs" },
    { 0x979B, "player_notholdingcinderblockweapon" },
    { 0x979C, "player_notholdingholsteredweapon" },
    { 0x979D, "player_num_start_frac" },
    { 0x979E, "player_nvg_off" },
    { 0x979F, "player_nvg_on" },
    { 0x97A0, "player_nvg_watcher" },
    { 0x97A1, "player_nvgon" },
    { 0x97A2, "player_offhand_empty" },
    { 0x97A3, "player_offkitchenladder" },
    { 0x97A4, "player_on_armory" },
    { 0x97A5, "player_on_disconnect" },
    { 0x97A6, "player_on_fast_rope" },
    { 0x97A7, "player_on_ladder_flag" },
    { 0x97A8, "player_on_ladder_hack" },
    { 0x97A9, "player_on_spot" },
    { 0x97AA, "player_onkitchenladder" },
    { 0x97AB, "player_ontownrooftop" },
    { 0x97AC, "player_open_door_monitor" },
    { 0x97AD, "player_open_dynamic_door_monitor" },
    { 0x97AE, "player_open_scriptable_door_monitor" },
    { 0x97AF, "player_overlay" },
    { 0x97B0, "player_pain_breathing_sfx" },
    { 0x97B1, "player_pain_vo" },
    { 0x97B2, "player_pauseallowdrones" },
    { 0x97B3, "player_persistence_init" },
    { 0x97B4, "player_phone_pickup_anim" },
    { 0x97B5, "player_picked_team" },
    { 0x97B6, "player_picks_up_detonator" },
    { 0x97B7, "player_pickup_bomb" },
    { 0x97B8, "player_pickupweaponlogic" },
    { 0x97B9, "player_ping_callback" },
    { 0x97BA, "player_pistol_damage_func" },
    { 0x97BB, "player_pistolassigntritiumsights" },
    { 0x97BC, "player_play_anime_into_idle" },
    { 0x97BD, "player_play_response" },
    { 0x97BE, "player_post_escort_setup" },
    { 0x97BF, "player_post_getup" },
    { 0x97C0, "player_progress_market_think" },
    { 0x97C1, "player_progress_trigger_think" },
    { 0x97C2, "player_prone_slide_dirt_fx" },
    { 0x97C3, "player_push_monitor" },
    { 0x97C4, "player_push_vehicle_stance_update_think" },
    { 0x97C5, "player_pushed_kill" },
    { 0x97C6, "player_pushes_mortar_house_early" },
    { 0x97C7, "player_pushing_house_watcher" },
    { 0x97C8, "player_putgasmaskon" },
    { 0x97C9, "player_queue" },
    { 0x97CA, "player_radio_emitter" },
    { 0x97CB, "player_rappel_disconnect" },
    { 0x97CC, "player_rappel_hackney_infil_think" },
    { 0x97CD, "player_rappel_sound_loop_off" },
    { 0x97CE, "player_rappel_sound_loop_on" },
    { 0x97CF, "player_rappel_weapon_switch" },
    { 0x97D0, "player_reacted_to_civ" },
    { 0x97D1, "player_refillammo" },
    { 0x97D2, "player_refillsinglecountammo" },
    { 0x97D3, "player_regroup" },
    { 0x97D4, "player_relative_offset" },
    { 0x97D5, "player_relative_offset_accel" },
    { 0x97D6, "player_removecarrydebuff" },
    { 0x97D7, "player_restoreweapons" },
    { 0x97D8, "player_resumeallowdrones" },
    { 0x97D9, "player_revived_or_dead" },
    { 0x97DA, "player_rig" },
    { 0x97DB, "player_rig_allow_internal" },
    { 0x97DC, "player_rig_allow_weapon" },
    { 0x97DD, "player_rig_end_scene_setup" },
    { 0x97DE, "player_rig_shadow" },
    { 0x97DF, "player_rig_standup_fov_user_scale" },
    { 0x97E0, "player_rig_visible" },
    { 0x97E1, "player_riganimationstopondeath" },
    { 0x97E2, "player_rigenter" },
    { 0x97E3, "player_rigenterabsolute" },
    { 0x97E4, "player_rigexit" },
    { 0x97E5, "player_roe_check" },
    { 0x97E6, "player_role_monitor" },
    { 0x97E7, "player_roof_mortars" },
    { 0x97E8, "player_run_pent_updates" },
    { 0x97E9, "player_runby_monitor" },
    { 0x97EA, "player_runs_out_watcher" },
    { 0x97EB, "player_rush_think" },
    { 0x97EC, "player_safe" },
    { 0x97ED, "player_safe_from_enemy_proximity" },
    { 0x97EE, "player_safe_from_poi_los" },
    { 0x97EF, "player_saw_kill" },
    { 0x97F0, "player_say_clear" },
    { 0x97F1, "player_scr_anim" },
    { 0x97F2, "player_scr_animname" },
    { 0x97F3, "player_scr_eventanim" },
    { 0x97F4, "player_scr_viewmodelanim" },
    { 0x97F5, "player_see_me_monitor" },
    { 0x97F6, "player_seek_disable" },
    { 0x97F7, "player_seek_enable" },
    { 0x97F8, "player_seen_pos" },
    { 0x97F9, "player_sees_hvt" },
    { 0x97FA, "player_sees_hvt_timeout" },
    { 0x97FB, "player_sees_my_location" },
    { 0x97FC, "player_sees_my_scope" },
    { 0x97FD, "player_sees_spawner" },
    { 0x97FE, "player_selected_team_in_front_end" },
    { 0x97FF, "player_set_pass_target" },
    { 0x9800, "player_setflag" },
    { 0x9801, "player_setflareequipment" },
    { 0x9802, "player_setholsterallowed" },
    { 0x9803, "player_setup" },
    { 0x9804, "player_shining_light_at" },
    { 0x9805, "player_shoot_boss" },
    { 0x9806, "player_shooting_murderhole_monitor" },
    { 0x9807, "player_shooting_murderholes_monitor" },
    { 0x9808, "player_shot_monitor" },
    { 0x9809, "player_should_be_killed_by_mover" },
    { 0x980A, "player_slamzoom" },
    { 0x980B, "player_smoke_death_time" },
    { 0x980C, "player_smoke_exposure" },
    { 0x980D, "player_smoke_vision" },
    { 0x980E, "player_sniper_bullet_impact_vfx" },
    { 0x980F, "player_sniperzoomedin" },
    { 0x9810, "player_sniping_threatbisas" },
    { 0x9811, "player_spawnrig" },
    { 0x9812, "player_speed" },
    { 0x9813, "player_speed_default" },
    { 0x9814, "player_speed_hud" },
    { 0x9815, "player_speed_lerp" },
    { 0x9816, "player_speed_management_ending" },
    { 0x9817, "player_speed_management_intro" },
    { 0x9818, "player_speed_percent" },
    { 0x9819, "player_speed_post_bomb" },
    { 0x981A, "player_speed_proc" },
    { 0x981B, "player_speed_set" },
    { 0x981C, "player_spotted_thread" },
    { 0x981D, "player_stabbed_boss" },
    { 0x981E, "player_stancecrouching" },
    { 0x981F, "player_stanceprone" },
    { 0x9820, "player_startallowdrones" },
    { 0x9821, "player_startpronehack" },
    { 0x9822, "player_stay_behind_ai" },
    { 0x9823, "player_stayahead_enemy_behavior" },
    { 0x9824, "player_stealth_kill_direction" },
    { 0x9825, "player_stopallowdrones" },
    { 0x9826, "player_struct" },
    { 0x9827, "player_suit" },
    { 0x9828, "player_swapped_weapon" },
    { 0x9829, "player_take_cellphone" },
    { 0x982A, "player_takeawaygunlessweapon" },
    { 0x982B, "player_tango72_infil_think" },
    { 0x982C, "player_target" },
    { 0x982D, "player_temp_invul" },
    { 0x982E, "player_threw_grenade" },
    { 0x982F, "player_threw_offhand" },
    { 0x9830, "player_throwgrenade_timer" },
    { 0x9831, "player_throwinggrenade" },
    { 0x9832, "player_throwingmolotov" },
    { 0x9833, "player_tired_movement" },
    { 0x9834, "player_trace" },
    { 0x9835, "player_trace_get_all_results" },
    { 0x9836, "player_trace_passed" },
    { 0x9837, "player_trackadsfullout" },
    { 0x9838, "player_trackdronekills" },
    { 0x9839, "player_trackvariablezoom" },
    { 0x983A, "player_tried" },
    { 0x983B, "player_tries_to_take_water" },
    { 0x983C, "player_trying_to_join_infil_monitor" },
    { 0x983D, "player_tunnel_explosion_experience" },
    { 0x983E, "player_tunnel_explosion_watch" },
    { 0x983F, "player_umike_infil_think" },
    { 0x9840, "player_under_low_cover_monitor" },
    { 0x9841, "player_underbarrel_grenade_launcher_equipped_monitor" },
    { 0x9842, "player_underbarrel_grenade_launcher_used_monitor" },
    { 0x9843, "player_unlink" },
    { 0x9844, "player_unresolved_collision_watch" },
    { 0x9845, "player_update_allowed_callouts" },
    { 0x9846, "player_update_pass_target" },
    { 0x9847, "player_update_pass_target_hudoutline" },
    { 0x9848, "player_update_unresolved_collision" },
    { 0x9849, "player_use_turret_watcher" },
    { 0x984A, "player_used_fulton_recently" },
    { 0x984B, "player_usedrone" },
    { 0x984C, "player_using_flash" },
    { 0x984D, "player_using_molotov" },
    { 0x984E, "player_using_sniper_rifle" },
    { 0x984F, "player_using_staircase_monitor" },
    { 0x9850, "player_usingflare" },
    { 0x9851, "player_usingprimaryweaponaltmode" },
    { 0x9852, "player_van_disconnect" },
    { 0x9853, "player_van_hackney_infil_think" },
    { 0x9854, "player_vehicle" },
    { 0x9855, "player_vehicle_sound" },
    { 0x9856, "player_vehicle_spawner" },
    { 0x9857, "player_view" },
    { 0x9858, "player_view_blur" },
    { 0x9859, "player_view_lerp_clamp" },
    { 0x985A, "player_view_trace" },
    { 0x985B, "player_vindia_infil_think" },
    { 0x985C, "player_vo_playing" },
    { 0x985D, "player_waitdronecooldown" },
    { 0x985E, "player_waittill_alive" },
    { 0x985F, "player_waittill_player_death" },
    { 0x9860, "player_waittillholstered" },
    { 0x9861, "player_waittilllookingatai" },
    { 0x9862, "player_waittillmaxhealth" },
    { 0x9863, "player_waittillnearai" },
    { 0x9864, "player_waittillusingflare" },
    { 0x9865, "player_wander_fail" },
    { 0x9866, "player_wander_fail_handler" },
    { 0x9867, "player_wander_fail_manager" },
    { 0x9868, "player_wander_nag" },
    { 0x9869, "player_wander_nag_manager" },
    { 0x986A, "player_wander_struct" },
    { 0x986B, "player_warn_trigger" },
    { 0x986C, "player_weapon_class" },
    { 0x986D, "player_weapon_holstered" },
    { 0x986E, "player_weapon_holstered_door_bash_monitor" },
    { 0x986F, "player_weapon_listener" },
    { 0x9870, "player_weaponchangelogic" },
    { 0x9871, "player_weaponfire_watcher" },
    { 0x9872, "player_weaponisspecialflareweapon" },
    { 0x9873, "player_weapons" },
    { 0x9874, "player_weaponstats_track_shots" },
    { 0x9875, "player_who_tagged" },
    { 0x9876, "player_window_gesture" },
    { 0x9877, "player_wire_cutting_think" },
    { 0x9878, "player_zoomedin" },
    { 0x9879, "player_zoomedout" },
    { 0x987A, "player_zoomingsniper" },
    { 0x987B, "playerac130cleanup" },
    { 0x987C, "playeraccessinglaptops" },
    { 0x987D, "playeraddjailbreaktimer" },
    { 0x987E, "playeraddtoplundercount" },
    { 0x987F, "playeraffectedarray" },
    { 0x9880, "playerallowedtriggers" },
    { 0x9881, "playeraltweapon" },
    { 0x9882, "playeranimlinktochopper" },
    { 0x9883, "playeranimlooping" },
    { 0x9884, "playeranimnameswitch" },
    { 0x9885, "playeranimsingle" },
    { 0x9886, "playerarmor" },
    { 0x9887, "playerarmorenabled" },
    { 0x9888, "playerattackedmonitor" },
    { 0x9889, "playerautodeployaftertime" },
    { 0x988A, "playerballoondeposit" },
    { 0x988B, "playerbankplunder" },
    { 0x988C, "playerbeton" },
    { 0x988D, "playerbreathingbettersound" },
    { 0x988E, "playerbreathingpainsound" },
    { 0x988F, "playerbullets" },
    { 0x9890, "playercanautopickupaxe" },
    { 0x9891, "playercancellation" },
    { 0x9892, "playercanpickupkillstreak" },
    { 0x9893, "playercanseecircle" },
    { 0x9894, "playercanusearmorvest" },
    { 0x9895, "playercanusetags" },
    { 0x9896, "playerclearcallback" },
    { 0x9897, "playerclockdirection" },
    { 0x9898, "playerconnectedevents" },
    { 0x9899, "playercontrolled" },
    { 0x989A, "playercontrolledmodel" },
    { 0x989B, "playercontrolledstreak" },
    { 0x989C, "playercounterpress" },
    { 0x989D, "playercrouchmovedist" },
    { 0x989E, "playercustomizationdata" },
    { 0x989F, "playerdamaged" },
    { 0x98A0, "playerdamagemain" },
    { 0x98A1, "playerdamagewaiter" },
    { 0x98A2, "playerdead" },
    { 0x98A3, "playerdeath" },
    { 0x98A4, "playerdeathangles" },
    { 0x98A5, "playerdelayautobankplunder" },
    { 0x98A6, "playerdelayedvo" },
    { 0x98A7, "playerdenyextraction" },
    { 0x98A8, "playerdestroyhud" },
    { 0x98A9, "playerdied" },
    { 0x98AA, "playerdisconnect" },
    { 0x98AB, "playerdistfrac" },
    { 0x98AC, "playerdodefibrillator" },
    { 0x98AD, "playerdogfightwaiter" },
    { 0x98AE, "playerdoportabledefibrillator" },
    { 0x98AF, "playerdoublegrenadetime" },
    { 0x98B0, "playerdroneintrodof" },
    { 0x98B1, "playerdropplunder" },
    { 0x98B2, "playerdropplunderondeath" },
    { 0x98B3, "playerdropweaponfrominventory" },
    { 0x98B4, "playerenterarea" },
    { 0x98B5, "playerentercallback" },
    { 0x98B6, "playerentersoftlanding" },
    { 0x98B7, "playerexitcallback" },
    { 0x98B8, "playerfacingpct" },
    { 0x98B9, "playerfakespectate" },
    { 0x98BA, "playerfakespectatecontrols" },
    { 0x98BB, "playerfields" },
    { 0x98BC, "playerfocus" },
    { 0x98BD, "playerfocusmain" },
    { 0x98BE, "playerforplayercard" },
    { 0x98BF, "playerframeupdatecallbacks" },
    { 0x98C0, "playerfultoncrateextract" },
    { 0x98C1, "playergetbountypoints" },
    { 0x98C2, "playergetnextarena" },
    { 0x98C3, "playergivearenaloadout" },
    { 0x98C4, "playergivedefibrillator" },
    { 0x98C5, "playergivetriggerweapon" },
    { 0x98C6, "playergrabbed" },
    { 0x98C7, "playergrenadebasetime" },
    { 0x98C8, "playergrenaderangetime" },
    { 0x98C9, "playergulagarenaready" },
    { 0x98CA, "playergulagautowin" },
    { 0x98CB, "playergulagdonesplash" },
    { 0x98CC, "playergulaggestures" },
    { 0x98CD, "playergulaggesturesdisable" },
    { 0x98CE, "playergulaghud" },
    { 0x98CF, "playerhandlekillstreak" },
    { 0x98D0, "playerhasmolotovs" },
    { 0x98D1, "playerhaspistol" },
    { 0x98D2, "playerhealth" },
    { 0x98D3, "playerhealth_regularregendelay" },
    { 0x98D4, "playerhealthregen" },
    { 0x98D5, "playerheli" },
    { 0x98D6, "playerhelmetenabled" },
    { 0x98D7, "playerid" },
    { 0x98D8, "playerinaiwarning" },
    { 0x98D9, "playerinfildisabled" },
    { 0x98DA, "playerinit" },
    { 0x98DB, "playerinitinvulnerability" },
    { 0x98DC, "playerinnagvolume" },
    { 0x98DD, "playerintripwiredangerzone" },
    { 0x98DE, "playerjoininfil" },
    { 0x98DF, "playerjoinwatcher" },
    { 0x98E0, "playerjumpseencount" },
    { 0x98E1, "playerkeeploadingstreamedassets" },
    { 0x98E2, "playerkilled_deathscene" },
    { 0x98E3, "playerkilled_deletecorpseoutofvehicle" },
    { 0x98E4, "playerkilled_finddeathtype" },
    { 0x98E5, "playerkilled_fixupattacker" },
    { 0x98E6, "playerkilled_handlecorpse" },
    { 0x98E7, "playerkilled_handledeathtype" },
    { 0x98E8, "playerkilled_initdeathdata" },
    { 0x98E9, "playerkilled_internal" },
    { 0x98EA, "playerkilled_killcam" },
    { 0x98EB, "playerkilled_killcamsetup" },
    { 0x98EC, "playerkilled_logkill" },
    { 0x98ED, "playerkilled_parameterfixup" },
    { 0x98EE, "playerkilled_precalc" },
    { 0x98EF, "playerkilled_sharedlogic_early" },
    { 0x98F0, "playerkilled_sharedlogic_late" },
    { 0x98F1, "playerkilled_spawn" },
    { 0x98F2, "playerkillstreakearlyexitlocation" },
    { 0x98F3, "playerkillstreakhud" },
    { 0x98F4, "playerkillstreaks" },
    { 0x98F5, "playerlastdialogstatus" },
    { 0x98F6, "playerlastposition" },
    { 0x98F7, "playerlaststand" },
    { 0x98F8, "playerlead" },
    { 0x98F9, "playerleavearea" },
    { 0x98FA, "playerleavesoftlanding" },
    { 0x98FB, "playerletgo" },
    { 0x98FC, "playerlinked" },
    { 0x98FD, "playerlinkedcounter" },
    { 0x98FE, "playerlinkent" },
    { 0x98FF, "playerlinktochopper" },
    { 0x9900, "playerlinktopositionent" },
    { 0x9901, "playerlist" },
    { 0x9902, "playerlootenabled" },
    { 0x9903, "playermaxammo" },
    { 0x9904, "playermaxarmor" },
    { 0x9905, "playermaxhealth" },
    { 0x9906, "playermaybecomemyenemy" },
    { 0x9907, "playermeleedamagemultiplier_dvar" },
    { 0x9908, "playermeleeseencount" },
    { 0x9909, "playermeleestunregentime" },
    { 0x990A, "playermodelforweapon" },
    { 0x990B, "playermonitor" },
    { 0x990C, "playermonitordistancefromambulance" },
    { 0x990D, "playermonitorweaponchange" },
    { 0x990E, "playermovedistlerptime" },
    { 0x990F, "playermover" },
    { 0x9910, "playernadessafe" },
    { 0x9911, "playernameids" },
    { 0x9912, "playernumforplayercard" },
    { 0x9913, "playeroffhandmain" },
    { 0x9914, "playeroffhandthread" },
    { 0x9915, "playeroffset" },
    { 0x9916, "playeroffsets" },
    { 0x9917, "playeronright" },
    { 0x9918, "playeroriginalweapon" },
    { 0x9919, "playeroutlined" },
    { 0x991A, "playeroutlineid" },
    { 0x991B, "playeroutlinemonitor" },
    { 0x991C, "playeroutlines" },
    { 0x991D, "playeroutoftimecallback" },
    { 0x991E, "playeroutoftimeminefield" },
    { 0x991F, "playeroutoftimeminefieldinternal" },
    { 0x9920, "playerowner" },
    { 0x9921, "playerpainbreathingsound" },
    { 0x9922, "playerpassengerthink" },
    { 0x9923, "playerphotostatus" },
    { 0x9924, "playerpickupaxe" },
    { 0x9925, "playerpickupbody" },
    { 0x9926, "playerpiggyback" },
    { 0x9927, "playerplaybankanim" },
    { 0x9928, "playerplayinfilloopanim" },
    { 0x9929, "playerplaypickupanim" },
    { 0x992A, "playerplaytakephotoanim" },
    { 0x992B, "playerplunderlivelobbydropondeath" },
    { 0x992C, "playerpositionents" },
    { 0x992D, "playerprematchallow" },
    { 0x992E, "playerpronemovedist" },
    { 0x992F, "playerproxyagent" },
    { 0x9930, "playerputinc130" },
    { 0x9931, "playerregisterbountyindex" },
    { 0x9932, "playerremovekillstreak" },
    { 0x9933, "playerremoveoutline" },
    { 0x9934, "playerremoveplunderfrominventory" },
    { 0x9935, "playerresetbountypoints" },
    { 0x9936, "playerresetbountystreak" },
    { 0x9937, "playerrespawn" },
    { 0x9938, "playerrespawngulagcleanup" },
    { 0x9939, "players" },
    { 0x993A, "players_as_passenger" },
    { 0x993B, "players_being_revived" },
    { 0x993C, "players_cannot_see_vehicle_icon" },
    { 0x993D, "players_connect_monitor" },
    { 0x993E, "players_cut_wire_think" },
    { 0x993F, "players_do_black_screen" },
    { 0x9940, "players_enter_ambush_sniper_fire_sequence" },
    { 0x9941, "players_entered_bank" },
    { 0x9942, "players_exit_ambush_sniper_fire_sequence" },
    { 0x9943, "players_expected_for_circle_num" },
    { 0x9944, "players_gun_game_level" },
    { 0x9945, "players_health_as_farah" },
    { 0x9946, "players_holding_hvt_handler" },
    { 0x9947, "players_in_c130" },
    { 0x9948, "players_in_killzone" },
    { 0x9949, "players_in_plane" },
    { 0x994A, "players_in_range" },
    { 0x994B, "players_in_respawn_queue" },
    { 0x994C, "players_inside_plane" },
    { 0x994D, "players_nearby_hvt" },
    { 0x994E, "players_not_in_killzone" },
    { 0x994F, "players_on_roof" },
    { 0x9950, "players_open_door_monitor" },
    { 0x9951, "players_pickedup_hvt" },
    { 0x9952, "players_reached_airport" },
    { 0x9953, "players_using_breach" },
    { 0x9954, "players_waiting_for_callback" },
    { 0x9955, "players_waiting_to_join" },
    { 0x9956, "players_waittill_loadout_given" },
    { 0x9957, "players_waittill_loadout_given_parachute" },
    { 0x9958, "players_want_to_restart" },
    { 0x9959, "players_within_distance" },
    { 0x995A, "playersareenemies" },
    { 0x995B, "playersbyentitynumber" },
    { 0x995C, "playerscaptured" },
    { 0x995D, "playersdebuffed" },
    { 0x995E, "playerseenproneduration" },
    { 0x995F, "playerseesme" },
    { 0x9960, "playerseesmetime" },
    { 0x9961, "playerselectspawnclass" },
    { 0x9962, "playerselectspawnlocation" },
    { 0x9963, "playerselectspawnsequence" },
    { 0x9964, "playerseondaryoffhandtacaim" },
    { 0x9965, "playerseondaryoffhandtacaimlogic" },
    { 0x9966, "playersetbountypoints" },
    { 0x9967, "playersetcarryteammates" },
    { 0x9968, "playersetinlaststand" },
    { 0x9969, "playersetplundercount" },
    { 0x996A, "playersettagcount" },
    { 0x996B, "playersetupac130" },
    { 0x996C, "playersetupcontrolsforinfil" },
    { 0x996D, "playersetupcrate" },
    { 0x996E, "playersetupplayersalivemessage" },
    { 0x996F, "playersfx" },
    { 0x9970, "playershielddisconnectwaiter" },
    { 0x9971, "playershieldwatchoverclockremove" },
    { 0x9972, "playershieldwatchplayerdeath" },
    { 0x9973, "playershoulddofauxdeath" },
    { 0x9974, "playersinc130" },
    { 0x9975, "playersincylinder" },
    { 0x9976, "playersindisorientradius" },
    { 0x9977, "playersinengagedradius" },
    { 0x9978, "playersininitialsmokerange" },
    { 0x9979, "playersininnerradius" },
    { 0x997A, "playersinnotifyradius" },
    { 0x997B, "playersinrange" },
    { 0x997C, "playersinsidebank" },
    { 0x997D, "playersinsphere" },
    { 0x997E, "playersintrigger" },
    { 0x997F, "playerslot1" },
    { 0x9980, "playerslot2" },
    { 0x9981, "playerslot3" },
    { 0x9982, "playerslot4" },
    { 0x9983, "playerslots" },
    { 0x9984, "playersnear" },
    { 0x9985, "playersnearcustom" },
    { 0x9986, "playersoutsideinitialsmokerange" },
    { 0x9987, "playerspawnangles" },
    { 0x9988, "playerspawnextractchopper" },
    { 0x9989, "playerspawnpos" },
    { 0x998A, "playerspawnprotectionac130" },
    { 0x998B, "playerspawnsessionteamassignmentfunc" },
    { 0x998C, "playerspawnteamassignmentfunc" },
    { 0x998D, "playerspeedfrac" },
    { 0x998E, "playerspread" },
    { 0x998F, "playersrevived" },
    { 0x9990, "playerstancechanged" },
    { 0x9991, "playerstandmovedist" },
    { 0x9992, "playerstarthealthregen" },
    { 0x9993, "playerstartpos" },
    { 0x9994, "playerstartselectspawnclassnonexclusion" },
    { 0x9995, "playerstats" },
    { 0x9996, "playerstingerads" },
    { 0x9997, "playerstreakspeedscale" },
    { 0x9998, "playerstriggered" },
    { 0x9999, "playersused" },
    { 0x999A, "playersvisibleto" },
    { 0x999B, "playersvisibletopending" },
    { 0x999C, "playerswithdoorsense" },
    { 0x999D, "playertag" },
    { 0x999E, "playertakeawaydefibrillator" },
    { 0x999F, "playertakeawayrock" },
    { 0x99A0, "playertakefultononweapchange" },
    { 0x99A1, "playerteam" },
    { 0x99A2, "playerthinkanim" },
    { 0x99A3, "playerthinkpath" },
    { 0x99A4, "playerthreadthreader" },
    { 0x99A5, "playertimenearai" },
    { 0x99A6, "playertoomnvarmap" },
    { 0x99A7, "playertoomvarmap" },
    { 0x99A8, "playertrigger" },
    { 0x99A9, "playertriggered" },
    { 0x99AA, "playertriggerkillstreak" },
    { 0x99AB, "playertrytakedefibrillator" },
    { 0x99AC, "playertweaks" },
    { 0x99AD, "playerunlimitedammothread" },
    { 0x99AE, "playerupdateplunderleaderboard" },
    { 0x99AF, "playerupdaterank" },
    { 0x99B0, "playerusehealslotwatch" },
    { 0x99B1, "playerusing" },
    { 0x99B2, "playervehicle" },
    { 0x99B3, "playervehiclewaiter" },
    { 0x99B4, "playerviewowner" },
    { 0x99B5, "playervisiblecount" },
    { 0x99B6, "playerwasholdingcinderblock" },
    { 0x99B7, "playerwasnearby" },
    { 0x99B8, "playerwasrunning" },
    { 0x99B9, "playerwatch_unresolved_collision" },
    { 0x99BA, "playerwatch_unresolved_collision_count" },
    { 0x99BB, "playerwatchdisconnect" },
    { 0x99BC, "playerwatchforredeploy" },
    { 0x99BD, "playerweapondrawnseencount" },
    { 0x99BE, "playerweaponinfo" },
    { 0x99BF, "playerworlddeath" },
    { 0x99C0, "playerxpenabled" },
    { 0x99C1, "playeventvo" },
    { 0x99C2, "playexplodedeathanim" },
    { 0x99C3, "playexplosivedeathanim" },
    { 0x99C4, "playexposedcoveranim" },
    { 0x99C5, "playexposedcrouchaimdownloop" },
    { 0x99C6, "playexposedcrouchloop" },
    { 0x99C7, "playexposedidleaimdownloop" },
    { 0x99C8, "playexposedloop" },
    { 0x99C9, "playexposedproneloop" },
    { 0x99CA, "playfacesound" },
    { 0x99CB, "playfacethread" },
    { 0x99CC, "playfacialanim" },
    { 0x99CD, "playfirechainsfx" },
    { 0x99CE, "playfirstcamblendpt" },
    { 0x99CF, "playflarefx" },
    { 0x99D0, "playflavorburstline" },
    { 0x99D1, "playflyoveraudioline" },
    { 0x99D2, "playfootprinteffect" },
    { 0x99D3, "playfootstep" },
    { 0x99D4, "playfootstepeffect" },
    { 0x99D5, "playfootstepeffectsmall" },
    { 0x99D6, "playfxatpoint" },
    { 0x99D7, "playfxcallback" },
    { 0x99D8, "playfxnophase" },
    { 0x99D9, "playfxonplayer" },
    { 0x99DA, "playgestureanim" },
    { 0x99DB, "playgestureforcraftingandskillpointstablet" },
    { 0x99DC, "playgrenadeavoidanim" },
    { 0x99DD, "playgrenadereturnthrowanim" },
    { 0x99DE, "playground_anim_node" },
    { 0x99DF, "playhandstep" },
    { 0x99E0, "playhardpointneutralfx" },
    { 0x99E1, "playheatfx" },
    { 0x99E2, "playholdtwovo" },
    { 0x99E3, "playhostagehelp" },
    { 0x99E4, "playidlepatrolanim" },
    { 0x99E5, "playincomingwarning" },
    { 0x99E6, "playinfilplayeranims" },
    { 0x99E7, "playinformevent" },
    { 0x99E8, "playing_gesture" },
    { 0x99E9, "playing_ghosts_n_skulls" },
    { 0x99EA, "playing_radio_dialogue" },
    { 0x99EB, "playing_rumble" },
    { 0x99EC, "playing_skit" },
    { 0x99ED, "playing_sound" },
    { 0x99EE, "playing_stumble" },
    { 0x99EF, "playing_terrorist_respawn_music" },
    { 0x99F0, "playingburningfx" },
    { 0x99F1, "playinglocksound" },
    { 0x99F2, "playingselfvo" },
    { 0x99F3, "playingselfvotracking" },
    { 0x99F4, "playinteractable" },
    { 0x99F5, "playkillstreakdialogonplayer" },
    { 0x99F6, "playkillstreakoperatordialog" },
    { 0x99F7, "playkillstreakslotsound" },
    { 0x99F8, "playkillstreakusedialog" },
    { 0x99F9, "playleadtakendialog" },
    { 0x99FA, "playlerptrack" },
    { 0x99FB, "playlifelinkfx" },
    { 0x99FC, "playlinkedsmokeeffect" },
    { 0x99FD, "playlocalsound_safe" },
    { 0x99FE, "playlocalsoundwrapper" },
    { 0x99FF, "playlockerrorsound" },
    { 0x9A00, "playlocksound" },
    { 0x9A01, "playlongdeathanim" },
    { 0x9A02, "playlongdeathfinaldeath" },
    { 0x9A03, "playlongdeathgrenade" },
    { 0x9A04, "playlongdeathgrenadepull" },
    { 0x9A05, "playlongdeathidle" },
    { 0x9A06, "playlongdeathintro" },
    { 0x9A07, "playlongdeathmercy" },
    { 0x9A08, "playlookanimation" },
    { 0x9A09, "playloopedfxontag" },
    { 0x9A0A, "playloopedfxontag_originupdate" },
    { 0x9A0B, "playlootsound" },
    { 0x9A0C, "playmeleeanim_c6freed" },
    { 0x9A0D, "playmeleeanim_chargetoready" },
    { 0x9A0E, "playmeleeanim_chargetoready_distcheck" },
    { 0x9A0F, "playmeleeanim_seekerattack" },
    { 0x9A10, "playmeleeanim_seekerattack_cleanup" },
    { 0x9A11, "playmeleeanim_seekerattack_victim" },
    { 0x9A12, "playmeleeanim_synced" },
    { 0x9A13, "playmeleeanim_synced_cleanup" },
    { 0x9A14, "playmeleeanim_synced_survive" },
    { 0x9A15, "playmeleeanim_synced_victim" },
    { 0x9A16, "playmeleeanim_synced_waitforpartnerexit" },
    { 0x9A17, "playmeleeanim_vsplayer" },
    { 0x9A18, "playmeleeattacksound" },
    { 0x9A19, "playmeleechargeanim" },
    { 0x9A1A, "playmeleechargesound" },
    { 0x9A1B, "playmoveloop" },
    { 0x9A1C, "playmoveloop_codeblend" },
    { 0x9A1D, "playmoveloop_mp" },
    { 0x9A1E, "playmoveloopcasual" },
    { 0x9A1F, "playmoveloopcasualcleanup" },
    { 0x9A20, "playmovestrafeloop" },
    { 0x9A21, "playmovestrafeloop_codeblend" },
    { 0x9A22, "playmovestrafeloop_forwardbackwardmonitor" },
    { 0x9A23, "playmovestrafeloopnew" },
    { 0x9A24, "playnamelist" },
    { 0x9A25, "playnukeintrovo" },
    { 0x9A26, "playnukeusedvo" },
    { 0x9A27, "playoperatorstaticinterrupt" },
    { 0x9A28, "playorderevent" },
    { 0x9A29, "playovertime" },
    { 0x9A2A, "playpainanim" },
    { 0x9A2B, "playpainanim_damageshieldtoground" },
    { 0x9A2C, "playpainanim_damageshieldtoground_cleanup" },
    { 0x9A2D, "playpainanim_exposedcrouch" },
    { 0x9A2E, "playpainanim_exposedcrouchtransition" },
    { 0x9A2F, "playpainanim_exposedstand" },
    { 0x9A30, "playpainanim_faceplayer" },
    { 0x9A31, "playpainaniminternal" },
    { 0x9A32, "playpainanimlmg" },
    { 0x9A33, "playpainanimwithadditives" },
    { 0x9A34, "playpainoverlay" },
    { 0x9A35, "playpapgesture" },
    { 0x9A36, "playphrase" },
    { 0x9A37, "playplanefx" },
    { 0x9A38, "playplayerandnpcsounds" },
    { 0x9A39, "playplayerbattlechatter" },
    { 0x9A3A, "playpulsesfx" },
    { 0x9A3B, "playradio" },
    { 0x9A3C, "playradioecho" },
    { 0x9A3D, "playradiotransmission" },
    { 0x9A3E, "playreactionevent" },
    { 0x9A3F, "playreloadwhilemoving" },
    { 0x9A40, "playremotesequence" },
    { 0x9A41, "playresponseevent" },
    { 0x9A42, "playrunngun" },
    { 0x9A43, "plays_quick_poi" },
    { 0x9A44, "plays_single_anim" },
    { 0x9A45, "plays_wait_poi" },
    { 0x9A46, "playscaledjump" },
    { 0x9A47, "playselfbattlechatter" },
    { 0x9A48, "playselfvo" },
    { 0x9A49, "playsharpturnanim" },
    { 0x9A4A, "playshockpainloop" },
    { 0x9A4B, "playshootinglongdeathidle" },
    { 0x9A4C, "playshuffleanim_arrival" },
    { 0x9A4D, "playshuffleanim_terminate" },
    { 0x9A4E, "playshuffleloop" },
    { 0x9A4F, "playskydivefxloop" },
    { 0x9A50, "playslamzoomflash" },
    { 0x9A51, "playsmartobjectanim" },
    { 0x9A52, "playsmartobjectdeathanim" },
    { 0x9A53, "playsmartobjectexit" },
    { 0x9A54, "playsmartobjectintro" },
    { 0x9A55, "playsmartobjectlogic" },
    { 0x9A56, "playsmartobjectpainanim" },
    { 0x9A57, "playsmartobjectreactanim" },
    { 0x9A58, "playsmokeflarevisualmarker" },
    { 0x9A59, "playsmokefx" },
    { 0x9A5A, "playsonicboom" },
    { 0x9A5B, "playsonicshockfx" },
    { 0x9A5C, "playsound_vo" },
    { 0x9A5D, "playsound_wait" },
    { 0x9A5E, "playsound25mm" },
    { 0x9A5F, "playsoundatpoint" },
    { 0x9A60, "playsoundatpos_safe" },
    { 0x9A61, "playsoundforteam" },
    { 0x9A62, "playsoundinspace" },
    { 0x9A63, "playsoundonentity" },
    { 0x9A64, "playsoundonplayers" },
    { 0x9A65, "playsoundontag" },
    { 0x9A66, "playsoundoverradio" },
    { 0x9A67, "playsoundtoplayer_safe" },
    { 0x9A68, "playspinnerfx" },
    { 0x9A69, "playstartanim" },
    { 0x9A6A, "playstealthevent" },
    { 0x9A6B, "playstumblingpaintransition" },
    { 0x9A6C, "playstumblingwander" },
    { 0x9A6D, "playteamfxforclient" },
    { 0x9A6E, "playthanksvo" },
    { 0x9A6F, "playthreatevent" },
    { 0x9A70, "playtickingsound" },
    { 0x9A71, "playtracks" },
    { 0x9A72, "playtransitiontocoverhide" },
    { 0x9A73, "playtransitiontoexposedanim" },
    { 0x9A74, "playtransitiontoexposedanimanglefixup" },
    { 0x9A75, "playtraversaltransition" },
    { 0x9A76, "playtraverseanim" },
    { 0x9A77, "playtraverseanim_deprecated" },
    { 0x9A78, "playtraverseanim_doublejump" },
    { 0x9A79, "playtraverseanim_external" },
    { 0x9A7A, "playtraverseanim_ladder" },
    { 0x9A7B, "playtraverseanim_scaled" },
    { 0x9A7C, "playtraversearrivalanim" },
    { 0x9A7D, "playturnanim" },
    { 0x9A7E, "playturnanim_cleanup" },
    { 0x9A7F, "playturnanim_turnanimanglefixup" },
    { 0x9A80, "playusesound" },
    { 0x9A81, "playvehicleevent" },
    { 0x9A82, "playvfx" },
    { 0x9A83, "playvofordowned" },
    { 0x9A84, "playvoforlaststand" },
    { 0x9A85, "playvoforpillage" },
    { 0x9A86, "playvoforrevived" },
    { 0x9A87, "playvoforscriptable" },
    { 0x9A88, "playwallrunattach" },
    { 0x9A89, "playwallruncontinue" },
    { 0x9A8A, "playwallrunendsound" },
    { 0x9A8B, "playwallrunenter" },
    { 0x9A8C, "playwallrunexit" },
    { 0x9A8D, "playwallrunloop" },
    { 0x9A8E, "playwallruntomantle" },
    { 0x9A8F, "plot_circle" },
    { 0x9A90, "plot_points" },
    { 0x9A91, "plotarmor" },
    { 0x9A92, "plunder" },
    { 0x9A93, "plunderbanked" },
    { 0x9A94, "plundercount" },
    { 0x9A95, "plundercountondeath" },
    { 0x9A96, "plunderitems" },
    { 0x9A97, "plunderleaderboard" },
    { 0x9A98, "plunderlivelobby" },
    { 0x9A99, "plunderpickupcallback" },
    { 0x9A9A, "plunderrarities" },
    { 0x9A9B, "plundersiteused" },
    { 0x9A9C, "plundersiteusedinternal" },
    { 0x9A9D, "plus" },
    { 0x9A9E, "pmc_match" },
    { 0x9A9F, "pod_addusedpoint" },
    { 0x9AA0, "pod_cleanupusedpoints" },
    { 0x9AA1, "pod_combat_periodicping" },
    { 0x9AA2, "pod_combat_update_checklosttarget" },
    { 0x9AA3, "pod_delete" },
    { 0x9AA4, "pod_getclosestguy" },
    { 0x9AA5, "pod_haslostenemy" },
    { 0x9AA6, "pod_hunt_delayednotify" },
    { 0x9AA7, "pod_hunt_hunker_update" },
    { 0x9AA8, "pod_hunt_update" },
    { 0x9AA9, "pod_hunt_vo" },
    { 0x9AAA, "pod_isclosetoanymembers" },
    { 0x9AAB, "pod_isleader" },
    { 0x9AAC, "pod_settocombat" },
    { 0x9AAD, "pod_settohunt" },
    { 0x9AAE, "pod_settoidle" },
    { 0x9AAF, "pod_updateinvestigateorigin" },
    { 0x9AB0, "podiumindex" },
    { 0x9AB1, "pods" },
    { 0x9AB2, "poi_activeai" },
    { 0x9AB3, "poi_disablefov" },
    { 0x9AB4, "poi_enable" },
    { 0x9AB5, "poi_enabled" },
    { 0x9AB6, "poi_firstpoint" },
    { 0x9AB7, "poi_fovlimit" },
    { 0x9AB8, "poi_oldturnrate" },
    { 0x9AB9, "poi_starttime" },
    { 0x9ABA, "poiauto" },
    { 0x9ABB, "poiauto_angles" },
    { 0x9ABC, "poiauto_getshootpos" },
    { 0x9ABD, "poiauto_glanceend" },
    { 0x9ABE, "poiauto_glancerandom" },
    { 0x9ABF, "poiauto_init" },
    { 0x9AC0, "poiauto_isglancing" },
    { 0x9AC1, "poiauto_nextaimtime" },
    { 0x9AC2, "poiauto_nextangles" },
    { 0x9AC3, "poiauto_relativeangletopos" },
    { 0x9AC4, "poiauto_setnewaimangle" },
    { 0x9AC5, "poiauto_think" },
    { 0x9AC6, "point_center_anim" },
    { 0x9AC7, "point_down_anim" },
    { 0x9AC8, "point_gesture_active" },
    { 0x9AC9, "point_in_fov" },
    { 0x9ACA, "point_is_towards_target" },
    { 0x9ACB, "point_left_anim" },
    { 0x9ACC, "point_of_no_return" },
    { 0x9ACD, "point_orientation_relative_to_player" },
    { 0x9ACE, "point_right_anim" },
    { 0x9ACF, "point_side_of_line2d" },
    { 0x9AD0, "point_to_ambush" },
    { 0x9AD1, "point_up_anim" },
    { 0x9AD2, "point0" },
    { 0x9AD3, "point1" },
    { 0x9AD4, "pointblank" },
    { 0x9AD5, "pointcost" },
    { 0x9AD6, "pointdata" },
    { 0x9AD7, "pointeventdata" },
    { 0x9AD8, "pointindex" },
    { 0x9AD9, "pointinfov" },
    { 0x9ADA, "pointoncircle" },
    { 0x9ADB, "points" },
    { 0x9ADC, "pointsneeded" },
    { 0x9ADD, "pointsonpath" },
    { 0x9ADE, "pointsperflag" },
    { 0x9ADF, "pointvscone" },
    { 0x9AE0, "pointvscylinder" },
    { 0x9AE1, "poison" },
    { 0x9AE2, "poistates" },
    { 0x9AE3, "poke_out_guy_loop" },
    { 0x9AE4, "police_arrive_car_firstframe" },
    { 0x9AE5, "police_car_anim_setup" },
    { 0x9AE6, "police_car_set_animrate" },
    { 0x9AE7, "police_car_set_animtime" },
    { 0x9AE8, "police_car_unlock" },
    { 0x9AE9, "police_corpse_manager" },
    { 0x9AEA, "police_dialog_struct" },
    { 0x9AEB, "police_die" },
    { 0x9AEC, "police_helpresponses" },
    { 0x9AED, "police_vignette" },
    { 0x9AEE, "police_vo_indexes" },
    { 0x9AEF, "policecar" },
    { 0x9AF0, "poll_for_found" },
    { 0x9AF1, "pollallowedstancesthread" },
    { 0x9AF2, "pool_damage_ai" },
    { 0x9AF3, "pool_damage_scriptables" },
    { 0x9AF4, "pool_damage_vehicles" },
    { 0x9AF5, "pooldata" },
    { 0x9AF6, "poolid" },
    { 0x9AF7, "poolmask" },
    { 0x9AF8, "poolshouldlink" },
    { 0x9AF9, "pop_first_vo_out_of_queue" },
    { 0x9AFA, "popdisabledgunpose" },
    { 0x9AFB, "popfov" },
    { 0x9AFC, "popnextmatch" },
    { 0x9AFD, "popoffhelmet" },
    { 0x9AFE, "poppies_catchup" },
    { 0x9AFF, "poppies_enemies" },
    { 0x9B00, "poppies_enemies_spawn" },
    { 0x9B01, "poppies_enemy_stealth_filter" },
    { 0x9B02, "poppies_main" },
    { 0x9B03, "poppies_nags" },
    { 0x9B04, "poppies_start" },
    { 0x9B05, "poppies_start_vo" },
    { 0x9B06, "poppies_trafficker_enemies" },
    { 0x9B07, "poppies_vo_sources" },
    { 0x9B08, "popstackedstreakintogimmeslot" },
    { 0x9B09, "populate_civilians" },
    { 0x9B0A, "populate_civs_looping" },
    { 0x9B0B, "populate_civs_no_loop" },
    { 0x9B0C, "populate_landmine_signs" },
    { 0x9B0D, "popup_omnvar" },
    { 0x9B0E, "portable_mg_behavior" },
    { 0x9B0F, "portable_mg_gun_tag" },
    { 0x9B10, "portable_mg_spot" },
    { 0x9B11, "portalgiactive" },
    { 0x9B12, "portalgiangle" },
    { 0x9B13, "portalgiset" },
    { 0x9B14, "pos" },
    { 0x9B15, "pos_is_valid_outside_for_vanguard" },
    { 0x9B16, "pos_override_struct" },
    { 0x9B17, "pos_passes_sky_trace" },
    { 0x9B18, "posalongpath" },
    { 0x9B19, "posclosed" },
    { 0x9B1A, "posent" },
    { 0x9B1B, "position_elevators" },
    { 0x9B1C, "position_near_other_nodes" },
    { 0x9B1D, "position_outro" },
    { 0x9B1E, "position_price" },
    { 0x9B1F, "position_struct" },
    { 0x9B20, "positionptm" },
    { 0x9B21, "posopen" },
    { 0x9B22, "possessionresetcondition" },
    { 0x9B23, "possessionresettime" },
    { 0x9B24, "possiblethreatcallouts" },
    { 0x9B25, "post_activate_update" },
    { 0x9B26, "post_alley_scene" },
    { 0x9B27, "post_alley_spawn_func" },
    { 0x9B28, "post_bomb_ambient" },
    { 0x9B29, "post_bomb_background_vo" },
    { 0x9B2A, "post_bomb_catchup" },
    { 0x9B2B, "post_bomb_civ_death" },
    { 0x9B2C, "post_bomb_main" },
    { 0x9B2D, "post_bomb_room_price_anim" },
    { 0x9B2E, "post_bomb_start" },
    { 0x9B2F, "post_bomb_vo" },
    { 0x9B30, "post_boss_house_gate" },
    { 0x9B31, "post_boss_house_gate_clip" },
    { 0x9B32, "post_bullet_load_setup" },
    { 0x9B33, "post_car_vo" },
    { 0x9B34, "post_collapse_geo" },
    { 0x9B35, "post_crash_ents" },
    { 0x9B36, "post_entity_creation_function" },
    { 0x9B37, "post_explosion_visionset" },
    { 0x9B38, "post_grounds_cleanup" },
    { 0x9B39, "post_hvt_fadeout" },
    { 0x9B3A, "post_infil_weapon" },
    { 0x9B3B, "post_jugg_allies_plant_bombs" },
    { 0x9B3C, "post_jugg_ally_node" },
    { 0x9B3D, "post_jugg_nags" },
    { 0x9B3E, "post_jugg_plant_ally" },
    { 0x9B3F, "post_load" },
    { 0x9B40, "post_load_funcs" },
    { 0x9B41, "post_load_functions" },
    { 0x9B42, "post_load_precache" },
    { 0x9B43, "post_meleeexplode" },
    { 0x9B44, "post_module_delay" },
    { 0x9B45, "post_nondeterministic_func" },
    { 0x9B46, "post_reaction_func" },
    { 0x9B47, "post_reaction_params" },
    { 0x9B48, "post_reaction_vo" },
    { 0x9B49, "post_reaction_vo_array" },
    { 0x9B4A, "post_setup_func" },
    { 0x9B4B, "post_spawn_ai_funcs" },
    { 0x9B4C, "post_spawn_spawner_funcs" },
    { 0x9B4D, "post_spawn_vehicle_init" },
    { 0x9B4E, "post_stairtrain_anim" },
    { 0x9B4F, "post_wait_func" },
    { 0x9B50, "postdeathkill" },
    { 0x9B51, "postdelay" },
    { 0x9B52, "posted" },
    { 0x9B53, "postencounterscorefunc" },
    { 0x9B54, "postfx_ied_explosion" },
    { 0x9B55, "postfx_slam_zoom" },
    { 0x9B56, "postgameexfil" },
    { 0x9B57, "postgamenotifies" },
    { 0x9B58, "postgamepromotion" },
    { 0x9B59, "postintroscreenfunc" },
    { 0x9B5A, "postload" },
    { 0x9B5B, "postloadbink" },
    { 0x9B5C, "postmoddamagecallbacks" },
    { 0x9B5D, "postmoddamagefunc" },
    { 0x9B5E, "postpawn_friendly_shared" },
    { 0x9B5F, "postpawn_friendly_weapon" },
    { 0x9B60, "postplayerdamaged" },
    { 0x9B61, "postroundfadenokillcam" },
    { 0x9B62, "postroundtime" },
    { 0x9B63, "postshipmodifiedkothzones" },
    { 0x9B64, "postshipmodifiedzonebrushes" },
    { 0x9B65, "postshipmodifiedzones" },
    { 0x9B66, "postspawn_1f_runner" },
    { 0x9B67, "postspawn_2f_data" },
    { 0x9B68, "postspawn_2f_dataciv" },
    { 0x9B69, "postspawn_2f_enemies" },
    { 0x9B6A, "postspawn_allies" },
    { 0x9B6B, "postspawn_ally" },
    { 0x9B6C, "postspawn_alpha" },
    { 0x9B6D, "postspawn_attic_enemy" },
    { 0x9B6E, "postspawn_axis" },
    { 0x9B6F, "postspawn_baby_mom" },
    { 0x9B70, "postspawn_backyard_alley_extra" },
    { 0x9B71, "postspawn_barrier_cop" },
    { 0x9B72, "postspawn_bed_guy" },
    { 0x9B73, "postspawn_bravo" },
    { 0x9B74, "postspawn_bravo2" },
    { 0x9B75, "postspawn_bravo3" },
    { 0x9B76, "postspawn_bravo4" },
    { 0x9B77, "postspawn_bravo4_reinforcement" },
    { 0x9B78, "postspawn_buddy_down_enemy" },
    { 0x9B79, "postspawn_buddy_down_gunner" },
    { 0x9B7A, "postspawn_car1_terries" },
    { 0x9B7B, "postspawn_car1_terry" },
    { 0x9B7C, "postspawn_car2_terry" },
    { 0x9B7D, "postspawn_cellphone_guy" },
    { 0x9B7E, "postspawn_charlie" },
    { 0x9B7F, "postspawn_dining_enemy" },
    { 0x9B80, "postspawn_friendlies" },
    { 0x9B81, "postspawn_garage_enemy" },
    { 0x9B82, "postspawn_garage_office_alerter" },
    { 0x9B83, "postspawn_garage_office_enemy" },
    { 0x9B84, "postspawn_garage2_enemy" },
    { 0x9B85, "postspawn_hero" },
    { 0x9B86, "postspawn_hiding_door_enemy" },
    { 0x9B87, "postspawn_infil_dogs" },
    { 0x9B88, "postspawn_intro_civ" },
    { 0x9B89, "postspawn_second_floor_enemy" },
    { 0x9B8A, "postspawn_suspend_ai_framedelay" },
    { 0x9B8B, "postspawn_suspended_ai" },
    { 0x9B8C, "postspawnresetorigin" },
    { 0x9B8D, "postspawnselectionstream" },
    { 0x9B8E, "potential_hero_players_as_target_in_range" },
    { 0x9B8F, "potg_killcam" },
    { 0x9B90, "potgenabled" },
    { 0x9B91, "potgglobals" },
    { 0x9B92, "potgid" },
    { 0x9B93, "potgkillcamcleanup" },
    { 0x9B94, "potgkillcamover" },
    { 0x9B95, "pouranimpct" },
    { 0x9B96, "pourdangerrange" },
    { 0x9B97, "pourdistancediff" },
    { 0x9B98, "pov_switch_bink" },
    { 0x9B99, "power" },
    { 0x9B9A, "power_addammo" },
    { 0x9B9B, "power_adjustcharges" },
    { 0x9B9C, "power_area" },
    { 0x9B9D, "power_areas_list" },
    { 0x9B9E, "power_clearpower" },
    { 0x9B9F, "power_cooldownremaining" },
    { 0x9BA0, "power_cooldowns" },
    { 0x9BA1, "power_createdefaultstruct" },
    { 0x9BA2, "power_createplayerstruct" },
    { 0x9BA3, "power_disableactivation" },
    { 0x9BA4, "power_disablepower" },
    { 0x9BA5, "power_docooldown" },
    { 0x9BA6, "power_dodrain" },
    { 0x9BA7, "power_down_electronics" },
    { 0x9BA8, "power_enableactivation" },
    { 0x9BA9, "power_enablepower" },
    { 0x9BAA, "power_endcooldown" },
    { 0x9BAB, "power_enddrain" },
    { 0x9BAC, "power_enddrainoninterrupt" },
    { 0x9BAD, "power_getinputcommand" },
    { 0x9BAE, "power_getpowerkeys" },
    { 0x9BAF, "power_handle_down" },
    { 0x9BB0, "power_haspower" },
    { 0x9BB1, "power_hud_info" },
    { 0x9BB2, "power_interact" },
    { 0x9BB3, "power_interact_anim" },
    { 0x9BB4, "power_lever" },
    { 0x9BB5, "power_modifychargesonpickuporfailure" },
    { 0x9BB6, "power_modifychargesonscavenge" },
    { 0x9BB7, "power_modifycooldowncounteronscavenge" },
    { 0x9BB8, "power_modifycooldownrate" },
    { 0x9BB9, "power_name" },
    { 0x9BBA, "power_objective" },
    { 0x9BBB, "power_on" },
    { 0x9BBC, "power_on_all" },
    { 0x9BBD, "power_on_electronics" },
    { 0x9BBE, "power_override" },
    { 0x9BBF, "power_resetcooldownrate" },
    { 0x9BC0, "power_setcooldowncounter" },
    { 0x9BC1, "power_sethudstate" },
    { 0x9BC2, "power_setup_init" },
    { 0x9BC3, "power_shouldcooldown" },
    { 0x9BC4, "power_switch" },
    { 0x9BC5, "power_table" },
    { 0x9BC6, "power_unsethudstate" },
    { 0x9BC7, "power_unsethudstateonremoved" },
    { 0x9BC8, "power_up_table" },
    { 0x9BC9, "power_updateammo" },
    { 0x9BCA, "power_variableselection" },
    { 0x9BCB, "power_waitonbuttonheld" },
    { 0x9BCC, "power_watch_hint" },
    { 0x9BCD, "power_watchhudcharges" },
    { 0x9BCE, "power_watchhudcooldownmeter" },
    { 0x9BCF, "power_watchhuddrainmeter" },
    { 0x9BD0, "powercooldowns" },
    { 0x9BD1, "powerdurations" },
    { 0x9BD2, "powered_on" },
    { 0x9BD3, "powerleverinteract" },
    { 0x9BD4, "powerparsetable" },
    { 0x9BD5, "powerpassivemap" },
    { 0x9BD6, "powerpassiveparsetable" },
    { 0x9BD7, "powerprimarygrenade" },
    { 0x9BD8, "powers" },
    { 0x9BD9, "powers_active" },
    { 0x9BDA, "powers_clearpower" },
    { 0x9BDB, "powersecondarygrenade" },
    { 0x9BDC, "powersetfuncs" },
    { 0x9BDD, "powersetupfunctions" },
    { 0x9BDE, "powershortcooldown" },
    { 0x9BDF, "powershud_assignpower" },
    { 0x9BE0, "powershud_beginpowercooldown" },
    { 0x9BE1, "powershud_beginpowerdrain" },
    { 0x9BE2, "powershud_clearpower" },
    { 0x9BE3, "powershud_endpowerdrain" },
    { 0x9BE4, "powershud_finishpowercooldown" },
    { 0x9BE5, "powershud_getslotomnvar" },
    { 0x9BE6, "powershud_init" },
    { 0x9BE7, "powershud_updatepowercharges" },
    { 0x9BE8, "powershud_updatepowerchargescp" },
    { 0x9BE9, "powershud_updatepowercooldown" },
    { 0x9BEA, "powershud_updatepowerdisabled" },
    { 0x9BEB, "powershud_updatepowerdrain" },
    { 0x9BEC, "powershud_updatepowerdrainprogress" },
    { 0x9BED, "powershud_updatepowermaxcharges" },
    { 0x9BEE, "powershud_updatepowermeter" },
    { 0x9BEF, "powershud_updatepoweroffcooldown" },
    { 0x9BF0, "powershud_updatepowerstate" },
    { 0x9BF1, "powerunsetfuncs" },
    { 0x9BF2, "powerupicons" },
    { 0x9BF3, "powerweaponmap" },
    { 0x9BF4, "ppkasjugg" },
    { 0x9BF5, "ppkjuggonjugg" },
    { 0x9BF6, "ppkonjugg" },
    { 0x9BF7, "practicemode" },
    { 0x9BF8, "practicenotify" },
    { 0x9BF9, "practiceround" },
    { 0x9BFA, "prdconstant" },
    { 0x9BFB, "prdprobability" },
    { 0x9BFC, "pre_apache_angles" },
    { 0x9BFD, "pre_apache_origin" },
    { 0x9BFE, "pre_apache_weapon" },
    { 0x9BFF, "pre_arcade_game_weapon" },
    { 0x9C00, "pre_arcade_game_weapon_clip" },
    { 0x9C01, "pre_arcade_game_weapon_stock" },
    { 0x9C02, "pre_boss_house_gate" },
    { 0x9C03, "pre_boss_house_gate_clip" },
    { 0x9C04, "pre_cam_change_dialogue" },
    { 0x9C05, "pre_charge_main" },
    { 0x9C06, "pre_charge_start" },
    { 0x9C07, "pre_charge_wall_anims" },
    { 0x9C08, "pre_charge_wall_guys" },
    { 0x9C09, "pre_charge_wallspawner_spawn_func" },
    { 0x9C0A, "pre_collapse_geo" },
    { 0x9C0B, "pre_crash_ents" },
    { 0x9C0C, "pre_drone_angles" },
    { 0x9C0D, "pre_drone_weapon" },
    { 0x9C0E, "pre_end_game_display_func" },
    { 0x9C0F, "pre_fire_chair_anim" },
    { 0x9C10, "pre_fire_performance" },
    { 0x9C11, "pre_gunner_weapon" },
    { 0x9C12, "pre_laststand_powers" },
    { 0x9C13, "pre_laststand_weapon" },
    { 0x9C14, "pre_laststand_weapon_ammo_clip" },
    { 0x9C15, "pre_laststand_weapon_stock" },
    { 0x9C16, "pre_map_restart_func" },
    { 0x9C17, "pre_missile_defense_weapon" },
    { 0x9C18, "pre_office_door_open" },
    { 0x9C19, "pre_office_teleport_allies" },
    { 0x9C1A, "pre_reaction_func" },
    { 0x9C1B, "pre_reaction_params" },
    { 0x9C1C, "pre_reaper_weapon" },
    { 0x9C1D, "pre_regen_wait" },
    { 0x9C1E, "pre_truck_office_cleanup" },
    { 0x9C1F, "pre_wait_time" },
    { 0x9C20, "pre_wave_weapons_free" },
    { 0x9C21, "precache_basement" },
    { 0x9C22, "precache_civilian_anims" },
    { 0x9C23, "precache_fx" },
    { 0x9C24, "precache_garage_milk_crate" },
    { 0x9C25, "precache_mineshaft" },
    { 0x9C26, "precache_mp" },
    { 0x9C27, "precache_prop_models" },
    { 0x9C28, "precache_pvpe_vfx" },
    { 0x9C29, "precache_script_models_thread" },
    { 0x9C2A, "precache_storage" },
    { 0x9C2B, "precache_weapon_models_thread" },
    { 0x9C2C, "precacheanims" },
    { 0x9C2D, "precached" },
    { 0x9C2E, "precachehelicoptersounds" },
    { 0x9C2F, "precacheimages" },
    { 0x9C30, "precachelb" },
    { 0x9C31, "precachemodelarray" },
    { 0x9C32, "precachetrap" },
    { 0x9C33, "precalculated_paths" },
    { 0x9C34, "precap" },
    { 0x9C35, "precappoints" },
    { 0x9C36, "precharge_getallycovernodes" },
    { 0x9C37, "precircletime" },
    { 0x9C38, "precisionairstrikebeginuse" },
    { 0x9C39, "precomputed_sky_illumination_bounce_count" },
    { 0x9C3A, "precomputed_sky_illumination_diffuse_reflectance" },
    { 0x9C3B, "precutstartframe" },
    { 0x9C3C, "predamageshieldignoreme" },
    { 0x9C3D, "predatormissileimpact" },
    { 0x9C3E, "predictedaimyaw" },
    { 0x9C3F, "preexplpos" },
    { 0x9C40, "prefarah" },
    { 0x9C41, "preferalliesbydistance" },
    { 0x9C42, "preferbyteambase" },
    { 0x9C43, "preferclosepoints" },
    { 0x9C44, "preferclosetoally" },
    { 0x9C45, "preferdompoints" },
    { 0x9C46, "preferneargroupsofteammates" },
    { 0x9C47, "prefernearlastteamspawn" },
    { 0x9C48, "prefernearsinglepoint" },
    { 0x9C49, "preferoccupiedlanes" },
    { 0x9C4A, "preferoptimalttlos" },
    { 0x9C4B, "preferred_crash_style" },
    { 0x9C4C, "preferredtarget" },
    { 0x9C4D, "prefers_drones" },
    { 0x9C4E, "prefershortestdisttokothzone" },
    { 0x9C4F, "prefertobalancelanes" },
    { 0x9C50, "prekillcamnotify" },
    { 0x9C51, "preload" },
    { 0x9C52, "preload_transients" },
    { 0x9C53, "preload_transients_sa" },
    { 0x9C54, "preloadandqueueclass" },
    { 0x9C55, "preloadandqueueclassstruct" },
    { 0x9C56, "preloadedclassstruct" },
    { 0x9C57, "preloadfinalkillcam" },
    { 0x9C58, "prematch_over" },
    { 0x9C59, "prematchaddkillfunc" },
    { 0x9C5A, "prematchallowfunc" },
    { 0x9C5B, "prematchcountdownnotify" },
    { 0x9C5C, "prematchdeployparachute" },
    { 0x9C5D, "prematchfunc" },
    { 0x9C5E, "prematchlook" },
    { 0x9C5F, "prematchperiod" },
    { 0x9C60, "prematchperiodend" },
    { 0x9C61, "prematchspawnoriginnextidx" },
    { 0x9C62, "prematchspawnorigins" },
    { 0x9C63, "prematchspawnoriginsforteams" },
    { 0x9C64, "prematchstarted" },
    { 0x9C65, "prematurecornergrenadedeath" },
    { 0x9C66, "premoddamagecallbacks" },
    { 0x9C67, "premoddamagefunc" },
    { 0x9C68, "prep_player_and_enemy" },
    { 0x9C69, "prepare_option_for_change" },
    { 0x9C6A, "prepare_player_for_viewmodel_anim" },
    { 0x9C6B, "prepareplayerforrespawn" },
    { 0x9C6C, "preparetograb" },
    { 0x9C6D, "preparetohoist" },
    { 0x9C6E, "preplayerdamaged" },
    { 0x9C6F, "prereqs" },
    { 0x9C70, "prespawn_suspended_ai" },
    { 0x9C71, "prespawnfromspectaorfunc" },
    { 0x9C72, "prespawnfromspectatorfunc" },
    { 0x9C73, "press_defuse_button_on_detonator" },
    { 0x9C74, "pressed" },
    { 0x9C75, "prestige_getdamagetakenscalar" },
    { 0x9C76, "prestige_getminammo" },
    { 0x9C77, "prestige_getmoneyearnedscalar" },
    { 0x9C78, "prestige_getmoveslowscalar" },
    { 0x9C79, "prestige_getnoabilities" },
    { 0x9C7A, "prestige_getnoclassallowed" },
    { 0x9C7B, "prestige_getnodeployables" },
    { 0x9C7C, "prestige_getpistolsonly" },
    { 0x9C7D, "prestige_getslowhealthregenscalar" },
    { 0x9C7E, "prestige_getthreatbiasscalar" },
    { 0x9C7F, "prestige_getwalletsizescalar" },
    { 0x9C80, "prestige_getweapondamagescalar" },
    { 0x9C81, "prestige_nerf_func" },
    { 0x9C82, "prestigedoubleweaponxp" },
    { 0x9C83, "prestigeextras" },
    { 0x9C84, "prestigehealthregennerfscalar" },
    { 0x9C85, "prestreamgeo" },
    { 0x9C86, "prestreamgeotimeout" },
    { 0x9C87, "prev_anim_name" },
    { 0x9C88, "prev_defend_node" },
    { 0x9C89, "prev_node" },
    { 0x9C8A, "prev_num_active_zones" },
    { 0x9C8B, "prev_personality" },
    { 0x9C8C, "prev_role" },
    { 0x9C8D, "prev_time" },
    { 0x9C8E, "prevangles" },
    { 0x9C8F, "prevattack" },
    { 0x9C90, "prevatvdeath" },
    { 0x9C91, "prevatvdeathtime" },
    { 0x9C92, "prevbody" },
    { 0x9C93, "prevbomb" },
    { 0x9C94, "prevbomb2" },
    { 0x9C95, "prevclass" },
    { 0x9C96, "prevclassstruct" },
    { 0x9C97, "prevclothtype" },
    { 0x9C98, "prevduckangles" },
    { 0x9C99, "prevent_redraw" },
    { 0x9C9A, "preventpainforashorttime" },
    { 0x9C9B, "preventrecentanimindex" },
    { 0x9C9C, "preventstarttime" },
    { 0x9C9D, "preventuse" },
    { 0x9C9E, "prevflag" },
    { 0x9C9F, "prevflag2" },
    { 0x9CA0, "prevframevelocity" },
    { 0x9CA1, "prevguy_dist_max" },
    { 0x9CA2, "prevhead" },
    { 0x9CA3, "prevhealth" },
    { 0x9CA4, "previdlerumbletime" },
    { 0x9CA5, "previewbomb" },
    { 0x9CA6, "previewbuildfirstallies" },
    { 0x9CA7, "previewbuildfirstaxis" },
    { 0x9CA8, "previewmodels" },
    { 0x9CA9, "previous_button" },
    { 0x9CAA, "previous_cam" },
    { 0x9CAB, "previous_kidnap_attempt_time" },
    { 0x9CAC, "previous_node" },
    { 0x9CAD, "previous_state" },
    { 0x9CAE, "previous_struct" },
    { 0x9CAF, "previous_vehicle_seat" },
    { 0x9CB0, "previous_weapon" },
    { 0x9CB1, "previousanim" },
    { 0x9CB2, "previouscarrier" },
    { 0x9CB3, "previousclosespawnent" },
    { 0x9CB4, "previouslevelcompleted" },
    { 0x9CB5, "previouslytouchedtriggertype" },
    { 0x9CB6, "previousmapselectioninfo" },
    { 0x9CB7, "previousobjectiveindex" },
    { 0x9CB8, "previousoverridewarningindex" },
    { 0x9CB9, "previouspatrolpoint" },
    { 0x9CBA, "previousplayerorigin" },
    { 0x9CBB, "previousplayertimenearai" },
    { 0x9CBC, "previouspoints" },
    { 0x9CBD, "previousremotetankviewstate" },
    { 0x9CBE, "previousscramblerstrength" },
    { 0x9CBF, "previousstate" },
    { 0x9CC0, "previousstatename" },
    { 0x9CC1, "previousstreakpoints" },
    { 0x9CC2, "previouswarningcooldowntime" },
    { 0x9CC3, "previousweaponbeforenukein747" },
    { 0x9CC4, "previs_model" },
    { 0x9CC5, "prevlastkilltime" },
    { 0x9CC6, "prevlightmeter" },
    { 0x9CC7, "prevmaxhealth" },
    { 0x9CC8, "prevmoveright" },
    { 0x9CC9, "prevmoverumbletime" },
    { 0x9CCA, "prevobj" },
    { 0x9CCB, "prevorigin" },
    { 0x9CCC, "prevownerteam" },
    { 0x9CCD, "prevpathdist" },
    { 0x9CCE, "prevpathlookahead" },
    { 0x9CCF, "prevpitchdelta" },
    { 0x9CD0, "prevplayeronright" },
    { 0x9CD1, "prevprogress" },
    { 0x9CD2, "prevradio" },
    { 0x9CD3, "prevradio2" },
    { 0x9CD4, "prevradius" },
    { 0x9CD5, "prevregion" },
    { 0x9CD6, "prevrevivenodepos" },
    { 0x9CD7, "prevrevivepos" },
    { 0x9CD8, "prevsnowmobiledeath" },
    { 0x9CD9, "prevsnowmobiledeathtime" },
    { 0x9CDA, "prevspawnpos" },
    { 0x9CDB, "prevspawnpos2" },
    { 0x9CDC, "prevspeedscale" },
    { 0x9CDD, "prevstartingweap" },
    { 0x9CDE, "prevsuit" },
    { 0x9CDF, "prevteam" },
    { 0x9CE0, "prevval" },
    { 0x9CE1, "prevviewangles" },
    { 0x9CE2, "prevviewmodel" },
    { 0x9CE3, "prevweapon" },
    { 0x9CE4, "prevweaponobj" },
    { 0x9CE5, "prevyawdelta" },
    { 0x9CE6, "prevzoneindex" },
    { 0x9CE7, "prevzonelist" },
    { 0x9CE8, "pri_bunker_last_line" },
    { 0x9CE9, "price" },
    { 0x9CEA, "price_adjust_accuracy_over_time" },
    { 0x9CEB, "price_ads_anims" },
    { 0x9CEC, "price_advance_trigger" },
    { 0x9CED, "price_ai" },
    { 0x9CEE, "price_ammo_pickup" },
    { 0x9CEF, "price_and_player_ignored" },
    { 0x9CF0, "price_approach_gate" },
    { 0x9CF1, "price_at_attic_door" },
    { 0x9CF2, "price_bottom_stairs" },
    { 0x9CF3, "price_breach_door" },
    { 0x9CF4, "price_car_enter" },
    { 0x9CF5, "price_clean_up_last_enemy" },
    { 0x9CF6, "price_clip" },
    { 0x9CF7, "price_color_trigger" },
    { 0x9CF8, "price_color_trigger_set" },
    { 0x9CF9, "price_compound_run_triggers_on" },
    { 0x9CFA, "price_content_warning" },
    { 0x9CFB, "price_dataciv_is_dead" },
    { 0x9CFC, "price_dialog_struct" },
    { 0x9CFD, "price_dining_room" },
    { 0x9CFE, "price_dining_room_end" },
    { 0x9CFF, "price_directions_finished" },
    { 0x9D00, "price_dof" },
    { 0x9D01, "price_door_lookats" },
    { 0x9D02, "price_door_nag" },
    { 0x9D03, "price_ending_cinematic" },
    { 0x9D04, "price_exit_vo" },
    { 0x9D05, "price_exits_light_tut" },
    { 0x9D06, "price_face_swap" },
    { 0x9D07, "price_field_nag" },
    { 0x9D08, "price_gate_anim" },
    { 0x9D09, "price_get_los_enemy" },
    { 0x9D0A, "price_goes_hot" },
    { 0x9D0B, "price_gun_fire" },
    { 0x9D0C, "price_gun_pickup_anims" },
    { 0x9D0D, "price_gun_recall" },
    { 0x9D0E, "price_gun_remove" },
    { 0x9D0F, "price_hat_pickup" },
    { 0x9D10, "price_hostage_poi" },
    { 0x9D11, "price_hot_cleanup" },
    { 0x9D12, "price_hot_or_not" },
    { 0x9D13, "price_intro_debris_and_interact" },
    { 0x9D14, "price_intro_dof" },
    { 0x9D15, "price_intro_fov" },
    { 0x9D16, "price_intro_lighting" },
    { 0x9D17, "price_intro_vo_finished" },
    { 0x9D18, "price_kill" },
    { 0x9D19, "price_kill_logic" },
    { 0x9D1A, "price_kills_left_guys" },
    { 0x9D1B, "price_kills_rappel_enemies" },
    { 0x9D1C, "price_kills_right_side_light_enemies_then_goes_hot" },
    { 0x9D1D, "price_lab_nag" },
    { 0x9D1E, "price_lighting" },
    { 0x9D1F, "price_line" },
    { 0x9D20, "price_meet_sas_scene" },
    { 0x9D21, "price_mortar_roof_exit" },
    { 0x9D22, "price_mortar_run" },
    { 0x9D23, "price_mortar_run_field_path" },
    { 0x9D24, "price_mortar_run_triggers_on" },
    { 0x9D25, "price_move_midway" },
    { 0x9D26, "price_nvg_check" },
    { 0x9D27, "price_offer_bullets" },
    { 0x9D28, "price_pistol_fire" },
    { 0x9D29, "price_pistol_pickup" },
    { 0x9D2A, "price_place_revolver" },
    { 0x9D2B, "price_poi" },
    { 0x9D2C, "price_push_off" },
    { 0x9D2D, "price_push_on" },
    { 0x9D2E, "price_rally_nags" },
    { 0x9D2F, "price_redshirt" },
    { 0x9D30, "price_set_accuracy_average" },
    { 0x9D31, "price_set_accuracy_high" },
    { 0x9D32, "price_set_accuracy_low" },
    { 0x9D33, "price_set_accuracy_max" },
    { 0x9D34, "price_shoots_light_timeout" },
    { 0x9D35, "price_silenced_pistol_hack" },
    { 0x9D36, "price_spawn_func" },
    { 0x9D37, "price_spec_catchup" },
    { 0x9D38, "price_spec_intro" },
    { 0x9D39, "price_spec_main" },
    { 0x9D3A, "price_spec_start" },
    { 0x9D3B, "price_stealth_reprimand" },
    { 0x9D3C, "price_stop_use_pistol" },
    { 0x9D3D, "price_to_idle_to_climb" },
    { 0x9D3E, "price_tunnel_think" },
    { 0x9D3F, "price_use_pistol" },
    { 0x9D40, "priceanimnode" },
    { 0x9D41, "priceshootcount" },
    { 0x9D42, "primary_weapon_array" },
    { 0x9D43, "primary_weapons" },
    { 0x9D44, "primaryanchorpos" },
    { 0x9D45, "primaryentity" },
    { 0x9D46, "primaryflags" },
    { 0x9D47, "primaryflags2" },
    { 0x9D48, "primarygrenade" },
    { 0x9D49, "primarymode" },
    { 0x9D4A, "primarymodefunc" },
    { 0x9D4B, "primarymodestring" },
    { 0x9D4C, "primaryobjectives" },
    { 0x9D4D, "primaryprogressbarfontsize" },
    { 0x9D4E, "primaryprogressbarheight" },
    { 0x9D4F, "primaryprogressbartextx" },
    { 0x9D50, "primaryprogressbartexty" },
    { 0x9D51, "primaryprogressbarwidth" },
    { 0x9D52, "primaryprogressbarx" },
    { 0x9D53, "primaryprogressbary" },
    { 0x9D54, "primarytarget" },
    { 0x9D55, "primaryweapon_leave_behind" },
    { 0x9D56, "primaryweapon_leave_behind_internal" },
    { 0x9D57, "primaryweaponclipammo" },
    { 0x9D58, "primaryweaponobj" },
    { 0x9D59, "primaryweaponstockammo" },
    { 0x9D5A, "prime_attic_door_states" },
    { 0x9D5B, "primedents" },
    { 0x9D5C, "print_active_modules_to_screen" },
    { 0x9D5D, "print_bonus_time_text" },
    { 0x9D5E, "print_console_debug" },
    { 0x9D5F, "print_debug" },
    { 0x9D60, "print_debug_info" },
    { 0x9D61, "print_display_name_on_source" },
    { 0x9D62, "print_dot" },
    { 0x9D63, "print_fx_options" },
    { 0x9D64, "print_key_strings" },
    { 0x9D65, "print_last_anim_info" },
    { 0x9D66, "print_leads_text_max" },
    { 0x9D67, "print_navtrace" },
    { 0x9D68, "print_nitrate_text" },
    { 0x9D69, "print_no_achievement" },
    { 0x9D6A, "print_notetrack" },
    { 0x9D6B, "print_org" },
    { 0x9D6C, "print_position_values" },
    { 0x9D6D, "print_reaction_state" },
    { 0x9D6E, "print_screen_pos_from_center" },
    { 0x9D6F, "print_spawnpoint_debug" },
    { 0x9D70, "print_timer" },
    { 0x9D71, "print_total_leads_text" },
    { 0x9D72, "print_type_text" },
    { 0x9D73, "print_vehicle_info" },
    { 0x9D74, "print2d3d_debug" },
    { 0x9D75, "print3d_ai" },
    { 0x9D76, "print3d_debug" },
    { 0x9D77, "print3d_on_me" },
    { 0x9D78, "print3dfortime" },
    { 0x9D79, "print3donme" },
    { 0x9D7A, "print3drise" },
    { 0x9D7B, "print3dtime" },
    { 0x9D7C, "printabovehead" },
    { 0x9D7D, "printandsoundoneveryone" },
    { 0x9D7E, "printandsoundonplayer" },
    { 0x9D7F, "printandsoundonteam" },
    { 0x9D80, "printboldonteam" },
    { 0x9D81, "printboldonteamarg" },
    { 0x9D82, "printcustomization" },
    { 0x9D83, "printdisplaceinfo" },
    { 0x9D84, "printed" },
    { 0x9D85, "printgameaction" },
    { 0x9D86, "printheap" },
    { 0x9D87, "printnotetracks" },
    { 0x9D88, "printonplayers" },
    { 0x9D89, "printonteam" },
    { 0x9D8A, "printonteamarg" },
    { 0x9D8B, "printothint" },
    { 0x9D8C, "printpermute" },
    { 0x9D8D, "printplayerdatastats" },
    { 0x9D8E, "printqueueevent" },
    { 0x9D8F, "printshoot" },
    { 0x9D90, "printshootproc" },
    { 0x9D91, "printstartupdebugmessages" },
    { 0x9D92, "printweapon" },
    { 0x9D93, "prioritize_colorcoded_nodes" },
    { 0x9D94, "prioritize_knock_off_on_context_melee" },
    { 0x9D95, "prioritize_watch_nodes_toward_enemies" },
    { 0x9D96, "priority" },
    { 0x9D97, "priority_array_list" },
    { 0x9D98, "priority_func" },
    { 0x9D99, "priority_player" },
    { 0x9D9A, "priority_queue" },
    { 0x9D9B, "prioritygroup" },
    { 0x9D9C, "prioritymultiplier" },
    { 0x9D9D, "prisoner_loop_window_scene_till_dead" },
    { 0x9D9E, "prisoner_secured" },
    { 0x9D9F, "prisoner_spawn_func" },
    { 0x9DA0, "prisoners_react_to_enemy" },
    { 0x9DA1, "privatematch" },
    { 0x9DA2, "probabilities" },
    { 0x9DA3, "probabilityarmor" },
    { 0x9DA4, "probabilityfunc" },
    { 0x9DA5, "probabilityoffhand" },
    { 0x9DA6, "probabilityzero" },
    { 0x9DA7, "probe" },
    { 0x9DA8, "probesoffset" },
    { 0x9DA9, "process_action" },
    { 0x9DAA, "process_action_override" },
    { 0x9DAB, "process_agent_on_killed_merits" },
    { 0x9DAC, "process_blend" },
    { 0x9DAD, "process_button_held_and_clicked" },
    { 0x9DAE, "process_color_order_to_ai" },
    { 0x9DAF, "process_concrete_blocker_controlling_struct" },
    { 0x9DB0, "process_convoy_path_noteworthy" },
    { 0x9DB1, "process_cover_node" },
    { 0x9DB2, "process_cover_node_with_last_in_mind_allies" },
    { 0x9DB3, "process_cover_node_with_last_in_mind_axis" },
    { 0x9DB4, "process_damage_feedback" },
    { 0x9DB5, "process_damage_rewards" },
    { 0x9DB6, "process_damage_score" },
    { 0x9DB7, "process_deathflags" },
    { 0x9DB8, "process_dvarfuncs" },
    { 0x9DB9, "process_frame_events" },
    { 0x9DBA, "process_fx_rotater" },
    { 0x9DBB, "process_kill_rewards" },
    { 0x9DBC, "process_linked_ents" },
    { 0x9DBD, "process_linked_structs" },
    { 0x9DBE, "process_module_params" },
    { 0x9DBF, "process_module_var" },
    { 0x9DC0, "process_moving_platform_death" },
    { 0x9DC1, "process_nextpoint_after_struct_wait" },
    { 0x9DC2, "process_path_node" },
    { 0x9DC3, "process_rank_merits" },
    { 0x9DC4, "process_stop_short_of_node" },
    { 0x9DC5, "process_turret_sweep_nodes" },
    { 0x9DC6, "process_vehicle_struct_node" },
    { 0x9DC7, "processassist" },
    { 0x9DC8, "processassist_regularmp" },
    { 0x9DC9, "processcalloutdeath" },
    { 0x9DCA, "processcameradata" },
    { 0x9DCB, "processcontext" },
    { 0x9DCC, "processdamage" },
    { 0x9DCD, "processdoublejumpmantletraversal" },
    { 0x9DCE, "processedwinloss" },
    { 0x9DCF, "processepictaunt" },
    { 0x9DD0, "processevent" },
    { 0x9DD1, "processeventforwitnesses" },
    { 0x9DD2, "processfinalkillchallenges" },
    { 0x9DD3, "processfreegroupname" },
    { 0x9DD4, "processiconposref" },
    { 0x9DD5, "processing" },
    { 0x9DD6, "processkillstreaksintotiers" },
    { 0x9DD7, "processlobbydata" },
    { 0x9DD8, "processlobbyscoreboards" },
    { 0x9DD9, "processmastermerit" },
    { 0x9DDA, "processmerit" },
    { 0x9DDB, "processnoscopeoutlinesetnotifs" },
    { 0x9DDC, "processnoscopeoutlineunsetnotifs" },
    { 0x9DDD, "processnotifyweapondrop" },
    { 0x9DDE, "processot" },
    { 0x9DDF, "processscoring" },
    { 0x9DE0, "processshieldassist" },
    { 0x9DE1, "processshieldassist_regularmp" },
    { 0x9DE2, "processtauntsound" },
    { 0x9DE3, "processtimelineevent" },
    { 0x9DE4, "processtimeout" },
    { 0x9DE5, "processtripwiretarget" },
    { 0x9DE6, "processuavassist" },
    { 0x9DE7, "processwallruntraversal" },
    { 0x9DE8, "progress" },
    { 0x9DE9, "progress_bar" },
    { 0x9DEA, "progress_objective_on_group_killed" },
    { 0x9DEB, "progress_objective_on_group_killed_interal" },
    { 0x9DEC, "progress_objective_on_veh_group_killed" },
    { 0x9DED, "progress_objective_on_veh_group_killed_interal" },
    { 0x9DEE, "progression" },
    { 0x9DEF, "progression_gates" },
    { 0x9DF0, "projectedalliescenter" },
    { 0x9DF1, "projectedaxiscenter" },
    { 0x9DF2, "projectedtargetpos" },
    { 0x9DF3, "projectile" },
    { 0x9DF4, "projectiledeathcounter" },
    { 0x9DF5, "projectilehits" },
    { 0x9DF6, "projectileimpactcoutner" },
    { 0x9DF7, "projectilekillstreaks" },
    { 0x9DF8, "projectilenearbydialogs" },
    { 0x9DF9, "projimpacted" },
    { 0x9DFA, "promode" },
    { 0x9DFB, "promote_nearest_friendly" },
    { 0x9DFC, "promote_nearest_friendly_with_classname" },
    { 0x9DFD, "prompt_knife" },
    { 0x9DFE, "prompt_moved" },
    { 0x9DFF, "prone_only" },
    { 0x9E00, "prone_speedup" },
    { 0x9E01, "prone_visible_from" },
    { 0x9E02, "proneaiming" },
    { 0x9E03, "pronedetectdist" },
    { 0x9E04, "proneogspeed" },
    { 0x9E05, "proneupoffset" },
    { 0x9E06, "pronevisiblenodes" },
    { 0x9E07, "prop" },
    { 0x9E08, "prop_deathanim" },
    { 0x9E09, "propagandaent" },
    { 0x9E0A, "propagate_event_thread" },
    { 0x9E0B, "propane_reset_position" },
    { 0x9E0C, "propane_rocket_badplace_manager" },
    { 0x9E0D, "propane_rockets_init" },
    { 0x9E0E, "propdistance" },
    { 0x9E0F, "propmodel" },
    { 0x9E10, "props_spawned" },
    { 0x9E11, "proptablelookat" },
    { 0x9E12, "propweapon" },
    { 0x9E13, "protect_current_headquarters" },
    { 0x9E14, "protect_radius" },
    { 0x9E15, "protect_watch_allies" },
    { 0x9E16, "prox_open_door" },
    { 0x9E17, "proxbar" },
    { 0x9E18, "proxbartext" },
    { 0x9E19, "proxcmdwatcher" },
    { 0x9E1A, "proxentlos" },
    { 0x9E1B, "proximity_alert" },
    { 0x9E1C, "proximity_bump_dist_sqr_override" },
    { 0x9E1D, "proximity_check" },
    { 0x9E1E, "proximity_combat_radius_bump" },
    { 0x9E1F, "proximity_combat_radius_fake_sight" },
    { 0x9E20, "proximity_combat_radius_sight" },
    { 0x9E21, "proximity_spawn" },
    { 0x9E22, "proximity_spawn_think" },
    { 0x9E23, "proximity_spawning" },
    { 0x9E24, "proximity_threat_func" },
    { 0x9E25, "proximity_threat_func_hometown" },
    { 0x9E26, "proximity_trig" },
    { 0x9E27, "proximityassist" },
    { 0x9E28, "proximitydata" },
    { 0x9E29, "proximitykill" },
    { 0x9E2A, "proximityrevive" },
    { 0x9E2B, "proximityrevivefauxtrigger" },
    { 0x9E2C, "proximityrevivethink" },
    { 0x9E2D, "proxtriggerlos" },
    { 0x9E2E, "proxtriggerthink" },
    { 0x9E2F, "proxy_cameraman_handler" },
    { 0x9E30, "proxy_execution_fail_hide_names" },
    { 0x9E31, "proxy_executioner_handler" },
    { 0x9E32, "proxy_hostage_1_handler" },
    { 0x9E33, "proxy_hostage_2_handler" },
    { 0x9E34, "proxy_hostage_3_handler" },
    { 0x9E35, "proxy_hostage_killed_fail_state" },
    { 0x9E36, "proxy_wolf" },
    { 0x9E37, "proxyaniminit" },
    { 0x9E38, "proxydisableweapon" },
    { 0x9E39, "proxywar_check_crouch" },
    { 0x9E3A, "proxywar_check_grenade_throw" },
    { 0x9E3B, "proxywar_check_offhand_throw" },
    { 0x9E3C, "proxywar_check_swap_weapon" },
    { 0x9E3D, "proxywar_courtyard_flags" },
    { 0x9E3E, "proxywar_courtyard_hints" },
    { 0x9E3F, "proxywar_courtyard_precache" },
    { 0x9E40, "proxywar_courtyard_spawn_func" },
    { 0x9E41, "proxywar_flags" },
    { 0x9E42, "proxywar_forest_flags" },
    { 0x9E43, "proxywar_forest_hints" },
    { 0x9E44, "proxywar_forest_init" },
    { 0x9E45, "proxywar_forest_precache" },
    { 0x9E46, "proxywar_forest_spawn_funcs" },
    { 0x9E47, "proxywar_heli_flags" },
    { 0x9E48, "proxywar_heli_hints" },
    { 0x9E49, "proxywar_heli_init" },
    { 0x9E4A, "proxywar_heli_precache" },
    { 0x9E4B, "proxywar_hints" },
    { 0x9E4C, "proxywar_init" },
    { 0x9E4D, "proxywar_intro_screen" },
    { 0x9E4E, "proxywar_loadout" },
    { 0x9E4F, "proxywar_precache" },
    { 0x9E50, "proxywar_railyard_flags" },
    { 0x9E51, "proxywar_railyard_hints" },
    { 0x9E52, "proxywar_railyard_precache" },
    { 0x9E53, "proxywar_railyard_spawn_funcs" },
    { 0x9E54, "proxywar_spawn_funcs" },
    { 0x9E55, "proxywar_starts" },
    { 0x9E56, "proxywar_threat_bias" },
    { 0x9E57, "proxywar_timeout" },
    { 0x9E58, "proxywar_trucks_flags" },
    { 0x9E59, "proxywar_trucks_hints" },
    { 0x9E5A, "proxywar_trucks_init" },
    { 0x9E5B, "proxywar_trucks_objectives" },
    { 0x9E5C, "proxywar_trucks_precache" },
    { 0x9E5D, "proxywar_trucks_spawnfuncs" },
    { 0x9E5E, "proxywar_tutorials" },
    { 0x9E5F, "proxywar_vo_flags" },
    { 0x9E60, "proxywar_warehouse_flags" },
    { 0x9E61, "proxywar_warehouse_hints" },
    { 0x9E62, "proxywar_warehouse_init" },
    { 0x9E63, "proxywar_warehouse_precache" },
    { 0x9E64, "proxywar_warehouse_spawn_func" },
    { 0x9E65, "pull_player_out_of_rig_hide_rig" },
    { 0x9E66, "pull_player_out_of_rig_hide_rig_no_stance_mod" },
    { 0x9E67, "pullattachmentsforweapon" },
    { 0x9E68, "pullback" },
    { 0x9E69, "pullbackoffset" },
    { 0x9E6A, "pullbackstruct" },
    { 0x9E6B, "pullbothup" },
    { 0x9E6C, "pullchute" },
    { 0x9E6D, "pullinref" },
    { 0x9E6E, "pullinteract" },
    { 0x9E6F, "pulluptrigger" },
    { 0x9E70, "pulluptriggerthink" },
    { 0x9E71, "pulse" },
    { 0x9E72, "pulse_ai" },
    { 0x9E73, "pulse_blur" },
    { 0x9E74, "pulse_soldiers_to_help_convoy" },
    { 0x9E75, "pulsedarts" },
    { 0x9E76, "pulsegrenade_earthquake" },
    { 0x9E77, "pulsesfx" },
    { 0x9E78, "pulsesin" },
    { 0x9E79, "pulsesinx" },
    { 0x9E7A, "pulsesinxrate" },
    { 0x9E7B, "pulsetime" },
    { 0x9E7C, "pumpjacks" },
    { 0x9E7D, "purchase_type" },
    { 0x9E7E, "purchasing_ammo" },
    { 0x9E7F, "purge_undefined" },
    { 0x9E80, "purify_activate" },
    { 0x9E81, "pursuer" },
    { 0x9E82, "pursuit_autosave" },
    { 0x9E83, "pursuit_death_flag_save" },
    { 0x9E84, "pursuit_early_autosave" },
    { 0x9E85, "pursuit_hud_cleanup" },
    { 0x9E86, "pursuit_timer" },
    { 0x9E87, "pursuit_timer_fail" },
    { 0x9E88, "push" },
    { 0x9E89, "push_conditions" },
    { 0x9E8A, "push_delay" },
    { 0x9E8B, "push_door" },
    { 0x9E8C, "push_door_override" },
    { 0x9E8D, "push_door_player_effects" },
    { 0x9E8E, "push_hint_duration_think" },
    { 0x9E8F, "push_hint_think" },
    { 0x9E90, "push_loc_into_storage" },
    { 0x9E91, "push_magic_coefficient" },
    { 0x9E92, "push_manager" },
    { 0x9E93, "push_monitor" },
    { 0x9E94, "push_player" },
    { 0x9E95, "push_players_out_of_the_way" },
    { 0x9E96, "push_rumble" },
    { 0x9E97, "push_stick_intensity" },
    { 0x9E98, "push_up_mortar_house" },
    { 0x9E99, "push_vfx" },
    { 0x9E9A, "push_yaw_delta" },
    { 0x9E9B, "push_yaw_delta_live" },
    { 0x9E9C, "pushdisabledgunpose" },
    { 0x9E9D, "pushents" },
    { 0x9E9E, "pushents_clear" },
    { 0x9E9F, "pusher1" },
    { 0x9EA0, "pusher2" },
    { 0x9EA1, "pushgimmeslotstreakontostack" },
    { 0x9EA2, "pushing_mine_cart" },
    { 0x9EA3, "pushlogic" },
    { 0x9EA4, "pushmonitor" },
    { 0x9EA5, "pushplayertodoor" },
    { 0x9EA6, "pushplayertoplayeroffset" },
    { 0x9EA7, "pushproxcheck" },
    { 0x9EA8, "put_guy_in_truck" },
    { 0x9EA9, "put_hvi_into_decho_rebel" },
    { 0x9EAA, "put_icon_on_hvt_vehicle" },
    { 0x9EAB, "put_icon_on_vehicle" },
    { 0x9EAC, "put_icon_on_vehicle_repair_point" },
    { 0x9EAD, "put_into_player_false_positive_bank" },
    { 0x9EAE, "put_objective_icon_on_cruise_missile" },
    { 0x9EAF, "put_objective_icon_on_interceptor_missile" },
    { 0x9EB0, "put_objective_icon_on_reaper_missile_target_ent" },
    { 0x9EB1, "put_objective_icon_on_warhead" },
    { 0x9EB2, "put_player_into_cam_rig" },
    { 0x9EB3, "put_player_into_rig" },
    { 0x9EB4, "put_player_into_rig_no_stance_mod" },
    { 0x9EB5, "put_player_on_cam" },
    { 0x9EB6, "put_riders_into_decho_dirty" },
    { 0x9EB7, "put_riders_into_decho_rebel" },
    { 0x9EB8, "put_target_marker_on_critical_enemy_ai" },
    { 0x9EB9, "putgunaway" },
    { 0x9EBA, "putgunbackinhandonkillanimscript" },
    { 0x9EBB, "putguninhand" },
    { 0x9EBC, "putonground" },
    { 0x9EBD, "putweaponbackinrighthand" },
    { 0x9EBE, "puzzle_clip" },
    { 0x9EBF, "puzzle_piece" },
    { 0x9EC0, "pvpe_allow_munitions" },
    { 0x9EC1, "pvpe_allow_players_to_restart" },
    { 0x9EC2, "pvpe_allow_super" },
    { 0x9EC3, "pvpe_disable_bleedout_ent_usability_func" },
    { 0x9EC4, "pvpe_enable_bleedout_ent_usability_func" },
    { 0x9EC5, "pvpe_enabled" },
    { 0x9EC6, "pvpe_end_game" },
    { 0x9EC7, "pvpe_force_end_game" },
    { 0x9EC8, "pvpe_game_should_really_end" },
    { 0x9EC9, "pvpe_gameshouldendfunc" },
    { 0x9ECA, "pvpe_get_num_of_charges_for_power" },
    { 0x9ECB, "pvpe_player_connect_monitor" },
    { 0x9ECC, "pvpe_playerspawnsessionteamassignmentfunc" },
    { 0x9ECD, "pvpe_playerspawnteamassignmentfunc" },
    { 0x9ECE, "pvpe_pre_map_restart_func" },
    { 0x9ECF, "pvpe_revive_ent_usability_func" },
    { 0x9ED0, "pvpe_round_timer" },
    { 0x9ED1, "pvpe_terrorist_players_respawn_timer" },
    { 0x9ED2, "pvpve_break_doors" },
    { 0x9ED3, "pvpve_enabled" },
    { 0x9ED4, "pw" },
    { 0x9ED5, "pw_behind_buffer" },
    { 0x9ED6, "pw_infront_buffer" },
    { 0x9ED7, "pyramid_death_report" },
    { 0x9ED8, "pyramid_spawn" },
    { 0x9ED9, "pyramid_spawner_reports_death" },
    { 0x9EDA, "python_enter" },
    { 0x9EDB, "python_longdeath_callback" },
    { 0x9EDC, "qafinished" },
    { 0x9EDD, "qlerp" },
    { 0x9EDE, "qsetgoalpos" },
    { 0x9EDF, "quadfeed" },
    { 0x9EE0, "quadfeedinfo" },
    { 0x9EE1, "quadrantanimweights" },
    { 0x9EE2, "quality" },
    { 0x9EE3, "quantitycommon" },
    { 0x9EE4, "quantityepic" },
    { 0x9EE5, "quantitylegendary" },
    { 0x9EE6, "quantityrare" },
    { 0x9EE7, "quarry_hacking_sfx" },
    { 0x9EE8, "quest_line_exist" },
    { 0x9EE9, "quest_step_func" },
    { 0x9EEA, "questcategory" },
    { 0x9EEB, "questdeletedomgameobject" },
    { 0x9EEC, "questinfo" },
    { 0x9EED, "questinstances" },
    { 0x9EEE, "question_answer_check" },
    { 0x9EEF, "question_barkov_response" },
    { 0x9EF0, "questlocale" },
    { 0x9EF1, "quests" },
    { 0x9EF2, "questtype" },
    { 0x9EF3, "queue" },
    { 0x9EF4, "queue_dialogue" },
    { 0x9EF5, "queue_dialogue_for_team" },
    { 0x9EF6, "queue_gesture_reaction" },
    { 0x9EF7, "queue_interaction_vo" },
    { 0x9EF8, "queue_reminder" },
    { 0x9EF9, "queue_reminder_distance_anim" },
    { 0x9EFA, "queue_reminder_with_reaction" },
    { 0x9EFB, "queueadd" },
    { 0x9EFC, "queueanimationafter" },
    { 0x9EFD, "queuecapturekill" },
    { 0x9EFE, "queuecapturekillchoice" },
    { 0x9EFF, "queueclientforsquadspawn" },
    { 0x9F00, "queueconnectednotify" },
    { 0x9F01, "queuecreate" },
    { 0x9F02, "queuedstate" },
    { 0x9F03, "queuedswaploadout" },
    { 0x9F04, "queuedtaunts" },
    { 0x9F05, "queuedvo" },
    { 0x9F06, "queueforkillcam" },
    { 0x9F07, "queuemidmatchaward" },
    { 0x9F08, "queueremovefirst" },
    { 0x9F09, "queues" },
    { 0x9F0A, "queuescoreeventpopup" },
    { 0x9F0B, "queuescorepointspopup" },
    { 0x9F0C, "queuesplash" },
    { 0x9F0D, "queuetokens" },
    { 0x9F0E, "queuevehiclewakeup" },
    { 0x9F0F, "quick_fadeout_in" },
    { 0x9F10, "quick_fadeup" },
    { 0x9F11, "quick_maffs" },
    { 0x9F12, "quick_spawn_model" },
    { 0x9F13, "quick_wake_up" },
    { 0x9F14, "quickavailable" },
    { 0x9F15, "quicken_scene_speed_while_offscreen" },
    { 0x9F16, "quickmessagetoall" },
    { 0x9F17, "quicksort" },
    { 0x9F18, "quicksort_compare" },
    { 0x9F19, "quicksortmid" },
    { 0x9F1A, "quicktrigger" },
    { 0x9F1B, "quicktriggerthink" },
    { 0x9F1C, "quicktriggertimeout" },
    { 0x9F1D, "quietly_kill_all_axis" },
    { 0x9F1E, "r" },
    { 0x9F1F, "r1_deaths" },
    { 0x9F20, "r2_deaths" },
    { 0x9F21, "r3_deaths" },
    { 0x9F22, "raceendnotify" },
    { 0x9F23, "raceendon" },
    { 0x9F24, "rack_focus_between_tile_and_mom" },
    { 0x9F25, "rad_extractor_hint_displayed" },
    { 0x9F26, "radar" },
    { 0x9F27, "radar_block_count" },
    { 0x9F28, "radar_models" },
    { 0x9F29, "radar_structs" },
    { 0x9F2A, "radar_think" },
    { 0x9F2B, "radardrone_equipment_wrapper" },
    { 0x9F2C, "radarendgame" },
    { 0x9F2D, "radarhideshots" },
    { 0x9F2E, "radarpingtime" },
    { 0x9F2F, "radarviewtime" },
    { 0x9F30, "radial_distortion" },
    { 0x9F31, "radialhealer" },
    { 0x9F32, "radialtimeobjid" },
    { 0x9F33, "radians_to_degrees" },
    { 0x9F34, "radiant_cockpit_light" },
    { 0x9F35, "radiantplaced" },
    { 0x9F36, "radiationeffect" },
    { 0x9F37, "radiationoverlay" },
    { 0x9F38, "radiationsound" },
    { 0x9F39, "radio" },
    { 0x9F3A, "radio_dialog_struct" },
    { 0x9F3B, "radio_dialogue" },
    { 0x9F3C, "radio_dialogue_clear_stack" },
    { 0x9F3D, "radio_dialogue_interupt" },
    { 0x9F3E, "radio_dialogue_overlap" },
    { 0x9F3F, "radio_dialogue_queue" },
    { 0x9F40, "radio_dialogue_safe" },
    { 0x9F41, "radio_dialogue_stop" },
    { 0x9F42, "radio_getallypronenodes" },
    { 0x9F43, "radio_getinteractstruct" },
    { 0x9F44, "radio_getradioally" },
    { 0x9F45, "radio_getradioallynode" },
    { 0x9F46, "radio_in_use" },
    { 0x9F47, "radio_main" },
    { 0x9F48, "radio_nag" },
    { 0x9F49, "radio_radioallysurvivedlogic" },
    { 0x9F4A, "radio_spawnradioally" },
    { 0x9F4B, "radio_start" },
    { 0x9F4C, "radio_tower_switches" },
    { 0x9F4D, "radio_waittillplayernearradio" },
    { 0x9F4E, "radioforcedtransmissionqueue" },
    { 0x9F4F, "radioobject" },
    { 0x9F50, "radios" },
    { 0x9F51, "radios2" },
    { 0x9F52, "radiowatchplayerjoin" },
    { 0x9F53, "radius_damage" },
    { 0x9F54, "radius_detection_monitor" },
    { 0x9F55, "radius_detection_monitor_send_notify" },
    { 0x9F56, "radius_max_sq" },
    { 0x9F57, "radius_min_sq" },
    { 0x9F58, "radiusmax" },
    { 0x9F59, "radiuspathnodes" },
    { 0x9F5A, "radiusplayerdamage" },
    { 0x9F5B, "radiussqrd" },
    { 0x9F5C, "radtriggers" },
    { 0x9F5D, "radzones" },
    { 0x9F5E, "ragdoll_damagelocation_none" },
    { 0x9F5F, "ragdoll_death_after_anim" },
    { 0x9F60, "ragdoll_directionscale" },
    { 0x9F61, "ragdoll_fall_anim" },
    { 0x9F62, "ragdoll_focus_camera" },
    { 0x9F63, "ragdoll_focus_camera_clean_up_monitor" },
    { 0x9F64, "ragdoll_getout_death" },
    { 0x9F65, "ragdoll_immediate" },
    { 0x9F66, "ragdoll_start_vel" },
    { 0x9F67, "ragdolldeath" },
    { 0x9F68, "ragdollhitloc" },
    { 0x9F69, "ragdollimpactvector" },
    { 0x9F6A, "ragdolltime" },
    { 0x9F6B, "ragdollzerog" },
    { 0x9F6C, "raid_init_func" },
    { 0x9F6D, "raid_is_starting" },
    { 0x9F6E, "raid_obj_func" },
    { 0x9F6F, "raid_player_initial_spawner_script_noteworthy" },
    { 0x9F70, "rail_player_model" },
    { 0x9F71, "rail_player_model_shadow" },
    { 0x9F72, "railyard_breach_ally_alpha" },
    { 0x9F73, "railyard_breach_ally_alpha_speed" },
    { 0x9F74, "railyard_breach_ally_bravo" },
    { 0x9F75, "railyard_breach_breach_door" },
    { 0x9F76, "railyard_breach_catchup" },
    { 0x9F77, "railyard_breach_check_deaths" },
    { 0x9F78, "railyard_breach_door_open_checker" },
    { 0x9F79, "railyard_breach_enemy_individual" },
    { 0x9F7A, "railyard_breach_extinguisher_start_fx" },
    { 0x9F7B, "railyard_breach_extinguisher_stop_fx" },
    { 0x9F7C, "railyard_breach_main" },
    { 0x9F7D, "railyard_breach_player_fire_checker" },
    { 0x9F7E, "railyard_breach_player_flashlight_checker" },
    { 0x9F7F, "railyard_breach_player_looking_at_breach" },
    { 0x9F80, "railyard_breach_skip_ally_alpha" },
    { 0x9F81, "railyard_breach_skip_enemy" },
    { 0x9F82, "railyard_breach_start" },
    { 0x9F83, "railyard_breach_stop_fx_on_death" },
    { 0x9F84, "railyard_combat_allies_left" },
    { 0x9F85, "railyard_combat_allies_right" },
    { 0x9F86, "railyard_combat_catchup" },
    { 0x9F87, "railyard_combat_enemies" },
    { 0x9F88, "railyard_combat_enemy_individual" },
    { 0x9F89, "railyard_combat_enemy_individual_platform" },
    { 0x9F8A, "railyard_combat_enemy_individual_player_near_check" },
    { 0x9F8B, "railyard_combat_intro_alpha1" },
    { 0x9F8C, "railyard_combat_intro_alpha2" },
    { 0x9F8D, "railyard_combat_intro_catchup" },
    { 0x9F8E, "railyard_combat_intro_check_player_tries_door" },
    { 0x9F8F, "railyard_combat_intro_door" },
    { 0x9F90, "railyard_combat_intro_door_catchup" },
    { 0x9F91, "railyard_combat_intro_lmg" },
    { 0x9F92, "railyard_combat_intro_lmg_light" },
    { 0x9F93, "railyard_combat_intro_main" },
    { 0x9F94, "railyard_combat_intro_player_looking" },
    { 0x9F95, "railyard_combat_intro_start" },
    { 0x9F96, "railyard_combat_lmg" },
    { 0x9F97, "railyard_combat_lmg_check_being_suppressed" },
    { 0x9F98, "railyard_combat_lmg_check_can_see_player" },
    { 0x9F99, "railyard_combat_lmg_fire" },
    { 0x9F9A, "railyard_combat_lmg_search_behavior" },
    { 0x9F9B, "railyard_combat_lmg_suppress_ally" },
    { 0x9F9C, "railyard_combat_lmg_suppress_door_behavior" },
    { 0x9F9D, "railyard_combat_lmg_suppressed_behavior" },
    { 0x9F9E, "railyard_combat_lmg_track_player_behavior" },
    { 0x9F9F, "railyard_combat_machine_gunner" },
    { 0x9FA0, "railyard_combat_machine_gunner_attack_point" },
    { 0x9FA1, "railyard_combat_machine_gunner_check_damage" },
    { 0x9FA2, "railyard_combat_machine_gunner_check_player_near" },
    { 0x9FA3, "railyard_combat_machine_gunner_check_player_staring" },
    { 0x9FA4, "railyard_combat_machine_gunner_drop_weapon" },
    { 0x9FA5, "railyard_combat_machine_gunner_flag_on_death" },
    { 0x9FA6, "railyard_combat_machine_gunner_lethal_on_bypass" },
    { 0x9FA7, "railyard_combat_main" },
    { 0x9FA8, "railyard_combat_mg_grenade_check" },
    { 0x9FA9, "railyard_combat_mg_nest_destruction_fx" },
    { 0x9FAA, "railyard_combat_rus_railyard_left_start" },
    { 0x9FAB, "railyard_combat_rus_railyard_left_traincars" },
    { 0x9FAC, "railyard_combat_rus_railyard_mg_platform" },
    { 0x9FAD, "railyard_combat_rus_railyard_right_room" },
    { 0x9FAE, "railyard_combat_rus_railyard_right_traincar" },
    { 0x9FAF, "railyard_combat_rus_railyard_right_traincar_surprise" },
    { 0x9FB0, "railyard_combat_rus_railyard_start" },
    { 0x9FB1, "railyard_combat_setup_lmg" },
    { 0x9FB2, "railyard_combat_start" },
    { 0x9FB3, "railyard_combat_supressing_ally" },
    { 0x9FB4, "railyard_combat_threat_think" },
    { 0x9FB5, "railyard_combat_wait_dead_pct" },
    { 0x9FB6, "railyard_enemies" },
    { 0x9FB7, "railyard_entrance_allies" },
    { 0x9FB8, "railyard_entrance_burning_guy" },
    { 0x9FB9, "railyard_entrance_catchup" },
    { 0x9FBA, "railyard_entrance_crawling_guy" },
    { 0x9FBB, "railyard_entrance_crawling_guy_alpha2" },
    { 0x9FBC, "railyard_entrance_main" },
    { 0x9FBD, "railyard_entrance_pistol_guy" },
    { 0x9FBE, "railyard_entrance_pistol_guy_burning_fx" },
    { 0x9FBF, "railyard_entrance_setup_burned_rus" },
    { 0x9FC0, "railyard_entrance_start" },
    { 0x9FC1, "railyard_entrance_tower_collapse" },
    { 0x9FC2, "railyard_guards_comment" },
    { 0x9FC3, "railyard_lmg" },
    { 0x9FC4, "railyard_lmg_turn_off_light" },
    { 0x9FC5, "railyard_lmg_turn_on_light" },
    { 0x9FC6, "railyard_player_near_breach" },
    { 0x9FC7, "railyard_player_skipped_breach" },
    { 0x9FC8, "railyard_vfx_fire_blocker" },
    { 0x9FC9, "rain_exploder" },
    { 0x9FCA, "raindrop_fx_manager" },
    { 0x9FCB, "raindrop_fx_thread" },
    { 0x9FCC, "raindrop_fx_trigger_think" },
    { 0x9FCD, "ralfa_delete_door_collision" },
    { 0x9FCE, "rally_to_snakecam_door" },
    { 0x9FCF, "rally_to_snakecam_door_monitor" },
    { 0x9FD0, "rallypoint" },
    { 0x9FD1, "rallypoint_activatevehiclemarker" },
    { 0x9FD2, "rallypoint_deacivatevehiclemarker" },
    { 0x9FD3, "rallypoint_showtoplayer" },
    { 0x9FD4, "rallypoint_updatepositions" },
    { 0x9FD5, "rallypoint_watchforvehicledeath" },
    { 0x9FD6, "rallypoint_wathcforenemydiscovery" },
    { 0x9FD7, "rallypointhealth" },
    { 0x9FD8, "rallypoints" },
    { 0x9FD9, "rallypointvehicle_activate" },
    { 0x9FDA, "rallypointvehicle_deactivate" },
    { 0x9FDB, "rallypointvehicles" },
    { 0x9FDC, "ramboaccuracymult" },
    { 0x9FDD, "ramboaim" },
    { 0x9FDE, "ramboaiminternal" },
    { 0x9FDF, "rambochance" },
    { 0x9FE0, "ramp_wind" },
    { 0x9FE1, "rand_num" },
    { 0x9FE2, "rand_pos_or_neg" },
    { 0x9FE3, "randchance" },
    { 0x9FE4, "randhidespots" },
    { 0x9FE5, "random" },
    { 0x9FE6, "random_aitype_list" },
    { 0x9FE7, "random_ambient_idle_playing" },
    { 0x9FE8, "random_consumable_chosen" },
    { 0x9FE9, "random_idle_controller" },
    { 0x9FEA, "random_idle_controller_stateful" },
    { 0x9FEB, "random_idle_group_controller" },
    { 0x9FEC, "random_idle_playing" },
    { 0x9FED, "random_idle_scene_controller" },
    { 0x9FEE, "random_idle_scene_controller_simple" },
    { 0x9FEF, "random_idle_scene_controller_simple_single" },
    { 0x9FF0, "random_idle_scene_controller_single" },
    { 0x9FF1, "random_idle_scene_end" },
    { 0x9FF2, "random_idle_scene_end_cheap" },
    { 0x9FF3, "random_idle_scene_end_cheap_single" },
    { 0x9FF4, "random_idle_scene_end_single" },
    { 0x9FF5, "random_idles" },
    { 0x9FF6, "random_intensity_off" },
    { 0x9FF7, "random_intensity_on" },
    { 0x9FF8, "random_killer_update" },
    { 0x9FF9, "random_killspawner" },
    { 0x9FFA, "random_spawn" },
    { 0x9FFB, "random_spread" },
    { 0x9FFC, "random_vector_2d" },
    { 0x9FFD, "random_weight" },
    { 0x9FFE, "random_weight_sorted" },
    { 0x9FFF, "randomaditionaltime" },
    { 0xA000, "randomangle" },
    { 0xA001, "randomdrops" },
    { 0xA002, "randomfasteranimspeed" },
    { 0xA003, "randomgrenaderange" },
    { 0xA004, "randomintrange_otn" },
    { 0xA005, "randominttable" },
    { 0xA006, "randominttablesize" },
    { 0xA007, "randomize_name_list" },
    { 0xA008, "randomize_player_sessiondata" },
    { 0xA009, "randomize_session_team_to_team_number_mapping" },
    { 0xA00A, "randomize_start_targetname_array" },
    { 0xA00B, "randomize_team_id_to_team_number_mapping" },
    { 0xA00C, "randomize_weapon" },
    { 0xA00D, "randomize_wire_color" },
    { 0xA00E, "randomizeidleset" },
    { 0xA00F, "randomizepassthroughchildren" },
    { 0xA010, "randomjackalmovement" },
    { 0xA011, "randomness" },
    { 0xA012, "randomness_increase" },
    { 0xA013, "randomness_multiplier" },
    { 0xA014, "randomoccurrance" },
    { 0xA015, "randomonunitsphere" },
    { 0xA016, "randomscore" },
    { 0xA017, "randomspawnscore" },
    { 0xA018, "randomvector" },
    { 0xA019, "randomvectorrange" },
    { 0xA01A, "range" },
    { 0xA01B, "rangecountdownactive" },
    { 0xA01C, "rangefinder" },
    { 0xA01D, "ranges" },
    { 0xA01E, "rangetrigger" },
    { 0xA01F, "rank_init" },
    { 0xA020, "rankceiling" },
    { 0xA021, "rankedmatch" },
    { 0xA022, "rankedmatchupdates" },
    { 0xA023, "rankfloor" },
    { 0xA024, "rankinfo" },
    { 0xA025, "rankingenabled" },
    { 0xA026, "ranktable" },
    { 0xA027, "rankxpmultipliers" },
    { 0xA028, "rappel_actor_dmg_func" },
    { 0xA029, "rappel_actor_stealth_filter" },
    { 0xA02A, "rappel_alq_logic" },
    { 0xA02B, "rappel_anim" },
    { 0xA02C, "rappel_bump" },
    { 0xA02D, "rappel_ground_anim" },
    { 0xA02E, "rappel_guys" },
    { 0xA02F, "rappel_hackney_get_length" },
    { 0xA030, "rappel_hackney_init" },
    { 0xA031, "rappel_hackney_spawn" },
    { 0xA032, "rappel_nvgs" },
    { 0xA033, "rappel_offhands" },
    { 0xA034, "rappel_player" },
    { 0xA035, "rappel_price" },
    { 0xA036, "rappel_reload_internal" },
    { 0xA037, "rappel_reloading" },
    { 0xA038, "rappel_scene_vo" },
    { 0xA039, "rappel_victim_death" },
    { 0xA03A, "rappelfootstep" },
    { 0xA03B, "rare" },
    { 0xA03C, "rarity" },
    { 0xA03D, "rat_executevisuals" },
    { 0xA03E, "rate" },
    { 0xA03F, "rateofchange" },
    { 0xA040, "ratiochildren" },
    { 0xA041, "ratios" },
    { 0xA042, "rave_mode" },
    { 0xA043, "ray_to_plane_intersection_distance" },
    { 0xA044, "ray_trace" },
    { 0xA045, "ray_trace_detail" },
    { 0xA046, "ray_trace_detail_passed" },
    { 0xA047, "ray_trace_ents" },
    { 0xA048, "ray_trace_get_all_results" },
    { 0xA049, "ray_trace_passed" },
    { 0xA04A, "raycountscalelg" },
    { 0xA04B, "rayguidemode" },
    { 0xA04C, "re_calculate_traverse_data" },
    { 0xA04D, "reach_and_arrive_internal" },
    { 0xA04E, "reach_death_notify" },
    { 0xA04F, "reach_door_check" },
    { 0xA050, "reach_end_monitor" },
    { 0xA051, "reach_goal_pos" },
    { 0xA052, "reach_path_end_monitor" },
    { 0xA053, "reach_to_idle" },
    { 0xA054, "reach_to_idle_farah" },
    { 0xA055, "reach_to_interact_begin" },
    { 0xA056, "reach_to_interact_end" },
    { 0xA057, "reach_with_arrivals_begin" },
    { 0xA058, "reach_with_planting" },
    { 0xA059, "reach_with_planting_and_arrivals" },
    { 0xA05A, "reach_with_standard_adjustments_begin" },
    { 0xA05B, "reach_with_standard_adjustments_end" },
    { 0xA05C, "reached_goal" },
    { 0xA05D, "reached_halfway" },
    { 0xA05E, "reached_infil_node" },
    { 0xA05F, "reached_main_road" },
    { 0xA060, "reached_node_but_could_not_claim_it" },
    { 0xA061, "reachedinvestigate" },
    { 0xA062, "reachers" },
    { 0xA063, "reachidle" },
    { 0xA064, "reacquire_attemptcharge" },
    { 0xA065, "reacquire_charge" },
    { 0xA066, "reacquire_charge_terminate" },
    { 0xA067, "reacquire_checkadvanceonenemyconditions" },
    { 0xA068, "reacquire_clear" },
    { 0xA069, "reacquire_init" },
    { 0xA06A, "reacquire_step" },
    { 0xA06B, "reacquire_terminate" },
    { 0xA06C, "reacquiredtime" },
    { 0xA06D, "react_1f_vo" },
    { 0xA06E, "react_announce" },
    { 0xA06F, "react_announce_specific" },
    { 0xA070, "react_enter" },
    { 0xA071, "react_to_flare" },
    { 0xA072, "reactendtime" },
    { 0xA073, "reaction_blend_end" },
    { 0xA074, "reaction_group_look_distance_based" },
    { 0xA075, "reaction_look_distance_based" },
    { 0xA076, "reaction_state" },
    { 0xA077, "reaction_state_basename" },
    { 0xA078, "reaction_state_busy_loop" },
    { 0xA079, "reaction_stop_anims" },
    { 0xA07A, "reactioncasualty" },
    { 0xA07B, "reactionfriendlyfire" },
    { 0xA07C, "reactionindex" },
    { 0xA07D, "reactiontakingfire" },
    { 0xA07E, "reactiontaunt" },
    { 0xA07F, "reactiontrigger" },
    { 0xA080, "reactive_foliage" },
    { 0xA081, "reactive_foliage_high" },
    { 0xA082, "reactive_foliage_low" },
    { 0xA083, "reactive_foliage_med" },
    { 0xA084, "reactive_fx_ents" },
    { 0xA085, "reactive_fx_thread" },
    { 0xA086, "reactive_sound_ents" },
    { 0xA087, "reactive_thread" },
    { 0xA088, "reactivefoliagestate" },
    { 0xA089, "reacts_to_rush" },
    { 0xA08A, "reactto" },
    { 0xA08B, "reacttobulletchance" },
    { 0xA08C, "reacttodynolightsinhunt" },
    { 0xA08D, "reacttolightifpossible" },
    { 0xA08E, "read_actions" },
    { 0xA08F, "read_munition_table" },
    { 0xA090, "read_properties" },
    { 0xA091, "readcraftingmaterialstable" },
    { 0xA092, "reading_pl_stairs_guy_logic" },
    { 0xA093, "reading_place_friendlies_enter" },
    { 0xA094, "readnodeevents" },
    { 0xA095, "readplayerstat" },
    { 0xA096, "readsupertablecell" },
    { 0xA097, "readweaponinfofromtable" },
    { 0xA098, "ready" },
    { 0xA099, "ready_to_breach_dialogue" },
    { 0xA09A, "ready_to_breach_poi" },
    { 0xA09B, "readytoextract" },
    { 0xA09C, "real_ai_distance_check" },
    { 0xA09D, "realspawners" },
    { 0xA09E, "realtext" },
    { 0xA09F, "reaper" },
    { 0xA0A0, "reaper_camera_reset_think" },
    { 0xA0A1, "reaper_camera_zoom_think" },
    { 0xA0A2, "reaper_fire_missile_think" },
    { 0xA0A3, "reaper_get_target_in_circle_omnvar_value" },
    { 0xA0A4, "reaper_missile_target_ent_objective_clean_up_think" },
    { 0xA0A5, "reaper_radar_control" },
    { 0xA0A6, "reaper_waitforweaponreloadtime" },
    { 0xA0A7, "reapply_visionset_after_host_migration" },
    { 0xA0A8, "reapplyarchetype" },
    { 0xA0A9, "rear_mantle_handler" },
    { 0xA0AA, "rearguardattackers" },
    { 0xA0AB, "rearinteract" },
    { 0xA0AC, "rearturret" },
    { 0xA0AD, "reasons" },
    { 0xA0AE, "reassign_bodyguard_vehicle_id" },
    { 0xA0AF, "reassign_weapon_name" },
    { 0xA0B0, "reassure_hadir" },
    { 0xA0B1, "rebar_hits" },
    { 0xA0B2, "rebar_weapon_interact" },
    { 0xA0B3, "rebel_1" },
    { 0xA0B4, "rebel_1_drs_setup" },
    { 0xA0B5, "rebel_2" },
    { 0xA0B6, "rebel_2_catchup" },
    { 0xA0B7, "rebel_2_drs_setup" },
    { 0xA0B8, "rebel_3" },
    { 0xA0B9, "rebel_4" },
    { 0xA0BA, "rebel_5" },
    { 0xA0BB, "rebel_flood_spawner" },
    { 0xA0BC, "rebel_plant_bomb" },
    { 0xA0BD, "rebel_plant_bomb_wait" },
    { 0xA0BE, "reboarding_points" },
    { 0xA0BF, "reboost_nav_obstacle" },
    { 0xA0C0, "rebuild" },
    { 0xA0C1, "rebuild_heroes_array" },
    { 0xA0C2, "receivevolumedecals" },
    { 0xA0C3, "recent_attacker" },
    { 0xA0C4, "recent_player_attackers" },
    { 0xA0C5, "recent_position" },
    { 0xA0C6, "recentattackers" },
    { 0xA0C7, "recentdamageamount" },
    { 0xA0C8, "recentdamages" },
    { 0xA0C9, "recentdefendcount" },
    { 0xA0CA, "recentindices" },
    { 0xA0CB, "recentkillcount" },
    { 0xA0CC, "recentkillsperweapon" },
    { 0xA0CD, "recently_in_combat" },
    { 0xA0CE, "recently_loaded_thread" },
    { 0xA0CF, "recentlysawenemy" },
    { 0xA0D0, "recentshieldxp" },
    { 0xA0D1, "recentsplashcount" },
    { 0xA0D2, "recenttagcount" },
    { 0xA0D3, "rechamber" },
    { 0xA0D4, "recharge_lethals_over_time" },
    { 0xA0D5, "recharge_power" },
    { 0xA0D6, "recharge_super" },
    { 0xA0D7, "recharged" },
    { 0xA0D8, "rechargeequipment_clearplayer" },
    { 0xA0D9, "rechargeequipment_updateslot" },
    { 0xA0DA, "rechargeequipment_updatestate" },
    { 0xA0DB, "rechargeequipment_updateui" },
    { 0xA0DC, "rechargeequipmentstate" },
    { 0xA0DD, "rechargeequipmentthink_init" },
    { 0xA0DE, "recipe_getkillstreak" },
    { 0xA0DF, "reclaimed" },
    { 0xA0E0, "reclaimedreservedobjectives" },
    { 0xA0E1, "recoilscale" },
    { 0xA0E2, "recon_team" },
    { 0xA0E3, "recon1" },
    { 0xA0E4, "recon2" },
    { 0xA0E5, "recon3" },
    { 0xA0E6, "recon4" },
    { 0xA0E7, "recondrone_addtolists" },
    { 0xA0E8, "recondrone_allowcontrols" },
    { 0xA0E9, "recondrone_beginsuper" },
    { 0xA0EA, "recondrone_cleanupreserved" },
    { 0xA0EB, "recondrone_disablecontrols" },
    { 0xA0EC, "recondrone_endsuper" },
    { 0xA0ED, "recondrone_equipment_wrapper" },
    { 0xA0EE, "recondrone_givedeployweapon" },
    { 0xA0EF, "recondrone_removefromlists" },
    { 0xA0F0, "recondrone_removefromlistsondeath" },
    { 0xA0F1, "recondrone_takedeployweapon" },
    { 0xA0F2, "recondrone_unsetsuper" },
    { 0xA0F3, "recondrone_watchcleanupreserved" },
    { 0xA0F4, "recondrone_watchsuper" },
    { 0xA0F5, "recondrone_watchsuperendfromdeath" },
    { 0xA0F6, "recondrone_watchsuperendfromswitch" },
    { 0xA0F7, "recondronebeginuse" },
    { 0xA0F8, "recondroneenduse" },
    { 0xA0F9, "recondronefrozecontrols" },
    { 0xA0FA, "recondronerefund" },
    { 0xA0FB, "recondronereserved" },
    { 0xA0FC, "recondronesafespawn" },
    { 0xA0FD, "recondronesuper" },
    { 0xA0FE, "recondronesupers" },
    { 0xA0FF, "recondroneunset" },
    { 0xA100, "reconmarked" },
    { 0xA101, "reconstruct_actor_array" },
    { 0xA102, "reconvehiclereserved" },
    { 0xA103, "record_bleedout" },
    { 0xA104, "record_bread_crumbs_for_ambush" },
    { 0xA105, "record_enemy_sightings" },
    { 0xA106, "record_player_kills" },
    { 0xA107, "record_player_shoottime" },
    { 0xA108, "record_revive_success" },
    { 0xA109, "record_seat" },
    { 0xA10A, "record_sighting" },
    { 0xA10B, "record_suicide_bomber_death_or_deleted" },
    { 0xA10C, "record_teleport_data_and_teleport" },
    { 0xA10D, "recordbreadcrumbdata" },
    { 0xA10E, "recordedusers" },
    { 0xA10F, "recordfinalkillcam" },
    { 0xA110, "recordingenabledcount" },
    { 0xA111, "recordingstarttime" },
    { 0xA112, "recordplayerlogs" },
    { 0xA113, "recordplayersegmentdata" },
    { 0xA114, "recordsuperearnedanalytics" },
    { 0xA115, "recordthrowingknifetraveldist" },
    { 0xA116, "recordvalidationinfraction" },
    { 0xA117, "recordxpgains" },
    { 0xA118, "recover_bb" },
    { 0xA119, "recover_from_careful_disable" },
    { 0xA11A, "recover_interval" },
    { 0xA11B, "recruit_amount" },
    { 0xA11C, "recruit_distance" },
    { 0xA11D, "recruit_enable" },
    { 0xA11E, "recruit_juggs" },
    { 0xA11F, "recruit_time_between" },
    { 0xA120, "recruit_time_until" },
    { 0xA121, "recurse" },
    { 0xA122, "recurse_internal" },
    { 0xA123, "recursive_delete_targets" },
    { 0xA124, "recyclespotted" },
    { 0xA125, "red_barrel" },
    { 0xA126, "red_barrel_death" },
    { 0xA127, "red_barrel_hit" },
    { 0xA128, "red_barrel_init" },
    { 0xA129, "red_damage_custom" },
    { 0xA12A, "red_marine_cleanup" },
    { 0xA12B, "red_marine_lookat_target" },
    { 0xA12C, "red_wire_lower" },
    { 0xA12D, "red_wire_upper" },
    { 0xA12E, "redefine_interaction_radius" },
    { 0xA12F, "redeployenabled" },
    { 0xA130, "redshirt_die" },
    { 0xA131, "redshirt_refill" },
    { 0xA132, "redshirtgoalamount" },
    { 0xA133, "reduce_bullet_spread" },
    { 0xA134, "reduce_command_count_after_duration" },
    { 0xA135, "reduce_friendlyfire_penalties" },
    { 0xA136, "reduce_goalradius_over_time" },
    { 0xA137, "reduce_money_earned" },
    { 0xA138, "reduce_recoil" },
    { 0xA139, "reduce_timer_on_breaking_stealth" },
    { 0xA13A, "reduce_wallet_size" },
    { 0xA13B, "reduce_wallet_size_and_money_earned" },
    { 0xA13C, "reducegiptponkillanimscript" },
    { 0xA13D, "reducehealthregendelay" },
    { 0xA13E, "reduceshotcountbydistance" },
    { 0xA13F, "reducesuperusepercent" },
    { 0xA140, "reducetacopstimelimitms" },
    { 0xA141, "reducetakecoverwarnings" },
    { 0xA142, "reducewind" },
    { 0xA143, "reenable_ai_for_player" },
    { 0xA144, "reenable_ai_on_player_fire_or_kill" },
    { 0xA145, "reenable_barrel_interaction" },
    { 0xA146, "reenable_dynents" },
    { 0xA147, "reenable_zombie_emmisive" },
    { 0xA148, "reentercallback" },
    { 0xA149, "reevaluatehvts" },
    { 0xA14A, "ref" },
    { 0xA14B, "ref_col" },
    { 0xA14C, "referencename" },
    { 0xA14D, "refill" },
    { 0xA14E, "refill_grenades" },
    { 0xA14F, "refill_if_empty" },
    { 0xA150, "refill_used" },
    { 0xA151, "refillammo" },
    { 0xA152, "refillclip" },
    { 0xA153, "refillequipment" },
    { 0xA154, "refillsinglecountammo" },
    { 0xA155, "reflectionprobe_hide_front" },
    { 0xA156, "reflectionprobe_hide_hp" },
    { 0xA157, "reflectionvolume" },
    { 0xA158, "reflectionvolume2" },
    { 0xA159, "reflectionvolume3" },
    { 0xA15A, "refname" },
    { 0xA15B, "refresh" },
    { 0xA15C, "refresh_ambush_vehicles_behind_player_vehicle_target" },
    { 0xA15D, "refresh_existing_bots" },
    { 0xA15E, "refresh_interaction" },
    { 0xA15F, "refresh_nearby_playerhints" },
    { 0xA160, "refresh_open_struct" },
    { 0xA161, "refresh_piccadilly_civs_array" },
    { 0xA162, "refresh_reactive_fx_ents" },
    { 0xA163, "refreshdynamicspawns" },
    { 0xA164, "refreshfreecamhardpointfx" },
    { 0xA165, "refreshplayerspawnareaomnvars" },
    { 0xA166, "refreshspottimer" },
    { 0xA167, "refreshsquadspawns" },
    { 0xA168, "refreshuimatchinprogressomnvarvalue" },
    { 0xA169, "refundsuper" },
    { 0xA16A, "regen_time_scalar" },
    { 0xA16B, "regenamount" },
    { 0xA16C, "regendelayreduce_onkill" },
    { 0xA16D, "regendelayreduction" },
    { 0xA16E, "regendelayreductiontime" },
    { 0xA16F, "regendelayspeed" },
    { 0xA170, "regenduration" },
    { 0xA171, "regenerate" },
    { 0xA172, "regenerate_health" },
    { 0xA173, "regeneratehealth" },
    { 0xA174, "regenfasterhealthmod" },
    { 0xA175, "region" },
    { 0xA176, "region_links" },
    { 0xA177, "register_achievement" },
    { 0xA178, "register_ai_damage_callbacks" },
    { 0xA179, "register_ai_drop_funcs" },
    { 0xA17A, "register_aievent_func_for_group" },
    { 0xA17B, "register_aitype_setup" },
    { 0xA17C, "register_apprehension_objective" },
    { 0xA17D, "register_archetype" },
    { 0xA17E, "register_attack_heli_objective" },
    { 0xA17F, "register_buried_sources" },
    { 0xA180, "register_care_package_interaction" },
    { 0xA181, "register_combined_vehicles" },
    { 0xA182, "register_consumable" },
    { 0xA183, "register_convoy4_objectives" },
    { 0xA184, "register_convoyescort_objective" },
    { 0xA185, "register_create_script" },
    { 0xA186, "register_create_script_arrays" },
    { 0xA187, "register_cs_inits" },
    { 0xA188, "register_cs_offsets" },
    { 0xA189, "register_deaths" },
    { 0xA18A, "register_default_achievements" },
    { 0xA18B, "register_default_end_game_string_index" },
    { 0xA18C, "register_drop_func" },
    { 0xA18D, "register_encounter_score_component" },
    { 0xA18E, "register_end_game_string_index" },
    { 0xA18F, "register_eog_score_component" },
    { 0xA190, "register_eog_to_lb_playerdata_mapping" },
    { 0xA191, "register_event" },
    { 0xA192, "register_extraction_interactions" },
    { 0xA193, "register_farah_deaths" },
    { 0xA194, "register_hack_spot_interaction" },
    { 0xA195, "register_helidown_objective" },
    { 0xA196, "register_house_boss_vo_sources" },
    { 0xA197, "register_house_enter_vo_sources" },
    { 0xA198, "register_idle_scene" },
    { 0xA199, "register_iedrace_objective" },
    { 0xA19A, "register_infil_spots" },
    { 0xA19B, "register_interaction" },
    { 0xA19C, "register_interactions" },
    { 0xA19D, "register_kill" },
    { 0xA19E, "register_ladder_interactions" },
    { 0xA19F, "register_lb_escape_rank" },
    { 0xA1A0, "register_ml_p1_objectives" },
    { 0xA1A1, "register_ml_p3_objectives" },
    { 0xA1A2, "register_module_ai_death_func" },
    { 0xA1A3, "register_module_ai_spawn_func" },
    { 0xA1A4, "register_module_as_passive" },
    { 0xA1A5, "register_module_for_spawn_owner_disables" },
    { 0xA1A6, "register_module_init_func" },
    { 0xA1A7, "register_module_run_func_after_notify" },
    { 0xA1A8, "register_module_weapons_free_func" },
    { 0xA1A9, "register_munitions_interaction" },
    { 0xA1AA, "register_nerf_activated" },
    { 0xA1AB, "register_new_weapon" },
    { 0xA1AC, "register_objective" },
    { 0xA1AD, "register_objectives" },
    { 0xA1AE, "register_objectives_for_convoy" },
    { 0xA1AF, "register_overwatch_objective" },
    { 0xA1B0, "register_physics_collision_func" },
    { 0xA1B1, "register_physics_collisions" },
    { 0xA1B2, "register_plane_hijack_objectives" },
    { 0xA1B3, "register_player_death" },
    { 0xA1B4, "register_player_deaths" },
    { 0xA1B5, "register_prison_breakout" },
    { 0xA1B6, "register_quest_step" },
    { 0xA1B7, "register_relic" },
    { 0xA1B8, "register_relics" },
    { 0xA1B9, "register_scoring_mode" },
    { 0xA1BA, "register_shot_hit" },
    { 0xA1BB, "register_smugglercache_objective" },
    { 0xA1BC, "register_spawn_functions" },
    { 0xA1BD, "register_spawn_groups" },
    { 0xA1BE, "register_spawn_modules" },
    { 0xA1BF, "register_spawner_functions" },
    { 0xA1C0, "register_spawner_script_function" },
    { 0xA1C1, "register_spawners" },
    { 0xA1C2, "register_state_interaction" },
    { 0xA1C3, "register_stealth_state_func" },
    { 0xA1C4, "register_stealth_state_funcs" },
    { 0xA1C5, "register_trigger_func" },
    { 0xA1C6, "register_triggered_infinite_module" },
    { 0xA1C7, "register_triggered_looping_module" },
    { 0xA1C8, "register_triggered_module" },
    { 0xA1C9, "register_triggered_module_maze_jugg" },
    { 0xA1CA, "register_triggered_timeout_module" },
    { 0xA1CB, "register_unloaded_func" },
    { 0xA1CC, "register_unloading_func" },
    { 0xA1CD, "register_vault_assault_objectives" },
    { 0xA1CE, "register_vehicle_build" },
    { 0xA1CF, "register_vehicle_interaction_info" },
    { 0xA1D0, "register_vehicle_spawn" },
    { 0xA1D1, "register_vehicle_spawn_drivers" },
    { 0xA1D2, "register_vo" },
    { 0xA1D3, "register_vo_source" },
    { 0xA1D4, "register_vo_source_at_pos" },
    { 0xA1D5, "register_vo_source_attached" },
    { 0xA1D6, "registeraccolade" },
    { 0xA1D7, "registeractionset" },
    { 0xA1D8, "registerambientgroup" },
    { 0xA1D9, "registerammoloot" },
    { 0xA1DA, "registerarchetype" },
    { 0xA1DB, "registerarenamap" },
    { 0xA1DC, "registerbcsoundtype" },
    { 0xA1DD, "registerbehaviortree" },
    { 0xA1DE, "registercheckiflocaleisavailable" },
    { 0xA1DF, "registerclearquestvars" },
    { 0xA1E0, "registercodefactors" },
    { 0xA1E1, "registercodeperkinfo" },
    { 0xA1E2, "registercrankedtimerdvar" },
    { 0xA1E3, "registercrateforcleanup" },
    { 0xA1E4, "registercreatequestlocale" },
    { 0xA1E5, "registerdogtagsenableddvar" },
    { 0xA1E6, "registerdvars" },
    { 0xA1E7, "registered_events" },
    { 0xA1E8, "registered_interaction" },
    { 0xA1E9, "registeredrallypointplayers" },
    { 0xA1EA, "registeredvehicles" },
    { 0xA1EB, "registerentforoob" },
    { 0xA1EC, "registerfactor" },
    { 0xA1ED, "registerfindsearcharea" },
    { 0xA1EE, "registerfireteamleader" },
    { 0xA1EF, "registerhalftimedvar" },
    { 0xA1F0, "registerhvtscriptmodels" },
    { 0xA1F1, "registerinfillocationselectionhandler" },
    { 0xA1F2, "registeringshothit" },
    { 0xA1F3, "registerinitquesttype" },
    { 0xA1F4, "registerinitquestvars" },
    { 0xA1F5, "registerinteractable" },
    { 0xA1F6, "registerinteraction" },
    { 0xA1F7, "registerinteractions" },
    { 0xA1F8, "registerkidnapperspawnmod" },
    { 0xA1F9, "registerkill" },
    { 0xA1FA, "registerkillstreak" },
    { 0xA1FB, "registerlargemap" },
    { 0xA1FC, "registerlaststandhealthdvar" },
    { 0xA1FD, "registerlaststandinvulntimerdvar" },
    { 0xA1FE, "registerlaststandrevivedecayscaledvar" },
    { 0xA1FF, "registerlaststandrevivehealthdvar" },
    { 0xA200, "registerlaststandrevivetimerdvar" },
    { 0xA201, "registerlaststandsuicidetimerdvar" },
    { 0xA202, "registerlaststandtimerdvar" },
    { 0xA203, "registerlaststandweapondelaydvar" },
    { 0xA204, "registerlaststandweapondvar" },
    { 0xA205, "registerloot" },
    { 0xA206, "registermeritcallback" },
    { 0xA207, "registermoralesinteraction" },
    { 0xA208, "registermoralesobjectives" },
    { 0xA209, "registernightmap" },
    { 0xA20A, "registernotetracks" },
    { 0xA20B, "registernotetracksifnot" },
    { 0xA20C, "registernumlivesdvar" },
    { 0xA20D, "registernumrevivesdvar" },
    { 0xA20E, "registernumteamsdvar" },
    { 0xA20F, "registerobjective" },
    { 0xA210, "registerobjectives" },
    { 0xA211, "registeroffhandfirefunc" },
    { 0xA212, "registeroffhandloot" },
    { 0xA213, "registerondisconnecteventcallback" },
    { 0xA214, "registeronluieventcallback" },
    { 0xA215, "registeronplayerjoinsquadcallback" },
    { 0xA216, "registeronplayerjointeamcallback" },
    { 0xA217, "registeronplayerkilled" },
    { 0xA218, "registeronplayerspawncallback" },
    { 0xA219, "registeroobclearcallback" },
    { 0xA21A, "registeroobentercallback" },
    { 0xA21B, "registeroobexitcallback" },
    { 0xA21C, "registerooboutoftimecallback" },
    { 0xA21D, "registerpayloadobjective" },
    { 0xA21E, "registerpayloadvfx" },
    { 0xA21F, "registerpentparams" },
    { 0xA220, "registerperk" },
    { 0xA221, "registerplayercharacter" },
    { 0xA222, "registerplayercharfunc" },
    { 0xA223, "registerplayerfilter" },
    { 0xA224, "registerplayerframeupdatecallback" },
    { 0xA225, "registerplayerstatratio" },
    { 0xA226, "registerplayerwithrallypoint" },
    { 0xA227, "registerpotgentity" },
    { 0xA228, "registerquarryobjectives" },
    { 0xA229, "registerquestcategory" },
    { 0xA22A, "registerquestcircletick" },
    { 0xA22B, "registerquestlocale" },
    { 0xA22C, "registerquestthink" },
    { 0xA22D, "registerquestthinkrate" },
    { 0xA22E, "registerremovequestinstance" },
    { 0xA22F, "registerremovequestthread" },
    { 0xA230, "registerroundlimitdvar" },
    { 0xA231, "registerroundswitchdvar" },
    { 0xA232, "registersafehouse" },
    { 0xA233, "registerscoreinfo" },
    { 0xA234, "registerscorelimitdvar" },
    { 0xA235, "registerscriptedagent" },
    { 0xA236, "registerscriptedagents" },
    { 0xA237, "registerscriptperk" },
    { 0xA238, "registersentient" },
    { 0xA239, "registersharedfunc" },
    { 0xA23A, "registerspawn" },
    { 0xA23B, "registerspawncount" },
    { 0xA23C, "registerspawnlocation" },
    { 0xA23D, "registerspawnpoints" },
    { 0xA23E, "registerspawnset" },
    { 0xA23F, "registersquadspawners" },
    { 0xA240, "registerstatecallbacksforpoitype" },
    { 0xA241, "registersuper" },
    { 0xA242, "registersupers" },
    { 0xA243, "registerteamonquest" },
    { 0xA244, "registertimelimitdvar" },
    { 0xA245, "registertmtylobjective" },
    { 0xA246, "registertweakable" },
    { 0xA247, "registervaliddroplocations" },
    { 0xA248, "registervehicle" },
    { 0xA249, "registervehicleinteractions" },
    { 0xA24A, "registervehicletype" },
    { 0xA24B, "registervisibilityomnvarforkillstreak" },
    { 0xA24C, "registerwatchdvar" },
    { 0xA24D, "registerwatchdvarfloat" },
    { 0xA24E, "registerwatchdvarint" },
    { 0xA24F, "registerweaponchangecallback" },
    { 0xA250, "registerweaponupgradeinteractions" },
    { 0xA251, "registerwinbytwoenableddvar" },
    { 0xA252, "registerwinbytwomaxroundsdvar" },
    { 0xA253, "registerwinlimitdvar" },
    { 0xA254, "registerwithpickupmonitor" },
    { 0xA255, "regroup_at_safehouse" },
    { 0xA256, "regroup_blackscreen" },
    { 0xA257, "regular_enemy_death_func" },
    { 0xA258, "reincrement_count_if_deleted" },
    { 0xA259, "reinforce_after_door_section" },
    { 0xA25A, "reinforcement_convoy_get_to_blockade" },
    { 0xA25B, "reinforcement_loop" },
    { 0xA25C, "reinforcement_test" },
    { 0xA25D, "reinforcements_allieslogic" },
    { 0xA25E, "reinforcements_cleanupenemieslogic" },
    { 0xA25F, "reinforcements_dialoguelogic" },
    { 0xA260, "reinforcements_driverdeathlogic" },
    { 0xA261, "reinforcements_getallypaths" },
    { 0xA262, "reinforcements_getenemies" },
    { 0xA263, "reinforcements_getvehicles" },
    { 0xA264, "reinforcements_main" },
    { 0xA265, "reinforcements_spawnvehicles" },
    { 0xA266, "reinforcements_start" },
    { 0xA267, "reinforcements_vehicledoorsfxlogic" },
    { 0xA268, "reinforcements_vehiclesdisableddialoguelogic" },
    { 0xA269, "reinforcements_vehicleslogic" },
    { 0xA26A, "reinforcements_vehiclessfxlogic" },
    { 0xA26B, "reinforcements_vehiclesstoppedautosave" },
    { 0xA26C, "reinforcements_vehiclesunloadedlogic" },
    { 0xA26D, "reinitializematchrulesonmigration" },
    { 0xA26E, "reinitializethermal" },
    { 0xA26F, "relatedbrushmodel" },
    { 0xA270, "relative_ads_anims" },
    { 0xA271, "relativepoint" },
    { 0xA272, "relaunchaxe" },
    { 0xA273, "relaysource" },
    { 0xA274, "release_character_number" },
    { 0xA275, "release_control" },
    { 0xA276, "release_from_being_dragged" },
    { 0xA277, "release_interaction_ent" },
    { 0xA278, "release_node" },
    { 0xA279, "release_player_from_viewmodel_anim" },
    { 0xA27A, "release_player_interaction_trigger" },
    { 0xA27B, "release_player_on_death" },
    { 0xA27C, "release_stunstick" },
    { 0xA27D, "releasedusebutton" },
    { 0xA27E, "releasegrenadeorigin" },
    { 0xA27F, "releaseid" },
    { 0xA280, "releasemachineonplayerdisconnect" },
    { 0xA281, "releaseownerangles" },
    { 0xA282, "releaseownereye" },
    { 0xA283, "releaseownerorigin" },
    { 0xA284, "releaseteamonquest" },
    { 0xA285, "relic_combos" },
    { 0xA286, "relic_swat_modifyplayerdamage" },
    { 0xA287, "relics" },
    { 0xA288, "relics_monitor" },
    { 0xA289, "relink_cutters_on_anim_end" },
    { 0xA28A, "reload_cheatammo" },
    { 0xA28B, "reload_cleanup" },
    { 0xA28C, "reload_damage_increase" },
    { 0xA28D, "reload_launcher" },
    { 0xA28E, "reload_on_kill" },
    { 0xA28F, "reloadifneeded" },
    { 0xA290, "reloadonempty" },
    { 0xA291, "reloadtime" },
    { 0xA292, "reloadtracking" },
    { 0xA293, "reloadweapon" },
    { 0xA294, "relocate_gunship_origin" },
    { 0xA295, "relocatetrigger" },
    { 0xA296, "remainingflags" },
    { 0xA297, "remainingteamsset" },
    { 0xA298, "remainingtime" },
    { 0xA299, "remap" },
    { 0xA29A, "remapdomtriggerscriptlabel" },
    { 0xA29B, "remappedscriptlabel" },
    { 0xA29C, "remapscoreeventforweapon" },
    { 0xA29D, "remind_calltrain" },
    { 0xA29E, "remind_calltrain_sethot" },
    { 0xA29F, "reminder_animnode" },
    { 0xA2A0, "reminder_cooldown_timer" },
    { 0xA2A1, "reminder_queue_cleanup" },
    { 0xA2A2, "reminder_reaction_pointat" },
    { 0xA2A3, "reminder_vo_init" },
    { 0xA2A4, "remote_detonation_monitor" },
    { 0xA2A5, "remote_tank_armor_bulletdamage" },
    { 0xA2A6, "remote_tanks" },
    { 0xA2A7, "remote_uav" },
    { 0xA2A8, "remote_uav_ridelifeid" },
    { 0xA2A9, "remote_vehicle_setup" },
    { 0xA2AA, "remotedefusecallback" },
    { 0xA2AB, "remotedefusesetup" },
    { 0xA2AC, "remotedetonatebeginuse" },
    { 0xA2AD, "remotedetonateonset" },
    { 0xA2AE, "remotedetonatethink" },
    { 0xA2AF, "remoteinfo" },
    { 0xA2B0, "remoteinteractsetup" },
    { 0xA2B1, "remotekillstreaks" },
    { 0xA2B2, "remotemissile_fx" },
    { 0xA2B3, "remotemissileinprogress" },
    { 0xA2B4, "remotetank_rumble" },
    { 0xA2B5, "remotetanks" },
    { 0xA2B6, "remoteuav" },
    { 0xA2B7, "remoteuav_cantargetuav" },
    { 0xA2B8, "remoteuav_cleanup" },
    { 0xA2B9, "remoteuav_clear_marked_on_gameended" },
    { 0xA2BA, "remoteuav_clearincomingwarning" },
    { 0xA2BB, "remoteuav_clearmarkedforowner" },
    { 0xA2BC, "remoteuav_delaylaunchdialog" },
    { 0xA2BD, "remoteuav_dialog" },
    { 0xA2BE, "remoteuav_endride" },
    { 0xA2BF, "remoteuav_explode_on_changeteams" },
    { 0xA2C0, "remoteuav_explode_on_death" },
    { 0xA2C1, "remoteuav_explode_on_disconnect" },
    { 0xA2C2, "remoteuav_fire" },
    { 0xA2C3, "remoteuav_freezebuffer" },
    { 0xA2C4, "remoteuav_fx" },
    { 0xA2C5, "remoteuav_handledamage" },
    { 0xA2C6, "remoteuav_handleincomingsam" },
    { 0xA2C7, "remoteuav_handleincomingstinger" },
    { 0xA2C8, "remoteuav_in_range" },
    { 0xA2C9, "remoteuav_lastdialogtime" },
    { 0xA2CA, "remoteuav_leave" },
    { 0xA2CB, "remoteuav_leave_on_timeout" },
    { 0xA2CC, "remoteuav_light_fx" },
    { 0xA2CD, "remoteuav_markplayer" },
    { 0xA2CE, "remoteuav_nodeployzones" },
    { 0xA2CF, "remoteuav_operationrumble" },
    { 0xA2D0, "remoteuav_playerexit" },
    { 0xA2D1, "remoteuav_processtaggedassist" },
    { 0xA2D2, "remoteuav_rangecountdown" },
    { 0xA2D3, "remoteuav_ride" },
    { 0xA2D4, "remoteuav_rumble" },
    { 0xA2D5, "remoteuav_staticfade" },
    { 0xA2D6, "remoteuav_track" },
    { 0xA2D7, "remoteuav_trackentities" },
    { 0xA2D8, "remoteuav_unmarkremovedplayer" },
    { 0xA2D9, "remoteuav_watch_distance" },
    { 0xA2DA, "remoteuav_watchheliproximity" },
    { 0xA2DB, "remoteuavmarkedobjid01" },
    { 0xA2DC, "remoteuavmarkedobjid02" },
    { 0xA2DD, "remoteuavmarkedobjid03" },
    { 0xA2DE, "remoteunpinned" },
    { 0xA2DF, "remove_action_slot_after_put_away" },
    { 0xA2E0, "remove_actor_from_manager" },
    { 0xA2E1, "remove_adrenaline_visuals" },
    { 0xA2E2, "remove_ai_air_infil_for_time" },
    { 0xA2E3, "remove_ai_ground_infil_for_time" },
    { 0xA2E4, "remove_aitype_spawner_override" },
    { 0xA2E5, "remove_all_aitype_overrides" },
    { 0xA2E6, "remove_all_armor" },
    { 0xA2E7, "remove_all_intel" },
    { 0xA2E8, "remove_all_powers" },
    { 0xA2E9, "remove_all_primaries_weapon" },
    { 0xA2EA, "remove_ally" },
    { 0xA2EB, "remove_anim_corpse_col" },
    { 0xA2EC, "remove_animated_door" },
    { 0xA2ED, "remove_as_opener" },
    { 0xA2EE, "remove_at_ammo_count" },
    { 0xA2EF, "remove_at_shield_death" },
    { 0xA2F0, "remove_attachment" },
    { 0xA2F1, "remove_axis_model" },
    { 0xA2F2, "remove_berserk_after_timeout" },
    { 0xA2F3, "remove_bg_hud" },
    { 0xA2F4, "remove_blackboard_isburning" },
    { 0xA2F5, "remove_c4_train" },
    { 0xA2F6, "remove_can" },
    { 0xA2F7, "remove_card_from_use" },
    { 0xA2F8, "remove_civ_left_subway" },
    { 0xA2F9, "remove_clan_tag" },
    { 0xA2FA, "remove_color_from_array" },
    { 0xA2FB, "remove_consumable" },
    { 0xA2FC, "remove_convoy_from_level" },
    { 0xA2FD, "remove_corpses_away_from_player_pos" },
    { 0xA2FE, "remove_corpses_near_pos" },
    { 0xA2FF, "remove_cover_node_spawners_around_pos_with_id" },
    { 0xA300, "remove_crafted_item_from_dpad" },
    { 0xA301, "remove_crafted_item_from_inventory" },
    { 0xA302, "remove_crafted_item_from_slot" },
    { 0xA303, "remove_crafting_item" },
    { 0xA304, "remove_crawled" },
    { 0xA305, "remove_cursor_hint" },
    { 0xA306, "remove_damage_effects_instantly" },
    { 0xA307, "remove_damage_function" },
    { 0xA308, "remove_death_react" },
    { 0xA309, "remove_deathanim" },
    { 0xA30A, "remove_deathfunc" },
    { 0xA30B, "remove_deathfx_entity_delay" },
    { 0xA30C, "remove_default_kvps" },
    { 0xA30D, "remove_dining_deathanim" },
    { 0xA30E, "remove_dining_deathanim_ragonly" },
    { 0xA30F, "remove_disguise" },
    { 0xA310, "remove_distraction_interact" },
    { 0xA311, "remove_distraction_interact_on_end" },
    { 0xA312, "remove_door_c4_ability" },
    { 0xA313, "remove_door_snake_cam_ability" },
    { 0xA314, "remove_door_speed_modifiers" },
    { 0xA315, "remove_dupes" },
    { 0xA316, "remove_emp" },
    { 0xA317, "remove_ends_from_path" },
    { 0xA318, "remove_enemy_ai_outline_for_overwatch" },
    { 0xA319, "remove_equipment_immediately" },
    { 0xA31A, "remove_exotic_nvg_types" },
    { 0xA31B, "remove_expired_vo_from_queue" },
    { 0xA31C, "remove_explosive_touch" },
    { 0xA31D, "remove_extra_autosave_check" },
    { 0xA31E, "remove_extra_structs" },
    { 0xA31F, "remove_eye_effects" },
    { 0xA320, "remove_force_drop_on_group" },
    { 0xA321, "remove_fov_of_player_during_hvt_interact" },
    { 0xA322, "remove_fov_of_player_during_rappel" },
    { 0xA323, "remove_friendly_fire_damage_modifier" },
    { 0xA324, "remove_from_active_quests" },
    { 0xA325, "remove_from_ambush_vehicles_ahead_player_vehicle_array" },
    { 0xA326, "remove_from_ambush_vehicles_behind_player_vehicle_array" },
    { 0xA327, "remove_from_animloop" },
    { 0xA328, "remove_from_bot_damage_targets" },
    { 0xA329, "remove_from_bot_use_targets" },
    { 0xA32A, "remove_from_current_interaction_list" },
    { 0xA32B, "remove_from_current_interaction_list_for_player" },
    { 0xA32C, "remove_from_enemy_list" },
    { 0xA32D, "remove_from_hack_attackers_list" },
    { 0xA32E, "remove_from_identified_ieds_list" },
    { 0xA32F, "remove_from_kill_off_list" },
    { 0xA330, "remove_from_list_on_death" },
    { 0xA331, "remove_from_marked_critical_enemy_ai_list_on_death" },
    { 0xA332, "remove_from_marked_enemy_ai_list_on_death" },
    { 0xA333, "remove_from_module_vehicles_list" },
    { 0xA334, "remove_from_nag_vo" },
    { 0xA335, "remove_from_overwatch_target_group" },
    { 0xA336, "remove_from_owner_revive_icon_list" },
    { 0xA337, "remove_from_player_revive_icon_list" },
    { 0xA338, "remove_from_players_as_passenger_list" },
    { 0xA339, "remove_from_players_being_revived" },
    { 0xA33A, "remove_from_players_cannot_see_vehicle_icon_list" },
    { 0xA33B, "remove_from_revive_icon_entity_list" },
    { 0xA33C, "remove_from_snakecam_immediate" },
    { 0xA33D, "remove_from_spawner_flags" },
    { 0xA33E, "remove_from_special_lockon_target_list" },
    { 0xA33F, "remove_from_struct_array" },
    { 0xA340, "remove_from_target_marker_group" },
    { 0xA341, "remove_from_unidentified_ieds_list" },
    { 0xA342, "remove_from_vehicle_queue" },
    { 0xA343, "remove_from_vehicle_repair_interaction_list" },
    { 0xA344, "remove_from_weapon_array" },
    { 0xA345, "remove_fxlighting_object" },
    { 0xA346, "remove_gas_mask" },
    { 0xA347, "remove_global_spawn_function" },
    { 0xA348, "remove_graycard_objects" },
    { 0xA349, "remove_green_beam" },
    { 0xA34A, "remove_grenades" },
    { 0xA34B, "remove_group_fulton_interact" },
    { 0xA34C, "remove_gun" },
    { 0xA34D, "remove_gunless_monitor" },
    { 0xA34E, "remove_hadir" },
    { 0xA34F, "remove_hadir_blocker_house" },
    { 0xA350, "remove_headicon_on_death" },
    { 0xA351, "remove_heli_corpse_after_timeout" },
    { 0xA352, "remove_ied_marker_vfx" },
    { 0xA353, "remove_if_ignited_oilfire" },
    { 0xA354, "remove_ignition_flare" },
    { 0xA355, "remove_intel_item" },
    { 0xA356, "remove_intel_piece" },
    { 0xA357, "remove_invalid_aitypes" },
    { 0xA358, "remove_item_from_priority_queue" },
    { 0xA359, "remove_item_if_already_in_queue" },
    { 0xA35A, "remove_jugg_key" },
    { 0xA35B, "remove_jugg_suit_after_timer" },
    { 0xA35C, "remove_key_card_head_icon" },
    { 0xA35D, "remove_laptop" },
    { 0xA35E, "remove_launcher_after_timeout" },
    { 0xA35F, "remove_lead" },
    { 0xA360, "remove_line_from_open" },
    { 0xA361, "remove_magic_bullet_shield_from_guy_on_unload_or_death" },
    { 0xA362, "remove_mask" },
    { 0xA363, "remove_mask_overlay" },
    { 0xA364, "remove_mayhem_clip_under_ladder" },
    { 0xA365, "remove_missile_defense_weapons" },
    { 0xA366, "remove_most_recently_used_spawner" },
    { 0xA367, "remove_munition" },
    { 0xA368, "remove_munition_from_array" },
    { 0xA369, "remove_name" },
    { 0xA36A, "remove_node_clip" },
    { 0xA36B, "remove_nodes_away_from_navmesh" },
    { 0xA36C, "remove_noteworthy_from_array" },
    { 0xA36D, "remove_offhand_for_molotov" },
    { 0xA36E, "remove_oldest_item_at_priority" },
    { 0xA36F, "remove_on_notify" },
    { 0xA370, "remove_one_item" },
    { 0xA371, "remove_open_ability" },
    { 0xA372, "remove_open_interact_hint" },
    { 0xA373, "remove_open_prompts" },
    { 0xA374, "remove_option" },
    { 0xA375, "remove_outline_on_exit_think" },
    { 0xA376, "remove_pacifist_flag_from_spawns" },
    { 0xA377, "remove_pacifist_from_enemies" },
    { 0xA378, "remove_pacifist_from_guy" },
    { 0xA379, "remove_pacifist_spawn_flag" },
    { 0xA37A, "remove_passive_wave_spawning_spawner_override" },
    { 0xA37B, "remove_path_dist" },
    { 0xA37C, "remove_pilot_from_cockpit" },
    { 0xA37D, "remove_pipes_jumpdown_lights" },
    { 0xA37E, "remove_pistol_arena_blocker" },
    { 0xA37F, "remove_player_armor" },
    { 0xA380, "remove_player_from_attacker_list" },
    { 0xA381, "remove_player_from_cam" },
    { 0xA382, "remove_player_gasmask" },
    { 0xA383, "remove_player_perks" },
    { 0xA384, "remove_player_rig" },
    { 0xA385, "remove_prime_ents" },
    { 0xA386, "remove_reaper_weapons" },
    { 0xA387, "remove_recon_silencer" },
    { 0xA388, "remove_reflection_objects" },
    { 0xA389, "remove_replace_on_death" },
    { 0xA38A, "remove_road_corner_ai_clip" },
    { 0xA38B, "remove_road_corner_ai_clip_watcher" },
    { 0xA38C, "remove_rpg_guys" },
    { 0xA38D, "remove_rpg_on_back" },
    { 0xA38E, "remove_script_friendnames_from_list" },
    { 0xA38F, "remove_scripted_deaths" },
    { 0xA390, "remove_selectable" },
    { 0xA391, "remove_selected_option" },
    { 0xA392, "remove_sentry_for_player" },
    { 0xA393, "remove_similar_nodes" },
    { 0xA394, "remove_skipdeathanim" },
    { 0xA395, "remove_spawn_function" },
    { 0xA396, "remove_spawn_scoring_poi" },
    { 0xA397, "remove_spawners_from_passive_wave_spawning" },
    { 0xA398, "remove_spygame_when_down" },
    { 0xA399, "remove_state" },
    { 0xA39A, "remove_team_armor_buff" },
    { 0xA39B, "remove_team_stopping_power" },
    { 0xA39C, "remove_temporal_increase" },
    { 0xA39D, "remove_twister" },
    { 0xA39E, "remove_van_lights" },
    { 0xA39F, "remove_vehicle_spawned_thisframe" },
    { 0xA3A0, "remove_visionset_from_stack" },
    { 0xA3A1, "remove_visionset_specific_from_stack" },
    { 0xA3A2, "remove_visuals" },
    { 0xA3A3, "remove_vo_data" },
    { 0xA3A4, "remove_when_charges_exhausted" },
    { 0xA3A5, "remove_when_no_one_around" },
    { 0xA3A6, "remove_wife_blendshape_in_hallway" },
    { 0xA3A7, "remove_without_classname" },
    { 0xA3A8, "remove_without_model" },
    { 0xA3A9, "removeactivecounteruav" },
    { 0xA3AA, "removeactivespawner" },
    { 0xA3AB, "removeactiveuav" },
    { 0xA3AC, "removeadrenaline" },
    { 0xA3AD, "removealarmdoor" },
    { 0xA3AE, "removealarmmonitor" },
    { 0xA3AF, "removeallaqui" },
    { 0xA3B0, "removeallevents" },
    { 0xA3B1, "removeallfromlivescount" },
    { 0xA3B2, "removeallmolotovinteractsuntilavailable" },
    { 0xA3B3, "removeallobjids" },
    { 0xA3B4, "removealtmodefromweaponname" },
    { 0xA3B5, "removeambulances" },
    { 0xA3B6, "removearchetype" },
    { 0xA3B7, "removeattachmentsandgiveweapon" },
    { 0xA3B8, "removebestminimapid" },
    { 0xA3B9, "removebestobjectiveid" },
    { 0xA3BA, "removebestsentient" },
    { 0xA3BB, "removebestworldid" },
    { 0xA3BC, "removebombcarrierclass" },
    { 0xA3BD, "removebombzonec" },
    { 0xA3BE, "removeboxfromlevelarray" },
    { 0xA3BF, "removeboxfromownerarray" },
    { 0xA3C0, "removecallout" },
    { 0xA3C1, "removecameraondisconnect" },
    { 0xA3C2, "removecarrydebuff" },
    { 0xA3C3, "removechild" },
    { 0xA3C4, "removeconflictingattachments" },
    { 0xA3C5, "removeconflictingdefaultattachment" },
    { 0xA3C6, "removecustombcevent" },
    { 0xA3C7, "removed" },
    { 0xA3C8, "removed_building_lines" },
    { 0xA3C9, "removedamagemodifier" },
    { 0xA3CA, "removedamagemodifieronlaststand" },
    { 0xA3CB, "removedamagemodifierontimeout" },
    { 0xA3CC, "removedeletableexploders" },
    { 0xA3CD, "removedestroyedchildren" },
    { 0xA3CE, "removedisconnectedplayerfromplacement" },
    { 0xA3CF, "removedjuggupdater" },
    { 0xA3D0, "removedompoint" },
    { 0xA3D1, "removedoorcollision" },
    { 0xA3D2, "removedronescreeneffects" },
    { 0xA3D3, "removedynamicspawnarea" },
    { 0xA3D4, "removeenemyoutlines" },
    { 0xA3D5, "removeequip" },
    { 0xA3D6, "removeexcludedattachments" },
    { 0xA3D7, "removeextractionkillstreak" },
    { 0xA3D8, "removefirechainsdamagemodifieronlaststand" },
    { 0xA3D9, "removefirechainsdamagemodifierontimeout" },
    { 0xA3DA, "removefiredamageimmediate" },
    { 0xA3DB, "removeflag" },
    { 0xA3DC, "removeflagcarrierclass" },
    { 0xA3DD, "removeflagoutlineongameend" },
    { 0xA3DE, "removeflagpickupradiuseffect" },
    { 0xA3DF, "removefromactivekillstreaklist" },
    { 0xA3E0, "removefromairstrikelistondeath" },
    { 0xA3E1, "removefromalivecount" },
    { 0xA3E2, "removefromassaultdronelistondeath" },
    { 0xA3E3, "removefromcarrylistondeathorcarry" },
    { 0xA3E4, "removefromcharactersarray" },
    { 0xA3E5, "removefromhelilist" },
    { 0xA3E6, "removefromhelilistondeath" },
    { 0xA3E7, "removefrominteractionslistbynoteworthy" },
    { 0xA3E8, "removefrominventorybyindex" },
    { 0xA3E9, "removefromlists" },
    { 0xA3EA, "removefromlittlebirdlistondeath" },
    { 0xA3EB, "removefromlivescount" },
    { 0xA3EC, "removefromparticipantsarray" },
    { 0xA3ED, "removefrompersonalinteractionlist" },
    { 0xA3EE, "removefromplayerkillstreaklistondeath" },
    { 0xA3EF, "removefromprojectilelistondeath" },
    { 0xA3F0, "removefromremotekillstreaklistondeath" },
    { 0xA3F1, "removefromspawnedgrouparray" },
    { 0xA3F2, "removefromspawnselection" },
    { 0xA3F3, "removefromspawnselectionaftertime" },
    { 0xA3F4, "removefromsquad" },
    { 0xA3F5, "removefromsupportdronelistondeath" },
    { 0xA3F6, "removefromsystem" },
    { 0xA3F7, "removefromtacopsmap" },
    { 0xA3F8, "removefromtargetmarkeronkillfunc" },
    { 0xA3F9, "removefromteamcount" },
    { 0xA3FA, "removefromteamlives" },
    { 0xA3FB, "removefromtraplist" },
    { 0xA3FC, "removefromturretlist" },
    { 0xA3FD, "removefromturretlistondeathorcarry" },
    { 0xA3FE, "removefromuavlistondeath" },
    { 0xA3FF, "removefromugvlist" },
    { 0xA400, "removefrozentickontimeout" },
    { 0xA401, "removefunc" },
    { 0xA402, "removegasmask" },
    { 0xA403, "removeglobalrankxpmultiplier" },
    { 0xA404, "removeglobalspawnarea" },
    { 0xA405, "removeglobalweaponrankxpmultiplier" },
    { 0xA406, "removegpsjammer" },
    { 0xA407, "removeheadgear" },
    { 0xA408, "removeheadicon" },
    { 0xA409, "removeheavyarmor" },
    { 0xA40A, "removehelidroppingcratefromlist" },
    { 0xA40B, "removehelperdrone" },
    { 0xA40C, "removehudincoming_attacker" },
    { 0xA40D, "removeifalerted" },
    { 0xA40E, "removeincominghelperdrone" },
    { 0xA40F, "removeinvalidperks" },
    { 0xA410, "removeinvalidstructs" },
    { 0xA411, "removeitemfrominventory" },
    { 0xA412, "removejuggernautweapononaction" },
    { 0xA413, "removejuggongameended" },
    { 0xA414, "removejuggonteamchangeordeath" },
    { 0xA415, "removekilleventsplash" },
    { 0xA416, "removekillstreak" },
    { 0xA417, "removelinkafterdelay" },
    { 0xA418, "removelittlebird" },
    { 0xA419, "removeloadingplayer" },
    { 0xA41A, "removelockedon" },
    { 0xA41B, "removelowermessage" },
    { 0xA41C, "removemapvisionset" },
    { 0xA41D, "removemarkfromtarget" },
    { 0xA41E, "removeminimapicons" },
    { 0xA41F, "removemoltovinteract" },
    { 0xA420, "removenotetrack" },
    { 0xA421, "removenowyouseemeonlaststand" },
    { 0xA422, "removenukeweapononaction" },
    { 0xA423, "removenvg" },
    { 0xA424, "removeobjective" },
    { 0xA425, "removeoffhandloot" },
    { 0xA426, "removeofficerfromsquad" },
    { 0xA427, "removeoldattackersovertime" },
    { 0xA428, "removeoldevents" },
    { 0xA429, "removeondeath" },
    { 0xA42A, "removeorbitcamera" },
    { 0xA42B, "removeoutline" },
    { 0xA42C, "removeoutlineoccluder" },
    { 0xA42D, "removeoutlineonnotify" },
    { 0xA42E, "removeperk" },
    { 0xA42F, "removeperks" },
    { 0xA430, "removeperkstemp" },
    { 0xA431, "removeplayerdataafterleavinggame" },
    { 0xA432, "removeplayerfromlevelarrays" },
    { 0xA433, "removeplayerfromteam" },
    { 0xA434, "removeplayerondisconnect" },
    { 0xA435, "removeplayeroutlinesforoverheadcam" },
    { 0xA436, "removepoint" },
    { 0xA437, "removepower" },
    { 0xA438, "removequestinstance" },
    { 0xA439, "removeradialdistortion" },
    { 0xA43A, "removeradialdistortion_notify" },
    { 0xA43B, "removerankxpmultiplier" },
    { 0xA43C, "removeremoteweapon" },
    { 0xA43D, "removerespawntoken" },
    { 0xA43E, "removereviveentfromlevelarrayondeath" },
    { 0xA43F, "removeselected" },
    { 0xA440, "removeselffrom_squadlastseenenemypos" },
    { 0xA441, "removeselfreviveonearlyexit" },
    { 0xA442, "removeshield" },
    { 0xA443, "removeslowmoveonlaststand" },
    { 0xA444, "removespawn" },
    { 0xA445, "removespawnareaondeathdisconnect" },
    { 0xA446, "removespawncircleents" },
    { 0xA447, "removespawndangerzone" },
    { 0xA448, "removespawnerfromcolornumberarray" },
    { 0xA449, "removespawnlocation" },
    { 0xA44A, "removespawnmessageshortly" },
    { 0xA44B, "removespawnprotection" },
    { 0xA44C, "removespawnsinactivedz" },
    { 0xA44D, "removespawnsinactiveflag" },
    { 0xA44E, "removespawnsinactivehq" },
    { 0xA44F, "removespawnviewer" },
    { 0xA450, "removespeaker" },
    { 0xA451, "removestashlocation" },
    { 0xA452, "removesuppressioneffectsaftertimeout" },
    { 0xA453, "removetags" },
    { 0xA454, "removetagsongameended" },
    { 0xA455, "removetargetmarkergroup" },
    { 0xA456, "removeteamheadicononnotify" },
    { 0xA457, "removeteamrankxpmultiplier" },
    { 0xA458, "removethermal" },
    { 0xA459, "removethinker" },
    { 0xA45A, "removetimedoutinstructions" },
    { 0xA45B, "removetrigger" },
    { 0xA45C, "removetriggerobject" },
    { 0xA45D, "removeuavmodel" },
    { 0xA45E, "removeundefined" },
    { 0xA45F, "removeuplinkgoal" },
    { 0xA460, "removeuseobject" },
    { 0xA461, "removeweaponaftertimeout" },
    { 0xA462, "removeweaponhostagedrop" },
    { 0xA463, "removeweaponrankxpmultiplier" },
    { 0xA464, "removeweapons" },
    { 0xA465, "renderlasertargetting" },
    { 0xA466, "repair_icon_clean_up_think" },
    { 0xA467, "repair_interaction_list" },
    { 0xA468, "repair_nag" },
    { 0xA469, "repair_tag" },
    { 0xA46A, "repair_think" },
    { 0xA46B, "repair_vehicle_intro_vo_monitor" },
    { 0xA46C, "repair_wave_think" },
    { 0xA46D, "repeat" },
    { 0xA46E, "repeater_headshot_ammo_passive" },
    { 0xA46F, "replace_door_open_interact_hint" },
    { 0xA470, "replace_fake_actors_with_real" },
    { 0xA471, "replace_on_death" },
    { 0xA472, "replace_sas_with_police" },
    { 0xA473, "replacetankwithwheelson" },
    { 0xA474, "replacewithspecialistkillstreaks" },
    { 0xA475, "replenishloadout" },
    { 0xA476, "report_trigger" },
    { 0xA477, "reportalias" },
    { 0xA478, "reportchallengeuserevent_done" },
    { 0xA479, "reposition_cover_node" },
    { 0xA47A, "reproductionstreak" },
    { 0xA47B, "repulsor" },
    { 0xA47C, "repulsorent" },
    { 0xA47D, "repulsorname" },
    { 0xA47E, "request_hostage_id" },
    { 0xA47F, "request_new_spawn_module" },
    { 0xA480, "request_overwatch_vo" },
    { 0xA481, "request_paratroopers" },
    { 0xA482, "requestarchive" },
    { 0xA483, "requestcoverfind" },
    { 0xA484, "requested_spawners" },
    { 0xA485, "requested_spawns_count" },
    { 0xA486, "requested_spawns_groups" },
    { 0xA487, "requestednode" },
    { 0xA488, "requestednodetype" },
    { 0xA489, "requestedspeed" },
    { 0xA48A, "requestedturret" },
    { 0xA48B, "requestedturretpose" },
    { 0xA48C, "requestentervehicle" },
    { 0xA48D, "requestexitvehicle" },
    { 0xA48E, "requestid" },
    { 0xA48F, "requestminimapid" },
    { 0xA490, "requestnewsquad" },
    { 0xA491, "requestobjectiveid" },
    { 0xA492, "requestopendoor" },
    { 0xA493, "requestopendoorparams" },
    { 0xA494, "requestquestlocale" },
    { 0xA495, "requestreservedid" },
    { 0xA496, "requesttime" },
    { 0xA497, "requestworldid" },
    { 0xA498, "requiredexitstance" },
    { 0xA499, "requiredplayercount" },
    { 0xA49A, "requires_power" },
    { 0xA49B, "requireslos" },
    { 0xA49C, "requiresminstartspawns" },
    { 0xA49D, "reroll_binary_op" },
    { 0xA49E, "rerollcallback" },
    { 0xA49F, "rerollcrate" },
    { 0xA4A0, "rerollstring" },
    { 0xA4A1, "rescue_hadir_sequence" },
    { 0xA4A2, "rescue_soldier01_ai" },
    { 0xA4A3, "rescue_soldier01b_ai" },
    { 0xA4A4, "rescue_soldier02_ai" },
    { 0xA4A5, "rescue_type_escort" },
    { 0xA4A6, "rescue_type_harness" },
    { 0xA4A7, "rescuedplayers" },
    { 0xA4A8, "reserve_turret" },
    { 0xA4A9, "reserved" },
    { 0xA4AA, "reserved_spawn_slots" },
    { 0xA4AB, "reservevehicle" },
    { 0xA4AC, "reset_active_count" },
    { 0xA4AD, "reset_actor_interaction_values" },
    { 0xA4AE, "reset_after_anim" },
    { 0xA4AF, "reset_aisettings_on_plane" },
    { 0xA4B0, "reset_all_ai_sight" },
    { 0xA4B1, "reset_axis_of_selected_ents" },
    { 0xA4B2, "reset_baseaccuracy" },
    { 0xA4B3, "reset_convoy_soon" },
    { 0xA4B4, "reset_door" },
    { 0xA4B5, "reset_drop_inc" },
    { 0xA4B6, "reset_encounter_performance" },
    { 0xA4B7, "reset_end_game_score" },
    { 0xA4B8, "reset_enemy_turret_shot_count" },
    { 0xA4B9, "reset_eog_stats" },
    { 0xA4BA, "reset_event_timers" },
    { 0xA4BB, "reset_farah_glowstick" },
    { 0xA4BC, "reset_friendlyfire_participation" },
    { 0xA4BD, "reset_friendlyfire_penalties" },
    { 0xA4BE, "reset_fx_hud_colors" },
    { 0xA4BF, "reset_gasmask" },
    { 0xA4C0, "reset_gravity" },
    { 0xA4C1, "reset_grenades" },
    { 0xA4C2, "reset_group_advance_to_enemy_timer" },
    { 0xA4C3, "reset_gunpose" },
    { 0xA4C4, "reset_guy" },
    { 0xA4C5, "reset_in_pvpe_end_game" },
    { 0xA4C6, "reset_interaction" },
    { 0xA4C7, "reset_interaction_linebook" },
    { 0xA4C8, "reset_interaction_triggers" },
    { 0xA4C9, "reset_interrupt_vo" },
    { 0xA4CA, "reset_machine_state" },
    { 0xA4CB, "reset_meter" },
    { 0xA4CC, "reset_munitions" },
    { 0xA4CD, "reset_objective_omnvars" },
    { 0xA4CE, "reset_objective_slots" },
    { 0xA4CF, "reset_objective_timers" },
    { 0xA4D0, "reset_override_visionset" },
    { 0xA4D1, "reset_path_node_placement" },
    { 0xA4D2, "reset_path_node_placement_for_box_creation" },
    { 0xA4D3, "reset_path_node_placement_for_lookat" },
    { 0xA4D4, "reset_path_node_placement_for_radius" },
    { 0xA4D5, "reset_player_consumables_earned_performance" },
    { 0xA4D6, "reset_player_damage_performance" },
    { 0xA4D7, "reset_player_encounter_lua_omnvars" },
    { 0xA4D8, "reset_player_encounter_performance" },
    { 0xA4D9, "reset_player_money_earned_performance" },
    { 0xA4DA, "reset_player_performance_func" },
    { 0xA4DB, "reset_player_tickets_earned_performance" },
    { 0xA4DC, "reset_players_encounter_performance_and_lua" },
    { 0xA4DD, "reset_players_subparty_data" },
    { 0xA4DE, "reset_poiauto_constraints" },
    { 0xA4DF, "reset_prone_scale_post_first_raise" },
    { 0xA4E0, "reset_respawner_markers" },
    { 0xA4E1, "reset_root" },
    { 0xA4E2, "reset_spawn_count_from_groupname" },
    { 0xA4E3, "reset_spawn_point_targetname" },
    { 0xA4E4, "reset_spawn_vars" },
    { 0xA4E5, "reset_special_ammo" },
    { 0xA4E6, "reset_speed_at_node" },
    { 0xA4E7, "reset_struct_when_pent_moves" },
    { 0xA4E8, "reset_subobjective_slot" },
    { 0xA4E9, "reset_team_consumables_earned_performance" },
    { 0xA4EA, "reset_team_damage_performance" },
    { 0xA4EB, "reset_team_money_earned_performance" },
    { 0xA4EC, "reset_team_performance_func" },
    { 0xA4ED, "reset_team_tickets_earned_performance" },
    { 0xA4EE, "reset_throttle" },
    { 0xA4EF, "reset_time" },
    { 0xA4F0, "reset_totals_texts" },
    { 0xA4F1, "reset_turret_shot_count" },
    { 0xA4F2, "reset_unresolved_collision_handler" },
    { 0xA4F3, "reset_visionset_on_disconnect" },
    { 0xA4F4, "reset_visionset_on_spawn" },
    { 0xA4F5, "reset_visionset_on_team_change" },
    { 0xA4F6, "resetactionslots" },
    { 0xA4F7, "resetalldoors" },
    { 0xA4F8, "resetattackerlist" },
    { 0xA4F9, "resetattackerlist_internal" },
    { 0xA4FA, "resetbombsite" },
    { 0xA4FB, "resetbombzone" },
    { 0xA4FC, "resetbroshot" },
    { 0xA4FD, "resetc4explodethisframe" },
    { 0xA4FE, "resetcacheuseability" },
    { 0xA4FF, "resetcaptureprogress" },
    { 0xA500, "resetconvergence" },
    { 0xA501, "resetcqbtwitch" },
    { 0xA502, "resetdefaultweaponammo" },
    { 0xA503, "resetents" },
    { 0xA504, "resetequipment" },
    { 0xA505, "resetforloadoutswitch" },
    { 0xA506, "resetfovzoom" },
    { 0xA507, "resetfunctionality" },
    { 0xA508, "resetgoalpos" },
    { 0xA509, "resetgroupvariables" },
    { 0xA50A, "resetguidedinteraction" },
    { 0xA50B, "resethitmanaftertimeout" },
    { 0xA50C, "resethvtstatus" },
    { 0xA50D, "resetjugg" },
    { 0xA50E, "resetjuggloadoutonchangeteam" },
    { 0xA50F, "resetjuggloadoutondisconnect" },
    { 0xA510, "resetlevelarrays" },
    { 0xA511, "resetlevelflags" },
    { 0xA512, "resetmissdebouncetime" },
    { 0xA513, "resetmissilelauncherlocking" },
    { 0xA514, "resetmissilelauncherlockingondeath" },
    { 0xA515, "resetmissiles" },
    { 0xA516, "resetmisstime" },
    { 0xA517, "resetnextsaytimes" },
    { 0xA518, "resetnonfauxspawnscriptfields" },
    { 0xA519, "resetnow" },
    { 0xA51A, "resetperkpackage" },
    { 0xA51B, "resetpersonalent" },
    { 0xA51C, "resetpersstats" },
    { 0xA51D, "resetperupdatespawnglobals" },
    { 0xA51E, "resetpet" },
    { 0xA51F, "resetplayerdamagemodifiers" },
    { 0xA520, "resetplayerhud" },
    { 0xA521, "resetplayerinventory" },
    { 0xA522, "resetplayerinventorywithdelay" },
    { 0xA523, "resetplayeromnvarsonkillcam" },
    { 0xA524, "resetplayeromnvarsonspawn" },
    { 0xA525, "resetplayerspawneffects" },
    { 0xA526, "resetplayerspawnomnvar" },
    { 0xA527, "resetplayerspawnscriptfields" },
    { 0xA528, "resetplayervariables" },
    { 0xA529, "resetpostgamestateonjoinedspectators" },
    { 0xA52A, "resetprogress" },
    { 0xA52B, "resetreticlemarkingprogressstate" },
    { 0xA52C, "resetscoreonroundstart" },
    { 0xA52D, "resetskill" },
    { 0xA52E, "resetsoundtimescalefactor" },
    { 0xA52F, "resetstats" },
    { 0xA530, "resetstingerlocking" },
    { 0xA531, "resetstingerlockingondeath" },
    { 0xA532, "resetstreakavailability" },
    { 0xA533, "resetstreakcount" },
    { 0xA534, "resetstreakpoints" },
    { 0xA535, "resetsuperusepercent" },
    { 0xA536, "resettags" },
    { 0xA537, "resetuidvarsonconnect" },
    { 0xA538, "resetuidvarsonspectate" },
    { 0xA539, "resetuiomnvargamemode" },
    { 0xA53A, "resetuiomnvarscommon" },
    { 0xA53B, "resetzone" },
    { 0xA53C, "residence_arrival_and_exit" },
    { 0xA53D, "residence_arrival_catchup" },
    { 0xA53E, "residence_arrival_civs" },
    { 0xA53F, "residence_arrival_delete_on_exit_door_close" },
    { 0xA540, "residence_arrival_done" },
    { 0xA541, "residence_arrival_door_delete" },
    { 0xA542, "residence_arrival_door_open" },
    { 0xA543, "residence_arrival_door_pauser" },
    { 0xA544, "residence_arrival_door_setup" },
    { 0xA545, "residence_arrival_facade_doors" },
    { 0xA546, "residence_arrival_facade_doors_catchup" },
    { 0xA547, "residence_arrival_handle_technical_on_door_close" },
    { 0xA548, "residence_arrival_main" },
    { 0xA549, "residence_arrival_marines" },
    { 0xA54A, "residence_arrival_marines_look_at" },
    { 0xA54B, "residence_arrival_only" },
    { 0xA54C, "residence_arrival_player_demeanor" },
    { 0xA54D, "residence_arrival_side_door" },
    { 0xA54E, "residence_arrival_stacy_reactions" },
    { 0xA54F, "residence_arrival_start" },
    { 0xA550, "residence_arrival_vfx_cleanup" },
    { 0xA551, "residence_arrival_vo" },
    { 0xA552, "residence_arrival_wolf" },
    { 0xA553, "residence_bodies" },
    { 0xA554, "residence_exit_done" },
    { 0xA555, "residence_wall_swap" },
    { 0xA556, "residualfarradius" },
    { 0xA557, "resistedstun" },
    { 0xA558, "respawn" },
    { 0xA559, "respawn_active" },
    { 0xA55A, "respawn_asspectator" },
    { 0xA55B, "respawn_bleedout_func" },
    { 0xA55C, "respawn_c130" },
    { 0xA55D, "respawn_camera_movement_think" },
    { 0xA55E, "respawn_cooldown" },
    { 0xA55F, "respawn_dpad_func" },
    { 0xA560, "respawn_enemy_list" },
    { 0xA561, "respawn_forcespawnangles" },
    { 0xA562, "respawn_forcespawnorigin" },
    { 0xA563, "respawn_friendlies_force_vision_check" },
    { 0xA564, "respawn_friendlies_without_vision_check" },
    { 0xA565, "respawn_func" },
    { 0xA566, "respawn_function_toggle" },
    { 0xA567, "respawn_in_progress" },
    { 0xA568, "respawn_loc_override_func" },
    { 0xA569, "respawn_on" },
    { 0xA56A, "respawn_on_death" },
    { 0xA56B, "respawn_spawner_org" },
    { 0xA56C, "respawn_uses" },
    { 0xA56D, "respawn_watcher" },
    { 0xA56E, "respawn_with_launcher" },
    { 0xA56F, "respawnbombcase" },
    { 0xA570, "respawnc130_gatherc130playerstospawn" },
    { 0xA571, "respawnc130_jumplistener" },
    { 0xA572, "respawnc130_listenjump" },
    { 0xA573, "respawnc130_listenkick" },
    { 0xA574, "respawnc130_parachute" },
    { 0xA575, "respawnc130_spawnplayertoc130" },
    { 0xA576, "respawnc130_spawnprotection" },
    { 0xA577, "respawnc130_think" },
    { 0xA578, "respawnc130_updateflightpathmessaging" },
    { 0xA579, "respawnc130_watchkickvar" },
    { 0xA57A, "respawnc130cutoff" },
    { 0xA57B, "respawnc130started" },
    { 0xA57C, "respawnclientcharacter" },
    { 0xA57D, "respawnclosets" },
    { 0xA57E, "respawnent" },
    { 0xA57F, "respawner_selection_think" },
    { 0xA580, "respawning" },
    { 0xA581, "respawning_enemies" },
    { 0xA582, "respawningfromtoken" },
    { 0xA583, "respawnitems" },
    { 0xA584, "respawnitems_assignrespawnitems" },
    { 0xA585, "respawnitems_clear" },
    { 0xA586, "respawnitems_getequipmentref" },
    { 0xA587, "respawnitems_getrespawnitems" },
    { 0xA588, "respawnitems_getstreakpoints" },
    { 0xA589, "respawnitems_getstreaks" },
    { 0xA58A, "respawnitems_getsuperextrapoints" },
    { 0xA58B, "respawnitems_getsuperpoints" },
    { 0xA58C, "respawnitems_getsuperref" },
    { 0xA58D, "respawnitems_getweaponobj" },
    { 0xA58E, "respawnitems_giveequipmentammo" },
    { 0xA58F, "respawnitems_giveweaponammo" },
    { 0xA590, "respawnitems_hasequipmentdata" },
    { 0xA591, "respawnitems_hasrespawnitems" },
    { 0xA592, "respawnitems_hasstreakdata" },
    { 0xA593, "respawnitems_hassuperdata" },
    { 0xA594, "respawnitems_hasweapondata" },
    { 0xA595, "respawnitems_saveequipment" },
    { 0xA596, "respawnitems_saveequipmentitems" },
    { 0xA597, "respawnitems_saveplayeritemstostruct" },
    { 0xA598, "respawnitems_savestreaks" },
    { 0xA599, "respawnitems_savesuper" },
    { 0xA59A, "respawnitems_saveweapon" },
    { 0xA59B, "respawnitems_saveweapons" },
    { 0xA59C, "respawnoldjugg" },
    { 0xA59D, "respawnoldjugg_fx" },
    { 0xA59E, "respawnqueue" },
    { 0xA59F, "respawntimerstarttime" },
    { 0xA5A0, "respond_if_player_chases" },
    { 0xA5A1, "respond_player_location_dialogue" },
    { 0xA5A2, "responder" },
    { 0xA5A3, "responderclockdirection" },
    { 0xA5A4, "respondto" },
    { 0xA5A5, "response_timeout" },
    { 0xA5A6, "responsealiases" },
    { 0xA5A7, "responseevent_failsafe" },
    { 0xA5A8, "responsegeneric" },
    { 0xA5A9, "responselocationcallout" },
    { 0xA5AA, "responsetakingfire" },
    { 0xA5AB, "responsethreatcallout" },
    { 0xA5AC, "responsethreatexposed" },
    { 0xA5AD, "responsetimedout" },
    { 0xA5AE, "responsive" },
    { 0xA5AF, "restart" },
    { 0xA5B0, "restart_breath_fade" },
    { 0xA5B1, "restart_fx_looper" },
    { 0xA5B2, "restart_map" },
    { 0xA5B3, "restart_rotors" },
    { 0xA5B4, "restart_trial_attempt" },
    { 0xA5B5, "restarteffect" },
    { 0xA5B6, "restartexploder" },
    { 0xA5B7, "restartlevel" },
    { 0xA5B8, "restartmission" },
    { 0xA5B9, "restarttimer" },
    { 0xA5BA, "restock_allieslogic" },
    { 0xA5BB, "restock_allyplace" },
    { 0xA5BC, "restock_connectiedpaths" },
    { 0xA5BD, "restock_dialoguelogic" },
    { 0xA5BE, "restock_getfarahnode" },
    { 0xA5BF, "restock_gethadirnode" },
    { 0xA5C0, "restock_getiedpathentities" },
    { 0xA5C1, "restock_getredshirtnodes" },
    { 0xA5C2, "restock_main" },
    { 0xA5C3, "restock_plantingallylogic" },
    { 0xA5C4, "restock_playerlogic" },
    { 0xA5C5, "restock_preplaceied" },
    { 0xA5C6, "restock_preplaceieds" },
    { 0xA5C7, "restock_replacediedlogic" },
    { 0xA5C8, "restock_setupradioally" },
    { 0xA5C9, "restock_start" },
    { 0xA5CA, "restore_after_deathsdoor" },
    { 0xA5CB, "restore_default_player_control_post_carry" },
    { 0xA5CC, "restore_fov_of_player_during_hvt_interact" },
    { 0xA5CD, "restore_fov_of_player_during_rappel" },
    { 0xA5CE, "restore_func" },
    { 0xA5CF, "restore_outline_settings" },
    { 0xA5D0, "restore_player_demeanor" },
    { 0xA5D1, "restore_player_perk" },
    { 0xA5D2, "restore_player_weapons_after_bleedout" },
    { 0xA5D3, "restore_players_weapons" },
    { 0xA5D4, "restore_powers" },
    { 0xA5D5, "restore_primary_weapons_only" },
    { 0xA5D6, "restore_replaced_weapon" },
    { 0xA5D7, "restore_super_weapon" },
    { 0xA5D8, "restore_weapons_status" },
    { 0xA5D9, "restoreangles" },
    { 0xA5DA, "restorebasevisionset" },
    { 0xA5DB, "restoredefaultpitch" },
    { 0xA5DC, "restoredefaults" },
    { 0xA5DD, "restoreperk" },
    { 0xA5DE, "restoreperks" },
    { 0xA5DF, "restorepitch" },
    { 0xA5E0, "restoreriotshieldonland" },
    { 0xA5E1, "restorespawner" },
    { 0xA5E2, "restorestrengthafterhostmigration" },
    { 0xA5E3, "restoreweapon" },
    { 0xA5E4, "restoreweaponlist" },
    { 0xA5E5, "restoreweapons" },
    { 0xA5E6, "restoreweaponsdefaultfunc" },
    { 0xA5E7, "restrict_player_stance_to_this" },
    { 0xA5E8, "restrictingads" },
    { 0xA5E9, "restrictingdoublejump" },
    { 0xA5EA, "restrictingfire" },
    { 0xA5EB, "restrictingmantle" },
    { 0xA5EC, "restrictingmeleeattack" },
    { 0xA5ED, "restrictingoffhandweapons" },
    { 0xA5EE, "restrictingpronemovement" },
    { 0xA5EF, "restrictingpronespeed" },
    { 0xA5F0, "restrictingpronestance" },
    { 0xA5F1, "restrictingreload" },
    { 0xA5F2, "restrictingsprint" },
    { 0xA5F3, "restrictingwallrun" },
    { 0xA5F4, "restrictingweaponswitch" },
    { 0xA5F5, "restrictions" },
    { 0xA5F6, "results" },
    { 0xA5F7, "resume_chatter" },
    { 0xA5F8, "resume_idle_or_anim" },
    { 0xA5F9, "resume_interrogation" },
    { 0xA5FA, "resume_tank" },
    { 0xA5FB, "resume_technical" },
    { 0xA5FC, "resumeballtimer" },
    { 0xA5FD, "resumecountdowntimer" },
    { 0xA5FE, "resumetacopstimer" },
    { 0xA5FF, "resumetimer" },
    { 0xA600, "resupply_nag" },
    { 0xA601, "retaliate" },
    { 0xA602, "reticlestate" },
    { 0xA603, "retreat_advance_available_left_paths" },
    { 0xA604, "retreat_advance_available_left_paths_index" },
    { 0xA605, "retreat_advance_available_right_paths" },
    { 0xA606, "retreat_advance_available_right_paths_index" },
    { 0xA607, "retreat_allied_nav_clip_disable" },
    { 0xA608, "retreat_allied_nav_clip_enable" },
    { 0xA609, "retreat_aq_counterattack_flank_retreat_monitor" },
    { 0xA60A, "retreat_aq_counterattack_handler" },
    { 0xA60B, "retreat_aq_counterattack_rooftop_handler" },
    { 0xA60C, "retreat_aq_counterattack_timeout" },
    { 0xA60D, "retreat_assault_turret" },
    { 0xA60E, "retreat_assault_vehicle" },
    { 0xA60F, "retreat_assault_vehicle_sound" },
    { 0xA610, "retreat_backup_apc_handler" },
    { 0xA611, "retreat_body_cleanup" },
    { 0xA612, "retreat_bombardment_player_monitor" },
    { 0xA613, "retreat_building_magic_bullets" },
    { 0xA614, "retreat_building_magic_bullets_damage_monitor" },
    { 0xA615, "retreat_building_magic_bullets_fire" },
    { 0xA616, "retreat_building_magic_bullets_fire_bradley_ping" },
    { 0xA617, "retreat_catchup" },
    { 0xA618, "retreat_crawling_deaths_handler" },
    { 0xA619, "retreat_door_bash_monitor" },
    { 0xA61A, "retreat_gate_breach_griggs_runby" },
    { 0xA61B, "retreat_gate_breach_marines" },
    { 0xA61C, "retreat_ground_vehicle_movement_sound" },
    { 0xA61D, "retreat_heli_left" },
    { 0xA61E, "retreat_heli_left_1" },
    { 0xA61F, "retreat_heli_left_deploy" },
    { 0xA620, "retreat_heli_right" },
    { 0xA621, "retreat_heli_right_1" },
    { 0xA622, "retreat_heli_right_deploy" },
    { 0xA623, "retreat_hospital_gate_distance_check" },
    { 0xA624, "retreat_init" },
    { 0xA625, "retreat_main" },
    { 0xA626, "retreat_marine_bombardment_reaction_dialogue" },
    { 0xA627, "retreat_marine_setup" },
    { 0xA628, "retreat_open_hospital_gate" },
    { 0xA629, "retreat_rpg_detonation_manager" },
    { 0xA62A, "retreat_rpg_detonation_monitor" },
    { 0xA62B, "retreat_start" },
    { 0xA62C, "retreat_support_apc_1" },
    { 0xA62D, "retreat_support_apc_1_sound" },
    { 0xA62E, "retreat_support_apc_2" },
    { 0xA62F, "retreat_support_apc_2_sound" },
    { 0xA630, "retreat_tank_advance" },
    { 0xA631, "retreat_tank_rpg_hit" },
    { 0xA632, "retreat_to_gap_sniping" },
    { 0xA633, "retreat_window_glass_shatter" },
    { 0xA634, "retrieve_interrupt_vo" },
    { 0xA635, "retrieve_vo_from_queue" },
    { 0xA636, "retry_timer" },
    { 0xA637, "retry_total_votes" },
    { 0xA638, "retry_yes_votes" },
    { 0xA639, "return_anime" },
    { 0xA63A, "return_cleanupcivilianworkers" },
    { 0xA63B, "return_cover_spawners" },
    { 0xA63C, "return_enemyspawners_in_zones" },
    { 0xA63D, "return_false" },
    { 0xA63E, "return_getfarahanimationstruct" },
    { 0xA63F, "return_getpathblockers" },
    { 0xA640, "return_getplayerexittrigger" },
    { 0xA641, "return_main" },
    { 0xA642, "return_musiclogic" },
    { 0xA643, "return_nearby_cover_nodes" },
    { 0xA644, "return_paratroopers_spawners" },
    { 0xA645, "return_pathblockersclear" },
    { 0xA646, "return_player_to_previous_vehicle_seat" },
    { 0xA647, "return_random_number" },
    { 0xA648, "return_spawners_by_targetname" },
    { 0xA649, "return_start" },
    { 0xA64A, "return_to_compound_objective" },
    { 0xA64B, "return_to_last_goalradius" },
    { 0xA64C, "return_to_mission_nagged" },
    { 0xA64D, "return_to_previous_seat" },
    { 0xA64E, "return_to_safehouse_vo" },
    { 0xA64F, "return_to_seat_after_ambush_sniper" },
    { 0xA650, "return_to_vehicle_after_ambush_sniper" },
    { 0xA651, "return_triggerer" },
    { 0xA652, "return_true" },
    { 0xA653, "return_undefined_param_if_empty" },
    { 0xA654, "return_wave_veh_spawners" },
    { 0xA655, "return_wbk_version_of_weapon" },
    { 0xA656, "return_weapon_name_with_like_attachments" },
    { 0xA657, "return_when_cansee_player" },
    { 0xA658, "returnaftertime" },
    { 0xA659, "returnarraywithoutdefaults" },
    { 0xA65A, "returnblankfuncifundefined" },
    { 0xA65B, "returnflag" },
    { 0xA65C, "returngoal" },
    { 0xA65D, "returnheadicons" },
    { 0xA65E, "returnhome" },
    { 0xA65F, "returnminimapid" },
    { 0xA660, "returnobjectiveid" },
    { 0xA661, "returnoncorner" },
    { 0xA662, "returnonwarpstart" },
    { 0xA663, "returnplayer" },
    { 0xA664, "returnreservedobjectiveid" },
    { 0xA665, "returnsuccessiftrue" },
    { 0xA666, "returntime" },
    { 0xA667, "returntrue" },
    { 0xA668, "returnzeroifundefined" },
    { 0xA669, "reunion" },
    { 0xA66A, "reunion_catchup" },
    { 0xA66B, "reunion_corpse" },
    { 0xA66C, "reunion_ladder_rumble" },
    { 0xA66D, "reunion_ladder_scene" },
    { 0xA66E, "reunion_ladder_scene_dof" },
    { 0xA66F, "reunion_ladder_scene_farah_finish" },
    { 0xA670, "reunion_ladder_scene_player_finish" },
    { 0xA671, "reunion_magic_shoot_enemy" },
    { 0xA672, "reunion_mayhem" },
    { 0xA673, "reunion_setup" },
    { 0xA674, "reunion_start" },
    { 0xA675, "reunion_waittill_player_left_stick_or_jump" },
    { 0xA676, "reveal_firing" },
    { 0xA677, "revealed" },
    { 0xA678, "revealminimapforteam" },
    { 0xA679, "revealrope" },
    { 0xA67A, "revenge" },
    { 0xA67B, "revengeparams" },
    { 0xA67C, "reverb_settings" },
    { 0xA67D, "reverse_breach_orders" },
    { 0xA67E, "reverse_breach_scene" },
    { 0xA67F, "reverse_impact_think" },
    { 0xA680, "reversed" },
    { 0xA681, "revert_to_stealth" },
    { 0xA682, "revive_chosenclass" },
    { 0xA683, "revive_damage_scalar" },
    { 0xA684, "revive_ent_usability_func" },
    { 0xA685, "revive_gesture" },
    { 0xA686, "revive_icon_color_management" },
    { 0xA687, "revive_icon_entities" },
    { 0xA688, "revive_icon_initial_alpha_func" },
    { 0xA689, "revive_icon_player_connect_monitor" },
    { 0xA68A, "revive_icons" },
    { 0xA68B, "revive_onuse" },
    { 0xA68C, "revive_player" },
    { 0xA68D, "revive_player_inside_c130" },
    { 0xA68E, "revive_progress_bar_id" },
    { 0xA68F, "revive_success_analytics_func" },
    { 0xA690, "revive_success_vo_func" },
    { 0xA691, "revive_time_scalar" },
    { 0xA692, "revive_use_hold_think" },
    { 0xA693, "revive_use_hold_vo_func" },
    { 0xA694, "revive_vip" },
    { 0xA695, "revive_watch_for_finished" },
    { 0xA696, "revivealphaiconfunc" },
    { 0xA697, "revivecameraent" },
    { 0xA698, "revivecamerapullin" },
    { 0xA699, "revivecount" },
    { 0xA69A, "revived_hud_update" },
    { 0xA69B, "revivedplayer" },
    { 0xA69C, "reviveent" },
    { 0xA69D, "revivefromspectatorweaponsetup" },
    { 0xA69E, "reviveiconcleanup" },
    { 0xA69F, "reviveiconent" },
    { 0xA6A0, "reviveiconentcleanup" },
    { 0xA6A1, "revivepos" },
    { 0xA6A2, "reviver" },
    { 0xA6A3, "revivesetup" },
    { 0xA6A4, "revivespawnvalidationcheck" },
    { 0xA6A5, "revivetimeoutthink" },
    { 0xA6A6, "revivetriggeravailable" },
    { 0xA6A7, "revivetriggerblockedinremote" },
    { 0xA6A8, "revivetriggerholdonuse" },
    { 0xA6A9, "revivetriggerholdonusebegin" },
    { 0xA6AA, "revivetriggerholdonuseend" },
    { 0xA6AB, "revivetriggeroncantuse" },
    { 0xA6AC, "revivetriggers" },
    { 0xA6AD, "revivetriggerspawned" },
    { 0xA6AE, "revivetriggerspawnposition" },
    { 0xA6AF, "revivetriggerspectateteamupdater" },
    { 0xA6B0, "revivetriggerteamupdater" },
    { 0xA6B1, "revivetriggerthink" },
    { 0xA6B2, "revocator_hint_displayed" },
    { 0xA6B3, "revocatorkills" },
    { 0xA6B4, "revocatorowner" },
    { 0xA6B5, "revocatorownercount" },
    { 0xA6B6, "revolver" },
    { 0xA6B7, "revolver_ads_hint" },
    { 0xA6B8, "revolvervodone" },
    { 0xA6B9, "reward" },
    { 0xA6BA, "reward_tier" },
    { 0xA6BB, "rewardicon" },
    { 0xA6BC, "rewardiconcleanup" },
    { 0xA6BD, "rewardlocation" },
    { 0xA6BE, "rewardobjectcleanup" },
    { 0xA6BF, "rewardobjectlock" },
    { 0xA6C0, "rewardobjectlockthink" },
    { 0xA6C1, "rewardobjectsetusable" },
    { 0xA6C2, "rewardobjectusewatch" },
    { 0xA6C3, "rewardspawn" },
    { 0xA6C4, "rewardteammateproximity" },
    { 0xA6C5, "rewardtier" },
    { 0xA6C6, "rewind_hint_displayed" },
    { 0xA6C7, "rewinding_path" },
    { 0xA6C8, "rex_emitter_test" },
    { 0xA6C9, "ricochet_bullet" },
    { 0xA6CA, "ricochetdamage" },
    { 0xA6CB, "ride_audiologic" },
    { 0xA6CC, "ride_cinematiccamerasettings" },
    { 0xA6CD, "ride_dof" },
    { 0xA6CE, "ride_end" },
    { 0xA6CF, "ride_farahmodellogic" },
    { 0xA6D0, "ride_gatesfxlogic" },
    { 0xA6D1, "ride_getanimatedallies" },
    { 0xA6D2, "ride_getgateanimations" },
    { 0xA6D3, "ride_getgatetypes" },
    { 0xA6D4, "ride_getvehicle" },
    { 0xA6D5, "ride_lighting" },
    { 0xA6D6, "ride_main" },
    { 0xA6D7, "ride_screenshakelogic" },
    { 0xA6D8, "ride_spawnanimatedalexally" },
    { 0xA6D9, "ride_spawnanimateddriverally" },
    { 0xA6DA, "ride_spawnanimatedgateallies" },
    { 0xA6DB, "ride_spawnvehicle" },
    { 0xA6DC, "ride_start" },
    { 0xA6DD, "rideloop" },
    { 0xA6DE, "rider" },
    { 0xA6DF, "rider_clean_up_monitor" },
    { 0xA6E0, "rider_death_func" },
    { 0xA6E1, "rider_death_monitor" },
    { 0xA6E2, "rider_func" },
    { 0xA6E3, "riders" },
    { 0xA6E4, "riders_unloadable" },
    { 0xA6E5, "ridersbackup" },
    { 0xA6E6, "ridge_tower" },
    { 0xA6E7, "ridge_tree_init" },
    { 0xA6E8, "ridge_tree_logic" },
    { 0xA6E9, "ridingvehicle" },
    { 0xA6EA, "rifle" },
    { 0xA6EB, "rig" },
    { 0xA6EC, "right_anim" },
    { 0xA6ED, "right_back_passenger" },
    { 0xA6EE, "right_bound" },
    { 0xA6EF, "right_corner_civs" },
    { 0xA6F0, "right_door" },
    { 0xA6F1, "right_door_marine_monitor" },
    { 0xA6F2, "right_ent" },
    { 0xA6F3, "right_flank_running" },
    { 0xA6F4, "right_guy" },
    { 0xA6F5, "right_kill_squad_dmg_func" },
    { 0xA6F6, "right_kill_squad_logic" },
    { 0xA6F7, "right_offset_from_tag_origin" },
    { 0xA6F8, "right_rpg_fov_checks" },
    { 0xA6F9, "right_side" },
    { 0xA6FA, "right_side_bomber_track" },
    { 0xA6FB, "right_side_cleanup" },
    { 0xA6FC, "right_side_combat" },
    { 0xA6FD, "right_side_draw_civs" },
    { 0xA6FE, "right_side_kill_squad_flags" },
    { 0xA6FF, "right_stick_movement" },
    { 0xA700, "right_street_autosave" },
    { 0xA701, "right_subway_bg_fake_civs" },
    { 0xA702, "right_underground_bomber_runner_logic" },
    { 0xA703, "right_vindia_infil_start_targetname_array" },
    { 0xA704, "right_vindia_infil_start_targetname_array_index" },
    { 0xA705, "rightarmdismembered" },
    { 0xA706, "rightback_anim" },
    { 0xA707, "rightchains" },
    { 0xA708, "rightclip" },
    { 0xA709, "rightdir" },
    { 0xA70A, "rightdistance" },
    { 0xA70B, "rightexitgate1" },
    { 0xA70C, "rightexitgate2" },
    { 0xA70D, "rightextents" },
    { 0xA70E, "rightplantang" },
    { 0xA70F, "rightplantorg" },
    { 0xA710, "rightpoint" },
    { 0xA711, "rightside" },
    { 0xA712, "rightwindow" },
    { 0xA713, "rightwingfxent" },
    { 0xA714, "rim_max_intensity" },
    { 0xA715, "riot_shield" },
    { 0xA716, "riot_shield_broken" },
    { 0xA717, "riot_shield_claymore" },
    { 0xA718, "riot_shield_damage" },
    { 0xA719, "riot_shield_damage_adjustment" },
    { 0xA71A, "riot_shield_flashbang_init" },
    { 0xA71B, "riotblock" },
    { 0xA71C, "riotshield_attach" },
    { 0xA71D, "riotshield_attach_parachute" },
    { 0xA71E, "riotshield_clear" },
    { 0xA71F, "riotshield_detach" },
    { 0xA720, "riotshield_detach_parachute" },
    { 0xA721, "riotshield_getmodel" },
    { 0xA722, "riotshield_getmodel_parachute" },
    { 0xA723, "riotshield_hastwo" },
    { 0xA724, "riotshield_hasweapon" },
    { 0xA725, "riotshield_hasweapon_parachute" },
    { 0xA726, "riotshield_lock_orientation" },
    { 0xA727, "riotshield_move" },
    { 0xA728, "riotshield_unlock_orientation" },
    { 0xA729, "riotshieldmod" },
    { 0xA72A, "riotshieldmodel" },
    { 0xA72B, "riotshieldmodelstowed" },
    { 0xA72C, "riotshieldname" },
    { 0xA72D, "riotshieldonweaponchange" },
    { 0xA72E, "riotshieldtype" },
    { 0xA72F, "riotshieldxpbullets" },
    { 0xA730, "river_enter_watcher" },
    { 0xA731, "rlinner" },
    { 0xA732, "rlinnercone" },
    { 0xA733, "rlouter" },
    { 0xA734, "rloutercone" },
    { 0xA735, "rloutter" },
    { 0xA736, "rlouttercone" },
    { 0xA737, "roaming" },
    { 0xA738, "robot_hint_displayed" },
    { 0xA739, "rock_used" },
    { 0xA73A, "rockable_car_add_player" },
    { 0xA73B, "rockable_car_debug" },
    { 0xA73C, "rockable_car_remove_player" },
    { 0xA73D, "rockable_car_rock" },
    { 0xA73E, "rockable_car_watch_damage" },
    { 0xA73F, "rockable_car_watch_dead" },
    { 0xA740, "rockable_car_watch_death" },
    { 0xA741, "rockable_cars_init" },
    { 0xA742, "rockable_cars_watch_players" },
    { 0xA743, "rockable_last_meansofdeath" },
    { 0xA744, "rockable_last_point" },
    { 0xA745, "rockablecars" },
    { 0xA746, "rockcounter" },
    { 0xA747, "rocket_arc" },
    { 0xA748, "rocket_cleanupondeath" },
    { 0xA749, "rocket_deletepristinetargets" },
    { 0xA74A, "rocket_ff_check" },
    { 0xA74B, "rocket_fire_cooldown" },
    { 0xA74C, "rocket_func" },
    { 0xA74D, "rocket_getdamagedtargets" },
    { 0xA74E, "rocket_getpristinetargets" },
    { 0xA74F, "rocket_hidedamagedtargets" },
    { 0xA750, "rocket_hint_shutdown" },
    { 0xA751, "rocket_hit_blur" },
    { 0xA752, "rocket_setnotsolidtargets" },
    { 0xA753, "rocket_showdamagedtargets" },
    { 0xA754, "rocket_tag" },
    { 0xA755, "rocketeer_count" },
    { 0xA756, "rockets" },
    { 0xA757, "rockets_ready" },
    { 0xA758, "rockets_target" },
    { 0xA759, "rockpaperscissors" },
    { 0xA75A, "rockpaperscissorschoice" },
    { 0xA75B, "rocks" },
    { 0xA75C, "rockstrings" },
    { 0xA75D, "rocktimes" },
    { 0xA75E, "rockused" },
    { 0xA75F, "rodeo" },
    { 0xA760, "rodeorequest" },
    { 0xA761, "rodeorequested" },
    { 0xA762, "rofweaponslist" },
    { 0xA763, "role" },
    { 0xA764, "roll" },
    { 0xA765, "rollingdeath" },
    { 0xA766, "rollnewcamerapath" },
    { 0xA767, "rollsequencepercamera" },
    { 0xA768, "roof" },
    { 0xA769, "roof_b_corner_wall_init" },
    { 0xA76A, "roof_b_wall" },
    { 0xA76B, "roof_b_wall_02_init" },
    { 0xA76C, "roof_b_wall_init" },
    { 0xA76D, "roof_catchup" },
    { 0xA76E, "roof_collapse_init" },
    { 0xA76F, "roof_combat_start" },
    { 0xA770, "roof_door" },
    { 0xA771, "roof_enemy_watcher" },
    { 0xA772, "roof_getfarahclip" },
    { 0xA773, "roof_gethadirclip" },
    { 0xA774, "roof_heli_crash_explosion_light_01" },
    { 0xA775, "roof_heli_explosion_crash_light_flicker" },
    { 0xA776, "roof_heli_explosion_light" },
    { 0xA777, "roof_heli_explosion_vision" },
    { 0xA778, "roof_jugg_logic" },
    { 0xA779, "roof_jugg_run_once_doors_open" },
    { 0xA77A, "roof_jugg_spawn_func" },
    { 0xA77B, "roof_jugg_wake_logic" },
    { 0xA77C, "roof_main" },
    { 0xA77D, "roof_objective_struct" },
    { 0xA77E, "roof_scenealogic" },
    { 0xA77F, "roof_sceneanaglogic" },
    { 0xA780, "roof_sceneblogic" },
    { 0xA781, "roof_sceneclogic" },
    { 0xA782, "roof_scenefarahanimationlogic" },
    { 0xA783, "roof_scenefarahspotlogic" },
    { 0xA784, "roof_scenesniperlogic" },
    { 0xA785, "roof_setuptutorialallies" },
    { 0xA786, "roof_sniperpickupplayerdisablelogic" },
    { 0xA787, "roof_spawnsniperweapon" },
    { 0xA788, "roof_start" },
    { 0xA789, "roof_to_stairs_vo" },
    { 0xA78A, "roof_tops_cover_direction" },
    { 0xA78B, "roof_wreckage" },
    { 0xA78C, "rooftop_1_mortar" },
    { 0xA78D, "rooftop_2_mortar" },
    { 0xA78E, "rooftop_3_mortar" },
    { 0xA78F, "rooftop_actors" },
    { 0xA790, "rooftop_antennae" },
    { 0xA791, "rooftop_antennae_think" },
    { 0xA792, "rooftop_attackers" },
    { 0xA793, "rooftop_director_03" },
    { 0xA794, "rooftop_directoring" },
    { 0xA795, "rooftop_enter_watcher" },
    { 0xA796, "rooftop_hack_paused" },
    { 0xA797, "rooftop_obj_func" },
    { 0xA798, "rooftop_touch_trigger" },
    { 0xA799, "rooftop_triggers" },
    { 0xA79A, "rooftop_usb_drives" },
    { 0xA79B, "rooftop1_sat" },
    { 0xA79C, "rooftop2_sat" },
    { 0xA79D, "rooftop3_sat" },
    { 0xA79E, "rooftopid" },
    { 0xA79F, "rooftops_catchup" },
    { 0xA7A0, "rooftops_main" },
    { 0xA7A1, "rooftops_start" },
    { 0xA7A2, "room" },
    { 0xA7A3, "room_beating_patrol_bp" },
    { 0xA7A4, "room_enter_chair_anim" },
    { 0xA7A5, "room_enter_enforcer" },
    { 0xA7A6, "room_enter_price" },
    { 0xA7A7, "room_enter_threads" },
    { 0xA7A8, "room_enter_yegor" },
    { 0xA7A9, "room_struct" },
    { 0xA7AA, "root" },
    { 0xA7AB, "root_ecounterstart" },
    { 0xA7AC, "root_failconditions" },
    { 0xA7AD, "root_getspawneraitype" },
    { 0xA7AE, "root_inittargets" },
    { 0xA7AF, "root_monitorplayers" },
    { 0xA7B0, "rootai_ecounterstart" },
    { 0xA7B1, "rootnonai_ecounterstart" },
    { 0xA7B2, "rootsofcubic" },
    { 0xA7B3, "rootsofquadratic" },
    { 0xA7B4, "rope" },
    { 0xA7B5, "ropethink" },
    { 0xA7B6, "rotate_ent_think" },
    { 0xA7B7, "rotate_over_time" },
    { 0xA7B8, "rotate_plane" },
    { 0xA7B9, "rotate_plane_randomly" },
    { 0xA7BA, "rotate_tags" },
    { 0xA7BB, "rotate90aroundaxis" },
    { 0xA7BC, "rotateplane" },
    { 0xA7BD, "rotatetofinalangles" },
    { 0xA7BE, "rotateuavrig" },
    { 0xA7BF, "rotation_is_occuring" },
    { 0xA7C0, "rotation_max" },
    { 0xA7C1, "rotation_speed" },
    { 0xA7C2, "rotation_spring_index" },
    { 0xA7C3, "rotationidmap" },
    { 0xA7C4, "round_end_music" },
    { 0xA7C5, "round_float" },
    { 0xA7C6, "round_millisec_on_sec" },
    { 0xA7C7, "round_server_time" },
    { 0xA7C8, "round_up_to_nearest" },
    { 0xA7C9, "round_up_to_nearest_twentieth" },
    { 0xA7CA, "roundbegin" },
    { 0xA7CB, "roundbreaktest" },
    { 0xA7CC, "rounddecimalplaces" },
    { 0xA7CD, "roundend" },
    { 0xA7CE, "roundend_checkscorelimit" },
    { 0xA7CF, "roundenddelay" },
    { 0xA7D0, "roundenddof" },
    { 0xA7D1, "roundendextramessage" },
    { 0xA7D2, "roundendwait" },
    { 0xA7D3, "roundlimit" },
    { 0xA7D4, "roundretainstreakprog" },
    { 0xA7D5, "roundretainstreaks" },
    { 0xA7D6, "roundrobinlimit" },
    { 0xA7D7, "rounds" },
    { 0xA7D8, "roundscorelimit" },
    { 0xA7D9, "roundswitch" },
    { 0xA7DA, "roundswitchdvar" },
    { 0xA7DB, "roundswitchmax" },
    { 0xA7DC, "roundswitchmin" },
    { 0xA7DD, "roundup" },
    { 0xA7DE, "roundwinnerdialog" },
    { 0xA7DF, "route_points" },
    { 0xA7E0, "route_soldiers_towards_backup_location" },
    { 0xA7E1, "route_spawned_soldiers_to_new_vehicle" },
    { 0xA7E2, "route_to_any_veh" },
    { 0xA7E3, "route_to_other_support_veh" },
    { 0xA7E4, "route_to_other_veh" },
    { 0xA7E5, "route_towards_exit" },
    { 0xA7E6, "router" },
    { 0xA7E7, "row_index" },
    { 0xA7E8, "rpg_ai" },
    { 0xA7E9, "rpg_callout" },
    { 0xA7EA, "rpg_chatter" },
    { 0xA7EB, "rpg_enemy_mover_clean_up" },
    { 0xA7EC, "rpg_enemy_think" },
    { 0xA7ED, "rpg_fire_pos" },
    { 0xA7EE, "rpg_get_shoot_pos" },
    { 0xA7EF, "rpg_get_shoot_start_pos" },
    { 0xA7F0, "rpg_guy" },
    { 0xA7F1, "rpg_guy_can_shoot" },
    { 0xA7F2, "rpg_guy_damage_func" },
    { 0xA7F3, "rpg_guy_death_func" },
    { 0xA7F4, "rpg_guy_face_target" },
    { 0xA7F5, "rpg_guy_force_kill" },
    { 0xA7F6, "rpg_guy_logic" },
    { 0xA7F7, "rpg_guy_proximity" },
    { 0xA7F8, "rpg_guy_retreat" },
    { 0xA7F9, "rpg_guy_scripted" },
    { 0xA7FA, "rpg_guy_shoot" },
    { 0xA7FB, "rpg_guy_wave_1" },
    { 0xA7FC, "rpg_guys_attack_start" },
    { 0xA7FD, "rpg_guys_fire" },
    { 0xA7FE, "rpg_impact" },
    { 0xA7FF, "rpg_impact_source" },
    { 0xA800, "rpg_interaction" },
    { 0xA801, "rpg_kill_handler" },
    { 0xA802, "rpg_left_allies" },
    { 0xA803, "rpg_left_fov_checks" },
    { 0xA804, "rpg_left_spawn" },
    { 0xA805, "rpg_notify" },
    { 0xA806, "rpg_on_back" },
    { 0xA807, "rpg_on_rebels" },
    { 0xA808, "rpg_picked_up" },
    { 0xA809, "rpg_playerrepulsor" },
    { 0xA80A, "rpg_respawning" },
    { 0xA80B, "rpg_right_allies" },
    { 0xA80C, "rpg_right_allies_post" },
    { 0xA80D, "rpg_right_spawn" },
    { 0xA80E, "rpg_skit_after_spawn" },
    { 0xA80F, "rpg7caches" },
    { 0xA810, "rpgambusherskilled" },
    { 0xA811, "rpgcrateenduse" },
    { 0xA812, "rpgcrateuseteamupdater" },
    { 0xA813, "rpgplayerrepulsor" },
    { 0xA814, "rpgplayerrepulsor_create" },
    { 0xA815, "rpgplayerrepulsor_getnummisses" },
    { 0xA816, "ru_1_shot_at" },
    { 0xA817, "ru_2_shot_at" },
    { 0xA818, "rubble_crumble" },
    { 0xA819, "rubble_hint" },
    { 0xA81A, "rugby" },
    { 0xA81B, "rugbyjugginfo" },
    { 0xA81C, "rugbyoverheadoutlines" },
    { 0xA81D, "rule_type" },
    { 0xA81E, "rules" },
    { 0xA81F, "rumb" },
    { 0xA820, "rumbforclient" },
    { 0xA821, "rumble" },
    { 0xA822, "rumble_basetime" },
    { 0xA823, "rumble_duration" },
    { 0xA824, "rumble_for_client" },
    { 0xA825, "rumble_low" },
    { 0xA826, "rumble_nearby_players" },
    { 0xA827, "rumble_on_breach" },
    { 0xA828, "rumble_on_death" },
    { 0xA829, "rumble_radius" },
    { 0xA82A, "rumble_ramp_off" },
    { 0xA82B, "rumble_ramp_on" },
    { 0xA82C, "rumble_ramp_to" },
    { 0xA82D, "rumble_randomaditionaltime" },
    { 0xA82E, "rumble_scale" },
    { 0xA82F, "rumbleent" },
    { 0xA830, "rumbleon" },
    { 0xA831, "rumbletrigger" },
    { 0xA832, "run_accuracy" },
    { 0xA833, "run_adrenaline_visuals" },
    { 0xA834, "run_ai_anim" },
    { 0xA835, "run_ai_anim_nonarc" },
    { 0xA836, "run_ai_post_spawn_actions" },
    { 0xA837, "run_ai_post_spawn_init" },
    { 0xA838, "run_aievent_func" },
    { 0xA839, "run_airdrop_spawn_loop" },
    { 0xA83A, "run_aitype_spawn_func" },
    { 0xA83B, "run_and_die" },
    { 0xA83C, "run_anim_alias" },
    { 0xA83D, "run_anim_override" },
    { 0xA83E, "run_animatedenemiesdamagelogic" },
    { 0xA83F, "run_animatedstretcherguardsalertedlogic" },
    { 0xA840, "run_ball" },
    { 0xA841, "run_blended_interaction" },
    { 0xA842, "run_call_after_wait_array" },
    { 0xA843, "run_combat_func" },
    { 0xA844, "run_common_functions" },
    { 0xA845, "run_convoy_roaming" },
    { 0xA846, "run_cp_blockade_start_spawning" },
    { 0xA847, "run_cp_donetsk_start_spawning" },
    { 0xA848, "run_deadeye_charge_watcher" },
    { 0xA849, "run_dialogue" },
    { 0xA84A, "run_dialoguelogic" },
    { 0xA84B, "run_door_spawn_end_funcs" },
    { 0xA84C, "run_enemylogic" },
    { 0xA84D, "run_example_interactable" },
    { 0xA84E, "run_farahpathlogic" },
    { 0xA84F, "run_func_after_wait_array" },
    { 0xA850, "run_func_on_group_by_groupname" },
    { 0xA851, "run_getanimatedenemies" },
    { 0xA852, "run_getanimatedstretcher" },
    { 0xA853, "run_getanimationstruct" },
    { 0xA854, "run_getenemyvehicle" },
    { 0xA855, "run_getfarahanimationstruct" },
    { 0xA856, "run_getvehiclespawner" },
    { 0xA857, "run_group_death_funcs" },
    { 0xA858, "run_helicopter_boss" },
    { 0xA859, "run_main" },
    { 0xA85A, "run_mission" },
    { 0xA85B, "run_modular_spawning_func" },
    { 0xA85C, "run_module_init_funcs_on_module_struct" },
    { 0xA85D, "run_n_gun" },
    { 0xA85E, "run_noself_call_after_wait_array" },
    { 0xA85F, "run_objective" },
    { 0xA860, "run_open_door_anim" },
    { 0xA861, "run_override_weights" },
    { 0xA862, "run_overrideanim" },
    { 0xA863, "run_path_node_removal" },
    { 0xA864, "run_rate_max" },
    { 0xA865, "run_rate_min" },
    { 0xA866, "run_rearguard" },
    { 0xA867, "run_reminders" },
    { 0xA868, "run_repeating_event" },
    { 0xA869, "run_script_func_when_triggered" },
    { 0xA86A, "run_scripted_anim" },
    { 0xA86B, "run_scripted_state_machine" },
    { 0xA86C, "run_scripted_state_machine_nonarc" },
    { 0xA86D, "run_single_grid_point_test" },
    { 0xA86E, "run_spawn_functions" },
    { 0xA86F, "run_spawn_module" },
    { 0xA870, "run_spawnanimatedenemies" },
    { 0xA871, "run_spawnenemies" },
    { 0xA872, "run_spawnenemieslogic" },
    { 0xA873, "run_spawner_post_spawn_actions" },
    { 0xA874, "run_spawnvehicle" },
    { 0xA875, "run_speed" },
    { 0xA876, "run_start" },
    { 0xA877, "run_super_loop" },
    { 0xA878, "run_thread_on_noteworthy" },
    { 0xA879, "run_thread_on_targetname" },
    { 0xA87A, "run_through_timestamps" },
    { 0xA87B, "run_timely_torrent" },
    { 0xA87C, "run_to_and_launch_flare" },
    { 0xA87D, "run_to_and_plant_bomb" },
    { 0xA87E, "run_to_and_set_alarm" },
    { 0xA87F, "run_to_bomb_location" },
    { 0xA880, "run_to_launcher" },
    { 0xA881, "run_to_new_spot_and_setup_gun" },
    { 0xA882, "run_to_position" },
    { 0xA883, "run_trigger_func" },
    { 0xA884, "run_triggered_module_registration" },
    { 0xA885, "run_vehiclelogic" },
    { 0xA886, "run_vehiclesfxlogic" },
    { 0xA887, "run_weapons_free_funcs" },
    { 0xA888, "runadsawareness" },
    { 0xA889, "runanim" },
    { 0xA88A, "runaonrules" },
    { 0xA88B, "runarenaloadoutrulesonplayer" },
    { 0xA88C, "runbtmflags" },
    { 0xA88D, "runby_manager" },
    { 0xA88E, "runcamoscripts" },
    { 0xA88F, "runcooldown" },
    { 0xA890, "runcruisepredator" },
    { 0xA891, "runcurrentspawngroup" },
    { 0xA892, "rundebugstartobjective" },
    { 0xA893, "rundebugvfxcircletest" },
    { 0xA894, "rundelay" },
    { 0xA895, "rundisconnectcallbacks" },
    { 0xA896, "rundronehive" },
    { 0xA897, "runequipmentping" },
    { 0xA898, "runexfil" },
    { 0xA899, "runexfilnotactivefill" },
    { 0xA89A, "runexfilwaitactiveunfill" },
    { 0xA89B, "runflickerroutine" },
    { 0xA89C, "runfrontlinespawntrapchecks" },
    { 0xA89D, "runheadgear" },
    { 0xA89E, "runheadgeareffects" },
    { 0xA89F, "runhover" },
    { 0xA8A0, "runjiprules" },
    { 0xA8A1, "runkillstreakreward" },
    { 0xA8A2, "runlauncherlogic" },
    { 0xA8A3, "runleanthreadmode" },
    { 0xA8A4, "runlightswitch" },
    { 0xA8A5, "runmainobjective" },
    { 0xA8A6, "runmissionrewarddelivery" },
    { 0xA8A7, "runmisteffects" },
    { 0xA8A8, "runmomentum" },
    { 0xA8A9, "runmprangefinder" },
    { 0xA8AA, "runner" },
    { 0xA8AB, "runner_1f" },
    { 0xA8AC, "runner_flashbang_watcher" },
    { 0xA8AD, "runner_got_away" },
    { 0xA8AE, "runner_temp_death" },
    { 0xA8AF, "runner1_behavior" },
    { 0xA8B0, "runner2_behavior" },
    { 0xA8B1, "runner2_deathfunc" },
    { 0xA8B2, "runnextmode" },
    { 0xA8B3, "runngun_watchapproach" },
    { 0xA8B4, "runngundisableaim" },
    { 0xA8B5, "running" },
    { 0xA8B6, "running_away_watcher" },
    { 0xA8B7, "running_trip_stance" },
    { 0xA8B8, "runningtovehicle" },
    { 0xA8B9, "runnormaldomflags" },
    { 0xA8BA, "runnvg" },
    { 0xA8BB, "runobjectivecam" },
    { 0xA8BC, "runobjectiveloop" },
    { 0xA8BD, "runobjectives" },
    { 0xA8BE, "runobjflag" },
    { 0xA8BF, "runprematch" },
    { 0xA8C0, "runqueuedtaunts" },
    { 0xA8C1, "runscoperadarinloop" },
    { 0xA8C2, "runsecondaryobjectives" },
    { 0xA8C3, "runslamzoomonspawn" },
    { 0xA8C4, "runspawnmodule" },
    { 0xA8C5, "runtacopsmap" },
    { 0xA8C6, "runtacopsshowteamicons" },
    { 0xA8C7, "runtovehicleoverride" },
    { 0xA8C8, "runtrackempsignatures" },
    { 0xA8C9, "runtrackkillstreakuse" },
    { 0xA8CA, "runtvdestructible" },
    { 0xA8CB, "runupdates" },
    { 0xA8CC, "runway_convoys" },
    { 0xA8CD, "runweaponscriptvfx" },
    { 0xA8CE, "runzonethink" },
    { 0xA8CF, "rus_overlook_patrol_spawnfunc" },
    { 0xA8D0, "rush_dudes_think" },
    { 0xA8D1, "rushing_player" },
    { 0xA8D2, "rushtimer" },
    { 0xA8D3, "rushtimeramount" },
    { 0xA8D4, "rushtimerteam" },
    { 0xA8D5, "russian_carhide_convo" },
    { 0xA8D6, "russian_found_revolver" },
    { 0xA8D7, "russian_gas_blocker_array" },
    { 0xA8D8, "russian_gas_briefing_straggler_ai" },
    { 0xA8D9, "russian_gas_patrol_array" },
    { 0xA8DA, "russian_patroller_investigate" },
    { 0xA8DB, "russian_patroller_spawn_func" },
    { 0xA8DC, "russian_patroller_spawn_func_no_flashlight" },
    { 0xA8DD, "russian_patroller_spawn_func_no_flashlight_ignore" },
    { 0xA8DE, "russian_patroller_stealth_filter" },
    { 0xA8DF, "russian_shooter_1_ai" },
    { 0xA8E0, "russian_shooter_2_ai" },
    { 0xA8E1, "russian_shooter_3_ai" },
    { 0xA8E2, "russian_shooter_4_ai" },
    { 0xA8E3, "russian_vo" },
    { 0xA8E4, "russians_enemyinfinitespawninglogic" },
    { 0xA8E5, "russians_getenemygoalcount" },
    { 0xA8E6, "russians_getenemyinfinitespawners" },
    { 0xA8E7, "russians_infiniteenemylogic" },
    { 0xA8E8, "russians_main" },
    { 0xA8E9, "russians_playerinfiniteenemiessurvivaltimelogic" },
    { 0xA8EA, "russians_playerkillcounterlogic" },
    { 0xA8EB, "russians_playerkillcounterworthy" },
    { 0xA8EC, "russians_setenemygoalcount" },
    { 0xA8ED, "russians_start" },
    { 0xA8EE, "russiansenemygoalcount" },
    { 0xA8EF, "s" },
    { 0xA8F0, "saboteurgotocache" },
    { 0xA8F1, "saboteurlogic" },
    { 0xA8F2, "safe_delete_distance" },
    { 0xA8F3, "safe_to_shoot_missiles" },
    { 0xA8F4, "safe_to_start_objective" },
    { 0xA8F5, "safe_trigger" },
    { 0xA8F6, "safe_zoom_end_think" },
    { 0xA8F7, "safe_zoom_in_listen" },
    { 0xA8F8, "safe_zoom_out_listen" },
    { 0xA8F9, "safe_zoom_think" },
    { 0xA8FA, "safebreathrange" },
    { 0xA8FB, "safecircleent" },
    { 0xA8FC, "safecircleui" },
    { 0xA8FD, "safedefaultfov" },
    { 0xA8FE, "safedelete" },
    { 0xA8FF, "safehouse_debug_func" },
    { 0xA900, "safehouse_edit_loadout" },
    { 0xA901, "safehouse_gunshop_edit_loadout" },
    { 0xA902, "safehouse_interior_catchup" },
    { 0xA903, "safehouse_interior_main" },
    { 0xA904, "safehouse_interior_mix" },
    { 0xA905, "safehouse_interior_start" },
    { 0xA906, "safehouse_loadout_interaction" },
    { 0xA907, "safehouse_obj_func" },
    { 0xA908, "safehouse_outside_runners" },
    { 0xA909, "safehouse_outside_runners_behavior" },
    { 0xA90A, "safehouse_s11_obj_func" },
    { 0xA90B, "safehouse_yasim" },
    { 0xA90C, "safelyplayanimatrateuntilnotetrack" },
    { 0xA90D, "safelyplayanimnatrateuntilnotetrack" },
    { 0xA90E, "safelyplayanimnuntilnotetrack" },
    { 0xA90F, "safelyplayanimuntilnotetrack" },
    { 0xA910, "safemod" },
    { 0xA911, "safeorigin" },
    { 0xA912, "saferoom" },
    { 0xA913, "saferoom_catchup" },
    { 0xA914, "saferoom_door" },
    { 0xA915, "saferoom_door_delay_notify_for_keypad" },
    { 0xA916, "saferoom_escape_screens" },
    { 0xA917, "saferoom_fill_light" },
    { 0xA918, "saferoom_kyle_fill_light" },
    { 0xA919, "saferoom_kyle_rim_light" },
    { 0xA91A, "saferoom_last_nag_time" },
    { 0xA91B, "saferoom_last_nagger" },
    { 0xA91C, "saferoom_main" },
    { 0xA91D, "saferoom_player_aware_of_teleport" },
    { 0xA91E, "saferoom_player_uses_buzzer" },
    { 0xA91F, "saferoom_price" },
    { 0xA920, "saferoom_price_behind_catchup" },
    { 0xA921, "saferoom_price_reach_or_skip" },
    { 0xA922, "saferoom_rim_light" },
    { 0xA923, "saferoom_scene_then_idle" },
    { 0xA924, "saferoom_screens" },
    { 0xA925, "saferoom_setup_doors_and_ap" },
    { 0xA926, "saferoom_setup_mic" },
    { 0xA927, "saferoom_start" },
    { 0xA928, "saferoom_teleport_price" },
    { 0xA929, "safestop" },
    { 0xA92A, "said_around_corner_hallway" },
    { 0xA92B, "said_body" },
    { 0xA92C, "said_bravo3_vo" },
    { 0xA92D, "said_cart" },
    { 0xA92E, "said_cont_hallway" },
    { 0xA92F, "said_hallway_corner" },
    { 0xA930, "said_pillar" },
    { 0xA931, "said_shelf" },
    { 0xA932, "saidtoorecently" },
    { 0xA933, "salter" },
    { 0xA934, "sam_acquiretarget" },
    { 0xA935, "sam_attacktargets" },
    { 0xA936, "sam_fireontarget" },
    { 0xA937, "sam_watchcrashing" },
    { 0xA938, "sam_watchlaser" },
    { 0xA939, "sam_watchleaving" },
    { 0xA93A, "sam_watchlineofsight" },
    { 0xA93B, "samdamagescale" },
    { 0xA93C, "same_color_code_as_last_time" },
    { 0xA93D, "sammissilegroup" },
    { 0xA93E, "sammissilegroups" },
    { 0xA93F, "samtargetent" },
    { 0xA940, "samturret" },
    { 0xA941, "sandboxobjectivesa" },
    { 0xA942, "sandboxrewarda" },
    { 0xA943, "sas" },
    { 0xA944, "sas_hero_sun" },
    { 0xA945, "sas_spawn_func" },
    { 0xA946, "sas1" },
    { 0xA947, "sas2" },
    { 0xA948, "sat_computer_init" },
    { 0xA949, "sat_computer_think" },
    { 0xA94A, "sat_connected" },
    { 0xA94B, "sat_damage_monitor" },
    { 0xA94C, "sat_setup" },
    { 0xA94D, "sat_setup_usb_keys" },
    { 0xA94E, "sat_setup_usb_pickup" },
    { 0xA94F, "sat_wait_for_all_connected" },
    { 0xA950, "sat_wait_for_connect" },
    { 0xA951, "satellitecount" },
    { 0xA952, "satelliteiconid" },
    { 0xA953, "satellitekeyboard" },
    { 0xA954, "satellitetruckactivetimeseconds" },
    { 0xA955, "satellitetruckplundercost" },
    { 0xA956, "sats_active" },
    { 0xA957, "sats_connected" },
    { 0xA958, "save" },
    { 0xA959, "save_after_rockets" },
    { 0xA95A, "save_at_mh_building" },
    { 0xA95B, "save_building_autosave" },
    { 0xA95C, "save_game_after_battlefield" },
    { 0xA95D, "save_intel_for_all_players" },
    { 0xA95E, "save_last_goal" },
    { 0xA95F, "save_on_return_to_compound" },
    { 0xA960, "save_outline_settings" },
    { 0xA961, "save_trace_data" },
    { 0xA962, "save_turret_sharing_info" },
    { 0xA963, "saveaarawards" },
    { 0xA964, "saveaarawardsonroundswitch" },
    { 0xA965, "savealtstates" },
    { 0xA966, "savecommit_aftergrenade" },
    { 0xA967, "saved_actionslotdata" },
    { 0xA968, "saved_last_stand_pistol" },
    { 0xA969, "saved_lastweapon" },
    { 0xA96A, "saved_lastweaponhack" },
    { 0xA96B, "saved_script_forcegoal" },
    { 0xA96C, "saved_struct_paths" },
    { 0xA96D, "savedaarawards" },
    { 0xA96E, "saveddoorspeed" },
    { 0xA96F, "savedintensity" },
    { 0xA970, "savedmorales" },
    { 0xA971, "savedsegmentposition" },
    { 0xA972, "savegraverobberammo" },
    { 0xA973, "savenvgstate" },
    { 0xA974, "savetogglescopestates" },
    { 0xA975, "savetostructfn" },
    { 0xA976, "saw_armory" },
    { 0xA977, "saw_mgturretlink" },
    { 0xA978, "say" },
    { 0xA979, "say_array" },
    { 0xA97A, "say_as_chatter" },
    { 0xA97B, "say_as_chatter_with_gesture" },
    { 0xA97C, "say_choke_stab_vo_01" },
    { 0xA97D, "say_choke_stab_vo_02" },
    { 0xA97E, "say_choke_stab_vo_03" },
    { 0xA97F, "say_if_good_distance" },
    { 0xA980, "say_line_as_chatter_on_closest_ally" },
    { 0xA981, "say_line_on_closest_ally" },
    { 0xA982, "say_line_on_enemy_radio" },
    { 0xA983, "say_offhand_nag" },
    { 0xA984, "say_on_closest_enemy" },
    { 0xA985, "say_on_enemy_radio" },
    { 0xA986, "say_on_kill_ai_type" },
    { 0xA987, "say_on_see_butcher" },
    { 0xA988, "say_sequence" },
    { 0xA989, "say_sequence_as_chatter" },
    { 0xA98A, "say_vo_item" },
    { 0xA98B, "say_weapon_pickup_line" },
    { 0xA98C, "say_wolf_line" },
    { 0xA98D, "saygenericdialogue" },
    { 0xA98E, "saylocalsound" },
    { 0xA98F, "sayspecificdialogue" },
    { 0xA990, "saytoself" },
    { 0xA991, "scaffolding_choice" },
    { 0xA992, "scaffolding_combat" },
    { 0xA993, "scaffolding_mayhem" },
    { 0xA994, "scaffolding_rocket_watcher" },
    { 0xA995, "scalar_projection" },
    { 0xA996, "scale" },
    { 0xA997, "scale_alien_damage_by_perks" },
    { 0xA998, "scale_alien_damage_by_prestige" },
    { 0xA999, "scale_alien_damage_by_weapon_type" },
    { 0xA99A, "scale_anim_on_player_speed" },
    { 0xA99B, "scale_gravity" },
    { 0xA99C, "scale_player_death_shield_duration" },
    { 0xA99D, "scale_speed" },
    { 0xA99E, "scale_youngfarrah_firetime" },
    { 0xA99F, "scalebattlechatterfrequency" },
    { 0xA9A0, "scaled_duration" },
    { 0xA9A1, "scaledsaytime" },
    { 0xA9A2, "scanning_camera_anchor" },
    { 0xA9A3, "scanning_mode_get_target_in_circle_omnvar_value" },
    { 0xA9A4, "scared_civs_cower" },
    { 0xA9A5, "scared_civs_notice_player" },
    { 0xA9A6, "scared_civs_player_looking" },
    { 0xA9A7, "scared_civs_trigger_grenade" },
    { 0xA9A8, "scav_hudenabled" },
    { 0xA9A9, "scav_itemcount_hud" },
    { 0xA9AA, "scavengebagthink" },
    { 0xA9AB, "scavengebagusemonitoring" },
    { 0xA9AC, "scavengeditems" },
    { 0xA9AD, "scavenger_altmode" },
    { 0xA9AE, "scavenger_budget_delete" },
    { 0xA9AF, "scavenger_secondary" },
    { 0xA9B0, "scavengerammo" },
    { 0xA9B1, "scavengerbagcleanupthink" },
    { 0xA9B2, "scavengerbagtimeoutthink" },
    { 0xA9B3, "scavengerbagusesetup" },
    { 0xA9B4, "scavengergiveammo" },
    { 0xA9B5, "scene" },
    { 0xA9B6, "scene_alex_flare_support_breakout" },
    { 0xA9B7, "scene_ally_drag" },
    { 0xA9B8, "scene_bookcase" },
    { 0xA9B9, "scene_flare_react" },
    { 0xA9BA, "scene_flare_react_break_out" },
    { 0xA9BB, "scene_gate_farah" },
    { 0xA9BC, "scene_glass_killer" },
    { 0xA9BD, "scene_intro" },
    { 0xA9BE, "scene_intro_return" },
    { 0xA9BF, "scene_intro_to_ai" },
    { 0xA9C0, "scene_intro_to_roof_to_idle" },
    { 0xA9C1, "scene_intro_to_rooftops" },
    { 0xA9C2, "scene_kill_target" },
    { 0xA9C3, "scene_mayhem" },
    { 0xA9C4, "scene_mortars" },
    { 0xA9C5, "scene_mortars_ai_to_anim" },
    { 0xA9C6, "scene_node" },
    { 0xA9C7, "scene_opening" },
    { 0xA9C8, "scene_pep_talk" },
    { 0xA9C9, "scene_room_beating" },
    { 0xA9CA, "scene_sequential_sounter" },
    { 0xA9CB, "scene_sniper_roof" },
    { 0xA9CC, "scene_table_beating" },
    { 0xA9CD, "scene_triage" },
    { 0xA9CE, "scene_triage_to_exit" },
    { 0xA9CF, "scene_triage_to_idle" },
    { 0xA9D0, "scene_truck_gate" },
    { 0xA9D1, "scene_trucks_drive_in" },
    { 0xA9D2, "scene_wall_kill" },
    { 0xA9D3, "scene_wounded" },
    { 0xA9D4, "sceneid" },
    { 0xA9D5, "scenenode" },
    { 0xA9D6, "scenenodekey" },
    { 0xA9D7, "scenenodeoffset" },
    { 0xA9D8, "scenenodes" },
    { 0xA9D9, "sciprt_mover_use_object_wait_for_disconnect" },
    { 0xA9DA, "scomboname" },
    { 0xA9DB, "scope_swap_hint_check" },
    { 0xA9DC, "scopemodel" },
    { 0xA9DD, "scoperadar_executeping" },
    { 0xA9DE, "scoperadar_executevisuals" },
    { 0xA9DF, "score_added" },
    { 0xA9E0, "score_ai_spawns" },
    { 0xA9E1, "score_calculate" },
    { 0xA9E2, "score_earned" },
    { 0xA9E3, "score_event_collateral" },
    { 0xA9E4, "score_event_target_hit" },
    { 0xA9E5, "score_event_time_remaining" },
    { 0xA9E6, "score_factor_ai" },
    { 0xA9E7, "score_fx" },
    { 0xA9E8, "score_initialized_once" },
    { 0xA9E9, "score_valid_spawnpoints" },
    { 0xA9EA, "scoreamount" },
    { 0xA9EB, "scorebuddyspawn" },
    { 0xA9EC, "scorecarry" },
    { 0xA9ED, "scoreconfirm" },
    { 0xA9EE, "scoredeny" },
    { 0xA9EF, "scoreeventalwaysshowassplash" },
    { 0xA9F0, "scoreeventcount" },
    { 0xA9F1, "scoreeventhastext" },
    { 0xA9F2, "scoreeventlistindex" },
    { 0xA9F3, "scoreeventlistsize" },
    { 0xA9F4, "scoreeventpopup" },
    { 0xA9F5, "scoreeventqueue" },
    { 0xA9F6, "scoreeventref" },
    { 0xA9F7, "scorefrozentimer" },
    { 0xA9F8, "scorefrozenuntil" },
    { 0xA9F9, "scorehostage" },
    { 0xA9FA, "scoreinfo" },
    { 0xA9FB, "scorelimit" },
    { 0xA9FC, "scorelimitoverride" },
    { 0xA9FD, "scoreminimum" },
    { 0xA9FE, "scoremod" },
    { 0xA9FF, "scoreontargetplayer" },
    { 0xAA00, "scorepercentagecutoff" },
    { 0xAA01, "scoreperplayer" },
    { 0xAA02, "scorepertick" },
    { 0xAA03, "scorepointspopup" },
    { 0xAA04, "scorepointsqueue" },
    { 0xAA05, "scorepop" },
    { 0xAA06, "scorepopup" },
    { 0xAA07, "scorespawnpoint" },
    { 0xAA08, "scorestreakvariantattackerinfo" },
    { 0xAA09, "scorethrow" },
    { 0xAA0A, "scoretick" },
    { 0xAA0B, "scoreupdatetotal" },
    { 0xAA0C, "scoringtime" },
    { 0xAA0D, "scout_drone_clean_up" },
    { 0xAA0E, "scout_drone_clean_up_func" },
    { 0xAA0F, "scout_drone_mark_npcs" },
    { 0xAA10, "scout_drone_markvehicles" },
    { 0xAA11, "scouting_main" },
    { 0xAA12, "scouting_start" },
    { 0xAA13, "scoutpingmod" },
    { 0xAA14, "scoutpingpreviousstage" },
    { 0xAA15, "scoutpingradius" },
    { 0xAA16, "scoutsweeptime" },
    { 0xAA17, "scr_anim" },
    { 0xAA18, "scr_animname" },
    { 0xAA19, "scr_animsound" },
    { 0xAA1A, "scr_animtree" },
    { 0xAA1B, "scr_blockin" },
    { 0xAA1C, "scr_br_assassination_quest" },
    { 0xAA1D, "scr_br_dom_quest" },
    { 0xAA1E, "scr_br_scavenger_findpath" },
    { 0xAA1F, "scr_br_scavenger_quest" },
    { 0xAA20, "scr_eventanim" },
    { 0xAA21, "scr_face" },
    { 0xAA22, "scr_gesture" },
    { 0xAA23, "scr_goaltime" },
    { 0xAA24, "scr_head" },
    { 0xAA25, "scr_look" },
    { 0xAA26, "scr_lookat" },
    { 0xAA27, "scr_model" },
    { 0xAA28, "scr_notetrack" },
    { 0xAA29, "scr_plrdialogue" },
    { 0xAA2A, "scr_radio" },
    { 0xAA2B, "scr_sound" },
    { 0xAA2C, "scr_text" },
    { 0xAA2D, "scr_traverse" },
    { 0xAA2E, "scr_viewmodelanim" },
    { 0xAA2F, "scr_weapon" },
    { 0xAA30, "scramble_acquiretarget" },
    { 0xAA31, "scramble_watchcrashing" },
    { 0xAA32, "scramble_watchlaser" },
    { 0xAA33, "scramble_watchleaving" },
    { 0xAA34, "scramble_watchlineofsight" },
    { 0xAA35, "scramblebeginuse" },
    { 0xAA36, "scrambled" },
    { 0xAA37, "scrambledby" },
    { 0xAA38, "scrambleent" },
    { 0xAA39, "scrambler" },
    { 0xAA3A, "scrambler_executevisuals" },
    { 0xAA3B, "scrambler_stun_damage" },
    { 0xAA3C, "scramblerdrone_counteruavmodeoff" },
    { 0xAA3D, "scramblerdrone_counteruavmodeon" },
    { 0xAA3E, "scramblerdrone_equipment_wrapper" },
    { 0xAA3F, "scramblers" },
    { 0xAA40, "scrambletarget" },
    { 0xAA41, "scrambletargetent" },
    { 0xAA42, "scrambleturretattacktargets" },
    { 0xAA43, "scrambleusefinished" },
    { 0xAA44, "screams_when_seeing_enemy" },
    { 0xAA45, "screen_corner_line" },
    { 0xAA46, "screen_detailed_alpha" },
    { 0xAA47, "screen_fade_back_to_normal" },
    { 0xAA48, "screen_fade_to_black" },
    { 0xAA49, "screen_model" },
    { 0xAA4A, "screen_shake_infil" },
    { 0xAA4B, "screen_shake_landing" },
    { 0xAA4C, "screen_shake_pre_infil" },
    { 0xAA4D, "screen_shake_stuff" },
    { 0xAA4E, "screeneffectcleanup" },
    { 0xAA4F, "screenprint_dosceneprintplayback" },
    { 0xAA50, "screenprint_newpotgchosen" },
    { 0xAA51, "screens" },
    { 0xAA52, "screens_alertflip" },
    { 0xAA53, "screens_bink" },
    { 0xAA54, "screens_create" },
    { 0xAA55, "screens_damage_think" },
    { 0xAA56, "screens_debug_counter" },
    { 0xAA57, "screens_delete" },
    { 0xAA58, "screens_fixed" },
    { 0xAA59, "screens_flagged" },
    { 0xAA5A, "screens_flip" },
    { 0xAA5B, "screens_fliprnd" },
    { 0xAA5C, "screens_off_test" },
    { 0xAA5D, "screens_red" },
    { 0xAA5E, "screens_static" },
    { 0xAA5F, "screens_think" },
    { 0xAA60, "screens_think_func" },
    { 0xAA61, "screens_wait_for_flag" },
    { 0xAA62, "screens_widget" },
    { 0xAA63, "screensaver" },
    { 0xAA64, "screensaver_play" },
    { 0xAA65, "screensaver_point_create" },
    { 0xAA66, "screensaver_record" },
    { 0xAA67, "screensaverpath" },
    { 0xAA68, "scrip_delay_post" },
    { 0xAA69, "script_accel" },
    { 0xAA6A, "script_accel_fraction" },
    { 0xAA6B, "script_accumulate" },
    { 0xAA6C, "script_accuracy" },
    { 0xAA6D, "script_ai_invulnerable" },
    { 0xAA6E, "script_aigroup" },
    { 0xAA6F, "script_airresistance" },
    { 0xAA70, "script_airspeed" },
    { 0xAA71, "script_allow_driver_death" },
    { 0xAA72, "script_allow_rider_deaths" },
    { 0xAA73, "script_allowdeath" },
    { 0xAA74, "script_ammo_alt_clip" },
    { 0xAA75, "script_ammo_alt_extra" },
    { 0xAA76, "script_ammo_clip" },
    { 0xAA77, "script_ammo_extra" },
    { 0xAA78, "script_ammo_max" },
    { 0xAA79, "script_angle_max" },
    { 0xAA7A, "script_angles" },
    { 0xAA7B, "script_anglevehicle" },
    { 0xAA7C, "script_animation" },
    { 0xAA7D, "script_animation_exit" },
    { 0xAA7E, "script_animation_type" },
    { 0xAA7F, "script_animname" },
    { 0xAA80, "script_animnode" },
    { 0xAA81, "script_arbitrary_up" },
    { 0xAA82, "script_area" },
    { 0xAA83, "script_assaultnode" },
    { 0xAA84, "script_attacker_accuracy" },
    { 0xAA85, "script_attackeraccuracy" },
    { 0xAA86, "script_attackmetype" },
    { 0xAA87, "script_attackpattern" },
    { 0xAA88, "script_attackspeed" },
    { 0xAA89, "script_audio_blend_mode" },
    { 0xAA8A, "script_audio_enter_func" },
    { 0xAA8B, "script_audio_enter_msg" },
    { 0xAA8C, "script_audio_exit_func" },
    { 0xAA8D, "script_audio_exit_msg" },
    { 0xAA8E, "script_audio_parameters" },
    { 0xAA8F, "script_audio_point_func" },
    { 0xAA90, "script_audio_progress_func" },
    { 0xAA91, "script_audio_progress_map" },
    { 0xAA92, "script_audio_progress_msg" },
    { 0xAA93, "script_audio_update_rate" },
    { 0xAA94, "script_audio_zones" },
    { 0xAA95, "script_autosave" },
    { 0xAA96, "script_autosavename" },
    { 0xAA97, "script_autotarget" },
    { 0xAA98, "script_avoidplayer" },
    { 0xAA99, "script_avoidvehicles" },
    { 0xAA9A, "script_badplace" },
    { 0xAA9B, "script_balcony" },
    { 0xAA9C, "script_battlechatter" },
    { 0xAA9D, "script_battleplan" },
    { 0xAA9E, "script_bcdialog" },
    { 0xAA9F, "script_bctrigger" },
    { 0xAAA0, "script_bg_offset" },
    { 0xAAA1, "script_block" },
    { 0xAAA2, "script_bodyonly" },
    { 0xAAA3, "script_bombmode_dual" },
    { 0xAAA4, "script_bombmode_original" },
    { 0xAAA5, "script_bombmode_single" },
    { 0xAAA6, "script_bombplayer" },
    { 0xAAA7, "script_brake" },
    { 0xAAA8, "script_breach_id" },
    { 0xAAA9, "script_breachgroup" },
    { 0xAAAA, "script_bulletshield" },
    { 0xAAAB, "script_burst" },
    { 0xAAAC, "script_burst_fire_rate" },
    { 0xAAAD, "script_burst_max" },
    { 0xAAAE, "script_burst_min" },
    { 0xAAAF, "script_callsign" },
    { 0xAAB0, "script_car_collision" },
    { 0xAAB1, "script_careful" },
    { 0xAAB2, "script_chance" },
    { 0xAAB3, "script_char_group" },
    { 0xAAB4, "script_char_index" },
    { 0xAAB5, "script_chatgroup" },
    { 0xAAB6, "script_civilian_state" },
    { 0xAAB7, "script_cleartargetyaw" },
    { 0xAAB8, "script_cobratarget" },
    { 0xAAB9, "script_collision_delete" },
    { 0xAABA, "script_color" },
    { 0xAABB, "script_color_01" },
    { 0xAABC, "script_color_02" },
    { 0xAABD, "script_color_allies" },
    { 0xAABE, "script_color_axis" },
    { 0xAABF, "script_color_delay_override" },
    { 0xAAC0, "script_color2" },
    { 0xAAC1, "script_colorlast" },
    { 0xAAC2, "script_combatbehavior" },
    { 0xAAC3, "script_combatmode" },
    { 0xAAC4, "script_control_enter" },
    { 0xAAC5, "script_count" },
    { 0xAAC6, "script_count_max" },
    { 0xAAC7, "script_count_min" },
    { 0xAAC8, "script_crashtype" },
    { 0xAAC9, "script_danger_react" },
    { 0xAACA, "script_death" },
    { 0xAACB, "script_deathanim" },
    { 0xAACC, "script_deathchain" },
    { 0xAACD, "script_deathflag" },
    { 0xAACE, "script_deathflag_longdeath" },
    { 0xAACF, "script_deathroll" },
    { 0xAAD0, "script_deathtime" },
    { 0xAAD1, "script_decel" },
    { 0xAAD2, "script_decel_fraction" },
    { 0xAAD3, "script_delay_max" },
    { 0xAAD4, "script_delay_min" },
    { 0xAAD5, "script_delay_post" },
    { 0xAAD6, "script_delay_spawn" },
    { 0xAAD7, "script_delay2" },
    { 0xAAD8, "script_delay2_max" },
    { 0xAAD9, "script_delay2_min" },
    { 0xAADA, "script_delayed_playerseek" },
    { 0xAADB, "script_deleteai" },
    { 0xAADC, "script_demeanor" },
    { 0xAADD, "script_demeanor_post" },
    { 0xAADE, "script_destruct_collision" },
    { 0xAADF, "script_destructable_area" },
    { 0xAAE0, "script_destructible" },
    { 0xAAE1, "script_dialogue" },
    { 0xAAE2, "script_diequietly" },
    { 0xAAE3, "script_difficulty" },
    { 0xAAE4, "script_disable_arrivals" },
    { 0xAAE5, "script_disable_exits" },
    { 0xAAE6, "script_disable_unloadoffset" },
    { 0xAAE7, "script_disconnectpaths" },
    { 0xAAE8, "script_displaceable" },
    { 0xAAE9, "script_dist_only" },
    { 0xAAEA, "script_do_arrival" },
    { 0xAAEB, "script_do_arrivals" },
    { 0xAAEC, "script_do_exits" },
    { 0xAAED, "script_dof_far_blur" },
    { 0xAAEE, "script_dof_far_end" },
    { 0xAAEF, "script_dof_far_start" },
    { 0xAAF0, "script_dof_near_blur" },
    { 0xAAF1, "script_dof_near_end" },
    { 0xAAF2, "script_dof_near_start" },
    { 0xAAF3, "script_dont_link_turret" },
    { 0xAAF4, "script_dontpeek" },
    { 0xAAF5, "script_dontremove" },
    { 0xAAF6, "script_dontshootwhilemoving" },
    { 0xAAF7, "script_dontunloadonend" },
    { 0xAAF8, "script_dot" },
    { 0xAAF9, "script_drone" },
    { 0xAAFA, "script_drone_override" },
    { 0xAAFB, "script_drone_repeat_count" },
    { 0xAAFC, "script_dronelag" },
    { 0xAAFD, "script_drones_max" },
    { 0xAAFE, "script_drones_min" },
    { 0xAAFF, "script_dronestartmove" },
    { 0xAB00, "script_duration" },
    { 0xAB01, "script_emptyspawner" },
    { 0xAB02, "script_ender" },
    { 0xAB03, "script_enemyselector" },
    { 0xAB04, "script_engage" },
    { 0xAB05, "script_engagedelay" },
    { 0xAB06, "script_engine_states" },
    { 0xAB07, "script_ent_flag_clear" },
    { 0xAB08, "script_ent_flag_set" },
    { 0xAB09, "script_ent_flag_wait" },
    { 0xAB0A, "script_escalation_level" },
    { 0xAB0B, "script_explode" },
    { 0xAB0C, "script_exploder_delay" },
    { 0xAB0D, "script_explosive_bullet_shield" },
    { 0xAB0E, "script_faceangles" },
    { 0xAB0F, "script_faceenemydist" },
    { 0xAB10, "script_fakeactor" },
    { 0xAB11, "script_fakeactor_node" },
    { 0xAB12, "script_fallback_group" },
    { 0xAB13, "script_falldirection" },
    { 0xAB14, "script_favoriteenemy" },
    { 0xAB15, "script_fightdist" },
    { 0xAB16, "script_firefx" },
    { 0xAB17, "script_firefxdelay" },
    { 0xAB18, "script_firefxsound" },
    { 0xAB19, "script_firefxtimeout" },
    { 0xAB1A, "script_firelink" },
    { 0xAB1B, "script_fireondrones" },
    { 0xAB1C, "script_fixednode" },
    { 0xAB1D, "script_flag" },
    { 0xAB1E, "script_flag_clear" },
    { 0xAB1F, "script_flag_false" },
    { 0xAB20, "script_flag_min" },
    { 0xAB21, "script_flag_set" },
    { 0xAB22, "script_flag_true" },
    { 0xAB23, "script_flag_wait" },
    { 0xAB24, "script_flakaicount" },
    { 0xAB25, "script_followmax" },
    { 0xAB26, "script_followmin" },
    { 0xAB27, "script_followmode" },
    { 0xAB28, "script_force_color" },
    { 0xAB29, "script_force_count" },
    { 0xAB2A, "script_forcebalconydeath" },
    { 0xAB2B, "script_forcecolor" },
    { 0xAB2C, "script_forcefire_delay" },
    { 0xAB2D, "script_forcefire_duration" },
    { 0xAB2E, "script_forcegoal" },
    { 0xAB2F, "script_forcegrenade" },
    { 0xAB30, "script_forcespawn" },
    { 0xAB31, "script_forcespawndist" },
    { 0xAB32, "script_forceyaw" },
    { 0xAB33, "script_fov_inner" },
    { 0xAB34, "script_fov_outer" },
    { 0xAB35, "script_free" },
    { 0xAB36, "script_friendly_fire_disable" },
    { 0xAB37, "script_friendname" },
    { 0xAB38, "script_friendnames" },
    { 0xAB39, "script_func" },
    { 0xAB3A, "script_function" },
    { 0xAB3B, "script_fxcommand" },
    { 0xAB3C, "script_fxgroup" },
    { 0xAB3D, "script_fxid" },
    { 0xAB3E, "script_fxstart" },
    { 0xAB3F, "script_fxstop" },
    { 0xAB40, "script_gameobjectname" },
    { 0xAB41, "script_gametype_ctf" },
    { 0xAB42, "script_gametype_dm" },
    { 0xAB43, "script_gametype_hq" },
    { 0xAB44, "script_gametype_koth" },
    { 0xAB45, "script_gametype_sd" },
    { 0xAB46, "script_gametype_tdm" },
    { 0xAB47, "script_gesture" },
    { 0xAB48, "script_goal_radius" },
    { 0xAB49, "script_goal_type" },
    { 0xAB4A, "script_goal_yaw" },
    { 0xAB4B, "script_goalheight" },
    { 0xAB4C, "script_goalvolume" },
    { 0xAB4D, "script_goalyaw" },
    { 0xAB4E, "script_godmode" },
    { 0xAB4F, "script_grenades" },
    { 0xAB50, "script_grenadeshield" },
    { 0xAB51, "script_grenadespeed" },
    { 0xAB52, "script_group" },
    { 0xAB53, "script_groupname" },
    { 0xAB54, "script_growl" },
    { 0xAB55, "script_gunpose" },
    { 0xAB56, "script_health" },
    { 0xAB57, "script_helimove" },
    { 0xAB58, "script_hidden" },
    { 0xAB59, "script_hint" },
    { 0xAB5A, "script_hoverwait" },
    { 0xAB5B, "script_huntlookaroundduration" },
    { 0xAB5C, "script_idle" },
    { 0xAB5D, "script_ignore_claimed" },
    { 0xAB5E, "script_ignore_suppression" },
    { 0xAB5F, "script_ignoreall" },
    { 0xAB60, "script_ignoreme" },
    { 0xAB61, "script_immunetoflash" },
    { 0xAB62, "script_increment" },
    { 0xAB63, "script_index" },
    { 0xAB64, "script_intensity" },
    { 0xAB65, "script_intensity_01" },
    { 0xAB66, "script_intensity_02" },
    { 0xAB67, "script_intensity_start" },
    { 0xAB68, "script_intensity2" },
    { 0xAB69, "script_keepdriver" },
    { 0xAB6A, "script_kill_ai" },
    { 0xAB6B, "script_kill_vehicle_spawner" },
    { 0xAB6C, "script_killspawn" },
    { 0xAB6D, "script_killspawner" },
    { 0xAB6E, "script_killspawner_group" },
    { 0xAB6F, "script_label" },
    { 0xAB70, "script_land" },
    { 0xAB71, "script_landmark" },
    { 0xAB72, "script_laser" },
    { 0xAB73, "script_light" },
    { 0xAB74, "script_light_idle_sfx" },
    { 0xAB75, "script_light_startnotify" },
    { 0xAB76, "script_light_stopnotify" },
    { 0xAB77, "script_light_switch_fx" },
    { 0xAB78, "script_light_switch_fx_tag" },
    { 0xAB79, "script_light_switch_sfx" },
    { 0xAB7A, "script_light_switch_state" },
    { 0xAB7B, "script_location" },
    { 0xAB7C, "script_longdeath" },
    { 0xAB7D, "script_lookat_setup" },
    { 0xAB7E, "script_looping" },
    { 0xAB7F, "script_manualtarget" },
    { 0xAB80, "script_mapsize_08" },
    { 0xAB81, "script_mapsize_16" },
    { 0xAB82, "script_mapsize_32" },
    { 0xAB83, "script_mapsize_64" },
    { 0xAB84, "script_max_left_angle" },
    { 0xAB85, "script_max_right_angle" },
    { 0xAB86, "script_max_wait" },
    { 0xAB87, "script_maxdist" },
    { 0xAB88, "script_maxspawn" },
    { 0xAB89, "script_mg_angle" },
    { 0xAB8A, "script_mg42" },
    { 0xAB8B, "script_mg42auto" },
    { 0xAB8C, "script_mgturret" },
    { 0xAB8D, "script_mgturretauto" },
    { 0xAB8E, "script_min_wait" },
    { 0xAB8F, "script_missiles" },
    { 0xAB90, "script_model_alpha_anims" },
    { 0xAB91, "script_model_anims" },
    { 0xAB92, "script_model_exfil_anims" },
    { 0xAB93, "script_model_init_anims" },
    { 0xAB94, "script_modelname" },
    { 0xAB95, "script_models" },
    { 0xAB96, "script_mortargroup" },
    { 0xAB97, "script_movement_anim" },
    { 0xAB98, "script_moveoverride" },
    { 0xAB99, "script_moveplaybackrate" },
    { 0xAB9A, "script_mover" },
    { 0xAB9B, "script_mover_add_hintstring" },
    { 0xAB9C, "script_mover_add_parameters" },
    { 0xAB9D, "script_mover_agent_spawn_watch" },
    { 0xAB9E, "script_mover_allow_usable" },
    { 0xAB9F, "script_mover_apply_move_parameters" },
    { 0xABA0, "script_mover_call_func_on_notify" },
    { 0xABA1, "script_mover_classnames" },
    { 0xABA2, "script_mover_connect_watch" },
    { 0xABA3, "script_mover_defaults" },
    { 0xABA4, "script_mover_func_on_notify" },
    { 0xABA5, "script_mover_get_top_parent" },
    { 0xABA6, "script_mover_has_parent_moved" },
    { 0xABA7, "script_mover_hintstrings" },
    { 0xABA8, "script_mover_init_move_parameters" },
    { 0xABA9, "script_mover_int" },
    { 0xABAA, "script_mover_is_script_mover" },
    { 0xABAB, "script_mover_link_to_use_object" },
    { 0xABAC, "script_mover_move_to_named_goal" },
    { 0xABAD, "script_mover_move_to_target" },
    { 0xABAE, "script_mover_named_goals" },
    { 0xABAF, "script_mover_parameters" },
    { 0xABB0, "script_mover_parse_move_parameters" },
    { 0xABB1, "script_mover_parse_range" },
    { 0xABB2, "script_mover_parse_targets" },
    { 0xABB3, "script_mover_run_notify" },
    { 0xABB4, "script_mover_save_default_move_parameters" },
    { 0xABB5, "script_mover_set_defaults" },
    { 0xABB6, "script_mover_set_param" },
    { 0xABB7, "script_mover_set_usable" },
    { 0xABB8, "script_mover_start_use" },
    { 0xABB9, "script_mover_trigger_on" },
    { 0xABBA, "script_mover_unlink_from_use_object" },
    { 0xABBB, "script_mover_use_can_link" },
    { 0xABBC, "script_mover_use_trigger" },
    { 0xABBD, "script_mp_style_helicopter" },
    { 0xABBE, "script_multiplier" },
    { 0xABBF, "script_namenumber" },
    { 0xABC0, "script_nexthuntpos" },
    { 0xABC1, "script_no_reorient" },
    { 0xABC2, "script_no_seeker" },
    { 0xABC3, "script_noarmor" },
    { 0xABC4, "script_nobark" },
    { 0xABC5, "script_nobloodpool" },
    { 0xABC6, "script_node_pausetime" },
    { 0xABC7, "script_nodestate" },
    { 0xABC8, "script_nodrop" },
    { 0xABC9, "script_noflashlight" },
    { 0xABCA, "script_noflip" },
    { 0xABCB, "script_nofriendlywave" },
    { 0xABCC, "script_nohealth" },
    { 0xABCD, "script_noloot" },
    { 0xABCE, "script_nomg" },
    { 0xABCF, "script_noragdoll" },
    { 0xABD0, "script_nosight" },
    { 0xABD1, "script_nosurprise" },
    { 0xABD2, "script_noteowrthy" },
    { 0xABD3, "script_noteworth" },
    { 0xABD4, "script_noteworty" },
    { 0xABD5, "script_notify_start" },
    { 0xABD6, "script_notify_stop" },
    { 0xABD7, "script_notworthy" },
    { 0xABD8, "script_nowall" },
    { 0xABD9, "script_objective" },
    { 0xABDA, "script_objective_active" },
    { 0xABDB, "script_objective_inactive" },
    { 0xABDC, "script_offhands" },
    { 0xABDD, "script_offradius" },
    { 0xABDE, "script_offset" },
    { 0xABDF, "script_offtime" },
    { 0xABE0, "script_oneway" },
    { 0xABE1, "script_onlyidle" },
    { 0xABE2, "script_origin_other" },
    { 0xABE3, "script_pacifist" },
    { 0xABE4, "script_painter_facade" },
    { 0xABE5, "script_painter_maxdist" },
    { 0xABE6, "script_painter_treeorient" },
    { 0xABE7, "script_paintergroup" },
    { 0xABE8, "script_parameter" },
    { 0xABE9, "script_parameters" },
    { 0xABEA, "script_pathtype" },
    { 0xABEB, "script_patroller" },
    { 0xABEC, "script_percent" },
    { 0xABED, "script_personality" },
    { 0xABEE, "script_pet" },
    { 0xABEF, "script_physics" },
    { 0xABF0, "script_physicsjolt" },
    { 0xABF1, "script_pilottalk" },
    { 0xABF2, "script_plane" },
    { 0xABF3, "script_playerconeradius" },
    { 0xABF4, "script_playerseek" },
    { 0xABF5, "script_poi_forcestrafe" },
    { 0xABF6, "script_portal" },
    { 0xABF7, "script_prefab_exploder" },
    { 0xABF8, "script_presound" },
    { 0xABF9, "script_print_fx" },
    { 0xABFA, "script_priority" },
    { 0xABFB, "script_qualityspotshadow" },
    { 0xABFC, "script_random_killspawner" },
    { 0xABFD, "script_randomspawn" },
    { 0xABFE, "script_reaction" },
    { 0xABFF, "script_readystand" },
    { 0xAC00, "script_repeat" },
    { 0xAC01, "script_requires_player" },
    { 0xAC02, "script_reuse" },
    { 0xAC03, "script_reuse_max" },
    { 0xAC04, "script_reuse_min" },
    { 0xAC05, "script_rotation_amount" },
    { 0xAC06, "script_rotation_max" },
    { 0xAC07, "script_rotation_platform" },
    { 0xAC08, "script_rotation_speed" },
    { 0xAC09, "script_rss" },
    { 0xAC0A, "script_savetrigger_timer" },
    { 0xAC0B, "script_seekgoal" },
    { 0xAC0C, "script_selfdestruct" },
    { 0xAC0D, "script_selfdestruct_delay" },
    { 0xAC0E, "script_shotcount" },
    { 0xAC0F, "script_side" },
    { 0xAC10, "script_sightrange" },
    { 0xAC11, "script_skilloverride" },
    { 0xAC12, "script_skiplookaroundanim" },
    { 0xAC13, "script_slowmo_breach" },
    { 0xAC14, "script_slowmo_breach_doortype" },
    { 0xAC15, "script_slowmo_breach_spawners" },
    { 0xAC16, "script_smartobject" },
    { 0xAC17, "script_sound" },
    { 0xAC18, "script_sound_type" },
    { 0xAC19, "script_soundalias" },
    { 0xAC1A, "script_spawn_delay" },
    { 0xAC1B, "script_spawn_here" },
    { 0xAC1C, "script_spawn_once" },
    { 0xAC1D, "script_spawn_open_yaw" },
    { 0xAC1E, "script_spawn_pool" },
    { 0xAC1F, "script_spawngroup" },
    { 0xAC20, "script_spawnsoldiers" },
    { 0xAC21, "script_spawnsubgroup" },
    { 0xAC22, "script_specialops" },
    { 0xAC23, "script_specialopsname" },
    { 0xAC24, "script_speed" },
    { 0xAC25, "script_speed_scale" },
    { 0xAC26, "script_speed_type" },
    { 0xAC27, "script_spotlight" },
    { 0xAC28, "script_spotlimit" },
    { 0xAC29, "script_squad" },
    { 0xAC2A, "script_squadname" },
    { 0xAC2B, "script_stack" },
    { 0xAC2C, "script_stance" },
    { 0xAC2D, "script_start" },
    { 0xAC2E, "script_start_intensity" },
    { 0xAC2F, "script_start_state" },
    { 0xAC30, "script_startdelay" },
    { 0xAC31, "script_startdelay_max" },
    { 0xAC32, "script_startdelay_min" },
    { 0xAC33, "script_startinghealth" },
    { 0xAC34, "script_startingposition" },
    { 0xAC35, "script_startname" },
    { 0xAC36, "script_startrunning" },
    { 0xAC37, "script_stay_drone" },
    { 0xAC38, "script_stealth" },
    { 0xAC39, "script_stealth_clear" },
    { 0xAC3A, "script_stealth_region_group" },
    { 0xAC3B, "script_stealthgroup" },
    { 0xAC3C, "script_stopnode" },
    { 0xAC3D, "script_stoptoshoot" },
    { 0xAC3E, "script_struct_fx_init" },
    { 0xAC3F, "script_sunenable" },
    { 0xAC40, "script_sunsamplesizenear" },
    { 0xAC41, "script_sunshadowscale" },
    { 0xAC42, "script_suppression" },
    { 0xAC43, "script_suspend" },
    { 0xAC44, "script_suspend_group" },
    { 0xAC45, "script_tag" },
    { 0xAC46, "script_tankgroup" },
    { 0xAC47, "script_targetoffset_z" },
    { 0xAC48, "script_targettype" },
    { 0xAC49, "script_team" },
    { 0xAC4A, "script_tess_distance" },
    { 0xAC4B, "script_tess_falloff" },
    { 0xAC4C, "script_threatbias" },
    { 0xAC4D, "script_threatbiasgroup" },
    { 0xAC4E, "script_threshold" },
    { 0xAC4F, "script_time_max" },
    { 0xAC50, "script_time_min" },
    { 0xAC51, "script_timeout" },
    { 0xAC52, "script_timer" },
    { 0xAC53, "script_transient" },
    { 0xAC54, "script_transient_set" },
    { 0xAC55, "script_transient_unload" },
    { 0xAC56, "script_transient_unload_set" },
    { 0xAC57, "script_translate_max" },
    { 0xAC58, "script_translate_speed" },
    { 0xAC59, "script_translation_amount" },
    { 0xAC5A, "script_translation_time" },
    { 0xAC5B, "script_transmission" },
    { 0xAC5C, "script_trial" },
    { 0xAC5D, "script_trigger_group" },
    { 0xAC5E, "script_triggered_playerseek" },
    { 0xAC5F, "script_triggername" },
    { 0xAC60, "script_turningdir" },
    { 0xAC61, "script_turret" },
    { 0xAC62, "script_turret_ambush" },
    { 0xAC63, "script_turret_autonomous" },
    { 0xAC64, "script_turret_reuse_max" },
    { 0xAC65, "script_turret_reuse_min" },
    { 0xAC66, "script_turret_share" },
    { 0xAC67, "script_turretmain" },
    { 0xAC68, "script_turretmg" },
    { 0xAC69, "script_turrets" },
    { 0xAC6A, "script_type" },
    { 0xAC6B, "script_unload" },
    { 0xAC6C, "script_unloaddelay" },
    { 0xAC6D, "script_unloadmgguy" },
    { 0xAC6E, "script_use_pain" },
    { 0xAC6F, "script_use_real_fire" },
    { 0xAC70, "script_useangles" },
    { 0xAC71, "script_usemg42" },
    { 0xAC72, "script_vehicle_lights_off" },
    { 0xAC73, "script_vehicle_lights_on" },
    { 0xAC74, "script_vehicle_selfremove" },
    { 0xAC75, "script_vehiclecargo" },
    { 0xAC76, "script_vehicledetour" },
    { 0xAC77, "script_vehicledetourgroup" },
    { 0xAC78, "script_vehicledetourtype" },
    { 0xAC79, "script_vehiclegroup" },
    { 0xAC7A, "script_vehiclegroupdelete" },
    { 0xAC7B, "script_vehiclenodegroup" },
    { 0xAC7C, "script_vehiclespawngroup" },
    { 0xAC7D, "script_wait" },
    { 0xAC7E, "script_wait_01_max" },
    { 0xAC7F, "script_wait_01_min" },
    { 0xAC80, "script_wait_02_max" },
    { 0xAC81, "script_wait_02_min" },
    { 0xAC82, "script_wait_add" },
    { 0xAC83, "script_wait_max" },
    { 0xAC84, "script_wait_min" },
    { 0xAC85, "script_wait2_min" },
    { 0xAC86, "script_wallrun_type" },
    { 0xAC87, "script_wheeldirection" },
    { 0xAC88, "script_wingman" },
    { 0xAC89, "script_wtf" },
    { 0xAC8A, "script_yawspeed" },
    { 0xAC8B, "scriptable_addnotifycallback" },
    { 0xAC8C, "scriptable_addpostinitcallback" },
    { 0xAC8D, "scriptable_addtouchedcallback" },
    { 0xAC8E, "scriptable_addusedcallback" },
    { 0xAC8F, "scriptable_anim" },
    { 0xAC90, "scriptable_brake_reset" },
    { 0xAC91, "scriptable_braking" },
    { 0xAC92, "scriptable_car_getouts" },
    { 0xAC93, "scriptable_car_passenger" },
    { 0xAC94, "scriptable_cleanup" },
    { 0xAC95, "scriptable_clearanim" },
    { 0xAC96, "scriptable_compound_car_shadows" },
    { 0xAC97, "scriptable_cpcallback" },
    { 0xAC98, "scriptable_cpglobalcallback" },
    { 0xAC99, "scriptable_damage_proc" },
    { 0xAC9A, "scriptable_damage_thread" },
    { 0xAC9B, "scriptable_destroy_part" },
    { 0xAC9C, "scriptable_door_auto_close" },
    { 0xAC9D, "scriptable_door_autoclose_delay" },
    { 0xAC9E, "scriptable_door_claim" },
    { 0xAC9F, "scriptable_door_claim_update_on_state_change" },
    { 0xACA0, "scriptable_door_close_all_doors" },
    { 0xACA1, "scriptable_door_disable_autoclose" },
    { 0xACA2, "scriptable_door_enable_autoclose" },
    { 0xACA3, "scriptable_door_get_angle_delta" },
    { 0xACA4, "scriptable_door_get_angle_step_begin" },
    { 0xACA5, "scriptable_door_get_closest_state" },
    { 0xACA6, "scriptable_door_hinge_progression" },
    { 0xACA7, "scriptable_door_init" },
    { 0xACA8, "scriptable_door_initialized" },
    { 0xACA9, "scriptable_door_postinit" },
    { 0xACAA, "scriptable_door_scriptable_touched_callback" },
    { 0xACAB, "scriptable_door_scriptable_used_callback" },
    { 0xACAC, "scriptable_door_side_flip" },
    { 0xACAD, "scriptable_door_side_get_for_state" },
    { 0xACAE, "scriptable_door_state_name_make" },
    { 0xACAF, "scriptable_door_timer_elapsed" },
    { 0xACB0, "scriptable_door_unclaim" },
    { 0xACB1, "scriptable_door_unclaim_think" },
    { 0xACB2, "scriptable_doors_opened" },
    { 0xACB3, "scriptable_engineinitialize" },
    { 0xACB4, "scriptable_enginenotifycallback" },
    { 0xACB5, "scriptable_enginepostinitialize" },
    { 0xACB6, "scriptable_enginetouched" },
    { 0xACB7, "scriptable_engineused" },
    { 0xACB8, "scriptable_explosive_damage" },
    { 0xACB9, "scriptable_explosive_damage_framedelay" },
    { 0xACBA, "scriptable_field_lights_swap" },
    { 0xACBB, "scriptable_get_full_partname" },
    { 0xACBC, "scriptable_get_part_by_index" },
    { 0xACBD, "scriptable_get_part_origin" },
    { 0xACBE, "scriptable_gun_damage" },
    { 0xACBF, "scriptable_ignore_attacker" },
    { 0xACC0, "scriptable_ignore_mod" },
    { 0xACC1, "scriptable_inherit_parameters" },
    { 0xACC2, "scriptable_init" },
    { 0xACC3, "scriptable_lantern_lights" },
    { 0xACC4, "scriptable_lantern_think" },
    { 0xACC5, "scriptable_lanterns" },
    { 0xACC6, "scriptable_mpcallback" },
    { 0xACC7, "scriptable_mpglobalcallback" },
    { 0xACC8, "scriptable_notify_callback_funcs" },
    { 0xACC9, "scriptable_part_struct" },
    { 0xACCA, "scriptable_parts_init" },
    { 0xACCB, "scriptable_postinit" },
    { 0xACCC, "scriptable_print_warning" },
    { 0xACCD, "scriptable_setinitcallback" },
    { 0xACCE, "scriptable_should_be_ignored" },
    { 0xACCF, "scriptable_spcallback" },
    { 0xACD0, "scriptable_spglobalcallback" },
    { 0xACD1, "scriptable_touched_funcs" },
    { 0xACD2, "scriptable_update_map" },
    { 0xACD3, "scriptable_used_funcs" },
    { 0xACD4, "scriptable_vo_handler" },
    { 0xACD5, "scriptable_vo_played" },
    { 0xACD6, "scriptable_warning" },
    { 0xACD7, "scriptable_watcher" },
    { 0xACD8, "scriptablecleanup" },
    { 0xACD9, "scriptablename" },
    { 0xACDA, "scriptableparts" },
    { 0xACDB, "scriptables" },
    { 0xACDC, "scriptables_init" },
    { 0xACDD, "scriptablestate" },
    { 0xACDE, "scriptablestatefunc" },
    { 0xACDF, "scriptablestates" },
    { 0xACE0, "scriptagentstealth_init" },
    { 0xACE1, "scriptbundletype" },
    { 0xACE2, "scriptcoll" },
    { 0xACE3, "scriptdata" },
    { 0xACE4, "scripted_ability_harpoonv1" },
    { 0xACE5, "scripted_ai_rocket" },
    { 0xACE6, "scripted_ai_rocket_player" },
    { 0xACE7, "scripted_anim_settings" },
    { 0xACE8, "scripted_anime" },
    { 0xACE9, "scripted_animnode" },
    { 0xACEA, "scripted_bridge_shot" },
    { 0xACEB, "scripted_deathanim" },
    { 0xACEC, "scripted_deathanim_loop" },
    { 0xACED, "scripted_dialogue" },
    { 0xACEE, "scripted_door_open" },
    { 0xACEF, "scripted_elems" },
    { 0xACF0, "scripted_flash" },
    { 0xACF1, "scripted_health" },
    { 0xACF2, "scripted_ispushable" },
    { 0xACF3, "scripted_long_deaths" },
    { 0xACF4, "scripted_longdeath" },
    { 0xACF5, "scripted_longdeath_3" },
    { 0xACF6, "scripted_melee_active" },
    { 0xACF7, "scripted_mode" },
    { 0xACF8, "scripted_movement" },
    { 0xACF9, "scripted_movement_arrival" },
    { 0xACFA, "scripted_movement_arrivefuncs" },
    { 0xACFB, "scripted_movement_idle" },
    { 0xACFC, "scripted_movement_post_wait" },
    { 0xACFD, "scripted_path_style" },
    { 0xACFE, "scripted_plant_bomb" },
    { 0xACFF, "scripted_poi_start" },
    { 0xAD00, "scripted_reload_dmg" },
    { 0xAD01, "scripted_shot" },
    { 0xAD02, "scripted_shot_monitor" },
    { 0xAD03, "scripted_smoke_gren" },
    { 0xAD04, "scripted_sniper_can_save" },
    { 0xAD05, "scripted_spawner_func" },
    { 0xAD06, "scripted_spawner_func_strings" },
    { 0xAD07, "scripted_spawner_map_strings" },
    { 0xAD08, "scripted_spawners" },
    { 0xAD09, "scripted_spawners_models" },
    { 0xAD0A, "scripted_spawners_triggers" },
    { 0xAD0B, "scripted_stacy_idle" },
    { 0xAD0C, "scripted_targets" },
    { 0xAD0D, "scripted_targets_check_los" },
    { 0xAD0E, "scripted_targets_notify" },
    { 0xAD0F, "scriptedattacker" },
    { 0xAD10, "scriptedattackeraccuracy" },
    { 0xAD11, "scriptedcoverposerequestis" },
    { 0xAD12, "scriptedcoverposerequestisdefined" },
    { 0xAD13, "scripteddamagemultiplier" },
    { 0xAD14, "scripteddeathshielddurationscale" },
    { 0xAD15, "scripteddialoguebuffertime" },
    { 0xAD16, "scripteddialoguenonotify" },
    { 0xAD17, "scripteddialoguenotify" },
    { 0xAD18, "scripteddialoguestarttime" },
    { 0xAD19, "scriptedflashed" },
    { 0xAD1A, "scriptedignorerandombulletdamage" },
    { 0xAD1B, "scriptedinitialinvestigatedelay" },
    { 0xAD1C, "scriptedisalive" },
    { 0xAD1D, "scriptedstealth" },
    { 0xAD1E, "scriptedtalkingknob" },
    { 0xAD1F, "scriptedthread" },
    { 0xAD20, "scriptedweaponclassprimary" },
    { 0xAD21, "scriptedweaponfailed" },
    { 0xAD22, "scriptedweaponfailed_primaryarray" },
    { 0xAD23, "scriptedweaponfailed_secondaryarray" },
    { 0xAD24, "scriptedweaponfailed_sidearmarray" },
    { 0xAD25, "scripter_note" },
    { 0xAD26, "scripter_note_proc" },
    { 0xAD27, "scripternote" },
    { 0xAD28, "scriptfirecount" },
    { 0xAD29, "scripthuddestroy" },
    { 0xAD2A, "scripthudthread" },
    { 0xAD2B, "scriptitem_buildspawnflags" },
    { 0xAD2C, "scriptitem_itemwatchfortrigger" },
    { 0xAD2D, "scriptitem_playerwatchforanypickup" },
    { 0xAD2E, "scriptitem_testspawn" },
    { 0xAD2F, "scriptlights_setup" },
    { 0xAD30, "scriptmodel" },
    { 0xAD31, "scriptmoverlinkdummy" },
    { 0xAD32, "scriptnoteworthy" },
    { 0xAD33, "scriptonlytest" },
    { 0xAD34, "scriptperks" },
    { 0xAD35, "scriptswitchweaponhack" },
    { 0xAD36, "scriptuseagetype" },
    { 0xAD37, "scrub_guy" },
    { 0xAD38, "scs_last_spawn_time" },
    { 0xAD39, "scuttle_heli" },
    { 0xAD3A, "sd_bomb_just_planted" },
    { 0xAD3B, "sd_bombplanted_music" },
    { 0xAD3C, "sd_endgame" },
    { 0xAD3D, "sd_loadout" },
    { 0xAD3E, "sd_onbombtimerend" },
    { 0xAD3F, "sd_press_use" },
    { 0xAD40, "sdbomb" },
    { 0xAD41, "sdbombmodel" },
    { 0xAD42, "sealevelorigin" },
    { 0xAD43, "search_anim_pain_or_death" },
    { 0xAD44, "search_anim_react" },
    { 0xAD45, "search_anim_think" },
    { 0xAD46, "search_cells" },
    { 0xAD47, "search_cleanup" },
    { 0xAD48, "search_ground_hint" },
    { 0xAD49, "search_location" },
    { 0xAD4A, "search_points" },
    { 0xAD4B, "searchcenter" },
    { 0xAD4C, "searchforshocksentryairtarget" },
    { 0xAD4D, "searchlight_sweep" },
    { 0xAD4E, "searchlightmodel" },
    { 0xAD4F, "seat" },
    { 0xAD50, "seat_player" },
    { 0xAD51, "seatdata" },
    { 0xAD52, "seated_players" },
    { 0xAD53, "seatenterarrays" },
    { 0xAD54, "seatid" },
    { 0xAD55, "seatidmap" },
    { 0xAD56, "seatids" },
    { 0xAD57, "seatswitcharray" },
    { 0xAD58, "seatunavailable" },
    { 0xAD59, "second_floor_back_bedroom" },
    { 0xAD5A, "second_floor_bathroom" },
    { 0xAD5B, "second_floor_bedroom" },
    { 0xAD5C, "second_floor_bedroom_check_stop" },
    { 0xAD5D, "second_floor_bedroom_door2" },
    { 0xAD5E, "second_floor_bedroom_fire" },
    { 0xAD5F, "second_floor_bedroom_reveal_fire" },
    { 0xAD60, "second_floor_bravo4_1_arrive_flag" },
    { 0xAD61, "second_floor_catchup" },
    { 0xAD62, "second_floor_clear" },
    { 0xAD63, "second_floor_clear_nag" },
    { 0xAD64, "second_floor_enemies_dead_dialogue" },
    { 0xAD65, "second_floor_enemy_bulletshield" },
    { 0xAD66, "second_floor_follow_tag_flash" },
    { 0xAD67, "second_floor_lookup_handler" },
    { 0xAD68, "second_floor_main" },
    { 0xAD69, "second_floor_movement" },
    { 0xAD6A, "second_floor_player_watcher" },
    { 0xAD6B, "second_floor_price" },
    { 0xAD6C, "second_floor_reveal_stuff" },
    { 0xAD6D, "second_floor_stairtrain_arrive" },
    { 0xAD6E, "second_floor_start" },
    { 0xAD6F, "second_idle" },
    { 0xAD70, "second_roof_struct" },
    { 0xAD71, "second_stab_lines" },
    { 0xAD72, "secondary_power" },
    { 0xAD73, "secondarygrenade" },
    { 0xAD74, "secondarygroup" },
    { 0xAD75, "secondarymode" },
    { 0xAD76, "secondarymodefunc" },
    { 0xAD77, "secondarymodestring" },
    { 0xAD78, "secondaryobjectives" },
    { 0xAD79, "secondarypainactive" },
    { 0xAD7A, "secondarytarget" },
    { 0xAD7B, "secondaryweaponclipammo" },
    { 0xAD7C, "secondaryweaponobj" },
    { 0xAD7D, "secondaryweaponstockammo" },
    { 0xAD7E, "seconddeathfunction" },
    { 0xAD7F, "secondowner" },
    { 0xAD80, "secondupgrade" },
    { 0xAD81, "secrethunt" },
    { 0xAD82, "secrethunt_debuglocations" },
    { 0xAD83, "secured" },
    { 0xAD84, "securedoor" },
    { 0xAD85, "securestarted" },
    { 0xAD86, "security_cam_01_catchup" },
    { 0xAD87, "security_cam_01_main" },
    { 0xAD88, "security_cam_01_post_intro_catchup" },
    { 0xAD89, "security_cam_01_post_intro_main" },
    { 0xAD8A, "security_cam_01_post_intro_start" },
    { 0xAD8B, "security_cam_01_start" },
    { 0xAD8C, "security_cam_02_catchup" },
    { 0xAD8D, "security_cam_02_main" },
    { 0xAD8E, "security_cam_02_start" },
    { 0xAD8F, "security_cam_bink_main" },
    { 0xAD90, "security_id" },
    { 0xAD91, "securitycam_slow_look" },
    { 0xAD92, "see_icon_on_cruise_missiles" },
    { 0xAD93, "see_icon_on_interceptor_missiles" },
    { 0xAD94, "seeing_player_time_tracker" },
    { 0xAD95, "seeker_collide" },
    { 0xAD96, "seeker_evaluatesyncedmelee" },
    { 0xAD97, "seeker_getplayerriganims" },
    { 0xAD98, "seeker_initmelee" },
    { 0xAD99, "seeker_meleeexplode" },
    { 0xAD9A, "seeker_meleegrab_bash" },
    { 0xAD9B, "seeker_meleegrab_checkinterrupt" },
    { 0xAD9C, "seeker_meleegrab_counterhint" },
    { 0xAD9D, "seeker_meleegrab_counterinput" },
    { 0xAD9E, "seeker_meleegrab_hint" },
    { 0xAD9F, "seeker_meleegrab_interrupt" },
    { 0xADA0, "seeker_meleegrab_notetracks" },
    { 0xADA1, "seeker_meleegrab_rumble" },
    { 0xADA2, "seeker_meleegrabkillplayer" },
    { 0xADA3, "seeker_meleegrabplayer" },
    { 0xADA4, "seeker_meleegrabplayercounter" },
    { 0xADA5, "seeker_pickattachdirection" },
    { 0xADA6, "seeker_playergrabbed_screenshake" },
    { 0xADA7, "seeker_playerrig_link" },
    { 0xADA8, "seeker_playerrig_meleegrabplayer" },
    { 0xADA9, "seeker_traversal" },
    { 0xADAA, "seekerattack_victim_checkattacker" },
    { 0xADAB, "seekermeleedetonate" },
    { 0xADAC, "seeking_player" },
    { 0xADAD, "seen" },
    { 0xADAE, "seen_attacker" },
    { 0xADAF, "seenatseeker" },
    { 0xADB0, "segment_size" },
    { 0xADB1, "segmented_health_regen" },
    { 0xADB2, "segmented_health_regen_disabled" },
    { 0xADB3, "segmented_health_regen_internal" },
    { 0xADB4, "segmented_health_regen_parameters" },
    { 0xADB5, "segments" },
    { 0xADB6, "segmentvssphere" },
    { 0xADB7, "seigemode_hint_displayed" },
    { 0xADB8, "select" },
    { 0xADB9, "select_all_exploders_of_currently_selected" },
    { 0xADBA, "select_by_name" },
    { 0xADBB, "select_by_name_list" },
    { 0xADBC, "select_by_substring" },
    { 0xADBD, "select_end_bridge_stair_spawners" },
    { 0xADBE, "select_enemy_left_spawners" },
    { 0xADBF, "select_enemy_right_spawners" },
    { 0xADC0, "select_enemy_rpg_spawners" },
    { 0xADC1, "select_enemy_sniper_spawners" },
    { 0xADC2, "select_entity" },
    { 0xADC3, "select_func" },
    { 0xADC4, "select_index_array" },
    { 0xADC5, "select_jugg_node" },
    { 0xADC6, "select_last_entity" },
    { 0xADC7, "select_left_turret_spawners" },
    { 0xADC8, "select_mid_bridge_left_spawners" },
    { 0xADC9, "select_mid_bridge_right_spawners" },
    { 0xADCA, "select_middle_turret_spawners" },
    { 0xADCB, "select_mortar_spawners" },
    { 0xADCC, "select_random_spawners" },
    { 0xADCD, "select_random_vector_in_radius" },
    { 0xADCE, "select_right_turret_spawners" },
    { 0xADCF, "select_spot_array" },
    { 0xADD0, "select_under_bridge_reinforce_spawners" },
    { 0xADD1, "selectable_ents" },
    { 0xADD2, "selectableattachmentlist" },
    { 0xADD3, "selectableattachmentmap" },
    { 0xADD4, "selectairstrikelocation" },
    { 0xADD5, "selectanim" },
    { 0xADD6, "selectbestspawnpoint" },
    { 0xADD7, "selectdomspawn" },
    { 0xADD8, "selected" },
    { 0xADD9, "selected_ent_buttons" },
    { 0xADDA, "selected_fx" },
    { 0xADDB, "selected_fx_ents" },
    { 0xADDC, "selected_fx_option_index" },
    { 0xADDD, "selected_hint" },
    { 0xADDE, "selected_node" },
    { 0xADDF, "selectedaitype" },
    { 0xADE0, "selectedclass" },
    { 0xADE1, "selectedents" },
    { 0xADE2, "selectedhint" },
    { 0xADE3, "selectedmove_forward" },
    { 0xADE4, "selectedmove_right" },
    { 0xADE5, "selectedmove_up" },
    { 0xADE6, "selectedrotate_pitch" },
    { 0xADE7, "selectedrotate_roll" },
    { 0xADE8, "selectedrotate_yaw" },
    { 0xADE9, "selectedspawnarea" },
    { 0xADEA, "selectedweapons" },
    { 0xADEB, "selectfirstavailablekillstreak" },
    { 0xADEC, "selectinglocation" },
    { 0xADED, "selection" },
    { 0xADEE, "selection_error" },
    { 0xADEF, "selectiondelaymessaging" },
    { 0xADF0, "selectionmade" },
    { 0xADF1, "selectlocationvo" },
    { 0xADF2, "selectmostexpensivekillstreak" },
    { 0xADF3, "selectneutralspawn" },
    { 0xADF4, "selectnextavailablekillstreak" },
    { 0xADF5, "selectonemanarmyclass" },
    { 0xADF6, "self_delete" },
    { 0xADF7, "self_destruct" },
    { 0xADF8, "self_destruct_drone" },
    { 0xADF9, "self_func" },
    { 0xADFA, "self_onfirstuse" },
    { 0xADFB, "self_onuse" },
    { 0xADFC, "self_revive" },
    { 0xADFD, "self_revive_activated" },
    { 0xADFE, "self_revive_wait_override" },
    { 0xADFF, "self_revives_purchased" },
    { 0xAE00, "selfdamaging" },
    { 0xAE01, "selfdeletedelay" },
    { 0xAE02, "selfdestruct" },
    { 0xAE03, "selfdestructnow" },
    { 0xAE04, "selflookatfriendly" },
    { 0xAE05, "selfvodelay" },
    { 0xAE06, "selfvodelaycomplete" },
    { 0xAE07, "selfvohistory" },
    { 0xAE08, "selfvoinfo" },
    { 0xAE09, "selfvomap" },
    { 0xAE0A, "semiaces" },
    { 0xAE0B, "semifirenumshots" },
    { 0xAE0C, "semtex_delete" },
    { 0xAE0D, "semtex_destroy" },
    { 0xAE0E, "semtex_explode" },
    { 0xAE0F, "semtex_watch_beacon" },
    { 0xAE10, "semtex_watch_cleanup" },
    { 0xAE11, "semtex_watch_cleanup_end_early" },
    { 0xAE12, "semtex_watch_fuse" },
    { 0xAE13, "semtex_watch_stuck" },
    { 0xAE14, "semtexfiremain" },
    { 0xAE15, "semtexstuckto" },
    { 0xAE16, "semtexstucktoenemy" },
    { 0xAE17, "semtexstucktoplayer" },
    { 0xAE18, "semtexused" },
    { 0xAE19, "send_ai_to_colorvolume" },
    { 0xAE1A, "send_aievent_to_others_in_group" },
    { 0xAE1B, "send_convoy_soldier_here" },
    { 0xAE1C, "send_down" },
    { 0xAE1D, "send_drone_down" },
    { 0xAE1E, "send_enemies_to_attack_hack" },
    { 0xAE1F, "send_griggs_to_ied" },
    { 0xAE20, "send_guy_to_org" },
    { 0xAE21, "send_heli_reinforcements" },
    { 0xAE22, "send_hvt_to_elevator" },
    { 0xAE23, "send_notify" },
    { 0xAE24, "send_notify_after_frame_end" },
    { 0xAE25, "send_notify_from_ied_controller" },
    { 0xAE26, "send_notify_on_damaged_by_player" },
    { 0xAE27, "send_notify_on_killed_by_player" },
    { 0xAE28, "send_notify_to_groups_from_groupname" },
    { 0xAE29, "send_out_convoy_towards_exit" },
    { 0xAE2A, "send_players_to_floor" },
    { 0xAE2B, "send_riders_to_proper_combat_spot" },
    { 0xAE2C, "send_right_flank_goto" },
    { 0xAE2D, "send_running_if_player_skipped_farah_ceiling_scene" },
    { 0xAE2E, "send_to_goal_open_goalradius" },
    { 0xAE2F, "sendafksquadmembertogulag" },
    { 0xAE30, "sendcodcastermatchdata" },
    { 0xAE31, "senddelayedevent" },
    { 0xAE32, "sendgameendedfrozennotify" },
    { 0xAE33, "sendmissiontelemetry" },
    { 0xAE34, "sendout_notify_of_vehicle_kill" },
    { 0xAE35, "sendplayerstatusmessage" },
    { 0xAE36, "sendsuperpointstoui" },
    { 0xAE37, "sendwinnerresultstoclients" },
    { 0xAE38, "sendzombiehorde" },
    { 0xAE39, "sensor" },
    { 0xAE3A, "sentientaddedtime" },
    { 0xAE3B, "sentientdisabled" },
    { 0xAE3C, "sentientpool" },
    { 0xAE3D, "sentientpoolindex" },
    { 0xAE3E, "sentientpools" },
    { 0xAE3F, "sentientteam" },
    { 0xAE40, "sentry_attacktargets" },
    { 0xAE41, "sentry_beepsounds" },
    { 0xAE42, "sentry_burstfirestart" },
    { 0xAE43, "sentry_burstfirestop" },
    { 0xAE44, "sentry_clearteamheadicon" },
    { 0xAE45, "sentry_deleteturret" },
    { 0xAE46, "sentry_destroyongameend" },
    { 0xAE47, "sentry_empcleared" },
    { 0xAE48, "sentry_empstarted" },
    { 0xAE49, "sentry_handlealteratepickup" },
    { 0xAE4A, "sentry_handledamage" },
    { 0xAE4B, "sentry_handledeath" },
    { 0xAE4C, "sentry_handlemanualuse" },
    { 0xAE4D, "sentry_handleownerdisconnect" },
    { 0xAE4E, "sentry_handleuse" },
    { 0xAE4F, "sentry_heatmonitor" },
    { 0xAE50, "sentry_initsentry" },
    { 0xAE51, "sentry_laser_burstfirestart" },
    { 0xAE52, "sentry_makenotsolid" },
    { 0xAE53, "sentry_makesolid" },
    { 0xAE54, "sentry_moving_platform_death" },
    { 0xAE55, "sentry_oncarrierchangedteam" },
    { 0xAE56, "sentry_oncarrierdeathoremp" },
    { 0xAE57, "sentry_oncarrierdisconnect" },
    { 0xAE58, "sentry_ongameended" },
    { 0xAE59, "sentry_place_delay" },
    { 0xAE5A, "sentry_setactive" },
    { 0xAE5B, "sentry_setcancelled" },
    { 0xAE5C, "sentry_setcarried" },
    { 0xAE5D, "sentry_setinactive" },
    { 0xAE5E, "sentry_setowner" },
    { 0xAE5F, "sentry_setplaced" },
    { 0xAE60, "sentry_setteamheadicon" },
    { 0xAE61, "sentry_spindown" },
    { 0xAE62, "sentry_spinup" },
    { 0xAE63, "sentry_targetlocksound" },
    { 0xAE64, "sentry_timeout" },
    { 0xAE65, "sentry_watchownerstatus" },
    { 0xAE66, "sentrygun" },
    { 0xAE67, "sentryhandledeathdamage" },
    { 0xAE68, "sentrymodeoff" },
    { 0xAE69, "sentrymodeon" },
    { 0xAE6A, "sentrymodifydamage" },
    { 0xAE6B, "sentrysettings" },
    { 0xAE6C, "sentryshocksamtarget" },
    { 0xAE6D, "sentryshocktargetent" },
    { 0xAE6E, "sentryshocktargets" },
    { 0xAE6F, "sentryturret_create" },
    { 0xAE70, "sentryturret_createhintobject" },
    { 0xAE71, "sentryturret_delaydeletemarker" },
    { 0xAE72, "sentryturret_delayplacementinstructions" },
    { 0xAE73, "sentryturret_delayscriptabledelete" },
    { 0xAE74, "sentryturret_disableplayerdismantleonconnect" },
    { 0xAE75, "sentryturret_disableplayerpickuponconnect" },
    { 0xAE76, "sentryturret_disableplayeruseonconnect" },
    { 0xAE77, "sentryturret_empcleared" },
    { 0xAE78, "sentryturret_empstarted" },
    { 0xAE79, "sentryturret_empupdate" },
    { 0xAE7A, "sentryturret_gettargetmarker" },
    { 0xAE7B, "sentryturret_handledeathdamage" },
    { 0xAE7C, "sentryturret_initsentrysettings" },
    { 0xAE7D, "sentryturret_laststandwatcher" },
    { 0xAE7E, "sentryturret_modifydamage" },
    { 0xAE7F, "sentryturret_monitordamage" },
    { 0xAE80, "sentryturret_munitionused" },
    { 0xAE81, "sentryturret_revivedwatcher" },
    { 0xAE82, "sentryturret_setcarried" },
    { 0xAE83, "sentryturret_setinactive" },
    { 0xAE84, "sentryturret_setplaced" },
    { 0xAE85, "sentryturret_setturretmodel" },
    { 0xAE86, "sentryturret_switchbacklastweapon" },
    { 0xAE87, "sentryturret_watchdamage" },
    { 0xAE88, "sentryturret_watchdeath" },
    { 0xAE89, "sentryturret_watchdismantle" },
    { 0xAE8A, "sentryturret_watchdisown" },
    { 0xAE8B, "sentryturret_watchpickup" },
    { 0xAE8C, "sentryturret_watchplacement" },
    { 0xAE8D, "sentryturret_watchtimeout" },
    { 0xAE8E, "sentrytype" },
    { 0xAE8F, "sequence_locked" },
    { 0xAE90, "sequence_operator" },
    { 0xAE91, "sequence_succeed_fail_think" },
    { 0xAE92, "sequencename" },
    { 0xAE93, "sequencetype" },
    { 0xAE94, "sequential" },
    { 0xAE95, "sequential_loop_padding" },
    { 0xAE96, "sequential_scene" },
    { 0xAE97, "sequential_wait_time" },
    { 0xAE98, "server_culled_sounds" },
    { 0xAE99, "session_stats_init" },
    { 0xAE9A, "set" },
    { 0xAE9B, "set_accuracy_at_dist" },
    { 0xAE9C, "set_accuracy_based_on_situation" },
    { 0xAE9D, "set_active_camera" },
    { 0xAE9E, "set_agent_health" },
    { 0xAE9F, "set_agent_model" },
    { 0xAEA0, "set_agent_spawn_health" },
    { 0xAEA1, "set_agent_species" },
    { 0xAEA2, "set_agent_team" },
    { 0xAEA3, "set_agent_traversal_unit_type" },
    { 0xAEA4, "set_aggro_flag_on_enter_combat" },
    { 0xAEA5, "set_ai_bcvoice" },
    { 0xAEA6, "set_ai_number" },
    { 0xAEA7, "set_aim_and_turn_limits" },
    { 0xAEA8, "set_aim_target" },
    { 0xAEA9, "set_alert_level" },
    { 0xAEAA, "set_alien_damage_by_weapon_type" },
    { 0xAEAB, "set_alien_emissive" },
    { 0xAEAC, "set_aliensession_stat" },
    { 0xAEAD, "set_all_exceptions" },
    { 0xAEAE, "set_all_reaction_states" },
    { 0xAEAF, "set_allowdeath" },
    { 0xAEB0, "set_ally_movement_courtyard" },
    { 0xAEB1, "set_ally_movement_pre_breach" },
    { 0xAEB2, "set_ambient_max_count" },
    { 0xAEB3, "set_ambient_min_count" },
    { 0xAEB4, "set_ambush_sidestep_anims" },
    { 0xAEB5, "set_amount_cars_to_compromise" },
    { 0xAEB6, "set_anglemod_move_vector" },
    { 0xAEB7, "set_anim_playback_rate" },
    { 0xAEB8, "set_anim_pos" },
    { 0xAEB9, "set_anim_state" },
    { 0xAEBA, "set_animarray_add_turn_aims_crouch" },
    { 0xAEBB, "set_animarray_add_turn_aims_stand" },
    { 0xAEBC, "set_animarray_burst_and_semi_fire_crouch" },
    { 0xAEBD, "set_animarray_burst_and_semi_fire_stand" },
    { 0xAEBE, "set_animarray_crouching" },
    { 0xAEBF, "set_animarray_crouching_turns" },
    { 0xAEC0, "set_animarray_custom_burst_and_semi_fire_crouch" },
    { 0xAEC1, "set_animarray_custom_burst_and_semi_fire_stand" },
    { 0xAEC2, "set_animarray_prone" },
    { 0xAEC3, "set_animarray_stance_change" },
    { 0xAEC4, "set_animarray_standing" },
    { 0xAEC5, "set_animarray_standing_turns" },
    { 0xAEC6, "set_animarray_standing_turns_pistol" },
    { 0xAEC7, "set_animsets" },
    { 0xAEC8, "set_apache_desc_delay" },
    { 0xAEC9, "set_apply_emp_callback" },
    { 0xAECA, "set_archetype" },
    { 0xAECB, "set_armor" },
    { 0xAECC, "set_armor_vest_amount" },
    { 0xAECD, "set_arrival_speed" },
    { 0xAECE, "set_as_innocent" },
    { 0xAECF, "set_attach_objective_icon" },
    { 0xAED0, "set_attached_models" },
    { 0xAED1, "set_attachment_mod_damage_data" },
    { 0xAED2, "set_attachment_mod_damage_data_for_vehicle" },
    { 0xAED3, "set_attackeraccuracy" },
    { 0xAED4, "set_attackeraccuracy_handler" },
    { 0xAED5, "set_audio_level_fade_time" },
    { 0xAED6, "set_axis_model" },
    { 0xAED7, "set_backyard_objective" },
    { 0xAED8, "set_baseaccuracy" },
    { 0xAED9, "set_battlechatter" },
    { 0xAEDA, "set_battlechatter_reaction_alias" },
    { 0xAEDB, "set_battlechatter_variable" },
    { 0xAEDC, "set_blind" },
    { 0xAEDD, "set_bloody_model" },
    { 0xAEDE, "set_blur" },
    { 0xAEDF, "set_blur_safe" },
    { 0xAEE0, "set_bounding_overwatch" },
    { 0xAEE1, "set_brakes" },
    { 0xAEE2, "set_building_hostage_id" },
    { 0xAEE3, "set_cam" },
    { 0xAEE4, "set_can_compromise_before_1st_target" },
    { 0xAEE5, "set_can_update_player_armor_model" },
    { 0xAEE6, "set_cautious_navigation" },
    { 0xAEE7, "set_center_compromises" },
    { 0xAEE8, "set_center_hull_invulnerable" },
    { 0xAEE9, "set_character_models" },
    { 0xAEEA, "set_cinematicmotionomnvaroverrides" },
    { 0xAEEB, "set_cinematicmotionomnvarovertime" },
    { 0xAEEC, "set_class_playerdata" },
    { 0xAEED, "set_clear_emp_callback" },
    { 0xAEEE, "set_completed_quest_mark" },
    { 0xAEEF, "set_compromise_megahealth" },
    { 0xAEF0, "set_consumable" },
    { 0xAEF1, "set_controlled" },
    { 0xAEF2, "set_convoy_durations_modifier" },
    { 0xAEF3, "set_convoy_lookahead_dist" },
    { 0xAEF4, "set_convoy_path_from_helidown" },
    { 0xAEF5, "set_convoy_settings" },
    { 0xAEF6, "set_convoy_target" },
    { 0xAEF7, "set_convoy_targeted_hvt" },
    { 0xAEF8, "set_convoy_vehicle_speed" },
    { 0xAEF9, "set_cop_free" },
    { 0xAEFA, "set_corpse_entity" },
    { 0xAEFB, "set_corpse_ignore" },
    { 0xAEFC, "set_corpse_ranges" },
    { 0xAEFD, "set_corpse_ranges_default" },
    { 0xAEFE, "set_count" },
    { 0xAEFF, "set_count_based_on_grouped_modules" },
    { 0xAF00, "set_crafted_inventory_item" },
    { 0xAF01, "set_createfx_enabled" },
    { 0xAF02, "set_cs_file_dvar" },
    { 0xAF03, "set_ctf_role" },
    { 0xAF04, "set_current_health_regen_segment" },
    { 0xAF05, "set_current_node" },
    { 0xAF06, "set_current_reaper_camera_zoom_level" },
    { 0xAF07, "set_current_stealth_state" },
    { 0xAF08, "set_custom_death_quote" },
    { 0xAF09, "set_custom_distances" },
    { 0xAF0A, "set_custom_stats" },
    { 0xAF0B, "set_death_callback" },
    { 0xAF0C, "set_death_hint" },
    { 0xAF0D, "set_death_hint_standard" },
    { 0xAF0E, "set_death_icon" },
    { 0xAF0F, "set_deathanim" },
    { 0xAF10, "set_deathanim_bed_death" },
    { 0xAF11, "set_deathsdoor" },
    { 0xAF12, "set_debug_models" },
    { 0xAF13, "set_default_aim_limits" },
    { 0xAF14, "set_default_ar_values" },
    { 0xAF15, "set_default_pathenemy_settings" },
    { 0xAF16, "set_default_patrol_style" },
    { 0xAF17, "set_default_patrol_values" },
    { 0xAF18, "set_default_rpg_values" },
    { 0xAF19, "set_default_settings" },
    { 0xAF1A, "set_default_sniper_values" },
    { 0xAF1B, "set_default_soldier_values" },
    { 0xAF1C, "set_default_spawner_values" },
    { 0xAF1D, "set_default_start" },
    { 0xAF1E, "set_default_start_alt" },
    { 0xAF1F, "set_default_stealth_funcs" },
    { 0xAF20, "set_default_values" },
    { 0xAF21, "set_default_vip_hints" },
    { 0xAF22, "set_demeanor" },
    { 0xAF23, "set_demeanor_code_think" },
    { 0xAF24, "set_demeanor_for_duration" },
    { 0xAF25, "set_demeanor_from_unittype" },
    { 0xAF26, "set_demeanor_func" },
    { 0xAF27, "set_despawn_at_distance" },
    { 0xAF28, "set_despawn_at_farz" },
    { 0xAF29, "set_despawn_distance" },
    { 0xAF2A, "set_detect_ranges" },
    { 0xAF2B, "set_detect_ranges_internal" },
    { 0xAF2C, "set_dialogue_on_cooldown" },
    { 0xAF2D, "set_difficulty_from_locked_settings" },
    { 0xAF2E, "set_disguised" },
    { 0xAF2F, "set_disguised_default" },
    { 0xAF30, "set_do_arrivals" },
    { 0xAF31, "set_do_exits" },
    { 0xAF32, "set_dog_walk_anim" },
    { 0xAF33, "set_dont_enter_combat_flag" },
    { 0xAF34, "set_dontkilloff_flag" },
    { 0xAF35, "set_dontmelee" },
    { 0xAF36, "set_door_state" },
    { 0xAF37, "set_doublejumpenergy" },
    { 0xAF38, "set_doublejumpenergyrestorerate" },
    { 0xAF39, "set_early_level" },
    { 0xAF3A, "set_emp_damage_callback" },
    { 0xAF3B, "set_empty_promotion_order" },
    { 0xAF3C, "set_enemy_low_health" },
    { 0xAF3D, "set_enter_function" },
    { 0xAF3E, "set_entity_count_hud" },
    { 0xAF3F, "set_escort_phase" },
    { 0xAF40, "set_escort_player_pitch_bounds" },
    { 0xAF41, "set_event_distances" },
    { 0xAF42, "set_event_override" },
    { 0xAF43, "set_exception" },
    { 0xAF44, "set_extra_xp" },
    { 0xAF45, "set_favoriteenemy" },
    { 0xAF46, "set_firing" },
    { 0xAF47, "set_first_wave_override" },
    { 0xAF48, "set_fixednode_false" },
    { 0xAF49, "set_fixednode_true" },
    { 0xAF4A, "set_flag_on_dead" },
    { 0xAF4B, "set_flag_on_dead_or_dying" },
    { 0xAF4C, "set_flag_on_death" },
    { 0xAF4D, "set_flag_on_death_or_damage" },
    { 0xAF4E, "set_flag_on_func_wait_proc" },
    { 0xAF4F, "set_flag_on_spawned" },
    { 0xAF50, "set_flag_on_spawned_ai_proc" },
    { 0xAF51, "set_flag_on_targetname_trigger" },
    { 0xAF52, "set_flag_on_trigger" },
    { 0xAF53, "set_flag_spawned" },
    { 0xAF54, "set_flag_when_dead" },
    { 0xAF55, "set_flag_when_rpg_picked_up" },
    { 0xAF56, "set_flavorbursts" },
    { 0xAF57, "set_flavorbursts_team_state" },
    { 0xAF58, "set_flinch_values" },
    { 0xAF59, "set_focus_infinite_hold" },
    { 0xAF5A, "set_focus_objectives_update_display" },
    { 0xAF5B, "set_force_armor_drop" },
    { 0xAF5C, "set_force_color" },
    { 0xAF5D, "set_force_color_spawner" },
    { 0xAF5E, "set_force_cover" },
    { 0xAF5F, "set_force_sprint" },
    { 0xAF60, "set_forcedgoal" },
    { 0xAF61, "set_forcegoal" },
    { 0xAF62, "set_forward_and_up_vectors" },
    { 0xAF63, "set_frantic" },
    { 0xAF64, "set_friendlyfire_warnings" },
    { 0xAF65, "set_friendname" },
    { 0xAF66, "set_front_door_light_enable_disable" },
    { 0xAF67, "set_func" },
    { 0xAF68, "set_fx_hudelement" },
    { 0xAF69, "set_game_data" },
    { 0xAF6A, "set_gameskill" },
    { 0xAF6B, "set_generic_deathanim" },
    { 0xAF6C, "set_generic_idle_anim" },
    { 0xAF6D, "set_generic_run_anim" },
    { 0xAF6E, "set_generic_run_anim_array" },
    { 0xAF6F, "set_goal_and_volume" },
    { 0xAF70, "set_goal_ent" },
    { 0xAF71, "set_goal_entity" },
    { 0xAF72, "set_goal_from_settings" },
    { 0xAF73, "set_goal_height_from_settings" },
    { 0xAF74, "set_goal_node" },
    { 0xAF75, "set_goal_node_and_poi" },
    { 0xAF76, "set_goal_node_targetname" },
    { 0xAF77, "set_goal_pos" },
    { 0xAF78, "set_goal_pos_check_for_offset" },
    { 0xAF79, "set_goal_pos_to_center_of_nearby_ai" },
    { 0xAF7A, "set_goal_radius" },
    { 0xAF7B, "set_goal_volume" },
    { 0xAF7C, "set_goal_volume_for_all" },
    { 0xAF7D, "set_goal_volume_for_substr" },
    { 0xAF7E, "set_goalradius" },
    { 0xAF7F, "set_gravity" },
    { 0xAF80, "set_green_beam_demeanor" },
    { 0xAF81, "set_grenadeammo" },
    { 0xAF82, "set_grenadeweapon" },
    { 0xAF83, "set_group_advance_to_enemy_parameters" },
    { 0xAF84, "set_gunpose" },
    { 0xAF85, "set_has_seen_perm_tutorial" },
    { 0xAF86, "set_has_seen_tutorial" },
    { 0xAF87, "set_headshot_ammo" },
    { 0xAF88, "set_headshot_super" },
    { 0xAF89, "set_healthdrain_on_lowhealth" },
    { 0xAF8A, "set_hide_icon_on_pickup_target" },
    { 0xAF8B, "set_high_priority_target_for_bot" },
    { 0xAF8C, "set_hostage_aliases" },
    { 0xAF8D, "set_hud_element" },
    { 0xAF8E, "set_hudelem" },
    { 0xAF8F, "set_hudoutline" },
    { 0xAF90, "set_hvt_gone_flag" },
    { 0xAF91, "set_hvt_label" },
    { 0xAF92, "set_hvt_label_life" },
    { 0xAF93, "set_idle_anim" },
    { 0xAF94, "set_idle_anim_override" },
    { 0xAF95, "set_ied_scanned_flag_from_ied_controller" },
    { 0xAF96, "set_if_undefined" },
    { 0xAF97, "set_ignore_claimed" },
    { 0xAF98, "set_ignoreall" },
    { 0xAF99, "set_ignoreme" },
    { 0xAF9A, "set_ignoreme_after_time" },
    { 0xAF9B, "set_ignoresuppression" },
    { 0xAF9C, "set_initial_rush_goal" },
    { 0xAF9D, "set_interaction_point" },
    { 0xAF9E, "set_interaction_trigger_properties" },
    { 0xAF9F, "set_interceptor_missile_target" },
    { 0xAFA0, "set_is_playing_pain_breathing_sfx" },
    { 0xAFA1, "set_join_in_progress" },
    { 0xAFA2, "set_juggernaut_flags" },
    { 0xAFA3, "set_kill_off_time" },
    { 0xAFA4, "set_kill_off_vars" },
    { 0xAFA5, "set_kill_trigger_event_processed" },
    { 0xAFA6, "set_last_spawn_time" },
    { 0xAFA7, "set_last_stand_count" },
    { 0xAFA8, "set_last_stand_timer" },
    { 0xAFA9, "set_laststand_stats" },
    { 0xAFAA, "set_level_score_callback_func" },
    { 0xAFAB, "set_level_score_data" },
    { 0xAFAC, "set_light_parts_off" },
    { 0xAFAD, "set_light_parts_on" },
    { 0xAFAE, "set_light_values_by_frac" },
    { 0xAFAF, "set_lightbar" },
    { 0xAFB0, "set_lightbar_color" },
    { 0xAFB1, "set_lightbar_endon_death" },
    { 0xAFB2, "set_lightbar_for_time" },
    { 0xAFB3, "set_lightbar_for_time_endon_death" },
    { 0xAFB4, "set_lightbar_off" },
    { 0xAFB5, "set_lightbar_on" },
    { 0xAFB6, "set_lightbar_perm" },
    { 0xAFB7, "set_lightbar_perm_endon_death" },
    { 0xAFB8, "set_lightbar_pulse_time" },
    { 0xAFB9, "set_lighting_dvars" },
    { 0xAFBA, "set_lights_internal" },
    { 0xAFBB, "set_lights_values" },
    { 0xAFBC, "set_loaded_when_full" },
    { 0xAFBD, "set_lookat_from_dest" },
    { 0xAFBE, "set_lookat_point" },
    { 0xAFBF, "set_lua_encounter_score_row" },
    { 0xAFC0, "set_lua_eog_score_row" },
    { 0xAFC1, "set_matrix_from_up" },
    { 0xAFC2, "set_matrix_from_up_and_angles" },
    { 0xAFC3, "set_maxfaceenemydist" },
    { 0xAFC4, "set_maxsightdistsquared" },
    { 0xAFC5, "set_maxvisibledist" },
    { 0xAFC6, "set_menu_hudelem" },
    { 0xAFC7, "set_min_detect_range_darkness" },
    { 0xAFC8, "set_mission_failed_override" },
    { 0xAFC9, "set_mode" },
    { 0xAFCA, "set_monitor_script_noteworthy" },
    { 0xAFCB, "set_move_anim" },
    { 0xAFCC, "set_movement_speed" },
    { 0xAFCD, "set_moveplaybackrate" },
    { 0xAFCE, "set_moverate_along_dir" },
    { 0xAFCF, "set_nearby_console" },
    { 0xAFD0, "set_nerf_scalar" },
    { 0xAFD1, "set_new_bomber" },
    { 0xAFD2, "set_new_goal_vol" },
    { 0xAFD3, "set_next_can_take_sniper_damage_time_stamp" },
    { 0xAFD4, "set_normalhealth" },
    { 0xAFD5, "set_notify_handlers" },
    { 0xAFD6, "set_nvg_bool" },
    { 0xAFD7, "set_nvg_flir" },
    { 0xAFD8, "set_nvg_flir_proc" },
    { 0xAFD9, "set_nvg_light" },
    { 0xAFDA, "set_nvg_light_proc" },
    { 0xAFDB, "set_nvg_vision" },
    { 0xAFDC, "set_nvg_vision_proc" },
    { 0xAFDD, "set_objective" },
    { 0xAFDE, "set_objective_icon_label" },
    { 0xAFDF, "set_objective_struct" },
    { 0xAFE0, "set_off_exploders" },
    { 0xAFE1, "set_off_hostage_bomb" },
    { 0xAFE2, "set_off_storage_propane_tanks" },
    { 0xAFE3, "set_office_speeds" },
    { 0xAFE4, "set_option_index" },
    { 0xAFE5, "set_origin_and_angles" },
    { 0xAFE6, "set_original_baseaccuracy" },
    { 0xAFE7, "set_outline" },
    { 0xAFE8, "set_outline_for_player" },
    { 0xAFE9, "set_outline_passive_minimap_damage" },
    { 0xAFEA, "set_pacifist" },
    { 0xAFEB, "set_passive_below_the_belt" },
    { 0xAFEC, "set_passive_berserk" },
    { 0xAFED, "set_passive_cold_damage" },
    { 0xAFEE, "set_passive_crouch_move_speed" },
    { 0xAFEF, "set_passive_double_kill_reload" },
    { 0xAFF0, "set_passive_double_kill_super" },
    { 0xAFF1, "set_passive_empty_reload_speed" },
    { 0xAFF2, "set_passive_fast_melee" },
    { 0xAFF3, "set_passive_fortified" },
    { 0xAFF4, "set_passive_gore" },
    { 0xAFF5, "set_passive_health_on_kill" },
    { 0xAFF6, "set_passive_health_regen_on_kill" },
    { 0xAFF7, "set_passive_hitman" },
    { 0xAFF8, "set_passive_hunter_killer" },
    { 0xAFF9, "set_passive_increased_scope_breath" },
    { 0xAFFA, "set_passive_infinite_ammo" },
    { 0xAFFB, "set_passive_jump_super" },
    { 0xAFFC, "set_passive_last_shots_ammo" },
    { 0xAFFD, "set_passive_melee_cone_expl" },
    { 0xAFFE, "set_passive_melee_kill" },
    { 0xAFFF, "set_passive_melee_super" },
    { 0xB000, "set_passive_minimap_damage" },
    { 0xB001, "set_passive_miss_refund" },
    { 0xB002, "set_passive_mode_switch_score" },
    { 0xB003, "set_passive_move_speed" },
    { 0xB004, "set_passive_move_speed_on_kill" },
    { 0xB005, "set_passive_ninja" },
    { 0xB006, "set_passive_nuke" },
    { 0xB007, "set_passive_railgun_overload" },
    { 0xB008, "set_passive_random_attachment" },
    { 0xB009, "set_passive_random_perks" },
    { 0xB00A, "set_passive_refresh" },
    { 0xB00B, "set_passive_scope_radar" },
    { 0xB00C, "set_passive_score_bonus_kills" },
    { 0xB00D, "set_passive_scorestreak_damage" },
    { 0xB00E, "set_passive_scoutping" },
    { 0xB00F, "set_passive_scrambler" },
    { 0xB010, "set_passive_sonic" },
    { 0xB011, "set_passive_spawn_window_time" },
    { 0xB012, "set_passive_visor_detonation" },
    { 0xB013, "set_passive_wave_high_threshold" },
    { 0xB014, "set_passive_wave_low_threshold" },
    { 0xB015, "set_passive_wave_spawn_time" },
    { 0xB016, "set_path_dist" },
    { 0xB017, "set_path_jitter" },
    { 0xB018, "set_patrol_move_loop_anim" },
    { 0xB019, "set_patrol_react" },
    { 0xB01A, "set_patrol_style" },
    { 0xB01B, "set_perk" },
    { 0xB01C, "set_perk_mod_damage_data" },
    { 0xB01D, "set_perk_mod_damage_data_for_vehicle" },
    { 0xB01E, "set_permanent_notify_handlers" },
    { 0xB01F, "set_pistol_interactable_before_anim" },
    { 0xB020, "set_pivot_point" },
    { 0xB021, "set_player_angles_inside_plane" },
    { 0xB022, "set_player_attacker_accuracy" },
    { 0xB023, "set_player_consumables" },
    { 0xB024, "set_player_count" },
    { 0xB025, "set_player_currency" },
    { 0xB026, "set_player_data" },
    { 0xB027, "set_player_demeanor" },
    { 0xB028, "set_player_game_data" },
    { 0xB029, "set_player_health_fragile" },
    { 0xB02A, "set_player_health_semifragile" },
    { 0xB02B, "set_player_health_standard" },
    { 0xB02C, "set_player_ignore_random_bullet_damage" },
    { 0xB02D, "set_player_is_pushing_vehicle" },
    { 0xB02E, "set_player_ladder_weapon" },
    { 0xB02F, "set_player_max_currency" },
    { 0xB030, "set_player_max_health" },
    { 0xB031, "set_player_optimal_speed" },
    { 0xB032, "set_player_perks" },
    { 0xB033, "set_player_photo_option" },
    { 0xB034, "set_player_photo_status" },
    { 0xB035, "set_player_playing_as_terrorist_omnvar" },
    { 0xB036, "set_player_prestige" },
    { 0xB037, "set_player_rank" },
    { 0xB038, "set_player_rig_allows" },
    { 0xB039, "set_player_session_rankup" },
    { 0xB03A, "set_player_session_tokens" },
    { 0xB03B, "set_player_session_xp" },
    { 0xB03C, "set_player_set_rig_allows" },
    { 0xB03D, "set_player_side" },
    { 0xB03E, "set_player_speed_hud" },
    { 0xB03F, "set_player_stealthed" },
    { 0xB040, "set_player_viewmodel" },
    { 0xB041, "set_player_xp" },
    { 0xB042, "set_poiauto_constraints" },
    { 0xB043, "set_pos" },
    { 0xB044, "set_post_mod_damage_callback" },
    { 0xB045, "set_pre_mod_damage_callback" },
    { 0xB046, "set_pre_wave_spawning_spawn_funcs" },
    { 0xB047, "set_prevguy" },
    { 0xB048, "set_progress_to_zero_on_death" },
    { 0xB049, "set_promotion_order" },
    { 0xB04A, "set_properties_based_on_state" },
    { 0xB04B, "set_props_spawned" },
    { 0xB04C, "set_proto_values" },
    { 0xB04D, "set_provide_cover_fire" },
    { 0xB04E, "set_pvpve_weapon_interaction_func" },
    { 0xB04F, "set_quest_icon" },
    { 0xB050, "set_quest_icon_internal" },
    { 0xB051, "set_raid_checkpoint" },
    { 0xB052, "set_reaction_state" },
    { 0xB053, "set_real_fire" },
    { 0xB054, "set_rebel" },
    { 0xB055, "set_recent_pain" },
    { 0xB056, "set_recruited_goal_distance" },
    { 0xB057, "set_recruiting_amount" },
    { 0xB058, "set_recruiting_distance" },
    { 0xB059, "set_recruiting_time_btwn" },
    { 0xB05A, "set_recruiting_time_until" },
    { 0xB05B, "set_relic_boom" },
    { 0xB05C, "set_relic_catch" },
    { 0xB05D, "set_relic_collat_dmg" },
    { 0xB05E, "set_relic_glasscannon" },
    { 0xB05F, "set_relic_icon_omnvar" },
    { 0xB060, "set_relic_swat" },
    { 0xB061, "set_relics" },
    { 0xB062, "set_remove_emp_callback" },
    { 0xB063, "set_repair_omnvars" },
    { 0xB064, "set_revive_icon_color" },
    { 0xB065, "set_revive_time" },
    { 0xB066, "set_riders_target" },
    { 0xB067, "set_roaming" },
    { 0xB068, "set_root" },
    { 0xB069, "set_rumble_intensity" },
    { 0xB06A, "set_run_anim" },
    { 0xB06B, "set_run_anim_array" },
    { 0xB06C, "set_run_anim_override" },
    { 0xB06D, "set_score_fraction_to_hero_team" },
    { 0xB06E, "set_screens_to_red" },
    { 0xB06F, "set_script_count_on_spawns" },
    { 0xB070, "set_script_origin_other_for_group" },
    { 0xB071, "set_script_origin_other_on_ai" },
    { 0xB072, "set_script_origin_other_to_center_of_players" },
    { 0xB073, "set_scriptablepartinfo" },
    { 0xB074, "set_scriptablepartstate" },
    { 0xB075, "set_scripted_node_angles" },
    { 0xB076, "set_scripted_pathing_style" },
    { 0xB077, "set_scripthud" },
    { 0xB078, "set_segmented_health_regen_parameters" },
    { 0xB079, "set_sequential_wait_time" },
    { 0xB07A, "set_sight_state" },
    { 0xB07B, "set_single_value_stats" },
    { 0xB07C, "set_skipdeathanim" },
    { 0xB07D, "set_slowmo_dialogue_end" },
    { 0xB07E, "set_slowmo_dialogue_start" },
    { 0xB07F, "set_slowmo_sniper_breath_end" },
    { 0xB080, "set_slowmo_sniper_breath_start" },
    { 0xB081, "set_smuggler_crash_loc" },
    { 0xB082, "set_snake_cam_ignore_ents" },
    { 0xB083, "set_snake_cam_vision" },
    { 0xB084, "set_snap_to_head" },
    { 0xB085, "set_soldier_backup_deposit_names" },
    { 0xB086, "set_soldier_pickup_to_origin" },
    { 0xB087, "set_spawn_loc" },
    { 0xB088, "set_spawn_scoring_params_for_group" },
    { 0xB089, "set_spawn_values" },
    { 0xB08A, "set_spawner_chosen_nearby" },
    { 0xB08B, "set_spawner_init_flag" },
    { 0xB08C, "set_split_screen" },
    { 0xB08D, "set_sprint" },
    { 0xB08E, "set_start_emp_callback" },
    { 0xB08F, "set_start_location" },
    { 0xB090, "set_start_location_by_animname" },
    { 0xB091, "set_start_pos" },
    { 0xB092, "set_start_positions" },
    { 0xB093, "set_stat_dvars" },
    { 0xB094, "set_stayahead_values" },
    { 0xB095, "set_stayahead_wait_func" },
    { 0xB096, "set_stayahead_wait_nodes" },
    { 0xB097, "set_stayahead_wait_values" },
    { 0xB098, "set_stealth_func" },
    { 0xB099, "set_stealth_guy_to_combat" },
    { 0xB09A, "set_stealth_meter_progress" },
    { 0xB09B, "set_stealth_mode" },
    { 0xB09C, "set_stealth_mode_sp" },
    { 0xB09D, "set_stealth_state" },
    { 0xB09E, "set_stealth_values" },
    { 0xB09F, "set_stop_all_cars" },
    { 0xB0A0, "set_sun_disable" },
    { 0xB0A1, "set_sun_enable" },
    { 0xB0A2, "set_sun_enable_disable" },
    { 0xB0A3, "set_sun_shadow_params" },
    { 0xB0A4, "set_suspend_at_end_path" },
    { 0xB0A5, "set_talker_until_msg" },
    { 0xB0A6, "set_target_entity" },
    { 0xB0A7, "set_target_in_view" },
    { 0xB0A8, "set_team_allies" },
    { 0xB0A9, "set_team_axis" },
    { 0xB0AA, "set_team_bcvoice" },
    { 0xB0AB, "set_team_pacifist" },
    { 0xB0AC, "set_team_score_for_players" },
    { 0xB0AD, "set_temp_energy_rest_time" },
    { 0xB0AE, "set_temp_energy_restore_rate" },
    { 0xB0AF, "set_throttle_zero" },
    { 0xB0B0, "set_time_via_rate" },
    { 0xB0B1, "set_timescale" },
    { 0xB0B2, "set_tires_desc" },
    { 0xB0B3, "set_to_combat_speed" },
    { 0xB0B4, "set_to_max_escalation" },
    { 0xB0B5, "set_to_min_escalation" },
    { 0xB0B6, "set_tool_hudelem" },
    { 0xB0B7, "set_train_lighting_disable" },
    { 0xB0B8, "set_train_lighting_enable" },
    { 0xB0B9, "set_train_moment_shadows" },
    { 0xB0BA, "set_trigger_flag_permissions" },
    { 0xB0BB, "set_turret_owner_to_riders" },
    { 0xB0BC, "set_turret_settings_from_model" },
    { 0xB0BD, "set_turret_settings_from_weapon" },
    { 0xB0BE, "set_turret_target_loc" },
    { 0xB0BF, "set_turret_team" },
    { 0xB0C0, "set_tv_script_noteworthy" },
    { 0xB0C1, "set_uav_radarstrength" },
    { 0xB0C2, "set_unload_at_target" },
    { 0xB0C3, "set_up_blockade_gates" },
    { 0xB0C4, "set_up_bomb_for_pick_up" },
    { 0xB0C5, "set_up_bomb_model_marker" },
    { 0xB0C6, "set_up_concrete_blockers" },
    { 0xB0C7, "set_up_fake_character_models" },
    { 0xB0C8, "set_up_fx" },
    { 0xB0C9, "set_up_gate_door" },
    { 0xB0CA, "set_up_ied_triggering_tags" },
    { 0xB0CB, "set_up_ieds" },
    { 0xB0CC, "set_up_modular_spawning" },
    { 0xB0CD, "set_up_placing_bomb_interactions" },
    { 0xB0CE, "set_up_pvpe_callback" },
    { 0xB0CF, "set_up_sight_blockers" },
    { 0xB0D0, "set_up_sniper_rifle_pickups" },
    { 0xB0D1, "set_up_suicide_bomber_call_back" },
    { 0xB0D2, "set_up_team_score" },
    { 0xB0D3, "set_up_vehicle_interactions" },
    { 0xB0D4, "set_update_function" },
    { 0xB0D5, "set_use_pain" },
    { 0xB0D6, "set_use_path_speeds_modifier" },
    { 0xB0D7, "set_vehicle_anims" },
    { 0xB0D8, "set_vehicle_anims_civ" },
    { 0xB0D9, "set_vehicle_anims_police" },
    { 0xB0DA, "set_vehicle_anims_rebel" },
    { 0xB0DB, "set_vehicle_effect" },
    { 0xB0DC, "set_vehicle_hit_damage_data" },
    { 0xB0DD, "set_vehicle_hit_damage_data_for_weapon" },
    { 0xB0DE, "set_vehicle_settings_on_spawners" },
    { 0xB0DF, "set_vehicle_to_chase" },
    { 0xB0E0, "set_veil_weights" },
    { 0xB0E1, "set_viewangles" },
    { 0xB0E2, "set_vip_hints" },
    { 0xB0E3, "set_vision_naked" },
    { 0xB0E4, "set_visionset_for_watching_players" },
    { 0xB0E5, "set_vo_bucket_fills_all" },
    { 0xB0E6, "set_vo_bucket_selection" },
    { 0xB0E7, "set_vo_bucket_sequential" },
    { 0xB0E8, "set_vo_currently_playing" },
    { 0xB0E9, "set_vo_line_scale" },
    { 0xB0EA, "set_vo_line_weight" },
    { 0xB0EB, "set_vo_system_busy" },
    { 0xB0EC, "set_vo_system_playing" },
    { 0xB0ED, "set_wait_then_clear_skipbloodpool" },
    { 0xB0EE, "set_walking_speed" },
    { 0xB0EF, "set_wander_fail_volume" },
    { 0xB0F0, "set_wants_to_move" },
    { 0xB0F1, "set_wave_ref_override" },
    { 0xB0F2, "set_wave_settings" },
    { 0xB0F3, "set_wave_settings_for_all_with_groupname" },
    { 0xB0F4, "set_wave_show_hud" },
    { 0xB0F5, "set_weapon_class_mod_damage_data" },
    { 0xB0F6, "set_weapon_class_mod_damage_data_for_vehicle" },
    { 0xB0F7, "set_weapon_hit_damage_data" },
    { 0xB0F8, "set_weapon_hit_damage_data_for_vehicle" },
    { 0xB0F9, "set_weapon_interaction_string" },
    { 0xB0FA, "set_weapon_purchase_disabled" },
    { 0xB0FB, "set_weapons_free_for_all_groups" },
    { 0xB0FC, "set_wind" },
    { 0xB0FD, "set_wind_amplitude" },
    { 0xB0FE, "set_wind_area_scale" },
    { 0xB0FF, "set_wind_frequency" },
    { 0xB100, "set_wolfdoor_open_flag_on_trigger" },
    { 0xB101, "set_x" },
    { 0xB102, "set_y" },
    { 0xB103, "set_z" },
    { 0xB104, "set_zombie_awareness" },
    { 0xB105, "set3duseicon" },
    { 0xB106, "setactionslotoverrideammo" },
    { 0xB107, "setactivegrenadetimer" },
    { 0xB108, "setactivemapconfig" },
    { 0xB109, "setactivereload" },
    { 0xB10A, "setactivespawnlogic" },
    { 0xB10B, "setactivespawnquerycontext" },
    { 0xB10C, "setadsawareness" },
    { 0xB10D, "setadsmarktarget" },
    { 0xB10E, "setaffinityextralauncher" },
    { 0xB10F, "setaffinityspeedboost" },
    { 0xB110, "setafterburner" },
    { 0xB111, "setagentteam" },
    { 0xB112, "setalertedhuntmode" },
    { 0xB113, "setallunusable" },
    { 0xB114, "setallvehiclefx" },
    { 0xB115, "setalwaysminimap" },
    { 0xB116, "setambientmovespeed" },
    { 0xB117, "setammonameamount" },
    { 0xB118, "setanchorent" },
    { 0xB119, "setandremoveinvulnerability" },
    { 0xB11A, "setandunsetzombieignoreme" },
    { 0xB11B, "setanimaimweight" },
    { 0xB11C, "setanimrate_lerp" },
    { 0xB11D, "setanimrate_lerp_internal" },
    { 0xB11E, "setanimrestart_once" },
    { 0xB11F, "setanims" },
    { 0xB120, "setanims_rebel" },
    { 0xB121, "setanimtree" },
    { 0xB122, "setarenaplayerintronum" },
    { 0xB123, "setarmoramount" },
    { 0xB124, "setarmormaxamount" },
    { 0xB125, "setarmorvest" },
    { 0xB126, "setarmorvestamount" },
    { 0xB127, "setarmorvestmaxamount" },
    { 0xB128, "setassists" },
    { 0xB129, "setauraquickswap" },
    { 0xB12A, "setauraspeed" },
    { 0xB12B, "setautospot" },
    { 0xB12C, "setaxeidlescriptablestate" },
    { 0xB12D, "setaxescriptablestate" },
    { 0xB12E, "setback" },
    { 0xB12F, "setbackstreak" },
    { 0xB130, "setballcarrier" },
    { 0xB131, "setbarrier" },
    { 0xB132, "setbasearchetype" },
    { 0xB133, "setbatterypack" },
    { 0xB134, "setbattlechatter" },
    { 0xB135, "setbattleslide" },
    { 0xB136, "setbattleslideoffense" },
    { 0xB137, "setbattleslideshield" },
    { 0xB138, "setbestscore" },
    { 0xB139, "setblackbox" },
    { 0xB13A, "setblastshield" },
    { 0xB13B, "setblindeye" },
    { 0xB13C, "setblockhealthregen" },
    { 0xB13D, "setblocking" },
    { 0xB13E, "setbombdefusingomnvar" },
    { 0xB13F, "setbombplantingomnvar" },
    { 0xB140, "setbombtimeromnvars" },
    { 0xB141, "setboom" },
    { 0xB142, "setboominternal" },
    { 0xB143, "setbountyhunter" },
    { 0xB144, "setbreacher" },
    { 0xB145, "setbreachernum" },
    { 0xB146, "setbucketval" },
    { 0xB147, "setbulletoutline" },
    { 0xB148, "setbulletstorm" },
    { 0xB149, "setc130heightoverrides" },
    { 0xB14A, "setcamoclone" },
    { 0xB14B, "setcamoelite" },
    { 0xB14C, "setcanuse" },
    { 0xB14D, "setcapturebehavior" },
    { 0xB14E, "setcapturestats" },
    { 0xB14F, "setcarepackage" },
    { 0xB150, "setcarrier" },
    { 0xB151, "setcarriervisibility" },
    { 0xB152, "setcarriervisible" },
    { 0xB153, "setcarryicon" },
    { 0xB154, "setcarryingremoteuav" },
    { 0xB155, "setcarryingsentry" },
    { 0xB156, "setcharactermodels" },
    { 0xB157, "setcharmodels" },
    { 0xB158, "setcinematiccamerastyle" },
    { 0xB159, "setcinematicmotion_disabled" },
    { 0xB15A, "setcinematicmotion_heli" },
    { 0xB15B, "setcinematicmotion_omnvaroverride_max_1" },
    { 0xB15C, "setcinematicmotion_omnvaroverride_max_2" },
    { 0xB15D, "setcinematicmotion_omnvaroverride_max_3" },
    { 0xB15E, "setcinematicmotion_omnvaroverride_max_4" },
    { 0xB15F, "setcinematicmotion_omnvaroverride_max_5" },
    { 0xB160, "setcinematicmotion_omnvaroverride_max_instant" },
    { 0xB161, "setcinematicmotion_omnvaroverride_min_1" },
    { 0xB162, "setcinematicmotion_omnvaroverride_min_2" },
    { 0xB163, "setcinematicmotion_omnvaroverride_min_3" },
    { 0xB164, "setcinematicmotion_omnvaroverride_min_4" },
    { 0xB165, "setcinematicmotion_omnvaroverride_min_5" },
    { 0xB166, "setcinematicmotion_omnvaroverride_min_instant" },
    { 0xB167, "setcinematicmotion_playermotion" },
    { 0xB168, "setciviliankillcount" },
    { 0xB169, "setclaimteam" },
    { 0xB16A, "setclass" },
    { 0xB16B, "setcloak" },
    { 0xB16C, "setcloakaerial" },
    { 0xB16D, "setclosinguicircle" },
    { 0xB16E, "setcodcasterplayervalue" },
    { 0xB16F, "setcombathigh" },
    { 0xB170, "setcombatspeed" },
    { 0xB171, "setcombatspeedscalar" },
    { 0xB172, "setcomexp" },
    { 0xB173, "setcomlink" },
    { 0xB174, "setcommonrulesfrommatchrulesdata" },
    { 0xB175, "setcontestedicons" },
    { 0xB176, "setcooldown" },
    { 0xB177, "setcoopplayerdata_for_everyone" },
    { 0xB178, "setcornerstepoutsdisabled" },
    { 0xB179, "setcorpseremovetimerfuncmp" },
    { 0xB17A, "setcorpseremovetimersp" },
    { 0xB17B, "setcoverchangestanceforfuntime" },
    { 0xB17C, "setcovercrouchtype" },
    { 0xB17D, "setcoverstate" },
    { 0xB17E, "setcoverwarningcount" },
    { 0xB17F, "setcrankedbombtimer" },
    { 0xB180, "setcrankeddvarfordev" },
    { 0xB181, "setcrankedplayerbombtimer" },
    { 0xB182, "setcrankedtimerdomflag" },
    { 0xB183, "setcrankedtimerzonecap" },
    { 0xB184, "setcrawlingpaintransanim" },
    { 0xB185, "setcritchance" },
    { 0xB186, "setcurpotgscene" },
    { 0xB187, "setcurrentcustombcevent" },
    { 0xB188, "setcurrentgroup" },
    { 0xB189, "setcustomization_body" },
    { 0xB18A, "setcustomization_head" },
    { 0xB18B, "setcustomsmartobjectarrivaldata" },
    { 0xB18C, "setdamageflag" },
    { 0xB18D, "setdamagestate" },
    { 0xB18E, "setdash" },
    { 0xB18F, "setddlfieldsforplayer" },
    { 0xB190, "setdeathangles" },
    { 0xB191, "setdeathtimerlength" },
    { 0xB192, "setdefaultammoclip" },
    { 0xB193, "setdefaultcallbacks" },
    { 0xB194, "setdefaultcharacterdata" },
    { 0xB195, "setdefaultdvars" },
    { 0xB196, "setdefaultgameparameters" },
    { 0xB197, "setdefaultjiprules" },
    { 0xB198, "setdefaultleveldata" },
    { 0xB199, "setdefaultmodel" },
    { 0xB19A, "setdefaultvisionset" },
    { 0xB19B, "setdefending" },
    { 0xB19C, "setdelaymine" },
    { 0xB19D, "setdeliverymodesettings" },
    { 0xB19E, "setdemolitions" },
    { 0xB19F, "setdesiredbtaction" },
    { 0xB1A0, "setdifficulty" },
    { 0xB1A1, "setdisabled" },
    { 0xB1A2, "setdismemberstatefx" },
    { 0xB1A3, "setdisruptorpunch" },
    { 0xB1A4, "setdodge" },
    { 0xB1A5, "setdodgedefense" },
    { 0xB1A6, "setdodgewave" },
    { 0xB1A7, "setdof_ac130" },
    { 0xB1A8, "setdof_ac130_zoom" },
    { 0xB1A9, "setdof_apache" },
    { 0xB1AA, "setdof_cruisefirst" },
    { 0xB1AB, "setdof_cruisethird" },
    { 0xB1AC, "setdof_default" },
    { 0xB1AD, "setdof_dynamic" },
    { 0xB1AE, "setdof_gunship" },
    { 0xB1AF, "setdof_gunship_zoom" },
    { 0xB1B0, "setdof_infil" },
    { 0xB1B1, "setdof_killer" },
    { 0xB1B2, "setdof_killer_update" },
    { 0xB1B3, "setdof_scrambler_strength_1" },
    { 0xB1B4, "setdof_scrambler_strength_2" },
    { 0xB1B5, "setdof_scrambler_strength_3" },
    { 0xB1B6, "setdof_scrambler_strength_4" },
    { 0xB1B7, "setdof_scrambler_strength_5" },
    { 0xB1B8, "setdof_spectator" },
    { 0xB1B9, "setdof_tank" },
    { 0xB1BA, "setdof_thirdperson" },
    { 0xB1BB, "setdoftracerange" },
    { 0xB1BC, "setdomscriptablepartstate" },
    { 0xB1BD, "setdomscriptablepartstatefunc" },
    { 0xB1BE, "setdooralarm" },
    { 0xB1BF, "setdoorbreach" },
    { 0xB1C0, "setdoorsense" },
    { 0xB1C1, "setdoubleload" },
    { 0xB1C2, "setdropped" },
    { 0xB1C3, "setdroppedweaponammo" },
    { 0xB1C4, "setearlyfinishtime" },
    { 0xB1C5, "setempimmune" },
    { 0xB1C6, "setemptysessionteam" },
    { 0xB1C7, "setendgame" },
    { 0xB1C8, "setendofroundsoundtimescalefactor" },
    { 0xB1C9, "setenemyloadoutomnvars" },
    { 0xB1CA, "setenemyloadoutomnvarsatmatchend" },
    { 0xB1CB, "setengineer" },
    { 0xB1CC, "setenhancedsixthsense" },
    { 0xB1CD, "setequipmentammo" },
    { 0xB1CE, "setequipmentping" },
    { 0xB1CF, "setequipmentslotammo" },
    { 0xB1D0, "setescortmodesettings" },
    { 0xB1D1, "setexplodermodel" },
    { 0xB1D2, "setexplosiveusablehintstring" },
    { 0xB1D3, "setextenddodge" },
    { 0xB1D4, "setextraammo" },
    { 0xB1D5, "setextradeadly" },
    { 0xB1D6, "setextradodge" },
    { 0xB1D7, "setextraequipment" },
    { 0xB1D8, "setextrascore0" },
    { 0xB1D9, "setextrascore1" },
    { 0xB1DA, "setextrascore2" },
    { 0xB1DB, "setextrascore3" },
    { 0xB1DC, "setfacialindexfornonai" },
    { 0xB1DD, "setfacialstate" },
    { 0xB1DE, "setfadetime" },
    { 0xB1DF, "setfakeloadoutweaponslot" },
    { 0xB1E0, "setfastcrouch" },
    { 0xB1E1, "setfastreloadlaunchers" },
    { 0xB1E2, "setfirstinfected" },
    { 0xB1E3, "setfirstsavetime" },
    { 0xB1E4, "setflagcaptured" },
    { 0xB1E5, "setflagpositions" },
    { 0xB1E6, "setflashbangimmunity" },
    { 0xB1E7, "setflashfrac" },
    { 0xB1E8, "setflashlightmodel" },
    { 0xB1E9, "setfollower" },
    { 0xB1EA, "setfollowmode" },
    { 0xB1EB, "setfootprinteffect" },
    { 0xB1EC, "setfootstepeffect" },
    { 0xB1ED, "setfootstepeffectsmall" },
    { 0xB1EE, "setforceradars" },
    { 0xB1EF, "setforcespawninfo" },
    { 0xB1F0, "setfreefall" },
    { 0xB1F1, "setfreelook" },
    { 0xB1F2, "setfriendlyfire" },
    { 0xB1F3, "setftlslide" },
    { 0xB1F4, "setfunc" },
    { 0xB1F5, "setgamemodecamera" },
    { 0xB1F6, "setgamemodestat" },
    { 0xB1F7, "setgasgrenaderesist" },
    { 0xB1F8, "setghost" },
    { 0xB1F9, "setglobalaimsettings" },
    { 0xB1FA, "setglobaldifficulty" },
    { 0xB1FB, "setglobalintermissionspawninfo" },
    { 0xB1FC, "setglobalnextpossibleblindfiretime" },
    { 0xB1FD, "setgoalandtimeout" },
    { 0xB1FE, "setgoalpos" },
    { 0xB1FF, "setgrenadetimer" },
    { 0xB200, "setgroundpound" },
    { 0xB201, "setgroundpoundboost" },
    { 0xB202, "setgroundpoundshield" },
    { 0xB203, "setgroundpoundshock" },
    { 0xB204, "setgroup_down" },
    { 0xB205, "setgroup_up" },
    { 0xB206, "setguardmode" },
    { 0xB207, "setgunladder" },
    { 0xB208, "setgunsfinal" },
    { 0xB209, "setguntypeforui" },
    { 0xB20A, "sethadarmor" },
    { 0xB20B, "sethardline" },
    { 0xB20C, "sethardshell" },
    { 0xB20D, "sethasdonecombat" },
    { 0xB20E, "setheadgear" },
    { 0xB20F, "setheadicon" },
    { 0xB210, "setheadicon_allowiconcreation" },
    { 0xB211, "setheadicon_createnewicon" },
    { 0xB212, "setheadicon_deleteicon" },
    { 0xB213, "setheadicon_factionimage" },
    { 0xB214, "setheadicon_findlowestprioritygroup" },
    { 0xB215, "setheadicon_findoldestcreatedicon" },
    { 0xB216, "setheadicon_getexistingiconinfo" },
    { 0xB217, "setheadicon_multiimage" },
    { 0xB218, "setheadicon_removeoldicon" },
    { 0xB219, "setheadicon_singleimage" },
    { 0xB21A, "setheadicon_watchdeath" },
    { 0xB21B, "setheadicon_watchforlateconnect" },
    { 0xB21C, "setheadicon_watchforlatespawn" },
    { 0xB21D, "setheadicon_watchfornewowner" },
    { 0xB21E, "setheadicon_watchforteamswitch" },
    { 0xB21F, "sethealer" },
    { 0xB220, "sethealthshield" },
    { 0xB221, "setheight" },
    { 0xB222, "setheligoal" },
    { 0xB223, "sethelmet" },
    { 0xB224, "sethintobject" },
    { 0xB225, "sethotfunc" },
    { 0xB226, "sethover" },
    { 0xB227, "sethqmarkerobjective" },
    { 0xB228, "sethudslot" },
    { 0xB229, "sethunter" },
    { 0xB22A, "seticonnames" },
    { 0xB22B, "seticonshader" },
    { 0xB22C, "seticonsize" },
    { 0xB22D, "setignoreriotshieldxp" },
    { 0xB22E, "setimmunetokidnapper" },
    { 0xB22F, "setimprovedmelee" },
    { 0xB230, "setimprovedprone" },
    { 0xB231, "setincog" },
    { 0xB232, "setinfectedmodels" },
    { 0xB233, "setinfectedmsg" },
    { 0xB234, "setinflictorstat" },
    { 0xB235, "setinitialbotdifficulties" },
    { 0xB236, "setinitialtonormalinfected" },
    { 0xB237, "setintel" },
    { 0xB238, "setintrocamnetworkmodel" },
    { 0xB239, "setinvehicle" },
    { 0xB23A, "setinvestigateendtime" },
    { 0xB23B, "setitemasloot" },
    { 0xB23C, "setjuggernautmodel" },
    { 0xB23D, "setjuiced" },
    { 0xB23E, "setkeyobject" },
    { 0xB23F, "setkillcamentity" },
    { 0xB240, "setkillcamequipmenttypeomnvars" },
    { 0xB241, "setkillcamerastyle" },
    { 0xB242, "setkillcamexecutiontypeomnvars" },
    { 0xB243, "setkillcamkilledbyitemomnvars" },
    { 0xB244, "setkillcamkillstreaktypeomnvars" },
    { 0xB245, "setkillcammisctypeomnvars" },
    { 0xB246, "setkillcamnormalweaponomnvars" },
    { 0xB247, "setkillcamsupertypeomnvars" },
    { 0xB248, "setkillcamuitimer" },
    { 0xB249, "setkillcamweapontypeomnvars" },
    { 0xB24A, "setkilledbyuiomnvar" },
    { 0xB24B, "setkillstreakcontrolpriority" },
    { 0xB24C, "setkillstreaktoscorestreak" },
    { 0xB24D, "setkineticpulse" },
    { 0xB24E, "setkineticwave" },
    { 0xB24F, "setkothwaypoints" },
    { 0xB250, "setladder" },
    { 0xB251, "setlastcallouttype" },
    { 0xB252, "setlevelcompleted" },
    { 0xB253, "setlevelmlgcam" },
    { 0xB254, "setlevelobjectivetext" },
    { 0xB255, "setlifepack" },
    { 0xB256, "setlifepackoutlinestate" },
    { 0xB257, "setlifepackvisualforplayer" },
    { 0xB258, "setlightarmor" },
    { 0xB259, "setlightarmorvalue" },
    { 0xB25A, "setlightweight" },
    { 0xB25B, "setlocaljammer" },
    { 0xB25C, "setlocationmarking" },
    { 0xB25D, "setlockedoncallback" },
    { 0xB25E, "setlockedonremovedcallback" },
    { 0xB25F, "setlowermessage" },
    { 0xB260, "setlowermessageomnvar" },
    { 0xB261, "setmanatarms" },
    { 0xB262, "setmapcenterfordev" },
    { 0xB263, "setmaplocationselection" },
    { 0xB264, "setmapsizespawnconsts" },
    { 0xB265, "setmarkequipment" },
    { 0xB266, "setmarksman" },
    { 0xB267, "setmarktargets" },
    { 0xB268, "setmatchstat" },
    { 0xB269, "setmeleekill" },
    { 0xB26A, "setmenu" },
    { 0xB26B, "setmissilekillcament" },
    { 0xB26C, "setmisstime" },
    { 0xB26D, "setmlgannouncement" },
    { 0xB26E, "setmlgspectatorclientloadoutdata" },
    { 0xB26F, "setmodelfromarray" },
    { 0xB270, "setmodelfromcustomization" },
    { 0xB271, "setmodelvisibility" },
    { 0xB272, "setmodifiedbombzonescollision" },
    { 0xB273, "setmomentum" },
    { 0xB274, "setmortarmount" },
    { 0xB275, "setmunitions" },
    { 0xB276, "setnameandrank_andaddtosquad" },
    { 0xB277, "setneutral" },
    { 0xB278, "setneutralicons" },
    { 0xB279, "setnewarmsracecacheloc" },
    { 0xB27A, "setnextlookforcovertime" },
    { 0xB27B, "setnextpatrolpoint" },
    { 0xB27C, "setnextplayergrenadetime" },
    { 0xB27D, "setnextpossibleblindfiretime" },
    { 0xB27E, "setnextroundclass" },
    { 0xB27F, "setnoscopeoutline" },
    { 0xB280, "setnotetrackeffect" },
    { 0xB281, "setnotetracksound" },
    { 0xB282, "setnpcid" },
    { 0xB283, "setnuketimescalefactor" },
    { 0xB284, "setobjectivehinttext" },
    { 0xB285, "setobjectiveicons" },
    { 0xB286, "setobjectivemarkerpos" },
    { 0xB287, "setobjectivescoretext" },
    { 0xB288, "setobjectivestatusicons" },
    { 0xB289, "setobjectivetext" },
    { 0xB28A, "setobjectivetextforplayer" },
    { 0xB28B, "setobjectivetocompleteanddroploot" },
    { 0xB28C, "setobjpointteamcolor" },
    { 0xB28D, "setoffhandloot" },
    { 0xB28E, "setoffhandprimaryclassfunc" },
    { 0xB28F, "setoffhandprovider" },
    { 0xB290, "setoffhandsecondaryclassfunc" },
    { 0xB291, "setomnvarbasedonindex" },
    { 0xB292, "setomnvarsforperklist" },
    { 0xB293, "setomvarviewoffset" },
    { 0xB294, "setonemanarmy" },
    { 0xB295, "setoperatorcustomization" },
    { 0xB296, "setopticwave" },
    { 0xB297, "setoriginbyname" },
    { 0xB298, "setoutlinekillstreaks" },
    { 0xB299, "setovercharge" },
    { 0xB29A, "setoverclock" },
    { 0xB29B, "setoverkill" },
    { 0xB29C, "setoverkillpro" },
    { 0xB29D, "setoverridearchetype" },
    { 0xB29E, "setoverridewatchdvar" },
    { 0xB29F, "setoverrideweaponspeed" },
    { 0xB2A0, "setovertimelimitdvar" },
    { 0xB2A1, "setoverwatchmodesettings" },
    { 0xB2A2, "setownerteam" },
    { 0xB2A3, "setpainted" },
    { 0xB2A4, "setparamscontextual" },
    { 0xB2A5, "setparamsenemy" },
    { 0xB2A6, "setparamsloot" },
    { 0xB2A7, "setparent" },
    { 0xB2A8, "setpassivedeathwatching" },
    { 0xB2A9, "setpassivevalue" },
    { 0xB2AA, "setpatrolstate" },
    { 0xB2AB, "setpatrolstyle_base" },
    { 0xB2AC, "setpeeklookstarttime" },
    { 0xB2AD, "setpersonaltrophy" },
    { 0xB2AE, "setphase" },
    { 0xB2AF, "setphasefall" },
    { 0xB2B0, "setphaseshift" },
    { 0xB2B1, "setphaseslashrephase" },
    { 0xB2B2, "setphaseslide" },
    { 0xB2B3, "setphasespeed" },
    { 0xB2B4, "setphasesplit" },
    { 0xB2B5, "setpickedup" },
    { 0xB2B6, "setpickupcallback" },
    { 0xB2B7, "setpitcher" },
    { 0xB2B8, "setpitcherinternal" },
    { 0xB2B9, "setplantedequipmentuse" },
    { 0xB2BA, "setplayerbcnameid" },
    { 0xB2BB, "setplayerblinded" },
    { 0xB2BC, "setplayercalloutarea" },
    { 0xB2BD, "setplayerconnectscriptfields" },
    { 0xB2BE, "setplayerdatagroups" },
    { 0xB2BF, "setplayerempimmune" },
    { 0xB2C0, "setplayerheadicon" },
    { 0xB2C1, "setplayerhudphoto" },
    { 0xB2C2, "setplayerinfire" },
    { 0xB2C3, "setplayerloadout" },
    { 0xB2C4, "setplayerlootenabled" },
    { 0xB2C5, "setplayermodels" },
    { 0xB2C6, "setplayerofffire" },
    { 0xB2C7, "setplayeronfire" },
    { 0xB2C8, "setplayeroutoffire" },
    { 0xB2C9, "setplayerprematchallows" },
    { 0xB2CA, "setplayerscoreboardinfo" },
    { 0xB2CB, "setplayerstat" },
    { 0xB2CC, "setplayerstat_internal" },
    { 0xB2CD, "setplayerstatbuffered" },
    { 0xB2CE, "setplayerstunned" },
    { 0xB2CF, "setplayertocamera" },
    { 0xB2D0, "setplayerunblinded" },
    { 0xB2D1, "setplayerunstunned" },
    { 0xB2D2, "setplayervargulag" },
    { 0xB2D3, "setplayervargulagarena" },
    { 0xB2D4, "setplayervarinrespawnc130" },
    { 0xB2D5, "setplayerviewmodel" },
    { 0xB2D6, "setpoi" },
    { 0xB2D7, "setpoint" },
    { 0xB2D8, "setpointbar" },
    { 0xB2D9, "setpose" },
    { 0xB2DA, "setposition" },
    { 0xB2DB, "setpowercell" },
    { 0xB2DC, "setpowerovertime" },
    { 0xB2DD, "setpowerovertimeduration" },
    { 0xB2DE, "setquickswap" },
    { 0xB2DF, "setradarmode" },
    { 0xB2E0, "setrearguard" },
    { 0xB2E1, "setrechargeequipment" },
    { 0xB2E2, "setrecoilscale" },
    { 0xB2E3, "setreconmodesettings" },
    { 0xB2E4, "setreduceregendelay" },
    { 0xB2E5, "setreduceregendelayonobjective" },
    { 0xB2E6, "setrefillammo" },
    { 0xB2E7, "setrefillgrenades" },
    { 0xB2E8, "setreflectshield" },
    { 0xB2E9, "setregenfaster" },
    { 0xB2EA, "setremainingteams" },
    { 0xB2EB, "setremotedefuse" },
    { 0xB2EC, "setrevenge" },
    { 0xB2ED, "setreviveuseweapon" },
    { 0xB2EE, "setrewind" },
    { 0xB2EF, "setroundwinstreakarray" },
    { 0xB2F0, "setrshieldradar" },
    { 0xB2F1, "setrshieldradar_cleanup" },
    { 0xB2F2, "setrshieldscrambler" },
    { 0xB2F3, "setrshieldscrambler_cleanup" },
    { 0xB2F4, "setruggedeqp" },
    { 0xB2F5, "setrush" },
    { 0xB2F6, "setsaboteur" },
    { 0xB2F7, "setscavengereqp" },
    { 0xB2F8, "setscorelimit" },
    { 0xB2F9, "setscorestreakpack" },
    { 0xB2FA, "setscoretobeat" },
    { 0xB2FB, "setscoutping" },
    { 0xB2FC, "setscrambled" },
    { 0xB2FD, "setscrambler" },
    { 0xB2FE, "setscrambler_cleanup" },
    { 0xB2FF, "setscrapweapons" },
    { 0xB300, "setscriptablestateflag" },
    { 0xB301, "setscriptammo" },
    { 0xB302, "setseekerattached" },
    { 0xB303, "setselectedkillstreak" },
    { 0xB304, "setselfusable" },
    { 0xB305, "setselfvoinfo" },
    { 0xB306, "setsessionteam" },
    { 0xB307, "setsharpfocus" },
    { 0xB308, "setshocksamtargetent" },
    { 0xB309, "setshootenttoenemy" },
    { 0xB30A, "setshootstyle" },
    { 0xB30B, "setsixthsense" },
    { 0xB30C, "setsize" },
    { 0xB30D, "setskill" },
    { 0xB30E, "setsmartobject" },
    { 0xB30F, "setsmokewall" },
    { 0xB310, "setsniperaccuracy" },
    { 0xB311, "setsolobuddyboost" },
    { 0xB312, "setsonicpulse" },
    { 0xB313, "setspawncamera" },
    { 0xB314, "setspawncloak" },
    { 0xB315, "setspawnlocations" },
    { 0xB316, "setspawnnotifyomnvar" },
    { 0xB317, "setspawnpoint" },
    { 0xB318, "setspawnradar" },
    { 0xB319, "setspawnselectionorder" },
    { 0xB31A, "setspawnvariables" },
    { 0xB31B, "setspawnview" },
    { 0xB31C, "setspecialloadout" },
    { 0xB31D, "setspecialloadouts" },
    { 0xB31E, "setspectatepermissions" },
    { 0xB31F, "setspectaterules" },
    { 0xB320, "setspectator" },
    { 0xB321, "setspeedboost" },
    { 0xB322, "setspotter" },
    { 0xB323, "setsquad" },
    { 0xB324, "setsquadgoalposition" },
    { 0xB325, "setstackvalues" },
    { 0xB326, "setstate" },
    { 0xB327, "setstatelocked" },
    { 0xB328, "setstaticuicircles" },
    { 0xB329, "setsteadyaimpro" },
    { 0xB32A, "setstealth" },
    { 0xB32B, "setstealthmovespeed" },
    { 0xB32C, "setstealthstate" },
    { 0xB32D, "setstealthstate_neutral" },
    { 0xB32E, "setsteelnerves" },
    { 0xB32F, "setstoredvehspeeds" },
    { 0xB330, "setstreakcounttonext" },
    { 0xB331, "setstreakpoints" },
    { 0xB332, "setstunresistance" },
    { 0xB333, "setsuperbasepoints" },
    { 0xB334, "setsuperextrapoints" },
    { 0xB335, "setsuperpack" },
    { 0xB336, "setsupersprintenhanced" },
    { 0xB337, "setsuperweapondisabled" },
    { 0xB338, "setsupport" },
    { 0xB339, "setsupportkillstreaks" },
    { 0xB33A, "setsurvivaltime" },
    { 0xB33B, "setsurvivor" },
    { 0xB33C, "settacticalinsertion" },
    { 0xB33D, "settagger" },
    { 0xB33E, "settaggerinternal" },
    { 0xB33F, "settank" },
    { 0xB340, "settargetsbasedonchosenarray" },
    { 0xB341, "settargettooclose" },
    { 0xB342, "setteam" },
    { 0xB343, "setteamdata" },
    { 0xB344, "setteamheadicon" },
    { 0xB345, "setteamicons" },
    { 0xB346, "setteaminhuddatafromteamname" },
    { 0xB347, "setteammapposition" },
    { 0xB348, "setteammateomnvarsforplayer" },
    { 0xB349, "setteamorplayeronly" },
    { 0xB34A, "setteamradarwrapper" },
    { 0xB34B, "setteamusetext" },
    { 0xB34C, "setteamusetime" },
    { 0xB34D, "setteleport" },
    { 0xB34E, "settelereap" },
    { 0xB34F, "setteleslide" },
    { 0xB350, "settessellationvalues" },
    { 0xB351, "setthermal" },
    { 0xB352, "setthermalvision" },
    { 0xB353, "setthief" },
    { 0xB354, "setthirdpersondof" },
    { 0xB355, "setthrowingknifemelee" },
    { 0xB356, "setthruster" },
    { 0xB357, "settimelimit" },
    { 0xB358, "settimetobeat" },
    { 0xB359, "settings" },
    { 0xB35A, "settingsfunc" },
    { 0xB35B, "settingtypes" },
    { 0xB35C, "settle_anim" },
    { 0xB35D, "settletime" },
    { 0xB35E, "settoughenup" },
    { 0xB35F, "settoughenupmodel" },
    { 0xB360, "settoughenupvisiblestate" },
    { 0xB361, "settournamentwinner" },
    { 0xB362, "settracker" },
    { 0xB363, "settransponder" },
    { 0xB364, "settriggerhappy" },
    { 0xB365, "settriggerhappyinternal" },
    { 0xB366, "settweakabledvar" },
    { 0xB367, "settweakablelastvalue" },
    { 0xB368, "settweakablevalue" },
    { 0xB369, "setuav" },
    { 0xB36A, "setuipostgamefade" },
    { 0xB36B, "setuipregamefadeup" },
    { 0xB36C, "setup_1f_kitchen_scene" },
    { 0xB36D, "setup_1f_main_door" },
    { 0xB36E, "setup_1f_main_door_arrival" },
    { 0xB36F, "setup_1f_side_door" },
    { 0xB370, "setup_1f_side_door_anim" },
    { 0xB371, "setup_1f_side_door_arrival" },
    { 0xB372, "setup_2d_ui_images" },
    { 0xB373, "setup_2f_bedroom" },
    { 0xB374, "setup_2f_bravo1" },
    { 0xB375, "setup_2f_data_enemies" },
    { 0xB376, "setup_2f_price" },
    { 0xB377, "setup_2f_stairs_vo" },
    { 0xB378, "setup_3f_bravo1" },
    { 0xB379, "setup_3f_scene" },
    { 0xB37A, "setup_agent" },
    { 0xB37B, "setup_aianimthreads" },
    { 0xB37C, "setup_aisettings_on_plane" },
    { 0xB37D, "setup_aitypes_array" },
    { 0xB37E, "setup_allies" },
    { 0xB37F, "setup_ally_bombs" },
    { 0xB380, "setup_ally_flashlight" },
    { 0xB381, "setup_ally_team" },
    { 0xB382, "setup_alpha_breach_approach" },
    { 0xB383, "setup_alpha_breach_jumpto" },
    { 0xB384, "setup_alpha_breach_team" },
    { 0xB385, "setup_alpha_sledge_team" },
    { 0xB386, "setup_anim_guy" },
    { 0xB387, "setup_animation" },
    { 0xB388, "setup_armored" },
    { 0xB389, "setup_armored_helmet" },
    { 0xB38A, "setup_assault_vehicle" },
    { 0xB38B, "setup_blend_interaction_idles" },
    { 0xB38C, "setup_bodies_for_streaming" },
    { 0xB38D, "setup_bomb_object" },
    { 0xB38E, "setup_bot_air" },
    { 0xB38F, "setup_bot_arm" },
    { 0xB390, "setup_bot_ball" },
    { 0xB391, "setup_bot_bhd" },
    { 0xB392, "setup_bot_blitz" },
    { 0xB393, "setup_bot_br" },
    { 0xB394, "setup_bot_conf" },
    { 0xB395, "setup_bot_cranked" },
    { 0xB396, "setup_bot_ctf" },
    { 0xB397, "setup_bot_cyber" },
    { 0xB398, "setup_bot_dd" },
    { 0xB399, "setup_bot_defcon" },
    { 0xB39A, "setup_bot_dm" },
    { 0xB39B, "setup_bot_dom" },
    { 0xB39C, "setup_bot_front" },
    { 0xB39D, "setup_bot_grnd" },
    { 0xB39E, "setup_bot_gun" },
    { 0xB39F, "setup_bot_hvt" },
    { 0xB3A0, "setup_bot_infect" },
    { 0xB3A1, "setup_bot_koth" },
    { 0xB3A2, "setup_bot_lava" },
    { 0xB3A3, "setup_bot_mtmc" },
    { 0xB3A4, "setup_bot_payload" },
    { 0xB3A5, "setup_bot_pill" },
    { 0xB3A6, "setup_bot_sam" },
    { 0xB3A7, "setup_bot_sd" },
    { 0xB3A8, "setup_bot_siege" },
    { 0xB3A9, "setup_bot_sotf" },
    { 0xB3AA, "setup_bot_tac_ops" },
    { 0xB3AB, "setup_bot_tjugg" },
    { 0xB3AC, "setup_bot_to_hstg" },
    { 0xB3AD, "setup_bot_vip" },
    { 0xB3AE, "setup_bot_war" },
    { 0xB3AF, "setup_bot_wmd" },
    { 0xB3B0, "setup_bpg_car_fire_flicker" },
    { 0xB3B1, "setup_bpg_combat" },
    { 0xB3B2, "setup_bpg_metal_detector_fire_flicker" },
    { 0xB3B3, "setup_bravo_roof" },
    { 0xB3B4, "setup_breadcrumbs_to_hvt" },
    { 0xB3B5, "setup_breadcrumbs_to_roof" },
    { 0xB3B6, "setup_breath_overlay" },
    { 0xB3B7, "setup_bridge_drone" },
    { 0xB3B8, "setup_bridge_missile" },
    { 0xB3B9, "setup_bt_and_asm" },
    { 0xB3BA, "setup_button_notifys" },
    { 0xB3BB, "setup_c4" },
    { 0xB3BC, "setup_c6" },
    { 0xB3BD, "setup_c8" },
    { 0xB3BE, "setup_callbacks" },
    { 0xB3BF, "setup_cart_animation" },
    { 0xB3C0, "setup_cell_doors" },
    { 0xB3C1, "setup_chair_carry_fsm" },
    { 0xB3C2, "setup_charges_new" },
    { 0xB3C3, "setup_civ_groups" },
    { 0xB3C4, "setup_civ_types" },
    { 0xB3C5, "setup_combatant_wolf_aq" },
    { 0xB3C6, "setup_create_script" },
    { 0xB3C7, "setup_dead_bodies" },
    { 0xB3C8, "setup_debug_button_combos_for_player" },
    { 0xB3C9, "setup_detonator" },
    { 0xB3CA, "setup_detonator_for_ges" },
    { 0xB3CB, "setup_detonator_swap" },
    { 0xB3CC, "setup_downstairs_pillage" },
    { 0xB3CD, "setup_dpad_slots" },
    { 0xB3CE, "setup_dummy_flares" },
    { 0xB3CF, "setup_end_bus" },
    { 0xB3D0, "setup_ending" },
    { 0xB3D1, "setup_enemy_for_price_clean_up" },
    { 0xB3D2, "setup_enemysoldier_model" },
    { 0xB3D3, "setup_exit_states_for_interaction" },
    { 0xB3D4, "setup_extras" },
    { 0xB3D5, "setup_fake_bomber" },
    { 0xB3D6, "setup_fakeactor_nodes" },
    { 0xB3D7, "setup_fallback_trigger" },
    { 0xB3D8, "setup_fast_rope_anims" },
    { 0xB3D9, "setup_fight_guy" },
    { 0xB3DA, "setup_final_shot" },
    { 0xB3DB, "setup_final_shot_animnode" },
    { 0xB3DC, "setup_fire_flicker" },
    { 0xB3DD, "setup_flags" },
    { 0xB3DE, "setup_gas_lab_door" },
    { 0xB3DF, "setup_gear_alex" },
    { 0xB3E0, "setup_generic_human" },
    { 0xB3E1, "setup_global_event_objectives" },
    { 0xB3E2, "setup_grounds_dumpster_scene" },
    { 0xB3E3, "setup_gulag_weapon_check" },
    { 0xB3E4, "setup_hallway_scriptables" },
    { 0xB3E5, "setup_hardpoint" },
    { 0xB3E6, "setup_headicon_on_jammer" },
    { 0xB3E7, "setup_heli" },
    { 0xB3E8, "setup_heli_scene" },
    { 0xB3E9, "setup_heli_tags_bravo" },
    { 0xB3EA, "setup_hints" },
    { 0xB3EB, "setup_hostage_anims" },
    { 0xB3EC, "setup_hostage_fulton_anims" },
    { 0xB3ED, "setup_hud_elem" },
    { 0xB3EE, "setup_hvt_in_heli" },
    { 0xB3EF, "setup_individual_exploder" },
    { 0xB3F0, "setup_infil_lights" },
    { 0xB3F1, "setup_informant" },
    { 0xB3F2, "setup_initial_entities" },
    { 0xB3F3, "setup_interact" },
    { 0xB3F4, "setup_interaction_head" },
    { 0xB3F5, "setup_interrogate" },
    { 0xB3F6, "setup_intro_idles" },
    { 0xB3F7, "setup_investigate_location" },
    { 0xB3F8, "setup_irish_luck_consumables" },
    { 0xB3F9, "setup_jugg" },
    { 0xB3FA, "setup_keypad" },
    { 0xB3FB, "setup_kyledrone" },
    { 0xB3FC, "setup_laser_pointer_fsm" },
    { 0xB3FD, "setup_level_arrays" },
    { 0xB3FE, "setup_level_ents" },
    { 0xB3FF, "setup_lighting" },
    { 0xB400, "setup_lighting_dvars" },
    { 0xB401, "setup_lights" },
    { 0xB402, "setup_linked_collision_entities" },
    { 0xB403, "setup_main_door_jumpto_damage" },
    { 0xB404, "setup_manual_goalpos" },
    { 0xB405, "setup_map_specific_devgui" },
    { 0xB406, "setup_marine_allies" },
    { 0xB407, "setup_mine_cart" },
    { 0xB408, "setup_mine_carts" },
    { 0xB409, "setup_miniguns" },
    { 0xB40A, "setup_model" },
    { 0xB40B, "setup_module_groups" },
    { 0xB40C, "setup_named_ai" },
    { 0xB40D, "setup_named_ai_after_spawn" },
    { 0xB40E, "setup_named_vehicle" },
    { 0xB40F, "setup_names" },
    { 0xB410, "setup_noisemaker_pickups" },
    { 0xB411, "setup_office_door" },
    { 0xB412, "setup_open_struct" },
    { 0xB413, "setup_overheat_sound_org" },
    { 0xB414, "setup_overheat_sound_orgs" },
    { 0xB415, "setup_overlook_scene" },
    { 0xB416, "setup_painter_group" },
    { 0xB417, "setup_personalities" },
    { 0xB418, "setup_pilot" },
    { 0xB419, "setup_place_soldiers_on_truck" },
    { 0xB41A, "setup_play_test_name_to_team_id_mapping" },
    { 0xB41B, "setup_player" },
    { 0xB41C, "setup_player_animnode" },
    { 0xB41D, "setup_player_ar" },
    { 0xB41E, "setup_player_deaths" },
    { 0xB41F, "setup_player_door_wedge" },
    { 0xB420, "setup_player_last_frame" },
    { 0xB421, "setup_player_rig" },
    { 0xB422, "setup_player_silenced_pistol" },
    { 0xB423, "setup_player_vehicles" },
    { 0xB424, "setup_player_weapon_models" },
    { 0xB425, "setup_post_bomb_crash" },
    { 0xB426, "setup_post_cinematic" },
    { 0xB427, "setup_price_silenced_pistol" },
    { 0xB428, "setup_price_smg" },
    { 0xB429, "setup_prison_break_spawn_modules" },
    { 0xB42A, "setup_prompt_knife" },
    { 0xB42B, "setup_radio_tower_uavs" },
    { 0xB42C, "setup_raid_infil" },
    { 0xB42D, "setup_revive_icon_ent" },
    { 0xB42E, "setup_router_objective" },
    { 0xB42F, "setup_run_n_gun" },
    { 0xB430, "setup_script_collision" },
    { 0xB431, "setup_scriptable_car" },
    { 0xB432, "setup_scriptable_lights_for_compile" },
    { 0xB433, "setup_scripted_car" },
    { 0xB434, "setup_scripted_door" },
    { 0xB435, "setup_search_anims" },
    { 0xB436, "setup_search_area" },
    { 0xB437, "setup_search_areas" },
    { 0xB438, "setup_search_points" },
    { 0xB439, "setup_spawn_skits" },
    { 0xB43A, "setup_spawn_struct" },
    { 0xB43B, "setup_stair_b" },
    { 0xB43C, "setup_stealth_funcs" },
    { 0xB43D, "setup_support_marines" },
    { 0xB43E, "setup_switch" },
    { 0xB43F, "setup_tea_room" },
    { 0xB440, "setup_temp_car_stuff" },
    { 0xB441, "setup_test_computer" },
    { 0xB442, "setup_trafficking_soldier_anims" },
    { 0xB443, "setup_traps" },
    { 0xB444, "setup_traversalassist" },
    { 0xB445, "setup_trigger_spawn" },
    { 0xB446, "setup_truck_lighting" },
    { 0xB447, "setup_tunnel" },
    { 0xB448, "setup_turret" },
    { 0xB449, "setup_turret_a1" },
    { 0xB44A, "setup_turret_a2" },
    { 0xB44B, "setup_turret_anims" },
    { 0xB44C, "setup_van_lights" },
    { 0xB44D, "setup_vehicles" },
    { 0xB44E, "setup_vfx_int_vs_ext" },
    { 0xB44F, "setup_vista_driving_boats" },
    { 0xB450, "setup_vo_civs" },
    { 0xB451, "setup_waitforallhacks" },
    { 0xB452, "setup_wave_vars" },
    { 0xB453, "setup_waves_truck_section" },
    { 0xB454, "setup_wire" },
    { 0xB455, "setupagent" },
    { 0xB456, "setupaim" },
    { 0xB457, "setupaiming" },
    { 0xB458, "setupairpath" },
    { 0xB459, "setupareabrushes" },
    { 0xB45A, "setuparena" },
    { 0xB45B, "setuparmor" },
    { 0xB45C, "setupbarriers" },
    { 0xB45D, "setupbaseareabrushes" },
    { 0xB45E, "setupbases" },
    { 0xB45F, "setupbobbingboat" },
    { 0xB460, "setupbombzones" },
    { 0xB461, "setupbradleys" },
    { 0xB462, "setupbtaction" },
    { 0xB463, "setupbtmflags" },
    { 0xB464, "setupcallbacks" },
    { 0xB465, "setupcaptureflares" },
    { 0xB466, "setupchallengelocales" },
    { 0xB467, "setupcommoncallbacks" },
    { 0xB468, "setupconfigentities" },
    { 0xB469, "setupconfigs" },
    { 0xB46A, "setupcqbpointsofinterest" },
    { 0xB46B, "setupdamageflags" },
    { 0xB46C, "setupdamagetriggers" },
    { 0xB46D, "setupdestructibledoors" },
    { 0xB46E, "setupdestructiblekillcaments" },
    { 0xB46F, "setupdestructibleparts" },
    { 0xB470, "setupdevguientries" },
    { 0xB471, "setupdynamicladders" },
    { 0xB472, "setupendzones" },
    { 0xB473, "setupexploders" },
    { 0xB474, "setupexplodertriggers" },
    { 0xB475, "setupextractgoal" },
    { 0xB476, "setupextractioncallouts" },
    { 0xB477, "setupfireteamleader" },
    { 0xB478, "setupflags" },
    { 0xB479, "setupfordefusing" },
    { 0xB47A, "setupforplanting" },
    { 0xB47B, "setupglobalcallbackfunctions_sp" },
    { 0xB47C, "setupgoalvisualsforjugg" },
    { 0xB47D, "setupgrenades" },
    { 0xB47E, "setuphalodropplayer" },
    { 0xB47F, "setupheliobjective" },
    { 0xB480, "setuphud" },
    { 0xB481, "setuphudelements" },
    { 0xB482, "setupinitialstate" },
    { 0xB483, "setupinputnotifications" },
    { 0xB484, "setupkillcament" },
    { 0xB485, "setupkillcamui" },
    { 0xB486, "setupminesettings" },
    { 0xB487, "setupminimap" },
    { 0xB488, "setupmodel" },
    { 0xB489, "setupmodel_bypass" },
    { 0xB48A, "setupmortarmodelanimscripts" },
    { 0xB48B, "setupmortarplayeranimscripts" },
    { 0xB48C, "setupnextobjective" },
    { 0xB48D, "setupobjective" },
    { 0xB48E, "setupobjectiveicons" },
    { 0xB48F, "setupobjectiveloops" },
    { 0xB490, "setupobjectives" },
    { 0xB491, "setupobjectobjective" },
    { 0xB492, "setupoutofrangewatcher" },
    { 0xB493, "setupovercookfuncs" },
    { 0xB494, "setupoverridearchetypeprioritytable" },
    { 0xB495, "setuppingwatcher" },
    { 0xB496, "setupplayerasjugg" },
    { 0xB497, "setupplayermodel" },
    { 0xB498, "setupplayerspawnsightdata" },
    { 0xB499, "setupplunderextractionsites" },
    { 0xB49A, "setuppotgui" },
    { 0xB49B, "setupquantities" },
    { 0xB49C, "setupradios" },
    { 0xB49D, "setuprandomlooktarget" },
    { 0xB49E, "setuprandomtable" },
    { 0xB49F, "setuprope" },
    { 0xB4A0, "setuprpgcaches" },
    { 0xB4A1, "setupsavedactionslots" },
    { 0xB4A2, "setupscriptablevisuals" },
    { 0xB4A3, "setupselfvo" },
    { 0xB4A4, "setupsfxobjs" },
    { 0xB4A5, "setupsoldieraitype" },
    { 0xB4A6, "setupsoldierdefaults" },
    { 0xB4A7, "setupspawnareas" },
    { 0xB4A8, "setupspawninfluencezones" },
    { 0xB4A9, "setupspawnlocations" },
    { 0xB4AA, "setuptankendgoal" },
    { 0xB4AB, "setupteamoobtriggers" },
    { 0xB4AC, "setuptraversaltransitioncheck" },
    { 0xB4AD, "setupuniqueanims" },
    { 0xB4AE, "setupvehiclespawnvolumes" },
    { 0xB4AF, "setupvfxobjs" },
    { 0xB4B0, "setupvisuals" },
    { 0xB4B1, "setupwait" },
    { 0xB4B2, "setupwallrunaimlimits" },
    { 0xB4B3, "setupwallrunifneeded" },
    { 0xB4B4, "setupwaypointicons" },
    { 0xB4B5, "setupweapon" },
    { 0xB4B6, "setupweapons" },
    { 0xB4B7, "setupweaponvars" },
    { 0xB4B8, "setupzoneareabrushes" },
    { 0xB4B9, "setupzonecallouts" },
    { 0xB4BA, "setupzones" },
    { 0xB4BB, "setusablebyteam" },
    { 0xB4BC, "setuseanimgoalweight" },
    { 0xB4BD, "setuseanimgoalweight_wait" },
    { 0xB4BE, "setusehinttext" },
    { 0xB4BF, "setusetext" },
    { 0xB4C0, "setusetime" },
    { 0xB4C1, "setusingarmorvest" },
    { 0xB4C2, "setusingremote" },
    { 0xB4C3, "setvehgoalpos_wrap" },
    { 0xB4C4, "setvehiclearchetype" },
    { 0xB4C5, "setvehiclefx" },
    { 0xB4C6, "setviewkickoverride" },
    { 0xB4C7, "setviewoffset" },
    { 0xB4C8, "setvisibleteam" },
    { 0xB4C9, "setvisionsetnaked" },
    { 0xB4CA, "setwaitweaponchangeonuse" },
    { 0xB4CB, "setwalllock" },
    { 0xB4CC, "setwaypointiconinfo" },
    { 0xB4CD, "setweaponlaser" },
    { 0xB4CE, "setweaponlaser_func" },
    { 0xB4CF, "setweaponlaser_internal" },
    { 0xB4D0, "setweaponlaser_monitorads" },
    { 0xB4D1, "setweaponlaser_monitorweaponswitchstart" },
    { 0xB4D2, "setweaponlaser_onweaponswitchstart" },
    { 0xB4D3, "setweaponlaser_waitforlaserweapon" },
    { 0xB4D4, "setweaponsfree" },
    { 0xB4D5, "setweaponstat" },
    { 0xB4D6, "setwidth" },
    { 0xB4D7, "setwinner" },
    { 0xB4D8, "setworldloot" },
    { 0xB4D9, "setworsenedgunkick" },
    { 0xB4DA, "setxenonranks" },
    { 0xB4DB, "setzombiestate" },
    { 0xB4DC, "sex" },
    { 0xB4DD, "sfx" },
    { 0xB4DE, "sfx_airbase_alarm" },
    { 0xB4DF, "sfx_alley_gas_walla" },
    { 0xB4E0, "sfx_amb_car_int" },
    { 0xB4E1, "sfx_bar_escape_door" },
    { 0xB4E2, "sfx_barkov_heli_flyover" },
    { 0xB4E3, "sfx_barrier_open" },
    { 0xB4E4, "sfx_basement_door_fire" },
    { 0xB4E5, "sfx_bombvest_expl_finale" },
    { 0xB4E6, "sfx_bottom_hill_trucks" },
    { 0xB4E7, "sfx_buddy_down_debris" },
    { 0xB4E8, "sfx_buddy_down_fire_volley" },
    { 0xB4E9, "sfx_bunker_breach" },
    { 0xB4EA, "sfx_bunker_heli_outro" },
    { 0xB4EB, "sfx_buried_debris_lp" },
    { 0xB4EC, "sfx_buried_footsteps" },
    { 0xB4ED, "sfx_buried_walla_lp" },
    { 0xB4EE, "sfx_cafe" },
    { 0xB4EF, "sfx_car_bomb_expl" },
    { 0xB4F0, "sfx_car_door_open" },
    { 0xB4F1, "sfx_car_door_slam" },
    { 0xB4F2, "sfx_courtyard_door_breach" },
    { 0xB4F3, "sfx_dist_battle" },
    { 0xB4F4, "sfx_distant_airplane" },
    { 0xB4F5, "sfx_dumpster_land" },
    { 0xB4F6, "sfx_dumpster_mantle" },
    { 0xB4F7, "sfx_falling_debris" },
    { 0xB4F8, "sfx_fire_context_disable" },
    { 0xB4F9, "sfx_fire_context_enable" },
    { 0xB4FA, "sfx_flag_burning" },
    { 0xB4FB, "sfx_glass_crack_01" },
    { 0xB4FC, "sfx_glass_crack_02" },
    { 0xB4FD, "sfx_glass_crack_03" },
    { 0xB4FE, "sfx_glass_crack_04" },
    { 0xB4FF, "sfx_glass_crack_05" },
    { 0xB500, "sfx_glass_crack_06a" },
    { 0xB501, "sfx_glass_crack_06b" },
    { 0xB502, "sfx_glass_crack_06c" },
    { 0xB503, "sfx_hadir_truck" },
    { 0xB504, "sfx_heli_ramp_center" },
    { 0xB505, "sfx_heli_ramp_left" },
    { 0xB506, "sfx_heli_ramp_right" },
    { 0xB507, "sfx_hometown_door_open_filtering_change" },
    { 0xB508, "sfx_ied_expl" },
    { 0xB509, "sfx_impact_shellshock" },
    { 0xB50A, "sfx_intro_chaos" },
    { 0xB50B, "sfx_intro_collapse" },
    { 0xB50C, "sfx_jet_flyby" },
    { 0xB50D, "sfx_jets_bomb_expl" },
    { 0xB50E, "sfx_jumpdown_amb_change" },
    { 0xB50F, "sfx_lantern_fire" },
    { 0xB510, "sfx_lights_off" },
    { 0xB511, "sfx_lights_on" },
    { 0xB512, "sfx_mayhem_beam_crack" },
    { 0xB513, "sfx_mayhem_corner_collapse" },
    { 0xB514, "sfx_mortar_setup" },
    { 0xB515, "sfx_piccadilly_intro_mix" },
    { 0xB516, "sfx_pipes_heli_flyover" },
    { 0xB517, "sfx_plr_van_getout" },
    { 0xB518, "sfx_pre_explo_mix_change_1" },
    { 0xB519, "sfx_pre_explo_mix_change_2" },
    { 0xB51A, "sfx_random_mvmt_behind_door" },
    { 0xB51B, "sfx_russians_shoot" },
    { 0xB51C, "sfx_safehouse_backpack_expl" },
    { 0xB51D, "sfx_safehouse_heli_expl" },
    { 0xB51E, "sfx_safehouse_truck_expl" },
    { 0xB51F, "sfx_scaffolding_mayhem" },
    { 0xB520, "sfx_sedan_passby" },
    { 0xB521, "sfx_smoke_grenade_smoke" },
    { 0xB522, "sfx_spawn_crickets" },
    { 0xB523, "sfx_stop_oil_barrel_stream" },
    { 0xB524, "sfx_stop_water_barrel_stream" },
    { 0xB525, "sfx_tarp_mayhem" },
    { 0xB526, "sfx_taxi_passby" },
    { 0xB527, "sfx_technical_drive_in" },
    { 0xB528, "sfx_technical_resume" },
    { 0xB529, "sfx_technical_stop" },
    { 0xB52A, "sfx_townhouse_audio_3rd_floor_buddy_down_look_at" },
    { 0xB52B, "sfx_townhouse_audio_3rd_floor_sound_look_at" },
    { 0xB52C, "sfx_townhouse_door_audio_2nd_floor_bathroom" },
    { 0xB52D, "sfx_townhouse_door_audio_2nd_floor_bedroom" },
    { 0xB52E, "sfx_townhouse_door_audio_2nd_floor_bedroom_bash" },
    { 0xB52F, "sfx_townhouse_door_audio_3rd_floor_price" },
    { 0xB530, "sfx_townhouse_door_audio_3rd_floor_python_enter" },
    { 0xB531, "sfx_townhouse_door_audio_3rd_floor_python_pre" },
    { 0xB532, "sfx_townhouse_door_audio_4th_floor_bathroom" },
    { 0xB533, "sfx_townhouse_door_audio_attic_open" },
    { 0xB534, "sfx_townhouse_door_audio_attic_prep" },
    { 0xB535, "sfx_townhouse_door_audio_backyard_gate" },
    { 0xB536, "sfx_townhouse_door_audio_basement_enter" },
    { 0xB537, "sfx_townhouse_door_audio_basement_prep" },
    { 0xB538, "sfx_townhouse_door_audio_front_open" },
    { 0xB539, "sfx_townhouse_door_audio_kitchen_girl" },
    { 0xB53A, "sfx_townhouse_door_audio_kitchen_girl_pre" },
    { 0xB53B, "sfx_truck_crashed_loops" },
    { 0xB53C, "sfx_trucks_drive_in_01" },
    { 0xB53D, "sfx_trucks_drive_in_02" },
    { 0xB53E, "sfx_tunnel_collapse_02" },
    { 0xB53F, "sfx_unknown_car" },
    { 0xB540, "sfx_van_door_open" },
    { 0xB541, "sfx_van_passby" },
    { 0xB542, "sfx_veh_main_gate_truck_03" },
    { 0xB543, "sfx_veh_main_gate_trucks" },
    { 0xB544, "sfx_veh_side_gate_trucks" },
    { 0xB545, "sfx_wp_01" },
    { 0xB546, "sfx_wp_02" },
    { 0xB547, "shackle_dof" },
    { 0xB548, "shackled_squat_override" },
    { 0xB549, "shader" },
    { 0xB54A, "shadername" },
    { 0xB54B, "shadow_distsqrd" },
    { 0xB54C, "shadow_manager" },
    { 0xB54D, "shadowarea" },
    { 0xB54E, "shadowbias" },
    { 0xB54F, "shadowcaster" },
    { 0xB550, "shadownearplanebias" },
    { 0xB551, "shadowsoftness" },
    { 0xB552, "shaft" },
    { 0xB553, "shaft_ab_light_prep" },
    { 0xB554, "shaft_ab_light_set" },
    { 0xB555, "shaft_ab_light_set_internal" },
    { 0xB556, "shaft_ab_lights" },
    { 0xB557, "shaft_ai_jump_down_think" },
    { 0xB558, "shaft_before_wolf_corpse_cleanup" },
    { 0xB559, "shaft_catchup" },
    { 0xB55A, "shaft_chaser_fire_aware" },
    { 0xB55B, "shaft_difficulty_think" },
    { 0xB55C, "shaft_epic_fire" },
    { 0xB55D, "shaft_epic_fire_catchup" },
    { 0xB55E, "shaft_epic_vfx_think" },
    { 0xB55F, "shaft_epic_vfx_trigs" },
    { 0xB560, "shaft_fall_victim" },
    { 0xB561, "shaft_fall_victim_burn" },
    { 0xB562, "shaft_fire_debug_print" },
    { 0xB563, "shaft_fire_kill_player" },
    { 0xB564, "shaft_fire_light" },
    { 0xB565, "shaft_fire_light_flicker" },
    { 0xB566, "shaft_fire_light_think" },
    { 0xB567, "shaft_fire_light_wobble_think" },
    { 0xB568, "shaft_fire_on_level" },
    { 0xB569, "shaft_fire_victim" },
    { 0xB56A, "shaft_follower" },
    { 0xB56B, "shaft_generic_scriptable_run" },
    { 0xB56C, "shaft_goal_volumes_setup" },
    { 0xB56D, "shaft_hero_planks_clip" },
    { 0xB56E, "shaft_ladder" },
    { 0xB56F, "shaft_ladder_add_fov_scale_factor_override" },
    { 0xB570, "shaft_ladder_fall" },
    { 0xB571, "shaft_ladder_remove_fov_scale_factor_override" },
    { 0xB572, "shaft_ladder_scene_fail_vo" },
    { 0xB573, "shaft_level_timer" },
    { 0xB574, "shaft_lvl2_flicker_light" },
    { 0xB575, "shaft_mayhem_beam_crack" },
    { 0xB576, "shaft_mayhem_corner_collapse" },
    { 0xB577, "shaft_mayhem_tarp_burn_lookat_failsafe" },
    { 0xB578, "shaft_mayhem_tarps" },
    { 0xB579, "shaft_propane_from_model_and_set_state" },
    { 0xB57A, "shaft_propane_kick_anim" },
    { 0xB57B, "shaft_propane_kick_cancel_if_burning_or_hurt" },
    { 0xB57C, "shaft_propane_kick_guy" },
    { 0xB57D, "shaft_propane_kick_setup" },
    { 0xB57E, "shaft_propane_state_change" },
    { 0xB57F, "shaft_propane_toss_guy" },
    { 0xB580, "shaft_reunion_corpse_cleanup" },
    { 0xB581, "shaft_run_sparks" },
    { 0xB582, "shaft_scriptable_board" },
    { 0xB583, "shaft_scriptable_plank" },
    { 0xB584, "shaft_scriptable_propane_tank" },
    { 0xB585, "shaft_scriptable_pulley" },
    { 0xB586, "shaft_scriptable_trigs" },
    { 0xB587, "shaft_scriptables_think" },
    { 0xB588, "shaft_setup" },
    { 0xB589, "shaft_smoke_survival_vo" },
    { 0xB58A, "shaft_smoke_vision_manager" },
    { 0xB58B, "shaft_start" },
    { 0xB58C, "shaft_top_ladder_escaper" },
    { 0xB58D, "shaft_top_ladder_escaper_wakeup" },
    { 0xB58E, "shaft_top_planks_break" },
    { 0xB58F, "shaft_vols" },
    { 0xB590, "shaft_wave_1_guy_fire_aware" },
    { 0xB591, "shaft_wave_1_guys_management" },
    { 0xB592, "shaft_wolf_pa_vo" },
    { 0xB593, "shakes" },
    { 0xB594, "shared_damage_points" },
    { 0xB595, "shared_data" },
    { 0xB596, "shared_portable_turrets" },
    { 0xB597, "shared_turrets" },
    { 0xB598, "shareddata" },
    { 0xB599, "sharedfuncs" },
    { 0xB59A, "sharedrushtimer" },
    { 0xB59B, "sharpturn_setupmotionwarp" },
    { 0xB59C, "sharpturn_terminate" },
    { 0xB59D, "sharpturncorner" },
    { 0xB59E, "sharpturnindex" },
    { 0xB59F, "sharpturnnextpathpoint" },
    { 0xB5A0, "sharpturnnumberindex" },
    { 0xB5A1, "shed_bullet_fx" },
    { 0xB5A2, "shed_umike" },
    { 0xB5A3, "shelf_monitor" },
    { 0xB5A4, "shelf_movement" },
    { 0xB5A5, "shelfexit" },
    { 0xB5A6, "shell" },
    { 0xB5A7, "shell_fx" },
    { 0xB5A8, "shell_sound" },
    { 0xB5A9, "shell_sound_enabled" },
    { 0xB5AA, "shellshock_artilleryearthquake" },
    { 0xB5AB, "shellshock_cleanup" },
    { 0xB5AC, "shellshock_damageinterruptdelayfunc" },
    { 0xB5AD, "shellshock_flashinterruptdelayfunc" },
    { 0xB5AE, "shellshock_gasinterruptdelayfunc" },
    { 0xB5AF, "shellshock_init" },
    { 0xB5B0, "shellshock_interruptdelayfunc" },
    { 0xB5B1, "shellshock_nointerruptdelayfunc" },
    { 0xB5B2, "shellshock_screenshakeonposition" },
    { 0xB5B3, "shellshock_stuninterruptdelayfunc" },
    { 0xB5B4, "shellshock_utility_init" },
    { 0xB5B5, "shellshocked" },
    { 0xB5B6, "shellshockondamage" },
    { 0xB5B7, "shellshockreduction" },
    { 0xB5B8, "shieldbroken" },
    { 0xB5B9, "shieldbullethits" },
    { 0xB5BA, "shielddamage" },
    { 0xB5BB, "shieldhealth" },
    { 0xB5BC, "shieldhudoutline" },
    { 0xB5BD, "shieldmodelvariant" },
    { 0xB5BE, "ship_assault" },
    { 0xB5BF, "shipcrib_linebook_anims" },
    { 0xB5C0, "shitloc" },
    { 0xB5C1, "shock_player" },
    { 0xB5C2, "shockcategory" },
    { 0xB5C3, "shockdeath" },
    { 0xB5C4, "shocked" },
    { 0xB5C5, "shocked_vig_handler" },
    { 0xB5C6, "shockinterruptdelayfuncs" },
    { 0xB5C7, "shockinterrupttime" },
    { 0xB5C8, "shockmelee" },
    { 0xB5C9, "shockname" },
    { 0xB5CA, "shockpainloop_c6_cleanup" },
    { 0xB5CB, "shockpainloop_internal" },
    { 0xB5CC, "shockpriorities" },
    { 0xB5CD, "shocktarget" },
    { 0xB5CE, "shoot_and_kill" },
    { 0xB5CF, "shoot_at_ent_delete_on_flag" },
    { 0xB5D0, "shoot_at_heli" },
    { 0xB5D1, "shoot_at_heli_station" },
    { 0xB5D2, "shoot_at_player_heli" },
    { 0xB5D3, "shoot_at_player_heli_station" },
    { 0xB5D4, "shoot_at_target" },
    { 0xB5D5, "shoot_bridge_guy" },
    { 0xB5D6, "shoot_clearconvergence" },
    { 0xB5D7, "shoot_clearshootparameters" },
    { 0xB5D8, "shoot_doagentnotetrackswithtimeout" },
    { 0xB5D9, "shoot_donotetrackswithtimeout" },
    { 0xB5DA, "shoot_down_heli" },
    { 0xB5DB, "shoot_enableconvergence" },
    { 0xB5DC, "shoot_enemy_until_he_hides_then_shoot_wall" },
    { 0xB5DD, "shoot_gas_grenade_from_notetrack" },
    { 0xB5DE, "shoot_generic" },
    { 0xB5DF, "shoot_getrate" },
    { 0xB5E0, "shoot_gun" },
    { 0xB5E1, "shoot_gun_from_notetrack" },
    { 0xB5E2, "shoot_gun_from_notetrack_player" },
    { 0xB5E3, "shoot_init" },
    { 0xB5E4, "shoot_mg" },
    { 0xB5E5, "shoot_mg_cleanup" },
    { 0xB5E6, "shoot_mg42_script_targets" },
    { 0xB5E7, "shoot_out_field_lights" },
    { 0xB5E8, "shoot_out_lights_thread" },
    { 0xB5E9, "shoot_out_perimeter_lights" },
    { 0xB5EA, "shoot_override" },
    { 0xB5EB, "shoot_patrol_guy" },
    { 0xB5EC, "shoot_player_if_in_center" },
    { 0xB5ED, "shoot_playidleanimloop" },
    { 0xB5EE, "shoot_playidleanimloop_sniper" },
    { 0xB5EF, "shoot_rockets_at_target" },
    { 0xB5F0, "shoot_setshootparameters" },
    { 0xB5F1, "shoot_shock" },
    { 0xB5F2, "shoot_shotgunpumpsound" },
    { 0xB5F3, "shoot_stopsoundwithdelay" },
    { 0xB5F4, "shoot_terminate" },
    { 0xB5F5, "shoot_timeout" },
    { 0xB5F6, "shoot_update" },
    { 0xB5F7, "shoot_updateparams" },
    { 0xB5F8, "shoot_vehicle_turret_at_attacker" },
    { 0xB5F9, "shoot_vehicle_turret_at_nearest_player" },
    { 0xB5FA, "shoot_while_driving_thread" },
    { 0xB5FB, "shootambient_targetspline" },
    { 0xB5FC, "shootambienttarget" },
    { 0xB5FD, "shootanimtime" },
    { 0xB5FE, "shootatshootentorpos" },
    { 0xB5FF, "shootenabled" },
    { 0xB600, "shootenemytarget_bullets" },
    { 0xB601, "shootenemytarget_bullets_debugline" },
    { 0xB602, "shootenemywrapper" },
    { 0xB603, "shootenemywrapper_func" },
    { 0xB604, "shootenemywrapper_normal" },
    { 0xB605, "shootenemywrapper_shootnotify" },
    { 0xB606, "shootent" },
    { 0xB607, "shootentvelocity" },
    { 0xB608, "shootforced" },
    { 0xB609, "shooting" },
    { 0xB60A, "shooting_monitor" },
    { 0xB60B, "shooting_target" },
    { 0xB60C, "shootnotetrack" },
    { 0xB60D, "shootobjective" },
    { 0xB60E, "shootobjective_internal" },
    { 0xB60F, "shootobjective_suppress" },
    { 0xB610, "shootparams" },
    { 0xB611, "shootparams_forceaim" },
    { 0xB612, "shootpos" },
    { 0xB613, "shootposoverride" },
    { 0xB614, "shootposwrapper" },
    { 0xB615, "shootposwrapper_func" },
    { 0xB616, "shootrateoverride" },
    { 0xB617, "shootshocksentrysamtarget" },
    { 0xB618, "shootstate" },
    { 0xB619, "shootstyle" },
    { 0xB61A, "shootstylefastburst" },
    { 0xB61B, "shootstylemgturret" },
    { 0xB61C, "shootstylesingle" },
    { 0xB61D, "shoottokill" },
    { 0xB61E, "shootuntilshootbehaviorchange" },
    { 0xB61F, "short" },
    { 0xB620, "short_and_long_delay" },
    { 0xB621, "shortencolor" },
    { 0xB622, "shortposecachearray" },
    { 0xB623, "shortposecachenode" },
    { 0xB624, "shot" },
    { 0xB625, "shot_at_check" },
    { 0xB626, "shot_at_react" },
    { 0xB627, "shot_count" },
    { 0xB628, "shot_in_back" },
    { 0xB629, "shotduringanim" },
    { 0xB62A, "shotfired" },
    { 0xB62B, "shotfiredphysicssphere" },
    { 0xB62C, "shotgroupaccuracy" },
    { 0xB62D, "shotgroupactive" },
    { 0xB62E, "shotgroupcount" },
    { 0xB62F, "shotgroupendwatcher" },
    { 0xB630, "shotgrouplastaccuracy" },
    { 0xB631, "shotgrouplastcount" },
    { 0xB632, "shotgun_rest" },
    { 0xB633, "shotgun_weapons_array" },
    { 0xB634, "shotguncollateral" },
    { 0xB635, "shotgundamagemod" },
    { 0xB636, "shotgunfirerate" },
    { 0xB637, "shotgunkillsinaframecount" },
    { 0xB638, "shotgunner_combat" },
    { 0xB639, "shotgunner_info_loop" },
    { 0xB63A, "shotgunner_spawn" },
    { 0xB63B, "shotgunpumpsound" },
    { 0xB63C, "shothit" },
    { 0xB63D, "shotisbadidea" },
    { 0xB63E, "shotisreasonablysafe" },
    { 0xB63F, "shotmissed" },
    { 0xB640, "shotrecord" },
    { 0xB641, "shots_fired" },
    { 0xB642, "shots_fired_recorder" },
    { 0xB643, "shots_hit" },
    { 0xB644, "shots_per_round" },
    { 0xB645, "shotsfired" },
    { 0xB646, "shotsfiredwithweapon" },
    { 0xB647, "shotslandedlmg" },
    { 0xB648, "shotsleft" },
    { 0xB649, "shotsmissedcount" },
    { 0xB64A, "shotsontargetwithweapon" },
    { 0xB64B, "shotstaken" },
    { 0xB64C, "should_abort" },
    { 0xB64D, "should_adjust_camera_anchor_position" },
    { 0xB64E, "should_advance_to_next_goal_struct" },
    { 0xB64F, "should_advance_to_next_goal_volume" },
    { 0xB650, "should_allow_airdrop" },
    { 0xB651, "should_allow_far_search_dist_func" },
    { 0xB652, "should_append_player_prefix" },
    { 0xB653, "should_append_player_suffix" },
    { 0xB654, "should_apply_dot" },
    { 0xB655, "should_bash_open" },
    { 0xB656, "should_be_affected_by_trap" },
    { 0xB657, "should_combat_react" },
    { 0xB658, "should_continue_current_shot_run" },
    { 0xB659, "should_continue_progress_bar_think" },
    { 0xB65A, "should_create_exposed_node" },
    { 0xB65B, "should_delay_flag_decision" },
    { 0xB65C, "should_deploy_front_suicide_truck" },
    { 0xB65D, "should_disable_infil_for_player" },
    { 0xB65E, "should_do_anim" },
    { 0xB65F, "should_do_arrivals" },
    { 0xB660, "should_do_damage_check_func" },
    { 0xB661, "should_do_damage_checks" },
    { 0xB662, "should_do_death_vignette" },
    { 0xB663, "should_do_exits" },
    { 0xB664, "should_do_gesture" },
    { 0xB665, "should_do_immediate_ragdoll" },
    { 0xB666, "should_do_pain_anim" },
    { 0xB667, "should_do_quest_step_func" },
    { 0xB668, "should_do_ragdoll" },
    { 0xB669, "should_drop_grenade" },
    { 0xB66A, "should_drop_hvt_key" },
    { 0xB66B, "should_drop_intel" },
    { 0xB66C, "should_drop_intel_func" },
    { 0xB66D, "should_drop_intel_piece" },
    { 0xB66E, "should_drop_weapon" },
    { 0xB66F, "should_enable_seat_when_exit_vehicle" },
    { 0xB670, "should_execute_continue" },
    { 0xB671, "should_filter_out_friendly_damage" },
    { 0xB672, "should_fire" },
    { 0xB673, "should_get_currency_from_kill" },
    { 0xB674, "should_give_extra_charge" },
    { 0xB675, "should_give_orghealth" },
    { 0xB676, "should_grunt" },
    { 0xB677, "should_hit_target" },
    { 0xB678, "should_hunt_player" },
    { 0xB679, "should_ignore_attacker_or_team_damage_filter" },
    { 0xB67A, "should_ignore_mod" },
    { 0xB67B, "should_ignore_sprint_footstep" },
    { 0xB67C, "should_intel_drop_func" },
    { 0xB67D, "should_interaction_fill_consumable_meter" },
    { 0xB67E, "should_intercept" },
    { 0xB67F, "should_interrupt_vo_system" },
    { 0xB680, "should_kill_off_flags" },
    { 0xB681, "should_kill_player" },
    { 0xB682, "should_load_new_map" },
    { 0xB683, "should_monitor_shooting" },
    { 0xB684, "should_move_to_target" },
    { 0xB685, "should_move_to_target_dist" },
    { 0xB686, "should_open_left" },
    { 0xB687, "should_play_cough_gesture" },
    { 0xB688, "should_play_melee_blood_vfx" },
    { 0xB689, "should_play_melee_blood_vfx_func" },
    { 0xB68A, "should_play_transformation_anim" },
    { 0xB68B, "should_play_tread_vfx" },
    { 0xB68C, "should_play_vo" },
    { 0xB68D, "should_print_warning_message" },
    { 0xB68E, "should_purge_undefined" },
    { 0xB68F, "should_put_player_outline_on" },
    { 0xB690, "should_real_fire" },
    { 0xB691, "should_record_final_score_cam" },
    { 0xB692, "should_remove_one_item" },
    { 0xB693, "should_revive_continue" },
    { 0xB694, "should_roam" },
    { 0xB695, "should_run_event" },
    { 0xB696, "should_run_event_func" },
    { 0xB697, "should_run_objectives" },
    { 0xB698, "should_select_new_ambush_point" },
    { 0xB699, "should_shoot_destructible_target" },
    { 0xB69A, "should_shoot_if_player_mounted" },
    { 0xB69B, "should_show_obj" },
    { 0xB69C, "should_show_revive_icon_to_player_func" },
    { 0xB69D, "should_show_tutorial_func" },
    { 0xB69E, "should_skip" },
    { 0xB69F, "should_skip_first_few_shot" },
    { 0xB6A0, "should_skip_interrogation" },
    { 0xB6A1, "should_skip_laststand" },
    { 0xB6A2, "should_skip_oilfire" },
    { 0xB6A3, "should_skip_torture_scene" },
    { 0xB6A4, "should_sound_take_priority" },
    { 0xB6A5, "should_spawn_ied_zone" },
    { 0xB6A6, "should_start_cautious_approach_default" },
    { 0xB6A7, "should_start_cautious_approach_dom" },
    { 0xB6A8, "should_start_cautious_approach_sd" },
    { 0xB6A9, "should_stop_seeking_weapon" },
    { 0xB6AA, "should_stop_using_bomb_detonator" },
    { 0xB6AB, "should_take_damage_from_attacker_or_team" },
    { 0xB6AC, "should_take_players_current_weapon" },
    { 0xB6AD, "should_teleport" },
    { 0xB6AE, "should_teleport_to_nearby_target" },
    { 0xB6AF, "should_track_weapon_fired" },
    { 0xB6B0, "should_try_generic_radio_confirmation" },
    { 0xB6B1, "should_turn_off_states" },
    { 0xB6B2, "should_update_ai_nvg_state" },
    { 0xB6B3, "should_update_func" },
    { 0xB6B4, "should_update_leaderboard_stats" },
    { 0xB6B5, "should_use_door_spawn_anim" },
    { 0xB6B6, "should_use_exit_anim" },
    { 0xB6B7, "should_wait_for_cs_flag" },
    { 0xB6B8, "should_warn_nonsuppressed" },
    { 0xB6B9, "shouldabortstrafe" },
    { 0xB6BA, "shouldabortwallrunattach" },
    { 0xB6BB, "shouldactivatedeathshield" },
    { 0xB6BC, "shouldaddtoarbitraryuptrigger" },
    { 0xB6BD, "shouldadvanceusingboundingoverwatch" },
    { 0xB6BE, "shouldaffectclaymore" },
    { 0xB6BF, "shouldallowinstantclassswap" },
    { 0xB6C0, "shouldattachmentsavealtstate" },
    { 0xB6C1, "shouldattemptanyreacquire" },
    { 0xB6C2, "shouldattemptcrawlingpain" },
    { 0xB6C3, "shouldattemptreacquirecharge" },
    { 0xB6C4, "shouldattemptstumblingpain" },
    { 0xB6C5, "shouldbashopen" },
    { 0xB6C6, "shouldbeajerk" },
    { 0xB6C7, "shouldbefrantic" },
    { 0xB6C8, "shouldbeginfiring" },
    { 0xB6C9, "shouldbeginshuffleexit" },
    { 0xB6CA, "shouldbeinlmgcover" },
    { 0xB6CB, "shouldblindfire" },
    { 0xB6CC, "shouldbounce" },
    { 0xB6CD, "shouldcasualkillerreacttonewenemy" },
    { 0xB6CE, "shouldchangestanceforfun" },
    { 0xB6CF, "shouldconsiderarrival" },
    { 0xB6D0, "shouldconsiderarrivalaftercodemove" },
    { 0xB6D1, "shouldconsidertraversearrival" },
    { 0xB6D2, "shouldcoverexpose" },
    { 0xB6D3, "shouldcoverexposedreload" },
    { 0xB6D4, "shouldcovermultiswitch" },
    { 0xB6D5, "shouldcqb" },
    { 0xB6D6, "shouldcqbaim" },
    { 0xB6D7, "shouldcustomexit" },
    { 0xB6D8, "shouldcustomtransition" },
    { 0xB6D9, "shoulddamageshielddowntoground" },
    { 0xB6DA, "shoulddeploylmg" },
    { 0xB6DB, "shoulddirectlytransition" },
    { 0xB6DC, "shoulddismountlmg" },
    { 0xB6DD, "shoulddisplayhud" },
    { 0xB6DE, "shoulddoanylongdeath" },
    { 0xB6DF, "shoulddoarrival" },
    { 0xB6E0, "shoulddobulletwhizby" },
    { 0xB6E1, "shoulddocoverlongdeath" },
    { 0xB6E2, "shoulddocrawlingbacklongdeath" },
    { 0xB6E3, "shoulddocrawlingonbellylongdeath" },
    { 0xB6E4, "shoulddocrawllongdeath" },
    { 0xB6E5, "shoulddodamageinvulnerabilty" },
    { 0xB6E6, "shoulddodge" },
    { 0xB6E7, "shoulddodyingbackcrawl" },
    { 0xB6E8, "shoulddodyingcrawl" },
    { 0xB6E9, "shoulddoexposedlongdeath" },
    { 0xB6EA, "shoulddofinaldeath" },
    { 0xB6EB, "shoulddoforcedmercy" },
    { 0xB6EC, "shoulddohealthdamageeffects" },
    { 0xB6ED, "shoulddolongdeathgrenade" },
    { 0xB6EE, "shoulddolongdeathgrenadefinal" },
    { 0xB6EF, "shoulddomercy" },
    { 0xB6F0, "shoulddomercytransition" },
    { 0xB6F1, "shoulddopainvision" },
    { 0xB6F2, "shoulddorunningforwarddeath" },
    { 0xB6F3, "shoulddosemiforvariety" },
    { 0xB6F4, "shoulddosemiprobabilityline" },
    { 0xB6F5, "shoulddosharpturn" },
    { 0xB6F6, "shoulddoshootinglongdeath" },
    { 0xB6F7, "shoulddostrongbulletdamage" },
    { 0xB6F8, "shoulddostumblinglongdeath" },
    { 0xB6F9, "shoulddotraditionaltraverse" },
    { 0xB6FA, "shoulddotraversalarrival" },
    { 0xB6FB, "shoulddotraversaltransition" },
    { 0xB6FC, "shoulddowallrunsharpturn" },
    { 0xB6FD, "shoulddoweaponnag" },
    { 0xB6FE, "shoulddroploot" },
    { 0xB6FF, "shoulddropscavengerbag" },
    { 0xB700, "shouldendlongdeath" },
    { 0xB701, "shouldendsniperidle" },
    { 0xB702, "shouldenterstairsstatepassthrough" },
    { 0xB703, "shouldentervehicle" },
    { 0xB704, "shouldentervehicleearly" },
    { 0xB705, "shouldexitstairsstate" },
    { 0xB706, "shouldexitvehicle" },
    { 0xB707, "shouldexplode" },
    { 0xB708, "shouldfaceenemyinexposed" },
    { 0xB709, "shouldfade" },
    { 0xB70A, "shouldfindnavmodifier" },
    { 0xB70B, "shouldfinishlongdeath" },
    { 0xB70C, "shouldfireintoairdeath" },
    { 0xB70D, "shouldflashinvul" },
    { 0xB70E, "shouldflipover" },
    { 0xB70F, "shouldforcesnipermissshot" },
    { 0xB710, "shouldforceupdatebt" },
    { 0xB711, "shouldfree" },
    { 0xB712, "shouldfreezeplayercontrolatspawn" },
    { 0xB713, "shouldgib" },
    { 0xB714, "shouldgivedefendersadvantage" },
    { 0xB715, "shouldgodirectlytospectate" },
    { 0xB716, "shouldgodirectlytospectatefunc" },
    { 0xB717, "shouldgrenadeavoid" },
    { 0xB718, "shouldgrenadedive" },
    { 0xB719, "shouldheadpop" },
    { 0xB71A, "shouldhelmetpop" },
    { 0xB71B, "shouldhelmetpopondeath" },
    { 0xB71C, "shouldhelmetpoponpain" },
    { 0xB71D, "shouldhelpadvancingteammate" },
    { 0xB71E, "shouldidlebark" },
    { 0xB71F, "shouldinitiallyattackfromexposedtime" },
    { 0xB720, "shouldinterruptstairsarrival" },
    { 0xB721, "shouldjoinsquad" },
    { 0xB722, "shouldkeepcrawling" },
    { 0xB723, "shouldkillfalling" },
    { 0xB724, "shouldkillimmediatly" },
    { 0xB725, "shouldkillmelee" },
    { 0xB726, "shouldleaveanimscripted" },
    { 0xB727, "shouldleavecasualkiller" },
    { 0xB728, "shouldleavecasualkillerimmediately" },
    { 0xB729, "shouldlogcodcasterclientmatchdata" },
    { 0xB72A, "shouldlookforinitialcover" },
    { 0xB72B, "shouldlookorpeek" },
    { 0xB72C, "shouldmelee" },
    { 0xB72D, "shouldmodescoreonties" },
    { 0xB72E, "shouldmodesetsquads" },
    { 0xB72F, "shouldnotblockspawns" },
    { 0xB730, "shouldnt_spawn_because_of_script_difficulty" },
    { 0xB731, "shouldopendoor" },
    { 0xB732, "shouldorienttoentervehicle" },
    { 0xB733, "shouldoverkill" },
    { 0xB734, "shouldpaincoverfaceplayer" },
    { 0xB735, "shouldpainfaceplayer" },
    { 0xB736, "shouldpainrunfaceplayer" },
    { 0xB737, "shouldpainruntostrafereverse" },
    { 0xB738, "shouldpatrolreactaim" },
    { 0xB739, "shouldpatrolreactlookaround" },
    { 0xB73A, "shouldpatrolreactlookaroundabort" },
    { 0xB73B, "shouldpeekwhilecanseefromexposed" },
    { 0xB73C, "shouldpingobject" },
    { 0xB73D, "shouldplayarenaintro" },
    { 0xB73E, "shouldplaybalconydeath" },
    { 0xB73F, "shouldplaybalconyraildeath" },
    { 0xB740, "shouldplayerlogevents" },
    { 0xB741, "shouldplayexplosivedeath" },
    { 0xB742, "shouldplayfiregesture" },
    { 0xB743, "shouldplayhalfwayvo" },
    { 0xB744, "shouldplayinteractable" },
    { 0xB745, "shouldplayovertime" },
    { 0xB746, "shouldplaypainanim" },
    { 0xB747, "shouldplaypainanimdefault" },
    { 0xB748, "shouldplaypainbreathingsound" },
    { 0xB749, "shouldplayplayermeleedeath" },
    { 0xB74A, "shouldplaypushedanim" },
    { 0xB74B, "shouldplayscoretobeatot" },
    { 0xB74C, "shouldplayshieldbashdeath" },
    { 0xB74D, "shouldplayshockdeath" },
    { 0xB74E, "shouldplayshuffleenter" },
    { 0xB74F, "shouldplaysmartobjectanim" },
    { 0xB750, "shouldplaysmartobjectdeath" },
    { 0xB751, "shouldplaysmartobjectpain" },
    { 0xB752, "shouldplaysmartobjectreact" },
    { 0xB753, "shouldplaystrongdamagedeath" },
    { 0xB754, "shouldplaystumble" },
    { 0xB755, "shouldplaysuffocatedeath" },
    { 0xB756, "shouldplaytimetobeatot" },
    { 0xB757, "shouldplaywinbytwo" },
    { 0xB758, "shouldqueuemidmatchaward" },
    { 0xB759, "shouldreacttolight" },
    { 0xB75A, "shouldreacttonewenemy" },
    { 0xB75B, "shouldrefundsuper" },
    { 0xB75C, "shouldreload" },
    { 0xB75D, "shouldreloadwhilemoving" },
    { 0xB75E, "shouldremovefromarbitraryuptrigger" },
    { 0xB75F, "shouldresetgiveuponsuppressiontimer" },
    { 0xB760, "shouldrestartaimchange" },
    { 0xB761, "shouldrunserversideeffects" },
    { 0xB762, "shouldshoot" },
    { 0xB763, "shouldshootduringlongdeath" },
    { 0xB764, "shouldshootenemyent" },
    { 0xB765, "shouldshootplayer" },
    { 0xB766, "shouldshowcompassduetoradar" },
    { 0xB767, "shouldshowcoverwarning" },
    { 0xB768, "shouldshowtutorial" },
    { 0xB769, "shouldshowwidemapshot" },
    { 0xB76A, "shouldskipdeathshield" },
    { 0xB76B, "shouldskipdeathsound" },
    { 0xB76C, "shouldskipdeathsshield" },
    { 0xB76D, "shouldskipfirstraise" },
    { 0xB76E, "shouldskiplaststand" },
    { 0xB76F, "shouldskippotg" },
    { 0xB770, "shouldsmartobjectreact" },
    { 0xB771, "shouldsnaptocover" },
    { 0xB772, "shouldsnaptocover_checktype" },
    { 0xB773, "shouldsniperbeginfiring" },
    { 0xB774, "shouldsniperidle" },
    { 0xB775, "shouldspawnbots" },
    { 0xB776, "shouldspawntags" },
    { 0xB777, "shouldsplash" },
    { 0xB778, "shouldstartarrival" },
    { 0xB779, "shouldstartarrivalpassthrough" },
    { 0xB77A, "shouldstartarrivalpassthroughcivilian" },
    { 0xB77B, "shouldstartarrivalpassthroughswitch" },
    { 0xB77C, "shouldstartarrivalpassthroughswitchcustom" },
    { 0xB77D, "shouldstartarrivalpatrol" },
    { 0xB77E, "shouldstartcasualarrival" },
    { 0xB77F, "shouldstartcasualarrivalaftercodemove" },
    { 0xB780, "shouldstartcasualarrivalwithgun" },
    { 0xB781, "shouldstartcasualarrivalwithgunaftercodemove" },
    { 0xB782, "shouldstartcustomidle" },
    { 0xB783, "shouldstarttraverse" },
    { 0xB784, "shouldstayalive" },
    { 0xB785, "shouldstopcustomidle" },
    { 0xB786, "shouldstrafe" },
    { 0xB787, "shouldstrafeaimchange" },
    { 0xB788, "shouldstrafearrive" },
    { 0xB789, "shouldstumble" },
    { 0xB78A, "shouldsuppress" },
    { 0xB78B, "shouldswitchtosidearm" },
    { 0xB78C, "shouldtakedamage" },
    { 0xB78D, "shouldthrowgrenade" },
    { 0xB78E, "shouldthrowgrenadeatenemyasap" },
    { 0xB78F, "shouldtracksuperweaponstats" },
    { 0xB790, "shouldtransitionparams" },
    { 0xB791, "shouldtraversetransitionto" },
    { 0xB792, "shouldtryleavenode" },
    { 0xB793, "shouldupdatesquadleadermovement" },
    { 0xB794, "shouldusedamageshieldanim" },
    { 0xB795, "shoulduseexplosiveindicator" },
    { 0xB796, "shoulduselasertag" },
    { 0xB797, "shoulduseprecomputedlos" },
    { 0xB798, "shoulduseteamstartspawn" },
    { 0xB799, "shouldusewallsize1" },
    { 0xB79A, "shouldusewallsize2" },
    { 0xB79B, "shouldusewallsize3" },
    { 0xB79C, "shouldusewallsize4" },
    { 0xB79D, "shouldusewarparrival" },
    { 0xB79E, "shouldusewarpnotetracks" },
    { 0xB79F, "shouldverifydedicatedconfig" },
    { 0xB7A0, "shouldwaitforsquadspawn" },
    { 0xB7A1, "shouldwalkandtalk" },
    { 0xB7A2, "shouldwallrunshoot" },
    { 0xB7A3, "shouldwallruntovault" },
    { 0xB7A4, "shouldweaponsavealtstate" },
    { 0xB7A5, "shove" },
    { 0xB7A6, "shove_gesture" },
    { 0xB7A7, "show_active_modules" },
    { 0xB7A8, "show_aftermath_cars" },
    { 0xB7A9, "show_aftermath_debris" },
    { 0xB7AA, "show_aftermath_geo" },
    { 0xB7AB, "show_aftermath_windows" },
    { 0xB7AC, "show_ai_marker_vfx_to_player" },
    { 0xB7AD, "show_ai_within_scan_range" },
    { 0xB7AE, "show_ai_within_target_circle" },
    { 0xB7AF, "show_all_cover_nodes" },
    { 0xB7B0, "show_all_non_overwatch_ied_marker_vfx_to_player" },
    { 0xB7B1, "show_all_player_wave_started_splash" },
    { 0xB7B2, "show_all_revive_icons" },
    { 0xB7B3, "show_animname" },
    { 0xB7B4, "show_animnames" },
    { 0xB7B5, "show_arrivalexit_state" },
    { 0xB7B6, "show_bad_path" },
    { 0xB7B7, "show_betting_to_players" },
    { 0xB7B8, "show_bomb_to_drone" },
    { 0xB7B9, "show_bullets" },
    { 0xB7BA, "show_chopper" },
    { 0xB7BB, "show_clacker" },
    { 0xB7BC, "show_combat_icon_to" },
    { 0xB7BD, "show_critical_target_icon_to_player" },
    { 0xB7BE, "show_cursor_on_prompt_knife" },
    { 0xB7BF, "show_damage_direction" },
    { 0xB7C0, "show_damage_state_health_ratio" },
    { 0xB7C1, "show_destroyed_choppers" },
    { 0xB7C2, "show_dist_override" },
    { 0xB7C3, "show_document" },
    { 0xB7C4, "show_encounter_scores" },
    { 0xB7C5, "show_enemy_ai_to_overwatch_player" },
    { 0xB7C6, "show_enemy_hvt_get_away_message" },
    { 0xB7C7, "show_ent_array" },
    { 0xB7C8, "show_entity" },
    { 0xB7C9, "show_ents" },
    { 0xB7CA, "show_exfil_progress" },
    { 0xB7CB, "show_exploder_models" },
    { 0xB7CC, "show_exploder_models_proc" },
    { 0xB7CD, "show_fake_player" },
    { 0xB7CE, "show_false_positive_dot" },
    { 0xB7CF, "show_false_positive_dots" },
    { 0xB7D0, "show_finale_bloodsplat" },
    { 0xB7D1, "show_garage_waypoint" },
    { 0xB7D2, "show_give_up_hint" },
    { 0xB7D3, "show_head" },
    { 0xB7D4, "show_health" },
    { 0xB7D5, "show_health_on_objective_icon" },
    { 0xB7D6, "show_help" },
    { 0xB7D7, "show_hud" },
    { 0xB7D8, "show_hud_listener" },
    { 0xB7D9, "show_hud_listener_logic" },
    { 0xB7DA, "show_identified_ied_to_non_overwatch" },
    { 0xB7DB, "show_identified_ied_to_overwatch" },
    { 0xB7DC, "show_identified_ieds_to_overwatch" },
    { 0xB7DD, "show_ied" },
    { 0xB7DE, "show_ied_nearby_message_think" },
    { 0xB7DF, "show_ied_zone_to_player" },
    { 0xB7E0, "show_interact_vehicle" },
    { 0xB7E1, "show_introscreen_text" },
    { 0xB7E2, "show_mask" },
    { 0xB7E3, "show_middle_enemy_turret" },
    { 0xB7E4, "show_name_on_basement_intro_skip" },
    { 0xB7E5, "show_non_overwatch_ied_marker_vfx_to_player" },
    { 0xB7E6, "show_objective_icon" },
    { 0xB7E7, "show_objective_tutorial" },
    { 0xB7E8, "show_objective_widget" },
    { 0xB7E9, "show_player" },
    { 0xB7EA, "show_respawn_hint" },
    { 0xB7EB, "show_respawn_hint_lastplayer" },
    { 0xB7EC, "show_revive_icon_to_player" },
    { 0xB7ED, "show_running_tool_message" },
    { 0xB7EE, "show_safehouse_regroup_text" },
    { 0xB7EF, "show_scaffolding_mayhem" },
    { 0xB7F0, "show_selection_menu" },
    { 0xB7F1, "show_self_pressed_buttons" },
    { 0xB7F2, "show_solid" },
    { 0xB7F3, "show_spotted_text" },
    { 0xB7F4, "show_stealth_meter_to" },
    { 0xB7F5, "show_stealth_meter_to_all_players" },
    { 0xB7F6, "show_targetnames" },
    { 0xB7F7, "show_terrorist_respawner" },
    { 0xB7F8, "show_to_players_that_are_near" },
    { 0xB7F9, "show_tripwire_hint" },
    { 0xB7FA, "show_turret" },
    { 0xB7FB, "show_unidentified_ied_within_scan_range" },
    { 0xB7FC, "show_unidentified_ied_within_target_circle" },
    { 0xB7FD, "show_vehicle_damage_state" },
    { 0xB7FE, "show_vip_waypoints" },
    { 0xB7FF, "show_wave_hud" },
    { 0xB800, "showactors" },
    { 0xB801, "showallambulancesforplayer" },
    { 0xB802, "showallambulancesforteam" },
    { 0xB803, "showallcachesimmediate" },
    { 0xB804, "showallcachesonroundstart" },
    { 0xB805, "showandhidebreachobjectsbasedonavailability" },
    { 0xB806, "showarmorvestmodeldelayed" },
    { 0xB807, "showassassinationhud" },
    { 0xB808, "showassplash" },
    { 0xB809, "showballbaseeffecttoplayer" },
    { 0xB80A, "showbaseeffecttoplayer" },
    { 0xB80B, "showbettinghud" },
    { 0xB80C, "showcaches" },
    { 0xB80D, "showcapturedhardpointeffecttoplayer" },
    { 0xB80E, "showchallengesplash" },
    { 0xB80F, "showcontestedbrush" },
    { 0xB810, "showcratesplash" },
    { 0xB811, "showdebugline" },
    { 0xB812, "showdebugproc" },
    { 0xB813, "showdebugtrace" },
    { 0xB814, "showelem" },
    { 0xB815, "showendzonevisualsforteam" },
    { 0xB816, "showenemybrush" },
    { 0xB817, "showenemycapturebrush" },
    { 0xB818, "showenemycarrier" },
    { 0xB819, "showenemydeathloc" },
    { 0xB81A, "showerrormessage" },
    { 0xB81B, "showerrormessagefunc" },
    { 0xB81C, "showerrormessagetoallplayers" },
    { 0xB81D, "showfakeloadout" },
    { 0xB81E, "showflagoutline" },
    { 0xB81F, "showflagradiuseffecttoplayers" },
    { 0xB820, "showfriendicon" },
    { 0xB821, "showfriendlybrush" },
    { 0xB822, "showfriendlycapturebrush" },
    { 0xB823, "showfxarray" },
    { 0xB824, "showgamemodeobjectivetext" },
    { 0xB825, "showheadicon" },
    { 0xB826, "showheadicontoenemy" },
    { 0xB827, "showicon" },
    { 0xB828, "showing_damage_state" },
    { 0xB829, "showing_ied_nearby_message" },
    { 0xB82A, "showing_the_stealth_meter_to_players" },
    { 0xB82B, "showingcursor" },
    { 0xB82C, "showingfinalkillcam" },
    { 0xB82D, "showkillstreaksplash" },
    { 0xB82E, "showlastenemysightpos" },
    { 0xB82F, "showlines" },
    { 0xB830, "showmatchhint" },
    { 0xB831, "showmessage" },
    { 0xB832, "showminimap" },
    { 0xB833, "showmiscmessage" },
    { 0xB834, "showmiscmessagetoteam" },
    { 0xB835, "showmwlogo" },
    { 0xB836, "showneutralbrush" },
    { 0xB837, "showninfected" },
    { 0xB838, "showntoents" },
    { 0xB839, "showntoteams" },
    { 0xB83A, "shownukelocation" },
    { 0xB83B, "showobjprogress" },
    { 0xB83C, "showobjprogressbackup" },
    { 0xB83D, "showoncompass" },
    { 0xB83E, "showonminimap" },
    { 0xB83F, "showonscreenbloodeffects" },
    { 0xB840, "showplacedmodel" },
    { 0xB841, "showprogressforteam" },
    { 0xB842, "showqueuehud" },
    { 0xB843, "showrespawnwarningmessage" },
    { 0xB844, "showrouter" },
    { 0xB845, "showspecificteamprogress" },
    { 0xB846, "showsplash" },
    { 0xB847, "showsplashinternal" },
    { 0xB848, "showsplashtoteam" },
    { 0xB849, "showsplashwithkillcheckhack" },
    { 0xB84A, "showsuicidehintstring" },
    { 0xB84B, "showsuperremindersplash" },
    { 0xB84C, "showtablets" },
    { 0xB84D, "showtargettime" },
    { 0xB84E, "showteamicons" },
    { 0xB84F, "showtimer" },
    { 0xB850, "showto" },
    { 0xB851, "showtoall" },
    { 0xB852, "showtoallfactions" },
    { 0xB853, "showtoteam" },
    { 0xB854, "showuavminimaponspawn" },
    { 0xB855, "showuidamageflash" },
    { 0xB856, "showuielements" },
    { 0xB857, "showuseresultsfeedback" },
    { 0xB858, "showvalueincreasesplash" },
    { 0xB859, "showwaverespawnmessage" },
    { 0xB85A, "showweaponmagattachment" },
    { 0xB85B, "showworldicon" },
    { 0xB85C, "showzonecontestedbrush" },
    { 0xB85D, "showzoneenemybrush" },
    { 0xB85E, "showzonefriendlybrush" },
    { 0xB85F, "showzoneneutralbrush" },
    { 0xB860, "shrapnelregendelay" },
    { 0xB861, "shufflefromnode" },
    { 0xB862, "shutdown" },
    { 0xB863, "shutdown_battlechatter" },
    { 0xB864, "shutdown_player_stay_behind_ai" },
    { 0xB865, "shutdown_squadbattlechatter" },
    { 0xB866, "shutdowncontact" },
    { 0xB867, "shutdowndropbagobjectiveicon" },
    { 0xB868, "shutdownenemysystem" },
    { 0xB869, "shutdowngulag" },
    { 0xB86A, "shutup_when_hit" },
    { 0xB86B, "side_alley_player_blocker" },
    { 0xB86C, "side_arm_array" },
    { 0xB86D, "side_breach_1f_vo" },
    { 0xB86E, "side_window_kill_target" },
    { 0xB86F, "side_window_moveup" },
    { 0xB870, "side_window_target" },
    { 0xB871, "sideisleftright" },
    { 0xB872, "sideoffset" },
    { 0xB873, "sidesteprate" },
    { 0xB874, "siege_a_xpos" },
    { 0xB875, "siege_a_ypos" },
    { 0xB876, "siege_a_zpos" },
    { 0xB877, "siege_activated" },
    { 0xB878, "siege_b_xpos" },
    { 0xB879, "siege_b_ypos" },
    { 0xB87A, "siege_b_zpos" },
    { 0xB87B, "siege_bot_team_need_flags" },
    { 0xB87C, "siege_c_xpos" },
    { 0xB87D, "siege_c_ypos" },
    { 0xB87E, "siege_c_zpos" },
    { 0xB87F, "siege_speedscale" },
    { 0xB880, "siegeflagcapturing" },
    { 0xB881, "siegegameinactive" },
    { 0xB882, "siegelatecomer" },
    { 0xB883, "siegetimeleft" },
    { 0xB884, "siegetimerstate" },
    { 0xB885, "sight_blocker_markers" },
    { 0xB886, "sight_blocker_models" },
    { 0xB887, "sight_distsqrd" },
    { 0xB888, "sight_ignore" },
    { 0xB889, "sightedenemies" },
    { 0xB88A, "sightlastactivetime" },
    { 0xB88B, "sightmaxdistance" },
    { 0xB88C, "sightpos" },
    { 0xB88D, "sightposleft" },
    { 0xB88E, "sightpostime" },
    { 0xB88F, "sightstate" },
    { 0xB890, "sighttime" },
    { 0xB891, "sighttrace_from_player" },
    { 0xB892, "sighttracepoint" },
    { 0xB893, "sign" },
    { 0xB894, "sign_reflections" },
    { 0xB895, "signalfiremain" },
    { 0xB896, "signallightsthink" },
    { 0xB897, "silenced_pistol" },
    { 0xB898, "silentplant" },
    { 0xB899, "silverscore" },
    { 0xB89A, "silvertime" },
    { 0xB89B, "similar_convoy_settings" },
    { 0xB89C, "similar_nodes_nearby" },
    { 0xB89D, "simple_dialogue" },
    { 0xB89E, "simple_dialogue_on_tag" },
    { 0xB89F, "simple_gesture_parent" },
    { 0xB8A0, "simple_interaction_idles" },
    { 0xB8A1, "simple_reposition_node" },
    { 0xB8A2, "simultaneouskillenabled" },
    { 0xB8A3, "single" },
    { 0xB8A4, "single_anim" },
    { 0xB8A5, "single_animation" },
    { 0xB8A6, "single_execution_a" },
    { 0xB8A7, "single_execution_b" },
    { 0xB8A8, "single_heli" },
    { 0xB8A9, "single_tread_list" },
    { 0xB8AA, "single_value_stats" },
    { 0xB8AB, "singleanimtohold" },
    { 0xB8AC, "singlefire" },
    { 0xB8AD, "sipes" },
    { 0xB8AE, "siren_light" },
    { 0xB8AF, "siren_light_setup" },
    { 0xB8B0, "siren_snd_handle" },
    { 0xB8B1, "sirens_on" },
    { 0xB8B2, "site" },
    { 0xB8B3, "sitrepdialogonplayer" },
    { 0xB8B4, "sittag" },
    { 0xB8B5, "sittag_angles_offset" },
    { 0xB8B6, "sittag_origin_offset" },
    { 0xB8B7, "sixth_sense_players" },
    { 0xB8B8, "sixthsense_think" },
    { 0xB8B9, "sixthsense_think_internal" },
    { 0xB8BA, "sixthsenselastactivetime" },
    { 0xB8BB, "sixthsensesource" },
    { 0xB8BC, "sixthsensestate" },
    { 0xB8BD, "skill_data" },
    { 0xB8BE, "skill_names" },
    { 0xB8BF, "skinref" },
    { 0xB8C0, "skip_ahead" },
    { 0xB8C1, "skip_ahead_scriptable" },
    { 0xB8C2, "skip_ambush_if_ambusher_died" },
    { 0xB8C3, "skip_clear_kill_off_flag" },
    { 0xB8C4, "skip_context_melee_anim" },
    { 0xB8C5, "skip_credits" },
    { 0xB8C6, "skip_door_exiters" },
    { 0xB8C7, "skip_ending_bink_thread" },
    { 0xB8C8, "skip_fallen_vo" },
    { 0xB8C9, "skip_friendly_fire_check" },
    { 0xB8CA, "skip_friendly_fire_nag_on_death" },
    { 0xB8CB, "skip_friendly_fire_nag_on_death_bed_civ" },
    { 0xB8CC, "skip_friendly_fire_nag_on_death_rush_civ" },
    { 0xB8CD, "skip_front_2_logic" },
    { 0xB8CE, "skip_idle" },
    { 0xB8CF, "skip_interaction" },
    { 0xB8D0, "skip_interrogation" },
    { 0xB8D1, "skip_intro" },
    { 0xB8D2, "skip_intro_sound" },
    { 0xB8D3, "skip_mother_and_marine" },
    { 0xB8D4, "skip_nav_check_on_spectate_respawn" },
    { 0xB8D5, "skip_next_friendly_fire_nag" },
    { 0xB8D6, "skip_outro" },
    { 0xB8D7, "skip_pilot_kill_count" },
    { 0xB8D8, "skip_playerhudphoto" },
    { 0xB8D9, "skip_screen_fx" },
    { 0xB8DA, "skip_to_final_phase" },
    { 0xB8DB, "skip_wait" },
    { 0xB8DC, "skip_weapon_check" },
    { 0xB8DD, "skipbloodpool" },
    { 0xB8DE, "skipchildrenkillingscene" },
    { 0xB8DF, "skipdeathanim" },
    { 0xB8E0, "skipdeathcleanup" },
    { 0xB8E1, "skipdefendersadvantage" },
    { 0xB8E2, "skipdescription" },
    { 0xB8E3, "skipdetonation" },
    { 0xB8E4, "skipdyingbackcrawl" },
    { 0xB8E5, "skipfinalkillcam" },
    { 0xB8E6, "skipkillcamandspawn" },
    { 0xB8E7, "skipkillcamduringdeathtimer" },
    { 0xB8E8, "skiploadout" },
    { 0xB8E9, "skiplogic" },
    { 0xB8EA, "skipminimapicon" },
    { 0xB8EB, "skipminimapids" },
    { 0xB8EC, "skipondeadevent" },
    { 0xB8ED, "skippable" },
    { 0xB8EE, "skippable_bunker_ending" },
    { 0xB8EF, "skippable_drive_scene" },
    { 0xB8F0, "skippable_ending" },
    { 0xB8F1, "skippable_ents" },
    { 0xB8F2, "skippable_heli_intro" },
    { 0xB8F3, "skippable_intro" },
    { 0xB8F4, "skippable_picc_ending" },
    { 0xB8F5, "skippable_tunnels_transition" },
    { 0xB8F6, "skipped" },
    { 0xB8F7, "skippedkillcam" },
    { 0xB8F8, "skippointdisplayxp" },
    { 0xB8F9, "skipprematchdropspawn" },
    { 0xB8FA, "skipspawncamera" },
    { 0xB8FB, "skipstealthcanseecheck" },
    { 0xB8FC, "skiptouching" },
    { 0xB8FD, "skiptraversals" },
    { 0xB8FE, "skipvehiclespashdamage" },
    { 0xB8FF, "skit_func" },
    { 0xB900, "skit_fx" },
    { 0xB901, "skit_logic" },
    { 0xB902, "skit_name" },
    { 0xB903, "skybox360" },
    { 0xB904, "skycolor" },
    { 0xB905, "skydive_dest" },
    { 0xB906, "skydive_idle" },
    { 0xB907, "skydive_idle_move" },
    { 0xB908, "skydomeintensity" },
    { 0xB909, "skydomelighting" },
    { 0xB90A, "skydomeradiosity" },
    { 0xB90B, "skylight" },
    { 0xB90C, "skyrotation" },
    { 0xB90D, "sl" },
    { 0xB90E, "slam_price" },
    { 0xB90F, "sledge_hits_door" },
    { 0xB910, "sledge_marine_advancing" },
    { 0xB911, "sledge_marine_cowabunga_advance" },
    { 0xB912, "sledge_put_away" },
    { 0xB913, "sleep" },
    { 0xB914, "slide" },
    { 0xB915, "slide_monitor" },
    { 0xB916, "slidemodel" },
    { 0xB917, "slidemonitor" },
    { 0xB918, "slidetriggerplayerthink" },
    { 0xB919, "slopecleanup" },
    { 0xB91A, "slopeupdate" },
    { 0xB91B, "slot" },
    { 0xB91C, "slot_array" },
    { 0xB91D, "slot_cap" },
    { 0xB91E, "slot_number" },
    { 0xB91F, "slotkillstreak" },
    { 0xB920, "slotomnvars" },
    { 0xB921, "slow_aim_ramp" },
    { 0xB922, "slow_down" },
    { 0xB923, "slow_down_if_leader" },
    { 0xB924, "slow_health_regen" },
    { 0xB925, "slow_react_enemy" },
    { 0xB926, "slow_react_stop_animscripted" },
    { 0xB927, "slow_react_type" },
    { 0xB928, "slow_scene_speed_while_offscreen" },
    { 0xB929, "slow_tread_vfx_trigger_speed" },
    { 0xB92A, "slowed" },
    { 0xB92B, "slowmo" },
    { 0xB92C, "slowmo_lerp_in" },
    { 0xB92D, "slowmo_lerp_out" },
    { 0xB92E, "slowmo_no" },
    { 0xB92F, "slowmo_setlerptime_in" },
    { 0xB930, "slowmo_setlerptime_out" },
    { 0xB931, "slowmo_setspeed_norm" },
    { 0xB932, "slowmo_setspeed_slow" },
    { 0xB933, "slowmo_system_defaults" },
    { 0xB934, "slowmo_system_init" },
    { 0xB935, "slowmo_yes" },
    { 0xB936, "slowmotionendofgame" },
    { 0xB937, "slowreactweapons" },
    { 0xB938, "smallesthole" },
    { 0xB939, "smallestoccluder" },
    { 0xB93A, "smart_dialogue" },
    { 0xB93B, "smart_dialogue_generic" },
    { 0xB93C, "smart_dialogue_no_combat" },
    { 0xB93D, "smart_dialogue_or_radio" },
    { 0xB93E, "smart_dialogue_tracked" },
    { 0xB93F, "smart_objects" },
    { 0xB940, "smart_player_dialogue" },
    { 0xB941, "smart_player_dialogue_gesture" },
    { 0xB942, "smart_player_dialogue_interrupt" },
    { 0xB943, "smart_radio_dialogue" },
    { 0xB944, "smart_radio_dialogue_interrupt" },
    { 0xB945, "smart_radio_dialogue_overlap" },
    { 0xB946, "smartobject" },
    { 0xB947, "smartobject_earlynotifier" },
    { 0xB948, "smartobject_notetrackhandler" },
    { 0xB949, "smartobject_setnextuse" },
    { 0xB94A, "smartobject_shouldexitintomove" },
    { 0xB94B, "smartobjectcomplete" },
    { 0xB94C, "smartobjecthasexits" },
    { 0xB94D, "smartobjecthasintro" },
    { 0xB94E, "smartobjecthaslogic" },
    { 0xB94F, "smartobjecthasoutro" },
    { 0xB950, "smartobjectinit" },
    { 0xB951, "smartobjectnotetrackhandle" },
    { 0xB952, "smartobjectpoints" },
    { 0xB953, "smartobjects" },
    { 0xB954, "smeansofdeath" },
    { 0xB955, "smellouterradiussq" },
    { 0xB956, "smellradiussq" },
    { 0xB957, "smg" },
    { 0xB958, "smg_flank_player" },
    { 0xB959, "smg_weapons_array" },
    { 0xB95A, "smoke_canister" },
    { 0xB95B, "smoke_canister_end" },
    { 0xB95C, "smoke_canister_spawn" },
    { 0xB95D, "smoke_canister_start" },
    { 0xB95E, "smoke_check" },
    { 0xB95F, "smoke_death_fail" },
    { 0xB960, "smoke_death_timer" },
    { 0xB961, "smoke_fx" },
    { 0xB962, "smoke_fx_ent" },
    { 0xB963, "smoke_grenade_late_death" },
    { 0xB964, "smoke_hint_handler" },
    { 0xB965, "smoke_lasers" },
    { 0xB966, "smoke_nag" },
    { 0xB967, "smoke_thread" },
    { 0xB968, "smoke_thrown" },
    { 0xB969, "smoke_thrown_in_streets" },
    { 0xB96A, "smoke_timeout_handler" },
    { 0xB96B, "smoke_up_landing_zone_for_enemy_ai" },
    { 0xB96C, "smoked" },
    { 0xB96D, "smokefiremain" },
    { 0xB96E, "smokegrenadeexplode" },
    { 0xB96F, "smokegrenadegiveblindeye" },
    { 0xB970, "smokegrenademonitorblindeyerecipients" },
    { 0xB971, "smokegrenadeused" },
    { 0xB972, "smokeleft" },
    { 0xB973, "smoking" },
    { 0xB974, "smoking_death" },
    { 0xB975, "smoking_idle" },
    { 0xB976, "smoking_idle_end" },
    { 0xB977, "smoking_idle_start" },
    { 0xB978, "smoking_react" },
    { 0xB979, "smoothstep" },
    { 0xB97A, "smtobjgetdamagedir" },
    { 0xB97B, "smuggler_base_room" },
    { 0xB97C, "smuggler_collect_loot" },
    { 0xB97D, "smuggler_disable_loots" },
    { 0xB97E, "smuggler_door_lock" },
    { 0xB97F, "smuggler_door_unlock" },
    { 0xB980, "smuggler_heli" },
    { 0xB981, "smuggler_heli_objective" },
    { 0xB982, "smuggler_heli_waittill_javelined" },
    { 0xB983, "smuggler_interactions_threaded" },
    { 0xB984, "smuggler_last_collector" },
    { 0xB985, "smuggler_loot_activate_func" },
    { 0xB986, "smuggler_loot_collected" },
    { 0xB987, "smuggler_loot_despawn" },
    { 0xB988, "smuggler_loot_hint_func" },
    { 0xB989, "smuggler_loot_init_func" },
    { 0xB98A, "smuggler_loot_max" },
    { 0xB98B, "smuggler_spawn" },
    { 0xB98C, "smuggler_temp_ending" },
    { 0xB98D, "smuggler_timeout_backup" },
    { 0xB98E, "smuggler_too_far_fail" },
    { 0xB98F, "smugglercache_init" },
    { 0xB990, "smugglermdl" },
    { 0xB991, "snake_cam_control" },
    { 0xB992, "snake_cam_logic" },
    { 0xB993, "snake_door_cam_hud" },
    { 0xB994, "snake_door_cam_hud_blur_v2" },
    { 0xB995, "snake_door_cam_hud_blur_v3" },
    { 0xB996, "snakecam" },
    { 0xB997, "snakecam_activate_func" },
    { 0xB998, "snakecam_active" },
    { 0xB999, "snakecam_allow_exit" },
    { 0xB99A, "snakecam_allow_exit_prompt" },
    { 0xB99B, "snakecam_catchup" },
    { 0xB99C, "snakecam_controls_hint_clear" },
    { 0xB99D, "snakecam_controls_hint_cleared" },
    { 0xB99E, "snakecam_controls_hint_handler" },
    { 0xB99F, "snakecam_controls_hint_timeout" },
    { 0xB9A0, "snakecam_cursor_hint" },
    { 0xB9A1, "snakecam_delay_visionsetchange" },
    { 0xB9A2, "snakecam_dialogue_manager" },
    { 0xB9A3, "snakecam_enter_fadein" },
    { 0xB9A4, "snakecam_exit_input_manager" },
    { 0xB9A5, "snakecam_exit_manager" },
    { 0xB9A6, "snakecam_exit_monitor" },
    { 0xB9A7, "snakecam_exit_ui_manager" },
    { 0xB9A8, "snakecam_force_exit" },
    { 0xB9A9, "snakecam_griggs_find" },
    { 0xB9AA, "snakecam_griggs_setup_vo_done" },
    { 0xB9AB, "snakecam_hint_func" },
    { 0xB9AC, "snakecam_hint_timer" },
    { 0xB9AD, "snakecam_init_func" },
    { 0xB9AE, "snakecam_light_on" },
    { 0xB9AF, "snakecam_main" },
    { 0xB9B0, "snakecam_make_yellow_marine" },
    { 0xB9B1, "snakecam_marine" },
    { 0xB9B2, "snakecam_marine_behavior" },
    { 0xB9B3, "snakecam_marine_forcespawn" },
    { 0xB9B4, "snakecam_marine_moveto_node" },
    { 0xB9B5, "snakecam_marine_reached_node" },
    { 0xB9B6, "snakecam_marine_spawn_monitor" },
    { 0xB9B7, "snakecam_marine_spawned" },
    { 0xB9B8, "snakecam_marine_spawner" },
    { 0xB9B9, "snakecam_marine_spawner_immediate" },
    { 0xB9BA, "snakecam_marine_timer" },
    { 0xB9BB, "snakecam_movement_monitor" },
    { 0xB9BC, "snakecam_sequence" },
    { 0xB9BD, "snakecam_setting_up_vo" },
    { 0xB9BE, "snakecam_start" },
    { 0xB9BF, "snakecam_to_wolf" },
    { 0xB9C0, "snakecam_toggle_enable_on_delay" },
    { 0xB9C1, "snakecam_toggle_waittill" },
    { 0xB9C2, "snakecamvision" },
    { 0xB9C3, "snap_lock_turret_onto_target" },
    { 0xB9C4, "snap2angle" },
    { 0xB9C5, "snap2anglesnaps" },
    { 0xB9C6, "snap2normal" },
    { 0xB9C7, "snappointtomapbounds2d" },
    { 0xB9C8, "snapshot_get_flight_dest" },
    { 0xB9C9, "snapshot_grenade_cleanup_danger_icon" },
    { 0xB9CA, "snapshot_grenade_cleanup_mover" },
    { 0xB9CB, "snapshot_grenade_clear_outlines" },
    { 0xB9CC, "snapshot_grenade_create_marker" },
    { 0xB9CD, "snapshot_grenade_delete" },
    { 0xB9CE, "snapshot_grenade_destroy" },
    { 0xB9CF, "snapshot_grenade_detect" },
    { 0xB9D0, "snapshot_grenade_empapplied" },
    { 0xB9D1, "snapshot_grenade_handle_damage" },
    { 0xB9D2, "snapshot_grenade_handle_fatal_damage" },
    { 0xB9D3, "snapshot_grenade_update_outlines" },
    { 0xB9D4, "snapshot_grenade_used" },
    { 0xB9D5, "snapshot_grenade_watch_cleanup" },
    { 0xB9D6, "snapshot_grenade_watch_cleanup_end_early" },
    { 0xB9D7, "snapshot_grenade_watch_cleanup_outlines" },
    { 0xB9D8, "snapshot_grenade_watch_cleanup_outlines_end_early" },
    { 0xB9D9, "snapshot_grenade_watch_emp" },
    { 0xB9DA, "snapshot_grenade_watch_flight" },
    { 0xB9DB, "snapshot_grenade_watch_marker_end_early" },
    { 0xB9DC, "snaptospawncamera" },
    { 0xB9DD, "snatchspawnalltoc130done" },
    { 0xB9DE, "snd_doppler" },
    { 0xB9DF, "snd_doppler_stop" },
    { 0xB9E0, "snd_doppler_tick" },
    { 0xB9E1, "snipe_laser" },
    { 0xB9E2, "snipe_me" },
    { 0xB9E3, "snipe_whiz_sfx" },
    { 0xB9E4, "sniper" },
    { 0xB9E5, "sniper_achievement_check" },
    { 0xB9E6, "sniper_allieslogic" },
    { 0xB9E7, "sniper_assist_target" },
    { 0xB9E8, "sniper_backup_spawners" },
    { 0xB9E9, "sniper_breakout_behavior" },
    { 0xB9EA, "sniper_bullet_fly" },
    { 0xB9EB, "sniper_bullet_keeps_rotating" },
    { 0xB9EC, "sniper_bus_civ_enter" },
    { 0xB9ED, "sniper_bus_civ_outcome" },
    { 0xB9EE, "sniper_bus_civ1_down" },
    { 0xB9EF, "sniper_bus_rescue" },
    { 0xB9F0, "sniper_bus_terry_bullets" },
    { 0xB9F1, "sniper_bus_terry_logic" },
    { 0xB9F2, "sniper_check_for_target" },
    { 0xB9F3, "sniper_combat" },
    { 0xB9F4, "sniper_combatlogic" },
    { 0xB9F5, "sniper_convergence_time_multiplier" },
    { 0xB9F6, "sniper_cover_group_trigger" },
    { 0xB9F7, "sniper_damage_func" },
    { 0xB9F8, "sniper_death_enter" },
    { 0xB9F9, "sniper_death_func" },
    { 0xB9FA, "sniper_death_monitor" },
    { 0xB9FB, "sniper_deathfunc" },
    { 0xB9FC, "sniper_dialogueintrologic" },
    { 0xB9FD, "sniper_dialoguelogic" },
    { 0xB9FE, "sniper_dialoguerelocatelogic" },
    { 0xB9FF, "sniper_dialoguesightedlogic" },
    { 0xBA00, "sniper_enemy_watcher" },
    { 0xBA01, "sniper_enemyglinton" },
    { 0xBA02, "sniper_enemylogic" },
    { 0xBA03, "sniper_enemyrelocate" },
    { 0xBA04, "sniper_enemyspottedlogic" },
    { 0xBA05, "sniper_enemytargetentitylogic" },
    { 0xBA06, "sniper_exit_nest" },
    { 0xBA07, "sniper_fire_perfect_shot" },
    { 0xBA08, "sniper_fire_shot" },
    { 0xBA09, "sniper_fired" },
    { 0xBA0A, "sniper_fireshot" },
    { 0xBA0B, "sniper_fodder" },
    { 0xBA0C, "sniper_getenemy" },
    { 0xBA0D, "sniper_getenemynodes" },
    { 0xBA0E, "sniper_getenemyspawner" },
    { 0xBA0F, "sniper_getimpactstructs" },
    { 0xBA10, "sniper_handle_death" },
    { 0xBA11, "sniper_handle_exit_nest" },
    { 0xBA12, "sniper_handle_script_control" },
    { 0xBA13, "sniper_handle_shot_target" },
    { 0xBA14, "sniper_handle_shot_target_tracking" },
    { 0xBA15, "sniper_in_crouch_foliage_trigger" },
    { 0xBA16, "sniper_in_prone_foliage_trigger" },
    { 0xBA17, "sniper_in_standing_foliage_trigger" },
    { 0xBA18, "sniper_in_warehouse" },
    { 0xBA19, "sniper_interaction" },
    { 0xBA1A, "sniper_intro" },
    { 0xBA1B, "sniper_killplayerlogic" },
    { 0xBA1C, "sniper_laser" },
    { 0xBA1D, "sniper_laser_think" },
    { 0xBA1E, "sniper_locked_laser_to_target" },
    { 0xBA1F, "sniper_logic" },
    { 0xBA20, "sniper_lost_target_enter" },
    { 0xBA21, "sniper_lost_target_update" },
    { 0xBA22, "sniper_main" },
    { 0xBA23, "sniper_nest_scriptable_dmg" },
    { 0xBA24, "sniper_perch_setup" },
    { 0xBA25, "sniper_pickup" },
    { 0xBA26, "sniper_player_monitor" },
    { 0xBA27, "sniper_playerlookingatenemy" },
    { 0xBA28, "sniper_players_connect_monitor" },
    { 0xBA29, "sniper_playerscreenbloodeffectlogic" },
    { 0xBA2A, "sniper_postdeathlogic" },
    { 0xBA2B, "sniper_recue_abort" },
    { 0xBA2C, "sniper_reload_enter" },
    { 0xBA2D, "sniper_reload_update" },
    { 0xBA2E, "sniper_rifle" },
    { 0xBA2F, "sniper_rifle_nag" },
    { 0xBA30, "sniper_rifle_name" },
    { 0xBA31, "sniper_rifle_pick_up_monitor" },
    { 0xBA32, "sniper_seek_target_enter" },
    { 0xBA33, "sniper_setup_destruction_notify" },
    { 0xBA34, "sniper_shoot_logic" },
    { 0xBA35, "sniper_shoot_target_enter" },
    { 0xBA36, "sniper_shoot_target_internal" },
    { 0xBA37, "sniper_shot_target" },
    { 0xBA38, "sniper_spawnenemy" },
    { 0xBA39, "sniper_start" },
    { 0xBA3A, "sniper_target" },
    { 0xBA3B, "sniper_target_think" },
    { 0xBA3C, "sniper_track_allies" },
    { 0xBA3D, "sniper_tracking_target_enter" },
    { 0xBA3E, "sniper_tracking_target_exit" },
    { 0xBA3F, "sniper_tracking_target_update" },
    { 0xBA40, "sniper_tracks_friendlies" },
    { 0xBA41, "sniper_weapons_array" },
    { 0xBA42, "sniper_whizby" },
    { 0xBA43, "sniper_windshiftlogic" },
    { 0xBA44, "sniperaccuracyset" },
    { 0xBA45, "sniperadsblur" },
    { 0xBA46, "sniperadsblur_execute" },
    { 0xBA47, "sniperadsblur_remove" },
    { 0xBA48, "sniperadsblur_supported" },
    { 0xBA49, "sniperblur" },
    { 0xBA4A, "sniperdeathcleanup" },
    { 0xBA4B, "sniperdustwatcher" },
    { 0xBA4C, "sniperglint_add" },
    { 0xBA4D, "sniperglint_cleanup" },
    { 0xBA4E, "sniperglint_manage" },
    { 0xBA4F, "sniperglint_remove" },
    { 0xBA50, "sniperglint_supported" },
    { 0xBA51, "sniperhitcount" },
    { 0xBA52, "sniperlaserhackstart" },
    { 0xBA53, "sniperlaserhackstop" },
    { 0xBA54, "snipermissileattractor" },
    { 0xBA55, "snipermodel" },
    { 0xBA56, "snipernest" },
    { 0xBA57, "snipernest_damage_trigger" },
    { 0xBA58, "sniperroof" },
    { 0xBA59, "sniperroofdestroyed" },
    { 0xBA5A, "snipers" },
    { 0xBA5B, "snipershotcount" },
    { 0xBA5C, "sniping_specific_ai" },
    { 0xBA5D, "snowmobile_collide_death" },
    { 0xBA5E, "snowmobile_death_launchslide" },
    { 0xBA5F, "snowmobile_decide_shoot" },
    { 0xBA60, "snowmobile_decide_shoot_internal" },
    { 0xBA61, "snowmobile_do_event" },
    { 0xBA62, "snowmobile_get_death_anim" },
    { 0xBA63, "snowmobile_getoff" },
    { 0xBA64, "snowmobile_geton" },
    { 0xBA65, "snowmobile_handle_events" },
    { 0xBA66, "snowmobile_loop_driver" },
    { 0xBA67, "snowmobile_loop_driver_shooting" },
    { 0xBA68, "snowmobile_loop_passenger" },
    { 0xBA69, "snowmobile_loop_passenger_shooting" },
    { 0xBA6A, "snowmobile_normal_death" },
    { 0xBA6B, "snowmobile_path" },
    { 0xBA6C, "snowmobile_reload" },
    { 0xBA6D, "snowmobile_reload_internal" },
    { 0xBA6E, "snowmobile_setanim_common" },
    { 0xBA6F, "snowmobile_setanim_driver" },
    { 0xBA70, "snowmobile_setanim_passenger" },
    { 0xBA71, "snowmobile_shoot" },
    { 0xBA72, "snowmobile_start_shooting" },
    { 0xBA73, "snowmobile_stop_shooting" },
    { 0xBA74, "snowmobile_trackshootentorpos_driver" },
    { 0xBA75, "snowmobile_trackshootentorpos_passenger" },
    { 0xBA76, "snowmobile_waitfor_end" },
    { 0xBA77, "snowmobile_waitfor_start_aim" },
    { 0xBA78, "snowmobile_waitfor_start_lean" },
    { 0xBA79, "snowmobileshootbehavior" },
    { 0xBA7A, "soft_reserved_spawn_slots" },
    { 0xBA7B, "softlanding" },
    { 0xBA7C, "softlandingtriggers" },
    { 0xBA7D, "softlandingwaiter" },
    { 0xBA7E, "softlink" },
    { 0xBA7F, "softsighttest" },
    { 0xBA80, "soldier" },
    { 0xBA81, "soldier_agent_specialize_func" },
    { 0xBA82, "soldier_agent_specialize_init" },
    { 0xBA83, "soldier_agentfn0" },
    { 0xBA84, "soldier_agentfn1" },
    { 0xBA85, "soldier_agentfn2" },
    { 0xBA86, "soldier_agentfn3" },
    { 0xBA87, "soldier_agentfn4" },
    { 0xBA88, "soldier_agentfn5" },
    { 0xBA89, "soldier_agentfn6" },
    { 0xBA8A, "soldier_agentfn7" },
    { 0xBA8B, "soldier_agentfn8" },
    { 0xBA8C, "soldier_agentfn9" },
    { 0xBA8D, "soldier_damagesubparthandler" },
    { 0xBA8E, "soldier_enemy_death_func" },
    { 0xBA8F, "soldier_finds_pistol" },
    { 0xBA90, "soldier_finds_pistol_react" },
    { 0xBA91, "soldier_init" },
    { 0xBA92, "soldier_init_common" },
    { 0xBA93, "soldier_investigate" },
    { 0xBA94, "soldier_leave_truck" },
    { 0xBA95, "soldier_player_listener" },
    { 0xBA96, "soldier_player_listener_checker" },
    { 0xBA97, "soldier_specialization" },
    { 0xBA98, "soldier_wait_for_door_open_sequence" },
    { 0xBA99, "soldier_wmhostage" },
    { 0xBA9A, "soldierhuntmode" },
    { 0xBA9B, "soldieroffset" },
    { 0xBA9C, "soldiershockfunc" },
    { 0xBA9D, "soldierspawnfunc" },
    { 0xBA9E, "solid" },
    { 0xBA9F, "solo_fires" },
    { 0xBAA0, "solo_firing" },
    { 0xBAA1, "solo_gameshouldend" },
    { 0xBAA2, "solo_maydolaststand" },
    { 0xBAA3, "son_react_death" },
    { 0xBAA4, "sonanimnode" },
    { 0xBAA5, "sonar_tracked_location" },
    { 0xBAA6, "sonicboomsfx" },
    { 0xBAA7, "sonictimer" },
    { 0xBAA8, "sort_allies" },
    { 0xBAA9, "sort_by_key" },
    { 0xBAAA, "sort_by_startingpos" },
    { 0xBAAB, "sort_players_based_on_previous_kidnap_attempt_time" },
    { 0xBAAC, "sort_reactive_ents" },
    { 0xBAAD, "sort_weapon_array" },
    { 0xBAAE, "sortandcullanimstructarray" },
    { 0xBAAF, "sortandreturnowner" },
    { 0xBAB0, "sortballarray" },
    { 0xBAB1, "sortbyhvtkills" },
    { 0xBAB2, "sortbyweight" },
    { 0xBAB3, "sortdoorsbydistance" },
    { 0xBAB4, "sorter" },
    { 0xBAB5, "sorthelosize" },
    { 0xBAB6, "sorthighest" },
    { 0xBAB7, "sortkillstreaksbycost" },
    { 0xBAB8, "sortlocationsbydistance" },
    { 0xBAB9, "sortlocationsbydistance_closestfirst" },
    { 0xBABA, "sortlocationsbydistance_farthestfirst" },
    { 0xBABB, "sortlowermessages" },
    { 0xBABC, "sorttrucksize" },
    { 0xBABD, "sortvalidplayersinarray" },
    { 0xBABE, "sortwinnersandlosers" },
    { 0xBABF, "sotf" },
    { 0xBAC0, "sotf_bot_think_seek_dropped_weapons" },
    { 0xBAC1, "sotf_crate_can_use" },
    { 0xBAC2, "sotf_crate_in_range" },
    { 0xBAC3, "sotf_crate_low_ammo_check" },
    { 0xBAC4, "sotf_crate_should_claim" },
    { 0xBAC5, "sotf_crate_wait_use" },
    { 0xBAC6, "sotf_loadouts" },
    { 0xBAC7, "sotf_should_stop_seeking_weapon" },
    { 0xBAC8, "sotfcratethink" },
    { 0xBAC9, "sotomura" },
    { 0xBACA, "sound" },
    { 0xBACB, "sound_csv_include" },
    { 0xBACC, "sound_effect" },
    { 0xBACD, "sound_explode" },
    { 0xBACE, "sound_fade_and_delete" },
    { 0xBACF, "sound_fade_in" },
    { 0xBAD0, "sound_init" },
    { 0xBAD1, "sound_mover" },
    { 0xBAD2, "sound_mover_playsoundatpos" },
    { 0xBAD3, "sound_orgs" },
    { 0xBAD4, "sound_prefix" },
    { 0xBAD5, "sound_suffix" },
    { 0xBAD6, "sound_tag" },
    { 0xBAD7, "sound_tag_dupe" },
    { 0xBAD8, "soundalias" },
    { 0xBAD9, "soundaliases" },
    { 0xBADA, "soundent" },
    { 0xBADB, "soundevents" },
    { 0xBADC, "soundfx" },
    { 0xBADD, "soundfxdelete" },
    { 0xBADE, "sounds" },
    { 0xBADF, "soundwatcher" },
    { 0xBAE0, "source_name" },
    { 0xBAE1, "sourcepos" },
    { 0xBAE2, "sources" },
    { 0xBAE3, "sourcetrigger" },
    { 0xBAE4, "souvenir_hint_displayed" },
    { 0xBAE5, "souvenircointype" },
    { 0xBAE6, "sp" },
    { 0xBAE7, "sp_anim_handle_notetrack" },
    { 0xBAE8, "sp_areas" },
    { 0xBAE9, "sp_building" },
    { 0xBAEA, "sp_building_exterior" },
    { 0xBAEB, "sp_building_interior" },
    { 0xBAEC, "sp_counter" },
    { 0xBAED, "sp_embassy" },
    { 0xBAEE, "sp_highway" },
    { 0xBAEF, "sp_lab" },
    { 0xBAF0, "sp_objects" },
    { 0xBAF1, "sp_skip" },
    { 0xBAF2, "sp_vehicles" },
    { 0xBAF3, "spam_density_scale" },
    { 0xBAF4, "spam_errors_as_prints" },
    { 0xBAF5, "spam_group_hudelems" },
    { 0xBAF6, "spam_maxdist" },
    { 0xBAF7, "spam_model_circlescale" },
    { 0xBAF8, "spam_model_circlescale_accumtime" },
    { 0xBAF9, "spam_model_circlescale_lasttime" },
    { 0xBAFA, "spam_model_clearcondition" },
    { 0xBAFB, "spam_model_current_group" },
    { 0xBAFC, "spam_model_densityscale" },
    { 0xBAFD, "spam_model_erase" },
    { 0xBAFE, "spam_model_group" },
    { 0xBAFF, "spam_model_place" },
    { 0xBB00, "spam_model_radius" },
    { 0xBB01, "spam_modelattrace" },
    { 0xBB02, "spam_models_atcircle" },
    { 0xBB03, "spam_models_customheight" },
    { 0xBB04, "spam_models_customrotation" },
    { 0xBB05, "spam_models_flowrate" },
    { 0xBB06, "spam_models_iscustomheight" },
    { 0xBB07, "spam_models_iscustomrotation" },
    { 0xBB08, "spam_points_popup" },
    { 0xBB09, "spamed_models" },
    { 0xBB0A, "spaming_models" },
    { 0xBB0B, "spark_pos" },
    { 0xBB0C, "sparks" },
    { 0xBB0D, "spatrolpointscoring" },
    { 0xBB0E, "spawn" },
    { 0xBB0F, "spawn_1f_civ_jumpto" },
    { 0xBB10, "spawn_1f_civ_left" },
    { 0xBB11, "spawn_2f_bags" },
    { 0xBB12, "spawn_2f_bodies" },
    { 0xBB13, "spawn_2f_civ_jumpto" },
    { 0xBB14, "spawn_2f_extras" },
    { 0xBB15, "spawn_3f_enemy1" },
    { 0xBB16, "spawn_3f_enemy2" },
    { 0xBB17, "spawn_3f_hostage" },
    { 0xBB18, "spawn_3f_stairs_enemy" },
    { 0xBB19, "spawn_4player_car" },
    { 0xBB1A, "spawn_ac130" },
    { 0xBB1B, "spawn_agent" },
    { 0xBB1C, "spawn_agent_player" },
    { 0xBB1D, "spawn_ai" },
    { 0xBB1E, "spawn_ai_giving_disguise" },
    { 0xBB1F, "spawn_ai_in_truck" },
    { 0xBB20, "spawn_ai_mode" },
    { 0xBB21, "spawn_ai_wave_1" },
    { 0xBB22, "spawn_ai_wave_2_pre_push" },
    { 0xBB23, "spawn_airdrop_at_point" },
    { 0xBB24, "spawn_aitype_counts" },
    { 0xBB25, "spawn_alex" },
    { 0xBB26, "spawn_alex_friendlies" },
    { 0xBB27, "spawn_ally_teams" },
    { 0xBB28, "spawn_alpha_team" },
    { 0xBB29, "spawn_ambient_ac130" },
    { 0xBB2A, "spawn_ambient_zombie" },
    { 0xBB2B, "spawn_ambush_enemies" },
    { 0xBB2C, "spawn_and_enter_apc_rus" },
    { 0xBB2D, "spawn_and_enter_cargo_truck" },
    { 0xBB2E, "spawn_and_enter_cop_car" },
    { 0xBB2F, "spawn_and_enter_hoopty" },
    { 0xBB30, "spawn_and_enter_hoopty_truck" },
    { 0xBB31, "spawn_and_enter_jeep" },
    { 0xBB32, "spawn_and_enter_light_tank" },
    { 0xBB33, "spawn_and_enter_little_bird" },
    { 0xBB34, "spawn_and_enter_med_transport" },
    { 0xBB35, "spawn_and_enter_pickup_truck" },
    { 0xBB36, "spawn_and_enter_tac_rover" },
    { 0xBB37, "spawn_and_enter_technical" },
    { 0xBB38, "spawn_and_enter_van" },
    { 0xBB39, "spawn_and_start_c130" },
    { 0xBB3A, "spawn_anim_model" },
    { 0xBB3B, "spawn_anim_weapon" },
    { 0xBB3C, "spawn_animated_intro_civs" },
    { 0xBB3D, "spawn_animated_trailer_civs" },
    { 0xBB3E, "spawn_animating_ai_cop" },
    { 0xBB3F, "spawn_aq_enforcer" },
    { 0xBB40, "spawn_aq_enforcer_entourage" },
    { 0xBB41, "spawn_ar" },
    { 0xBB42, "spawn_at_mine" },
    { 0xBB43, "spawn_attackers" },
    { 0xBB44, "spawn_attackers_a" },
    { 0xBB45, "spawn_attackers_b" },
    { 0xBB46, "spawn_attackers_fallback" },
    { 0xBB47, "spawn_attackers_start" },
    { 0xBB48, "spawn_atvs" },
    { 0xBB49, "spawn_back_street_loop" },
    { 0xBB4A, "spawn_back_street_traffic" },
    { 0xBB4B, "spawn_backup" },
    { 0xBB4C, "spawn_barkov" },
    { 0xBB4D, "spawn_barrel_collision" },
    { 0xBB4E, "spawn_barrel_straps" },
    { 0xBB4F, "spawn_barrel_tracker" },
    { 0xBB50, "spawn_blackscreen_func" },
    { 0xBB51, "spawn_bodyguard_and_go_to_desk" },
    { 0xBB52, "spawn_bombardment_aq" },
    { 0xBB53, "spawn_bombers" },
    { 0xBB54, "spawn_bot_latent" },
    { 0xBB55, "spawn_bots" },
    { 0xBB56, "spawn_bravo_team" },
    { 0xBB57, "spawn_bridge_badies" },
    { 0xBB58, "spawn_c130" },
    { 0xBB59, "spawn_c4_interacts_for_train" },
    { 0xBB5A, "spawn_c6_script_inits" },
    { 0xBB5B, "spawn_callback_thread" },
    { 0xBB5C, "spawn_can" },
    { 0xBB5D, "spawn_car_and_link_driver" },
    { 0xBB5E, "spawn_car_passenger" },
    { 0xBB5F, "spawn_chair" },
    { 0xBB60, "spawn_check_func" },
    { 0xBB61, "spawn_chopper" },
    { 0xBB62, "spawn_civ" },
    { 0xBB63, "spawn_civ_hvt_for_later" },
    { 0xBB64, "spawn_claymore" },
    { 0xBB65, "spawn_closeenemydistsq" },
    { 0xBB66, "spawn_cluster" },
    { 0xBB67, "spawn_convoy" },
    { 0xBB68, "spawn_convoy_and_drive" },
    { 0xBB69, "spawn_convoy_apc" },
    { 0xBB6A, "spawn_convoy_decho" },
    { 0xBB6B, "spawn_convoy_from_type" },
    { 0xBB6C, "spawn_convoy_mkilo23" },
    { 0xBB6D, "spawn_convoy_truck" },
    { 0xBB6E, "spawn_convoys" },
    { 0xBB6F, "spawn_convoys_as_players_get_closer" },
    { 0xBB70, "spawn_cop_from_behind_player" },
    { 0xBB71, "spawn_corpse" },
    { 0xBB72, "spawn_corpses" },
    { 0xBB73, "spawn_count" },
    { 0xBB74, "spawn_covernode_soldiers" },
    { 0xBB75, "spawn_cross_street_traffic" },
    { 0xBB76, "spawn_dbldoor_anims" },
    { 0xBB77, "spawn_dead_body" },
    { 0xBB78, "spawn_deadzone_dist" },
    { 0xBB79, "spawn_death_vignette_ai" },
    { 0xBB7A, "spawn_debug_particles" },
    { 0xBB7B, "spawn_defenders" },
    { 0xBB7C, "spawn_defenders_a" },
    { 0xBB7D, "spawn_defenders_b" },
    { 0xBB7E, "spawn_defenders_fallback" },
    { 0xBB7F, "spawn_defenders_start" },
    { 0xBB80, "spawn_disengage_ai" },
    { 0xBB81, "spawn_distant_threat" },
    { 0xBB82, "spawn_door_anims" },
    { 0xBB83, "spawn_door_model" },
    { 0xBB84, "spawn_downed_pilot" },
    { 0xBB85, "spawn_driver" },
    { 0xBB86, "spawn_driver_and_passenger" },
    { 0xBB87, "spawn_drone_cop" },
    { 0xBB88, "spawn_drone_hitbox" },
    { 0xBB89, "spawn_dude_loop_anim" },
    { 0xBB8A, "spawn_dude_play_anim" },
    { 0xBB8B, "spawn_dude_play_anim_and_delete" },
    { 0xBB8C, "spawn_dude_play_anim_and_delete_animate" },
    { 0xBB8D, "spawn_endgame_camera" },
    { 0xBB8E, "spawn_enemy" },
    { 0xBB8F, "spawn_enemy_chopper" },
    { 0xBB90, "spawn_enemy_lbravo" },
    { 0xBB91, "spawn_enemy_soldier" },
    { 0xBB92, "spawn_enemy_tank" },
    { 0xBB93, "spawn_enemy_tanks" },
    { 0xBB94, "spawn_enforcer" },
    { 0xBB95, "spawn_escalation_soldiers" },
    { 0xBB96, "spawn_escape_heli" },
    { 0xBB97, "spawn_escape_weapons" },
    { 0xBB98, "spawn_evac_chopper" },
    { 0xBB99, "spawn_extra_collision" },
    { 0xBB9A, "spawn_failed" },
    { 0xBB9B, "spawn_fake_ai_vehicles" },
    { 0xBB9C, "spawn_fake_damage_fx" },
    { 0xBB9D, "spawn_fake_loots" },
    { 0xBB9E, "spawn_farah" },
    { 0xBB9F, "spawn_father" },
    { 0xBBA0, "spawn_friendlies" },
    { 0xBBA1, "spawn_fulton_crate_model" },
    { 0xBBA2, "spawn_fulton_group_use_interaction" },
    { 0xBBA3, "spawn_func" },
    { 0xBBA4, "spawn_funcs" },
    { 0xBBA5, "spawn_functions" },
    { 0xBBA6, "spawn_functions_enable" },
    { 0xBBA7, "spawn_functions_init" },
    { 0xBBA8, "spawn_gap_extras" },
    { 0xBBA9, "spawn_gap_hostage" },
    { 0xBBAA, "spawn_gate_overrunners" },
    { 0xBBAB, "spawn_glowstick_on_struct" },
    { 0xBBAC, "spawn_goliath_boss" },
    { 0xBBAD, "spawn_graycard" },
    { 0xBBAE, "spawn_grenade" },
    { 0xBBAF, "spawn_group" },
    { 0xBBB0, "spawn_group_manager" },
    { 0xBBB1, "spawn_groups" },
    { 0xBBB2, "spawn_guys_on_truck" },
    { 0xBBB3, "spawn_guys_until_death_or_no_count" },
    { 0xBBB4, "spawn_hacker_soldiers" },
    { 0xBBB5, "spawn_hadir" },
    { 0xBBB6, "spawn_heli_farah" },
    { 0xBBB7, "spawn_helicopter" },
    { 0xBBB8, "spawn_helidown_heli" },
    { 0xBBB9, "spawn_henchman" },
    { 0xBBBA, "spawn_henchman2" },
    { 0xBBBB, "spawn_henchman3" },
    { 0xBBBC, "spawn_hidden_reinforcement" },
    { 0xBBBD, "spawn_hill_friendlies" },
    { 0xBBBE, "spawn_hilltop_heli" },
    { 0xBBBF, "spawn_hvt" },
    { 0xBBC0, "spawn_hvt_in_building" },
    { 0xBBC1, "spawn_hvt_waypoint" },
    { 0xBBC2, "spawn_idle_cop" },
    { 0xBBC3, "spawn_ied" },
    { 0xBBC4, "spawn_ied_zone" },
    { 0xBBC5, "spawn_in_cover" },
    { 0xBBC6, "spawn_in_streaming_bodies" },
    { 0xBBC7, "spawn_infil_axis_ai" },
    { 0xBBC8, "spawn_infil_bodies" },
    { 0xBBC9, "spawn_init" },
    { 0xBBCA, "spawn_into_c130_without_respawn" },
    { 0xBBCB, "spawn_intro_choppers" },
    { 0xBBCC, "spawn_intro_soldiers" },
    { 0xBBCD, "spawn_intro_trucks" },
    { 0xBBCE, "spawn_investigate_train" },
    { 0xBBCF, "spawn_is_vehicle_spawn" },
    { 0xBBD0, "spawn_juggs" },
    { 0xBBD1, "spawn_key_objective" },
    { 0xBBD2, "spawn_kidnapper_for_player" },
    { 0xBBD3, "spawn_kyle" },
    { 0xBBD4, "spawn_kyledrone" },
    { 0xBBD5, "spawn_ldoor_anims" },
    { 0xBBD6, "spawn_lead_model" },
    { 0xBBD7, "spawn_light_tank" },
    { 0xBBD8, "spawn_lillywhite_rescue_police" },
    { 0xBBD9, "spawn_little_bird_at_location" },
    { 0xBBDA, "spawn_looping_fakeactor_wait_for_player" },
    { 0xBBDB, "spawn_lz_spawners_on_landing" },
    { 0xBBDC, "spawn_map_ac130" },
    { 0xBBDD, "spawn_map_technicals" },
    { 0xBBDE, "spawn_marines_friendlies" },
    { 0xBBDF, "spawn_marines_wave_5" },
    { 0xBBE0, "spawn_max_ai_wave_1_lmg_push" },
    { 0xBBE1, "spawn_max_ai_wave_1_refill" },
    { 0xBBE2, "spawn_max_ai_wave_1_technical_refill" },
    { 0xBBE3, "spawn_max_ai_wave_2_push" },
    { 0xBBE4, "spawn_max_ai_wave_2_push_again" },
    { 0xBBE5, "spawn_module_current" },
    { 0xBBE6, "spawn_module_hackers" },
    { 0xBBE7, "spawn_module_intro" },
    { 0xBBE8, "spawn_module_intro2" },
    { 0xBBE9, "spawn_module_juggs" },
    { 0xBBEA, "spawn_module_signal" },
    { 0xBBEB, "spawn_module_structs_memory" },
    { 0xBBEC, "spawn_module_supports" },
    { 0xBBED, "spawn_mortar_friendlies" },
    { 0xBBEE, "spawn_murderhole_with_dialogue" },
    { 0xBBEF, "spawn_my_crash_driver" },
    { 0xBBF0, "spawn_my_twin" },
    { 0xBBF1, "spawn_next_zone" },
    { 0xBBF2, "spawn_nikolai" },
    { 0xBBF3, "spawn_node" },
    { 0xBBF4, "spawn_objective_heli" },
    { 0xBBF5, "spawn_objective_loot" },
    { 0xBBF6, "spawn_oil_pusher" },
    { 0xBBF7, "spawn_on_stealth_break" },
    { 0xBBF8, "spawn_overwatch_extraguns" },
    { 0xBBF9, "spawn_overwatch_soldiers_02" },
    { 0xBBFA, "spawn_overwatch_soldiers_03" },
    { 0xBBFB, "spawn_overwatch_soldiers_04" },
    { 0xBBFC, "spawn_overwatch_soldiers_05" },
    { 0xBBFD, "spawn_overwatch_soldiers_06" },
    { 0xBBFE, "spawn_overwatch_tank" },
    { 0xBBFF, "spawn_overwatch_tanks" },
    { 0xBC00, "spawn_padlock" },
    { 0xBC01, "spawn_parachute" },
    { 0xBC02, "spawn_parameter_array" },
    { 0xBC03, "spawn_paul_revere_scene_ai" },
    { 0xBC04, "spawn_pavelows" },
    { 0xBC05, "spawn_per_player" },
    { 0xBC06, "spawn_phys_barrel_pickup" },
    { 0xBC07, "spawn_pilot_attacker" },
    { 0xBC08, "spawn_pilot_nikolai" },
    { 0xBC09, "spawn_pilots" },
    { 0xBC0A, "spawn_plane" },
    { 0xBC0B, "spawn_player_into_c130" },
    { 0xBC0C, "spawn_player_vehicles" },
    { 0xBC0D, "spawn_point" },
    { 0xBC0E, "spawn_point_too_far" },
    { 0xBC0F, "spawn_points" },
    { 0xBC10, "spawn_pos" },
    { 0xBC11, "spawn_power_up" },
    { 0xBC12, "spawn_pre_placed_flares_for_tunnels" },
    { 0xBC13, "spawn_prethink" },
    { 0xBC14, "spawn_price" },
    { 0xBC15, "spawn_price_infill" },
    { 0xBC16, "spawn_price_redshirt" },
    { 0xBC17, "spawn_printer" },
    { 0xBC18, "spawn_prisoners" },
    { 0xBC19, "spawn_queue" },
    { 0xBC1A, "spawn_rdoor_anims" },
    { 0xBC1B, "spawn_real_ai_from_drone_pos" },
    { 0xBC1C, "spawn_recon_team" },
    { 0xBC1D, "spawn_ref_point" },
    { 0xBC1E, "spawn_ref_point_override" },
    { 0xBC1F, "spawn_regular_agent" },
    { 0xBC20, "spawn_reinforcement" },
    { 0xBC21, "spawn_reinforcement_truck" },
    { 0xBC22, "spawn_remote_tank" },
    { 0xBC23, "spawn_reverse_breach_enemies" },
    { 0xBC24, "spawn_riders" },
    { 0xBC25, "spawn_right_flank_run_early_on_death_and_look_at_struct" },
    { 0xBC26, "spawn_rpg_guys_when_in_heli" },
    { 0xBC27, "spawn_rpg_support" },
    { 0xBC28, "spawn_sas" },
    { 0xBC29, "spawn_sas_redshirts" },
    { 0xBC2A, "spawn_scoring_array" },
    { 0xBC2B, "spawn_scoring_overrides" },
    { 0xBC2C, "spawn_scoring_pois" },
    { 0xBC2D, "spawn_scoring_type" },
    { 0xBC2E, "spawn_script_model_at_pos" },
    { 0xBC2F, "spawn_script_noteworthy" },
    { 0xBC30, "spawn_script_origin" },
    { 0xBC31, "spawn_script_weapon" },
    { 0xBC32, "spawn_scripted_agent" },
    { 0xBC33, "spawn_scripted_sniper" },
    { 0xBC34, "spawn_signal_soldier" },
    { 0xBC35, "spawn_skit_prop" },
    { 0xBC36, "spawn_skits" },
    { 0xBC37, "spawn_smoke_when_near_struct" },
    { 0xBC38, "spawn_smuggler_and_board_heli" },
    { 0xBC39, "spawn_smuggler_heli_pilot" },
    { 0xBC3A, "spawn_smuggler_javelin" },
    { 0xBC3B, "spawn_snipers_early" },
    { 0xBC3C, "spawn_soldier_scripted" },
    { 0xBC3D, "spawn_soldier_scripted_internal" },
    { 0xBC3E, "spawn_soldiers_attack_tower" },
    { 0xBC3F, "spawn_soldiers_ending" },
    { 0xBC40, "spawn_soldiers_intro" },
    { 0xBC41, "spawn_soldiers_juggs" },
    { 0xBC42, "spawn_soldiers_rooftops" },
    { 0xBC43, "spawn_soldiers_route_to_hvt" },
    { 0xBC44, "spawn_soldiers_switch_01" },
    { 0xBC45, "spawn_soldiers_switch_02" },
    { 0xBC46, "spawn_soldiers_switch_03" },
    { 0xBC47, "spawn_spec_hostage" },
    { 0xBC48, "spawn_spec_intro_actors" },
    { 0xBC49, "spawn_stacy" },
    { 0xBC4A, "spawn_start_enemies" },
    { 0xBC4B, "spawn_static_trucks" },
    { 0xBC4C, "spawn_stowed_glowstick_on_farah" },
    { 0xBC4D, "spawn_street_guys" },
    { 0xBC4E, "spawn_subclass_juggernaut" },
    { 0xBC4F, "spawn_suicide_truck_at_vehicle_spawner" },
    { 0xBC50, "spawn_support_wave_handler" },
    { 0xBC51, "spawn_table" },
    { 0xBC52, "spawn_tag_origin" },
    { 0xBC53, "spawn_tank2" },
    { 0xBC54, "spawn_targetname" },
    { 0xBC55, "spawn_team_allies" },
    { 0xBC56, "spawn_team_axis" },
    { 0xBC57, "spawn_team_farah" },
    { 0xBC58, "spawn_team_neutral" },
    { 0xBC59, "spawn_team_price" },
    { 0xBC5A, "spawn_team_team3" },
    { 0xBC5B, "spawn_technical" },
    { 0xBC5C, "spawn_technical_at_location" },
    { 0xBC5D, "spawn_technicals_for_players" },
    { 0xBC5E, "spawn_test_clients" },
    { 0xBC5F, "spawn_thing_play_anim_and_delete" },
    { 0xBC60, "spawn_thing_play_anim_and_last_frame" },
    { 0xBC61, "spawn_think" },
    { 0xBC62, "spawn_think_action" },
    { 0xBC63, "spawn_think_game_skill_related" },
    { 0xBC64, "spawn_think_script_inits" },
    { 0xBC65, "spawn_third_person_alex" },
    { 0xBC66, "spawn_time" },
    { 0xBC67, "spawn_traffic" },
    { 0xBC68, "spawn_train_c4_objects" },
    { 0xBC69, "spawn_train_car" },
    { 0xBC6A, "spawn_train_car_part" },
    { 0xBC6B, "spawn_train_end" },
    { 0xBC6C, "spawn_train_nav_blocker" },
    { 0xBC6D, "spawn_train_nav_blockers_all" },
    { 0xBC6E, "spawn_train_nav_repulsors" },
    { 0xBC6F, "spawn_train_stairs" },
    { 0xBC70, "spawn_triage_loot" },
    { 0xBC71, "spawn_triage_props" },
    { 0xBC72, "spawn_trickle_soldiers" },
    { 0xBC73, "spawn_type" },
    { 0xBC74, "spawn_unittype_soldier" },
    { 0xBC75, "spawn_unload_group" },
    { 0xBC76, "spawn_van_guys" },
    { 0xBC77, "spawn_vehicle" },
    { 0xBC78, "spawn_vehicle_accessory" },
    { 0xBC79, "spawn_vehicle_actors" },
    { 0xBC7A, "spawn_vehicle_and_attach_to_spline_path" },
    { 0xBC7B, "spawn_vehicle_and_gopath" },
    { 0xBC7C, "spawn_vehicle_at_vehicle_spawner" },
    { 0xBC7D, "spawn_vehicle_from_targetname" },
    { 0xBC7E, "spawn_vehicle_from_targetname_and_drive" },
    { 0xBC7F, "spawn_vehicle_turret" },
    { 0xBC80, "spawn_vehicle_turret_drone" },
    { 0xBC81, "spawn_vehicles_from_targetname" },
    { 0xBC82, "spawn_vehicles_from_targetname_and_drive" },
    { 0xBC83, "spawn_vip_escort_chopper" },
    { 0xBC84, "spawn_volume_array" },
    { 0xBC85, "spawn_volume_names" },
    { 0xBC86, "spawn_wave" },
    { 0xBC87, "spawn_wave_enemy_func" },
    { 0xBC88, "spawn_wave_total" },
    { 0xBC89, "spawn_waves_after_a_delay" },
    { 0xBC8A, "spawn_weapon_model" },
    { 0xBC8B, "spawn_weapons_and_armor" },
    { 0xBC8C, "spawn_wheel_collision" },
    { 0xBC8D, "spawn_wheel_outline_model" },
    { 0xBC8E, "spawn_window_open" },
    { 0xBC8F, "spawn_window_time" },
    { 0xBC90, "spawn_wolf" },
    { 0xBC91, "spawn_zoom_in_infill" },
    { 0xBC92, "spawnac130" },
    { 0xBC93, "spawnactors" },
    { 0xBC94, "spawnai_goalpos" },
    { 0xBC95, "spawnai_goalradius" },
    { 0xBC96, "spawnai_linkent" },
    { 0xBC97, "spawnai_realspawner" },
    { 0xBC98, "spawnaihandler" },
    { 0xBC99, "spawnaimode" },
    { 0xBC9A, "spawnallhostages" },
    { 0xBC9B, "spawnallies" },
    { 0xBC9C, "spawnambulance" },
    { 0xBC9D, "spawnammocountoverride_giveweaponammo" },
    { 0xBC9E, "spawnangles" },
    { 0xBC9F, "spawnapc" },
    { 0xBCA0, "spawnareas" },
    { 0xBCA1, "spawnatmines" },
    { 0xBCA2, "spawnavehicle" },
    { 0xBCA3, "spawnbradleynoduration" },
    { 0xBCA4, "spawnbradleypayload" },
    { 0xBCA5, "spawnc130" },
    { 0xBCA6, "spawnc130pathstruct" },
    { 0xBCA7, "spawnc130pathstructnew" },
    { 0xBCA8, "spawncallback" },
    { 0xBCA9, "spawncameradistfactor" },
    { 0xBCAA, "spawncameraendtime" },
    { 0xBCAB, "spawncameraent" },
    { 0xBCAC, "spawncameras" },
    { 0xBCAD, "spawncameraskipthermal" },
    { 0xBCAE, "spawncameraskipthermalonce" },
    { 0xBCAF, "spawncamerastartspawnallies" },
    { 0xBCB0, "spawncamerastartspawnalliesvec" },
    { 0xBCB1, "spawncamerastartspawnaxis" },
    { 0xBCB2, "spawncamerastartspawnaxisang" },
    { 0xBCB3, "spawncamerastartspawnaxisvec" },
    { 0xBCB4, "spawncameratargetang" },
    { 0xBCB5, "spawncameratargetpos" },
    { 0xBCB6, "spawncameratime" },
    { 0xBCB7, "spawnchests" },
    { 0xBCB8, "spawnchopper" },
    { 0xBCB9, "spawnclient" },
    { 0xBCBA, "spawnclientbr" },
    { 0xBCBB, "spawncmdgoal" },
    { 0xBCBC, "spawnconvoy" },
    { 0xBCBD, "spawnconvoyatpath" },
    { 0xBCBE, "spawncorpseloot" },
    { 0xBCBF, "spawncount" },
    { 0xBCC0, "spawndata" },
    { 0xBCC1, "spawndebugpickupfromdevgui" },
    { 0xBCC2, "spawndelay" },
    { 0xBCC3, "spawndepot" },
    { 0xBCC4, "spawndist" },
    { 0xBCC5, "spawndogtags" },
    { 0xBCC6, "spawndombradley" },
    { 0xBCC7, "spawndropbagobjectiveicon" },
    { 0xBCC8, "spawndropbagonlanding" },
    { 0xBCC9, "spawned_after_convoy_center" },
    { 0xBCCA, "spawned_ai" },
    { 0xBCCB, "spawned_allies" },
    { 0xBCCC, "spawned_convoys" },
    { 0xBCCD, "spawned_count" },
    { 0xBCCE, "spawned_enemies" },
    { 0xBCCF, "spawned_enemy_types" },
    { 0xBCD0, "spawned_goalie" },
    { 0xBCD1, "spawned_group" },
    { 0xBCD2, "spawned_guys" },
    { 0xBCD3, "spawned_hostage_modules" },
    { 0xBCD4, "spawned_juggernauts" },
    { 0xBCD5, "spawned_prop" },
    { 0xBCD6, "spawned_soldiers" },
    { 0xBCD7, "spawned_soldiers_vo" },
    { 0xBCD8, "spawned_suicide_bombers" },
    { 0xBCD9, "spawned_vehicles" },
    { 0xBCDA, "spawned_wait_node" },
    { 0xBCDB, "spawned_weapon" },
    { 0xBCDC, "spawnedcleanupitems_dropped" },
    { 0xBCDD, "spawnedcleanupitems_standard" },
    { 0xBCDE, "spawnedescortchopper" },
    { 0xBCDF, "spawnedhostagecount" },
    { 0xBCE0, "spawnedjugg" },
    { 0xBCE1, "spawnedkillcamcleanup" },
    { 0xBCE2, "spawnednoisemakerpickup" },
    { 0xBCE3, "spawnedusingc130" },
    { 0xBCE4, "spawnedvip" },
    { 0xBCE5, "spawnendofgame" },
    { 0xBCE6, "spawnenemychopper" },
    { 0xBCE7, "spawnentsincircle" },
    { 0xBCE8, "spawner_chosen_nearby" },
    { 0xBCE9, "spawner_critical_factors" },
    { 0xBCEA, "spawner_deathflag" },
    { 0xBCEB, "spawner_disable_after_count" },
    { 0xBCEC, "spawner_dronespawn" },
    { 0xBCED, "spawner_flags" },
    { 0xBCEE, "spawner_flags_check" },
    { 0xBCEF, "spawner_init" },
    { 0xBCF0, "spawner_makefakeactor" },
    { 0xBCF1, "spawner_makerealai" },
    { 0xBCF2, "spawner_number" },
    { 0xBCF3, "spawner_scoring_critical_factors" },
    { 0xBCF4, "spawner_scoring_funcs" },
    { 0xBCF5, "spawner_scoring_init" },
    { 0xBCF6, "spawner_script_funcs" },
    { 0xBCF7, "spawnercallbackthread" },
    { 0xBCF8, "spawnercount" },
    { 0xBCF9, "spawners" },
    { 0xBCFA, "spawners_using" },
    { 0xBCFB, "spawnerwave" },
    { 0xBCFC, "spawnescortchopper" },
    { 0xBCFD, "spawnexclusion2ddist" },
    { 0xBCFE, "spawnexfilpilotactors" },
    { 0xBCFF, "spawnexfilplayers" },
    { 0xBD00, "spawnexfilzone" },
    { 0xBD01, "spawnextractchopper" },
    { 0xBD02, "spawnextractzones" },
    { 0xBD03, "spawnfactorweights" },
    { 0xBD04, "spawnfilllight" },
    { 0xBD05, "spawnfinalchopper" },
    { 0xBD06, "spawnflag" },
    { 0xBD07, "spawnflagid" },
    { 0xBD08, "spawnflare" },
    { 0xBD09, "spawnfromstructsdelayornotify" },
    { 0xBD0A, "spawnfunc" },
    { 0xBD0B, "spawnfunc_registered" },
    { 0xBD0C, "spawnfxarray" },
    { 0xBD0D, "spawnfxdelay" },
    { 0xBD0E, "spawngameendflagzone" },
    { 0xBD0F, "spawnglobals" },
    { 0xBD10, "spawngroup" },
    { 0xBD11, "spawnguy" },
    { 0xBD12, "spawnhalfconvoyatpath" },
    { 0xBD13, "spawnheli" },
    { 0xBD14, "spawnhelicopters" },
    { 0xBD15, "spawnhelihvtexfilactors" },
    { 0xBD16, "spawnhintobjects" },
    { 0xBD17, "spawnhostage" },
    { 0xBD18, "spawnhvt" },
    { 0xBD19, "spawnidstobeinstrumented" },
    { 0xBD1A, "spawninfilvehicle" },
    { 0xBD1B, "spawninfluencezone_onusebegin" },
    { 0xBD1C, "spawninfluencezone_onuseend" },
    { 0xBD1D, "spawninfluencezones" },
    { 0xBD1E, "spawning_backup" },
    { 0xBD1F, "spawning_poi_handler" },
    { 0xBD20, "spawningafterremotedeath" },
    { 0xBD21, "spawningclientthisframereset" },
    { 0xBD22, "spawningintovehicle" },
    { 0xBD23, "spawninitialvehicles" },
    { 0xBD24, "spawninteractionmodel" },
    { 0xBD25, "spawninteractiveinfilai" },
    { 0xBD26, "spawnintermission" },
    { 0xBD27, "spawninvehicle" },
    { 0xBD28, "spawnitem" },
    { 0xBD29, "spawnjuggcate" },
    { 0xBD2A, "spawnkillstreaks" },
    { 0xBD2B, "spawnksjackal" },
    { 0xBD2C, "spawnlaunchchunkbots" },
    { 0xBD2D, "spawnlist" },
    { 0xBD2E, "spawnlittlebird" },
    { 0xBD2F, "spawnlogicteam" },
    { 0xBD30, "spawnlogictraceheight" },
    { 0xBD31, "spawnloopupdatefunc" },
    { 0xBD32, "spawnlootcache" },
    { 0xBD33, "spawnlootcaches" },
    { 0xBD34, "spawnlootitem" },
    { 0xBD35, "spawnlootitemsuspended" },
    { 0xBD36, "spawnlootweapons" },
    { 0xBD37, "spawnmanualdomflag" },
    { 0xBD38, "spawnmaxs" },
    { 0xBD39, "spawnmethod" },
    { 0xBD3A, "spawnmine" },
    { 0xBD3B, "spawnmins" },
    { 0xBD3C, "spawnmobilearmory" },
    { 0xBD3D, "spawnnewagent" },
    { 0xBD3E, "spawnnewagentaitype" },
    { 0xBD3F, "spawnnodetype" },
    { 0xBD40, "spawnnumber" },
    { 0xBD41, "spawnoccupied" },
    { 0xBD42, "spawnorbitcamera" },
    { 0xBD43, "spawnorigin" },
    { 0xBD44, "spawnperk" },
    { 0xBD45, "spawnpersistentvehicle" },
    { 0xBD46, "spawnpickup" },
    { 0xBD47, "spawnplayer" },
    { 0xBD48, "spawnplayer_actual" },
    { 0xBD49, "spawnplayer_internal" },
    { 0xBD4A, "spawnplayerfunc" },
    { 0xBD4B, "spawnplayerpositionent" },
    { 0xBD4C, "spawnplayerpositionparentent" },
    { 0xBD4D, "spawnplayerrig" },
    { 0xBD4E, "spawnplayertoc130" },
    { 0xBD4F, "spawnplayertoconvoy" },
    { 0xBD50, "spawnplayertohelicam" },
    { 0xBD51, "spawnplayertoselection" },
    { 0xBD52, "spawnpoint" },
    { 0xBD53, "spawnpoint_debug" },
    { 0xBD54, "spawnpointarray" },
    { 0xBD55, "spawnpointdistanceupdate" },
    { 0xBD56, "spawnpointinit" },
    { 0xBD57, "spawnpoints" },
    { 0xBD58, "spawnpointscriptdata" },
    { 0xBD59, "spawnpointsets" },
    { 0xBD5A, "spawnpointslist" },
    { 0xBD5B, "spawnpointupdate" },
    { 0xBD5C, "spawnpos" },
    { 0xBD5D, "spawnpriority" },
    { 0xBD5E, "spawnprotection" },
    { 0xBD5F, "spawnprotectiontimer" },
    { 0xBD60, "spawnpunishwave" },
    { 0xBD61, "spawnrandomhostages" },
    { 0xBD62, "spawnreinforementtruck" },
    { 0xBD63, "spawnreviveclosettrigger" },
    { 0xBD64, "spawnrevivetrigger" },
    { 0xBD65, "spawnrock" },
    { 0xBD66, "spawnrocks" },
    { 0xBD67, "spawnsandboxa" },
    { 0xBD68, "spawnsatellitetruck" },
    { 0xBD69, "spawnscore" },
    { 0xBD6A, "spawnselectedsquadmate" },
    { 0xBD6B, "spawnselectendfunc" },
    { 0xBD6C, "spawnselection_showenemyhq" },
    { 0xBD6D, "spawnselectionbegin" },
    { 0xBD6E, "spawnselectionend" },
    { 0xBD6F, "spawnselectioninfil" },
    { 0xBD70, "spawnselectionlocations" },
    { 0xBD71, "spawnselectionoperatorsound" },
    { 0xBD72, "spawnselectionshowenemy" },
    { 0xBD73, "spawnselectionshowfriendly" },
    { 0xBD74, "spawnselectionshutdown_nuke" },
    { 0xBD75, "spawnselectionteamforward" },
    { 0xBD76, "spawnselectionthink" },
    { 0xBD77, "spawnselectstartfunc" },
    { 0xBD78, "spawnset" },
    { 0xBD79, "spawnsetlists" },
    { 0xBD7A, "spawnsets" },
    { 0xBD7B, "spawnspectator" },
    { 0xBD7C, "spawnspectatormapcam" },
    { 0xBD7D, "spawnspreadconvoy" },
    { 0xBD7E, "spawnsquadleaderonly" },
    { 0xBD7F, "spawnsquads" },
    { 0xBD80, "spawnstartbradley" },
    { 0xBD81, "spawnstartingbradleyscmd" },
    { 0xBD82, "spawnstartingbradleysdom" },
    { 0xBD83, "spawnstartingbradleystdm" },
    { 0xBD84, "spawnstash" },
    { 0xBD85, "spawnstaticvan" },
    { 0xBD86, "spawnstaticvehicle" },
    { 0xBD87, "spawnswitchblade" },
    { 0xBD88, "spawntag" },
    { 0xBD89, "spawntags" },
    { 0xBD8A, "spawntango72" },
    { 0xBD8B, "spawntank" },
    { 0xBD8C, "spawntankandmonitor" },
    { 0xBD8D, "spawntanks" },
    { 0xBD8E, "spawnteam" },
    { 0xBD8F, "spawntestconvoy" },
    { 0xBD90, "spawntime" },
    { 0xBD91, "spawntoc130" },
    { 0xBD92, "spawntracelocation" },
    { 0xBD93, "spawntraincar" },
    { 0xBD94, "spawntrapdangerzone" },
    { 0xBD95, "spawntripwire" },
    { 0xBD96, "spawntripwirelevelstruct" },
    { 0xBD97, "spawntruck" },
    { 0xBD98, "spawntype" },
    { 0xBD99, "spawnuniversaldangerzone" },
    { 0xBD9A, "spawnusedbyenemies" },
    { 0xBD9B, "spawnvan" },
    { 0xBD9C, "spawnvfxincircle" },
    { 0xBD9D, "spawnviewers" },
    { 0xBD9E, "spawnviewersupdatetime" },
    { 0xBD9F, "spawnviewpathnodes" },
    { 0xBDA0, "spawnvip" },
    { 0xBDA1, "spawnwallprompt" },
    { 0xBDA2, "spawnweapon" },
    { 0xBDA3, "spawnweaponobj" },
    { 0xBDA4, "spawnwithplayersecondary" },
    { 0xBDA5, "spawnwmhostagecarry" },
    { 0xBDA6, "spawnzonefx" },
    { 0xBDA7, "speak_to_stacy" },
    { 0xBDA8, "speakers" },
    { 0xBDA9, "speaking" },
    { 0xBDAA, "spec" },
    { 0xBDAB, "spec_converge" },
    { 0xBDAC, "spec_intro_plr_rumble" },
    { 0xBDAD, "spec_list" },
    { 0xBDAE, "spec_terry_shot" },
    { 0xBDAF, "special" },
    { 0xBDB0, "special_ammo_type" },
    { 0xBDB1, "special_ammocount" },
    { 0xBDB2, "special_ammocount_ap" },
    { 0xBDB3, "special_ammocount_comb" },
    { 0xBDB4, "special_ammocount_explo" },
    { 0xBDB5, "special_ammocount_in" },
    { 0xBDB6, "special_autosavecondition" },
    { 0xBDB7, "special_delay_hide" },
    { 0xBDB8, "special_event" },
    { 0xBDB9, "special_lockon_target_list" },
    { 0xBDBA, "special_mode_activation_funcs" },
    { 0xBDBB, "special_weapon_dof_funcs" },
    { 0xBDBC, "special_weapon_logic" },
    { 0xBDBD, "special_zombie_damage" },
    { 0xBDBE, "specialdeath" },
    { 0xBDBF, "specialdeathfunc" },
    { 0xBDC0, "specialentitymonitor" },
    { 0xBDC1, "specialflashedfunc" },
    { 0xBDC2, "specialidleanim" },
    { 0xBDC3, "specialist" },
    { 0xBDC4, "specialistpoints" },
    { 0xBDC5, "specialoffhandgrenade" },
    { 0xBDC6, "specialpain" },
    { 0xBDC7, "specialpainblocker" },
    { 0xBDC8, "specialreloadanimfunc" },
    { 0xBDC9, "specialshootbehavior" },
    { 0xBDCA, "specialzombie" },
    { 0xBDCB, "species" },
    { 0xBDCC, "species_funcs" },
    { 0xBDCD, "species_pre_spawn_init" },
    { 0xBDCE, "speciesfunc" },
    { 0xBDCF, "specific_combat" },
    { 0xBDD0, "specs" },
    { 0xBDD1, "spectate_init" },
    { 0xBDD2, "spectateentity" },
    { 0xBDD3, "spectateoverride" },
    { 0xBDD4, "spectaterulesfunc" },
    { 0xBDD5, "spectating" },
    { 0xBDD6, "spectating_actively" },
    { 0xBDD7, "spectatingplayerbeforeballcam" },
    { 0xBDD8, "spectator_revive_time" },
    { 0xBDD9, "spectatorcament" },
    { 0xBDDA, "spectatorcameras" },
    { 0xBDDB, "spectatorcameratime" },
    { 0xBDDC, "speed_increase_segment" },
    { 0xBDDD, "speed_monitor" },
    { 0xBDDE, "speed_norm" },
    { 0xBDDF, "speed_override" },
    { 0xBDE0, "speed_reduction_segment" },
    { 0xBDE1, "speed_scale" },
    { 0xBDE2, "speed_slow" },
    { 0xBDE3, "speed_up" },
    { 0xBDE4, "speedadjust" },
    { 0xBDE5, "speedend" },
    { 0xBDE6, "speedmod" },
    { 0xBDE7, "speedonkillmod" },
    { 0xBDE8, "speedstart" },
    { 0xBDE9, "speedstripmod" },
    { 0xBDEA, "spend_type" },
    { 0xBDEB, "spendcraftedmaterials" },
    { 0xBDEC, "spets_nvgs_on" },
    { 0xBDED, "spets_spawn_func" },
    { 0xBDEE, "spewing_barrels" },
    { 0xBDEF, "spewtags" },
    { 0xBDF0, "sphere_debug" },
    { 0xBDF1, "sphere_get_closest_point" },
    { 0xBDF2, "sphere_test" },
    { 0xBDF3, "sphere_trace" },
    { 0xBDF4, "sphere_trace_get_all_results" },
    { 0xBDF5, "sphere_trace_passed" },
    { 0xBDF6, "spheres_on_heli" },
    { 0xBDF7, "spinsoundshortly" },
    { 0xBDF8, "spinuptime" },
    { 0xBDF9, "spitter_last_cloud_time" },
    { 0xBDFA, "splash_grenade_victim_scriptable_state_func" },
    { 0xBDFB, "splash_loop" },
    { 0xBDFC, "splash02fx" },
    { 0xBDFD, "splashfx" },
    { 0xBDFE, "splashlisttoggle" },
    { 0xBDFF, "splashname" },
    { 0xBE00, "splashpriorityqueue" },
    { 0xBE01, "splashqueuehead" },
    { 0xBE02, "splashqueuetail" },
    { 0xBE03, "splashshowncallback" },
    { 0xBE04, "splashshownthink" },
    { 0xBE05, "splashtablecache" },
    { 0xBE06, "split_array_into_quadrants" },
    { 0xBE07, "split_large_pathing_array" },
    { 0xBE08, "splitarrivalsleft" },
    { 0xBE09, "splitarrivalsright" },
    { 0xBE0A, "splitexitsleft" },
    { 0xBE0B, "splitexitsright" },
    { 0xBE0C, "splitscreen" },
    { 0xBE0D, "spoon" },
    { 0xBE0E, "spoon_check" },
    { 0xBE0F, "spot_player_dialogue" },
    { 0xBE10, "spotcull_mortar_and_triage" },
    { 0xBE11, "spotdistcull" },
    { 0xBE12, "spotexpire" },
    { 0xBE13, "spotlight" },
    { 0xBE14, "spotlight_aim_ents" },
    { 0xBE15, "spotplayer" },
    { 0xBE16, "spottarget" },
    { 0xBE17, "spotted" },
    { 0xBE18, "spotted_list" },
    { 0xBE19, "spotted_thread" },
    { 0xBE1A, "spottedindex" },
    { 0xBE1B, "spottedplayer" },
    { 0xBE1C, "spotter" },
    { 0xBE1D, "spotter_scope_check" },
    { 0xBE1E, "spotterlookatents" },
    { 0xBE1F, "spotterscope_aim_hint_check" },
    { 0xBE20, "spotterscope_check_lookat" },
    { 0xBE21, "spotterscope_equip_hint_check" },
    { 0xBE22, "spotterscope_fire_hint_check" },
    { 0xBE23, "spotterthink" },
    { 0xBE24, "spotupdatelimit" },
    { 0xBE25, "spout" },
    { 0xBE26, "spplayerconnect" },
    { 0xBE27, "sppmdata" },
    { 0xBE28, "sprimaryweapon" },
    { 0xBE29, "spring_add" },
    { 0xBE2A, "spring_count" },
    { 0xBE2B, "spring_delete" },
    { 0xBE2C, "spring_get_pos" },
    { 0xBE2D, "spring_get_vel" },
    { 0xBE2E, "spring_init" },
    { 0xBE2F, "spring_make_critically_damped" },
    { 0xBE30, "spring_make_over_damped" },
    { 0xBE31, "spring_make_under_damped" },
    { 0xBE32, "spring_set_pos" },
    { 0xBE33, "spring_set_vel" },
    { 0xBE34, "spring_update" },
    { 0xBE35, "springs" },
    { 0xBE36, "sprint" },
    { 0xBE37, "sprint_disabled" },
    { 0xBE38, "sprint_to_goal" },
    { 0xBE39, "sprint_watcher" },
    { 0xBE3A, "sprint_when_needed" },
    { 0xBE3B, "sprintfootstepradius" },
    { 0xBE3C, "sprinting" },
    { 0xBE3D, "sprintinitsfxtag" },
    { 0xBE3E, "sprintsfxtag" },
    { 0xBE3F, "sprinttracking" },
    { 0xBE40, "sq_checkiflocaleisavailable" },
    { 0xBE41, "sq_circletick" },
    { 0xBE42, "sq_createcircleobjectiveicon" },
    { 0xBE43, "sq_createquestlocale" },
    { 0xBE44, "sq_initlocaletype" },
    { 0xBE45, "sq_initquesttype" },
    { 0xBE46, "sq_localethink" },
    { 0xBE47, "sq_localethink_itemspawn" },
    { 0xBE48, "sq_localethink_objectivevisibility" },
    { 0xBE49, "sq_questthink" },
    { 0xBE4A, "sq_removelocaleinstance" },
    { 0xBE4B, "sq_removelocalethread" },
    { 0xBE4C, "sq_removequestinstance" },
    { 0xBE4D, "sq_removequestthread" },
    { 0xBE4E, "squad" },
    { 0xBE4F, "squad_allieslogic" },
    { 0xBE50, "squad_dialoguelogic" },
    { 0xBE51, "squad_enemieslogic" },
    { 0xBE52, "squad_getmortarmodels" },
    { 0xBE53, "squad_getvehicles" },
    { 0xBE54, "squad_getvehiclespawners" },
    { 0xBE55, "squad_init" },
    { 0xBE56, "squad_leader_group_size" },
    { 0xBE57, "squad_main" },
    { 0xBE58, "squad_max_size" },
    { 0xBE59, "squad_spawnvehicles" },
    { 0xBE5A, "squad_start" },
    { 0xBE5B, "squad_to_alley" },
    { 0xBE5C, "squadaddtosubgroup" },
    { 0xBE5D, "squadallowuse" },
    { 0xBE5E, "squadassignedfromlobby" },
    { 0xBE5F, "squadassignnewleader" },
    { 0xBE60, "squadcanburst" },
    { 0xBE61, "squadcreateandadd" },
    { 0xBE62, "squadcreatefuncs" },
    { 0xBE63, "squadcreatestrings" },
    { 0xBE64, "squaddata" },
    { 0xBE65, "squaddenyuse" },
    { 0xBE66, "squaddropbagcrate" },
    { 0xBE67, "squadexists" },
    { 0xBE68, "squadfindnearbysquadtomergewith" },
    { 0xBE69, "squadflavorbursttransmissions" },
    { 0xBE6A, "squadhasofficer" },
    { 0xBE6B, "squadid" },
    { 0xBE6C, "squadindex" },
    { 0xBE6D, "squadinitialized" },
    { 0xBE6E, "squadleaderindex" },
    { 0xBE6F, "squadlist" },
    { 0xBE70, "squadmemberbufferedstats" },
    { 0xBE71, "squadmemberid" },
    { 0xBE72, "squadmemberindex" },
    { 0xBE73, "squadmerge" },
    { 0xBE74, "squadmovecounter" },
    { 0xBE75, "squadname" },
    { 0xBE76, "squadnum" },
    { 0xBE77, "squadofficerid" },
    { 0xBE78, "squadrand" },
    { 0xBE79, "squadremoveondeath" },
    { 0xBE7A, "squads" },
    { 0xBE7B, "squadscounter" },
    { 0xBE7C, "squadspawnaborted" },
    { 0xBE7D, "squadspawnconfirmed" },
    { 0xBE7E, "squadspawnselectionlocations" },
    { 0xBE7F, "squadspectateang" },
    { 0xBE80, "squadspectatepos" },
    { 0xBE81, "squadstartlocationkey" },
    { 0xBE82, "squadthreatwaiter" },
    { 0xBE83, "squadtracker" },
    { 0xBE84, "squadupdatefuncs" },
    { 0xBE85, "squadupdatestrings" },
    { 0xBE86, "square_cleanuppreviousai" },
    { 0xBE87, "square_dialoguepostexecutionlogic" },
    { 0xBE88, "square_dudes_hide_array" },
    { 0xBE89, "square_farahlogic" },
    { 0xBE8A, "square_farahstayaheadlogic" },
    { 0xBE8B, "square_getcivilians" },
    { 0xBE8C, "square_getcivilianworkers" },
    { 0xBE8D, "square_gethangingcivilianheadmodels" },
    { 0xBE8E, "square_getplayerbesideexecutiontrigger" },
    { 0xBE8F, "square_hangingscenelogic" },
    { 0xBE90, "square_main" },
    { 0xBE91, "square_search_dead_bodies" },
    { 0xBE92, "square_spawncageddogs" },
    { 0xBE93, "square_spawncivilians" },
    { 0xBE94, "square_spawncivilianworkers" },
    { 0xBE95, "square_spawnenemies" },
    { 0xBE96, "square_spawnhotvehicles" },
    { 0xBE97, "square_start" },
    { 0xBE98, "square_stealthbrokenlogic" },
    { 0xBE99, "square_stealthbrokenturretlogic" },
    { 0xBE9A, "square_stealthbrokenvehicledriverlogic" },
    { 0xBE9B, "square_stealthbrokenvehiclelogic" },
    { 0xBE9C, "square_wallalogic" },
    { 0xBE9D, "squatefforts" },
    { 0xBE9E, "squib_back" },
    { 0xBE9F, "squib_chest" },
    { 0xBEA0, "squib_head" },
    { 0xBEA1, "squib_left_leg" },
    { 0xBEA2, "sr" },
    { 0xBEA3, "sr_ally_near_tag" },
    { 0xBEA4, "sr_camp_tag" },
    { 0xBEA5, "sr_door_buzzer" },
    { 0xBEA6, "sr_entrance_door" },
    { 0xBEA7, "sr_exit_door" },
    { 0xBEA8, "sr_pick_up_tag" },
    { 0xBEA9, "sre" },
    { 0xBEAA, "sre_func" },
    { 0xBEAB, "srelicref1" },
    { 0xBEAC, "srelicref2" },
    { 0xBEAD, "srelicref3" },
    { 0xBEAE, "srelicref4" },
    { 0xBEAF, "srelicref5" },
    { 0xBEB0, "srelicref6" },
    { 0xBEB1, "sse_bags" },
    { 0xBEB2, "sse_items" },
    { 0xBEB3, "stab_fail_extras" },
    { 0xBEB4, "stab_swap_01" },
    { 0xBEB5, "stab_swap_02" },
    { 0xBEB6, "stab_swap_03" },
    { 0xBEB7, "stab_swap_04" },
    { 0xBEB8, "stab_swap_05" },
    { 0xBEB9, "stab_swap_06" },
    { 0xBEBA, "stab_tag" },
    { 0xBEBB, "stab01_loop_vo" },
    { 0xBEBC, "stable_unlink" },
    { 0xBEBD, "stack_endon" },
    { 0xBEBE, "stack_endon_recurse" },
    { 0xBEBF, "stack_patch" },
    { 0xBEC0, "stack_patch_leaf" },
    { 0xBEC1, "stack_patch_node" },
    { 0xBEC2, "stack_patch_root" },
    { 0xBEC3, "stack_patch_stack" },
    { 0xBEC4, "stack_up_count" },
    { 0xBEC5, "stack_up_wooden_gate" },
    { 0xBEC6, "stackable" },
    { 0xBEC7, "stackscurrent" },
    { 0xBEC8, "stacksmax" },
    { 0xBEC9, "stackup_when_clear" },
    { 0xBECA, "stackvalues" },
    { 0xBECB, "stacy" },
    { 0xBECC, "stacy_bad_places" },
    { 0xBECD, "stacy_bad_zone_attack" },
    { 0xBECE, "stacy_confirmations" },
    { 0xBECF, "stacy_dejected_idle" },
    { 0xBED0, "stacy_dies" },
    { 0xBED1, "stacy_dies_after_freedom" },
    { 0xBED2, "stacy_direction_nags" },
    { 0xBED3, "stacy_distance_watcher" },
    { 0xBED4, "stacy_hasnt_moved_check" },
    { 0xBED5, "stacy_hostage_death" },
    { 0xBED6, "stacy_idle_watcher" },
    { 0xBED7, "stacy_killed_by_player" },
    { 0xBED8, "stacy_killer_dies" },
    { 0xBED9, "stacy_killer_succeeds" },
    { 0xBEDA, "stacy_movement_watcher" },
    { 0xBEDB, "stacy_moving_watcher" },
    { 0xBEDC, "stacy_nags" },
    { 0xBEDD, "stacy_nav_blockers" },
    { 0xBEDE, "stacy_nearby_detect" },
    { 0xBEDF, "stacy_reset_ff" },
    { 0xBEE0, "stacy_run_away_watcher" },
    { 0xBEE1, "stacy_should_confirm" },
    { 0xBEE2, "stacy_spawn" },
    { 0xBEE3, "stacy_spotted" },
    { 0xBEE4, "stagger_ai_to_pos" },
    { 0xBEE5, "stair_blocker_ai_handler" },
    { 0xBEE6, "stair_blocking_marine_handler" },
    { 0xBEE7, "stair_player_clip" },
    { 0xBEE8, "stairs_2f_nag" },
    { 0xBEE9, "stairs_3f_enemy" },
    { 0xBEEA, "stairs_3f_enemy_vo" },
    { 0xBEEB, "stairs_attack_catchup" },
    { 0xBEEC, "stairs_attack_main" },
    { 0xBEED, "stairs_attack_start" },
    { 0xBEEE, "stairs_blindfire_vignette" },
    { 0xBEEF, "stairs_climb_third_floor_dialogue_handler" },
    { 0xBEF0, "stairs_explosion_heli" },
    { 0xBEF1, "stairs_explosion_player_hit" },
    { 0xBEF2, "stairs_explosion_price" },
    { 0xBEF3, "stairs_explosion_scene" },
    { 0xBEF4, "stairs_guy_spawn_func" },
    { 0xBEF5, "stairs_scene_cowbell" },
    { 0xBEF6, "stairs_scene_finished" },
    { 0xBEF7, "stairs_terminate" },
    { 0xBEF8, "stairs_tripwire_approach_call" },
    { 0xBEF9, "stairs_tripwire_lookat_monitor" },
    { 0xBEFA, "stairs_weapon" },
    { 0xBEFB, "stairtrain" },
    { 0xBEFC, "stairtrain_1f" },
    { 0xBEFD, "stairtrain_1f_animcustom" },
    { 0xBEFE, "stairtrain_1f_setup" },
    { 0xBEFF, "stairtrain_2f" },
    { 0xBF00, "stairtrain_2f_animcustom" },
    { 0xBF01, "stairtrain_2f_setup" },
    { 0xBF02, "stairtrain_attic_animcustom" },
    { 0xBF03, "stairtrain_data" },
    { 0xBF04, "stairtrain_notetracks" },
    { 0xBF05, "stairtrain_player_data" },
    { 0xBF06, "stairtrain_prevguy" },
    { 0xBF07, "stairtrain_rate" },
    { 0xBF08, "stairtrain_rearguy" },
    { 0xBF09, "stairtrain_thread" },
    { 0xBF0A, "stairtrain_twitch_get" },
    { 0xBF0B, "stairtrain1" },
    { 0xBF0C, "stairtrain1_animcustom" },
    { 0xBF0D, "stairtrain1_catchup" },
    { 0xBF0E, "stairtrain1_main" },
    { 0xBF0F, "stairtrain1_nag" },
    { 0xBF10, "stairtrain1_price_player_race" },
    { 0xBF11, "stairtrain1_ready_thread" },
    { 0xBF12, "stairtrain1_setup" },
    { 0xBF13, "stairtrain1_start" },
    { 0xBF14, "stairtrain1_try_vo" },
    { 0xBF15, "stairtrain2" },
    { 0xBF16, "stairtrain2_animcustom" },
    { 0xBF17, "stairtrain2_main" },
    { 0xBF18, "stairtrain2_nag" },
    { 0xBF19, "stairtrain2_nags" },
    { 0xBF1A, "stairtrain2_player_near" },
    { 0xBF1B, "stairtrain2_remove_clip" },
    { 0xBF1C, "stairtrain2_setup" },
    { 0xBF1D, "stairtrain2_start" },
    { 0xBF1E, "stairtrain3" },
    { 0xBF1F, "stairtrain3_animcustom" },
    { 0xBF20, "stairtrain3_main" },
    { 0xBF21, "stairtrain3_nag" },
    { 0xBF22, "stairtrain3_player_near" },
    { 0xBF23, "stairtrain3_setup" },
    { 0xBF24, "stairtrain3_start" },
    { 0xBF25, "stairwell_advance_ignore_player_clear" },
    { 0xBF26, "stairwell_advance_ignore_player_enable" },
    { 0xBF27, "stairwell_available_paths" },
    { 0xBF28, "stairwell_available_paths_index" },
    { 0xBF29, "stairwell_catchup" },
    { 0xBF2A, "stairwell_corpses_cleanup" },
    { 0xBF2B, "stairwell_crowd_car_sound" },
    { 0xBF2C, "stairwell_guard_combat_think" },
    { 0xBF2D, "stairwell_guard_should_hunt" },
    { 0xBF2E, "stairwell_lower" },
    { 0xBF2F, "stairwell_main" },
    { 0xBF30, "stairwell_molotov" },
    { 0xBF31, "stairwell_price" },
    { 0xBF32, "stairwell_runner_respawner" },
    { 0xBF33, "stairwell_runners" },
    { 0xBF34, "stairwell_second_window" },
    { 0xBF35, "stairwell_start" },
    { 0xBF36, "stairwell_upper" },
    { 0xBF37, "stakeout_catchup" },
    { 0xBF38, "stakeout_intro_start" },
    { 0xBF39, "stakeout_start" },
    { 0xBF3A, "stakeout_stp_main" },
    { 0xBF3B, "stalemate" },
    { 0xBF3C, "stamina" },
    { 0xBF3D, "stance" },
    { 0xBF3E, "stance_carry" },
    { 0xBF3F, "stance_carry_icon_disable" },
    { 0xBF40, "stance_carry_icon_enable" },
    { 0xBF41, "stance_num" },
    { 0xBF42, "stancerecoiladjuster" },
    { 0xBF43, "stancerecoilupdate" },
    { 0xBF44, "standangles" },
    { 0xBF45, "standard_soldier_watcher" },
    { 0xBF46, "standard_spawnpoint_scoring" },
    { 0xBF47, "standard_spawnpoint_valid" },
    { 0xBF48, "standattack" },
    { 0xBF49, "standdetectdist" },
    { 0xBF4A, "standing" },
    { 0xBF4B, "standing_cellphone" },
    { 0xBF4C, "standing_cellphone_anim" },
    { 0xBF4D, "standing_cellphone_anim_seq" },
    { 0xBF4E, "standing_cellphone_loop" },
    { 0xBF4F, "standmodel" },
    { 0xBF50, "standoff_main" },
    { 0xBF51, "standoff_nag_vo" },
    { 0xBF52, "standoff_start" },
    { 0xBF53, "standoff_terry_vo" },
    { 0xBF54, "standoff_trailer_setup" },
    { 0xBF55, "standoffset" },
    { 0xBF56, "standupoffset" },
    { 0xBF57, "starsearned" },
    { 0xBF58, "start" },
    { 0xBF59, "start_2f_data" },
    { 0xBF5A, "start_ac130_respawn_sequence" },
    { 0xBF5B, "start_airstrikes_sequence" },
    { 0xBF5C, "start_alley_heli_crash_lgt_fire_flicker" },
    { 0xBF5D, "start_ally_stayahead_movement" },
    { 0xBF5E, "start_alt_death" },
    { 0xBF5F, "start_ambush_on_player_fire" },
    { 0xBF60, "start_angles" },
    { 0xBF61, "start_anim_death" },
    { 0xBF62, "start_arrays" },
    { 0xBF63, "start_attack_heli" },
    { 0xBF64, "start_automated_respawn_func" },
    { 0xBF65, "start_bb_recovery" },
    { 0xBF66, "start_black_screen" },
    { 0xBF67, "start_bomb_count_down" },
    { 0xBF68, "start_bomb_count_down_on_all_bombs" },
    { 0xBF69, "start_boss_checks" },
    { 0xBF6A, "start_bpg_metal_detector_fire_flicker" },
    { 0xBF6B, "start_breakout" },
    { 0xBF6C, "start_chasing_target_entity_think" },
    { 0xBF6D, "start_checkin_weapons" },
    { 0xBF6E, "start_chopper_engine" },
    { 0xBF6F, "start_circling_heli" },
    { 0xBF70, "start_civ_struct_spawner" },
    { 0xBF71, "start_closed" },
    { 0xBF72, "start_collect_nuclear_core" },
    { 0xBF73, "start_color" },
    { 0xBF74, "start_combat_marker_think" },
    { 0xBF75, "start_convoy" },
    { 0xBF76, "start_coop_bomb_defusal_sequence" },
    { 0xBF77, "start_coop_defuse" },
    { 0xBF78, "start_coop_escort" },
    { 0xBF79, "start_coop_push" },
    { 0xBF7A, "start_coop_stealth" },
    { 0xBF7B, "start_coop_vehicle_race_sequence" },
    { 0xBF7C, "start_countdown" },
    { 0xBF7D, "start_crate_drops" },
    { 0xBF7E, "start_delay" },
    { 0xBF7F, "start_destroy_c130" },
    { 0xBF80, "start_detonator" },
    { 0xBF81, "start_display_cleanup" },
    { 0xBF82, "start_drag_rumble" },
    { 0xBF83, "start_driver_role" },
    { 0xBF84, "start_emp_effects_player" },
    { 0xBF85, "start_ending_cinematic" },
    { 0xBF86, "start_enemies_logic" },
    { 0xBF87, "start_enemy_hvt_vehicle" },
    { 0xBF88, "start_equip_disguise" },
    { 0xBF89, "start_event" },
    { 0xBF8A, "start_event_director" },
    { 0xBF8B, "start_exfil_after_timeout" },
    { 0xBF8C, "start_exfil_plane" },
    { 0xBF8D, "start_exfil_spawn_sequence" },
    { 0xBF8E, "start_explosion" },
    { 0xBF8F, "start_extract_lz" },
    { 0xBF90, "start_fail_with_fade" },
    { 0xBF91, "start_fake_combat_below" },
    { 0xBF92, "start_fakeactor_notetracks" },
    { 0xBF93, "start_fardist" },
    { 0xBF94, "start_find_hvi" },
    { 0xBF95, "start_firing" },
    { 0xBF96, "start_firing_turret" },
    { 0xBF97, "start_first_raise" },
    { 0xBF98, "start_flag" },
    { 0xBF99, "start_flight" },
    { 0xBF9A, "start_func" },
    { 0xBF9B, "start_functions" },
    { 0xBF9C, "start_game_type" },
    { 0xBF9D, "start_globalthreat_timer" },
    { 0xBF9E, "start_go_to_the_prison" },
    { 0xBF9F, "start_hack_threaded" },
    { 0xBFA0, "start_handler" },
    { 0xBFA1, "start_health" },
    { 0xBFA2, "start_heli_shake" },
    { 0xBFA3, "start_heli_spawner" },
    { 0xBFA4, "start_heli_trip_sequence" },
    { 0xBFA5, "start_holdout" },
    { 0xBFA6, "start_idle" },
    { 0xBFA7, "start_infil_plane" },
    { 0xBFA8, "start_inserting_chatter" },
    { 0xBFA9, "start_jugg_patroll" },
    { 0xBFAA, "start_kill_tunnel_spawns" },
    { 0xBFAB, "start_land_at_lz" },
    { 0xBFAC, "start_landing_sequence" },
    { 0xBFAD, "start_light_flicker" },
    { 0xBFAE, "start_light_intensity" },
    { 0xBFAF, "start_light_pulse" },
    { 0xBFB0, "start_light_tut_on_player_view" },
    { 0xBFB1, "start_lillywhites" },
    { 0xBFB2, "start_list_menu" },
    { 0xBFB3, "start_list_settext" },
    { 0xBFB4, "start_load_transients" },
    { 0xBFB5, "start_location" },
    { 0xBFB6, "start_meet_with_informant" },
    { 0xBFB7, "start_menu" },
    { 0xBFB8, "start_mg_nags" },
    { 0xBFB9, "start_midway_guys" },
    { 0xBFBA, "start_ml_p1_intel" },
    { 0xBFBB, "start_ml_p3_intel" },
    { 0xBFBC, "start_ml_p3_intel_2" },
    { 0xBFBD, "start_ml_p3_intel_3" },
    { 0xBFBE, "start_mocap_ar" },
    { 0xBFBF, "start_mortars" },
    { 0xBFC0, "start_nag_for_morales_exfil" },
    { 0xBFC1, "start_neardist" },
    { 0xBFC2, "start_new_patrol_route" },
    { 0xBFC3, "start_next_wave" },
    { 0xBFC4, "start_node" },
    { 0xBFC5, "start_node_name" },
    { 0xBFC6, "start_nogame" },
    { 0xBFC7, "start_nonstealth_teleport_sequence" },
    { 0xBFC8, "start_notetrack_wait" },
    { 0xBFC9, "start_off_running" },
    { 0xBFCA, "start_office_walla" },
    { 0xBFCB, "start_origin" },
    { 0xBFCC, "start_overlay" },
    { 0xBFCD, "start_parachute_sequence" },
    { 0xBFCE, "start_patrol" },
    { 0xBFCF, "start_phone_countdown" },
    { 0xBFD0, "start_plant_jammers" },
    { 0xBFD1, "start_player_anim" },
    { 0xBFD2, "start_point" },
    { 0xBFD3, "start_point_check" },
    { 0xBFD4, "start_point_nvg_on_hint" },
    { 0xBFD5, "start_point_reset" },
    { 0xBFD6, "start_point_setup" },
    { 0xBFD7, "start_point_update" },
    { 0xBFD8, "start_point_vision_set" },
    { 0xBFD9, "start_position" },
    { 0xBFDA, "start_pre_vault_assault" },
    { 0xBFDB, "start_quest_line" },
    { 0xBFDC, "start_quest_system" },
    { 0xBFDD, "start_reach_drop_zone" },
    { 0xBFDE, "start_reach_lz" },
    { 0xBFDF, "start_recover_nuclear_core" },
    { 0xBFE0, "start_regen_early" },
    { 0xBFE1, "start_riders_combat_logic" },
    { 0xBFE2, "start_right_underground" },
    { 0xBFE3, "start_roof_heli_crash_fire_flicker" },
    { 0xBFE4, "start_rooftop_obj" },
    { 0xBFE5, "start_rooftop_raid_heli" },
    { 0xBFE6, "start_rooftop_raid_sats" },
    { 0xBFE7, "start_running" },
    { 0xBFE8, "start_safehouse" },
    { 0xBFE9, "start_safehouse_objective" },
    { 0xBFEA, "start_searching_for_targets" },
    { 0xBFEB, "start_slow_mode" },
    { 0xBFEC, "start_smoke_in_attic" },
    { 0xBFED, "start_smoke_show" },
    { 0xBFEE, "start_smuggler_heli_flyin" },
    { 0xBFEF, "start_sniper" },
    { 0xBFF0, "start_sound" },
    { 0xBFF1, "start_spawners_after_time" },
    { 0xBFF2, "start_spec_movement" },
    { 0xBFF3, "start_stair_b_car_fire_flicker" },
    { 0xBFF4, "start_sting" },
    { 0xBFF5, "start_sting_rear" },
    { 0xBFF6, "start_struct" },
    { 0xBFF7, "start_struct_path" },
    { 0xBFF8, "start_tarp_mayhem" },
    { 0xBFF9, "start_the_drone_hint" },
    { 0xBFFA, "start_thread" },
    { 0xBFFB, "start_threshold_timeout" },
    { 0xBFFC, "start_time" },
    { 0xBFFD, "start_tree_fire_flicker" },
    { 0xBFFE, "start_trigger" },
    { 0xBFFF, "start_truck_rumble" },
    { 0xC000, "start_tunnel_sequence" },
    { 0xC001, "start_tunnels_fireball" },
    { 0xC002, "start_turbulence_sequence" },
    { 0xC003, "start_use_func" },
    { 0xC004, "start_using_bomb_detonator" },
    { 0xC005, "start_vault_assault" },
    { 0xC006, "start_vault_assault_crypto" },
    { 0xC007, "start_vault_assault_cut" },
    { 0xC008, "start_vault_assault_rooftop" },
    { 0xC009, "start_vault_assault_rooftop_call_exfil" },
    { 0xC00A, "start_vault_assault_rooftop_defend" },
    { 0xC00B, "start_vault_assault_rooftop_exfil" },
    { 0xC00C, "start_vault_assault_rooftop_heli" },
    { 0xC00D, "start_vault_assault_vault" },
    { 0xC00E, "start_vault_assault_vault_fake_end" },
    { 0xC00F, "start_vehicle_path" },
    { 0xC010, "start_vehicle_push_sequence" },
    { 0xC011, "start_vo_system" },
    { 0xC012, "start_wave" },
    { 0xC013, "start_weak_moans" },
    { 0xC014, "start_y" },
    { 0xC015, "startagentstealth" },
    { 0xC016, "startang" },
    { 0xC017, "startangle" },
    { 0xC018, "startangles" },
    { 0xC019, "startanime" },
    { 0xC01A, "startanime_a" },
    { 0xC01B, "startanime_b" },
    { 0xC01C, "startarmsraceobj" },
    { 0xC01D, "startascenderanim" },
    { 0xC01E, "startbetting" },
    { 0xC01F, "startbombphase" },
    { 0xC020, "startbombtime" },
    { 0xC021, "startbroshot" },
    { 0xC022, "startbtmflag" },
    { 0xC023, "startburnfx" },
    { 0xC024, "startbutton_onuse" },
    { 0xC025, "startbuttons" },
    { 0xC026, "startcament" },
    { 0xC027, "startchopper" },
    { 0xC028, "startchoppergunnerintro" },
    { 0xC029, "startconcussionfx" },
    { 0xC02A, "startconditions" },
    { 0xC02B, "startcontrol" },
    { 0xC02C, "startcopteroutofbounds" },
    { 0xC02D, "startcopycatoption" },
    { 0xC02E, "startddbombs" },
    { 0xC02F, "startdeathswitch" },
    { 0xC030, "startdelayms" },
    { 0xC031, "startdoorstruct" },
    { 0xC032, "startdyingcrawlbackaimsoon" },
    { 0xC033, "started" },
    { 0xC034, "started_hack" },
    { 0xC035, "started_moving" },
    { 0xC036, "started_second_position" },
    { 0xC037, "startedenteringvehicle" },
    { 0xC038, "startedfromtacops" },
    { 0xC039, "startemp" },
    { 0xC03A, "startemppulse" },
    { 0xC03B, "startendgame" },
    { 0xC03C, "startenemychopper" },
    { 0xC03D, "startexitvehicle" },
    { 0xC03E, "startfadetransition" },
    { 0xC03F, "startflashing" },
    { 0xC040, "startfreefall" },
    { 0xC041, "startfunc" },
    { 0xC042, "startfuncs" },
    { 0xC043, "startgame" },
    { 0xC044, "startgate_think" },
    { 0xC045, "startglexfilobjective" },
    { 0xC046, "startgpsjammer" },
    { 0xC047, "starthackingdefense" },
    { 0xC048, "starthackingdefensewithnoobjstruct" },
    { 0xC049, "starthelicopter" },
    { 0xC04A, "starthelipilot" },
    { 0xC04B, "starthelperdrone" },
    { 0xC04C, "starthoveranim" },
    { 0xC04D, "starthoverjetairstrikepass" },
    { 0xC04E, "starthoverjetdefend" },
    { 0xC04F, "starthq" },
    { 0xC050, "starting_currency" },
    { 0xC051, "starting_currency_after_revived_from_spectator" },
    { 0xC052, "starting_duration" },
    { 0xC053, "starting_frac" },
    { 0xC054, "starting_health" },
    { 0xC055, "starting_marines" },
    { 0xC056, "starting_pos" },
    { 0xC057, "starting_random_idle" },
    { 0xC058, "starting_randomness" },
    { 0xC059, "starting_skillpoints_given" },
    { 0xC05A, "starting_weapon" },
    { 0xC05B, "startingangles" },
    { 0xC05C, "startingcasttype" },
    { 0xC05D, "startingcooldown" },
    { 0xC05E, "startingdifficulty" },
    { 0xC05F, "startingfobnames_allies" },
    { 0xC060, "startingfobnames_axis" },
    { 0xC061, "startingfobnames_neutral" },
    { 0xC062, "startingfobs_allies" },
    { 0xC063, "startingfobs_axis" },
    { 0xC064, "startingfobs_neutral" },
    { 0xC065, "startinghealth" },
    { 0xC066, "startingjumpdownanim" },
    { 0xC067, "startingorigin" },
    { 0xC068, "startingspawns" },
    { 0xC069, "startingstuckto" },
    { 0xC06A, "startingweapon" },
    { 0xC06B, "startintensity" },
    { 0xC06C, "startjugg" },
    { 0xC06D, "startjugghud" },
    { 0xC06E, "startkeyearning" },
    { 0xC06F, "startlastextraction" },
    { 0xC070, "startlatejoinpodium" },
    { 0xC071, "startlocation" },
    { 0xC072, "startlocations" },
    { 0xC073, "startloopingcoughaudio" },
    { 0xC074, "startmapselectsequence" },
    { 0xC075, "startmarkingpassivetarget" },
    { 0xC076, "startmarkingtarget" },
    { 0xC077, "startmarkingtarget_cp" },
    { 0xC078, "startmodeobjidnotify" },
    { 0xC079, "startmonitoring" },
    { 0xC07A, "startmorales_1" },
    { 0xC07B, "startmorales_2" },
    { 0xC07C, "startmorales_3" },
    { 0xC07D, "startmorales_4" },
    { 0xC07E, "startmorales_5" },
    { 0xC07F, "startmorales_6" },
    { 0xC080, "startmoralesfastloadobj" },
    { 0xC081, "startmoraleshackobj" },
    { 0xC082, "startmoralesholdoutobj" },
    { 0xC083, "startmoralesinfilobj" },
    { 0xC084, "startmoralesrescueobj" },
    { 0xC085, "startmoralessignalobj" },
    { 0xC086, "startmoralesslowloadobj" },
    { 0xC087, "startmove" },
    { 0xC088, "startmovetime" },
    { 0xC089, "startmovey" },
    { 0xC08A, "startnode" },
    { 0xC08B, "startnodeoriginalangles" },
    { 0xC08C, "startnpcbombusesound" },
    { 0xC08D, "startobjective" },
    { 0xC08E, "startobjective1" },
    { 0xC08F, "startobjective2" },
    { 0xC090, "startobjective3" },
    { 0xC091, "startofquestnotifications" },
    { 0xC092, "startonpath" },
    { 0xC093, "startoperatorsound" },
    { 0xC094, "startorigin" },
    { 0xC095, "startotmechanics" },
    { 0xC096, "startparachute" },
    { 0xC097, "startpayloadobj" },
    { 0xC098, "startphaseoob" },
    { 0xC099, "startplayerboarding" },
    { 0xC09A, "startpoint" },
    { 0xC09B, "startprogresstimer" },
    { 0xC09C, "startpt" },
    { 0xC09D, "startquarrydef1" },
    { 0xC09E, "startquarrydef2" },
    { 0xC09F, "startquarrydef3" },
    { 0xC0A0, "startragdollwithoutwait" },
    { 0xC0A1, "startrangeroverobjective" },
    { 0xC0A2, "startrecording" },
    { 0xC0A3, "startremoteuav" },
    { 0xC0A4, "starts" },
    { 0xC0A5, "startsavedprogression" },
    { 0xC0A6, "startspawnavg" },
    { 0xC0A7, "startspawncamera" },
    { 0xC0A8, "startspawnchest" },
    { 0xC0A9, "startspawnclassname" },
    { 0xC0AA, "startspawnpoint" },
    { 0xC0AB, "startspawnpoints" },
    { 0xC0AC, "startspectatorview" },
    { 0xC0AD, "startsuspended" },
    { 0xC0AE, "startsystemshutdown" },
    { 0xC0AF, "starttabletscreen" },
    { 0xC0B0, "starttankdropoff" },
    { 0xC0B1, "starttime" },
    { 0xC0B2, "starttime_compare" },
    { 0xC0B3, "starttimefrommatchstart" },
    { 0xC0B4, "starttimeutcseconds" },
    { 0xC0B5, "starttmtylobj" },
    { 0xC0B6, "starttomastrike" },
    { 0xC0B7, "starttrackingplane" },
    { 0xC0B8, "startuiclosetimer" },
    { 0xC0B9, "startusemover" },
    { 0xC0BA, "startuseorigin" },
    { 0xC0BB, "startusingcrate" },
    { 0xC0BC, "startusingtank" },
    { 0xC0BD, "startvalue" },
    { 0xC0BE, "startvip" },
    { 0xC0BF, "startweapon" },
    { 0xC0C0, "startweapontabletfadetransition" },
    { 0xC0C1, "startyaw" },
    { 0xC0C2, "stashedgunposeoverride" },
    { 0xC0C3, "stashmakeunusabletoplayer" },
    { 0xC0C4, "stashmakeusabletoteam" },
    { 0xC0C5, "stashthink" },
    { 0xC0C6, "stataddchild" },
    { 0xC0C7, "stataddchildbuffered" },
    { 0xC0C8, "stataddchildbufferedwithmax" },
    { 0xC0C9, "state" },
    { 0xC0CA, "state_goto" },
    { 0xC0CB, "state_hidden" },
    { 0xC0CC, "state_interactions" },
    { 0xC0CD, "state_machine" },
    { 0xC0CE, "state_nofity_handler" },
    { 0xC0CF, "state_spotted" },
    { 0xC0D0, "state_transitions" },
    { 0xC0D1, "state_up" },
    { 0xC0D2, "statecontroller" },
    { 0xC0D3, "statecurr" },
    { 0xC0D4, "statedone" },
    { 0xC0D5, "stateenterinprogress" },
    { 0xC0D6, "statefunc1" },
    { 0xC0D7, "statefunc2" },
    { 0xC0D8, "statefunc3" },
    { 0xC0D9, "statefunc4" },
    { 0xC0DA, "statefunc5" },
    { 0xC0DB, "stateinterrupted" },
    { 0xC0DC, "statename" },
    { 0xC0DD, "stateprev" },
    { 0xC0DE, "states" },
    { 0xC0DF, "statgetchild" },
    { 0xC0E0, "statgetchildbuffered" },
    { 0xC0E1, "statgroups" },
    { 0xC0E2, "static_burst" },
    { 0xC0E3, "static_ks_crates" },
    { 0xC0E4, "static_ks_tablets" },
    { 0xC0E5, "static_rpgs" },
    { 0xC0E6, "static_spawn_locations" },
    { 0xC0E7, "static_time" },
    { 0xC0E8, "static_trucks" },
    { 0xC0E9, "staticc130" },
    { 0xC0EA, "staticdata" },
    { 0xC0EB, "staticmodel" },
    { 0xC0EC, "staticsuperdata" },
    { 0xC0ED, "stationary" },
    { 0xC0EE, "stats" },
    { 0xC0EF, "statsetchild" },
    { 0xC0F0, "statsetchildbuffered" },
    { 0xC0F1, "status" },
    { 0xC0F2, "statusdialog" },
    { 0xC0F3, "statusnotifytime" },
    { 0xC0F4, "stay_in_front_of_player_vehicle" },
    { 0xC0F5, "stay_on_seat_when_exit_seat" },
    { 0xC0F6, "stay_passive_if_not_weapons_free" },
    { 0xC0F7, "stayahead" },
    { 0xC0F8, "stayahead_accel" },
    { 0xC0F9, "stayahead_add_to_team" },
    { 0xC0FA, "stayahead_at_waitnode" },
    { 0xC0FB, "stayahead_disable" },
    { 0xC0FC, "stayahead_disable_wait" },
    { 0xC0FD, "stayahead_goal_is_far_enough" },
    { 0xC0FE, "stayahead_goto_can_use_wait" },
    { 0xC0FF, "stayahead_lookat" },
    { 0xC100, "stayahead_lookat_debug" },
    { 0xC101, "stayahead_lookat_enabled" },
    { 0xC102, "stayahead_lookat_far" },
    { 0xC103, "stayahead_pause" },
    { 0xC104, "stayahead_set_goalnode" },
    { 0xC105, "stayahead_set_speed" },
    { 0xC106, "stayahead_set_wait_node_radius" },
    { 0xC107, "stayahead_team_debug" },
    { 0xC108, "stayahead_team_think" },
    { 0xC109, "stayahead_thread" },
    { 0xC10A, "stayahead_turbo_check" },
    { 0xC10B, "stayahead_values_tallgrass" },
    { 0xC10C, "stayahead_wait_func" },
    { 0xC10D, "stayahead_wait_set_goal_or_path" },
    { 0xC10E, "stayahead_wait_used" },
    { 0xC10F, "stayahead_watch_end" },
    { 0xC110, "stayontag" },
    { 0xC111, "stealing_hvt" },
    { 0xC112, "stealth_area_think" },
    { 0xC113, "stealth_areas" },
    { 0xC114, "stealth_behavior_active" },
    { 0xC115, "stealth_behavior_wait" },
    { 0xC116, "stealth_break_monitor" },
    { 0xC117, "stealth_break_timestamp" },
    { 0xC118, "stealth_broadcast" },
    { 0xC119, "stealth_call" },
    { 0xC11A, "stealth_call_thread" },
    { 0xC11B, "stealth_cansave" },
    { 0xC11C, "stealth_check" },
    { 0xC11D, "stealth_combat_check" },
    { 0xC11E, "stealth_combat_music_cleanup" },
    { 0xC11F, "stealth_combat_music_init" },
    { 0xC120, "stealth_combat_music_state" },
    { 0xC121, "stealth_combat_music_state_type" },
    { 0xC122, "stealth_combat_music_updatefunc" },
    { 0xC123, "stealth_death_hints" },
    { 0xC124, "stealth_dist_scalar" },
    { 0xC125, "stealth_enemy_getbsmstate" },
    { 0xC126, "stealth_enemy_updateeveryframe" },
    { 0xC127, "stealth_event_check" },
    { 0xC128, "stealth_event_on_light_death" },
    { 0xC129, "stealth_event_propagator" },
    { 0xC12A, "stealth_get_func" },
    { 0xC12B, "stealth_group" },
    { 0xC12C, "stealth_init" },
    { 0xC12D, "stealth_init_goal_radius" },
    { 0xC12E, "stealth_initfriendly" },
    { 0xC12F, "stealth_initialized" },
    { 0xC130, "stealth_initneutral" },
    { 0xC131, "stealth_meter_degree_think" },
    { 0xC132, "stealth_meter_display_think" },
    { 0xC133, "stealth_meter_objective_id" },
    { 0xC134, "stealth_meter_state" },
    { 0xC135, "stealth_music" },
    { 0xC136, "stealth_music_pause_monitor" },
    { 0xC137, "stealth_music_stop" },
    { 0xC138, "stealth_music_thread" },
    { 0xC139, "stealth_music_transition" },
    { 0xC13A, "stealth_music_transition_sp" },
    { 0xC13B, "stealth_neutral_updateeveryframe" },
    { 0xC13C, "stealth_note_pending" },
    { 0xC13D, "stealth_note_pending_targets" },
    { 0xC13E, "stealth_note_start_alert" },
    { 0xC13F, "stealth_noted" },
    { 0xC140, "stealth_noteworthy_aim_contents" },
    { 0xC141, "stealth_noteworthy_callout_type" },
    { 0xC142, "stealth_noteworthy_callouts" },
    { 0xC143, "stealth_noteworthy_callouts_init" },
    { 0xC144, "stealth_noteworthy_delayed" },
    { 0xC145, "stealth_noteworthy_entities" },
    { 0xC146, "stealth_noteworthy_get_eye" },
    { 0xC147, "stealth_noteworthy_init" },
    { 0xC148, "stealth_noteworthy_kill_monitor" },
    { 0xC149, "stealth_noteworthy_max_delay" },
    { 0xC14A, "stealth_noteworthy_min_ads" },
    { 0xC14B, "stealth_noteworthy_min_delay" },
    { 0xC14C, "stealth_noteworthy_min_dot" },
    { 0xC14D, "stealth_noteworthy_priority" },
    { 0xC14E, "stealth_noteworthy_thread" },
    { 0xC14F, "stealth_noteworthy_trace" },
    { 0xC150, "stealth_noteworthy_trace_safety_check" },
    { 0xC151, "stealth_noteworthy_visible" },
    { 0xC152, "stealth_notified" },
    { 0xC153, "stealth_offhand_monitor" },
    { 0xC154, "stealth_override_goal" },
    { 0xC155, "stealth_patrol" },
    { 0xC156, "stealth_reacter_updateeveryframe" },
    { 0xC157, "stealth_shouldfriendly" },
    { 0xC158, "stealth_shouldhunt" },
    { 0xC159, "stealth_shouldinvestigate" },
    { 0xC15A, "stealth_shouldneutral" },
    { 0xC15B, "stealth_sit_death" },
    { 0xC15C, "stealth_sit_idle" },
    { 0xC15D, "stealth_sit_react" },
    { 0xC15E, "stealth_sitting_cell" },
    { 0xC15F, "stealth_sitting_cell_no_props" },
    { 0xC160, "stealth_sitting_laptop" },
    { 0xC161, "stealth_sitting_pistol" },
    { 0xC162, "stealth_sitting_sleep" },
    { 0xC163, "stealth_soundaliases" },
    { 0xC164, "stealth_spotted_delay" },
    { 0xC165, "stealth_state_func" },
    { 0xC166, "stealth_suspicious_doors_init" },
    { 0xC167, "stealth_terminatefriendly" },
    { 0xC168, "stealth_used" },
    { 0xC169, "stealth_velocity_override" },
    { 0xC16A, "stealth_visibility_in_darkness" },
    { 0xC16B, "stealth_vo_ent" },
    { 0xC16C, "stealth_weapon_noise_scalar" },
    { 0xC16D, "stealthairstrike_earthquake" },
    { 0xC16E, "stealthannounce" },
    { 0xC16F, "stealthcombat" },
    { 0xC170, "stealthcommander" },
    { 0xC171, "stealthcustombc" },
    { 0xC172, "stealthdocustombc" },
    { 0xC173, "stealthforcegundown" },
    { 0xC174, "stealthgroups" },
    { 0xC175, "stealthhints_aimonitor" },
    { 0xC176, "stealthhints_combatmonitor" },
    { 0xC177, "stealthhints_deathmonitor" },
    { 0xC178, "stealthhints_eventmonitor" },
    { 0xC179, "stealthhints_thread" },
    { 0xC17A, "stealthhunt" },
    { 0xC17B, "stealthidle" },
    { 0xC17C, "stealthidlealert" },
    { 0xC17D, "stealthidledelay" },
    { 0xC17E, "stealthinit" },
    { 0xC17F, "stealthinvestigate" },
    { 0xC180, "stealthradio" },
    { 0xC181, "stealthvals" },
    { 0xC182, "steerfalling" },
    { 0xC183, "steerfallinginternal" },
    { 0xC184, "steering" },
    { 0xC185, "steering_enable" },
    { 0xC186, "steering_maxdelta" },
    { 0xC187, "steering_maxroll" },
    { 0xC188, "steerparachuting" },
    { 0xC189, "steerparachutinginternal" },
    { 0xC18A, "step_back_to_last_good_branch" },
    { 0xC18B, "step_inc" },
    { 0xC18C, "stepback" },
    { 0xC18D, "stepoutyaw" },
    { 0xC18E, "stepped_stamina" },
    { 0xC18F, "stepstructs" },
    { 0xC190, "stick_forward" },
    { 0xC191, "stick_movement" },
    { 0xC192, "sticky_minedetectiondot" },
    { 0xC193, "sticky_minedetectiongraceperiod" },
    { 0xC194, "sticky_minedetectionmindist" },
    { 0xC195, "sticky_minedetonateradius" },
    { 0xC196, "sting_actor_logic" },
    { 0xC197, "sting_building_rescue" },
    { 0xC198, "sting_inside_enemy_accuracy" },
    { 0xC199, "sting_sniping" },
    { 0xC19A, "sting_sniping_extras" },
    { 0xC19B, "sting_upstairs_extras" },
    { 0xC19C, "sting_upstairs_extras_cleanup" },
    { 0xC19D, "sting_window_guy" },
    { 0xC19E, "sting_window_guys_retreat" },
    { 0xC19F, "stinger" },
    { 0xC1A0, "stinger_finalizelock" },
    { 0xC1A1, "stinger_get_closest_to_player_view" },
    { 0xC1A2, "stingerdeathcleanup" },
    { 0xC1A3, "stingerfirednotify" },
    { 0xC1A4, "stingerirtloop" },
    { 0xC1A5, "stingerlockfinalized" },
    { 0xC1A6, "stingerlocksound" },
    { 0xC1A7, "stingerlockstarted" },
    { 0xC1A8, "stingerlockstarttime" },
    { 0xC1A9, "stingerlostsightlinetime" },
    { 0xC1AA, "stingerproximitydetonate" },
    { 0xC1AB, "stingerstage" },
    { 0xC1AC, "stingertarget" },
    { 0xC1AD, "stingertoggleloop" },
    { 0xC1AE, "stingerusage" },
    { 0xC1AF, "stingerusageloop" },
    { 0xC1B0, "stingeruseentered" },
    { 0xC1B1, "stingtargstruct_create" },
    { 0xC1B2, "stingtargstruct_getinlos" },
    { 0xC1B3, "stingtargstruct_getinreticle" },
    { 0xC1B4, "stingtargstruct_getoffsets" },
    { 0xC1B5, "stingtargstruct_getorigins" },
    { 0xC1B6, "stingtargstruct_isinlos" },
    { 0xC1B7, "stingtargstruct_isinreticle" },
    { 0xC1B8, "stock" },
    { 0xC1B9, "stock_ammo" },
    { 0xC1BA, "stockammo" },
    { 0xC1BB, "stompenemyteamprogress" },
    { 0xC1BC, "stompprogressreward" },
    { 0xC1BD, "stone_respawn_pool_check" },
    { 0xC1BE, "stone_respawner_check" },
    { 0xC1BF, "stone_respawner_cursor_check" },
    { 0xC1C0, "stop_ai_movement_control" },
    { 0xC1C1, "stop_aim_search_around" },
    { 0xC1C2, "stop_aiming" },
    { 0xC1C3, "stop_aiming_for_reload" },
    { 0xC1C4, "stop_all_convoy_cars" },
    { 0xC1C5, "stop_all_friendly_convoy_vehicles" },
    { 0xC1C6, "stop_all_groups" },
    { 0xC1C7, "stop_all_spawn_groups" },
    { 0xC1C8, "stop_all_vo_sources" },
    { 0xC1C9, "stop_all_wave_modules" },
    { 0xC1CA, "stop_alt_death" },
    { 0xC1CB, "stop_and_start_group" },
    { 0xC1CC, "stop_anim" },
    { 0xC1CD, "stop_anim_on_dmg" },
    { 0xC1CE, "stop_blend" },
    { 0xC1CF, "stop_boss_checks" },
    { 0xC1D0, "stop_bulletshield_wrapper" },
    { 0xC1D1, "stop_carry" },
    { 0xC1D2, "stop_changing_ai_speed_while_offscreen" },
    { 0xC1D3, "stop_changing_scene_speed_while_offscreen" },
    { 0xC1D4, "stop_chatter_in_left_tunnel" },
    { 0xC1D5, "stop_check_skip" },
    { 0xC1D6, "stop_clientside_exploder" },
    { 0xC1D7, "stop_convoy_car" },
    { 0xC1D8, "stop_current_dialogue" },
    { 0xC1D9, "stop_deaths_door_audio" },
    { 0xC1DA, "stop_drag_rumble" },
    { 0xC1DB, "stop_emp_effects_on_players" },
    { 0xC1DC, "stop_emp_effects_player" },
    { 0xC1DD, "stop_emp_scramble" },
    { 0xC1DE, "stop_event" },
    { 0xC1DF, "stop_exploder" },
    { 0xC1E0, "stop_exploder_proc" },
    { 0xC1E1, "stop_far_cars" },
    { 0xC1E2, "stop_fighting_with_player" },
    { 0xC1E3, "stop_final_speech" },
    { 0xC1E4, "stop_firing" },
    { 0xC1E5, "stop_firing_turret" },
    { 0xC1E6, "stop_following_all_players" },
    { 0xC1E7, "stop_following_ent" },
    { 0xC1E8, "stop_func" },
    { 0xC1E9, "stop_fx_idle" },
    { 0xC1EA, "stop_fx_looper" },
    { 0xC1EB, "stop_fx_on_vehicle_watcher" },
    { 0xC1EC, "stop_gesture_on_notify_or_timeout" },
    { 0xC1ED, "stop_gesture_reaction" },
    { 0xC1EE, "stop_goliath_grab" },
    { 0xC1EF, "stop_handling_moving_platforms" },
    { 0xC1F0, "stop_idle" },
    { 0xC1F1, "stop_idle_on_spotted" },
    { 0xC1F2, "stop_if_ground_down" },
    { 0xC1F3, "stop_ignoring_after_timer" },
    { 0xC1F4, "stop_illumination_mortars_thread" },
    { 0xC1F5, "stop_inserting_chatter" },
    { 0xC1F6, "stop_intel_spawning_and_start_p3" },
    { 0xC1F7, "stop_interaction" },
    { 0xC1F8, "stop_interactions" },
    { 0xC1F9, "stop_late_long_death" },
    { 0xC1FA, "stop_leads_texts" },
    { 0xC1FB, "stop_load" },
    { 0xC1FC, "stop_lookat_random" },
    { 0xC1FD, "stop_loop_sound_after_anim" },
    { 0xC1FE, "stop_loop_sound_on_entity" },
    { 0xC1FF, "stop_looping_sound_on_ent" },
    { 0xC200, "stop_loopsound" },
    { 0xC201, "stop_magic_bullet_safe" },
    { 0xC202, "stop_magic_bullet_shield" },
    { 0xC203, "stop_marker_vfx_on_enemy_players" },
    { 0xC204, "stop_marker_vfx_on_friendly_player_think" },
    { 0xC205, "stop_marker_vfx_on_friendly_players" },
    { 0xC206, "stop_mg_behavior_if_flanked" },
    { 0xC207, "stop_module_by_groupname" },
    { 0xC208, "stop_module_by_id" },
    { 0xC209, "stop_morales_quest" },
    { 0xC20A, "stop_move_barkov" },
    { 0xC20B, "stop_move_scene" },
    { 0xC20C, "stop_nags_on_combat" },
    { 0xC20D, "stop_office_side_vo" },
    { 0xC20E, "stop_office_walla" },
    { 0xC20F, "stop_patrol" },
    { 0xC210, "stop_patrolling" },
    { 0xC211, "stop_player_anim" },
    { 0xC212, "stop_player_anim_on_death" },
    { 0xC213, "stop_player_gesture" },
    { 0xC214, "stop_player_pushed_kill" },
    { 0xC215, "stop_playerwatch_unresolved_collision" },
    { 0xC216, "stop_previous_highlight" },
    { 0xC217, "stop_prone_slide_vfx" },
    { 0xC218, "stop_queued_reaction" },
    { 0xC219, "stop_random_idles" },
    { 0xC21A, "stop_reminders" },
    { 0xC21B, "stop_revive_gesture" },
    { 0xC21C, "stop_reviving" },
    { 0xC21D, "stop_roof_heli_crash_fire_flicker" },
    { 0xC21E, "stop_seeking" },
    { 0xC21F, "stop_sound" },
    { 0xC220, "stop_sound_on_hit" },
    { 0xC221, "stop_sound_when_slowed" },
    { 0xC222, "stop_sounds" },
    { 0xC223, "stop_sounds_on_damaged" },
    { 0xC224, "stop_sounds_on_death" },
    { 0xC225, "stop_sounds_post_bomb" },
    { 0xC226, "stop_speaking" },
    { 0xC227, "stop_stair_b_car_fire_flicker" },
    { 0xC228, "stop_state_based_interaction" },
    { 0xC229, "stop_stealth_meter" },
    { 0xC22A, "stop_struct_fx" },
    { 0xC22B, "stop_tank" },
    { 0xC22C, "stop_technical" },
    { 0xC22D, "stop_use_turret" },
    { 0xC22E, "stop_user_skip" },
    { 0xC22F, "stop_using_bomb_detonator" },
    { 0xC230, "stop_using_crate" },
    { 0xC231, "stop_using_turret" },
    { 0xC232, "stop_vehicle_on_damage" },
    { 0xC233, "stop_vehicle_on_damage_after_loaded" },
    { 0xC234, "stop_vehicle_on_damage_internal" },
    { 0xC235, "stop_vo_bs_idle" },
    { 0xC236, "stop_vo_bucket" },
    { 0xC237, "stop_vo_source" },
    { 0xC238, "stop_waiting_for_door" },
    { 0xC239, "stop_wave_spawning" },
    { 0xC23A, "stop_wave_spawning_once_heli_leaves" },
    { 0xC23B, "stop_wind" },
    { 0xC23C, "stop_wolf_pa_on_death" },
    { 0xC23D, "stopblinkinglight" },
    { 0xC23E, "stopburnfx" },
    { 0xC23F, "stopcamera" },
    { 0xC240, "stopconcussionfx" },
    { 0xC241, "stopcontrol" },
    { 0xC242, "stopcopycatoption" },
    { 0xC243, "stopdata" },
    { 0xC244, "stopflashing" },
    { 0xC245, "stopfuncs" },
    { 0xC246, "stophandlingmovingplatforms" },
    { 0xC247, "stopimpactsfx" },
    { 0xC248, "stopinfiniteammothread" },
    { 0xC249, "stopkeyearning" },
    { 0xC24A, "stoplocalsound_safe" },
    { 0xC24B, "stoplocationselection" },
    { 0xC24C, "stoploopingcoughaudio" },
    { 0xC24D, "stopmapselectsequence" },
    { 0xC24E, "stoponback" },
    { 0xC24F, "stopped" },
    { 0xC250, "stopped_by_leader" },
    { 0xC251, "stopped_by_player" },
    { 0xC252, "stopped_for_allies" },
    { 0xC253, "stopped_morales_quest" },
    { 0xC254, "stopped_recently" },
    { 0xC255, "stoppedatlocation" },
    { 0xC256, "stopping" },
    { 0xC257, "stopping_power_on_use" },
    { 0xC258, "stoppingpower_beginuse" },
    { 0xC259, "stoppingpower_breaksprint" },
    { 0xC25A, "stoppingpower_cancelreload" },
    { 0xC25B, "stoppingpower_clearhcr" },
    { 0xC25C, "stoppingpower_clearhcrondeath" },
    { 0xC25D, "stoppingpower_givefastreload" },
    { 0xC25E, "stoppingpower_givehcr" },
    { 0xC25F, "stoppingpower_removehcr" },
    { 0xC260, "stoppingpower_watchhcrweaponchange" },
    { 0xC261, "stoppingpower_watchhcrweaponfire" },
    { 0xC262, "stoppingpowerbeginuse" },
    { 0xC263, "stoppingpowerkills" },
    { 0xC264, "stopposition" },
    { 0xC265, "stoprecording" },
    { 0xC266, "stopremotesequence" },
    { 0xC267, "stoprunngun" },
    { 0xC268, "stops" },
    { 0xC269, "stopshooting" },
    { 0xC26A, "stopshotgunpumpaftertime" },
    { 0xC26B, "stopsoundoncompletion" },
    { 0xC26C, "stopsounds_on_notify" },
    { 0xC26D, "stopsuspensemusic" },
    { 0xC26E, "stoptabletscreen" },
    { 0xC26F, "stopthinking" },
    { 0xC270, "stoptickingsound" },
    { 0xC271, "stoptimes" },
    { 0xC272, "stoptrackingplane" },
    { 0xC273, "stoptreadfx" },
    { 0xC274, "stopunfillthread" },
    { 0xC275, "stopusesound" },
    { 0xC276, "stopusingcrate" },
    { 0xC277, "stopusingremote" },
    { 0xC278, "stopwatchingthermalinputchange" },
    { 0xC279, "stopwaveandstartthisone" },
    { 0xC27A, "storage" },
    { 0xC27B, "storage_3rd_room_propane_set_exploder" },
    { 0xC27C, "storage_3rd_room_propane_tripwire" },
    { 0xC27D, "storage_3rd_room_propane_tripwire_think" },
    { 0xC27E, "storage_3rd_room_propanes" },
    { 0xC27F, "storage_3rd_room_setoff_tripwires" },
    { 0xC280, "storage_3rd_room_spawn" },
    { 0xC281, "storage_advance_now" },
    { 0xC282, "storage_advancer" },
    { 0xC283, "storage_advancer_mg_aware" },
    { 0xC284, "storage_ambush_kickoff" },
    { 0xC285, "storage_ambush_runner" },
    { 0xC286, "storage_ambusher" },
    { 0xC287, "storage_ambusher_advance" },
    { 0xC288, "storage_ambusher_advance_watch" },
    { 0xC289, "storage_ambusher_attack" },
    { 0xC28A, "storage_ambusher_blind_fire" },
    { 0xC28B, "storage_ambusher_blind_fire_anim" },
    { 0xC28C, "storage_ambusher_blind_fire_guy" },
    { 0xC28D, "storage_ambusher_fake_can_shoot" },
    { 0xC28E, "storage_ambusher_fake_shoot" },
    { 0xC28F, "storage_ambusher_left_guy" },
    { 0xC290, "storage_ambusher_prep" },
    { 0xC291, "storage_catchup" },
    { 0xC292, "storage_death_hint_think" },
    { 0xC293, "storage_do_not_spawn_runner" },
    { 0xC294, "storage_enemy_hold_fire" },
    { 0xC295, "storage_enemy_temp_ignore" },
    { 0xC296, "storage_enemy_temp_ignore_shot" },
    { 0xC297, "storage_enemy_waittill_seen_or_hurt" },
    { 0xC298, "storage_farah_combat_behavior" },
    { 0xC299, "storage_first_room_enemy_whisper" },
    { 0xC29A, "storage_flank_weapon_watch" },
    { 0xC29B, "storage_lmg" },
    { 0xC29C, "storage_lmg_camper" },
    { 0xC29D, "storage_lmg_guy" },
    { 0xC29E, "storage_lmg_room_guy" },
    { 0xC29F, "storage_lmg_room_propane_detonation_think" },
    { 0xC2A0, "storage_mg_coward" },
    { 0xC2A1, "storage_mg_coward_monitor_death" },
    { 0xC2A2, "storage_mg_farah_behavior" },
    { 0xC2A3, "storage_mg_farah_suppression" },
    { 0xC2A4, "storage_mg_guy" },
    { 0xC2A5, "storage_mg_guy_flashbang_detector" },
    { 0xC2A6, "storage_mg_guy_health_management" },
    { 0xC2A7, "storage_mg_guy_molotov_crawl" },
    { 0xC2A8, "storage_mg_guy_molotov_crawl_anim" },
    { 0xC2A9, "storage_mg_guy_molotov_death" },
    { 0xC2AA, "storage_mg_guy_monitor_shot_by_player_near_mg_nest" },
    { 0xC2AB, "storage_mg_hint_objective" },
    { 0xC2AC, "storage_mg_nest_first_guy" },
    { 0xC2AD, "storage_mg_no_shoot_zone" },
    { 0xC2AE, "storage_mg_oilfire_scriptable_detonation" },
    { 0xC2AF, "storage_mg_oilfire_scriptable_detonation_think" },
    { 0xC2B0, "storage_mg_oilfire_setoff_other_propane_tanks" },
    { 0xC2B1, "storage_mg_player_lag" },
    { 0xC2B2, "storage_mg_putout_fire" },
    { 0xC2B3, "storage_mg_room_propanes" },
    { 0xC2B4, "storage_mg_shoot_wall_zone" },
    { 0xC2B5, "storage_mg_shoot_zone" },
    { 0xC2B6, "storage_mg_slow_reaction_zone" },
    { 0xC2B7, "storage_mg_tracer_remove_on_death" },
    { 0xC2B8, "storage_oil" },
    { 0xC2B9, "storage_oil_catchup" },
    { 0xC2BA, "storage_oil_final_room_nags" },
    { 0xC2BB, "storage_oil_fire" },
    { 0xC2BC, "storage_oil_player_clear_vo" },
    { 0xC2BD, "storage_oil_start" },
    { 0xC2BE, "storage_oilfire_puzzle" },
    { 0xC2BF, "storage_propane_toss" },
    { 0xC2C0, "storage_propane_toss_scene" },
    { 0xC2C1, "storage_redirect_enemies" },
    { 0xC2C2, "storage_retreat_on_look_at" },
    { 0xC2C3, "storage_room_2_lmg_buddy" },
    { 0xC2C4, "storage_runner" },
    { 0xC2C5, "storage_runner_cleared_detector" },
    { 0xC2C6, "storage_runners" },
    { 0xC2C7, "storage_runners_woke" },
    { 0xC2C8, "storage_setup" },
    { 0xC2C9, "storage_split" },
    { 0xC2CA, "storage_split_catchup" },
    { 0xC2CB, "storage_split_fall_vo" },
    { 0xC2CC, "storage_split_remove_fov_scale_factor_override" },
    { 0xC2CD, "storage_split_scene_farah" },
    { 0xC2CE, "storage_split_scene_farah_jump" },
    { 0xC2CF, "storage_split_scene_farah_vo" },
    { 0xC2D0, "storage_split_scene_player" },
    { 0xC2D1, "storage_split_skip_to_jump_monitor" },
    { 0xC2D2, "storage_split_start" },
    { 0xC2D3, "storage_spotter" },
    { 0xC2D4, "storage_start" },
    { 0xC2D5, "storage_surprise" },
    { 0xC2D6, "storage_surprise_guy" },
    { 0xC2D7, "storage_surprise_propane_exploder" },
    { 0xC2D8, "storage_surprise_shoot_on_notetrack" },
    { 0xC2D9, "storage_surprise_vo" },
    { 0xC2DA, "storage_surprise_wait" },
    { 0xC2DB, "storage_tripwire_chain_defuse" },
    { 0xC2DC, "storage_tripwire_chain_defuse_single" },
    { 0xC2DD, "storage_tripwire_chain_defuse_think" },
    { 0xC2DE, "store_attacker_info" },
    { 0xC2DF, "store_farah" },
    { 0xC2E0, "store_linked_smartobjects" },
    { 0xC2E1, "store_og_intensity" },
    { 0xC2E2, "store_old_root" },
    { 0xC2E3, "store_original_traverse_data" },
    { 0xC2E4, "store_players_weapons" },
    { 0xC2E5, "store_vehicle_nodes_ground_pos" },
    { 0xC2E6, "store_weapons_status" },
    { 0xC2E7, "storecenterflag" },
    { 0xC2E8, "storecompletedmerit" },
    { 0xC2E9, "storecompletedoperation" },
    { 0xC2EA, "stored_damage" },
    { 0xC2EB, "stored_ents" },
    { 0xC2EC, "stored_fnf" },
    { 0xC2ED, "stored_weapons" },
    { 0xC2EE, "storedslotsunlocked" },
    { 0xC2EF, "storedtarget" },
    { 0xC2F0, "storedweapon" },
    { 0xC2F1, "storedweapons" },
    { 0xC2F2, "storeothersideobjectreference" },
    { 0xC2F3, "storepowercooldowns" },
    { 0xC2F4, "storescorestreakpointsongameend" },
    { 0xC2F5, "storesupercooldownforroundchange" },
    { 0xC2F6, "storesuperpoints" },
    { 0xC2F7, "stow_halligan" },
    { 0xC2F8, "stowed_weapon" },
    { 0xC2F9, "stowsidearmposition" },
    { 0xC2FA, "stowsidearmpositiondefault" },
    { 0xC2FB, "stpetersburg_ai_spawn_function_setup" },
    { 0xC2FC, "stpetersburg_door_init" },
    { 0xC2FD, "stpetersburg_friendly_fire_think" },
    { 0xC2FE, "stpetersburg_intro_screen" },
    { 0xC2FF, "stpetersburg_objectives" },
    { 0xC300, "stpetersburg_player_setup" },
    { 0xC301, "stpetersburg_preload" },
    { 0xC302, "stpetersburg_starts" },
    { 0xC303, "stpetersburg_transients" },
    { 0xC304, "strafe_foot" },
    { 0xC305, "strafe_foot_time" },
    { 0xC306, "strafeaimchange_cleanup" },
    { 0xC307, "strafeaimchangealias" },
    { 0xC308, "strafeangle" },
    { 0xC309, "strafearrival_animindex" },
    { 0xC30A, "strafearrival_duration" },
    { 0xC30B, "strafearrival_idealstartpos" },
    { 0xC30C, "strafearrival_rate" },
    { 0xC30D, "strafeloop_codeblend_cleanup" },
    { 0xC30E, "strafepoispeedtarget" },
    { 0xC30F, "stranim" },
    { 0xC310, "straps" },
    { 0xC311, "strategy_level" },
    { 0xC312, "streakcanseetarget" },
    { 0xC313, "streakcheckistargetindoors" },
    { 0xC314, "streakdata" },
    { 0xC315, "streakdeploy_cancelalldeployments" },
    { 0xC316, "streakdeploy_dogesturedeploy" },
    { 0xC317, "streakdeploy_dothrowbackmarkerdeploy" },
    { 0xC318, "streakdeploy_doweaponfireddeploy" },
    { 0xC319, "streakdeploy_doweaponswitchdeploy" },
    { 0xC31A, "streakdeploy_doweapontabletdeploy" },
    { 0xC31B, "streakdeploy_giveandfireoffhandreliable" },
    { 0xC31C, "streakdeploy_watchgiveandfireoffhandreliablefailure" },
    { 0xC31D, "streakdeploy_watchgiveandfireoffhandreliablesuccess" },
    { 0xC31E, "streakglobals_onkillstreakbeginuse" },
    { 0xC31F, "streakglobals_onkillstreakfinishuse" },
    { 0xC320, "streakglobals_onkillstreaktriggered" },
    { 0xC321, "streakindex" },
    { 0xC322, "streakinfo" },
    { 0xC323, "streaklifeid" },
    { 0xC324, "streakmsg" },
    { 0xC325, "streakname" },
    { 0xC326, "streakpoints" },
    { 0xC327, "streaks" },
    { 0xC328, "streaksetupinfo" },
    { 0xC329, "streakshouldchain" },
    { 0xC32A, "streakstate" },
    { 0xC32B, "streaktable" },
    { 0xC32C, "streaktype" },
    { 0xC32D, "streaktyperesetsondeath" },
    { 0xC32E, "streamnode" },
    { 0xC32F, "streamsync" },
    { 0xC330, "streamweaponsonzonechange" },
    { 0xC331, "street_backshot_vig" },
    { 0xC332, "street_car_passenger" },
    { 0xC333, "street_civ_cower_01_behavior" },
    { 0xC334, "street_civ_cower_02_behavior" },
    { 0xC335, "street_civ_cower_03_behavior" },
    { 0xC336, "street_civ_cower_04_behavior" },
    { 0xC337, "street_civ_mag_bullet" },
    { 0xC338, "street_civ_run_cower_handler" },
    { 0xC339, "street_civ_run_cower_vig" },
    { 0xC33A, "street_civs_flee" },
    { 0xC33B, "street_cleanup_approach" },
    { 0xC33C, "street_cleanup_combat" },
    { 0xC33D, "street_cleanup_ents" },
    { 0xC33E, "street_couple_vig" },
    { 0xC33F, "street_cross_handler" },
    { 0xC340, "street_death_civ_vig" },
    { 0xC341, "street_friendlies" },
    { 0xC342, "street_jogger" },
    { 0xC343, "street_jogger_vo" },
    { 0xC344, "street_knocknock" },
    { 0xC345, "street_knocknock_vo" },
    { 0xC346, "street_main" },
    { 0xC347, "street_movement_completed" },
    { 0xC348, "street_patch_handler" },
    { 0xC349, "street_police1" },
    { 0xC34A, "street_start" },
    { 0xC34B, "streets_init" },
    { 0xC34C, "streets_loop_helis_1" },
    { 0xC34D, "streets_push_up_nag" },
    { 0xC34E, "streets_smoke_grenade_guaranteed_nag" },
    { 0xC34F, "streets_smoke_grenade_nag" },
    { 0xC350, "streets_stealth_settings" },
    { 0xC351, "stretchanim" },
    { 0xC352, "strike_add_to_cs_arrays" },
    { 0xC353, "strike_additem" },
    { 0xC354, "strike_addstructtolevel" },
    { 0xC355, "strike_fixautokvps" },
    { 0xC356, "strike_interactioncreate" },
    { 0xC357, "strike_modelcreate" },
    { 0xC358, "strike_player_connect_black_screen" },
    { 0xC359, "strike_player_connect_black_screen_fn" },
    { 0xC35A, "strike_setup_arrays" },
    { 0xC35B, "strike_triggerassignvalues" },
    { 0xC35C, "strike_triggercreate" },
    { 0xC35D, "string" },
    { 0xC35E, "string_is_single_digit_integer" },
    { 0xC35F, "string_remove" },
    { 0xC360, "string_starts_with" },
    { 0xC361, "string_to_bool" },
    { 0xC362, "stringcannotplace" },
    { 0xC363, "stringemissilefired" },
    { 0xC364, "stringref" },
    { 0xC365, "strings" },
    { 0xC366, "stringtofloat" },
    { 0xC367, "stringvar" },
    { 0xC368, "strip_old_ai" },
    { 0xC369, "strip_suffix" },
    { 0xC36A, "stripspawner" },
    { 0xC36B, "stripweaponsfromplayer" },
    { 0xC36C, "stripweapsuffix" },
    { 0xC36D, "strobe" },
    { 0xC36E, "strobelight" },
    { 0xC36F, "strrazorlinks" },
    { 0xC370, "struct" },
    { 0xC371, "struct_01" },
    { 0xC372, "struct_02" },
    { 0xC373, "struct_array_index" },
    { 0xC374, "struct_array_loadout_locations" },
    { 0xC375, "struct_arrayspawn" },
    { 0xC376, "struct_class_names" },
    { 0xC377, "struct_filter" },
    { 0xC378, "struct_filter_kvps" },
    { 0xC379, "struct_fx" },
    { 0xC37A, "struct_fx_active" },
    { 0xC37B, "struct_fx_inactive" },
    { 0xC37C, "struct_has_advanced_settings" },
    { 0xC37D, "struct_is_personally_disabled" },
    { 0xC37E, "struct_node_path_array" },
    { 0xC37F, "struct_node_path_duration_array" },
    { 0xC380, "struct_path_unload_node" },
    { 0xC381, "struct_wait" },
    { 0xC382, "structarray_add" },
    { 0xC383, "structarray_remove" },
    { 0xC384, "structarray_remove_index" },
    { 0xC385, "structarray_remove_undefined" },
    { 0xC386, "structarray_shuffle" },
    { 0xC387, "structarray_swap" },
    { 0xC388, "structarray_swaptolast" },
    { 0xC389, "struggle_decided" },
    { 0xC38A, "struggle_started" },
    { 0xC38B, "stub" },
    { 0xC38C, "stub_move" },
    { 0xC38D, "stub_move_to_struct" },
    { 0xC38E, "stub_path" },
    { 0xC38F, "stub_path_array" },
    { 0xC390, "stub_path_simple" },
    { 0xC391, "stuckbygrenade" },
    { 0xC392, "stuckenemyentity" },
    { 0xC393, "stuckexplosioncounted" },
    { 0xC394, "stuckinlaststand" },
    { 0xC395, "stucktime" },
    { 0xC396, "stuckto" },
    { 0xC397, "stucktoai" },
    { 0xC398, "stumble_ai" },
    { 0xC399, "stumble_player" },
    { 0xC39A, "stumblechooseanim" },
    { 0xC39B, "stumbledelay" },
    { 0xC39C, "stumbleterminate" },
    { 0xC39D, "stumbletimer" },
    { 0xC39E, "stumblingpain" },
    { 0xC39F, "stumblingpainalias" },
    { 0xC3A0, "stumblingpainanimindex" },
    { 0xC3A1, "stumblingpainanimseq" },
    { 0xC3A2, "stumblingpainnotetrackhandler" },
    { 0xC3A3, "stun_hit" },
    { 0xC3A4, "stun_hit_time" },
    { 0xC3A5, "stun_struct" },
    { 0xC3A6, "stuncooldown" },
    { 0xC3A7, "stundamageonplayers" },
    { 0xC3A8, "stunenemiesinrange" },
    { 0xC3A9, "stunned" },
    { 0xC3AA, "stunplayersinrange" },
    { 0xC3AB, "stunscalar" },
    { 0xC3AC, "stunstick" },
    { 0xC3AD, "stunstickattacker" },
    { 0xC3AE, "stuntguy1" },
    { 0xC3AF, "stuntguy2" },
    { 0xC3B0, "style" },
    { 0xC3B1, "subclass" },
    { 0xC3B2, "subclass_spawn_functions" },
    { 0xC3B3, "subdue_player_in_place" },
    { 0xC3B4, "subparthandler" },
    { 0xC3B5, "subscribedinstances" },
    { 0xC3B6, "subscriber_category" },
    { 0xC3B7, "subscriber_type" },
    { 0xC3B8, "substates" },
    { 0xC3B9, "subtractheavyarmor" },
    { 0xC3BA, "subtype" },
    { 0xC3BB, "subway_right_escape_magic_bullets" },
    { 0xC3BC, "subway_right_wave2_logic" },
    { 0xC3BD, "success" },
    { 0xC3BE, "successcondition_enemykills" },
    { 0xC3BF, "successful_smoke" },
    { 0xC3C0, "suicide_bomber" },
    { 0xC3C1, "suicide_bomber_clean_up" },
    { 0xC3C2, "suicide_bomber_combat_func" },
    { 0xC3C3, "suicide_bomber_count" },
    { 0xC3C4, "suicide_bomber_death_quote_skip" },
    { 0xC3C5, "suicide_bomber_explode_func" },
    { 0xC3C6, "suicide_bomber_explodes" },
    { 0xC3C7, "suicide_bomber_spawn_func" },
    { 0xC3C8, "suicide_bomber_think" },
    { 0xC3C9, "suicide_bombers_alive" },
    { 0xC3CA, "suicide_dialoguehintslogic" },
    { 0xC3CB, "suicide_dialoguelogic" },
    { 0xC3CC, "suicide_getvehicles" },
    { 0xC3CD, "suicide_main" },
    { 0xC3CE, "suicide_musiclogic" },
    { 0xC3CF, "suicide_playersawvehiclelogic" },
    { 0xC3D0, "suicide_spawnvehicle" },
    { 0xC3D1, "suicide_start" },
    { 0xC3D2, "suicide_truck_ahead_of_player_humvee" },
    { 0xC3D3, "suicide_truck_damage_monitor" },
    { 0xC3D4, "suicide_truck_detonate_think" },
    { 0xC3D5, "suicide_truck_explode_think" },
    { 0xC3D6, "suicide_truck_explodes" },
    { 0xC3D7, "suicide_truck_should_detonate" },
    { 0xC3D8, "suicide_truck_spawn_trigger_think" },
    { 0xC3D9, "suicide_truck_speed_manager" },
    { 0xC3DA, "suicide_truct_explods" },
    { 0xC3DB, "suicide_vest_timer" },
    { 0xC3DC, "suicide_when_players_not_looking" },
    { 0xC3DD, "suicidebomber" },
    { 0xC3DE, "suicidebomberchants" },
    { 0xC3DF, "suicidesetup" },
    { 0xC3E0, "suicidespawndelay" },
    { 0xC3E1, "suicideswitched" },
    { 0xC3E2, "suit" },
    { 0xC3E3, "summonextractchopper" },
    { 0xC3E4, "sun_adjustments_hospital_force" },
    { 0xC3E5, "sun_adjustments_hospital_trigger" },
    { 0xC3E6, "sun_adjustments_murderhole_building" },
    { 0xC3E7, "sun_adjustments_register_trigger" },
    { 0xC3E8, "sun_disable" },
    { 0xC3E9, "sun_enable" },
    { 0xC3EA, "sun_flare_ent" },
    { 0xC3EB, "sun_flare_off" },
    { 0xC3EC, "sun_flare_on" },
    { 0xC3ED, "sun_flare_pos" },
    { 0xC3EE, "sun_light_fade" },
    { 0xC3EF, "sun_shadow_trigger" },
    { 0xC3F0, "sunangles" },
    { 0xC3F1, "sunflare_changes" },
    { 0xC3F2, "sunflare_settings" },
    { 0xC3F3, "sunisprimarylight" },
    { 0xC3F4, "super" },
    { 0xC3F5, "super_activate_func" },
    { 0xC3F6, "super_activated" },
    { 0xC3F7, "super_hold_think" },
    { 0xC3F8, "super_invulnerable" },
    { 0xC3F9, "super_meter_draining" },
    { 0xC3FA, "super_progress" },
    { 0xC3FB, "super_progress_scalar" },
    { 0xC3FC, "super_ready" },
    { 0xC3FD, "superabilitywatcher" },
    { 0xC3FE, "superdeadsilence_beginsuper" },
    { 0xC3FF, "superdeadsilence_endhudsequence" },
    { 0xC400, "superdeadsilence_endsuper" },
    { 0xC401, "superdeadsilence_onkill" },
    { 0xC402, "superdeadsilence_starthudsequence" },
    { 0xC403, "superdeadsilence_updateuistate" },
    { 0xC404, "superdelay" },
    { 0xC405, "superdelayendtime" },
    { 0xC406, "superdelaypassed" },
    { 0xC407, "superdelaystarttime" },
    { 0xC408, "superdisabledinarbitraryup" },
    { 0xC409, "superdisabledinarbitraryupmessage" },
    { 0xC40A, "superearned" },
    { 0xC40B, "superearnratemultiplier" },
    { 0xC40C, "superfaction" },
    { 0xC40D, "superfastchargerate" },
    { 0xC40E, "superglobals" },
    { 0xC40F, "supergunout" },
    { 0xC410, "superid" },
    { 0xC411, "superkill" },
    { 0xC412, "superpoints" },
    { 0xC413, "superpointschanged" },
    { 0xC414, "superpointsmod" },
    { 0xC415, "superreminderset" },
    { 0xC416, "supers_init" },
    { 0xC417, "supersbyid" },
    { 0xC418, "supersbyoffhand" },
    { 0xC419, "superselectbeginuse" },
    { 0xC41A, "supershutdown" },
    { 0xC41B, "supersprintkillrefresh_init" },
    { 0xC41C, "supersprintkillrefresh_onkill" },
    { 0xC41D, "superstarted" },
    { 0xC41E, "superstate" },
    { 0xC41F, "supertrophy" },
    { 0xC420, "superusedurationupdated" },
    { 0xC421, "superusefinished" },
    { 0xC422, "superweapondropbeginuse" },
    { 0xC423, "superweapons" },
    { 0xC424, "superwide" },
    { 0xC425, "supplementary_fire_damage" },
    { 0xC426, "supplementary_molotov_damage" },
    { 0xC427, "supplypackmonitor" },
    { 0xC428, "support_equipment" },
    { 0xC429, "support_equipment_og" },
    { 0xC42A, "support_marine_ied_street_stayahead_behavior" },
    { 0xC42B, "support_mortar_tube" },
    { 0xC42C, "supportbox" },
    { 0xC42D, "supportbox_addheadicon" },
    { 0xC42E, "supportbox_addobjectiveicon" },
    { 0xC42F, "supportbox_addowneroutline" },
    { 0xC430, "supportbox_bulletdamagetohits" },
    { 0xC431, "supportbox_canusedeployable" },
    { 0xC432, "supportbox_delete" },
    { 0xC433, "supportbox_destroy" },
    { 0xC434, "supportbox_empapplied" },
    { 0xC435, "supportbox_explode" },
    { 0xC436, "supportbox_explosivedamagetohits" },
    { 0xC437, "supportbox_getcloseanimduration" },
    { 0xC438, "supportbox_getdeployanimduration" },
    { 0xC439, "supportbox_getuseanimduration" },
    { 0xC43A, "supportbox_givepointsfordeath" },
    { 0xC43B, "supportbox_givexpfortrigger" },
    { 0xC43C, "supportbox_givexpforuse" },
    { 0xC43D, "supportbox_grenadelaunchfunc" },
    { 0xC43E, "supportbox_handledamage" },
    { 0xC43F, "supportbox_handledeathdamage" },
    { 0xC440, "supportbox_handlefataldamage" },
    { 0xC441, "supportbox_handlemovingplatforms" },
    { 0xC442, "supportbox_hideandshowaftertime" },
    { 0xC443, "supportbox_init" },
    { 0xC444, "supportbox_makedamageable" },
    { 0xC445, "supportbox_maketriggerable" },
    { 0xC446, "supportbox_makeuntriggerable" },
    { 0xC447, "supportbox_makeunusable" },
    { 0xC448, "supportbox_makeusable" },
    { 0xC449, "supportbox_modifydamage" },
    { 0xC44A, "supportbox_ondeploy" },
    { 0xC44B, "supportbox_ondeployinternal" },
    { 0xC44C, "supportbox_onmovingplatformdeath" },
    { 0xC44D, "supportbox_onplayertrigger" },
    { 0xC44E, "supportbox_onplayeruse" },
    { 0xC44F, "supportbox_onplayeruseanim" },
    { 0xC450, "supportbox_onusedeployable" },
    { 0xC451, "supportbox_playercantrigger" },
    { 0xC452, "supportbox_playercanuse" },
    { 0xC453, "supportbox_removeheadicon" },
    { 0xC454, "supportbox_removeobjectiveicon" },
    { 0xC455, "supportbox_removeowneroutline" },
    { 0xC456, "supportbox_unset" },
    { 0xC457, "supportbox_updateplayersused" },
    { 0xC458, "supportbox_updateplayerusevisibility" },
    { 0xC459, "supportbox_used" },
    { 0xC45A, "supportbox_usedcallback" },
    { 0xC45B, "supportbox_waittill_notify" },
    { 0xC45C, "supportbox_waittill_removeorweaponchange" },
    { 0xC45D, "supportbox_watchallplayertrigger" },
    { 0xC45E, "supportbox_watchallplayeruse" },
    { 0xC45F, "supportbox_watchdisownedtimeout" },
    { 0xC460, "supportbox_watchdisownedtimeoutinternal" },
    { 0xC461, "supportbox_watchplayertrigger" },
    { 0xC462, "supportbox_watchplayeruse" },
    { 0xC463, "supportbox_watchplayeruseinternal" },
    { 0xC464, "supportbox_watchplayerweapon" },
    { 0xC465, "supportboxunset" },
    { 0xC466, "supportcranked" },
    { 0xC467, "supportdrones" },
    { 0xC468, "supportintel" },
    { 0xC469, "supportnuke" },
    { 0xC46A, "supportsothercapture" },
    { 0xC46B, "supportsownercapture" },
    { 0xC46C, "supportsreroll" },
    { 0xC46D, "supportstraversearrival" },
    { 0xC46E, "supportturret" },
    { 0xC46F, "suppresionfire" },
    { 0xC470, "suppress_numgoodtracesneeded" },
    { 0xC471, "suppress_reminder_last_time" },
    { 0xC472, "suppress_uselastenemysightpos" },
    { 0xC473, "suppressed" },
    { 0xC474, "suppressedtime" },
    { 0xC475, "suppressedturret" },
    { 0xC476, "suppressingenemy" },
    { 0xC477, "suppressingfiretracking" },
    { 0xC478, "suppression_monitor" },
    { 0xC479, "suppression_numgoodtracesneeded" },
    { 0xC47A, "suppressionmagnitude" },
    { 0xC47B, "suppressionthreshold" },
    { 0xC47C, "suppressiontime" },
    { 0xC47D, "suppresstimeout" },
    { 0xC47E, "suppressvehicleexplosion" },
    { 0xC47F, "suppresswaiter" },
    { 0xC480, "supress_sniper" },
    { 0xC481, "supressburnfx" },
    { 0xC482, "supressdamageflash" },
    { 0xC483, "surface_effects" },
    { 0xC484, "surface_speed_index" },
    { 0xC485, "survivalstarttime" },
    { 0xC486, "survive" },
    { 0xC487, "surviveanimallowed" },
    { 0xC488, "survivoralivescore" },
    { 0xC489, "survivorlethal" },
    { 0xC48A, "survivorprimaryweapon" },
    { 0xC48B, "survivorscoreevent" },
    { 0xC48C, "survivorscorepertick" },
    { 0xC48D, "survivorscoretime" },
    { 0xC48E, "survivorsecondaryweapon" },
    { 0xC48F, "survivorsuper" },
    { 0xC490, "survivortactical" },
    { 0xC491, "suseduration" },
    { 0xC492, "suspend_at_end_path" },
    { 0xC493, "suspend_beckon_poppies_start" },
    { 0xC494, "suspend_drive_anims" },
    { 0xC495, "suspend_driveanims" },
    { 0xC496, "suspend_sd_role" },
    { 0xC497, "suspended" },
    { 0xC498, "suspended_ai" },
    { 0xC499, "suspendedvehiclecount" },
    { 0xC49A, "suspendedvehicles" },
    { 0xC49B, "suspendtime" },
    { 0xC49C, "suspendvars" },
    { 0xC49D, "suspensemusic" },
    { 0xC49E, "suspicious_door" },
    { 0xC49F, "suspicious_door_found" },
    { 0xC4A0, "suspicious_door_sighting" },
    { 0xC4A1, "suspicious_door_stealth_check" },
    { 0xC4A2, "suv_enter_compound" },
    { 0xC4A3, "suv_patrol_comment" },
    { 0xC4A4, "suvdriver" },
    { 0xC4A5, "suvpassenger" },
    { 0xC4A6, "swab_add_fov_user_scale_override" },
    { 0xC4A7, "swab_remove_fov_user_scale_override" },
    { 0xC4A8, "swap" },
    { 0xC4A9, "swap_3f_anim" },
    { 0xC4AA, "swap_barkov_model" },
    { 0xC4AB, "swap_card_reader" },
    { 0xC4AC, "swap_clip" },
    { 0xC4AD, "swap_dmg_trig" },
    { 0xC4AE, "swap_glowstick_when_player_isnt_looking" },
    { 0xC4AF, "swap_kyle" },
    { 0xC4B0, "swap_player_ar" },
    { 0xC4B1, "swap_shell" },
    { 0xC4B2, "swap_to_fake_cpapa" },
    { 0xC4B3, "swap_to_farah_ak" },
    { 0xC4B4, "swap_to_farah_frag" },
    { 0xC4B5, "swap_to_farah_pistol" },
    { 0xC4B6, "swap_vehicle_for_scriptable" },
    { 0xC4B7, "swap_weapon_to" },
    { 0xC4B8, "swapcoverselector" },
    { 0xC4B9, "swaploadout" },
    { 0xC4BA, "swappedcoverselector" },
    { 0xC4BB, "swapswitchstatus" },
    { 0xC4BC, "swaptostaticmodel" },
    { 0xC4BD, "swapviaarraylocations" },
    { 0xC4BE, "sweapon" },
    { 0xC4BF, "sweep_aim_points" },
    { 0xC4C0, "sweep_fire_target" },
    { 0xC4C1, "sweepc4" },
    { 0xC4C2, "sweepclaymore" },
    { 0xC4C3, "sweepfiretarget" },
    { 0xC4C4, "sweepgas" },
    { 0xC4C5, "sweeptrophy" },
    { 0xC4C6, "swipe" },
    { 0xC4C7, "switch_case" },
    { 0xC4C8, "switch_color_at_goal" },
    { 0xC4C9, "switch_color_at_goal_thread" },
    { 0xC4CA, "switch_family_team_on_intel" },
    { 0xC4CB, "switch_func" },
    { 0xC4CC, "switch_head_to_hood" },
    { 0xC4CD, "switch_light_fixtures" },
    { 0xC4CE, "switch_loop" },
    { 0xC4CF, "switch_marine_color" },
    { 0xC4D0, "switch_marines_from_color_to_color" },
    { 0xC4D1, "switch_nest" },
    { 0xC4D2, "switch_test" },
    { 0xC4D3, "switch_think" },
    { 0xC4D4, "switch_to_ac130_if_plane_blows_up" },
    { 0xC4D5, "switch_to_bodydouble" },
    { 0xC4D6, "switch_to_ground_fly" },
    { 0xC4D7, "switch_to_ground_player_disable" },
    { 0xC4D8, "switch_to_ground_player_setup" },
    { 0xC4D9, "switch_to_guiding_missile" },
    { 0xC4DA, "switch_to_proper_zoom_weapon" },
    { 0xC4DB, "switchandtakesuperuseweapon" },
    { 0xC4DC, "switchblade_handle_awareness" },
    { 0xC4DD, "switchedsides" },
    { 0xC4DE, "switching_teams" },
    { 0xC4DF, "switching_teams_arena" },
    { 0xC4E0, "switchspawns" },
    { 0xC4E1, "switchstatus" },
    { 0xC4E2, "switchtodeployweapon" },
    { 0xC4E3, "switchtoexfilweapon" },
    { 0xC4E4, "switchtoexfilweapons" },
    { 0xC4E5, "switchtofists" },
    { 0xC4E6, "switchtolastweapon" },
    { 0xC4E7, "switchtouseweapon" },
    { 0xC4E8, "switchtoweaponreliable" },
    { 0xC4E9, "switchtoweaponwithbasename" },
    { 0xC4EA, "sync_bomb_defusal" },
    { 0xC4EB, "synch_attack_setup" },
    { 0xC4EC, "synch_directions" },
    { 0xC4ED, "syncxpstat" },
    { 0xC4EE, "system_init" },
    { 0xC4EF, "systemfinalized" },
    { 0xC4F0, "systemlink" },
    { 0xC4F1, "t_poser" },
    { 0xC4F2, "t2_combat_nags" },
    { 0xC4F3, "t2_doorbuster_enemy_2" },
    { 0xC4F4, "t2_doorbuster_enemy_3" },
    { 0xC4F5, "t2_enemy_fallback" },
    { 0xC4F6, "t2_enemy_update_volume" },
    { 0xC4F7, "t2_flood_init" },
    { 0xC4F8, "t2_floods" },
    { 0xC4F9, "t2_manager" },
    { 0xC4FA, "t2_player_pos" },
    { 0xC4FB, "t2_postspawn" },
    { 0xC4FC, "t2_update_volume" },
    { 0xC4FD, "table" },
    { 0xC4FE, "table_get_names" },
    { 0xC4FF, "table_getaccessory" },
    { 0xC500, "table_getarchetype" },
    { 0xC501, "table_getequipmentprimary" },
    { 0xC502, "table_getequipmentsecondary" },
    { 0xC503, "table_getexecution" },
    { 0xC504, "table_getextraequipmentprimary" },
    { 0xC505, "table_getextraequipmentsecondary" },
    { 0xC506, "table_getextraperk" },
    { 0xC507, "table_getgesture" },
    { 0xC508, "table_getkillstreak" },
    { 0xC509, "table_getloadoutname" },
    { 0xC50A, "table_getperk" },
    { 0xC50B, "table_getspecialist" },
    { 0xC50C, "table_getsuper" },
    { 0xC50D, "table_getweapon" },
    { 0xC50E, "table_getweaponattachment" },
    { 0xC50F, "table_getweaponcamo" },
    { 0xC510, "table_getweaponreticle" },
    { 0xC511, "table_knockdown_handler" },
    { 0xC512, "table_look_up" },
    { 0xC513, "table_origins" },
    { 0xC514, "tabledatabyref" },
    { 0xC515, "tablelookups" },
    { 0xC516, "tablet" },
    { 0xC517, "tablet_enabled_check_dvar" },
    { 0xC518, "tablet_gsc_stow" },
    { 0xC519, "tablet_location_obj_idx" },
    { 0xC51A, "tablet_lua_stow" },
    { 0xC51B, "tablet_lua_stow_in_progress" },
    { 0xC51C, "tablet_monitor" },
    { 0xC51D, "tablet_monitor_location_button" },
    { 0xC51E, "tablet_out" },
    { 0xC51F, "tablet_ready" },
    { 0xC520, "tablet_stow" },
    { 0xC521, "tablet_target" },
    { 0xC522, "tablet_targeting_off_monitor" },
    { 0xC523, "tablet_targeting_on_monitor" },
    { 0xC524, "tabletdofset" },
    { 0xC525, "tablethide" },
    { 0xC526, "tabletids" },
    { 0xC527, "tabletinfo" },
    { 0xC528, "tabletinit" },
    { 0xC529, "tabletpartname" },
    { 0xC52A, "tabletshow" },
    { 0xC52B, "tablettypes" },
    { 0xC52C, "tabletused" },
    { 0xC52D, "tac_cover_add_to_list" },
    { 0xC52E, "tac_cover_adjust_for_player_space" },
    { 0xC52F, "tac_cover_cannot_place_on" },
    { 0xC530, "tac_cover_coll_handle_damage" },
    { 0xC531, "tac_cover_coll_handle_fatal_damage" },
    { 0xC532, "tac_cover_delete" },
    { 0xC533, "tac_cover_deploy_freeze_controls" },
    { 0xC534, "tac_cover_deploy_unfreeze_controls" },
    { 0xC535, "tac_cover_destroy" },
    { 0xC536, "tac_cover_destroy_internal" },
    { 0xC537, "tac_cover_destroy_on_disowned" },
    { 0xC538, "tac_cover_destroy_on_game_end" },
    { 0xC539, "tac_cover_destroy_on_timeout" },
    { 0xC53A, "tac_cover_destroy_on_unstuck" },
    { 0xC53B, "tac_cover_entmanagerdelete" },
    { 0xC53C, "tac_cover_fire_failed" },
    { 0xC53D, "tac_cover_get_deploy_anim_dur" },
    { 0xC53E, "tac_cover_get_destroy_anim_dur" },
    { 0xC53F, "tac_cover_get_free_space" },
    { 0xC540, "tac_cover_give_deploy_weapon" },
    { 0xC541, "tac_cover_handle_damage" },
    { 0xC542, "tac_cover_handle_fatal_damage" },
    { 0xC543, "tac_cover_ignore_list" },
    { 0xC544, "tac_cover_init" },
    { 0xC545, "tac_cover_on_fired" },
    { 0xC546, "tac_cover_on_fired_super" },
    { 0xC547, "tac_cover_on_give" },
    { 0xC548, "tac_cover_on_take" },
    { 0xC549, "tac_cover_on_take_super" },
    { 0xC54A, "tac_cover_remove_from_list" },
    { 0xC54B, "tac_cover_set_can_damage" },
    { 0xC54C, "tac_cover_spawn" },
    { 0xC54D, "tac_cover_spawn_collision" },
    { 0xC54E, "tac_cover_spawn_internal" },
    { 0xC54F, "tac_cover_take_deploy_weapon" },
    { 0xC550, "tac_cover_used" },
    { 0xC551, "tac_cover_watch_deploy_failed" },
    { 0xC552, "tac_cover_watch_deploy_game_ended" },
    { 0xC553, "tac_cover_watch_deploy_succeeded" },
    { 0xC554, "tac_cover_watch_deploy_weapon_changed" },
    { 0xC555, "tac_rover_cp_create" },
    { 0xC556, "tac_rover_cp_createfromstructs" },
    { 0xC557, "tac_rover_cp_delete" },
    { 0xC558, "tac_rover_cp_getspawnstructscallback" },
    { 0xC559, "tac_rover_cp_init" },
    { 0xC55A, "tac_rover_cp_initlate" },
    { 0xC55B, "tac_rover_cp_initspawning" },
    { 0xC55C, "tac_rover_cp_ondeathrespawncallback" },
    { 0xC55D, "tac_rover_cp_spawncallback" },
    { 0xC55E, "tac_rover_cp_waitandspawn" },
    { 0xC55F, "tac_rover_create" },
    { 0xC560, "tac_rover_deathcallback" },
    { 0xC561, "tac_rover_deletenextframe" },
    { 0xC562, "tac_rover_enterend" },
    { 0xC563, "tac_rover_enterendinternal" },
    { 0xC564, "tac_rover_exitend" },
    { 0xC565, "tac_rover_exitendinternal" },
    { 0xC566, "tac_rover_explode" },
    { 0xC567, "tac_rover_getspawnstructscallback" },
    { 0xC568, "tac_rover_init" },
    { 0xC569, "tac_rover_initfx" },
    { 0xC56A, "tac_rover_initinteract" },
    { 0xC56B, "tac_rover_initlate" },
    { 0xC56C, "tac_rover_initoccupancy" },
    { 0xC56D, "tac_rover_initspawning" },
    { 0xC56E, "tac_rover_mp_create" },
    { 0xC56F, "tac_rover_mp_delete" },
    { 0xC570, "tac_rover_mp_getspawnstructscallback" },
    { 0xC571, "tac_rover_mp_init" },
    { 0xC572, "tac_rover_mp_initspawning" },
    { 0xC573, "tac_rover_mp_ondeathrespawncallback" },
    { 0xC574, "tac_rover_mp_spawncallback" },
    { 0xC575, "tac_rover_mp_waitandspawn" },
    { 0xC576, "tacadsactive" },
    { 0xC577, "tacadsstop" },
    { 0xC578, "taccoverbeginuse" },
    { 0xC579, "taccoverbulletcollision" },
    { 0xC57A, "taccovercollision" },
    { 0xC57B, "taccoverequipdeployfx" },
    { 0xC57C, "taccoverfrozecontrols" },
    { 0xC57D, "taccoverrefund" },
    { 0xC57E, "taccovers" },
    { 0xC57F, "taccoverunset" },
    { 0xC580, "tacinsert_damagelistener" },
    { 0xC581, "tacinsert_delayeddelete" },
    { 0xC582, "tacinsert_destroy" },
    { 0xC583, "tacinsert_empapplied" },
    { 0xC584, "tacinsert_enemyuselistener" },
    { 0xC585, "tacinsert_givepointsfordeath" },
    { 0xC586, "tacinsert_handledeathdamage" },
    { 0xC587, "tacinsert_init" },
    { 0xC588, "tacinsert_isvalidspawnposition" },
    { 0xC589, "tacinsert_modifydamage" },
    { 0xC58A, "tacinsert_set" },
    { 0xC58B, "tacinsert_setupandwaitfordeath" },
    { 0xC58C, "tacinsert_unset" },
    { 0xC58D, "tacinsert_updateenemyuse" },
    { 0xC58E, "tacinsert_updatespawnposition" },
    { 0xC58F, "tacinsert_used" },
    { 0xC590, "tacinsert_uselistener" },
    { 0xC591, "tacinsertonset" },
    { 0xC592, "tacinsertonunset" },
    { 0xC593, "tacopscurrentstate" },
    { 0xC594, "tacopsgasrole" },
    { 0xC595, "tacopsindex" },
    { 0xC596, "tacopskit" },
    { 0xC597, "tacopskitobjectives" },
    { 0xC598, "tacopskitstationonuse" },
    { 0xC599, "tacopskitsuseteamupdater" },
    { 0xC59A, "tacopslongwaitsec" },
    { 0xC59B, "tacopslz" },
    { 0xC59C, "tacopsmap" },
    { 0xC59D, "tacopsmapcameraent" },
    { 0xC59E, "tacopsmapselectedarea" },
    { 0xC59F, "tacopsmedicrole" },
    { 0xC5A0, "tacopsradio" },
    { 0xC5A1, "tacopsroundendwait" },
    { 0xC5A2, "tacopsroundresults" },
    { 0xC5A3, "tacopsspawnbeacons" },
    { 0xC5A4, "tacopsspawns" },
    { 0xC5A5, "tacopsspottedbyteam" },
    { 0xC5A6, "tacopsstations" },
    { 0xC5A7, "tacopsstealthrole" },
    { 0xC5A8, "tacopssublevel" },
    { 0xC5A9, "tacopssubmodetimeron" },
    { 0xC5AA, "tacopssupplypacks" },
    { 0xC5AB, "tacrover_mp_initmines" },
    { 0xC5AC, "tacrovers" },
    { 0xC5AD, "tactical" },
    { 0xC5AE, "tactical_goals" },
    { 0xC5AF, "tacticalitems" },
    { 0xC5B0, "tacticalmode" },
    { 0xC5B1, "tacticaltimemod" },
    { 0xC5B2, "tacticaltype" },
    { 0xC5B3, "tag_entity" },
    { 0xC5B4, "tag_flash_entity" },
    { 0xC5B5, "tag_flashing" },
    { 0xC5B6, "tag_getting" },
    { 0xC5B7, "tag_heli_with_head_icon" },
    { 0xC5B8, "tag_intel_with_head_icon" },
    { 0xC5B9, "tag_key_card_with_head_icon" },
    { 0xC5BA, "tag_next_flash" },
    { 0xC5BB, "tag_outline_entity" },
    { 0xC5BC, "tag_pile_watcher" },
    { 0xC5BD, "tag_sound" },
    { 0xC5BE, "tag_stowed_hip" },
    { 0xC5BF, "tag_trace_pulse" },
    { 0xC5C0, "tag_trace_state" },
    { 0xC5C1, "tag_trace_track" },
    { 0xC5C2, "tag_trace_update" },
    { 0xC5C3, "tag_update_enemy_in_sights" },
    { 0xC5C4, "tag_view_debug" },
    { 0xC5C5, "tag_watcher" },
    { 0xC5C6, "tagasjailknife" },
    { 0xC5C7, "tagavailable" },
    { 0xC5C8, "tagent" },
    { 0xC5C9, "tagged" },
    { 0xC5CA, "tagged_ads" },
    { 0xC5CB, "tagged_entity_death_cleanup" },
    { 0xC5CC, "tagged_entity_update" },
    { 0xC5CD, "tagged_flickered" },
    { 0xC5CE, "tagged_hudoutline" },
    { 0xC5CF, "tagged_status_hide" },
    { 0xC5D0, "tagged_status_show" },
    { 0xC5D1, "tagged_status_update" },
    { 0xC5D2, "tagged_time" },
    { 0xC5D3, "tagged_wait_shield_off" },
    { 0xC5D4, "taggedassist" },
    { 0xC5D5, "tagging" },
    { 0xC5D6, "tagging_entity_list" },
    { 0xC5D7, "tagging_highlight_dist_fade" },
    { 0xC5D8, "tagging_hudoutline_settings" },
    { 0xC5D9, "tagging_player_init" },
    { 0xC5DA, "tagging_player_stop" },
    { 0xC5DB, "tagging_player_thread" },
    { 0xC5DC, "tagging_set_enabled" },
    { 0xC5DD, "tagging_set_marking_enabled" },
    { 0xC5DE, "tagging_shield" },
    { 0xC5DF, "tagging_shutdown_player" },
    { 0xC5E0, "tagging_sight_trace_passed" },
    { 0xC5E1, "tagging_sight_trace_queue" },
    { 0xC5E2, "tagging_sight_traced_queued" },
    { 0xC5E3, "tagging_think" },
    { 0xC5E4, "tagging_visible" },
    { 0xC5E5, "tagginginit" },
    { 0xC5E6, "tagleaderwithheadicon" },
    { 0xC5E7, "tagmarkedplayer" },
    { 0xC5E8, "tagmodel" },
    { 0xC5E9, "tagmoveto" },
    { 0xC5EA, "tagoffset" },
    { 0xC5EB, "tagorigin" },
    { 0xC5EC, "tags" },
    { 0xC5ED, "tags_carried" },
    { 0xC5EE, "tags_seen" },
    { 0xC5EF, "tags_seen_by_owner" },
    { 0xC5F0, "tags_to_bank" },
    { 0xC5F1, "tagscarried" },
    { 0xC5F2, "tagsdeposited" },
    { 0xC5F3, "tagteamupdater" },
    { 0xC5F4, "tagtype" },
    { 0xC5F5, "taillights" },
    { 0xC5F6, "take_action_slot_weapon" },
    { 0xC5F7, "take_all_currency" },
    { 0xC5F8, "take_amped" },
    { 0xC5F9, "take_away_players_gunshipmunition" },
    { 0xC5FA, "take_away_special_ammo" },
    { 0xC5FB, "take_beam_ammo" },
    { 0xC5FC, "take_color_node" },
    { 0xC5FD, "take_control" },
    { 0xC5FE, "take_cover_near_hvt" },
    { 0xC5FF, "take_fists_weapon" },
    { 0xC600, "take_green_beam" },
    { 0xC601, "take_laststand" },
    { 0xC602, "take_melee_weapon" },
    { 0xC603, "take_off_loop" },
    { 0xC604, "take_offhand" },
    { 0xC605, "take_out_armor_nags" },
    { 0xC606, "take_player_currency" },
    { 0xC607, "take_player_money" },
    { 0xC608, "take_player_offhand_by_name" },
    { 0xC609, "take_player_out_of_rig" },
    { 0xC60A, "take_restock" },
    { 0xC60B, "take_screenshots" },
    { 0xC60C, "take_shrapnel" },
    { 0xC60D, "take_skill_points" },
    { 0xC60E, "take_tune_up" },
    { 0xC60F, "take_weapon" },
    { 0xC610, "take_weapons_away" },
    { 0xC611, "takeallweaponsexcludemelee" },
    { 0xC612, "takeammopickup" },
    { 0xC613, "takearmorpickup" },
    { 0xC614, "takecover" },
    { 0xC615, "takecoverwarning" },
    { 0xC616, "takedown_animatedenemydeathlogic" },
    { 0xC617, "takedown_animatedsceneendguardlogic" },
    { 0xC618, "takedown_animatedsceneenemydamagelogic" },
    { 0xC619, "takedown_animationbreakoutlogic" },
    { 0xC61A, "takedown_animationbreakoutnotifylogic" },
    { 0xC61B, "takedown_animationlogic" },
    { 0xC61C, "takedown_available" },
    { 0xC61D, "takedown_getanimationstruct" },
    { 0xC61E, "takedown_getdoor" },
    { 0xC61F, "takedown_getfarahnode" },
    { 0xC620, "takedown_grenade_monitor" },
    { 0xC621, "takedown_guards" },
    { 0xC622, "takedown_hostages" },
    { 0xC623, "takedown_main" },
    { 0xC624, "takedown_spawnanimatedenemy" },
    { 0xC625, "takedown_start" },
    { 0xC626, "takedown_victim" },
    { 0xC627, "takedown_wrapup_logic" },
    { 0xC628, "takeequipment" },
    { 0xC629, "takeequipmentpickup" },
    { 0xC62A, "takefists" },
    { 0xC62B, "takegasmask" },
    { 0xC62C, "takegenericgrenadepickup" },
    { 0xC62D, "takegoproattachments" },
    { 0xC62E, "takegunless" },
    { 0xC62F, "takegunlesscp" },
    { 0xC630, "takehelmet" },
    { 0xC631, "takeholywater" },
    { 0xC632, "takekillstreakpickup" },
    { 0xC633, "takeloadoutatinfilend" },
    { 0xC634, "taken" },
    { 0xC635, "takeobject" },
    { 0xC636, "takeoff" },
    { 0xC637, "takeoff_turbulence" },
    { 0xC638, "takeperk" },
    { 0xC639, "takeperkpointpickup" },
    { 0xC63A, "takeplunderpickup" },
    { 0xC63B, "takequestitem" },
    { 0xC63C, "takerateye" },
    { 0xC63D, "takerespawntokenpickup" },
    { 0xC63E, "takesupergunout" },
    { 0xC63F, "takesuperpickup" },
    { 0xC640, "takeutilitypickup" },
    { 0xC641, "takeweaponpickup" },
    { 0xC642, "takeweaponsdefaultfunc" },
    { 0xC643, "takeweaponsexceptcurrent" },
    { 0xC644, "takeweaponwhensafe" },
    { 0xC645, "takeweaponwhensafegungame" },
    { 0xC646, "takeyoungfarrahpistol" },
    { 0xC647, "takinggunless" },
    { 0xC648, "talk_for_time" },
    { 0xC649, "talk_to_hadir" },
    { 0xC64A, "tall_grass_birds" },
    { 0xC64B, "tall_grass_catchup" },
    { 0xC64C, "tall_grass_main" },
    { 0xC64D, "tall_grass_start" },
    { 0xC64E, "tango72_get_length" },
    { 0xC64F, "tango72_init" },
    { 0xC650, "tango72_spawn" },
    { 0xC651, "tank" },
    { 0xC652, "tank_aim_at" },
    { 0xC653, "tank_battle_test" },
    { 0xC654, "tank_canseetarget" },
    { 0xC655, "tank_checkspawnpoint" },
    { 0xC656, "tank_delayairburstscriptabledeath" },
    { 0xC657, "tank_destroy" },
    { 0xC658, "tank_destroycallback" },
    { 0xC659, "tank_disableriderprompt" },
    { 0xC65A, "tank_disableturretforfutureenemies" },
    { 0xC65B, "tank_disableturretuseforenemies" },
    { 0xC65C, "tank_driverexit" },
    { 0xC65D, "tank_earthquake" },
    { 0xC65E, "tank_empcleared" },
    { 0xC65F, "tank_empgrenaded" },
    { 0xC660, "tank_empstarted" },
    { 0xC661, "tank_enableriderprompt" },
    { 0xC662, "tank_engine_sfx" },
    { 0xC663, "tank_findclosestairbursttarget" },
    { 0xC664, "tank_findsafedetach" },
    { 0xC665, "tank_findsafespawn" },
    { 0xC666, "tank_finishdropoffsequence" },
    { 0xC667, "tank_fire_disable" },
    { 0xC668, "tank_fire_enable" },
    { 0xC669, "tank_handleairburst" },
    { 0xC66A, "tank_handlehelidamage" },
    { 0xC66B, "tank_handlehelideathdamage" },
    { 0xC66C, "tank_handlewheeldustfx" },
    { 0xC66D, "tank_help" },
    { 0xC66E, "tank_hero_lighting_off" },
    { 0xC66F, "tank_hint_message" },
    { 0xC670, "tank_hitmarkers" },
    { 0xC671, "tank_idle_aiming" },
    { 0xC672, "tank_interact" },
    { 0xC673, "tank_lockedoncallback" },
    { 0xC674, "tank_lockedonremovedcallback" },
    { 0xC675, "tank_logic" },
    { 0xC676, "tank_modifydamageresponse" },
    { 0xC677, "tank_modifydamagestate" },
    { 0xC678, "tank_modifyhelidamage" },
    { 0xC679, "tank_moveup_nag" },
    { 0xC67A, "tank_oncontested" },
    { 0xC67B, "tank_onuncontested" },
    { 0xC67C, "tank_onunoccupied" },
    { 0xC67D, "tank_onuse" },
    { 0xC67E, "tank_override_moving_platform_death" },
    { 0xC67F, "tank_pick_ai_target" },
    { 0xC680, "tank_pick_vehicle_target" },
    { 0xC681, "tank_playercameratransition" },
    { 0xC682, "tank_riderexit" },
    { 0xC683, "tank_rpg_death" },
    { 0xC684, "tank_shake_end" },
    { 0xC685, "tank_shake_start" },
    { 0xC686, "tank_shoot_at_target" },
    { 0xC687, "tank_shoot_target" },
    { 0xC688, "tank_shooting_logic" },
    { 0xC689, "tank_shot" },
    { 0xC68A, "tank_startfadetransition" },
    { 0xC68B, "tank_stop_for_allies_think" },
    { 0xC68C, "tank_stop_for_allies_think_debug" },
    { 0xC68D, "tank_struct_shoots" },
    { 0xC68E, "tank_turrethandleuse" },
    { 0xC68F, "tank_updatehudchassisangles" },
    { 0xC690, "tank_updatehudviewstate" },
    { 0xC691, "tank_vfx_handler" },
    { 0xC692, "tank_waittill_death" },
    { 0xC693, "tank_waittill_stopped" },
    { 0xC694, "tank_watchfiring" },
    { 0xC695, "tank_watchforairburstdetonate" },
    { 0xC696, "tank_watchfortimeoutdisowned" },
    { 0xC697, "tank_watchfortimeoutdisownedendearly" },
    { 0xC698, "tank_watchownerdeath" },
    { 0xC699, "tank_watchprojectiledeath" },
    { 0xC69A, "tank_watchriderabandon" },
    { 0xC69B, "tank_watchriderautodismount" },
    { 0xC69C, "tank_watchridermount" },
    { 0xC69D, "tank_watchriderturn" },
    { 0xC69E, "tank_watchstopuseturret" },
    { 0xC69F, "tank1_rpg_guys" },
    { 0xC6A0, "tank2" },
    { 0xC6A1, "tankdamfbackheavynum" },
    { 0xC6A2, "tankdamfbacklightnum" },
    { 0xC6A3, "tankdroplocaitons" },
    { 0xC6A4, "tankdrops_init" },
    { 0xC6A5, "tankdrops_run" },
    { 0xC6A6, "tankfovcos" },
    { 0xC6A7, "tankmovetopath" },
    { 0xC6A8, "tankobjkeys" },
    { 0xC6A9, "tanks" },
    { 0xC6AA, "tanks_moveup_hill_shooting_logic" },
    { 0xC6AB, "tanksettings" },
    { 0xC6AC, "tankspawncmd_1" },
    { 0xC6AD, "tankspawncmd_2" },
    { 0xC6AE, "tankspawncmd_3" },
    { 0xC6AF, "tankspawndom_a" },
    { 0xC6B0, "tankspawndom_b" },
    { 0xC6B1, "tankspawndom_c" },
    { 0xC6B2, "tankspawnlocs" },
    { 0xC6B3, "tankspawnlocs_allies" },
    { 0xC6B4, "tankspawnlocs_axis" },
    { 0xC6B5, "tankspeed" },
    { 0xC6B6, "tanksquish" },
    { 0xC6B7, "tanksquish_damage_check" },
    { 0xC6B8, "tanksshouldmove" },
    { 0xC6B9, "tankstartspawnallies" },
    { 0xC6BA, "tankstartspawnalliescmd" },
    { 0xC6BB, "tankstartspawnalliesdom" },
    { 0xC6BC, "tankstartspawnaxis" },
    { 0xC6BD, "tankstartspawnaxiscmd" },
    { 0xC6BE, "tankstartspawnaxisdom" },
    { 0xC6BF, "tankstartspawnneutral" },
    { 0xC6C0, "tanktimeoutlist" },
    { 0xC6C1, "tanktype" },
    { 0xC6C2, "tanto_doorway_flood_logic" },
    { 0xC6C3, "targeffect" },
    { 0xC6C4, "targent" },
    { 0xC6C5, "target_actual" },
    { 0xC6C6, "target_anchor" },
    { 0xC6C7, "target_circle_fov" },
    { 0xC6C8, "target_circle_radius" },
    { 0xC6C9, "target_damage" },
    { 0xC6CA, "target_damage_listener" },
    { 0xC6CB, "target_death_anim" },
    { 0xC6CC, "target_death_wrapper" },
    { 0xC6CD, "target_designation_nag" },
    { 0xC6CE, "target_enemy" },
    { 0xC6CF, "target_ent" },
    { 0xC6D0, "target_ent_cleanup" },
    { 0xC6D1, "target_ent_marker" },
    { 0xC6D2, "target_entity" },
    { 0xC6D3, "target_first_interacted" },
    { 0xC6D4, "target_first_interacted_routing" },
    { 0xC6D5, "target_flip" },
    { 0xC6D6, "target_follow_dummy" },
    { 0xC6D7, "target_highlight_attempt" },
    { 0xC6D8, "target_hit_monitor" },
    { 0xC6D9, "target_in_red_circle_think" },
    { 0xC6DA, "target_locked" },
    { 0xC6DB, "target_marker_group_id" },
    { 0xC6DC, "target_marker_group_id_list" },
    { 0xC6DD, "target_obj" },
    { 0xC6DE, "target_objective_sequence" },
    { 0xC6DF, "target_offset" },
    { 0xC6E0, "target_patrol_path" },
    { 0xC6E1, "target_play_anim" },
    { 0xC6E2, "target_player" },
    { 0xC6E3, "target_player_start" },
    { 0xC6E4, "target_player_stop_max" },
    { 0xC6E5, "target_player_stop_min" },
    { 0xC6E6, "target_player_volumes" },
    { 0xC6E7, "target_random_models" },
    { 0xC6E8, "target_requisites" },
    { 0xC6E9, "target_restore_idle_anim" },
    { 0xC6EA, "target_score" },
    { 0xC6EB, "target_select_think" },
    { 0xC6EC, "target_spot" },
    { 0xC6ED, "target_stealth_meter_progress" },
    { 0xC6EE, "target_think" },
    { 0xC6EF, "target_track" },
    { 0xC6F0, "target_wave" },
    { 0xC6F1, "target_within_range_think" },
    { 0xC6F2, "targetangles" },
    { 0xC6F3, "targetapcnearbyenemy" },
    { 0xC6F4, "targetarray" },
    { 0xC6F5, "targetbounty" },
    { 0xC6F6, "targetdamagethink" },
    { 0xC6F7, "targetdefault" },
    { 0xC6F8, "targeted_hvt" },
    { 0xC6F9, "targetent" },
    { 0xC6FA, "targethascoldblooded" },
    { 0xC6FB, "targethealthinfo" },
    { 0xC6FC, "targethit_effects" },
    { 0xC6FD, "targethitsinaframecount" },
    { 0xC6FE, "targetids" },
    { 0xC6FF, "targetincrouchfoliage" },
    { 0xC700, "targetindex" },
    { 0xC701, "targeting_delay" },
    { 0xC702, "targeting_marker" },
    { 0xC703, "targeting_player_icon_create" },
    { 0xC704, "targeting_player_icon_delete" },
    { 0xC705, "targetingplayerflag" },
    { 0xC706, "targetinpronefoliage" },
    { 0xC707, "targetinstandfoliage" },
    { 0xC708, "targetisnotinmarkingrange" },
    { 0xC709, "targetlead" },
    { 0xC70A, "targetlead_airburstholdthink" },
    { 0xC70B, "targetlead_airburstmissilethink" },
    { 0xC70C, "targetlead_checktargetstillheld" },
    { 0xC70D, "targetlead_earlyoutthink" },
    { 0xC70E, "targetlead_enterstate" },
    { 0xC70F, "targetlead_getleadposition" },
    { 0xC710, "targetlead_getqueuedstate" },
    { 0xC711, "targetlead_getvehicleoffset" },
    { 0xC712, "targetlead_holdstateenter" },
    { 0xC713, "targetlead_holdstateexit" },
    { 0xC714, "targetlead_holdstateupdate" },
    { 0xC715, "targetlead_init" },
    { 0xC716, "targetlead_looplocalseeksound" },
    { 0xC717, "targetlead_offstateenter" },
    { 0xC718, "targetlead_offstateexit" },
    { 0xC719, "targetlead_offstateupdate" },
    { 0xC71A, "targetlead_onstartthink" },
    { 0xC71B, "targetlead_onstopthink" },
    { 0xC71C, "targetlead_preupdate" },
    { 0xC71D, "targetlead_queuestate" },
    { 0xC71E, "targetlead_reset" },
    { 0xC71F, "targetlead_scanforvehicletarget" },
    { 0xC720, "targetlead_scanningstateenter" },
    { 0xC721, "targetlead_scanningstateupdate" },
    { 0xC722, "targetlead_shouldtargetleadthink" },
    { 0xC723, "targetlead_softsighttest" },
    { 0xC724, "targetlead_think" },
    { 0xC725, "targetlead_uimarkentities" },
    { 0xC726, "targetlead_uiunmarkentities" },
    { 0xC727, "targetlead_vehiclelocksighttest" },
    { 0xC728, "targetleadusageloop" },
    { 0xC729, "targetmarkergroup" },
    { 0xC72A, "targetmarkergroup_addtomarkingqueue" },
    { 0xC72B, "targetmarkergroup_getownedgroups" },
    { 0xC72C, "targetmarkergroup_handlemarkingfromqueue" },
    { 0xC72D, "targetmarkergroup_handleremovequeueondisconnect" },
    { 0xC72E, "targetmarkergroup_markentity" },
    { 0xC72F, "targetmarkergroup_markplayeronspawn" },
    { 0xC730, "targetmarkergroup_off" },
    { 0xC731, "targetmarkergroup_on" },
    { 0xC732, "targetmarkergroup_removefromgroupaction" },
    { 0xC733, "targetmarkergroup_removefrommarkingqueue" },
    { 0xC734, "targetmarkergroup_unmarkentity" },
    { 0xC735, "targetmarkergroup_watchfornoscopeoutlineperkset" },
    { 0xC736, "targetmarkergroup_watchfornoscopeoutlineperkunset" },
    { 0xC737, "targetmarkergroup_watchforplayerconnect" },
    { 0xC738, "targetmarkergroupexists" },
    { 0xC739, "targetmodels" },
    { 0xC73A, "targetmodifier" },
    { 0xC73B, "targetmovespeed" },
    { 0xC73C, "targetname_string" },
    { 0xC73D, "targetnode" },
    { 0xC73E, "targetnormal" },
    { 0xC73F, "targetnum" },
    { 0xC740, "targetoffset" },
    { 0xC741, "targetorigin" },
    { 0xC742, "targetoutline" },
    { 0xC743, "targetplayer" },
    { 0xC744, "targetplayercycle" },
    { 0xC745, "targetpos" },
    { 0xC746, "targetposition" },
    { 0xC747, "targets" },
    { 0xC748, "targets_and_uses_turret" },
    { 0xC749, "targets_behind_door_callout" },
    { 0xC74A, "targets_for_remote_detonation" },
    { 0xC74B, "targets_group_think" },
    { 0xC74C, "targets_missed_calculate" },
    { 0xC74D, "targets_thinking" },
    { 0xC74E, "targetsinouterradius" },
    { 0xC74F, "targetstart_extractiongoal" },
    { 0xC750, "targetstart_icon" },
    { 0xC751, "targetstart_reward" },
    { 0xC752, "targetstart_reward_prespawn" },
    { 0xC753, "targetstart_spawner" },
    { 0xC754, "targetstart_spawner_init" },
    { 0xC755, "targetstart_spawner_node" },
    { 0xC756, "targetstart_spawner_volume" },
    { 0xC757, "targetstart_spawntrigger" },
    { 0xC758, "targetteam" },
    { 0xC759, "targettoclose" },
    { 0xC75A, "targetvalues" },
    { 0xC75B, "targetvictim" },
    { 0xC75C, "targetvictimdeathwatcher" },
    { 0xC75D, "targetvisibleinfront" },
    { 0xC75E, "tarmac_bad_places_ids" },
    { 0xC75F, "tarmac_badplace" },
    { 0xC760, "tarmac_catchup" },
    { 0xC761, "tarmac_damaged_model_swaps" },
    { 0xC762, "tarmac_gameplay_fires" },
    { 0xC763, "tarmac_hangar_lights" },
    { 0xC764, "tarmac_main" },
    { 0xC765, "tarmac_model_init" },
    { 0xC766, "tarmac_nav_obstacles" },
    { 0xC767, "tarmac_push_player" },
    { 0xC768, "tarmac_start" },
    { 0xC769, "tarmac_tower" },
    { 0xC76A, "tarmac_tower_guy" },
    { 0xC76B, "tarmac_umike_01" },
    { 0xC76C, "tarmac_umike_01b" },
    { 0xC76D, "tarmac_umike_02" },
    { 0xC76E, "tarmac_umike_03" },
    { 0xC76F, "tarmac_umike_08" },
    { 0xC770, "tarmac_umike_09" },
    { 0xC771, "tarmac_vindia_02" },
    { 0xC772, "tarmac_vindia_03" },
    { 0xC773, "tarmace_player_allies" },
    { 0xC774, "tarp" },
    { 0xC775, "tarps" },
    { 0xC776, "taskid" },
    { 0xC777, "tauntinprogress" },
    { 0xC778, "tauntinputlisten" },
    { 0xC779, "taunts_done" },
    { 0xC77A, "taunts_used" },
    { 0xC77B, "tc" },
    { 0xC77C, "tdef" },
    { 0xC77D, "tdef_flagtime" },
    { 0xC77E, "tdefsuit" },
    { 0xC77F, "tdmanywhere_debugshowlocs" },
    { 0xC780, "tdmanywhere_distoffset" },
    { 0xC781, "tdmanywhere_dropheight" },
    { 0xC782, "tdmanywhere_perpenoffset" },
    { 0xC783, "tdmanywherefrontline" },
    { 0xC784, "tea_room_catchup" },
    { 0xC785, "tea_room_change" },
    { 0xC786, "tea_room_start" },
    { 0xC787, "teahouse_walk_vo" },
    { 0xC788, "team_and_slot_number_struct" },
    { 0xC789, "team_encounter_performance" },
    { 0xC78A, "team_id_num_slot_filled" },
    { 0xC78B, "team_id_one_slot_assignment_index" },
    { 0xC78C, "team_id_one_slot_index_list" },
    { 0xC78D, "team_id_slot_index_list" },
    { 0xC78E, "team_id_zero_slot_assignment_index" },
    { 0xC78F, "team_id_zero_slot_index_list" },
    { 0xC790, "team_instant_revive" },
    { 0xC791, "team_mask_up" },
    { 0xC792, "team_number" },
    { 0xC793, "team_score_component_name" },
    { 0xC794, "team_slot_assignment_available_from_player_disconnect" },
    { 0xC795, "team_specific_spawn_functions" },
    { 0xC796, "team_thinking" },
    { 0xC797, "team_unlimited_ammo" },
    { 0xC798, "teamavg" },
    { 0xC799, "teambalance" },
    { 0xC79A, "teambase" },
    { 0xC79B, "teambased" },
    { 0xC79C, "teamchangedthisframe" },
    { 0xC79D, "teamclusters" },
    { 0xC79E, "teamdata" },
    { 0xC79F, "teamdelayedvo" },
    { 0xC7A0, "teamdiffyaw" },
    { 0xC7A1, "teamemped" },
    { 0xC7A2, "teamfallbackspawnpoints" },
    { 0xC7A3, "teamflagbases" },
    { 0xC7A4, "teamflags" },
    { 0xC7A5, "teamflashbangimmunity" },
    { 0xC7A6, "teamhasinfil" },
    { 0xC7A7, "teamhasuav" },
    { 0xC7A8, "teamheadicon" },
    { 0xC7A9, "teamholdtimers" },
    { 0xC7AA, "teamhudtutorialmessage" },
    { 0xC7AB, "teaminstancelimitmessages" },
    { 0xC7AC, "teaminstancelimits" },
    { 0xC7AD, "teamkilldelay" },
    { 0xC7AE, "teamkillstreakqueue" },
    { 0xC7AF, "teammateswithhealperk" },
    { 0xC7B0, "teammaxfill" },
    { 0xC7B1, "teamnamelist" },
    { 0xC7B2, "teamonly" },
    { 0xC7B3, "teamoutcomenotify" },
    { 0xC7B4, "teamplayercardsplash" },
    { 0xC7B5, "teamprint" },
    { 0xC7B6, "teamprogress" },
    { 0xC7B7, "teamprogressbarfontsize" },
    { 0xC7B8, "teamprogressbarheight" },
    { 0xC7B9, "teamprogressbartexty" },
    { 0xC7BA, "teamprogressbarwidth" },
    { 0xC7BB, "teamprogressbary" },
    { 0xC7BC, "teamrankxpmultipliers" },
    { 0xC7BD, "teamrespawn" },
    { 0xC7BE, "teams" },
    { 0xC7BF, "teams_thread" },
    { 0xC7C0, "teamscored" },
    { 0xC7C1, "teamscoresonkill" },
    { 0xC7C2, "teamsextracting" },
    { 0xC7C3, "teamsmatch" },
    { 0xC7C4, "teamsonquests" },
    { 0xC7C5, "teamspawnlocations" },
    { 0xC7C6, "teamspawnpoints" },
    { 0xC7C7, "teamsplash" },
    { 0xC7C8, "teamspotindices" },
    { 0xC7C9, "teamstartspawnpoints" },
    { 0xC7CA, "teamstarttimer" },
    { 0xC7CB, "teamswithplayers" },
    { 0xC7CC, "teamthreatcalloutlimittimeout" },
    { 0xC7CD, "teamtweaks" },
    { 0xC7CE, "teamusetexts" },
    { 0xC7CF, "teamusetimes" },
    { 0xC7D0, "teargas_explode_started" },
    { 0xC7D1, "teargasfiremain" },
    { 0xC7D2, "technical" },
    { 0xC7D3, "technical_01" },
    { 0xC7D4, "technical_01_gunner" },
    { 0xC7D5, "technical_02" },
    { 0xC7D6, "technical_02_gunner" },
    { 0xC7D7, "technical_03" },
    { 0xC7D8, "technical_03_gunner" },
    { 0xC7D9, "technical_04" },
    { 0xC7DA, "technical_05" },
    { 0xC7DB, "technical_06" },
    { 0xC7DC, "technical_07" },
    { 0xC7DD, "technical_08" },
    { 0xC7DE, "technical_09" },
    { 0xC7DF, "technical_10" },
    { 0xC7E0, "technical_badplace_think" },
    { 0xC7E1, "technical_callout_think" },
    { 0xC7E2, "technical_can_reacquire_player" },
    { 0xC7E3, "technical_can_unload" },
    { 0xC7E4, "technical_cleanup" },
    { 0xC7E5, "technical_combat_think" },
    { 0xC7E6, "technical_cp_create" },
    { 0xC7E7, "technical_cp_createfromstructs" },
    { 0xC7E8, "technical_cp_delete" },
    { 0xC7E9, "technical_cp_getspawnstructscallback" },
    { 0xC7EA, "technical_cp_init" },
    { 0xC7EB, "technical_cp_initlate" },
    { 0xC7EC, "technical_cp_initspawning" },
    { 0xC7ED, "technical_cp_ondeathrespawncallback" },
    { 0xC7EE, "technical_cp_spawncallback" },
    { 0xC7EF, "technical_cp_waitandspawn" },
    { 0xC7F0, "technical_create" },
    { 0xC7F1, "technical_create_badplaces_along_path" },
    { 0xC7F2, "technical_damage_func" },
    { 0xC7F3, "technical_death_hint_think" },
    { 0xC7F4, "technical_deathcallback" },
    { 0xC7F5, "technical_deletenextframe" },
    { 0xC7F6, "technical_destroy_badplaces" },
    { 0xC7F7, "technical_dudes_01_spawn_func" },
    { 0xC7F8, "technical_enterend" },
    { 0xC7F9, "technical_enterendinternal" },
    { 0xC7FA, "technical_enterstart" },
    { 0xC7FB, "technical_exitend" },
    { 0xC7FC, "technical_exitendinternal" },
    { 0xC7FD, "technical_explode" },
    { 0xC7FE, "technical_getspawnstructscallback" },
    { 0xC7FF, "technical_gunner_anim_think" },
    { 0xC800, "technical_gunner_custom_death" },
    { 0xC801, "technical_gunner_set_aim" },
    { 0xC802, "technical_gunner_think" },
    { 0xC803, "technical_impact_think" },
    { 0xC804, "technical_init" },
    { 0xC805, "technical_initfx" },
    { 0xC806, "technical_initinteract" },
    { 0xC807, "technical_initlate" },
    { 0xC808, "technical_initoccupancy" },
    { 0xC809, "technical_initspawning" },
    { 0xC80A, "technical_investigate_think" },
    { 0xC80B, "technical_lights" },
    { 0xC80C, "technical_mp_create" },
    { 0xC80D, "technical_mp_delete" },
    { 0xC80E, "technical_mp_getspawnstructscallback" },
    { 0xC80F, "technical_mp_init" },
    { 0xC810, "technical_mp_initmines" },
    { 0xC811, "technical_mp_initspawning" },
    { 0xC812, "technical_mp_ondeathrespawncallback" },
    { 0xC813, "technical_mp_spawncallback" },
    { 0xC814, "technical_mp_waitandspawn" },
    { 0xC815, "technical_path_think" },
    { 0xC816, "technical_proximity_think" },
    { 0xC817, "technical_ram_think" },
    { 0xC818, "technical_rider_combat_think" },
    { 0xC819, "technical_rider_damage_func" },
    { 0xC81A, "technical_rider_deathfunc" },
    { 0xC81B, "technical_rider_spawnfunc" },
    { 0xC81C, "technical_rider_stealth_filter" },
    { 0xC81D, "technical_rider_unload" },
    { 0xC81E, "technical_roof_trig_think" },
    { 0xC81F, "technical_spawn_cover_nodes" },
    { 0xC820, "technical_spotlight_off" },
    { 0xC821, "technical_spotlight_on" },
    { 0xC822, "technical_spotlight_targets" },
    { 0xC823, "technical_stop_for_allies_think" },
    { 0xC824, "technical_stop_on_death_or_no_driver" },
    { 0xC825, "technical_stopanimatingplayer" },
    { 0xC826, "technical_turret_death" },
    { 0xC827, "technical_turret_think" },
    { 0xC828, "technical_waittill_stopped" },
    { 0xC829, "technicals" },
    { 0xC82A, "teenage_farah_cell_setup" },
    { 0xC82B, "teenage_farah_combat_setup" },
    { 0xC82C, "teenage_farah_precache" },
    { 0xC82D, "teenage_farah_setup" },
    { 0xC82E, "teenage_farah_stealth_setup" },
    { 0xC82F, "tele_and_setgoalpos" },
    { 0xC830, "teleport_after_time" },
    { 0xC831, "teleport_ai" },
    { 0xC832, "teleport_ai_to_cover_node" },
    { 0xC833, "teleport_black_overlay" },
    { 0xC834, "teleport_bravo_midway" },
    { 0xC835, "teleport_dom_finished_initializing" },
    { 0xC836, "teleport_ent" },
    { 0xC837, "teleport_entity" },
    { 0xC838, "teleport_geo" },
    { 0xC839, "teleport_humvee_to_struct" },
    { 0xC83A, "teleport_if_clear" },
    { 0xC83B, "teleport_interaction_actor" },
    { 0xC83C, "teleport_player" },
    { 0xC83D, "teleport_players" },
    { 0xC83E, "teleport_text" },
    { 0xC83F, "teleport_to_ent_tag" },
    { 0xC840, "teleport_to_location" },
    { 0xC841, "teleport_to_nearby_spawner" },
    { 0xC842, "teleport_to_node" },
    { 0xC843, "teleport_to_targetname" },
    { 0xC844, "teleport_trigger" },
    { 0xC845, "teleport_when_safe" },
    { 0xC846, "teleport_zone" },
    { 0xC847, "teleportallplayersinteamtostructs" },
    { 0xC848, "teleportdeltaovernumframes" },
    { 0xC849, "teleportdisableflags" },
    { 0xC84A, "teleportgetactivenodesfunc" },
    { 0xC84B, "teleportgetactivepathnodezonesfunc" },
    { 0xC84C, "teleporting" },
    { 0xC84D, "teleportplayertoteamstructs" },
    { 0xC84E, "teleportplayertoteamstructs_latejoin" },
    { 0xC84F, "teleportstructs_threadedwait" },
    { 0xC850, "teleportthread" },
    { 0xC851, "teleportthreadex" },
    { 0xC852, "temp" },
    { 0xC853, "temp_anchor" },
    { 0xC854, "temp_animator" },
    { 0xC855, "temp_approach_standoff_vo" },
    { 0xC856, "temp_attic_dialogue" },
    { 0xC857, "temp_bed_enemy_shooting" },
    { 0xC858, "temp_dialog" },
    { 0xC859, "temp_disable_interaction" },
    { 0xC85A, "temp_draw_crowd_num" },
    { 0xC85B, "temp_draw_multipoints" },
    { 0xC85C, "temp_draw_world_ap" },
    { 0xC85D, "temp_ent" },
    { 0xC85E, "temp_ignore" },
    { 0xC85F, "temp_invul" },
    { 0xC860, "temp_is_performance_active" },
    { 0xC861, "temp_kid_center_stage" },
    { 0xC862, "temp_ladder_hack" },
    { 0xC863, "temp_make_barrel_interactible" },
    { 0xC864, "temp_make_barrel_think" },
    { 0xC865, "temp_move_exfil_box" },
    { 0xC866, "temp_nags" },
    { 0xC867, "temp_performance_flag_clear" },
    { 0xC868, "temp_performance_flag_set" },
    { 0xC869, "temp_player_debug_whotriggered" },
    { 0xC86A, "temp_price_clip1" },
    { 0xC86B, "temp_price_clip2" },
    { 0xC86C, "temp_print_screen_type" },
    { 0xC86D, "temp_scriptablerotateto" },
    { 0xC86E, "temp_sound_fx" },
    { 0xC86F, "temp_sound_init" },
    { 0xC870, "temp_sound_watcher" },
    { 0xC871, "temp_spawn_backup_on_apc" },
    { 0xC872, "temp_spawn_gun" },
    { 0xC873, "temp_stairtrain_count" },
    { 0xC874, "temp_start_and_stop_test" },
    { 0xC875, "temp_stealth_meter_delete_on_death" },
    { 0xC876, "temp_stealthicon_changecolor" },
    { 0xC877, "temp_stealthicon_initiate" },
    { 0xC878, "temp_swap_gun" },
    { 0xC879, "temp_tag" },
    { 0xC87A, "temp_think" },
    { 0xC87B, "temp_trace_data" },
    { 0xC87C, "temp_trace_data_colors" },
    { 0xC87D, "temp_trim" },
    { 0xC87E, "temp_vehicle_manuallysetspeed" },
    { 0xC87F, "tempanim" },
    { 0xC880, "tempdisabledynmovementspeed" },
    { 0xC881, "tempintensity" },
    { 0xC882, "template_level" },
    { 0xC883, "template_script" },
    { 0xC884, "templates" },
    { 0xC885, "tempmovesoundent" },
    { 0xC886, "temporal_increase" },
    { 0xC887, "temporary_ignore" },
    { 0xC888, "temprateset" },
    { 0xC889, "temprespawntokenhud" },
    { 0xC88A, "tempresttime" },
    { 0xC88B, "ten_percent_of_max_health" },
    { 0xC88C, "tense_music" },
    { 0xC88D, "ter_op" },
    { 0xC88E, "terminate_casualkiller" },
    { 0xC88F, "terminate_chatter" },
    { 0xC890, "terminate_deploylmg" },
    { 0xC891, "terminate_ladder" },
    { 0xC892, "terminate_newenemyreaction" },
    { 0xC893, "terminate_transitiontoexposedanim" },
    { 0xC894, "terminate_weaponswitch" },
    { 0xC895, "terminateblindfire" },
    { 0xC896, "terminatechangestance" },
    { 0xC897, "terminatecoverexposenoenemy" },
    { 0xC898, "terminatecovermultiswitch" },
    { 0xC899, "terminatecoverreload" },
    { 0xC89A, "terminateexitstartanim" },
    { 0xC89B, "terminateexpose" },
    { 0xC89C, "terminateexposedcrouch" },
    { 0xC89D, "terminateexposedcrouchaimdown" },
    { 0xC89E, "terminateexposedidleaimdown" },
    { 0xC89F, "terminateexposedprone" },
    { 0xC8A0, "terminategrenadereturnthrowanim" },
    { 0xC8A1, "terminatehide" },
    { 0xC8A2, "terminateidle" },
    { 0xC8A3, "terminatelook" },
    { 0xC8A4, "terminatepeek" },
    { 0xC8A5, "terminatereload" },
    { 0xC8A6, "terminatereloadwhilemoving" },
    { 0xC8A7, "terminatestartanim" },
    { 0xC8A8, "terminatethrowgrenade" },
    { 0xC8A9, "terminatetraverse" },
    { 0xC8AA, "terminatewallruntraverse" },
    { 0xC8AB, "terrorist_archetype_selected" },
    { 0xC8AC, "terrorist_camera_move_to" },
    { 0xC8AD, "terrorist_decide_respawn_think" },
    { 0xC8AE, "terrorist_enter_laststand" },
    { 0xC8AF, "terrorist_move_through_respawners_think" },
    { 0xC8B0, "terrorist_nearby_respawner_markers" },
    { 0xC8B1, "terrorist_nearby_respawners" },
    { 0xC8B2, "terrorist_overlay" },
    { 0xC8B3, "terrorist_player_initial_spawn_select" },
    { 0xC8B4, "terrorist_respawn_camera" },
    { 0xC8B5, "terrorist_respawner_selected" },
    { 0xC8B6, "terrorist_selected_respawner_marker" },
    { 0xC8B7, "terrorist_self_revive_time_override" },
    { 0xC8B8, "terrorists_respawn" },
    { 0xC8B9, "terry" },
    { 0xC8BA, "terry_damage_monitor" },
    { 0xC8BB, "terry_noreact_window" },
    { 0xC8BC, "tesla_type" },
    { 0xC8BD, "tess" },
    { 0xC8BE, "tess_init" },
    { 0xC8BF, "tess_set_goal" },
    { 0xC8C0, "tess_update" },
    { 0xC8C1, "test" },
    { 0xC8C2, "test_ammo_crate" },
    { 0xC8C3, "test_begin" },
    { 0xC8C4, "test_combat_func" },
    { 0xC8C5, "test_crafted_sentry" },
    { 0xC8C6, "test_dist" },
    { 0xC8C7, "test_ecounterstart" },
    { 0xC8C8, "test_end" },
    { 0xC8C9, "test_go_hot" },
    { 0xC8CA, "test_intel_loc" },
    { 0xC8CB, "test_intel_pickup" },
    { 0xC8CC, "test_kill_vip" },
    { 0xC8CD, "test_player_data_set" },
    { 0xC8CE, "test_print" },
    { 0xC8CF, "test_prints" },
    { 0xC8D0, "test_shock_as_entering_cell" },
    { 0xC8D1, "test_spawn_locations" },
    { 0xC8D2, "test_tag" },
    { 0xC8D3, "test_trace_tag" },
    { 0xC8D4, "testanimation" },
    { 0xC8D5, "testanimationduringuseduration" },
    { 0xC8D6, "testbuddyspawncriticalfactors" },
    { 0xC8D7, "testcriticalfactors" },
    { 0xC8D8, "testdroppos" },
    { 0xC8D9, "testformarker" },
    { 0xC8DA, "testforsuccess" },
    { 0xC8DB, "testgamemodestringlist" },
    { 0xC8DC, "testing_weapon_collision" },
    { 0xC8DD, "testingthings" },
    { 0xC8DE, "testmiscmessage" },
    { 0xC8DF, "testmissionrewards" },
    { 0xC8E0, "testpassivemessage" },
    { 0xC8E1, "testpetdebug" },
    { 0xC8E2, "testrandomrealismclients" },
    { 0xC8E3, "testsoundplacement" },
    { 0xC8E4, "testsuperbeginuse" },
    { 0xC8E5, "testsuperrefundwatcher" },
    { 0xC8E6, "testtdmanywhere" },
    { 0xC8E7, "testtiming" },
    { 0xC8E8, "testweaponfiredtolisteners" },
    { 0xC8E9, "tetherplayer" },
    { 0xC8EA, "text" },
    { 0xC8EB, "textalpha" },
    { 0xC8EC, "textlogo" },
    { 0xC8ED, "the_bomb_is_detonated" },
    { 0xC8EE, "the_hoff" },
    { 0xC8EF, "the_hoff_revive" },
    { 0xC8F0, "thermal_vision" },
    { 0xC8F1, "thermaldrawenabledrone" },
    { 0xC8F2, "thermalvision" },
    { 0xC8F3, "thermite_delete" },
    { 0xC8F4, "thermite_destroy" },
    { 0xC8F5, "thermite_onplayerdamaged" },
    { 0xC8F6, "thermite_used" },
    { 0xC8F7, "thermite_watchdisowned" },
    { 0xC8F8, "thermite_watchstuck" },
    { 0xC8F9, "things_carried_anim" },
    { 0xC8FA, "thinkers" },
    { 0xC8FB, "thinkindex" },
    { 0xC8FC, "thinkoffset" },
    { 0xC8FD, "thinkrate" },
    { 0xC8FE, "thinkrates" },
    { 0xC8FF, "third_floor_buddy_down_drag" },
    { 0xC900, "third_floor_catchup" },
    { 0xC901, "third_floor_clear" },
    { 0xC902, "third_floor_clear_extra" },
    { 0xC903, "third_floor_clear_nag" },
    { 0xC904, "third_floor_death_counter" },
    { 0xC905, "third_floor_frame_pulse" },
    { 0xC906, "third_floor_main" },
    { 0xC907, "third_floor_movement" },
    { 0xC908, "third_floor_start" },
    { 0xC909, "third_floor_view_exit" },
    { 0xC90A, "thirsty_tired_effects" },
    { 0xC90B, "thirsty_wake_timer" },
    { 0xC90C, "thread_audio_doorpropagation_init" },
    { 0xC90D, "thread_churn" },
    { 0xC90E, "thread_churn_notify" },
    { 0xC90F, "thread_end_func" },
    { 0xC910, "thread_end_test" },
    { 0xC911, "thread_endon" },
    { 0xC912, "thread_hostage_fulton_anims" },
    { 0xC913, "thread_on_end" },
    { 0xC914, "thread_on_notetrack" },
    { 0xC915, "thread_on_notify" },
    { 0xC916, "thread_on_notify_no_endon_death" },
    { 0xC917, "thread_on_notify_proc" },
    { 0xC918, "thread_resume" },
    { 0xC919, "thread_running_notify" },
    { 0xC91A, "thread_teleportplayertoteamstructs_latejoin" },
    { 0xC91B, "thread_terminate_child" },
    { 0xC91C, "thread_terminate_notify" },
    { 0xC91D, "thread_terminate_wrapper" },
    { 0xC91E, "thread_timestamped_events" },
    { 0xC91F, "thread_wait" },
    { 0xC920, "thread_wait_local" },
    { 0xC921, "thread_wait_native" },
    { 0xC922, "thread_wait_notify" },
    { 0xC923, "thread_wait_patch" },
    { 0xC924, "thread_waitframe" },
    { 0xC925, "thread_waitframeend" },
    { 0xC926, "thread_waittill_match" },
    { 0xC927, "threaded" },
    { 0xC928, "threaded_debug_start" },
    { 0xC929, "threaded_sfx_townhouse_door_audio" },
    { 0xC92A, "threaded_start_tugofwar" },
    { 0xC92B, "threadedbcloop" },
    { 0xC92C, "threadedscriptspawners" },
    { 0xC92D, "threadedsetweaponstatbyname" },
    { 0xC92E, "threads" },
    { 0xC92F, "threat" },
    { 0xC930, "threat_combat" },
    { 0xC931, "threat_entities" },
    { 0xC932, "threat_sight_count" },
    { 0xC933, "threat_sight_enabled" },
    { 0xC934, "threat_sight_fake" },
    { 0xC935, "threat_sight_force_visible" },
    { 0xC936, "threat_sight_force_visible_thread" },
    { 0xC937, "threat_sight_immediate_thread" },
    { 0xC938, "threat_sight_lost" },
    { 0xC939, "threat_sight_player_entity_state_set" },
    { 0xC93A, "threat_sight_player_entity_state_thread" },
    { 0xC93B, "threat_sight_player_init" },
    { 0xC93C, "threat_sight_player_sight_audio" },
    { 0xC93D, "threat_sight_set_dvar" },
    { 0xC93E, "threat_sight_set_dvar_display" },
    { 0xC93F, "threat_sight_set_enabled" },
    { 0xC940, "threat_sight_set_state" },
    { 0xC941, "threat_sight_set_state_parameters" },
    { 0xC942, "threat_sight_sighted" },
    { 0xC943, "threat_sight_sighted_wait_lost" },
    { 0xC944, "threat_sight_snd_ent" },
    { 0xC945, "threat_sight_snd_threat" },
    { 0xC946, "threat_sight_snd_vol" },
    { 0xC947, "threat_sight_state" },
    { 0xC948, "threat_sighted" },
    { 0xC949, "threat_tag" },
    { 0xC94A, "threat_thread" },
    { 0xC94B, "threat_type" },
    { 0xC94C, "threat_visible" },
    { 0xC94D, "threatbiasoverride" },
    { 0xC94E, "threatcallouts" },
    { 0xC94F, "threatcallouttracking" },
    { 0xC950, "threatent" },
    { 0xC951, "threatinfantry" },
    { 0xC952, "threatinfantry_docalloutlocation" },
    { 0xC953, "threatinfantryexposed" },
    { 0xC954, "threatisviable" },
    { 0xC955, "threatlevel" },
    { 0xC956, "threatsightdistscale" },
    { 0xC957, "threatsightratescale" },
    { 0xC958, "threattype" },
    { 0xC959, "threatvehicle" },
    { 0xC95A, "threatwasalreadycalledout" },
    { 0xC95B, "threw_grenade" },
    { 0xC95C, "threwback" },
    { 0xC95D, "threwbackgrenade" },
    { 0xC95E, "throttle_counter" },
    { 0xC95F, "throw_bowl_and_create_food" },
    { 0xC960, "throw_loc" },
    { 0xC961, "throw_molotov" },
    { 0xC962, "throw_moltovs_out_windows" },
    { 0xC963, "throw_players_out" },
    { 0xC964, "throwammocrate" },
    { 0xC965, "throwangles2d" },
    { 0xC966, "throwbackmarker_takeweapon" },
    { 0xC967, "throwbackmarker_trythrowbackmarker" },
    { 0xC968, "throwbackmarker_watchdetonate" },
    { 0xC969, "throwbackmarker_watchplayerweapon" },
    { 0xC96A, "throwbackmarker_watchthrowback" },
    { 0xC96B, "throwbackmarker_weapondetonatefunc" },
    { 0xC96C, "throwbackmarker_weaponfired" },
    { 0xC96D, "throwbackmarker_weaponfiredfunc" },
    { 0xC96E, "throwbackmarker_weapongiven" },
    { 0xC96F, "throwbackmarker_weapongivenfunc" },
    { 0xC970, "throwbackmarker_weaponswitchended" },
    { 0xC971, "throwbackmarker_weaponswitchendedfunc" },
    { 0xC972, "throwbackmarker_weapontaken" },
    { 0xC973, "throwbackmarker_weapontakenfunc" },
    { 0xC974, "throwcrate" },
    { 0xC975, "throwdata" },
    { 0xC976, "throwdownweapon" },
    { 0xC977, "throwgrenade_init" },
    { 0xC978, "throwgrenade_shouldabort" },
    { 0xC979, "throwgrenade_terminate" },
    { 0xC97A, "throwgrenade_update" },
    { 0xC97B, "throwgrenadeatenemyasap" },
    { 0xC97C, "throwgrenadeatplayerasap" },
    { 0xC97D, "throwgrenadeatplayerasap_combat_utility" },
    { 0xC97E, "throwgrenadetarget" },
    { 0xC97F, "throwgun" },
    { 0xC980, "throwing_knife_cp_init" },
    { 0xC981, "throwing_knife_deletepickup" },
    { 0xC982, "throwing_knife_init" },
    { 0xC983, "throwing_knife_makepickup" },
    { 0xC984, "throwing_knife_mp_init" },
    { 0xC985, "throwing_knife_mp_ongive" },
    { 0xC986, "throwing_knife_mp_onstuck" },
    { 0xC987, "throwing_knife_mp_ontake" },
    { 0xC988, "throwing_knife_mp_trytopickup" },
    { 0xC989, "throwing_knife_ongive" },
    { 0xC98A, "throwing_knife_ontake" },
    { 0xC98B, "throwing_knife_trytopickup" },
    { 0xC98C, "throwing_knife_used" },
    { 0xC98D, "throwing_knife_watchpickup" },
    { 0xC98E, "throwing_knife_watchpickuptimeout" },
    { 0xC98F, "throwinggrenade" },
    { 0xC990, "throwingknifec4detonate" },
    { 0xC991, "throwingknifec4init" },
    { 0xC992, "throwingknifedamagedvictim" },
    { 0xC993, "throwingknifefiremain" },
    { 0xC994, "throwingknifemaxpickups" },
    { 0xC995, "throwingknifepickuptimeout" },
    { 0xC996, "throwingknifeteleport" },
    { 0xC997, "throwingknifeteleport_fxendburst" },
    { 0xC998, "throwingknifeteleport_fxstartburst" },
    { 0xC999, "throwingknifeused" },
    { 0xC99A, "throwingknifeused_recordownerinvalid" },
    { 0xC99B, "throwingknifeused_trygiveknife" },
    { 0xC99C, "throwingknives" },
    { 0xC99D, "thrown" },
    { 0xC99E, "thrown_semtex_grenades" },
    { 0xC99F, "throwndyinggrenade" },
    { 0xC9A0, "thrownflares" },
    { 0xC9A1, "throwspeedforward" },
    { 0xC9A2, "throwspeedup" },
    { 0xC9A3, "throwsupplypack" },
    { 0xC9A4, "throwtime" },
    { 0xC9A5, "thrusterdamageloop" },
    { 0xC9A6, "thrusterloop" },
    { 0xC9A7, "thrusterstopfx" },
    { 0xC9A8, "thrusterwatchdoublejump" },
    { 0xC9A9, "thrustfxent" },
    { 0xC9AA, "ti_spawn" },
    { 0xC9AB, "ticket" },
    { 0xC9AC, "tickets_earned" },
    { 0xC9AD, "tickincrement" },
    { 0xC9AE, "tickingobject" },
    { 0xC9AF, "tickpercent" },
    { 0xC9B0, "ticks" },
    { 0xC9B1, "tieractivationdelay" },
    { 0xC9B2, "tiercapturetime" },
    { 0xC9B3, "tierfailure_countdown_think" },
    { 0xC9B4, "tierholdtime" },
    { 0xC9B5, "tierindex" },
    { 0xC9B6, "tierrewardcounts" },
    { 0xC9B7, "time" },
    { 0xC9B8, "time_between_spawns" },
    { 0xC9B9, "time_calculate" },
    { 0xC9BA, "time_has_passed" },
    { 0xC9BB, "time_hit" },
    { 0xC9BC, "time_remaining" },
    { 0xC9BD, "time_seeing_players" },
    { 0xC9BE, "time_since_last_stab" },
    { 0xC9BF, "time_since_spoke" },
    { 0xC9C0, "time_spent_hiding" },
    { 0xC9C1, "time_stamp" },
    { 0xC9C2, "time_stamp_can_be_damaged_by_sniper" },
    { 0xC9C3, "time_survived" },
    { 0xC9C4, "time_think" },
    { 0xC9C5, "time_till_next_extraction" },
    { 0xC9C6, "time_till_next_extraction_tick" },
    { 0xC9C7, "time_till_next_respawn" },
    { 0xC9C8, "time_till_next_respawn_tick" },
    { 0xC9C9, "time_to_give_next_tickets" },
    { 0xC9CA, "timeadjust" },
    { 0xC9CB, "timebeforedeescalate" },
    { 0xC9CC, "timebeforeescalate" },
    { 0xC9CD, "timebetweenc130passes" },
    { 0xC9CE, "timebyrotation" },
    { 0xC9CF, "timecreated" },
    { 0xC9D0, "timed_melee_check" },
    { 0xC9D1, "timednotify" },
    { 0xC9D2, "timeelapsed" },
    { 0xC9D3, "timeenemyleftvolume" },
    { 0xC9D4, "timehack" },
    { 0xC9D5, "timehiddennolosbeforedeescalate" },
    { 0xC9D6, "timeinads" },
    { 0xC9D7, "timeitemlasted" },
    { 0xC9D8, "timelefttospawnaction" },
    { 0xC9D9, "timelimit" },
    { 0xC9DA, "timelimitclock" },
    { 0xC9DB, "timelimitclock_intermission" },
    { 0xC9DC, "timelimitmusic" },
    { 0xC9DD, "timelimitoverride" },
    { 0xC9DE, "timelimitthread" },
    { 0xC9DF, "timelineevents" },
    { 0xC9E0, "timeoff" },
    { 0xC9E1, "timeoffset" },
    { 0xC9E2, "timeoflaststatechange" },
    { 0xC9E3, "timeon" },
    { 0xC9E4, "timeout" },
    { 0xC9E5, "timeout_action" },
    { 0xC9E6, "timeout_after_min_count" },
    { 0xC9E7, "timeout_explode" },
    { 0xC9E8, "timeout_group_after_duration" },
    { 0xC9E9, "timeout_monitor" },
    { 0xC9EA, "timeout_notify_melee_thread" },
    { 0xC9EB, "timeout_remove_intel" },
    { 0xC9EC, "timeout_vo" },
    { 0xC9ED, "timeout_wave" },
    { 0xC9EE, "timeoutcapturekills" },
    { 0xC9EF, "timeoutduration" },
    { 0xC9F0, "timeoutent" },
    { 0xC9F1, "timeoutms" },
    { 0xC9F2, "timeoutregenfaster" },
    { 0xC9F3, "timeouttime" },
    { 0xC9F4, "timeoutvofunction" },
    { 0xC9F5, "timeoutwasoccupied" },
    { 0xC9F6, "timepaused" },
    { 0xC9F7, "timepausestart" },
    { 0xC9F8, "timepenalty" },
    { 0xC9F9, "timepercentagecutoff" },
    { 0xC9FA, "timeperiod" },
    { 0xC9FB, "timeplacedinstack" },
    { 0xC9FC, "timeplayed" },
    { 0xC9FD, "timeplayedonfirstspawn" },
    { 0xC9FE, "timeplayerused" },
    { 0xC9FF, "timer" },
    { 0xCA00, "timer_cancel" },
    { 0xCA01, "timer_countup_hud" },
    { 0xCA02, "timer_enabled" },
    { 0xCA03, "timer_loop" },
    { 0xCA04, "timer_override" },
    { 0xCA05, "timer_paused" },
    { 0xCA06, "timer_penalties_hud" },
    { 0xCA07, "timer_run" },
    { 0xCA08, "timer_scoring_hud" },
    { 0xCA09, "timer_total_hud" },
    { 0xCA0A, "timer1" },
    { 0xCA0B, "timer2" },
    { 0xCA0C, "timer3" },
    { 0xCA0D, "timerbackward" },
    { 0xCA0E, "timerecorded" },
    { 0xCA0F, "timerforward" },
    { 0xCA10, "timerhud" },
    { 0xCA11, "timerleft" },
    { 0xCA12, "timerlookleft" },
    { 0xCA13, "timerlookright" },
    { 0xCA14, "timername" },
    { 0xCA15, "timerobject" },
    { 0xCA16, "timerpausetime" },
    { 0xCA17, "timerright" },
    { 0xCA18, "timers_hud" },
    { 0xCA19, "timerstarttime" },
    { 0xCA1A, "timerstopped" },
    { 0xCA1B, "timerstoppedforgamemode" },
    { 0xCA1C, "timerwait" },
    { 0xCA1D, "times" },
    { 0xCA1E, "times_hit" },
    { 0xCA1F, "times_kidnapped" },
    { 0xCA20, "times_nagged" },
    { 0xCA21, "times_played" },
    { 0xCA22, "times_used" },
    { 0xCA23, "timesapchitbymine" },
    { 0xCA24, "timescale" },
    { 0xCA25, "timescaleold" },
    { 0xCA26, "timescaleramptime" },
    { 0xCA27, "timesincelastspawn" },
    { 0xCA28, "timesincelastweaponfire" },
    { 0xCA29, "timesitemspicked" },
    { 0xCA2A, "timesitemstimedout" },
    { 0xCA2B, "timeslfused" },
    { 0xCA2C, "timespapused" },
    { 0xCA2D, "timesperwave" },
    { 0xCA2E, "timestamp" },
    { 0xCA2F, "timestarted_expose" },
    { 0xCA30, "timestarted_hide" },
    { 0xCA31, "timesturretfired" },
    { 0xCA32, "timetoadd" },
    { 0xCA33, "timetodamage" },
    { 0xCA34, "timetolosetarget" },
    { 0xCA35, "timetomove" },
    { 0xCA36, "timeuntilbleedout" },
    { 0xCA37, "timeuntilnextc130" },
    { 0xCA38, "timeuntilrespawnc130" },
    { 0xCA39, "timeuntilroundend" },
    { 0xCA3A, "timeuntilspawn" },
    { 0xCA3B, "timeuntilspawnmessaging" },
    { 0xCA3C, "timeuntilwavespawn" },
    { 0xCA3D, "timeupnotify" },
    { 0xCA3E, "timewithitem" },
    { 0xCA3F, "tire_rigs" },
    { 0xCA40, "tireclips" },
    { 0xCA41, "tirednessfactor" },
    { 0xCA42, "tiresounds" },
    { 0xCA43, "tispawndelay" },
    { 0xCA44, "tispawnposition" },
    { 0xCA45, "titan" },
    { 0xCA46, "title" },
    { 0xCA47, "tivalidationcheck" },
    { 0xCA48, "tjugg_loadouts" },
    { 0xCA49, "tjugg_timerdisplay" },
    { 0xCA4A, "tmty_interrogations" },
    { 0xCA4B, "tmtyl_cur_index" },
    { 0xCA4C, "tmtyl_customworldid" },
    { 0xCA4D, "tmtyl_finished" },
    { 0xCA4E, "tmtyl_headicon" },
    { 0xCA4F, "tmtyl_interrogation_int_struct" },
    { 0xCA50, "tmtyl_punish_wave_ongoing" },
    { 0xCA51, "tmtyl_vips" },
    { 0xCA52, "to_air_spawns" },
    { 0xCA53, "to_balcony_catchup" },
    { 0xCA54, "to_balcony_main" },
    { 0xCA55, "to_balcony_start" },
    { 0xCA56, "to_bhd_spawns" },
    { 0xCA57, "to_blitz_spawns" },
    { 0xCA58, "to_blitzactivebradleys" },
    { 0xCA59, "to_dd_phase_1" },
    { 0xCA5A, "to_dd_spawns" },
    { 0xCA5B, "to_ddhvt" },
    { 0xCA5C, "to_hstg_spawns" },
    { 0xCA5D, "to_sam_spawns" },
    { 0xCA5E, "to_wmd_spawns" },
    { 0xCA5F, "toggle_alarm" },
    { 0xCA60, "toggle_always_attempt_killoff" },
    { 0xCA61, "toggle_axismode" },
    { 0xCA62, "toggle_cockpit_lights" },
    { 0xCA63, "toggle_convoy_wheel_outlines" },
    { 0xCA64, "toggle_createfx_axis" },
    { 0xCA65, "toggle_createfx_drawing" },
    { 0xCA66, "toggle_disable_nearby_structs" },
    { 0xCA67, "toggle_dynamically_from_doors" },
    { 0xCA68, "toggle_entity_selection" },
    { 0xCA69, "toggle_extraction_functionality_after_timeout" },
    { 0xCA6A, "toggle_flashlight" },
    { 0xCA6B, "toggle_flashlight_fx" },
    { 0xCA6C, "toggle_force_stop_wave_from_groupname" },
    { 0xCA6D, "toggle_ignore_all" },
    { 0xCA6E, "toggle_kamikaze_for_group" },
    { 0xCA6F, "toggle_player_emp_effects" },
    { 0xCA70, "toggle_poi" },
    { 0xCA71, "toggle_poiauto" },
    { 0xCA72, "toggle_price_poi" },
    { 0xCA73, "toggle_respawn_functionality_after_timeout" },
    { 0xCA74, "toggle_snap2angle" },
    { 0xCA75, "toggle_snap2normal" },
    { 0xCA76, "toggle_spotterscope" },
    { 0xCA77, "toggle_team_emp_effects" },
    { 0xCA78, "toggle_teleport_enemy_info_loop" },
    { 0xCA79, "toggle_tire_outlines" },
    { 0xCA7A, "toggle_trucks_disable_leave" },
    { 0xCA7B, "toggle_vo_on_convoy_death" },
    { 0xCA7C, "toggle_vo_on_hvt_pickup" },
    { 0xCA7D, "toggle_vo_on_hvt_rescued" },
    { 0xCA7E, "toggle_vo_on_nearby_convoy" },
    { 0xCA7F, "toggleblastshield" },
    { 0xCA80, "togglecellphoneallows" },
    { 0xCA81, "toggled_tire_outlines" },
    { 0xCA82, "toggledrophintstring" },
    { 0xCA83, "togglehvtusable" },
    { 0xCA84, "togglekidnappers" },
    { 0xCA85, "togglescores_button_hold_monitor" },
    { 0xCA86, "toggleuifunc" },
    { 0xCA87, "togglewavespawning" },
    { 0xCA88, "toggleweaponsfree" },
    { 0xCA89, "tokenreward" },
    { 0xCA8A, "toma_cameras" },
    { 0xCA8B, "toma_strike_branch_create_explosion" },
    { 0xCA8C, "toma_strike_branch_is_complete" },
    { 0xCA8D, "toma_strike_branch_register_cast" },
    { 0xCA8E, "toma_strike_create_branch" },
    { 0xCA8F, "toma_strike_create_explosion" },
    { 0xCA90, "toma_strike_delay_hide" },
    { 0xCA91, "toma_strike_explosion_end" },
    { 0xCA92, "toma_strike_get_cast_data" },
    { 0xCA93, "toma_strike_get_cast_dir" },
    { 0xCA94, "toma_strike_get_cast_dist" },
    { 0xCA95, "toma_strike_get_shared_data" },
    { 0xCA96, "toma_strike_getownerlookatpos" },
    { 0xCA97, "toma_strike_handlemarkerscriptable" },
    { 0xCA98, "toma_strike_launch_cluster" },
    { 0xCA99, "toma_strike_missile_explode" },
    { 0xCA9A, "toma_strike_molotov_branch_draw_hits" },
    { 0xCA9B, "toma_strike_monitordamage" },
    { 0xCA9C, "toma_strike_move_killcam" },
    { 0xCA9D, "toma_strike_rebuild_angles_up_forward" },
    { 0xCA9E, "toma_strike_rebuild_angles_up_right" },
    { 0xCA9F, "toma_strike_setmarkerobjective" },
    { 0xCAA0, "toma_strike_shared_data_can_cast_this_frame" },
    { 0xCAA1, "toma_strike_shared_data_is_complete" },
    { 0xCAA2, "toma_strike_shared_data_register_cast" },
    { 0xCAA3, "toma_strike_shared_data_register_ent" },
    { 0xCAA4, "toma_strike_start_branch" },
    { 0xCAA5, "toma_strike_start_explosion" },
    { 0xCAA6, "toma_strike_stuck" },
    { 0xCAA7, "toma_strike_stuck_player" },
    { 0xCAA8, "toma_strike_watch_airexplosion" },
    { 0xCAA9, "toma_strike_watch_stuck" },
    { 0xCAAA, "toma_strikes" },
    { 0xCAAB, "tomastrike_attacktarget" },
    { 0xCAAC, "tomastrike_explode" },
    { 0xCAAD, "tomastrike_firestrike" },
    { 0xCAAE, "tomastrike_getbombingpoints" },
    { 0xCAAF, "tomastrike_getmissileendpos" },
    { 0xCAB0, "tomastrike_getownerlookat" },
    { 0xCAB1, "tomastrike_handlemissiledetection" },
    { 0xCAB2, "tomastrike_ismarkertype" },
    { 0xCAB3, "tomastrike_isremotevehicletype" },
    { 0xCAB4, "tomastrike_modifydamage" },
    { 0xCAB5, "tomastrike_movetargetguide" },
    { 0xCAB6, "tomastrike_playearthquakeloop" },
    { 0xCAB7, "tomastrike_playercameratransition" },
    { 0xCAB8, "tomastrike_returnplayer" },
    { 0xCAB9, "tomastrike_screeninterference" },
    { 0xCABA, "tomastrike_startlasertarget" },
    { 0xCABB, "tomastrike_watchammousage" },
    { 0xCABC, "tomastrike_watchcameraswitch" },
    { 0xCABD, "tomastrike_watchdamage" },
    { 0xCABE, "tomastrike_watchdeathdamage" },
    { 0xCABF, "tomastrike_watchdestroyed" },
    { 0xCAC0, "tomastrike_watchdronedeath" },
    { 0xCAC1, "tomastrike_watchearlyexit" },
    { 0xCAC2, "tomastrike_watchgoal" },
    { 0xCAC3, "tomastrike_watchlaserrelease" },
    { 0xCAC4, "tomastrike_watchlasertarget" },
    { 0xCAC5, "tomastrike_watchleave" },
    { 0xCAC6, "tomastrike_watchlifetime" },
    { 0xCAC7, "tomastrike_watchowner" },
    { 0xCAC8, "tomastrike_watchreturnplayer" },
    { 0xCAC9, "tomastrikebeginuse" },
    { 0xCACA, "too_close_to_other_blocker_vehicle_in_front" },
    { 0xCACB, "too_close_to_other_bodyguard_vehicle_in_front" },
    { 0xCACC, "too_close_to_other_interactions" },
    { 0xCACD, "too_far" },
    { 0xCACE, "too_far_dist_sq" },
    { 0xCACF, "tookbreath" },
    { 0xCAD0, "tookvesthit" },
    { 0xCAD1, "tookweaponfrom" },
    { 0xCAD2, "tool_hud" },
    { 0xCAD3, "tool_hud_visible" },
    { 0xCAD4, "tool_hudelems" },
    { 0xCAD5, "top_left_sight_checker" },
    { 0xCAD6, "topaxisplayers" },
    { 0xCAD7, "topkillstreakcharge" },
    { 0xCAD8, "toplosingplayers" },
    { 0xCAD9, "topmodel" },
    { 0xCADA, "topplayers" },
    { 0xCADB, "toppoint" },
    { 0xCADC, "toptrigger" },
    { 0xCADD, "toptriggerthink" },
    { 0xCADE, "toptriggertrackplayer" },
    { 0xCADF, "topwatchtrigger" },
    { 0xCAE0, "torrent_start" },
    { 0xCAE1, "torso_center_anim" },
    { 0xCAE2, "torso_left_anim" },
    { 0xCAE3, "torso_leftback_anim" },
    { 0xCAE4, "torso_leftright_anim" },
    { 0xCAE5, "torso_right_anim" },
    { 0xCAE6, "torso_rightback_anim" },
    { 0xCAE7, "toss_glowstick" },
    { 0xCAE8, "tossclip" },
    { 0xCAE9, "tossed_flares" },
    { 0xCAEA, "tossgun" },
    { 0xCAEB, "total" },
    { 0xCAEC, "total_cluster_spawn_score" },
    { 0xCAED, "total_currency_earned" },
    { 0xCAEE, "total_cut_progress" },
    { 0xCAEF, "total_dist" },
    { 0xCAF0, "total_grid_points" },
    { 0xCAF1, "total_match_headshots" },
    { 0xCAF2, "total_spawn_score" },
    { 0xCAF3, "total_spawned_enemies" },
    { 0xCAF4, "total_tags_banked" },
    { 0xCAF5, "total_time" },
    { 0xCAF6, "total_trap_kills" },
    { 0xCAF7, "total_veh_spawn_score" },
    { 0xCAF8, "total_z_planes" },
    { 0xCAF9, "totalactivecounteruavs" },
    { 0xCAFA, "totalactiveuavs" },
    { 0xCAFB, "totalappliedpoints" },
    { 0xCAFC, "totalbarriers" },
    { 0xCAFD, "totaldamagetaken" },
    { 0xCAFE, "totaldist" },
    { 0xCAFF, "totaldisttracking" },
    { 0xCB00, "totalmeter" },
    { 0xCB01, "totalplayers" },
    { 0xCB02, "totalpoints" },
    { 0xCB03, "totalpossiblescore" },
    { 0xCB04, "totalprobability" },
    { 0xCB05, "totalscavengeditems" },
    { 0xCB06, "totalscorelimit" },
    { 0xCB07, "totalspawns" },
    { 0xCB08, "totalspottercount" },
    { 0xCB09, "totaltime" },
    { 0xCB0A, "totaltimeelapsed" },
    { 0xCB0B, "totaltracecount" },
    { 0xCB0C, "totalwaitframes" },
    { 0xCB0D, "totalxpearned" },
    { 0xCB0E, "touch_once" },
    { 0xCB0F, "touched" },
    { 0xCB10, "touched_trigger_runs_func" },
    { 0xCB11, "touching" },
    { 0xCB12, "touchingarbitraryuptrigger" },
    { 0xCB13, "touchingbadtrigger" },
    { 0xCB14, "touchingballallowedtrigger" },
    { 0xCB15, "touchingdroptonavmeshtrigger" },
    { 0xCB16, "touchinggameobjects" },
    { 0xCB17, "touchingnozonetrigger" },
    { 0xCB18, "touchingoobtrigger" },
    { 0xCB19, "touchingplayerallowedtrigger" },
    { 0xCB1A, "touchlist" },
    { 0xCB1B, "touchtimes" },
    { 0xCB1C, "touchtriggers" },
    { 0xCB1D, "toughenedup" },
    { 0xCB1E, "tovehiclelocaloffset" },
    { 0xCB1F, "tovehiclevector" },
    { 0xCB20, "tower_ai_thread" },
    { 0xCB21, "tower_comment" },
    { 0xCB22, "tower_damage_check" },
    { 0xCB23, "tower_drone_target" },
    { 0xCB24, "tower_elevator" },
    { 0xCB25, "tower_guy_cleanup" },
    { 0xCB26, "tower_guy_tarmac_spawn_func" },
    { 0xCB27, "tower_spawner_killer" },
    { 0xCB28, "tower_spawner_logic" },
    { 0xCB29, "towerkills" },
    { 0xCB2A, "towerstairs_getallycovernodes" },
    { 0xCB2B, "town_getallycovernodes" },
    { 0xCB2C, "town_technical_01" },
    { 0xCB2D, "town_truck_lights" },
    { 0xCB2E, "townhouse_stealth_settings" },
    { 0xCB2F, "townhousevolume" },
    { 0xCB30, "trace" },
    { 0xCB31, "trace_completion_thread" },
    { 0xCB32, "trace_contents" },
    { 0xCB33, "trace_data" },
    { 0xCB34, "trace_data_colors" },
    { 0xCB35, "trace_for_stairs" },
    { 0xCB36, "trace_impale" },
    { 0xCB37, "trace_location" },
    { 0xCB38, "trace_part_for_efx" },
    { 0xCB39, "trace_part_for_efx_cancel" },
    { 0xCB3A, "trace_result_hits_surface" },
    { 0xCB3B, "traceangle" },
    { 0xCB3C, "tracecountbyphase" },
    { 0xCB3D, "tracegroundheight" },
    { 0xCB3E, "tracegroundpoint" },
    { 0xCB3F, "tracenewpoint" },
    { 0xCB40, "tracer" },
    { 0xCB41, "traces" },
    { 0xCB42, "traces_count" },
    { 0xCB43, "tracestart" },
    { 0xCB44, "tracetimebyphase" },
    { 0xCB45, "track" },
    { 0xCB46, "track_achievement_death" },
    { 0xCB47, "track_dialogue" },
    { 0xCB48, "track_flir_footstep" },
    { 0xCB49, "track_fob_helo_spawn" },
    { 0xCB4A, "track_forward_velocity" },
    { 0xCB4B, "track_fulton_uses" },
    { 0xCB4C, "track_gunship_uses_per_player" },
    { 0xCB4D, "track_hellfire_kills" },
    { 0xCB4E, "track_hellfire_tower_kills" },
    { 0xCB4F, "track_hellfire_vehicle_kills" },
    { 0xCB50, "track_if_player_throw_smokes" },
    { 0xCB51, "track_player_achievements" },
    { 0xCB52, "track_player_combat_time" },
    { 0xCB53, "track_player_humvee_speed_monitor" },
    { 0xCB54, "track_player_indoors" },
    { 0xCB55, "track_player_light_meter" },
    { 0xCB56, "track_player_rpg" },
    { 0xCB57, "track_player_smoke_grenade" },
    { 0xCB58, "track_player_weapon_fire_time" },
    { 0xCB59, "track_pos" },
    { 0xCB5A, "track_target_delay" },
    { 0xCB5B, "track_tire_damage" },
    { 0xCB5C, "track_train_damage" },
    { 0xCB5D, "trackasm" },
    { 0xCB5E, "trackattackerleaderboarddeathstats" },
    { 0xCB5F, "trackbuffassist" },
    { 0xCB60, "trackbuffassistfortime" },
    { 0xCB61, "trackcarepackages" },
    { 0xCB62, "trackcarrier" },
    { 0xCB63, "trackdebuffassist" },
    { 0xCB64, "trackdebuffassistfortime" },
    { 0xCB65, "trackduration" },
    { 0xCB66, "trackedobject" },
    { 0xCB67, "tracker_bullet_hit" },
    { 0xCB68, "trackers" },
    { 0xCB69, "trackfreeplayedtime" },
    { 0xCB6A, "trackgametypevips" },
    { 0xCB6B, "trackgrenades" },
    { 0xCB6C, "trackhiddenobj" },
    { 0xCB6D, "trackhostmigrationend" },
    { 0xCB6E, "tracking_enemy" },
    { 0xCB6F, "tracking_hints_calltrain" },
    { 0xCB70, "tracking_init" },
    { 0xCB71, "tracking_speed" },
    { 0xCB72, "tracking_time_to_pickup" },
    { 0xCB73, "trackingdata" },
    { 0xCB74, "trackingteam" },
    { 0xCB75, "trackingweapon" },
    { 0xCB76, "trackingweapondeaths" },
    { 0xCB77, "trackingweaponheadshots" },
    { 0xCB78, "trackingweaponhits" },
    { 0xCB79, "trackingweaponkills" },
    { 0xCB7A, "trackingweaponshots" },
    { 0xCB7B, "trackinit" },
    { 0xCB7C, "trackkillsforpassivenuke" },
    { 0xCB7D, "trackkillsforrandomperks" },
    { 0xCB7E, "tracklaststandforpassivenuke" },
    { 0xCB7F, "tracklaststandforpassiverandomperks" },
    { 0xCB80, "trackleaderboarddeathstats" },
    { 0xCB81, "trackloop" },
    { 0xCB82, "trackloop_anglesfornoshootpos" },
    { 0xCB83, "trackloop_clampangles" },
    { 0xCB84, "trackloop_cqbshootpos" },
    { 0xCB85, "trackloop_getdesiredangles" },
    { 0xCB86, "trackloop_restoreaim" },
    { 0xCB87, "trackloop_setanimweights" },
    { 0xCB88, "trackloop_setanimweightslmg" },
    { 0xCB89, "trackmaxdistancethreshold" },
    { 0xCB8A, "trackmindistancethreshold" },
    { 0xCB8B, "trackmissile" },
    { 0xCB8C, "trackmissiles" },
    { 0xCB8D, "trackplayedtime" },
    { 0xCB8E, "trackplayedtimeupdate" },
    { 0xCB8F, "trackriotshield" },
    { 0xCB90, "trackriotshield_ontrophystow" },
    { 0xCB91, "trackshootentorpos" },
    { 0xCB92, "trackteamchanges" },
    { 0xCB93, "tracktoaccel" },
    { 0xCB94, "tracktodecel" },
    { 0xCB95, "tracktotime" },
    { 0xCB96, "trackturnofflaser" },
    { 0xCB97, "trackturnonlaser" },
    { 0xCB98, "trackvelocity" },
    { 0xCB99, "traffick_civ_1" },
    { 0xCB9A, "traffick_civ_2" },
    { 0xCB9B, "traffick_civ_3" },
    { 0xCB9C, "traffick_civ_4" },
    { 0xCB9D, "traffick_civ_5" },
    { 0xCB9E, "traffick_civ_6" },
    { 0xCB9F, "trafficked_scene" },
    { 0xCBA0, "trafficked_scene_kill" },
    { 0xCBA1, "trafficked_scene_solo" },
    { 0xCBA2, "trafficking_anim_node" },
    { 0xCBA3, "trafficking_truck_vehicle" },
    { 0xCBA4, "trail" },
    { 0xCBA5, "trail_fx" },
    { 0xCBA6, "trailer" },
    { 0xCBA7, "trailer_car_drive_off" },
    { 0xCBA8, "trailer_civ_setup" },
    { 0xCBA9, "trailer_left_cars" },
    { 0xCBAA, "trailer_start" },
    { 0xCBAB, "train" },
    { 0xCBAC, "train_attach_light" },
    { 0xCBAD, "train_car_length" },
    { 0xCBAE, "train_car_model" },
    { 0xCBAF, "train_check_if_player_nearby" },
    { 0xCBB0, "train_check_if_player_nearby_proc" },
    { 0xCBB1, "train_end_model" },
    { 0xCBB2, "train_go" },
    { 0xCBB3, "train_handler" },
    { 0xCBB4, "train_light_flicker" },
    { 0xCBB5, "train_move" },
    { 0xCBB6, "train_nav_blocks" },
    { 0xCBB7, "train_parts" },
    { 0xCBB8, "train_rumble" },
    { 0xCBB9, "train_sfx_1" },
    { 0xCBBA, "train_sfx_2" },
    { 0xCBBB, "train_sounds" },
    { 0xCBBC, "train_thread" },
    { 0xCBBD, "traincar" },
    { 0xCBBE, "trait" },
    { 0xCBBF, "trajectory" },
    { 0xCBC0, "transactionid" },
    { 0xCBC1, "transfer_damage_to_player" },
    { 0xCBC2, "transient_collision_grid_enabled" },
    { 0xCBC3, "transient_init" },
    { 0xCBC4, "transient_load" },
    { 0xCBC5, "transient_load_array" },
    { 0xCBC6, "transient_load_boss" },
    { 0xCBC7, "transient_load_poppies" },
    { 0xCBC8, "transient_load_town" },
    { 0xCBC9, "transient_loading" },
    { 0xCBCA, "transient_prefab" },
    { 0xCBCB, "transient_prefab_override" },
    { 0xCBCC, "transient_switch" },
    { 0xCBCD, "transient_unload" },
    { 0xCBCE, "transient_unload_array" },
    { 0xCBCF, "transient_unload_boss" },
    { 0xCBD0, "transient_unload_carried" },
    { 0xCBD1, "transient_unload_light_tut" },
    { 0xCBD2, "transient_unload_load" },
    { 0xCBD3, "transient_unload_poppies" },
    { 0xCBD4, "transient_unload_town" },
    { 0xCBD5, "transient_unloadall_and_load" },
    { 0xCBD6, "transient_waittill" },
    { 0xCBD7, "transient_world_grid_size" },
    { 0xCBD8, "transient_world_max_output_tris_lod_1" },
    { 0xCBD9, "transient_world_max_output_tris_lod_2" },
    { 0xCBDA, "transient_world_output_texture_dims_lod_1" },
    { 0xCBDB, "transient_world_output_texture_dims_lod_2" },
    { 0xCBDC, "transient_world_proxy_cull_distance" },
    { 0xCBDD, "transient_world_root" },
    { 0xCBDE, "transient_world_submap" },
    { 0xCBDF, "transition_arrivalisstopped" },
    { 0xCBE0, "transition_flashfinished" },
    { 0xCBE1, "transition_interrupted" },
    { 0xCBE2, "transition_isburning" },
    { 0xCBE3, "transition_isflashed" },
    { 0xCBE4, "transition_point" },
    { 0xCBE5, "transition_points" },
    { 0xCBE6, "transition_to_point" },
    { 0xCBE7, "transitionarray" },
    { 0xCBE8, "transitioncircle" },
    { 0xCBE9, "transitionedfromrun" },
    { 0xCBEA, "transitionfadein" },
    { 0xCBEB, "transitionfadeout" },
    { 0xCBEC, "transitionpulsefxin" },
    { 0xCBED, "transitionreset" },
    { 0xCBEE, "transitions" },
    { 0xCBEF, "transitionslidein" },
    { 0xCBF0, "transitionslideout" },
    { 0xCBF1, "transitionzoomin" },
    { 0xCBF2, "transitionzoomout" },
    { 0xCBF3, "translate_ent_think" },
    { 0xCBF4, "translate_local" },
    { 0xCBF5, "translate_local_on_ent" },
    { 0xCBF6, "translate_position_with_offset_data" },
    { 0xCBF7, "translate_spring_index" },
    { 0xCBF8, "translationdelta" },
    { 0xCBF9, "transponder_hint_displayed" },
    { 0xCBFA, "transport_bravo_spawn" },
    { 0xCBFB, "transporttime" },
    { 0xCBFC, "transtoidlealias" },
    { 0xCBFD, "trap" },
    { 0xCBFE, "trap_converationdialoguelogic" },
    { 0xCBFF, "trap_defused" },
    { 0xCC00, "trap_door_extras" },
    { 0xCC01, "trap_door_fx" },
    { 0xCC02, "trap_door_plywood" },
    { 0xCC03, "trap_door_rock" },
    { 0xCC04, "trap_door_scene" },
    { 0xCC05, "trap_getallyexplosivesreadylines" },
    { 0xCC06, "trap_killed_by" },
    { 0xCC07, "trap_main" },
    { 0xCC08, "trap_start" },
    { 0xCC09, "trapachievementboom" },
    { 0xCC0A, "trapactive" },
    { 0xCC0B, "trapdangerzoneproc" },
    { 0xCC0C, "trapkills" },
    { 0xCC0D, "traps" },
    { 0xCC0E, "traptypes" },
    { 0xCC0F, "traveltonode" },
    { 0xCC10, "traversal_assist_init" },
    { 0xCC11, "traversal_end_node" },
    { 0xCC12, "traversal_end_pos" },
    { 0xCC13, "traversal_nav_obstacle" },
    { 0xCC14, "traversal_start_node" },
    { 0xCC15, "traversal_test" },
    { 0xCC16, "traversal_test_logic" },
    { 0xCC17, "traversal_test_think" },
    { 0xCC18, "traversalassist" },
    { 0xCC19, "traversalassistmode" },
    { 0xCC1A, "traversalhasarrival" },
    { 0xCC1B, "traversalorientearlyterminate" },
    { 0xCC1C, "traversals" },
    { 0xCC1D, "traverse_animscript" },
    { 0xCC1E, "traverse_basic" },
    { 0xCC1F, "traverse_check" },
    { 0xCC20, "traverse_cleanup" },
    { 0xCC21, "traverse_donotetracks" },
    { 0xCC22, "traverse_doublejump_cleanup" },
    { 0xCC23, "traverse_drop_height_delta" },
    { 0xCC24, "traverse_height" },
    { 0xCC25, "traverse_height_delta" },
    { 0xCC26, "traverse_think" },
    { 0xCC27, "traverseanim" },
    { 0xCC28, "traverseanimroot" },
    { 0xCC29, "traversearrival" },
    { 0xCC2A, "traversechooseanim" },
    { 0xCC2B, "traversedeathanim" },
    { 0xCC2C, "traversedeathindex" },
    { 0xCC2D, "traverseendnode" },
    { 0xCC2E, "traversehandler" },
    { 0xCC2F, "traverseheight" },
    { 0xCC30, "traverseinfo" },
    { 0xCC31, "traversestartnode" },
    { 0xCC32, "traversestartz" },
    { 0xCC33, "traversethink" },
    { 0xCC34, "traversetype" },
    { 0xCC35, "traversexanim" },
    { 0xCC36, "tread" },
    { 0xCC37, "tread_override_thread" },
    { 0xCC38, "tread_vfx_set_up" },
    { 0xCC39, "tread_vfx_tags" },
    { 0xCC3A, "tread_vfx_think" },
    { 0xCC3B, "tread_wait" },
    { 0xCC3C, "treadfx_freq_scale" },
    { 0xCC3D, "treadfx_maxheight" },
    { 0xCC3E, "treadfx_orient_to_player" },
    { 0xCC3F, "treadsheavy" },
    { 0xCC40, "treadsneutral" },
    { 0xCC41, "treadsnormal" },
    { 0xCC42, "tree_dist_check" },
    { 0xCC43, "tree_dist_values" },
    { 0xCC44, "tree_is_animating" },
    { 0xCC45, "tree_test" },
    { 0xCC46, "trench_getallyspawners" },
    { 0xCC47, "trench_getrocketally" },
    { 0xCC48, "trench_spawnallies" },
    { 0xCC49, "trenchrun_getallycovernodes" },
    { 0xCC4A, "trgger_kill_civ_structs" },
    { 0xCC4B, "triage_ammo_nag" },
    { 0xCC4C, "triage_civ_breakout" },
    { 0xCC4D, "triage_door_close" },
    { 0xCC4E, "triage_door_open" },
    { 0xCC4F, "triage_end_fadeout_waiting" },
    { 0xCC50, "triage_reach_and_idle" },
    { 0xCC51, "triage_rpg_momment_cleanup" },
    { 0xCC52, "triage_scene" },
    { 0xCC53, "triage_scene_mayhem_anims" },
    { 0xCC54, "triage_start_watcher" },
    { 0xCC55, "trial" },
    { 0xCC56, "trial_accuracy_bonus" },
    { 0xCC57, "trial_akimbo_props" },
    { 0xCC58, "trial_chevron_init" },
    { 0xCC59, "trial_chevron_vfx" },
    { 0xCC5A, "trial_chevron_vfx_action" },
    { 0xCC5B, "trial_end_score_dialogue" },
    { 0xCC5C, "trial_fail_alt" },
    { 0xCC5D, "trial_failure_countdown" },
    { 0xCC5E, "trial_first_start" },
    { 0xCC5F, "trial_infinite_reserve_ammo" },
    { 0xCC60, "trial_loadout" },
    { 0xCC61, "trial_main_time" },
    { 0xCC62, "trial_map_loadout" },
    { 0xCC63, "trial_mission_data_init" },
    { 0xCC64, "trial_progression_init" },
    { 0xCC65, "trial_score_init" },
    { 0xCC66, "trial_start_init" },
    { 0xCC67, "trial_subtime" },
    { 0xCC68, "trial_ui_freeze_secondary_timer" },
    { 0xCC69, "trial_ui_hide_secondary_timer" },
    { 0xCC6A, "trial_ui_open_results_screen" },
    { 0xCC6B, "trial_ui_set_best_score" },
    { 0xCC6C, "trial_ui_set_best_time" },
    { 0xCC6D, "trial_ui_set_main_score" },
    { 0xCC6E, "trial_ui_set_main_time" },
    { 0xCC6F, "trial_ui_set_mission_index" },
    { 0xCC70, "trial_ui_set_objective_icon_index" },
    { 0xCC71, "trial_ui_set_objective_progress" },
    { 0xCC72, "trial_ui_set_reward_tier" },
    { 0xCC73, "trial_ui_set_reward_tier_preview" },
    { 0xCC74, "trial_ui_set_secondary_timer" },
    { 0xCC75, "trial_ui_set_stat_and_bonus_score" },
    { 0xCC76, "trial_ui_set_stat_and_bonus_time" },
    { 0xCC77, "trial_ui_set_subscore" },
    { 0xCC78, "trial_ui_set_subtime" },
    { 0xCC79, "trial_ui_set_tier_requirements" },
    { 0xCC7A, "trial_ui_set_tries_remaining" },
    { 0xCC7B, "trial_ui_set_wave" },
    { 0xCC7C, "trial_ui_waittill_retry" },
    { 0xCC7D, "trial_variant_init" },
    { 0xCC7E, "trial_weapon_spawn" },
    { 0xCC7F, "trial_weapons" },
    { 0xCC80, "tried_to_get_gun" },
    { 0xCC81, "tries_remaining" },
    { 0xCC82, "trig" },
    { 0xCC83, "trig_notify_start" },
    { 0xCC84, "trig_notify_stop" },
    { 0xCC85, "trigblock" },
    { 0xCC86, "trigger_alt_mode" },
    { 0xCC87, "trigger_arbitrary_up" },
    { 0xCC88, "trigger_array_delete_cafe" },
    { 0xCC89, "trigger_array_wait_then_delete" },
    { 0xCC8A, "trigger_array_wait_then_delete_cafe" },
    { 0xCC8B, "trigger_auto_crouch" },
    { 0xCC8C, "trigger_autosave" },
    { 0xCC8D, "trigger_autosave_stealth" },
    { 0xCC8E, "trigger_autosave_tactical" },
    { 0xCC8F, "trigger_battlechatter" },
    { 0xCC90, "trigger_cansee" },
    { 0xCC91, "trigger_check_shove" },
    { 0xCC92, "trigger_choose_func_from_list" },
    { 0xCC93, "trigger_cover_blown" },
    { 0xCC94, "trigger_createart_transient" },
    { 0xCC95, "trigger_damage_ondamage" },
    { 0xCC96, "trigger_damage_player_flag_set" },
    { 0xCC97, "trigger_damage_state_health" },
    { 0xCC98, "trigger_delete_link_chain" },
    { 0xCC99, "trigger_delete_on_touch" },
    { 0xCC9A, "trigger_delete_recursive" },
    { 0xCC9B, "trigger_delete_target_chain" },
    { 0xCC9C, "trigger_dooropen" },
    { 0xCC9D, "trigger_escort_disengage" },
    { 0xCC9E, "trigger_fakeactor_move" },
    { 0xCC9F, "trigger_fakeactor_node_disable" },
    { 0xCCA0, "trigger_fakeactor_node_disablegroup" },
    { 0xCCA1, "trigger_fakeactor_node_enable" },
    { 0xCCA2, "trigger_fakeactor_node_enablegroup" },
    { 0xCCA3, "trigger_fakeactor_node_lock" },
    { 0xCCA4, "trigger_fakeactor_node_passthrough" },
    { 0xCCA5, "trigger_fire" },
    { 0xCCA6, "trigger_fire_endon" },
    { 0xCCA7, "trigger_flag_clear" },
    { 0xCCA8, "trigger_flag_on_cleared" },
    { 0xCCA9, "trigger_flag_set" },
    { 0xCCAA, "trigger_flag_set_player" },
    { 0xCCAB, "trigger_flag_set_touching" },
    { 0xCCAC, "trigger_flags" },
    { 0xCCAD, "trigger_friendly_respawn" },
    { 0xCCAE, "trigger_friendly_stop_respawn" },
    { 0xCCAF, "trigger_func" },
    { 0xCCB0, "trigger_functions" },
    { 0xCCB1, "trigger_glass_break" },
    { 0xCCB2, "trigger_group" },
    { 0xCCB3, "trigger_group_remove" },
    { 0xCCB4, "trigger_hall_molotov" },
    { 0xCCB5, "trigger_hill_destruction" },
    { 0xCCB6, "trigger_hill_trees" },
    { 0xCCB7, "trigger_hint" },
    { 0xCCB8, "trigger_hint_func" },
    { 0xCCB9, "trigger_hint_string" },
    { 0xCCBA, "trigger_ied_monitor" },
    { 0xCCBB, "trigger_ignore" },
    { 0xCCBC, "trigger_interaction" },
    { 0xCCBD, "trigger_interaction_common" },
    { 0xCCBE, "trigger_interaction_multiple" },
    { 0xCCBF, "trigger_issues_orders" },
    { 0xCCC0, "trigger_landingzone" },
    { 0xCCC1, "trigger_landingzone_active" },
    { 0xCCC2, "trigger_light" },
    { 0xCCC3, "trigger_lookat" },
    { 0xCCC4, "trigger_lookat_think" },
    { 0xCCC5, "trigger_looking" },
    { 0xCCC6, "trigger_manager" },
    { 0xCCC7, "trigger_move_ent" },
    { 0xCCC8, "trigger_move_ent_sfx" },
    { 0xCCC9, "trigger_moveto" },
    { 0xCCCA, "trigger_multiple_compass" },
    { 0xCCCB, "trigger_multiple_depthoffield" },
    { 0xCCCC, "trigger_multiple_fx" },
    { 0xCCCD, "trigger_multiple_fx_trigger_off_think" },
    { 0xCCCE, "trigger_multiple_fx_trigger_on_think" },
    { 0xCCCF, "trigger_multiple_fx_volume" },
    { 0xCCD0, "trigger_multiple_fx_watersheeting" },
    { 0xCCD1, "trigger_multiple_kleenex" },
    { 0xCCD2, "trigger_multiple_sunflare" },
    { 0xCCD3, "trigger_multiple_tessellationcutoff" },
    { 0xCCD4, "trigger_multiple_transient" },
    { 0xCCD5, "trigger_nearest_friendly_respawn_trigger" },
    { 0xCCD6, "trigger_nearest_gasmasks" },
    { 0xCCD7, "trigger_no_crouch_or_prone" },
    { 0xCCD8, "trigger_no_prone" },
    { 0xCCD9, "trigger_nobloodpool" },
    { 0xCCDA, "trigger_off" },
    { 0xCCDB, "trigger_off_proc" },
    { 0xCCDC, "trigger_on" },
    { 0xCCDD, "trigger_on_proc" },
    { 0xCCDE, "trigger_outofbounds" },
    { 0xCCDF, "trigger_pacifist" },
    { 0xCCE0, "trigger_parse_parameters" },
    { 0xCCE1, "trigger_physics" },
    { 0xCCE2, "trigger_playerseek" },
    { 0xCCE3, "trigger_process_node" },
    { 0xCCE4, "trigger_radio" },
    { 0xCCE5, "trigger_radius" },
    { 0xCCE6, "trigger_reinforcement_get_reinforcement_spawner" },
    { 0xCCE7, "trigger_reinforcement_spawn_guys" },
    { 0xCCE8, "trigger_requires_player" },
    { 0xCCE9, "trigger_run_module_once" },
    { 0xCCEA, "trigger_run_spawn_module" },
    { 0xCCEB, "trigger_runs_function_on_touch" },
    { 0xCCEC, "trigger_safe_function" },
    { 0xCCED, "trigger_script_flag_false" },
    { 0xCCEE, "trigger_script_flag_true" },
    { 0xCCEF, "trigger_show_scriptables" },
    { 0xCCF0, "trigger_slide" },
    { 0xCCF1, "trigger_spawn" },
    { 0xCCF2, "trigger_spawn_func" },
    { 0xCCF3, "trigger_spawn_init" },
    { 0xCCF4, "trigger_spawn_module_func" },
    { 0xCCF5, "trigger_spawner" },
    { 0xCCF6, "trigger_spawner_reinforcement" },
    { 0xCCF7, "trigger_spawngroup" },
    { 0xCCF8, "trigger_stealth_shadow" },
    { 0xCCF9, "trigger_sun_off" },
    { 0xCCFA, "trigger_sun_on" },
    { 0xCCFB, "trigger_temp_stealth_meter" },
    { 0xCCFC, "trigger_think" },
    { 0xCCFD, "trigger_throw_grenade_at_player" },
    { 0xCCFE, "trigger_turns_off" },
    { 0xCCFF, "trigger_unlock" },
    { 0xCD00, "trigger_unlock_death" },
    { 0xCD01, "trigger_vehicle_spline_spawn" },
    { 0xCD02, "trigger_wait" },
    { 0xCD03, "trigger_wait_targetname" },
    { 0xCD04, "trigger_zone_spawn" },
    { 0xCD05, "triggeranim" },
    { 0xCD06, "triggerblind" },
    { 0xCD07, "triggerbrush" },
    { 0xCD08, "triggercallback" },
    { 0xCD09, "triggerdistance" },
    { 0xCD0A, "triggered" },
    { 0xCD0B, "triggered_by_ai_events" },
    { 0xCD0C, "triggered_by_oil_fire" },
    { 0xCD0D, "triggeredbyplayer" },
    { 0xCD0E, "triggereddelayedexplosion" },
    { 0xCD0F, "triggeredfunc" },
    { 0xCD10, "triggerenterents" },
    { 0xCD11, "triggerenterthink" },
    { 0xCD12, "triggerexitthink" },
    { 0xCD13, "triggerfunc" },
    { 0xCD14, "triggerfuncc4" },
    { 0xCD15, "triggerfuncfrag" },
    { 0xCD16, "triggerfuncsemtex" },
    { 0xCD17, "triggerfunctripwire" },
    { 0xCD18, "triggerheight" },
    { 0xCD19, "triggering_ent" },
    { 0xCD1A, "triggeringstreak" },
    { 0xCD1B, "triggerinsidetimes" },
    { 0xCD1C, "triggerkillstreak" },
    { 0xCD1D, "triggerlisten" },
    { 0xCD1E, "triggeroffset" },
    { 0xCD1F, "triggerradius" },
    { 0xCD20, "triggers" },
    { 0xCD21, "triggers_sequence" },
    { 0xCD22, "triggertouchthink" },
    { 0xCD23, "triggertrapfuncthink" },
    { 0xCD24, "triggertripwirefuncthink" },
    { 0xCD25, "triggertype" },
    { 0xCD26, "triggerunlocked" },
    { 0xCD27, "triggerutilityinit" },
    { 0xCD28, "trigorigin" },
    { 0xCD29, "trigunderwater" },
    { 0xCD2A, "trimkillcamtime" },
    { 0xCD2B, "trinityrocketlocked" },
    { 0xCD2C, "trip_defused_already" },
    { 0xCD2D, "trip_stance_monitor" },
    { 0xCD2E, "trip_stance_think" },
    { 0xCD2F, "trip_wall_defuse_vo_nags" },
    { 0xCD30, "trip_web_go_under_vo_nags" },
    { 0xCD31, "tripwire_cantriptrap" },
    { 0xCD32, "tripwire_chain_trigger" },
    { 0xCD33, "tripwire_check" },
    { 0xCD34, "tripwire_createhintobject" },
    { 0xCD35, "tripwire_damagefunc" },
    { 0xCD36, "tripwire_defuse_thread" },
    { 0xCD37, "tripwire_delete_cleanup" },
    { 0xCD38, "tripwire_disabled" },
    { 0xCD39, "tripwire_disarmgiveweapon" },
    { 0xCD3A, "tripwire_enemy_trip_monitor" },
    { 0xCD3B, "tripwire_enemy_trip_watch" },
    { 0xCD3C, "tripwire_enemy_watchers" },
    { 0xCD3D, "tripwire_explosion_enhancement" },
    { 0xCD3E, "tripwire_givegrenade" },
    { 0xCD3F, "tripwire_grenade_defused" },
    { 0xCD40, "tripwire_hint" },
    { 0xCD41, "tripwire_hint_dialogue" },
    { 0xCD42, "tripwire_init" },
    { 0xCD43, "tripwire_nag" },
    { 0xCD44, "tripwire_pathing_think" },
    { 0xCD45, "tripwire_pathing_watch" },
    { 0xCD46, "tripwire_randomize" },
    { 0xCD47, "tripwire_thread" },
    { 0xCD48, "tripwire_trap_count" },
    { 0xCD49, "tripwire_trigger_thread" },
    { 0xCD4A, "tripwirehastraps" },
    { 0xCD4B, "tripwiremodelprecache" },
    { 0xCD4C, "tripwires" },
    { 0xCD4D, "tripwireshouldtrigger" },
    { 0xCD4E, "tripwirethink" },
    { 0xCD4F, "tromeo_00" },
    { 0xCD50, "tromeo_01" },
    { 0xCD51, "tromeo_02" },
    { 0xCD52, "tromeo_03" },
    { 0xCD53, "tromeo_check" },
    { 0xCD54, "tromeo_cleanup" },
    { 0xCD55, "tromeo_entrance_00" },
    { 0xCD56, "tromeo_entrance_01" },
    { 0xCD57, "tromeo_entrance_02" },
    { 0xCD58, "tromeo_entrance_03" },
    { 0xCD59, "tromeo_guys_03_spawn_func" },
    { 0xCD5A, "tromeo_guys_spawn_func" },
    { 0xCD5B, "tromeo_vehicle_tarmac_00" },
    { 0xCD5C, "tromeos" },
    { 0xCD5D, "trophies" },
    { 0xCD5E, "trophy" },
    { 0xCD5F, "trophy_addstored" },
    { 0xCD60, "trophy_applyempcallback" },
    { 0xCD61, "trophy_castcontents" },
    { 0xCD62, "trophy_castorigin" },
    { 0xCD63, "trophy_checkignorelist" },
    { 0xCD64, "trophy_cleanuponparentdeath" },
    { 0xCD65, "trophy_clearstored" },
    { 0xCD66, "trophy_createexplosion" },
    { 0xCD67, "trophy_delete" },
    { 0xCD68, "trophy_deploy" },
    { 0xCD69, "trophy_deploysequence" },
    { 0xCD6A, "trophy_destroy" },
    { 0xCD6B, "trophy_destroyonemp" },
    { 0xCD6C, "trophy_destroyongameend" },
    { 0xCD6D, "trophy_explode" },
    { 0xCD6E, "trophy_getbesttag" },
    { 0xCD6F, "trophy_getdeployanimtime" },
    { 0xCD70, "trophy_getpartbytag" },
    { 0xCD71, "trophy_givedamagefeedback" },
    { 0xCD72, "trophy_givepointsfordeath" },
    { 0xCD73, "trophy_handledamage" },
    { 0xCD74, "trophy_handlefataldamage" },
    { 0xCD75, "trophy_hideandshowaftertime" },
    { 0xCD76, "trophy_init" },
    { 0xCD77, "trophy_maxstored" },
    { 0xCD78, "trophy_modifieddamage" },
    { 0xCD79, "trophy_modifiedprotectiondistsqr" },
    { 0xCD7A, "trophy_notifytrophytargetowner" },
    { 0xCD7B, "trophy_onsuperset" },
    { 0xCD7C, "trophy_pickup" },
    { 0xCD7D, "trophy_populatestored" },
    { 0xCD7E, "trophy_protectionsuccessful" },
    { 0xCD7F, "trophy_remote_destroy" },
    { 0xCD80, "trophy_removestored" },
    { 0xCD81, "trophy_set" },
    { 0xCD82, "trophy_shutdownanddestroy" },
    { 0xCD83, "trophy_startcooldownlist" },
    { 0xCD84, "trophy_unset" },
    { 0xCD85, "trophy_used" },
    { 0xCD86, "trophy_watchprotection" },
    { 0xCD87, "trophyonset" },
    { 0xCD88, "trophyremainingammo" },
    { 0xCD89, "truck" },
    { 0xCD8A, "truck_barrels_compromised" },
    { 0xCD8B, "truck_barrels_on_death" },
    { 0xCD8C, "truck_compromise" },
    { 0xCD8D, "truck_convoy" },
    { 0xCD8E, "truck_crash_wall_hole_light" },
    { 0xCD8F, "truck_crowd_walla_loop" },
    { 0xCD90, "truck_damage_custom" },
    { 0xCD91, "truck_damage_monitor" },
    { 0xCD92, "truck_dead_or_alive_monitor" },
    { 0xCD93, "truck_death_spot" },
    { 0xCD94, "truck_delete" },
    { 0xCD95, "truck_driver" },
    { 0xCD96, "truck_driver_damage_handler" },
    { 0xCD97, "truck_driver_delayed_death_handler" },
    { 0xCD98, "truck_drivers" },
    { 0xCD99, "truck_encounterstart" },
    { 0xCD9A, "truck_enemy_alive_count" },
    { 0xCD9B, "truck_getspawneraitype" },
    { 0xCD9C, "truck_lights" },
    { 0xCD9D, "truck_loc" },
    { 0xCD9E, "truck_move_on" },
    { 0xCD9F, "truck_office" },
    { 0xCDA0, "truck_office_aq_driver" },
    { 0xCDA1, "truck_office_aq_killer" },
    { 0xCDA2, "truck_office_aq_rider" },
    { 0xCDA3, "truck_office_bpg_scene_marine" },
    { 0xCDA4, "truck_office_bpg_scene_marine_move_to_marine" },
    { 0xCDA5, "truck_office_catchup" },
    { 0xCDA6, "truck_office_civ_idle_handler" },
    { 0xCDA7, "truck_office_civ_with_box" },
    { 0xCDA8, "truck_office_civs" },
    { 0xCDA9, "truck_office_crash_marine_vo" },
    { 0xCDAA, "truck_office_crash_price_vo" },
    { 0xCDAB, "truck_office_crash_vo" },
    { 0xCDAC, "truck_office_delete_all" },
    { 0xCDAD, "truck_office_enemies" },
    { 0xCDAE, "truck_office_enemy_death_counter" },
    { 0xCDAF, "truck_office_enter" },
    { 0xCDB0, "truck_office_flavor_aq_run_through" },
    { 0xCDB1, "truck_office_flavor_truck_drive_by" },
    { 0xCDB2, "truck_office_hide_all" },
    { 0xCDB3, "truck_office_main" },
    { 0xCDB4, "truck_office_marine_vo" },
    { 0xCDB5, "truck_office_price" },
    { 0xCDB6, "truck_office_price_move_to_marine" },
    { 0xCDB7, "truck_office_red_shirt" },
    { 0xCDB8, "truck_office_setup_truck" },
    { 0xCDB9, "truck_office_setup_walls" },
    { 0xCDBA, "truck_office_shotgun_impedence" },
    { 0xCDBB, "truck_office_start" },
    { 0xCDBC, "truck_office_truck" },
    { 0xCDBD, "truck_office_wall_collapse" },
    { 0xCDBE, "truck_office_walls_post" },
    { 0xCDBF, "truck_office_walls_pre" },
    { 0xCDC0, "truck_office_wreck_reaction_gesture" },
    { 0xCDC1, "truck_office_wreck_vfx" },
    { 0xCDC2, "truck_roll_door_init" },
    { 0xCDC3, "truck_roll_door_open" },
    { 0xCDC4, "truck_roll_door_sound" },
    { 0xCDC5, "truck_setup" },
    { 0xCDC6, "truck_smash_watcher" },
    { 0xCDC7, "truck_street_death_watcher" },
    { 0xCDC8, "truck_treadfx_health_hack" },
    { 0xCDC9, "truck_waittill_death" },
    { 0xCDCA, "truck_wreck_mb" },
    { 0xCDCB, "truck_wreck_vision" },
    { 0xCDCC, "truck1" },
    { 0xCDCD, "truck1_flip" },
    { 0xCDCE, "truck2" },
    { 0xCDCF, "truck3" },
    { 0xCDD0, "truck3_idle" },
    { 0xCDD1, "trucklightsoff" },
    { 0xCDD2, "truckmove02" },
    { 0xCDD3, "trucks_controller" },
    { 0xCDD4, "trucks_controller_spawn_func_poppies_hill_pickup" },
    { 0xCDD5, "trucks_controller_spawn_func_poppies_hill_umike" },
    { 0xCDD6, "trucks_controller_spawn_func_poppies_shed_umike" },
    { 0xCDD7, "trucks_convoy_catchup" },
    { 0xCDD8, "trucks_convoy_main" },
    { 0xCDD9, "trucks_convoy_start" },
    { 0xCDDA, "trucks_retreat_setup_actor" },
    { 0xCDDB, "trucks_sniper_suicide_truck" },
    { 0xCDDC, "trucks_stolen_catchup" },
    { 0xCDDD, "trucks_stolen_main" },
    { 0xCDDE, "trucks_stolen_start" },
    { 0xCDDF, "trucks_stopped_watcher" },
    { 0xCDE0, "true_start_angles" },
    { 0xCDE1, "truecount" },
    { 0xCDE2, "try_activate_final_bomb_detonate_sequence" },
    { 0xCDE3, "try_ambush_suicide_bomber_spawning" },
    { 0xCDE4, "try_announce_sound" },
    { 0xCDE5, "try_attic_dialogue_shoot_her" },
    { 0xCDE6, "try_cardinal_gunshot" },
    { 0xCDE7, "try_cardinal_patrol_update" },
    { 0xCDE8, "try_clear_hide_goal" },
    { 0xCDE9, "try_deaths" },
    { 0xCDEA, "try_door_hint" },
    { 0xCDEB, "try_enable_repair_interaction" },
    { 0xCDEC, "try_exit_vehicle" },
    { 0xCDED, "try_get_gun_anim_node" },
    { 0xCDEE, "try_get_gun_interact" },
    { 0xCDEF, "try_getlocalizedtext" },
    { 0xCDF0, "try_give_munition_to_slot" },
    { 0xCDF1, "try_give_player_weapon_xp" },
    { 0xCDF2, "try_give_weapon_xp_zombie_killed" },
    { 0xCDF3, "try_indoor_save" },
    { 0xCDF4, "try_interior_callout" },
    { 0xCDF5, "try_nag" },
    { 0xCDF6, "try_nvg_enable_hint" },
    { 0xCDF7, "try_og_origin" },
    { 0xCDF8, "try_place_global_badplace" },
    { 0xCDF9, "try_push_sound" },
    { 0xCDFA, "try_resume_vignette" },
    { 0xCDFB, "try_run_init_of_event" },
    { 0xCDFC, "try_shoot_at_current_target" },
    { 0xCDFD, "try_smart_radio_dialogue" },
    { 0xCDFE, "try_spawn_backup" },
    { 0xCDFF, "try_start_driving" },
    { 0xCE00, "try_start_event" },
    { 0xCE01, "try_take_player_currency" },
    { 0xCE02, "try_throw_molotov_at_spot" },
    { 0xCE03, "try_to_autosave_now" },
    { 0xCE04, "try_to_draw_line_to_node" },
    { 0xCE05, "try_to_play_vo" },
    { 0xCE06, "try_to_play_vo_for_one_player" },
    { 0xCE07, "try_to_play_vo_on_all_players" },
    { 0xCE08, "try_to_play_vo_on_team" },
    { 0xCE09, "try_tunnel_teleport" },
    { 0xCE0A, "try_update_lb_playerdata" },
    { 0xCE0B, "try_update_wait_for_repeating_event" },
    { 0xCE0C, "try_use_func" },
    { 0xCE0D, "tryadddeathanim" },
    { 0xCE0E, "tryaddfiringdeathanim" },
    { 0xCE0F, "tryairdroptriggered" },
    { 0xCE10, "tryautosave" },
    { 0xCE11, "trycornerrightgrenadedeath" },
    { 0xCE12, "trycreateextractpoint" },
    { 0xCE13, "trydisableminimap" },
    { 0xCE14, "trydive" },
    { 0xCE15, "trydof" },
    { 0xCE16, "trydroparmorfornewarmor" },
    { 0xCE17, "tryequiparmor" },
    { 0xCE18, "tryequipmentfrominventory" },
    { 0xCE19, "tryequiputility" },
    { 0xCE1A, "trygiveuseweapon" },
    { 0xCE1B, "trygrenadeposproc" },
    { 0xCE1C, "trygrenadethrow" },
    { 0xCE1D, "trygulagspawn" },
    { 0xCE1E, "tryhostagerespawn" },
    { 0xCE1F, "trying_rockets" },
    { 0xCE20, "trying_to_pass_player_vehicle_think" },
    { 0xCE21, "tryingcolorgesture" },
    { 0xCE22, "tryingopener" },
    { 0xCE23, "trylootdespawn" },
    { 0xCE24, "trylootdropdespawn" },
    { 0xCE25, "tryorderto" },
    { 0xCE26, "trypickupitem" },
    { 0xCE27, "trypickupitemfroment" },
    { 0xCE28, "tryplacespawner" },
    { 0xCE29, "tryresetrankxp" },
    { 0xCE2A, "tryrunnextobjective" },
    { 0xCE2B, "tryrunningtoenemy" },
    { 0xCE2C, "trysaylocalsound" },
    { 0xCE2D, "trysetqueuedselfvo" },
    { 0xCE2E, "tryspawnavehicle" },
    { 0xCE2F, "tryspawnlaunchchunkbots" },
    { 0xCE30, "tryspawnneutralbradleycmd" },
    { 0xCE31, "trysuperusebegin" },
    { 0xCE32, "trytocacheclassstruct" },
    { 0xCE33, "trytomastriketriggered" },
    { 0xCE34, "trytriggerkillstreakfromsuper" },
    { 0xCE35, "tryupdatehvtstatus" },
    { 0xCE36, "tryuseac130" },
    { 0xCE37, "tryuseairdropmarker" },
    { 0xCE38, "tryuseairdropmarkerfromstruct" },
    { 0xCE39, "tryuseairstrike" },
    { 0xCE3A, "tryuseairstrikefromstruct" },
    { 0xCE3B, "tryuseautosentry" },
    { 0xCE3C, "tryusechoppergunner" },
    { 0xCE3D, "tryusechoppergunnerfromstruct" },
    { 0xCE3E, "tryusechoppersupport" },
    { 0xCE3F, "tryusechoppersupportfromstruct" },
    { 0xCE40, "tryusecruisepredator" },
    { 0xCE41, "tryusecruisepredatorfromstruct" },
    { 0xCE42, "tryusedeathswitch" },
    { 0xCE43, "tryusedeathswitchfromstruct" },
    { 0xCE44, "tryusedeployablevest" },
    { 0xCE45, "tryusedronehive" },
    { 0xCE46, "tryusedronestrike" },
    { 0xCE47, "tryuseemp" },
    { 0xCE48, "tryuseempfromstruct" },
    { 0xCE49, "tryusegunship" },
    { 0xCE4A, "tryusegunshipfromstruct" },
    { 0xCE4B, "tryusehelicopter" },
    { 0xCE4C, "tryusehelipilot" },
    { 0xCE4D, "tryusehelperdrone" },
    { 0xCE4E, "tryusehelperdroneearlyout" },
    { 0xCE4F, "tryusehelperdronefromstruct" },
    { 0xCE50, "tryusehoverjet" },
    { 0xCE51, "tryusehoverjetfromstruct" },
    { 0xCE52, "tryuseitemfrominventory" },
    { 0xCE53, "tryusejuggernaut" },
    { 0xCE54, "tryusejuggernautfromstruct" },
    { 0xCE55, "tryusemanualturret" },
    { 0xCE56, "tryusemanualturretfromstruct" },
    { 0xCE57, "tryusenuke" },
    { 0xCE58, "tryusenukefromstruct" },
    { 0xCE59, "tryusepredatormissile" },
    { 0xCE5A, "tryuseremotemgturret" },
    { 0xCE5B, "tryuseremotetank" },
    { 0xCE5C, "tryuseremotetankfromstruct" },
    { 0xCE5D, "tryuseremoteuav" },
    { 0xCE5E, "tryusesam" },
    { 0xCE5F, "tryusesentryturret" },
    { 0xCE60, "tryusesentryturretfromstruct" },
    { 0xCE61, "tryuseshocksentry" },
    { 0xCE62, "tryusesupportbox" },
    { 0xCE63, "tryusetomastrike" },
    { 0xCE64, "tryusetomastrikefromstruct" },
    { 0xCE65, "tryuseuav" },
    { 0xCE66, "tryuseuavfromstruct" },
    { 0xCE67, "tryusewp" },
    { 0xCE68, "tryusewpfromstruct" },
    { 0xCE69, "ttlos_suppressasserts" },
    { 0xCE6A, "ttlosoverrides" },
    { 0xCE6B, "tugofwar_anim" },
    { 0xCE6C, "tugofwar_exfil_hvt" },
    { 0xCE6D, "tugofwar_exfil_location" },
    { 0xCE6E, "tunnel_animnode" },
    { 0xCE6F, "tunnel_catchup" },
    { 0xCE70, "tunnel_collapse_think" },
    { 0xCE71, "tunnel_door" },
    { 0xCE72, "tunnel_main" },
    { 0xCE73, "tunnel_open" },
    { 0xCE74, "tunnel_scene" },
    { 0xCE75, "tunnel_start" },
    { 0xCE76, "tunnel_struct" },
    { 0xCE77, "tunnels_achievement" },
    { 0xCE78, "tunnels_achievement_pistol_only" },
    { 0xCE79, "tunnels_achievement_pistol_only_final" },
    { 0xCE7A, "tunnels_achievements" },
    { 0xCE7B, "tunnels_ar_guys_force_ak47" },
    { 0xCE7C, "tunnels_baseaccuracy_when_player_on_ladder_or_in_smoke_or_above_player_in_shaft" },
    { 0xCE7D, "tunnels_combat" },
    { 0xCE7E, "tunnels_corpse_cleanup" },
    { 0xCE7F, "tunnels_deleteanimatedmattress" },
    { 0xCE80, "tunnels_door_anim" },
    { 0xCE81, "tunnels_door_guy_fire_aware" },
    { 0xCE82, "tunnels_door_player_extras" },
    { 0xCE83, "tunnels_farahgrabdisguiseanimationlogic" },
    { 0xCE84, "tunnels_flashlight_management" },
    { 0xCE85, "tunnels_getanimatedmattress" },
    { 0xCE86, "tunnels_getanimationstruct" },
    { 0xCE87, "tunnels_getplayermantletrigger" },
    { 0xCE88, "tunnels_hadirnaglogic" },
    { 0xCE89, "tunnels_main" },
    { 0xCE8A, "tunnels_notify_first_cell_guy_death" },
    { 0xCE8B, "tunnels_playerinteractlogic" },
    { 0xCE8C, "tunnels_playerinteractpintoedgelogic" },
    { 0xCE8D, "tunnels_playerladderspeedscalinglogic" },
    { 0xCE8E, "tunnels_playerspeedscalinglogic" },
    { 0xCE8F, "tunnels_setupanimatedmattress" },
    { 0xCE90, "tunnels_shaft_molotov_giveth" },
    { 0xCE91, "tunnels_shotgun_guy_accuracy_debug" },
    { 0xCE92, "tunnels_shotgun_guy_accuracy_management" },
    { 0xCE93, "tunnels_shotgun_guy_monitor_weapon_fire" },
    { 0xCE94, "tunnels_spawnfunctions" },
    { 0xCE95, "tunnels_start" },
    { 0xCE96, "turbine_cleanup" },
    { 0xCE97, "turbine_enemies_seek" },
    { 0xCE98, "turbine_pa_line" },
    { 0xCE99, "turbine_spin" },
    { 0xCE9A, "turbines_clear_thread" },
    { 0xCE9B, "turbines_dialog" },
    { 0xCE9C, "turbines_level_vars" },
    { 0xCE9D, "turbines_pa_chatter_say" },
    { 0xCE9E, "turbines_pa_say" },
    { 0xCE9F, "turbines_postload" },
    { 0xCEA0, "turbines_postspawns" },
    { 0xCEA1, "turbines_preload" },
    { 0xCEA2, "turbo" },
    { 0xCEA3, "turn_check" },
    { 0xCEA4, "turn_left_enter" },
    { 0xCEA5, "turn_left_exit" },
    { 0xCEA6, "turn_lights_onoff" },
    { 0xCEA7, "turn_off_ambush_light_models" },
    { 0xCEA8, "turn_off_consumable" },
    { 0xCEA9, "turn_off_drone_hud" },
    { 0xCEAA, "turn_off_firing_while_flashed" },
    { 0xCEAB, "turn_off_flood_spawner" },
    { 0xCEAC, "turn_off_floodlights" },
    { 0xCEAD, "turn_off_grenade_cooldown" },
    { 0xCEAE, "turn_off_headtracking" },
    { 0xCEAF, "turn_off_headtracking_solo" },
    { 0xCEB0, "turn_off_light_bar_on_death" },
    { 0xCEB1, "turn_off_lights" },
    { 0xCEB2, "turn_off_mansion_lights" },
    { 0xCEB3, "turn_off_players_birds_view_hud" },
    { 0xCEB4, "turn_off_power_vo" },
    { 0xCEB5, "turn_off_proc" },
    { 0xCEB6, "turn_off_prompt" },
    { 0xCEB7, "turn_off_states_on_death" },
    { 0xCEB8, "turn_off_suv_interior_light" },
    { 0xCEB9, "turn_off_vfx_on_zombie" },
    { 0xCEBA, "turn_on_after_timeout" },
    { 0xCEBB, "turn_on_cards" },
    { 0xCEBC, "turn_on_drone_hud" },
    { 0xCEBD, "turn_on_floodlights" },
    { 0xCEBE, "turn_on_headtracking" },
    { 0xCEBF, "turn_on_headtracking_solo" },
    { 0xCEC0, "turn_on_lights" },
    { 0xCEC1, "turn_on_proc" },
    { 0xCEC2, "turn_on_suv_interior_light" },
    { 0xCEC3, "turn_on_team_armor_buff" },
    { 0xCEC4, "turn_right_enter" },
    { 0xCEC5, "turn_right_exit" },
    { 0xCEC6, "turn_think" },
    { 0xCEC7, "turn_trucks_on" },
    { 0xCEC8, "turnanim" },
    { 0xCEC9, "turnbackon" },
    { 0xCECA, "turnkidnappertonormalai" },
    { 0xCECB, "turnlaserbackon" },
    { 0xCECC, "turnoff" },
    { 0xCECD, "turnofflaser" },
    { 0xCECE, "turnoffnvgs" },
    { 0xCECF, "turnofftimer" },
    { 0xCED0, "turnon" },
    { 0xCED1, "turnonlaser" },
    { 0xCED2, "turnspeedtarget" },
    { 0xCED3, "turret" },
    { 0xCED4, "turret_aim_think" },
    { 0xCED5, "turret_can_shoot_player" },
    { 0xCED6, "turret_coolmonitor" },
    { 0xCED7, "turret_corpse_monitor" },
    { 0xCED8, "turret_default_fire" },
    { 0xCED9, "turret_disabled" },
    { 0xCEDA, "turret_dst" },
    { 0xCEDB, "turret_enemy_mover_clean_up" },
    { 0xCEDC, "turret_enemy_watcher" },
    { 0xCEDD, "turret_find_user" },
    { 0xCEDE, "turret_fire_enable" },
    { 0xCEDF, "turret_getplayerusefuncs" },
    { 0xCEE0, "turret_guy_spawn_func" },
    { 0xCEE1, "turret_handlepickup" },
    { 0xCEE2, "turret_handleuse" },
    { 0xCEE3, "turret_heatmonitor" },
    { 0xCEE4, "turret_hint_func" },
    { 0xCEE5, "turret_hitbox_track_damage" },
    { 0xCEE6, "turret_impactquakes" },
    { 0xCEE7, "turret_init_func" },
    { 0xCEE8, "turret_internal" },
    { 0xCEE9, "turret_investigate_pos" },
    { 0xCEEA, "turret_investigate_pos_time" },
    { 0xCEEB, "turret_is_firing" },
    { 0xCEEC, "turret_is_mine" },
    { 0xCEED, "turret_is_on_ent" },
    { 0xCEEE, "turret_logic" },
    { 0xCEEF, "turret_manager" },
    { 0xCEF0, "turret_minigun_fire" },
    { 0xCEF1, "turret_minigun_target_track" },
    { 0xCEF2, "turret_monitoruse" },
    { 0xCEF3, "turret_operator" },
    { 0xCEF4, "turret_overheat_bar" },
    { 0xCEF5, "turret_overheat_org" },
    { 0xCEF6, "turret_owner_damage_func" },
    { 0xCEF7, "turret_playerstartfunc" },
    { 0xCEF8, "turret_playerstopfunc" },
    { 0xCEF9, "turret_playerthread" },
    { 0xCEFA, "turret_pointer" },
    { 0xCEFB, "turret_set_default_on_mode" },
    { 0xCEFC, "turret_shell_fx" },
    { 0xCEFD, "turret_shell_sound" },
    { 0xCEFE, "turret_shoot_think" },
    { 0xCEFF, "turret_shotmonitor" },
    { 0xCF00, "turret_should_keep_firing" },
    { 0xCF01, "turret_spotted_ent_think" },
    { 0xCF02, "turret_start_locs" },
    { 0xCF03, "turret_sweep" },
    { 0xCF04, "turret_sweep_to_loc" },
    { 0xCF05, "turret_think" },
    { 0xCF06, "turret_track_target" },
    { 0xCF07, "turret_track_target_think" },
    { 0xCF08, "turret_use_func" },
    { 0xCF09, "turret_use_time" },
    { 0xCF0A, "turret_user_moves" },
    { 0xCF0B, "turret_vm_playeranims_think" },
    { 0xCF0C, "turret_watchplayeruse" },
    { 0xCF0D, "turret_weapon" },
    { 0xCF0E, "turretangles" },
    { 0xCF0F, "turretarray" },
    { 0xCF10, "turretdeathdetacher" },
    { 0xCF11, "turretdetacher" },
    { 0xCF12, "turretfx" },
    { 0xCF13, "turretindex" },
    { 0xCF14, "turretinfo" },
    { 0xCF15, "turretinits" },
    { 0xCF16, "turretinitshared" },
    { 0xCF17, "turretmodel" },
    { 0xCF18, "turretoffset" },
    { 0xCF19, "turreton" },
    { 0xCF1A, "turretorigin" },
    { 0xCF1B, "turretparts" },
    { 0xCF1C, "turretplayerstartfunc" },
    { 0xCF1D, "turretplayerstopfunc" },
    { 0xCF1E, "turretpos" },
    { 0xCF1F, "turretrequested" },
    { 0xCF20, "turrets" },
    { 0xCF21, "turretsettings" },
    { 0xCF22, "turrettarget" },
    { 0xCF23, "turretthink" },
    { 0xCF24, "turrettimer" },
    { 0xCF25, "turrettype" },
    { 0xCF26, "turretweapon" },
    { 0xCF27, "tut_flood" },
    { 0xCF28, "tut_fusebox" },
    { 0xCF29, "tutorial" },
    { 0xCF2A, "tutorial_activated" },
    { 0xCF2B, "tutorial_ads" },
    { 0xCF2C, "tutorial_allieslogic" },
    { 0xCF2D, "tutorial_alliessearch" },
    { 0xCF2E, "tutorial_allysignaleffectslogic" },
    { 0xCF2F, "tutorial_catchup" },
    { 0xCF30, "tutorial_deletesniperbench" },
    { 0xCF31, "tutorial_flood_init" },
    { 0xCF32, "tutorial_getallies" },
    { 0xCF33, "tutorial_getallyaliasnames" },
    { 0xCF34, "tutorial_getallynames" },
    { 0xCF35, "tutorial_getallynodes" },
    { 0xCF36, "tutorial_getallyreadylines" },
    { 0xCF37, "tutorial_getallyreplylines" },
    { 0xCF38, "tutorial_getanimationorigin" },
    { 0xCF39, "tutorial_getfarahcommandallylines" },
    { 0xCF3A, "tutorial_getprimarytarget" },
    { 0xCF3B, "tutorial_getsecondarytarget" },
    { 0xCF3C, "tutorial_getsignalally" },
    { 0xCF3D, "tutorial_getsniperbench" },
    { 0xCF3E, "tutorial_goprone" },
    { 0xCF3F, "tutorial_interaction" },
    { 0xCF40, "tutorial_interaction_1" },
    { 0xCF41, "tutorial_interaction_2" },
    { 0xCF42, "tutorial_lookup_func" },
    { 0xCF43, "tutorial_main" },
    { 0xCF44, "tutorial_message_table" },
    { 0xCF45, "tutorial_placetargetdialoguelogic" },
    { 0xCF46, "tutorial_placetargetlogic" },
    { 0xCF47, "tutorial_primarytargetaim" },
    { 0xCF48, "tutorial_primarytargetaimgravity" },
    { 0xCF49, "tutorial_primarytargetaimwind" },
    { 0xCF4A, "tutorial_primarytargetlogic" },
    { 0xCF4B, "tutorial_primarytargetmiss" },
    { 0xCF4C, "tutorial_secondaryaim" },
    { 0xCF4D, "tutorial_secondarylookatbuilding" },
    { 0xCF4E, "tutorial_secondarytargetlogic" },
    { 0xCF4F, "tutorial_secondarytargetlookat" },
    { 0xCF50, "tutorial_secondarytargetmisslogic" },
    { 0xCF51, "tutorial_setalliesnames" },
    { 0xCF52, "tutorial_signalallylogic" },
    { 0xCF53, "tutorial_spawnallies" },
    { 0xCF54, "tutorial_spawnprimarytarget" },
    { 0xCF55, "tutorial_start" },
    { 0xCF56, "tutorial_timeout_check" },
    { 0xCF57, "tutorial_zoomin" },
    { 0xCF58, "tutorialprint" },
    { 0xCF59, "tv_image" },
    { 0xCF5A, "tv_station_bomb_defusal_success_func" },
    { 0xCF5B, "tv_station_spawning" },
    { 0xCF5C, "tvs" },
    { 0xCF5D, "tweakablesinitialized" },
    { 0xCF5E, "tweakedbyplayerduringmatch" },
    { 0xCF5F, "tweakfile" },
    { 0xCF60, "twelfthfloorturret" },
    { 0xCF61, "twister_array_zombie" },
    { 0xCF62, "twister_sfx" },
    { 0xCF63, "two_color" },
    { 0xCF64, "type_off" },
    { 0xCF65, "type_on" },
    { 0xCF66, "type_run" },
    { 0xCF67, "type_specific" },
    { 0xCF68, "typecast_kvps" },
    { 0xCF69, "typeid" },
    { 0xCF6A, "typelimited" },
    { 0xCF6B, "typeorig" },
    { 0xCF6C, "typeref" },
    { 0xCF6D, "types" },
    { 0xCF6E, "u_buttons" },
    { 0xCF6F, "u_buttons_disable" },
    { 0xCF70, "uav" },
    { 0xCF71, "uavbeginuse" },
    { 0xCF72, "uavblocktime" },
    { 0xCF73, "uavmodels" },
    { 0xCF74, "uavremotemarkedby" },
    { 0xCF75, "uavrig" },
    { 0xCF76, "uavrigslow" },
    { 0xCF77, "uavrotationorigin" },
    { 0xCF78, "uavsettings" },
    { 0xCF79, "uavtracker" },
    { 0xCF7A, "uavtype" },
    { 0xCF7B, "ugvs" },
    { 0xCF7C, "ui_action_slot_force_active_off" },
    { 0xCF7D, "ui_action_slot_force_active_on" },
    { 0xCF7E, "ui_action_slot_force_active_one_time" },
    { 0xCF7F, "ui_bg_images_2d" },
    { 0xCF80, "ui_bomb_planting_defusing" },
    { 0xCF81, "ui_ctf_securing" },
    { 0xCF82, "ui_ctf_stalemate" },
    { 0xCF83, "ui_dom_securing" },
    { 0xCF84, "ui_dom_stalemate" },
    { 0xCF85, "ui_hudhidden" },
    { 0xCF86, "ui_securing" },
    { 0xCF87, "ui_string_index" },
    { 0xCF88, "ui_updatebombtimer" },
    { 0xCF89, "ui_updatecmdcapturestatus" },
    { 0xCF8A, "ui_updatecmdholdprogress" },
    { 0xCF8B, "ui_updatecmdownerteam" },
    { 0xCF8C, "ui_updatecmdprogress" },
    { 0xCF8D, "ui_updatezonetimer" },
    { 0xCF8E, "ui_updatezonetimerpausedness" },
    { 0xCF8F, "uiobjectivehide" },
    { 0xCF90, "uiobjectivehidefromteam" },
    { 0xCF91, "uiobjectivesetparameter" },
    { 0xCF92, "uiobjectiveshow" },
    { 0xCF93, "uiobjectiveshowtoteam" },
    { 0xCF94, "uiparent" },
    { 0xCF95, "uitype" },
    { 0xCF96, "umike_cam_shake_ground" },
    { 0xCF97, "umike_damage_watcher" },
    { 0xCF98, "umike_get_length" },
    { 0xCF99, "umike_init" },
    { 0xCF9A, "umike_spawn" },
    { 0xCF9B, "unable_to_trigger_radius_detection_monitor" },
    { 0xCF9C, "unarchived" },
    { 0xCF9D, "unarmed" },
    { 0xCF9E, "unarmed_enemy_check" },
    { 0xCF9F, "unarmed_responses" },
    { 0xCFA0, "unarmedkilled" },
    { 0xCFA1, "unarmedmeleedamageoverride" },
    { 0xCFA2, "unblock_player" },
    { 0xCFA3, "unblockarea" },
    { 0xCFA4, "unblockentsinarea" },
    { 0xCFA5, "unblockperkfunction" },
    { 0xCFA6, "uncapturableobjectives" },
    { 0xCFA7, "unclaimsmartobject" },
    { 0xCFA8, "uncommon" },
    { 0xCFA9, "under_bridge_enemies_attack_logic" },
    { 0xCFAA, "under_bridge_enemy_attack_logic" },
    { 0xCFAB, "under_damped_move_to" },
    { 0xCFAC, "under_damped_move_to_thread" },
    { 0xCFAD, "under_vehicle_trigger" },
    { 0xCFAE, "underbridge_enemy_death_monitor" },
    { 0xCFAF, "underbridge_enemy_monitor" },
    { 0xCFB0, "underground_rescue_right" },
    { 0xCFB1, "underlowcover" },
    { 0xCFB2, "underwater" },
    { 0xCFB3, "unfreeze_all_players_control" },
    { 0xCFB4, "unfreeze_zombie" },
    { 0xCFB5, "unfreezecontrols" },
    { 0xCFB6, "unfreezecontrolsonroundend" },
    { 0xCFB7, "unfreezeonroundend" },
    { 0xCFB8, "unhighlightent" },
    { 0xCFB9, "unidentified_ieds" },
    { 0xCFBA, "unidentified_zone_vfxs" },
    { 0xCFBB, "unimogsnatch" },
    { 0xCFBC, "unimogtest" },
    { 0xCFBD, "uninit_drone_vo" },
    { 0xCFBE, "unique_id" },
    { 0xCFBF, "uniqueid" },
    { 0xCFC0, "uniqueinstanceid" },
    { 0xCFC1, "uniqueplayersconnected" },
    { 0xCFC2, "unittype_spawn_functions" },
    { 0xCFC3, "universal_input_loop" },
    { 0xCFC4, "unlimited_ammo" },
    { 0xCFC5, "unlimitedammo" },
    { 0xCFC6, "unlimitedmunitions" },
    { 0xCFC7, "unlink_and_travel_with_vehicle" },
    { 0xCFC8, "unlink_from_barkov" },
    { 0xCFC9, "unlink_on_use" },
    { 0xCFCA, "unlink_player_after_boots" },
    { 0xCFCB, "unlink_player_from_rig" },
    { 0xCFCC, "unlink_player_from_rig_after_anim" },
    { 0xCFCD, "unlink_player_from_rig_free_look" },
    { 0xCFCE, "unlink_player_from_rig_lab" },
    { 0xCFCF, "unlink_player_from_set_rig" },
    { 0xCFD0, "unlinknextframe" },
    { 0xCFD1, "unlit_models" },
    { 0xCFD2, "unload_at_target" },
    { 0xCFD3, "unload_embassy_load_anims" },
    { 0xCFD4, "unload_fx_func" },
    { 0xCFD5, "unload_group" },
    { 0xCFD6, "unload_groups" },
    { 0xCFD7, "unload_groups_rebel" },
    { 0xCFD8, "unload_hover_land_height" },
    { 0xCFD9, "unload_hover_offset" },
    { 0xCFDA, "unload_hover_offset_max" },
    { 0xCFDB, "unload_land_offset" },
    { 0xCFDC, "unload_loopanim" },
    { 0xCFDD, "unload_monitor" },
    { 0xCFDE, "unload_node" },
    { 0xCFDF, "unload_nodes" },
    { 0xCFE0, "unload_ondeath" },
    { 0xCFE1, "unload_relics_via_dvar" },
    { 0xCFE2, "unload_time" },
    { 0xCFE3, "unload_when_near_players" },
    { 0xCFE4, "unloaddelay" },
    { 0xCFE5, "unloaded_func" },
    { 0xCFE6, "unloaded_passengers" },
    { 0xCFE7, "unloadgroups" },
    { 0xCFE8, "unloading" },
    { 0xCFE9, "unloading_func" },
    { 0xCFEA, "unloading_passengers" },
    { 0xCFEB, "unloadque" },
    { 0xCFEC, "unlock" },
    { 0xCFED, "unlock_all_doors" },
    { 0xCFEE, "unlock_all_doors_except_arena" },
    { 0xCFEF, "unlock_door" },
    { 0xCFF0, "unlock_pap_and_ww" },
    { 0xCFF1, "unlock_player_intel" },
    { 0xCFF2, "unlock_thread" },
    { 0xCFF3, "unlock_volume" },
    { 0xCFF4, "unlock_volume_logic" },
    { 0xCFF5, "unlock_wait" },
    { 0xCFF6, "unlockedelevator" },
    { 0xCFF7, "unmark" },
    { 0xCFF8, "unmark_enemies" },
    { 0xCFF9, "unmark_kidnapper_target" },
    { 0xCFFA, "unmark_player_as_sniper_target" },
    { 0xCFFB, "unmark_selected_terrorist_respawner" },
    { 0xCFFC, "unmark_vehicle_as_friendly_target_group" },
    { 0xCFFD, "unmarkafterduration" },
    { 0xCFFE, "unmarkenemytarget" },
    { 0xCFFF, "unmarkent" },
    { 0xD000, "unmarkonownershipchange" },
    { 0xD001, "unmatched_death_rig_light_waits_for_lights_off" },
    { 0xD002, "unorientedboxpoints" },
    { 0xD003, "unpause_all_other_groups" },
    { 0xD004, "unpause_group_by_group_name" },
    { 0xD005, "unpause_group_by_id" },
    { 0xD006, "unpause_vo_system" },
    { 0xD007, "unregister_all_vo_sources" },
    { 0xD008, "unregister_vo_source" },
    { 0xD009, "unregistersentient" },
    { 0xD00A, "unregisterweaponchangecallback" },
    { 0xD00B, "unresolved_collision_count" },
    { 0xD00C, "unresolved_collision_damage" },
    { 0xD00D, "unresolved_collision_func" },
    { 0xD00E, "unresolved_collision_kill" },
    { 0xD00F, "unresolved_collision_mover" },
    { 0xD010, "unresolved_collision_nearest_node" },
    { 0xD011, "unresolved_collision_nodes" },
    { 0xD012, "unresolved_collision_notify_min" },
    { 0xD013, "unresolved_collision_owner_damage" },
    { 0xD014, "unresolved_collision_void" },
    { 0xD015, "unruly" },
    { 0xD016, "unrulyrate" },
    { 0xD017, "unrulystart" },
    { 0xD018, "unset" },
    { 0xD019, "unset_ai_events" },
    { 0xD01A, "unset_all_locations" },
    { 0xD01B, "unset_berserk" },
    { 0xD01C, "unset_consumable" },
    { 0xD01D, "unset_demeanor_on_weapon_change" },
    { 0xD01E, "unset_extra_xp" },
    { 0xD01F, "unset_forcegoal" },
    { 0xD020, "unset_func" },
    { 0xD021, "unset_headshot_ammo" },
    { 0xD022, "unset_headshot_super" },
    { 0xD023, "unset_outline" },
    { 0xD024, "unset_outline_for_player" },
    { 0xD025, "unset_outline_passive_minimap_damage" },
    { 0xD026, "unset_passive_below_the_belt" },
    { 0xD027, "unset_passive_berserk" },
    { 0xD028, "unset_passive_cold_damage" },
    { 0xD029, "unset_passive_crouch_move_speed" },
    { 0xD02A, "unset_passive_double_kill_reload" },
    { 0xD02B, "unset_passive_double_kill_super" },
    { 0xD02C, "unset_passive_empty_reload_speed" },
    { 0xD02D, "unset_passive_fast_melee" },
    { 0xD02E, "unset_passive_fortified" },
    { 0xD02F, "unset_passive_gore" },
    { 0xD030, "unset_passive_health_on_kill" },
    { 0xD031, "unset_passive_health_regen_on_kill" },
    { 0xD032, "unset_passive_hitman" },
    { 0xD033, "unset_passive_hunter_killer" },
    { 0xD034, "unset_passive_increased_scope_breath" },
    { 0xD035, "unset_passive_infinite_ammo" },
    { 0xD036, "unset_passive_jump_super" },
    { 0xD037, "unset_passive_last_shots_ammo" },
    { 0xD038, "unset_passive_melee_cone_expl" },
    { 0xD039, "unset_passive_melee_kill" },
    { 0xD03A, "unset_passive_melee_super" },
    { 0xD03B, "unset_passive_minimap_damage" },
    { 0xD03C, "unset_passive_miss_refund" },
    { 0xD03D, "unset_passive_mode_switch_score" },
    { 0xD03E, "unset_passive_move_speed" },
    { 0xD03F, "unset_passive_move_speed_on_kill" },
    { 0xD040, "unset_passive_ninja" },
    { 0xD041, "unset_passive_nuke" },
    { 0xD042, "unset_passive_railgun_overload" },
    { 0xD043, "unset_passive_random_attachment" },
    { 0xD044, "unset_passive_random_perks" },
    { 0xD045, "unset_passive_refresh" },
    { 0xD046, "unset_passive_scope_radar" },
    { 0xD047, "unset_passive_score_bonus_kills" },
    { 0xD048, "unset_passive_scorestreak_damage" },
    { 0xD049, "unset_passive_scoutping" },
    { 0xD04A, "unset_passive_scrambler" },
    { 0xD04B, "unset_passive_sonic" },
    { 0xD04C, "unset_passive_visor_detonation" },
    { 0xD04D, "unset_perk" },
    { 0xD04E, "unset_player_is_pushing_vehicle" },
    { 0xD04F, "unset_player_zoom_setting" },
    { 0xD050, "unset_pre_wave_spawning" },
    { 0xD051, "unset_relic_boom" },
    { 0xD052, "unset_relic_catch" },
    { 0xD053, "unset_relic_collat_dmg" },
    { 0xD054, "unset_relic_glasscannon" },
    { 0xD055, "unset_relic_swat" },
    { 0xD056, "unset_relics" },
    { 0xD057, "unset_scriptable_part_state_after_time" },
    { 0xD058, "unset_snap_to_head" },
    { 0xD059, "unset_suicide_bomber_call_back" },
    { 0xD05A, "unset_used_recently" },
    { 0xD05B, "unset_vo_currently_playing" },
    { 0xD05C, "unsetactivereload" },
    { 0xD05D, "unsetadsawareness" },
    { 0xD05E, "unsetadsmarktarget" },
    { 0xD05F, "unsetaffinityextralauncher" },
    { 0xD060, "unsetaffinityspeedboost" },
    { 0xD061, "unsetafterburner" },
    { 0xD062, "unsetalwaysminimap" },
    { 0xD063, "unsetarmorvest" },
    { 0xD064, "unsetassists" },
    { 0xD065, "unsetauraquickswap" },
    { 0xD066, "unsetauraspeed" },
    { 0xD067, "unsetautospot" },
    { 0xD068, "unsetballcarrier" },
    { 0xD069, "unsetbarrier" },
    { 0xD06A, "unsetbatterypack" },
    { 0xD06B, "unsetbattleslide" },
    { 0xD06C, "unsetbattleslideoffense" },
    { 0xD06D, "unsetbattleslideshield" },
    { 0xD06E, "unsetblackbox" },
    { 0xD06F, "unsetblastshield" },
    { 0xD070, "unsetblindeye" },
    { 0xD071, "unsetblockhealthregen" },
    { 0xD072, "unsetboom" },
    { 0xD073, "unsetbountyhunter" },
    { 0xD074, "unsetbreacher" },
    { 0xD075, "unsetbulletoutline" },
    { 0xD076, "unsetbulletstorm" },
    { 0xD077, "unsetcamoclone" },
    { 0xD078, "unsetcamoelite" },
    { 0xD079, "unsetcarepackage" },
    { 0xD07A, "unsetcloak" },
    { 0xD07B, "unsetcloakaerial" },
    { 0xD07C, "unsetcombathigh" },
    { 0xD07D, "unsetcombathighondeath" },
    { 0xD07E, "unsetcombathighonride" },
    { 0xD07F, "unsetcombatspeed" },
    { 0xD080, "unsetcombatspeedscalar" },
    { 0xD081, "unsetcomexp" },
    { 0xD082, "unsetcomlink" },
    { 0xD083, "unsetcooldown" },
    { 0xD084, "unsetcritchance" },
    { 0xD085, "unsetcustomjuiced" },
    { 0xD086, "unsetcustomjuicedondeath" },
    { 0xD087, "unsetcustomjuicedonmatchend" },
    { 0xD088, "unsetcustomjuicedonride" },
    { 0xD089, "unsetdash" },
    { 0xD08A, "unsetdelaymine" },
    { 0xD08B, "unsetdemolitions" },
    { 0xD08C, "unsetdisruptorpunch" },
    { 0xD08D, "unsetdodge" },
    { 0xD08E, "unsetdodgedefense" },
    { 0xD08F, "unsetdodgewave" },
    { 0xD090, "unsetdooralarm" },
    { 0xD091, "unsetdoorbreach" },
    { 0xD092, "unsetdoorsense" },
    { 0xD093, "unsetdoubleload" },
    { 0xD094, "unsetempimmune" },
    { 0xD095, "unsetendgame" },
    { 0xD096, "unsetengineer" },
    { 0xD097, "unsetenhancedsixthsense" },
    { 0xD098, "unsetequipmentping" },
    { 0xD099, "unsetextenddodge" },
    { 0xD09A, "unsetextraammo" },
    { 0xD09B, "unsetextradeadly" },
    { 0xD09C, "unsetextradodge" },
    { 0xD09D, "unsetextraequipment" },
    { 0xD09E, "unsetfastcrouch" },
    { 0xD09F, "unsetfastreloadlaunchers" },
    { 0xD0A0, "unsetfootprinteffect" },
    { 0xD0A1, "unsetfootstepeffect" },
    { 0xD0A2, "unsetfootstepeffectsmall" },
    { 0xD0A3, "unsetfreefall" },
    { 0xD0A4, "unsetftlslide" },
    { 0xD0A5, "unsetfunc" },
    { 0xD0A6, "unsetgasgrenaderesist" },
    { 0xD0A7, "unsetghost" },
    { 0xD0A8, "unsetgroundpound" },
    { 0xD0A9, "unsetgroundpoundboost" },
    { 0xD0AA, "unsetgroundpoundshield" },
    { 0xD0AB, "unsetgroundpoundshock" },
    { 0xD0AC, "unsethardline" },
    { 0xD0AD, "unsethardshell" },
    { 0xD0AE, "unsetheadgear" },
    { 0xD0AF, "unsethealer" },
    { 0xD0B0, "unsethelmet" },
    { 0xD0B1, "unsethover" },
    { 0xD0B2, "unsethunter" },
    { 0xD0B3, "unsetimprovedmelee" },
    { 0xD0B4, "unsetimprovedprone" },
    { 0xD0B5, "unsetincog" },
    { 0xD0B6, "unsetintel" },
    { 0xD0B7, "unsetjuiced" },
    { 0xD0B8, "unsetjuicedondeath" },
    { 0xD0B9, "unsetjuicedonmatchend" },
    { 0xD0BA, "unsetjuicedonride" },
    { 0xD0BB, "unsetkillstreaktoscorestreak" },
    { 0xD0BC, "unsetkineticpulse" },
    { 0xD0BD, "unsetkineticwave" },
    { 0xD0BE, "unsetladder" },
    { 0xD0BF, "unsetlifepack" },
    { 0xD0C0, "unsetlightarmor" },
    { 0xD0C1, "unsetlightweight" },
    { 0xD0C2, "unsetlocaljammer" },
    { 0xD0C3, "unsetlocationmarking" },
    { 0xD0C4, "unsetmanatarms" },
    { 0xD0C5, "unsetmarkequipment" },
    { 0xD0C6, "unsetmarksman" },
    { 0xD0C7, "unsetmarktargets" },
    { 0xD0C8, "unsetmeleekill" },
    { 0xD0C9, "unsetmomentum" },
    { 0xD0CA, "unsetmortarmount" },
    { 0xD0CB, "unsetmunitions" },
    { 0xD0CC, "unsetnoscopeoutline" },
    { 0xD0CD, "unsetoffhandprovider" },
    { 0xD0CE, "unsetonemanarmy" },
    { 0xD0CF, "unsetopticwave" },
    { 0xD0D0, "unsetoutlinekillstreaks" },
    { 0xD0D1, "unsetovercharge" },
    { 0xD0D2, "unsetoverclock" },
    { 0xD0D3, "unsetoverkill" },
    { 0xD0D4, "unsetoverkillpro" },
    { 0xD0D5, "unsetoverrideweaponspeed" },
    { 0xD0D6, "unsetpersonaltrophy" },
    { 0xD0D7, "unsetphasefall" },
    { 0xD0D8, "unsetphaseshift" },
    { 0xD0D9, "unsetphaseslashrephase" },
    { 0xD0DA, "unsetphaseslide" },
    { 0xD0DB, "unsetphasespeed" },
    { 0xD0DC, "unsetphasesplit" },
    { 0xD0DD, "unsetpitcher" },
    { 0xD0DE, "unsetpowercell" },
    { 0xD0DF, "unsetquadfeederpassive" },
    { 0xD0E0, "unsetquickswap" },
    { 0xD0E1, "unsetrearguard" },
    { 0xD0E2, "unsetrechargeequipment" },
    { 0xD0E3, "unsetreduceregendelay" },
    { 0xD0E4, "unsetreduceregendelayonobjective" },
    { 0xD0E5, "unsetrefillammo" },
    { 0xD0E6, "unsetrefillgrenades" },
    { 0xD0E7, "unsetreflectshield" },
    { 0xD0E8, "unsetregenfaster" },
    { 0xD0E9, "unsetremotedefuse" },
    { 0xD0EA, "unsetrevenge" },
    { 0xD0EB, "unsetreviveuseweapon" },
    { 0xD0EC, "unsetrewind" },
    { 0xD0ED, "unsetrshieldradar" },
    { 0xD0EE, "unsetrshieldscrambler" },
    { 0xD0EF, "unsetruggedeqp" },
    { 0xD0F0, "unsetrush" },
    { 0xD0F1, "unsetsaboteur" },
    { 0xD0F2, "unsetscavengereqp" },
    { 0xD0F3, "unsetscorestreakpack" },
    { 0xD0F4, "unsetscoutping" },
    { 0xD0F5, "unsetscrambler" },
    { 0xD0F6, "unsetscrapweapons" },
    { 0xD0F7, "unsetsharpfocus" },
    { 0xD0F8, "unsetsiegemode" },
    { 0xD0F9, "unsetsixthsense" },
    { 0xD0FA, "unsetslowmovementaftertime" },
    { 0xD0FB, "unsetsmokewall" },
    { 0xD0FC, "unsetsolobuddyboost" },
    { 0xD0FD, "unsetsonicpulse" },
    { 0xD0FE, "unsetspawncloak" },
    { 0xD0FF, "unsetspawnradar" },
    { 0xD100, "unsetspawnview" },
    { 0xD101, "unsetspeedboost" },
    { 0xD102, "unsetspotter" },
    { 0xD103, "unsetsteadyaimpro" },
    { 0xD104, "unsetstealth" },
    { 0xD105, "unsetsteelnerves" },
    { 0xD106, "unsetstunresistance" },
    { 0xD107, "unsetsuperpack" },
    { 0xD108, "unsetsupersprintenhanced" },
    { 0xD109, "unsetsupport" },
    { 0xD10A, "unsetsupportkillstreaks" },
    { 0xD10B, "unsetsurvivor" },
    { 0xD10C, "unsettacticalinsertion" },
    { 0xD10D, "unsettagger" },
    { 0xD10E, "unsettank" },
    { 0xD10F, "unsetteleport" },
    { 0xD110, "unsettelereap" },
    { 0xD111, "unsetteleslide" },
    { 0xD112, "unsetthermal" },
    { 0xD113, "unsetthief" },
    { 0xD114, "unsetthrowingknifemelee" },
    { 0xD115, "unsetthruster" },
    { 0xD116, "unsettoughenup" },
    { 0xD117, "unsettracker" },
    { 0xD118, "unsettransponder" },
    { 0xD119, "unsettriggerhappy" },
    { 0xD11A, "unsetuav" },
    { 0xD11B, "unsetviewkickoverride" },
    { 0xD11C, "unsetwalllock" },
    { 0xD11D, "unsetweaponlaser" },
    { 0xD11E, "unsetworsenedgunkick" },
    { 0xD11F, "unshow_terrorist_respawner" },
    { 0xD120, "unspotplayer" },
    { 0xD121, "unstowsuperweapon" },
    { 0xD122, "untrackbuffassist" },
    { 0xD123, "untrackdebuffassist" },
    { 0xD124, "up_offset_from_tag_origin" },
    { 0xD125, "up_point_valid" },
    { 0xD126, "upangles" },
    { 0xD127, "update" },
    { 0xD128, "update_achievement" },
    { 0xD129, "update_achievement_all_players" },
    { 0xD12A, "update_achievement_arcade" },
    { 0xD12B, "update_achievement_braindead" },
    { 0xD12C, "update_agent_damage_performance" },
    { 0xD12D, "update_alien_damage_performance" },
    { 0xD12E, "update_alien_kill_sessionstats" },
    { 0xD12F, "update_anim_phase_debug" },
    { 0xD130, "update_arena_char_loc" },
    { 0xD131, "update_battlechatter_hud" },
    { 0xD132, "update_bcs_locations" },
    { 0xD133, "update_bomb_objective" },
    { 0xD134, "update_boss_vo_context" },
    { 0xD135, "update_breadcrumb_for_player" },
    { 0xD136, "update_camera_depth_of_field" },
    { 0xD137, "update_camera_depth_of_field_slowly" },
    { 0xD138, "update_challenges_status" },
    { 0xD139, "update_char_loc" },
    { 0xD13A, "update_character_pos" },
    { 0xD13B, "update_color_nodes" },
    { 0xD13C, "update_computer_hint" },
    { 0xD13D, "update_conditions" },
    { 0xD13E, "update_crash_locations" },
    { 0xD13F, "update_current_count" },
    { 0xD140, "update_current_count_death" },
    { 0xD141, "update_current_health_regen_segment" },
    { 0xD142, "update_damage_score" },
    { 0xD143, "update_deathflag" },
    { 0xD144, "update_debug_friendlycolor" },
    { 0xD145, "update_debug_friendlycolor_on_death" },
    { 0xD146, "update_demolition_attackers" },
    { 0xD147, "update_demolition_defenders" },
    { 0xD148, "update_depends" },
    { 0xD149, "update_deployable_box_performance" },
    { 0xD14A, "update_deployable_box_performance_func" },
    { 0xD14B, "update_dialogue_huds" },
    { 0xD14C, "update_driver_interaction_hint" },
    { 0xD14D, "update_dropped_weapon_priorities" },
    { 0xD14E, "update_encounter_performance_internal" },
    { 0xD14F, "update_enemy_target_pos_while_running" },
    { 0xD150, "update_enemy_visualization_for_entering_reaper" },
    { 0xD151, "update_enemy_visualization_for_exiting_reaper" },
    { 0xD152, "update_entities_and_camera" },
    { 0xD153, "update_eog_totals_for_stat_ref" },
    { 0xD154, "update_event_dists" },
    { 0xD155, "update_every_frame" },
    { 0xD156, "update_facing_angles" },
    { 0xD157, "update_floor_enemy_info" },
    { 0xD158, "update_focus_counter" },
    { 0xD159, "update_game_ctf" },
    { 0xD15A, "update_game_demolition" },
    { 0xD15B, "update_gamer_profile" },
    { 0xD15C, "update_global_offhand_boxes" },
    { 0xD15D, "update_highest_wave_lb" },
    { 0xD15E, "update_hostages_objectives" },
    { 0xD15F, "update_humanoid_death_challenges" },
    { 0xD160, "update_laststand_times" },
    { 0xD161, "update_lb_aliensession_challenge" },
    { 0xD162, "update_lb_aliensession_escape" },
    { 0xD163, "update_lb_aliensession_wave" },
    { 0xD164, "update_leads_timer" },
    { 0xD165, "update_light_meter" },
    { 0xD166, "update_lmg" },
    { 0xD167, "update_lobby_char_loc" },
    { 0xD168, "update_lookat_delays" },
    { 0xD169, "update_lookat_status" },
    { 0xD16A, "update_lookat_weights" },
    { 0xD16B, "update_lua_consumable_slot" },
    { 0xD16C, "update_lua_inventory_slot" },
    { 0xD16D, "update_main_menu_char_loc" },
    { 0xD16E, "update_max_players_from_team_agents" },
    { 0xD16F, "update_missile_lock_hud_for_missile_defense_player" },
    { 0xD170, "update_money_earned_performance" },
    { 0xD171, "update_money_performance" },
    { 0xD172, "update_nav" },
    { 0xD173, "update_nvg_light" },
    { 0xD174, "update_objective" },
    { 0xD175, "update_objective_icon" },
    { 0xD176, "update_objective_marker_when_close" },
    { 0xD177, "update_objective_onentity" },
    { 0xD178, "update_objective_onentitywithrotation" },
    { 0xD179, "update_objective_ownerteam" },
    { 0xD17A, "update_objective_position" },
    { 0xD17B, "update_objective_setbackground" },
    { 0xD17C, "update_objective_setenemylabel" },
    { 0xD17D, "update_objective_setfriendlylabel" },
    { 0xD17E, "update_objective_sethot" },
    { 0xD17F, "update_objective_setneutrallabel" },
    { 0xD180, "update_objective_setzoffset" },
    { 0xD181, "update_objective_state" },
    { 0xD182, "update_offhand_box_item_models" },
    { 0xD183, "update_pent_hintstring" },
    { 0xD184, "update_pents_from_volumes" },
    { 0xD185, "update_pents_global" },
    { 0xD186, "update_performance_zombie_damage" },
    { 0xD187, "update_personal_encounter_performance" },
    { 0xD188, "update_personality_camper" },
    { 0xD189, "update_personality_default" },
    { 0xD18A, "update_player_attacker_accuracy" },
    { 0xD18B, "update_player_career_highest_wave" },
    { 0xD18C, "update_player_character_showcase" },
    { 0xD18D, "update_player_model" },
    { 0xD18E, "update_player_session_rankup" },
    { 0xD18F, "update_player_threat" },
    { 0xD190, "update_players_career_highest_wave" },
    { 0xD191, "update_players_encounter_performance" },
    { 0xD192, "update_players_revive_progress_bar" },
    { 0xD193, "update_progress" },
    { 0xD194, "update_respawners_vfx" },
    { 0xD195, "update_rumble_intensity" },
    { 0xD196, "update_sas_names" },
    { 0xD197, "update_script_demeanor_for_all_spawners_in_group" },
    { 0xD198, "update_scripternote_huds" },
    { 0xD199, "update_scripternote_width" },
    { 0xD19A, "update_searchlight_facing" },
    { 0xD19B, "update_selected_entities" },
    { 0xD19C, "update_spawn_data_on_death" },
    { 0xD19D, "update_spawn_data_on_spawn" },
    { 0xD19E, "update_special_mode_for_all_players" },
    { 0xD19F, "update_special_mode_for_player" },
    { 0xD1A0, "update_spending_type" },
    { 0xD1A1, "update_state" },
    { 0xD1A2, "update_state_machine" },
    { 0xD1A3, "update_stealth_spotted_thread" },
    { 0xD1A4, "update_steering" },
    { 0xD1A5, "update_struct_information" },
    { 0xD1A6, "update_super_icon" },
    { 0xD1A7, "update_suppression_value" },
    { 0xD1A8, "update_target_health_variable" },
    { 0xD1A9, "update_target_marker_group_id_on_ied" },
    { 0xD1AA, "update_target_offset" },
    { 0xD1AB, "update_target_player" },
    { 0xD1AC, "update_team_encounter_performance" },
    { 0xD1AD, "update_team_multiplier" },
    { 0xD1AE, "update_technical_speed_scale" },
    { 0xD1AF, "update_tickets_earned_performance" },
    { 0xD1B0, "update_time" },
    { 0xD1B1, "update_total_slots" },
    { 0xD1B2, "update_trap_placement_internal" },
    { 0xD1B3, "update_trigger_based_on_flags" },
    { 0xD1B4, "update_turret_investigate_pos" },
    { 0xD1B5, "update_turret_pointer" },
    { 0xD1B6, "update_ui_timers" },
    { 0xD1B7, "update_vehicle_objective_visibility" },
    { 0xD1B8, "update_vfx_shadow_limit" },
    { 0xD1B9, "update_vip_trigger" },
    { 0xD1BA, "update_visionsetnight_for_nvg_type" },
    { 0xD1BB, "update_wait_for_repeating_event" },
    { 0xD1BC, "update_weapon_loc" },
    { 0xD1BD, "update_weaponstats" },
    { 0xD1BE, "update_weaponstats_hits" },
    { 0xD1BF, "update_weaponstats_kills" },
    { 0xD1C0, "update_weaponstats_shots" },
    { 0xD1C1, "update_wolf_face_position" },
    { 0xD1C2, "update_zombie_damage_challenge" },
    { 0xD1C3, "updateactiveperks" },
    { 0xD1C4, "updateactivespectatorcounts" },
    { 0xD1C5, "updateactivesupers" },
    { 0xD1C6, "updateaisightonplayer" },
    { 0xD1C7, "updatealarmpromptsvisibilityforplayer" },
    { 0xD1C8, "updatealarmpromptvisibility" },
    { 0xD1C9, "updatealiveomnvars" },
    { 0xD1CA, "updateall" },
    { 0xD1CB, "updatealldifficulty" },
    { 0xD1CC, "updatealldoorsalarmvisibilityforplayer" },
    { 0xD1CD, "updatealldoorslockvisibilityforplayer" },
    { 0xD1CE, "updateallowedspawnareas" },
    { 0xD1CF, "updatealwayscoverexposed" },
    { 0xD1D0, "updateanimpose" },
    { 0xD1D1, "updateareanodes" },
    { 0xD1D2, "updatearenagungameloadout" },
    { 0xD1D3, "updatearmordroptimer" },
    { 0xD1D4, "updatearmorgesturefastblendout" },
    { 0xD1D5, "updatearmorui" },
    { 0xD1D6, "updatearmorvestcancel" },
    { 0xD1D7, "updatearmorvestmodel" },
    { 0xD1D8, "updatearmorvestui" },
    { 0xD1D9, "updateassassinationhud" },
    { 0xD1DA, "updateattachedweaponmodels" },
    { 0xD1DB, "updateballtimerpausedness" },
    { 0xD1DC, "updatebar" },
    { 0xD1DD, "updatebarscale" },
    { 0xD1DE, "updatebethud" },
    { 0xD1DF, "updatebetplayerfocus" },
    { 0xD1E0, "updateblinkinglight" },
    { 0xD1E1, "updatebombplantedomnvar" },
    { 0xD1E2, "updatebombsiteusability" },
    { 0xD1E3, "updatebpm" },
    { 0xD1E4, "updatebrscoreboardstat" },
    { 0xD1E5, "updatebudget" },
    { 0xD1E6, "updatebufferedstats" },
    { 0xD1E7, "updatec130pathomnvars" },
    { 0xD1E8, "updatecalloutdata" },
    { 0xD1E9, "updatecamoeliteoverlay" },
    { 0xD1EA, "updatecamoscripts" },
    { 0xD1EB, "updatecapsperminute" },
    { 0xD1EC, "updatecapturebrush" },
    { 0xD1ED, "updatecarryobjectorigin" },
    { 0xD1EE, "updatecarryremoteuavplacement" },
    { 0xD1EF, "updatechargeui" },
    { 0xD1F0, "updatechatter" },
    { 0xD1F1, "updatechevrons" },
    { 0xD1F2, "updatechildren" },
    { 0xD1F3, "updatecirclehide" },
    { 0xD1F4, "updatecombat" },
    { 0xD1F5, "updatecombatrecordkillstats" },
    { 0xD1F6, "updatecombatspeedscalar" },
    { 0xD1F7, "updatecommongametypedvars" },
    { 0xD1F8, "updatecompassicon" },
    { 0xD1F9, "updatecompassicons" },
    { 0xD1FA, "updatecontact" },
    { 0xD1FB, "updatecontextualwallpromptforplayer" },
    { 0xD1FC, "updatecontextuawalltraversals" },
    { 0xD1FD, "updatecountdownhudlist" },
    { 0xD1FE, "updatecovercroucharrivaltype" },
    { 0xD1FF, "updatecpm" },
    { 0xD200, "updatecraftingomnvars" },
    { 0xD201, "updatecurorigin" },
    { 0xD202, "updatecurrentobjective" },
    { 0xD203, "updatecurrentoutput" },
    { 0xD204, "updatedamagefeedback" },
    { 0xD205, "updatedamageindicatortype" },
    { 0xD206, "updatedamagemultiplier" },
    { 0xD207, "updatedamageoverlay" },
    { 0xD208, "updatedeathdetails" },
    { 0xD209, "updatedeathsdoorvisionset" },
    { 0xD20A, "updatedefaultcamera" },
    { 0xD20B, "updatedefaultflinchreduction" },
    { 0xD20C, "updatedepends" },
    { 0xD20D, "updatedistance" },
    { 0xD20E, "updatedomscores" },
    { 0xD20F, "updatedoncontestedspawnselection" },
    { 0xD210, "updatedversion" },
    { 0xD211, "updateemitterpositions" },
    { 0xD212, "updateeveryframe" },
    { 0xD213, "updateeveryframe_civ_default" },
    { 0xD214, "updateeveryframe_civ_global" },
    { 0xD215, "updateeveryframe_global" },
    { 0xD216, "updateeveryframe_magicdoorchecks" },
    { 0xD217, "updateeveryframe_noncombat" },
    { 0xD218, "updateeveryframe_stealth" },
    { 0xD219, "updateexistingspectatorsofvictim" },
    { 0xD21A, "updateexposedatnodestate" },
    { 0xD21B, "updateextracticons" },
    { 0xD21C, "updateflagcapturestate" },
    { 0xD21D, "updateflagstate" },
    { 0xD21E, "updateflares" },
    { 0xD21F, "updatefloorbrush" },
    { 0xD220, "updatefloorbrushwaitforjoined" },
    { 0xD221, "updatefobspawnselection" },
    { 0xD222, "updatefrantic" },
    { 0xD223, "updatefreeplayedtime" },
    { 0xD224, "updatefreeplayertimes" },
    { 0xD225, "updatefriendicons" },
    { 0xD226, "updatefriendiconsettings" },
    { 0xD227, "updatefrontline" },
    { 0xD228, "updatefrontlinedebug" },
    { 0xD229, "updatefrontlineposition" },
    { 0xD22A, "updatefunc" },
    { 0xD22B, "updatefuncs" },
    { 0xD22C, "updategameevents" },
    { 0xD22D, "updategamemodecamera" },
    { 0xD22E, "updategamemodespawncamera" },
    { 0xD22F, "updategameon" },
    { 0xD230, "updategameskill" },
    { 0xD231, "updategametypedvars" },
    { 0xD232, "updategiveuponsuppressiontimer" },
    { 0xD233, "updategroups" },
    { 0xD234, "updatehackdefenselabel" },
    { 0xD235, "updatehide" },
    { 0xD236, "updatehighinfilscore" },
    { 0xD237, "updatehighpriorityweapons" },
    { 0xD238, "updatehitmarker" },
    { 0xD239, "updatehqaliveomnvars" },
    { 0xD23A, "updatehunterkillerplayer" },
    { 0xD23B, "updatehunterkillerplayers" },
    { 0xD23C, "updatehvtenemyteamusable" },
    { 0xD23D, "updateifgreaterthan_zombiecareerstats" },
    { 0xD23E, "updateinfiniteammopassive" },
    { 0xD23F, "updateinflictorstat" },
    { 0xD240, "updateinputtypewatcher" },
    { 0xD241, "updateinstantclassswapallowed" },
    { 0xD242, "updateinteractionstructpositions" },
    { 0xD243, "updateisincombattimer" },
    { 0xD244, "updatejuggcrateobjectivestate" },
    { 0xD245, "updatejuggcurorigin" },
    { 0xD246, "updatejuggpingorigin" },
    { 0xD247, "updatekillstreakselectedui" },
    { 0xD248, "updatekillstreakuislot" },
    { 0xD249, "updatekillstreakuislots" },
    { 0xD24A, "updateknivesperminute" },
    { 0xD24B, "updatelaserangles" },
    { 0xD24C, "updatelaserstatus" },
    { 0xD24D, "updatelaststandpistol" },
    { 0xD24E, "updatelastweapon" },
    { 0xD24F, "updatelastweaponobj" },
    { 0xD250, "updatelauncherusage" },
    { 0xD251, "updateleaderboardstatmaximum" },
    { 0xD252, "updateleaderboardstats" },
    { 0xD253, "updateleaderboardstatscontinuous" },
    { 0xD254, "updatelightbasedflashlight" },
    { 0xD255, "updatelightmeter" },
    { 0xD256, "updatelinkedoriginandangles" },
    { 0xD257, "updateloadoutarray" },
    { 0xD258, "updateloadoutselect" },
    { 0xD259, "updatelocaleplayerlist" },
    { 0xD25A, "updatelocklight" },
    { 0xD25B, "updatelockpromptvisibility" },
    { 0xD25C, "updatelockpromptvisibilityforplayer" },
    { 0xD25D, "updatelooktarget" },
    { 0xD25E, "updatelossstats" },
    { 0xD25F, "updatelowermessage" },
    { 0xD260, "updatemarker" },
    { 0xD261, "updatematchbonusscores" },
    { 0xD262, "updatematchhasmorethan1playeromnvaronplayerdisconnect" },
    { 0xD263, "updatematchhasmorethan1playeromnvaronplayersfirstspawn" },
    { 0xD264, "updatematchqueuepositions" },
    { 0xD265, "updatematchstatushintforallplayers" },
    { 0xD266, "updatematchstatushintonspawn" },
    { 0xD267, "updatematchstatushintonspawncommon" },
    { 0xD268, "updatematchtimerhud" },
    { 0xD269, "updatememberstates" },
    { 0xD26A, "updatemerits" },
    { 0xD26B, "updateminimapsetting" },
    { 0xD26C, "updatemissilefire" },
    { 0xD26D, "updatemlgspectator" },
    { 0xD26E, "updatemovespeedonweaponchange" },
    { 0xD26F, "updatemovespeedscale" },
    { 0xD270, "updatenavobstacle" },
    { 0xD271, "updatenodelookpeek" },
    { 0xD272, "updatenotify" },
    { 0xD273, "updateobjectiveicons" },
    { 0xD274, "updateobjectivetext" },
    { 0xD275, "updateondamagerelics" },
    { 0xD276, "updateondamagerelicsfunc" },
    { 0xD277, "updateonkillrelics" },
    { 0xD278, "updateonkillrelicsfunc" },
    { 0xD279, "updateonusepassivesfunc" },
    { 0xD27A, "updateoobtriggers" },
    { 0xD27B, "updateoobvisuals" },
    { 0xD27C, "updateorigin" },
    { 0xD27D, "updateoutlines" },
    { 0xD27E, "updateoverheadcamerapos" },
    { 0xD27F, "updateovertimescore" },
    { 0xD280, "updateownercallback" },
    { 0xD281, "updatepainbreathingsound" },
    { 0xD282, "updatepainvars" },
    { 0xD283, "updateparentratios" },
    { 0xD284, "updateparentratiosbuffered" },
    { 0xD285, "updatepassivecolddamage" },
    { 0xD286, "updatepassiveminimapdamage" },
    { 0xD287, "updatepersistentrelics" },
    { 0xD288, "updatepersistentrelicsfunc" },
    { 0xD289, "updatepetstatesincelastupdate" },
    { 0xD28A, "updatepickupicon" },
    { 0xD28B, "updateplacement" },
    { 0xD28C, "updateplantedarray" },
    { 0xD28D, "updateplayedtime" },
    { 0xD28E, "updateplayercombatstatus" },
    { 0xD28F, "updateplayerleaderboardstats" },
    { 0xD290, "updateplayerlocationcallouts" },
    { 0xD291, "updateplayerrecording" },
    { 0xD292, "updateplayersalivemessage" },
    { 0xD293, "updateplayersegmentdata" },
    { 0xD294, "updateplayerstatratio" },
    { 0xD295, "updateplayerstatratiobuffered" },
    { 0xD296, "updateplayersuavstatus" },
    { 0xD297, "updateplayertimes" },
    { 0xD298, "updateplayerwindmaterial" },
    { 0xD299, "updatequadfeedcounter" },
    { 0xD29A, "updaterandomloadout" },
    { 0xD29B, "updaterandomlooktarget" },
    { 0xD29C, "updaterank" },
    { 0xD29D, "updaterankannouncehud" },
    { 0xD29E, "updaterecentkills" },
    { 0xD29F, "updaterecentkillsrelics_func" },
    { 0xD2A0, "updatereduceregendelayonobjective" },
    { 0xD2A1, "updaterespawntimer" },
    { 0xD2A2, "updaterevivetriggerspawnposition" },
    { 0xD2A3, "updateroundendreasontext" },
    { 0xD2A4, "updatesavedaltstate" },
    { 0xD2A5, "updatesavedlastweapon" },
    { 0xD2A6, "updatescavengerui" },
    { 0xD2A7, "updatescavengeruiforplayer" },
    { 0xD2A8, "updatescoperadar" },
    { 0xD2A9, "updatescoremod" },
    { 0xD2AA, "updatescores" },
    { 0xD2AB, "updatescoutping" },
    { 0xD2AC, "updatescoutpingvalues" },
    { 0xD2AD, "updateselfvobonuschance" },
    { 0xD2AE, "updateselfvohistory" },
    { 0xD2AF, "updatesentryplacement" },
    { 0xD2B0, "updateservericons" },
    { 0xD2B1, "updateserversettings" },
    { 0xD2B2, "updatesessionstate" },
    { 0xD2B3, "updateshakeonplayer" },
    { 0xD2B4, "updatesharpfocus" },
    { 0xD2B5, "updateshotgroup" },
    { 0xD2B6, "updatesightstate" },
    { 0xD2B7, "updatesixthsensevfx" },
    { 0xD2B8, "updateslotitemcount" },
    { 0xD2B9, "updatesniperglint" },
    { 0xD2BA, "updatespawnareas" },
    { 0xD2BB, "updatespawnpoints" },
    { 0xD2BC, "updatespawnviewers" },
    { 0xD2BD, "updatespecialistui" },
    { 0xD2BE, "updatespectatesettings" },
    { 0xD2BF, "updatespectatorcamera" },
    { 0xD2C0, "updatespmstats" },
    { 0xD2C1, "updatesppercent" },
    { 0xD2C2, "updatesppm" },
    { 0xD2C3, "updatesquad" },
    { 0xD2C4, "updatesquadleadermovement" },
    { 0xD2C5, "updatesquadlist" },
    { 0xD2C6, "updatesquadomnvars" },
    { 0xD2C7, "updatesquadspawn" },
    { 0xD2C8, "updatestancetracking" },
    { 0xD2C9, "updatestate" },
    { 0xD2CA, "updatestreakcost" },
    { 0xD2CB, "updatestreakcosts" },
    { 0xD2CC, "updatestreakcount" },
    { 0xD2CD, "updatestreakmeterui" },
    { 0xD2CE, "updatestumble" },
    { 0xD2CF, "updatesuperkills" },
    { 0xD2D0, "updatesuperuistate" },
    { 0xD2D1, "updatesuperuithink" },
    { 0xD2D2, "updatesuperweaponkills" },
    { 0xD2D3, "updatetargetcurorigin" },
    { 0xD2D4, "updatetargethealthvariable" },
    { 0xD2D5, "updatetargetlocation" },
    { 0xD2D6, "updateteambalance" },
    { 0xD2D7, "updateteambalancedvar" },
    { 0xD2D8, "updateteamcallback" },
    { 0xD2D9, "updateteamplacement" },
    { 0xD2DA, "updateteamscore" },
    { 0xD2DB, "updateteamscores" },
    { 0xD2DC, "updateteamtime" },
    { 0xD2DD, "updateteamuavstatus" },
    { 0xD2DE, "updateteamuavtype" },
    { 0xD2DF, "updatetiestats" },
    { 0xD2E0, "updatetimer" },
    { 0xD2E1, "updatetimerconstant" },
    { 0xD2E2, "updatetimerpausedness" },
    { 0xD2E3, "updatetimers" },
    { 0xD2E4, "updatetimerwaitforjoined" },
    { 0xD2E5, "updatetimestamp" },
    { 0xD2E6, "updatetogglescopestate" },
    { 0xD2E7, "updatetotalgameplaytime" },
    { 0xD2E8, "updatetotalteamscore" },
    { 0xD2E9, "updatetrigger" },
    { 0xD2EA, "updatetriggerposition" },
    { 0xD2EB, "updateuavmodelvisibility" },
    { 0xD2EC, "updateuavstatus" },
    { 0xD2ED, "updateuiammocount" },
    { 0xD2EE, "updateuiprogress" },
    { 0xD2EF, "updateuiscorelimit" },
    { 0xD2F0, "updateuisecuring" },
    { 0xD2F1, "updateuistate" },
    { 0xD2F2, "updateusablebyteam" },
    { 0xD2F3, "updateusablestate" },
    { 0xD2F4, "updateusablestateall" },
    { 0xD2F5, "updateuserate" },
    { 0xD2F6, "updateusetimedecay" },
    { 0xD2F7, "updateviewkickscale" },
    { 0xD2F8, "updatevisibilityaccordingtoradar" },
    { 0xD2F9, "updatevisibilityforplayer" },
    { 0xD2FA, "updatevisionforlighting" },
    { 0xD2FB, "updatewaitforjoined" },
    { 0xD2FC, "updatewatcheddvars" },
    { 0xD2FD, "updatewatcheddvarsexecute" },
    { 0xD2FE, "updatewavespawndelay" },
    { 0xD2FF, "updateweapon" },
    { 0xD300, "updateweaponarchetype" },
    { 0xD301, "updateweaponbufferedstats" },
    { 0xD302, "updateweaponchangetime" },
    { 0xD303, "updateweaponkick" },
    { 0xD304, "updateweaponpassivesondamage" },
    { 0xD305, "updateweaponpassivesonkill" },
    { 0xD306, "updateweaponpassivesonuse" },
    { 0xD307, "updateweaponperks" },
    { 0xD308, "updateweaponscriptvfx" },
    { 0xD309, "updateweaponspeed" },
    { 0xD30A, "updatewhizby" },
    { 0xD30B, "updatewinlossstats" },
    { 0xD30C, "updatewinstats" },
    { 0xD30D, "updatezombiegroupname" },
    { 0xD30E, "updating" },
    { 0xD30F, "updatingnavobstacle" },
    { 0xD310, "upload_hold" },
    { 0xD311, "uploadglobalstatcounters" },
    { 0xD312, "upper_body" },
    { 0xD313, "upper_cell_door_button_check" },
    { 0xD314, "upper_door" },
    { 0xD315, "upper_door_geo" },
    { 0xD316, "upper_level_plane_combat_start" },
    { 0xD317, "upper_team_move_courtyard" },
    { 0xD318, "uppercelldoors" },
    { 0xD319, "upperfloor_murderhole_handler" },
    { 0xD31A, "upperguys" },
    { 0xD31B, "uprightcqbidle" },
    { 0xD31C, "upsidedowntaunts" },
    { 0xD31D, "upstairs_guy_handler" },
    { 0xD31E, "upstairs_right_civ_ai_runners_logic" },
    { 0xD31F, "uptime" },
    { 0xD320, "upv" },
    { 0xD321, "upvec" },
    { 0xD322, "us_soldier_3" },
    { 0xD323, "usability_think" },
    { 0xD324, "usabilitytrigger" },
    { 0xD325, "usable" },
    { 0xD326, "usablecrates" },
    { 0xD327, "usableseats" },
    { 0xD328, "usagecost" },
    { 0xD329, "usageflags" },
    { 0xD32A, "usageperiod" },
    { 0xD32B, "use_a_turret" },
    { 0xD32C, "use_ac130_drone_func" },
    { 0xD32D, "use_alt_a" },
    { 0xD32E, "use_alt_b" },
    { 0xD32F, "use_ammocrate" },
    { 0xD330, "use_anywhere_but_here" },
    { 0xD331, "use_atomizer_gun" },
    { 0xD332, "use_bh_gun" },
    { 0xD333, "use_big_goal_until_goal_is_safe" },
    { 0xD334, "use_box" },
    { 0xD335, "use_bsp_nodes" },
    { 0xD336, "use_button_stopped_notify" },
    { 0xD337, "use_c6_animtree" },
    { 0xD338, "use_cant_miss" },
    { 0xD339, "use_claw_gun" },
    { 0xD33A, "use_count" },
    { 0xD33B, "use_cover_node_spawners_around_pos" },
    { 0xD33C, "use_crate" },
    { 0xD33D, "use_death_long_end" },
    { 0xD33E, "use_death_long_end2" },
    { 0xD33F, "use_detonate_drone_func" },
    { 0xD340, "use_dist_override" },
    { 0xD341, "use_distraction" },
    { 0xD342, "use_elevator" },
    { 0xD343, "use_ephemeral_enhancement" },
    { 0xD344, "use_exit_anim" },
    { 0xD345, "use_explosive_touch" },
    { 0xD346, "use_fire_chains" },
    { 0xD347, "use_force_push_near_death" },
    { 0xD348, "use_fov" },
    { 0xD349, "use_func" },
    { 0xD34A, "use_garage" },
    { 0xD34B, "use_goto_wait" },
    { 0xD34C, "use_grenade_cooldown" },
    { 0xD34D, "use_headshot_reload" },
    { 0xD34E, "use_hold_duration" },
    { 0xD34F, "use_hold_think" },
    { 0xD350, "use_increased_team_efficiency" },
    { 0xD351, "use_irish_luck" },
    { 0xD352, "use_killing_time" },
    { 0xD353, "use_late_long_death" },
    { 0xD354, "use_life_link" },
    { 0xD355, "use_long_death_for_death" },
    { 0xD356, "use_masochist" },
    { 0xD357, "use_monitor" },
    { 0xD358, "use_now_you_see_me" },
    { 0xD359, "use_nuclear_core" },
    { 0xD35A, "use_old_label" },
    { 0xD35B, "use_only_veh_spawners" },
    { 0xD35C, "use_path_speeds" },
    { 0xD35D, "use_penetration_gun" },
    { 0xD35E, "use_phoenix_up" },
    { 0xD35F, "use_precomputed_sky_illumination" },
    { 0xD360, "use_purify" },
    { 0xD361, "use_range" },
    { 0xD362, "use_reload_damage_increase" },
    { 0xD363, "use_reminder_anim" },
    { 0xD364, "use_reminder_reaction" },
    { 0xD365, "use_remote_tank" },
    { 0xD366, "use_scout_drone" },
    { 0xD367, "use_scout_drone_func" },
    { 0xD368, "use_scriptables_animtree" },
    { 0xD369, "use_seat" },
    { 0xD36A, "use_self_revive" },
    { 0xD36B, "use_shared_fate" },
    { 0xD36C, "use_slow_enemy_movement" },
    { 0xD36D, "use_spawn_anim" },
    { 0xD36E, "use_spawn_double_money" },
    { 0xD36F, "use_spawn_fire_sale" },
    { 0xD370, "use_spawn_infinite_ammo" },
    { 0xD371, "use_spawn_instakill" },
    { 0xD372, "use_spawn_max_ammo" },
    { 0xD373, "use_spawn_nuke" },
    { 0xD374, "use_spawn_reboard_windows" },
    { 0xD375, "use_steel_dragon" },
    { 0xD376, "use_temp_bc" },
    { 0xD377, "use_temporal_increase" },
    { 0xD378, "use_the_turret" },
    { 0xD379, "use_think" },
    { 0xD37A, "use_think_long_cut" },
    { 0xD37B, "use_thread" },
    { 0xD37C, "use_time" },
    { 0xD37D, "use_timely_torrent" },
    { 0xD37E, "use_trace_data" },
    { 0xD37F, "use_trigger" },
    { 0xD380, "use_triggers" },
    { 0xD381, "use_turret" },
    { 0xD382, "use_twister" },
    { 0xD383, "use_use_trigger" },
    { 0xD384, "use_welfare" },
    { 0xD385, "useadrenaline" },
    { 0xD386, "usealtmodel" },
    { 0xD387, "useammorestocklocs" },
    { 0xD388, "usearmageddon" },
    { 0xD389, "usearmorplate" },
    { 0xD38A, "usearmorvest" },
    { 0xD38B, "useartilleryrole" },
    { 0xD38C, "usebandage" },
    { 0xD38D, "usebarrier" },
    { 0xD38E, "usebulletstorm" },
    { 0xD38F, "usec130spawn" },
    { 0xD390, "usec130spawnfirstonly" },
    { 0xD391, "usechoppersupport" },
    { 0xD392, "useclip" },
    { 0xD393, "usecloak" },
    { 0xD394, "usecomlink" },
    { 0xD395, "usecondition" },
    { 0xD396, "usecooldown" },
    { 0xD397, "usecovernodeifpossible" },
    { 0xD398, "usecustombc" },
    { 0xD399, "used" },
    { 0xD39A, "used_an_mg42" },
    { 0xD39B, "used_destructible_targets" },
    { 0xD39C, "used_fulton_interact" },
    { 0xD39D, "used_molotov" },
    { 0xD39E, "used_recently" },
    { 0xD39F, "used_time" },
    { 0xD3A0, "usedadrenalineatfullhp" },
    { 0xD3A1, "usedambulance" },
    { 0xD3A2, "usedash" },
    { 0xD3A3, "usedata" },
    { 0xD3A4, "usedby" },
    { 0xD3A5, "usedcount" },
    { 0xD3A6, "usedelay" },
    { 0xD3A7, "usedestructibleobjects" },
    { 0xD3A8, "usedids" },
    { 0xD3A9, "usedismemberfxlite" },
    { 0xD3AA, "usedist" },
    { 0xD3AB, "usedkillstreak" },
    { 0xD3AC, "usedlastphase" },
    { 0xD3AD, "usedlocations" },
    { 0xD3AE, "usednotify" },
    { 0xD3AF, "usedomflag" },
    { 0xD3B0, "usedonce" },
    { 0xD3B1, "usedpoints" },
    { 0xD3B2, "usedpointsexpiry" },
    { 0xD3B3, "usedpositions" },
    { 0xD3B4, "usedronehive" },
    { 0xD3B5, "usedspawnposone" },
    { 0xD3B6, "usedspawnposthree" },
    { 0xD3B7, "usedspawnpostwo" },
    { 0xD3B8, "usedtargets" },
    { 0xD3B9, "useduration" },
    { 0xD3BA, "usedynamicobjectusethink" },
    { 0xD3BB, "useentdropbodyonplayerdone" },
    { 0xD3BC, "useentdropbodywhencomplete" },
    { 0xD3BD, "useenthide" },
    { 0xD3BE, "useentmonitorambulances" },
    { 0xD3BF, "useentpickupbody" },
    { 0xD3C0, "useentrespawncomplete" },
    { 0xD3C1, "useentrespawntimeout" },
    { 0xD3C2, "useentsetupcloseambulance" },
    { 0xD3C3, "useentshow" },
    { 0xD3C4, "useexfilchoppers" },
    { 0xD3C5, "useeyetoshoot" },
    { 0xD3C6, "usefov" },
    { 0xD3C7, "usefunc" },
    { 0xD3C8, "usegraverobber" },
    { 0xD3C9, "usegrenadegesture" },
    { 0xD3CA, "usegulag" },
    { 0xD3CB, "usehealthpacks" },
    { 0xD3CC, "usehelicopter" },
    { 0xD3CD, "usehelicopterpilot" },
    { 0xD3CE, "usehigh" },
    { 0xD3CF, "useholdloop" },
    { 0xD3D0, "useholdthink" },
    { 0xD3D1, "useholdthinkcleanup" },
    { 0xD3D2, "useholdthinkloop" },
    { 0xD3D3, "usehostagedrop" },
    { 0xD3D4, "usehprules" },
    { 0xD3D5, "usehpzonebrushes" },
    { 0xD3D6, "usehqrules" },
    { 0xD3D7, "useifproximity" },
    { 0xD3D8, "useinvulnerability" },
    { 0xD3D9, "useitemfrominventory" },
    { 0xD3DA, "usejuggernautrole" },
    { 0xD3DB, "usekineticpulse" },
    { 0xD3DC, "usekineticwave" },
    { 0xD3DD, "uselmapcompression" },
    { 0xD3DE, "uselocationbc" },
    { 0xD3DF, "usemightconnectflag" },
    { 0xD3E0, "usemortarmount" },
    { 0xD3E1, "usemuzzleheightoffset" },
    { 0xD3E2, "usemuzzlesideoffset" },
    { 0xD3E3, "usenormalscorelimit" },
    { 0xD3E4, "useobj" },
    { 0xD3E5, "useobj_trigger" },
    { 0xD3E6, "useobject" },
    { 0xD3E7, "useobjectdecay" },
    { 0xD3E8, "useobjectives" },
    { 0xD3E9, "useobjectproxthink" },
    { 0xD3EA, "useobjects" },
    { 0xD3EB, "useobjectusethink" },
    { 0xD3EC, "useobjs" },
    { 0xD3ED, "useoldlosverification" },
    { 0xD3EE, "useonce" },
    { 0xD3EF, "useonspawn" },
    { 0xD3F0, "useopticwave" },
    { 0xD3F1, "useotherobj" },
    { 0xD3F2, "useoutline" },
    { 0xD3F3, "useovercharge" },
    { 0xD3F4, "useownerobj" },
    { 0xD3F5, "useperbullethitmarkers" },
    { 0xD3F6, "usepercent" },
    { 0xD3F7, "usephaseshift" },
    { 0xD3F8, "usephasesplit" },
    { 0xD3F9, "usephysics" },
    { 0xD3FA, "useplayeruav" },
    { 0xD3FB, "usepowerweapon" },
    { 0xD3FC, "useprompt" },
    { 0xD3FD, "usequickrope" },
    { 0xD3FE, "usequickslothealitem" },
    { 0xD3FF, "user_triggered" },
    { 0xD400, "userallypointvehicles" },
    { 0xD401, "userange" },
    { 0xD402, "userate" },
    { 0xD403, "useratemultiplier" },
    { 0xD404, "usereflectshield" },
    { 0xD405, "useremoteuav" },
    { 0xD406, "userepulsor" },
    { 0xD407, "userespawnc130" },
    { 0xD408, "userewind" },
    { 0xD409, "userskip_input" },
    { 0xD40A, "userskip_stop" },
    { 0xD40B, "userskip_wait" },
    { 0xD40C, "uses" },
    { 0xD40D, "usesai" },
    { 0xD40E, "usesattackeraskillcamentity" },
    { 0xD40F, "usescriptable" },
    { 0xD410, "usescriptedweapon" },
    { 0xD411, "usesiegemode" },
    { 0xD412, "useslopes" },
    { 0xD413, "usesmokewall" },
    { 0xD414, "usesonicpulse" },
    { 0xD415, "usespawncamera" },
    { 0xD416, "usespawnselection" },
    { 0xD417, "usespeedboost" },
    { 0xD418, "usesquadleader" },
    { 0xD419, "usesquadspawn" },
    { 0xD41A, "usesquadspawnselection" },
    { 0xD41B, "usesremaining" },
    { 0xD41C, "usestartspawns" },
    { 0xD41D, "usestarttime" },
    { 0xD41E, "usestash" },
    { 0xD41F, "usestaticspawnselectioncamera" },
    { 0xD420, "usesvehiclekillcamentityrelay" },
    { 0xD421, "usetacopsmapongamestart" },
    { 0xD422, "usetag" },
    { 0xD423, "usetdmspawns" },
    { 0xD424, "useteam" },
    { 0xD425, "useteleport" },
    { 0xD426, "usetelereap" },
    { 0xD427, "usetest" },
    { 0xD428, "usetext" },
    { 0xD429, "usetextenemy" },
    { 0xD42A, "usetextfriendly" },
    { 0xD42B, "usethink" },
    { 0xD42C, "usetime" },
    { 0xD42D, "usetriggerholdloop" },
    { 0xD42E, "usetriggerthink" },
    { 0xD42F, "useturretrole" },
    { 0xD430, "usetype" },
    { 0xD431, "useuav" },
    { 0xD432, "useuavrole" },
    { 0xD433, "useunifiedspawnselectioncameraheight" },
    { 0xD434, "usevehicle" },
    { 0xD435, "useweapon" },
    { 0xD436, "useweaponclipammo" },
    { 0xD437, "useweaponstockammo" },
    { 0xD438, "useweaponswapped" },
    { 0xD439, "useweapontrackstats" },
    { 0xD43A, "usexp" },
    { 0xD43B, "usezonecapture" },
    { 0xD43C, "using_a_turret" },
    { 0xD43D, "using_bulletdrop_weapon" },
    { 0xD43E, "using_drone" },
    { 0xD43F, "using_goto_node" },
    { 0xD440, "using_path" },
    { 0xD441, "using_remote_tank" },
    { 0xD442, "usinganchors" },
    { 0xD443, "usingantiairweapon" },
    { 0xD444, "usingapache" },
    { 0xD445, "usingarmorvest" },
    { 0xD446, "usingascender" },
    { 0xD447, "usingaturret" },
    { 0xD448, "usingautomaticweapon" },
    { 0xD449, "usingboltactionweapon" },
    { 0xD44A, "usingchoppergunner" },
    { 0xD44B, "usingcustomdof" },
    { 0xD44C, "usinggameobjects" },
    { 0xD44D, "usinggunship" },
    { 0xD44E, "usingintermissionpos" },
    { 0xD44F, "usingmg" },
    { 0xD450, "usingnewlongdeaths" },
    { 0xD451, "usingnode" },
    { 0xD452, "usingobj" },
    { 0xD453, "usingonlinedataoffline" },
    { 0xD454, "usingpistol" },
    { 0xD455, "usingplayer" },
    { 0xD456, "usingplayergrenadetimer" },
    { 0xD457, "usingremote" },
    { 0xD458, "usingriflelikeweapon" },
    { 0xD459, "usingrocketlauncher" },
    { 0xD45A, "usingsemiautoweapon" },
    { 0xD45B, "usingsidearm" },
    { 0xD45C, "usingturret" },
    { 0xD45D, "usingvest" },
    { 0xD45E, "usingworldspacehitmarkers" },
    { 0xD45F, "utility_trigger_deleter" },
    { 0xD460, "utility_trigger_demeanoroverride" },
    { 0xD461, "utility_triggers" },
    { 0xD462, "v" },
    { 0xD463, "val" },
    { 0xD464, "val2" },
    { 0xD465, "valid_air_vehicle_spawn_points" },
    { 0xD466, "valid_ball_pickup_weapon" },
    { 0xD467, "valid_ball_super_pickup" },
    { 0xD468, "valid_for_vanguard" },
    { 0xD469, "valid_forward_dist" },
    { 0xD46A, "valid_reaction_sound" },
    { 0xD46B, "valid_rockable_vehicle" },
    { 0xD46C, "valid_vehicles" },
    { 0xD46D, "validate" },
    { 0xD46E, "validate_button_combo" },
    { 0xD46F, "validate_byte" },
    { 0xD470, "validate_current_weapon" },
    { 0xD471, "validate_grid_pos" },
    { 0xD472, "validate_hostage_drop_pos" },
    { 0xD473, "validate_int" },
    { 0xD474, "validate_pos" },
    { 0xD475, "validate_short" },
    { 0xD476, "validate_value" },
    { 0xD477, "validateaccuratetouching" },
    { 0xD478, "validatearchetype" },
    { 0xD479, "validateattachments" },
    { 0xD47A, "validateattacker" },
    { 0xD47B, "validatefalldirection" },
    { 0xD47C, "validatehighpriorityflag" },
    { 0xD47D, "validatelistener" },
    { 0xD47E, "validateloadout" },
    { 0xD47F, "validatenotetracks" },
    { 0xD480, "validateobjectives" },
    { 0xD481, "validatepasstarget" },
    { 0xD482, "validateperk" },
    { 0xD483, "validateperks" },
    { 0xD484, "validateplayers" },
    { 0xD485, "validatepower" },
    { 0xD486, "validaterecentattackers" },
    { 0xD487, "validateselectedspawnarea" },
    { 0xD488, "validatespawns" },
    { 0xD489, "validatestreaks" },
    { 0xD48A, "validatesuper" },
    { 0xD48B, "validateusestreak" },
    { 0xD48C, "validateweapon" },
    { 0xD48D, "validatewildcards" },
    { 0xD48E, "validationerror" },
    { 0xD48F, "validdroplocationstruct" },
    { 0xD490, "validlocations" },
    { 0xD491, "validplayer" },
    { 0xD492, "validplayers" },
    { 0xD493, "validshotcheck" },
    { 0xD494, "validtakeweapon" },
    { 0xD495, "vals" },
    { 0xD496, "value" },
    { 0xD497, "value_hudelem" },
    { 0xD498, "value_plus_or_minus_offset" },
    { 0xD499, "value_type" },
    { 0xD49A, "values" },
    { 0xD49B, "valuewithinrange" },
    { 0xD49C, "van_acquire_interact" },
    { 0xD49D, "van_anim_jumpto" },
    { 0xD49E, "van_bomb_add_fov_user_scale_override" },
    { 0xD49F, "van_brakelights_off" },
    { 0xD4A0, "van_brakelights_on" },
    { 0xD4A1, "van_bullethole_fx_tag" },
    { 0xD4A2, "van_cp_create" },
    { 0xD4A3, "van_cp_createfromstructs" },
    { 0xD4A4, "van_cp_delete" },
    { 0xD4A5, "van_cp_getspawnstructscallback" },
    { 0xD4A6, "van_cp_init" },
    { 0xD4A7, "van_cp_initlate" },
    { 0xD4A8, "van_cp_initspawning" },
    { 0xD4A9, "van_cp_ondeathrespawncallback" },
    { 0xD4AA, "van_cp_spawncallback" },
    { 0xD4AB, "van_cp_waitandspawn" },
    { 0xD4AC, "van_create" },
    { 0xD4AD, "van_damage_nag" },
    { 0xD4AE, "van_damage_temp_nag" },
    { 0xD4AF, "van_dead_guys" },
    { 0xD4B0, "van_deathcallback" },
    { 0xD4B1, "van_deletenextframe" },
    { 0xD4B2, "van_enterend" },
    { 0xD4B3, "van_enterendinternal" },
    { 0xD4B4, "van_exitend" },
    { 0xD4B5, "van_exitendinternal" },
    { 0xD4B6, "van_explode" },
    { 0xD4B7, "van_fx_tag" },
    { 0xD4B8, "van_getspawnstructscallback" },
    { 0xD4B9, "van_hackney_get_length" },
    { 0xD4BA, "van_hackney_init" },
    { 0xD4BB, "van_hackney_spawn" },
    { 0xD4BC, "van_health" },
    { 0xD4BD, "van_impact_ents" },
    { 0xD4BE, "van_infil_radio_idle" },
    { 0xD4BF, "van_infil_sfx_npc1" },
    { 0xD4C0, "van_infil_sfx_npc2" },
    { 0xD4C1, "van_infil_sfx_npc3" },
    { 0xD4C2, "van_infil_sfx_npc4" },
    { 0xD4C3, "van_infil_sfx_npc5" },
    { 0xD4C4, "van_infil_sfx_npc6" },
    { 0xD4C5, "van_init" },
    { 0xD4C6, "van_initfx" },
    { 0xD4C7, "van_initinteract" },
    { 0xD4C8, "van_initlate" },
    { 0xD4C9, "van_initoccupancy" },
    { 0xD4CA, "van_initspawning" },
    { 0xD4CB, "van_interior_sfx" },
    { 0xD4CC, "van_intro_anim" },
    { 0xD4CD, "van_mp_create" },
    { 0xD4CE, "van_mp_delete" },
    { 0xD4CF, "van_mp_getspawnstructscallback" },
    { 0xD4D0, "van_mp_init" },
    { 0xD4D1, "van_mp_initmines" },
    { 0xD4D2, "van_mp_initspawning" },
    { 0xD4D3, "van_mp_ondeathrespawncallback" },
    { 0xD4D4, "van_mp_spawncallback" },
    { 0xD4D5, "van_mp_waitandspawn" },
    { 0xD4D6, "van_restore_user_fov" },
    { 0xD4D7, "van_scene" },
    { 0xD4D8, "van_scene_a" },
    { 0xD4D9, "van_scene_cleanup" },
    { 0xD4DA, "van_scene_dialog" },
    { 0xD4DB, "van_scene_end" },
    { 0xD4DC, "van_scene_init" },
    { 0xD4DD, "van_scene_start" },
    { 0xD4DE, "van_smoke_fx_tag" },
    { 0xD4DF, "vanguard_allowed" },
    { 0xD4E0, "vanguard_control_aiming" },
    { 0xD4E1, "vanguard_get_node_origin" },
    { 0xD4E2, "vanguard_is_outside" },
    { 0xD4E3, "vanguard_missile_radius" },
    { 0xD4E4, "vanguard_num" },
    { 0xD4E5, "vanguard_origin" },
    { 0xD4E6, "vanguard_pick_node" },
    { 0xD4E7, "vans" },
    { 0xD4E8, "var_params" },
    { 0xD4E9, "variability" },
    { 0xD4EA, "variable1" },
    { 0xD4EB, "variable2" },
    { 0xD4EC, "variable3" },
    { 0xD4ED, "vars" },
    { 0xD4EE, "vartostring" },
    { 0xD4EF, "vault_assault_objective_func" },
    { 0xD4F0, "vault_assault_objectives_registered" },
    { 0xD4F1, "vault_door" },
    { 0xD4F2, "vault_door_broken" },
    { 0xD4F3, "vault_door_init" },
    { 0xD4F4, "vault_door_open_wait" },
    { 0xD4F5, "vault_door_sound" },
    { 0xD4F6, "vault_door_think" },
    { 0xD4F7, "vdir" },
    { 0xD4F8, "vdronestrikeheight" },
    { 0xD4F9, "vec_multiply" },
    { 0xD4FA, "vecscale" },
    { 0xD4FB, "vector_area_parallelogram" },
    { 0xD4FC, "vector_empty" },
    { 0xD4FD, "vector_project_endpoint" },
    { 0xD4FE, "vector_project_onto_plane" },
    { 0xD4FF, "vector_reflect" },
    { 0xD500, "vector2d" },
    { 0xD501, "vectortoanglessafe" },
    { 0xD502, "veh" },
    { 0xD503, "veh_goal_pos" },
    { 0xD504, "veh_ground_veh_spawn" },
    { 0xD505, "veh_heli_spawn" },
    { 0xD506, "veh_magic_bullet_array" },
    { 0xD507, "veh_map_ieddamage" },
    { 0xD508, "veh_model_spawner" },
    { 0xD509, "veh_path" },
    { 0xD50A, "veh_ping_vehicle_location_to_players" },
    { 0xD50B, "veh_spawn_point" },
    { 0xD50C, "veh_speed_vals" },
    { 0xD50D, "veh01_ied" },
    { 0xD50E, "vehicle" },
    { 0xD50F, "vehicle_addcovernodetemplate" },
    { 0xD510, "vehicle_ai_avoidance_heli" },
    { 0xD511, "vehicle_ai_avoidance_logic" },
    { 0xD512, "vehicle_ai_can_shoot_after_reload" },
    { 0xD513, "vehicle_ai_spawn_funcs" },
    { 0xD514, "vehicle_all_stop_func" },
    { 0xD515, "vehicle_allows_driver_death" },
    { 0xD516, "vehicle_allows_rider_death" },
    { 0xD517, "vehicle_animate" },
    { 0xD518, "vehicle_anims" },
    { 0xD519, "vehicle_badplace" },
    { 0xD51A, "vehicle_becomes_crashable" },
    { 0xD51B, "vehicle_bridge_stage_five_music" },
    { 0xD51C, "vehicle_build" },
    { 0xD51D, "vehicle_builds" },
    { 0xD51E, "vehicle_caps" },
    { 0xD51F, "vehicle_caps_counter" },
    { 0xD520, "vehicle_cleanup_handler" },
    { 0xD521, "vehicle_cleanupexitboundinginfo" },
    { 0xD522, "vehicle_clearpreventcollisiondamagefortimeafterexit" },
    { 0xD523, "vehicle_controlling" },
    { 0xD524, "vehicle_cp_init" },
    { 0xD525, "vehicle_createhealthbar" },
    { 0xD526, "vehicle_damage_cleareventlog" },
    { 0xD527, "vehicle_damage_cleareventlogatframeend" },
    { 0xD528, "vehicle_damage_clearvisuals" },
    { 0xD529, "vehicle_damage_dovisuals" },
    { 0xD52A, "vehicle_damage_enableownerdamage" },
    { 0xD52B, "vehicle_damage_getleveldata" },
    { 0xD52C, "vehicle_damage_getleveldataforvehicle" },
    { 0xD52D, "vehicle_damage_heavyvisualclearcallback" },
    { 0xD52E, "vehicle_damage_init" },
    { 0xD52F, "vehicle_damage_initdebug" },
    { 0xD530, "vehicle_damage_isownerdamageenabled" },
    { 0xD531, "vehicle_damage_isselfdamage" },
    { 0xD532, "vehicle_damage_keepturretalive" },
    { 0xD533, "vehicle_damage_keepturretaliveend" },
    { 0xD534, "vehicle_damage_lightvisualclearcallback" },
    { 0xD535, "vehicle_damage_logevent" },
    { 0xD536, "vehicle_damage_mediumvisualclearcallback" },
    { 0xD537, "vehicle_damage_monitor" },
    { 0xD538, "vehicle_damage_referevent" },
    { 0xD539, "vehicle_damage_setcandamage" },
    { 0xD53A, "vehicle_damage_visualstopwatchingspeedchange" },
    { 0xD53B, "vehicle_damage_watchturretselfdamage" },
    { 0xD53C, "vehicle_damagelogic" },
    { 0xD53D, "vehicle_death" },
    { 0xD53E, "vehicle_death_custom" },
    { 0xD53F, "vehicle_death_fx" },
    { 0xD540, "vehicle_death_ragdoll" },
    { 0xD541, "vehicle_death_watcher" },
    { 0xD542, "vehicle_deathcleanup" },
    { 0xD543, "vehicle_deathcustomlogic" },
    { 0xD544, "vehicle_deathearthquake" },
    { 0xD545, "vehicle_deathflag" },
    { 0xD546, "vehicle_deathjolt" },
    { 0xD547, "vehicle_deathkilllights" },
    { 0xD548, "vehicle_deathlogic" },
    { 0xD549, "vehicle_deathradiusdamage" },
    { 0xD54A, "vehicle_deathvfx" },
    { 0xD54B, "vehicle_deletecollmapvehicles" },
    { 0xD54C, "vehicle_detachfrompath" },
    { 0xD54D, "vehicle_disable_navobstacles" },
    { 0xD54E, "vehicle_disable_navrepulsors" },
    { 0xD54F, "vehicle_dlog_exitevent" },
    { 0xD550, "vehicle_dlog_getinstancedata" },
    { 0xD551, "vehicle_dlog_getleveldata" },
    { 0xD552, "vehicle_dlog_getuniqueid" },
    { 0xD553, "vehicle_dlog_init" },
    { 0xD554, "vehicle_dlog_spawnevent" },
    { 0xD555, "vehicle_docollisiondamage" },
    { 0xD556, "vehicle_docrash" },
    { 0xD557, "vehicle_door_interaction" },
    { 0xD558, "vehicle_dynamicpath" },
    { 0xD559, "vehicle_empclearcallback" },
    { 0xD55A, "vehicle_empstartcallback" },
    { 0xD55B, "vehicle_enable_navobstacles" },
    { 0xD55C, "vehicle_enable_navrepulsors" },
    { 0xD55D, "vehicle_end_loop_sounds" },
    { 0xD55E, "vehicle_findnextcrashpath" },
    { 0xD55F, "vehicle_fired_from" },
    { 0xD560, "vehicle_flippedendcallback" },
    { 0xD561, "vehicle_follow_parent" },
    { 0xD562, "vehicle_forcerocketdeath" },
    { 0xD563, "vehicle_freehealthbarui" },
    { 0xD564, "vehicle_gdt" },
    { 0xD565, "vehicle_get_path_array" },
    { 0xD566, "vehicle_get_riders_by_group" },
    { 0xD567, "vehicle_getanimstart" },
    { 0xD568, "vehicle_getcameraforseat" },
    { 0xD569, "vehicle_getdeathanimation" },
    { 0xD56A, "vehicle_getdriver" },
    { 0xD56B, "vehicle_gethealthbarid" },
    { 0xD56C, "vehicle_getinanim" },
    { 0xD56D, "vehicle_getinanim_clear" },
    { 0xD56E, "vehicle_getinsound" },
    { 0xD56F, "vehicle_getinsoundtag" },
    { 0xD570, "vehicle_getinstart" },
    { 0xD571, "vehicle_getleveldataforvehicle" },
    { 0xD572, "vehicle_getoutanim" },
    { 0xD573, "vehicle_getoutanim_clear" },
    { 0xD574, "vehicle_getoutanim_combat" },
    { 0xD575, "vehicle_getoutanim_combat_clear" },
    { 0xD576, "vehicle_getoutanim_combat_run" },
    { 0xD577, "vehicle_getoutanim_combat_run_clear" },
    { 0xD578, "vehicle_getoutsound" },
    { 0xD579, "vehicle_getoutsoundtag" },
    { 0xD57A, "vehicle_getvehicle" },
    { 0xD57B, "vehicle_getvehiclearray" },
    { 0xD57C, "vehicle_getvindiasmokegrenades" },
    { 0xD57D, "vehicle_handleunloadevent" },
    { 0xD57E, "vehicle_hasavailablespots" },
    { 0xD57F, "vehicle_hasdeathanimations" },
    { 0xD580, "vehicle_hasdustkickup" },
    { 0xD581, "vehicle_hasrocketdeath" },
    { 0xD582, "vehicle_helicoptercrash" },
    { 0xD583, "vehicle_hit_event" },
    { 0xD584, "vehicle_idle" },
    { 0xD585, "vehicle_idle_override" },
    { 0xD586, "vehicle_idling" },
    { 0xD587, "vehicle_info" },
    { 0xD588, "vehicle_init" },
    { 0xD589, "vehicle_init_anims" },
    { 0xD58A, "vehicle_initfx" },
    { 0xD58B, "vehicle_initlevelvariables" },
    { 0xD58C, "vehicle_interact_allowuseobjectuse" },
    { 0xD58D, "vehicle_interact_allowvehicleuse" },
    { 0xD58E, "vehicle_interact_allowvehicleuseglobal" },
    { 0xD58F, "vehicle_interact_cleanpoint" },
    { 0xD590, "vehicle_interact_cleanvehicle" },
    { 0xD591, "vehicle_interact_cp_init" },
    { 0xD592, "vehicle_interact_deregisterinstance" },
    { 0xD593, "vehicle_interact_getinstancedata" },
    { 0xD594, "vehicle_interact_getinstancedataforpoint" },
    { 0xD595, "vehicle_interact_getinstancedataforvehicle" },
    { 0xD596, "vehicle_interact_getleveldata" },
    { 0xD597, "vehicle_interact_getleveldataforvehicle" },
    { 0xD598, "vehicle_interact_getmaxmovespeedsqr" },
    { 0xD599, "vehicle_interact_getonusecallback" },
    { 0xD59A, "vehicle_interact_getuniqueinstanceid" },
    { 0xD59B, "vehicle_interact_getusableseats" },
    { 0xD59C, "vehicle_interact_getuseobject" },
    { 0xD59D, "vehicle_interact_getvehicleavailableteam" },
    { 0xD59E, "vehicle_interact_init" },
    { 0xD59F, "vehicle_interact_instanceisregistered" },
    { 0xD5A0, "vehicle_interact_makeunusable" },
    { 0xD5A1, "vehicle_interact_makeusable" },
    { 0xD5A2, "vehicle_interact_monitorplayerusability" },
    { 0xD5A3, "vehicle_interact_mp_init" },
    { 0xD5A4, "vehicle_interact_onuse" },
    { 0xD5A5, "vehicle_interact_playercanuse_full" },
    { 0xD5A6, "vehicle_interact_playercanuse_visibility" },
    { 0xD5A7, "vehicle_interact_playercanusevehicle" },
    { 0xD5A8, "vehicle_interact_playercanusevehicles" },
    { 0xD5A9, "vehicle_interact_playerusevehiclefullcheck" },
    { 0xD5AA, "vehicle_interact_pointavailableseat" },
    { 0xD5AB, "vehicle_interact_pointcanbeused" },
    { 0xD5AC, "vehicle_interact_pointisdisabled" },
    { 0xD5AD, "vehicle_interact_purgeinstancedata" },
    { 0xD5AE, "vehicle_interact_registerinstance" },
    { 0xD5AF, "vehicle_interact_scriptable_used" },
    { 0xD5B0, "vehicle_interact_scriptableused" },
    { 0xD5B1, "vehicle_interact_setcallbacks" },
    { 0xD5B2, "vehicle_interact_setpointdirty" },
    { 0xD5B3, "vehicle_interact_setpointsdirty" },
    { 0xD5B4, "vehicle_interact_setteamonly" },
    { 0xD5B5, "vehicle_interact_setusableseats" },
    { 0xD5B6, "vehicle_interact_setvehicledirty" },
    { 0xD5B7, "vehicle_interact_update_usability" },
    { 0xD5B8, "vehicle_interact_updateplayerusability" },
    { 0xD5B9, "vehicle_interact_updateusability" },
    { 0xD5BA, "vehicle_interact_usedcallback" },
    { 0xD5BB, "vehicle_interact_useobjectcanbeused" },
    { 0xD5BC, "vehicle_interact_useupdatevehicles" },
    { 0xD5BD, "vehicle_interact_vehiclecanbeused" },
    { 0xD5BE, "vehicle_interaction_info" },
    { 0xD5BF, "vehicle_interactions" },
    { 0xD5C0, "vehicle_is_crashing" },
    { 0xD5C1, "vehicle_is_falling_behind_vehicle_to_follow" },
    { 0xD5C2, "vehicle_is_stopped" },
    { 0xD5C3, "vehicle_is_too_far_ahead" },
    { 0xD5C4, "vehicle_isalive" },
    { 0xD5C5, "vehicle_iscorpse" },
    { 0xD5C6, "vehicle_iscrashing" },
    { 0xD5C7, "vehicle_isdestructible" },
    { 0xD5C8, "vehicle_jolt_watcher" },
    { 0xD5C9, "vehicle_keeps_going_after_driver_dies" },
    { 0xD5CA, "vehicle_kill_badplace_forever" },
    { 0xD5CB, "vehicle_kill_rumble_forever" },
    { 0xD5CC, "vehicle_killriders" },
    { 0xD5CD, "vehicle_land" },
    { 0xD5CE, "vehicle_landanims" },
    { 0xD5CF, "vehicle_landvehicle" },
    { 0xD5D0, "vehicle_lerpovertime" },
    { 0xD5D1, "vehicle_liftoff" },
    { 0xD5D2, "vehicle_liftoffvehicle" },
    { 0xD5D3, "vehicle_lights" },
    { 0xD5D4, "vehicle_lights_group" },
    { 0xD5D5, "vehicle_lights_group_override" },
    { 0xD5D6, "vehicle_lights_off" },
    { 0xD5D7, "vehicle_lights_on" },
    { 0xD5D8, "vehicle_linked_ent_clean_up_think" },
    { 0xD5D9, "vehicle_load_ai" },
    { 0xD5DA, "vehicle_loaded_if_full" },
    { 0xD5DB, "vehicle_loaded_notify_size" },
    { 0xD5DC, "vehicle_lockedoncallback" },
    { 0xD5DD, "vehicle_lockedonremovedcallback" },
    { 0xD5DE, "vehicle_logic" },
    { 0xD5DF, "vehicle_loop" },
    { 0xD5E0, "vehicle_maketurretsunusable" },
    { 0xD5E1, "vehicle_mines_getleveldata" },
    { 0xD5E2, "vehicle_mines_getleveldataformine" },
    { 0xD5E3, "vehicle_mines_getleveldataforvehicle" },
    { 0xD5E4, "vehicle_mines_getloscheckcontents" },
    { 0xD5E5, "vehicle_mines_getnormal2d" },
    { 0xD5E6, "vehicle_mines_init" },
    { 0xD5E7, "vehicle_mines_isfriendlytomine" },
    { 0xD5E8, "vehicle_mines_minetrigger" },
    { 0xD5E9, "vehicle_mines_mp_init" },
    { 0xD5EA, "vehicle_mines_mp_minetrigger" },
    { 0xD5EB, "vehicle_mines_shouldvehicletriggermine" },
    { 0xD5EC, "vehicle_mp_init" },
    { 0xD5ED, "vehicle_nav_repulsor" },
    { 0xD5EE, "vehicle_navobstacle" },
    { 0xD5EF, "vehicle_navrepulsor" },
    { 0xD5F0, "vehicle_nodegetcrashpaths" },
    { 0xD5F1, "vehicle_notifyonstop" },
    { 0xD5F2, "vehicle_occupancy_allowmovement" },
    { 0xD5F3, "vehicle_occupancy_allowmovementplayer" },
    { 0xD5F4, "vehicle_occupancy_allowsentient" },
    { 0xD5F5, "vehicle_occupancy_animateplayer" },
    { 0xD5F6, "vehicle_occupancy_animtagtoexittag" },
    { 0xD5F7, "vehicle_occupancy_applycameratooccupant" },
    { 0xD5F8, "vehicle_occupancy_applydamagemodifiertooccupant" },
    { 0xD5F9, "vehicle_occupancy_applyrestrictionstooccupant" },
    { 0xD5FA, "vehicle_occupancy_assignseatcorpse" },
    { 0xD5FB, "vehicle_occupancy_checkvalidanimtype" },
    { 0xD5FC, "vehicle_occupancy_clearallowmovement" },
    { 0xD5FD, "vehicle_occupancy_cleardamagefeedbackforplayer" },
    { 0xD5FE, "vehicle_occupancy_cleardisablefirefortime" },
    { 0xD5FF, "vehicle_occupancy_clearheavydamagefeedbackplayer" },
    { 0xD600, "vehicle_occupancy_clearlightdamagefeedbackplayer" },
    { 0xD601, "vehicle_occupancy_clearowner" },
    { 0xD602, "vehicle_occupancy_cp_init" },
    { 0xD603, "vehicle_occupancy_cp_onentervehicle" },
    { 0xD604, "vehicle_occupancy_cp_onexitvehicle" },
    { 0xD605, "vehicle_occupancy_damagemodifierignorefunc" },
    { 0xD606, "vehicle_occupancy_deleteseatcorpse" },
    { 0xD607, "vehicle_occupancy_deleteseatcorpses" },
    { 0xD608, "vehicle_occupancy_deregisterinstance" },
    { 0xD609, "vehicle_occupancy_deregisterturret" },
    { 0xD60A, "vehicle_occupancy_disablefirefortime" },
    { 0xD60B, "vehicle_occupancy_ejectalloccupants" },
    { 0xD60C, "vehicle_occupancy_enter" },
    { 0xD60D, "vehicle_occupancy_enterend" },
    { 0xD60E, "vehicle_occupancy_enterstart" },
    { 0xD60F, "vehicle_occupancy_exit" },
    { 0xD610, "vehicle_occupancy_exitend" },
    { 0xD611, "vehicle_occupancy_exitstart" },
    { 0xD612, "vehicle_occupancy_exitstartcallback" },
    { 0xD613, "vehicle_occupancy_findplayerexit" },
    { 0xD614, "vehicle_occupancy_generateseatswitcharray" },
    { 0xD615, "vehicle_occupancy_getalloccupants" },
    { 0xD616, "vehicle_occupancy_getalloccupantsandreserving" },
    { 0xD617, "vehicle_occupancy_getallvehicleseats" },
    { 0xD618, "vehicle_occupancy_getanimbasename" },
    { 0xD619, "vehicle_occupancy_getavailablevehicleseats" },
    { 0xD61A, "vehicle_occupancy_getcombatcabpassengerrestrictions" },
    { 0xD61B, "vehicle_occupancy_getcombatpassengerrestrictions" },
    { 0xD61C, "vehicle_occupancy_getdamagemodifierforseat" },
    { 0xD61D, "vehicle_occupancy_getdriver" },
    { 0xD61E, "vehicle_occupancy_getdriverrestrictions" },
    { 0xD61F, "vehicle_occupancy_getdriverseat" },
    { 0xD620, "vehicle_occupancy_getenterendcallbackforseat" },
    { 0xD621, "vehicle_occupancy_getenterstartcallbackforseat" },
    { 0xD622, "vehicle_occupancy_getexitangles" },
    { 0xD623, "vehicle_occupancy_getexitboundinginfo" },
    { 0xD624, "vehicle_occupancy_getexitcastcontents" },
    { 0xD625, "vehicle_occupancy_getexitcastignorelist" },
    { 0xD626, "vehicle_occupancy_getexitendcallbackforseat" },
    { 0xD627, "vehicle_occupancy_getexitposition" },
    { 0xD628, "vehicle_occupancy_getexitpositionandangles" },
    { 0xD629, "vehicle_occupancy_getexitstartcallbackforseat" },
    { 0xD62A, "vehicle_occupancy_getfallbackexitpositionandangles" },
    { 0xD62B, "vehicle_occupancy_getleveldata" },
    { 0xD62C, "vehicle_occupancy_getleveldataforseat" },
    { 0xD62D, "vehicle_occupancy_getleveldataforvehicle" },
    { 0xD62E, "vehicle_occupancy_getnextavailableseat" },
    { 0xD62F, "vehicle_occupancy_getoccupantrestrictions" },
    { 0xD630, "vehicle_occupancy_getoccupantseat" },
    { 0xD631, "vehicle_occupancy_getpassivepassengerrestrictions" },
    { 0xD632, "vehicle_occupancy_getreentercallbackforseat" },
    { 0xD633, "vehicle_occupancy_getrestrictionsforseat" },
    { 0xD634, "vehicle_occupancy_getseatoccupant" },
    { 0xD635, "vehicle_occupancy_getturretbyweapon" },
    { 0xD636, "vehicle_occupancy_getturretpassengerrestrictions" },
    { 0xD637, "vehicle_occupancy_getturrets" },
    { 0xD638, "vehicle_occupancy_givetaketurrettimeout" },
    { 0xD639, "vehicle_occupancy_giveturret" },
    { 0xD63A, "vehicle_occupancy_heavydamagefeedbackforplayer" },
    { 0xD63B, "vehicle_occupancy_hideoccupant" },
    { 0xD63C, "vehicle_occupancy_init" },
    { 0xD63D, "vehicle_occupancy_initdebug" },
    { 0xD63E, "vehicle_occupancy_isplayervalidowner" },
    { 0xD63F, "vehicle_occupancy_issentient" },
    { 0xD640, "vehicle_occupancy_killoccupants" },
    { 0xD641, "vehicle_occupancy_lightdamagefeedbackforplayer" },
    { 0xD642, "vehicle_occupancy_linkseatcorpse" },
    { 0xD643, "vehicle_occupancy_monitorexit" },
    { 0xD644, "vehicle_occupancy_monitorexitinternal" },
    { 0xD645, "vehicle_occupancy_monitoroccupant" },
    { 0xD646, "vehicle_occupancy_monitorseatswitch" },
    { 0xD647, "vehicle_occupancy_movementisallowed" },
    { 0xD648, "vehicle_occupancy_moveplayertoexit" },
    { 0xD649, "vehicle_occupancy_mp_deregisterinstance" },
    { 0xD64A, "vehicle_occupancy_mp_freefallcheck" },
    { 0xD64B, "vehicle_occupancy_mp_hideoccupantmodel" },
    { 0xD64C, "vehicle_occupancy_mp_hideoccupantoutlineandnameplate" },
    { 0xD64D, "vehicle_occupancy_mp_init" },
    { 0xD64E, "vehicle_occupancy_mp_issentient" },
    { 0xD64F, "vehicle_occupancy_mp_onentervehicle" },
    { 0xD650, "vehicle_occupancy_mp_onexitvehicle" },
    { 0xD651, "vehicle_occupancy_mp_registerinstance" },
    { 0xD652, "vehicle_occupancy_mp_registersentient" },
    { 0xD653, "vehicle_occupancy_mp_showoccupantmodel" },
    { 0xD654, "vehicle_occupancy_mp_showoccupantoutlineandnameplate" },
    { 0xD655, "vehicle_occupancy_mp_unregistersentient" },
    { 0xD656, "vehicle_occupancy_mp_updatemarkfilter" },
    { 0xD657, "vehicle_occupancy_mp_updateowner" },
    { 0xD658, "vehicle_occupancy_occupantisvehicledriver" },
    { 0xD659, "vehicle_occupancy_onentervehicle" },
    { 0xD65A, "vehicle_occupancy_onexitvehicle" },
    { 0xD65B, "vehicle_occupancy_purgedataforseatinstance" },
    { 0xD65C, "vehicle_occupancy_racecomplete" },
    { 0xD65D, "vehicle_occupancy_raceplayerdeathdisconnect" },
    { 0xD65E, "vehicle_occupancy_raceresults" },
    { 0xD65F, "vehicle_occupancy_raceseatunavailable" },
    { 0xD660, "vehicle_occupancy_racevehicledeath" },
    { 0xD661, "vehicle_occupancy_reenter" },
    { 0xD662, "vehicle_occupancy_registerinstance" },
    { 0xD663, "vehicle_occupancy_registersentient" },
    { 0xD664, "vehicle_occupancy_registerturret" },
    { 0xD665, "vehicle_occupancy_removecamerafromoccupant" },
    { 0xD666, "vehicle_occupancy_removedamagemodifierfromoccupant" },
    { 0xD667, "vehicle_occupancy_removerestrictionsfromoccupant" },
    { 0xD668, "vehicle_occupancy_seatisavailable" },
    { 0xD669, "vehicle_occupancy_setoriginalowner" },
    { 0xD66A, "vehicle_occupancy_setowner" },
    { 0xD66B, "vehicle_occupancy_setteam" },
    { 0xD66C, "vehicle_occupancy_showoccupant" },
    { 0xD66D, "vehicle_occupancy_startmovefeedbackforplayer" },
    { 0xD66E, "vehicle_occupancy_stopanimatingplayer" },
    { 0xD66F, "vehicle_occupancy_stopmonitoringoccupant" },
    { 0xD670, "vehicle_occupancy_stopmovefeedbackforplayer" },
    { 0xD671, "vehicle_occupancy_taketurret" },
    { 0xD672, "vehicle_occupancy_unregistersentient" },
    { 0xD673, "vehicle_occupancy_updatedamagefeedback" },
    { 0xD674, "vehicle_occupancy_updateempty" },
    { 0xD675, "vehicle_occupancy_updatefull" },
    { 0xD676, "vehicle_occupancy_updatemovefeedback" },
    { 0xD677, "vehicle_occupancy_updateowner" },
    { 0xD678, "vehicle_occupancy_watchmovefeedback" },
    { 0xD679, "vehicle_occupancy_watchowner" },
    { 0xD67A, "vehicle_occupancy_watchownerjoinedteam" },
    { 0xD67B, "vehicle_occupancy_watchplayeranimate" },
    { 0xD67C, "vehicle_oob_cp_clearcallback" },
    { 0xD67D, "vehicle_oob_cp_clearoob" },
    { 0xD67E, "vehicle_oob_cp_deregisterinstance" },
    { 0xD67F, "vehicle_oob_cp_entercallback" },
    { 0xD680, "vehicle_oob_cp_entercallbackforplayer" },
    { 0xD681, "vehicle_oob_cp_exitcallback" },
    { 0xD682, "vehicle_oob_cp_exitcallbackforplayer" },
    { 0xD683, "vehicle_oob_cp_getleveldata" },
    { 0xD684, "vehicle_oob_cp_init" },
    { 0xD685, "vehicle_oob_cp_outoftimecallback" },
    { 0xD686, "vehicle_oob_cp_registerinstance" },
    { 0xD687, "vehicle_oob_cp_registeroutoftimecallback" },
    { 0xD688, "vehicle_oob_mp_clearcallback" },
    { 0xD689, "vehicle_oob_mp_clearoob" },
    { 0xD68A, "vehicle_oob_mp_deregisterinstance" },
    { 0xD68B, "vehicle_oob_mp_entercallback" },
    { 0xD68C, "vehicle_oob_mp_entercallbackforplayer" },
    { 0xD68D, "vehicle_oob_mp_exitcallback" },
    { 0xD68E, "vehicle_oob_mp_exitcallbackforplayer" },
    { 0xD68F, "vehicle_oob_mp_getleveldata" },
    { 0xD690, "vehicle_oob_mp_init" },
    { 0xD691, "vehicle_oob_mp_outoftimecallback" },
    { 0xD692, "vehicle_oob_mp_registerinstance" },
    { 0xD693, "vehicle_oob_mp_registeroutoftimecallback" },
    { 0xD694, "vehicle_pathdetach" },
    { 0xD695, "vehicle_paths" },
    { 0xD696, "vehicle_paths_helicopter" },
    { 0xD697, "vehicle_paths_non_heli" },
    { 0xD698, "vehicle_play_exit_anim" },
    { 0xD699, "vehicle_playdeathanimation" },
    { 0xD69A, "vehicle_playdeatheffects" },
    { 0xD69B, "vehicle_playengineeffect" },
    { 0xD69C, "vehicle_playerkilledbycollision" },
    { 0xD69D, "vehicle_playexhausteffect" },
    { 0xD69E, "vehicle_position" },
    { 0xD69F, "vehicle_precachescripts" },
    { 0xD6A0, "vehicle_precachesetup" },
    { 0xD6A1, "vehicle_preventcollisiondamagefortimeafterexit" },
    { 0xD6A2, "vehicle_preventcollisiondamagefortimeafterexitinternal" },
    { 0xD6A3, "vehicle_progress_marker_think" },
    { 0xD6A4, "vehicle_race_ied_explosion_action" },
    { 0xD6A5, "vehicle_registrations" },
    { 0xD6A6, "vehicle_reload" },
    { 0xD6A7, "vehicle_remove_badplace" },
    { 0xD6A8, "vehicle_remove_navobstacle" },
    { 0xD6A9, "vehicle_remove_navrepulsor" },
    { 0xD6AA, "vehicle_removenonridersfromaiarray" },
    { 0xD6AB, "vehicle_resume_named" },
    { 0xD6AC, "vehicle_resumepath" },
    { 0xD6AD, "vehicle_resumepathvehicle" },
    { 0xD6AE, "vehicle_ride" },
    { 0xD6AF, "vehicle_rider_death_detection" },
    { 0xD6B0, "vehicle_riding_on" },
    { 0xD6B1, "vehicle_rocket_death_fx" },
    { 0xD6B2, "vehicle_rumble" },
    { 0xD6B3, "vehicle_script_forcecolor_riders" },
    { 0xD6B4, "vehicle_setcrashing" },
    { 0xD6B5, "vehicle_setdeathmodel" },
    { 0xD6B6, "vehicle_setstartinghealth" },
    { 0xD6B7, "vehicle_setteam" },
    { 0xD6B8, "vehicle_setuplevelvariables" },
    { 0xD6B9, "vehicle_setupspawners" },
    { 0xD6BA, "vehicle_setwheeldirection" },
    { 0xD6BB, "vehicle_should_regenerate" },
    { 0xD6BC, "vehicle_should_unload" },
    { 0xD6BD, "vehicle_shoulddocollisiondamage" },
    { 0xD6BE, "vehicle_shoulddorocketdeath" },
    { 0xD6BF, "vehicle_shouldhideoccupantforseat" },
    { 0xD6C0, "vehicle_shouldignorecollisiondamage" },
    { 0xD6C1, "vehicle_shouldplaydeathanimation" },
    { 0xD6C2, "vehicle_skipdeathanimation" },
    { 0xD6C3, "vehicle_skipdeathcrash" },
    { 0xD6C4, "vehicle_skipdeathmodel" },
    { 0xD6C5, "vehicle_skipdeathphysics" },
    { 0xD6C6, "vehicle_spawn" },
    { 0xD6C7, "vehicle_spawn_canspawnvehicle" },
    { 0xD6C8, "vehicle_spawn_checkspawnclearance" },
    { 0xD6C9, "vehicle_spawn_cp_canspawnvehicle" },
    { 0xD6CA, "vehicle_spawn_cp_gamemodesupportsrespawn" },
    { 0xD6CB, "vehicle_spawn_cp_init" },
    { 0xD6CC, "vehicle_spawn_deregisterinstance" },
    { 0xD6CD, "vehicle_spawn_func" },
    { 0xD6CE, "vehicle_spawn_gamemodesupportsrespawn" },
    { 0xD6CF, "vehicle_spawn_getinstancecount" },
    { 0xD6D0, "vehicle_spawn_getinstancecountforref" },
    { 0xD6D1, "vehicle_spawn_getleveldata" },
    { 0xD6D2, "vehicle_spawn_getleveldataforvehicle" },
    { 0xD6D3, "vehicle_spawn_init" },
    { 0xD6D4, "vehicle_spawn_initlate" },
    { 0xD6D5, "vehicle_spawn_initspawnclearance" },
    { 0xD6D6, "vehicle_spawn_internal" },
    { 0xD6D7, "vehicle_spawn_iscodevehicletest" },
    { 0xD6D8, "vehicle_spawn_iscodevehicletestlevel" },
    { 0xD6D9, "vehicle_spawn_isvehiclespawnstruct" },
    { 0xD6DA, "vehicle_spawn_mp_canspawnvehicle" },
    { 0xD6DB, "vehicle_spawn_mp_codetesthackinit" },
    { 0xD6DC, "vehicle_spawn_mp_codetesthackspawncallback" },
    { 0xD6DD, "vehicle_spawn_mp_codetesthackwatchrespawn" },
    { 0xD6DE, "vehicle_spawn_mp_gamemodesupportsrespawn" },
    { 0xD6DF, "vehicle_spawn_mp_init" },
    { 0xD6E0, "vehicle_spawn_mp_internal" },
    { 0xD6E1, "vehicle_spawn_point" },
    { 0xD6E2, "vehicle_spawn_registerinstance" },
    { 0xD6E3, "vehicle_spawn_removespawnstructswithflag" },
    { 0xD6E4, "vehicle_spawn_setclearancecheckminradius" },
    { 0xD6E5, "vehicle_spawn_spawnfromstructs" },
    { 0xD6E6, "vehicle_spawn_spawnfromstructscomparefunc" },
    { 0xD6E7, "vehicle_spawn_spawnvehicle" },
    { 0xD6E8, "vehicle_spawnaiarray" },
    { 0xD6E9, "vehicle_spawncovernodes" },
    { 0xD6EA, "vehicle_spawned_thisframe" },
    { 0xD6EB, "vehicle_spawner" },
    { 0xD6EC, "vehicle_spawner_deathflag" },
    { 0xD6ED, "vehicle_spawnerlogic" },
    { 0xD6EE, "vehicle_spawnpoint_scoring" },
    { 0xD6EF, "vehicle_spawnpoint_valid" },
    { 0xD6F0, "vehicle_spawnsuicidetruck" },
    { 0xD6F1, "vehicle_spawntechos" },
    { 0xD6F2, "vehicle_spawnvindias" },
    { 0xD6F3, "vehicle_specific_onentervehicle" },
    { 0xD6F4, "vehicle_specific_onexitvehicle" },
    { 0xD6F5, "vehicle_standattack" },
    { 0xD6F6, "vehicle_station_tutorial_vo_monitor" },
    { 0xD6F7, "vehicle_stop_named" },
    { 0xD6F8, "vehicle_suicidetruckarmorlogic" },
    { 0xD6F9, "vehicle_suicidetruckcrashlogic" },
    { 0xD6FA, "vehicle_suicidetruckdriverandanimationcleanup" },
    { 0xD6FB, "vehicle_suicidetruckengineblocklogic" },
    { 0xD6FC, "vehicle_suicidetruckexplode" },
    { 0xD6FD, "vehicle_suicidetruckexplodeoncrashpathend" },
    { 0xD6FE, "vehicle_suicidetruckfiresfxlogic" },
    { 0xD6FF, "vehicle_suicidetrucklaunchmesh" },
    { 0xD700, "vehicle_suicidetrucklogic" },
    { 0xD701, "vehicle_suicidetruckriderslogic" },
    { 0xD702, "vehicle_suicidetruckrunoverlogic" },
    { 0xD703, "vehicle_suicidetrucksfxlogic" },
    { 0xD704, "vehicle_suniform25dropbomb" },
    { 0xD705, "vehicle_suniform25effects" },
    { 0xD706, "vehicle_suspenddriveanimations" },
    { 0xD707, "vehicle_switch_paths" },
    { 0xD708, "vehicle_techodisablelogic" },
    { 0xD709, "vehicle_to_chase" },
    { 0xD70A, "vehicle_to_chase_is_behind" },
    { 0xD70B, "vehicle_to_push" },
    { 0xD70C, "vehicle_to_push_damage_monitor" },
    { 0xD70D, "vehicle_to_push_explode_sequence" },
    { 0xD70E, "vehicle_tracking_atinstancelimit" },
    { 0xD70F, "vehicle_tracking_deregisterinstance" },
    { 0xD710, "vehicle_tracking_getgameinstances" },
    { 0xD711, "vehicle_tracking_getgameinstancesforall" },
    { 0xD712, "vehicle_tracking_getownerinstances" },
    { 0xD713, "vehicle_tracking_getteaminstances" },
    { 0xD714, "vehicle_tracking_init" },
    { 0xD715, "vehicle_tracking_instancesarelimited" },
    { 0xD716, "vehicle_tracking_limitgameinstances" },
    { 0xD717, "vehicle_tracking_limitownerinstances" },
    { 0xD718, "vehicle_tracking_limitteaminstances" },
    { 0xD719, "vehicle_tracking_registerinstance" },
    { 0xD71A, "vehicle_travel_array" },
    { 0xD71B, "vehicle_treads" },
    { 0xD71C, "vehicle_triggerkillspawner" },
    { 0xD71D, "vehicle_turret_cleanup" },
    { 0xD71E, "vehicle_turret_difficulty" },
    { 0xD71F, "vehicle_turret_init" },
    { 0xD720, "vehicle_turret_scan_off" },
    { 0xD721, "vehicle_unload" },
    { 0xD722, "vehicle_vindiabodydamagelogic" },
    { 0xD723, "vehicle_vindiadamagelogic" },
    { 0xD724, "vehicle_vindialaunchsmokegrenades" },
    { 0xD725, "vehicle_vindiameshanimdrivecleanuplogic" },
    { 0xD726, "vehicle_vindiameshanimdrivelogic" },
    { 0xD727, "vehicle_vindiameshanimlogic" },
    { 0xD728, "vehicle_vindiameshanimunloadlogic" },
    { 0xD729, "vehicle_vindiasmokegrenadelogic" },
    { 0xD72A, "vehicle_vindiasmokelaunchsfxlogic" },
    { 0xD72B, "vehicle_vindiaspawnsmokegrenade" },
    { 0xD72C, "vehicle_vindiaspeeduplogic" },
    { 0xD72D, "vehicle_vindiaspeeduptimeoutlogic" },
    { 0xD72E, "vehicle_vindiatirelogic" },
    { 0xD72F, "vehicle_vindiaunloadlogic" },
    { 0xD730, "vehicle_waittill_stopped" },
    { 0xD731, "vehicle_waittillarraymoving" },
    { 0xD732, "vehicle_watchflipped" },
    { 0xD733, "vehicle_watchwheeldust" },
    { 0xD734, "vehicle_wheels_backward" },
    { 0xD735, "vehicle_wheels_forward" },
    { 0xD736, "vehicle_whizby_watcher" },
    { 0xD737, "vehicle_would_exceed_limit" },
    { 0xD738, "vehicleanimalias" },
    { 0xD739, "vehiclecanbesuspended" },
    { 0xD73A, "vehiclecanfly" },
    { 0xD73B, "vehiclecannotbesuspended" },
    { 0xD73C, "vehiclecanshoot" },
    { 0xD73D, "vehiclecanshootlmg" },
    { 0xD73E, "vehiclecollisionignorearray" },
    { 0xD73F, "vehiclecount" },
    { 0xD740, "vehiclecrashing" },
    { 0xD741, "vehicledata" },
    { 0xD742, "vehicledeath" },
    { 0xD743, "vehicledeathwait" },
    { 0xD744, "vehicledisabledmovement" },
    { 0xD745, "vehicledisablefire" },
    { 0xD746, "vehicledisablefireendtime" },
    { 0xD747, "vehicledisableturningwhileshooting" },
    { 0xD748, "vehicledisableweaponreloading" },
    { 0xD749, "vehicleendtime" },
    { 0xD74A, "vehicleexitanimtime" },
    { 0xD74B, "vehicleexitstatename" },
    { 0xD74C, "vehiclefollowpath" },
    { 0xD74D, "vehiclefollowpathgeneric" },
    { 0xD74E, "vehiclefollowstructpath" },
    { 0xD74F, "vehiclefollowstructpathsplines" },
    { 0xD750, "vehiclefriendlydamage" },
    { 0xD751, "vehiclegetoutcodemove" },
    { 0xD752, "vehiclehasalias" },
    { 0xD753, "vehicleheavydamagefeedbackid" },
    { 0xD754, "vehiclehidetime" },
    { 0xD755, "vehiclehint" },
    { 0xD756, "vehiclehitstokill" },
    { 0xD757, "vehicleidle" },
    { 0xD758, "vehicleidmap" },
    { 0xD759, "vehicleincombat" },
    { 0xD75A, "vehicleinfo" },
    { 0xD75B, "vehicleinitthread" },
    { 0xD75C, "vehicleinteract" },
    { 0xD75D, "vehicleisreserved" },
    { 0xD75E, "vehiclekilled" },
    { 0xD75F, "vehiclekills" },
    { 0xD760, "vehiclelightdamagefeedbackid" },
    { 0xD761, "vehiclelogic" },
    { 0xD762, "vehiclelostsightlinetime" },
    { 0xD763, "vehiclemoveshakeenabled" },
    { 0xD764, "vehiclename" },
    { 0xD765, "vehicleomnvars" },
    { 0xD766, "vehicleoverride" },
    { 0xD767, "vehicleowner" },
    { 0xD768, "vehicleplayermodel" },
    { 0xD769, "vehicleplaysounds" },
    { 0xD76A, "vehiclereload_terminate" },
    { 0xD76B, "vehiclerequest" },
    { 0xD76C, "vehiclerunexit" },
    { 0xD76D, "vehicles" },
    { 0xD76E, "vehicles_alpha_anims" },
    { 0xD76F, "vehicles_damage_deregisterdefaultvisuals" },
    { 0xD770, "vehicles_damage_deregistervisualpercentcallback" },
    { 0xD771, "vehicles_damage_enginevisualcallback" },
    { 0xD772, "vehicles_damage_enginevisualclearcallback" },
    { 0xD773, "vehicles_damage_heavyvisualcallback" },
    { 0xD774, "vehicles_damage_lightvisualcallback" },
    { 0xD775, "vehicles_damage_mediumvisualcallback" },
    { 0xD776, "vehicles_damage_registerdefaultvisuals" },
    { 0xD777, "vehicles_damage_registervisualpercentcallback" },
    { 0xD778, "vehicles_damage_visualwatchspeedchange" },
    { 0xD779, "vehicles_init" },
    { 0xD77A, "vehicles_remaining" },
    { 0xD77B, "vehicles_turnonlights" },
    { 0xD77C, "vehiclesetuprope" },
    { 0xD77D, "vehicleshouldhide" },
    { 0xD77E, "vehicleshouldrunexit" },
    { 0xD77F, "vehicleshouldsetuprope" },
    { 0xD780, "vehicleshouldstophide" },
    { 0xD781, "vehiclespawn_atv" },
    { 0xD782, "vehiclespawn_cargotruck" },
    { 0xD783, "vehiclespawn_copcar" },
    { 0xD784, "vehiclespawn_getspawndata" },
    { 0xD785, "vehiclespawn_hoopty" },
    { 0xD786, "vehiclespawn_hooptytruck" },
    { 0xD787, "vehiclespawn_hqtanks" },
    { 0xD788, "vehiclespawn_jeep" },
    { 0xD789, "vehiclespawn_largetransport" },
    { 0xD78A, "vehiclespawn_littlebird" },
    { 0xD78B, "vehiclespawn_medtransport" },
    { 0xD78C, "vehiclespawn_pickuptruck" },
    { 0xD78D, "vehiclespawn_tacrover" },
    { 0xD78E, "vehiclespawn_tank" },
    { 0xD78F, "vehiclespawn_truck" },
    { 0xD790, "vehiclespawn_van" },
    { 0xD791, "vehiclespawnlocs" },
    { 0xD792, "vehiclespawns" },
    { 0xD793, "vehiclesspawned" },
    { 0xD794, "vehiclestate" },
    { 0xD795, "vehicleteam" },
    { 0xD796, "vehiclethink" },
    { 0xD797, "vehiclethinkanim" },
    { 0xD798, "vehiclethinkmodel" },
    { 0xD799, "vehiclethinkpath" },
    { 0xD79A, "vehiclewatchforflip" },
    { 0xD79B, "vehiclewheeldirection" },
    { 0xD79C, "vehile_updatehealthbar" },
    { 0xD79D, "vehomn_clearall" },
    { 0xD79E, "vehomn_clearallinternal" },
    { 0xD79F, "vehomn_clearammo" },
    { 0xD7A0, "vehomn_clearcurrentseat" },
    { 0xD7A1, "vehomn_clearfuelpercent" },
    { 0xD7A2, "vehomn_clearhealthpercent" },
    { 0xD7A3, "vehomn_clearnextseat" },
    { 0xD7A4, "vehomn_clearrotation" },
    { 0xD7A5, "vehomn_clearseatentity" },
    { 0xD7A6, "vehomn_clearshowfuel" },
    { 0xD7A7, "vehomn_clearshowhealth" },
    { 0xD7A8, "vehomn_clearshowtime" },
    { 0xD7A9, "vehomn_cleartimepercent" },
    { 0xD7AA, "vehomn_clearvehicle" },
    { 0xD7AB, "vehomn_clearwarnings" },
    { 0xD7AC, "vehomn_getlevelstruct" },
    { 0xD7AD, "vehomn_hideammo" },
    { 0xD7AE, "vehomn_hidefuel" },
    { 0xD7AF, "vehomn_hidehealth" },
    { 0xD7B0, "vehomn_hidetime" },
    { 0xD7B1, "vehomn_hidewarning" },
    { 0xD7B2, "vehomn_init" },
    { 0xD7B3, "vehomn_initammoidmap" },
    { 0xD7B4, "vehomn_initrotationidmap" },
    { 0xD7B5, "vehomn_initseatidmap" },
    { 0xD7B6, "vehomn_initvehicleidmap" },
    { 0xD7B7, "vehomn_initwarningidmap" },
    { 0xD7B8, "vehomn_setammo" },
    { 0xD7B9, "vehomn_setcurrentseat" },
    { 0xD7BA, "vehomn_setfuelpercent" },
    { 0xD7BB, "vehomn_sethealthpercent" },
    { 0xD7BC, "vehomn_setnextseat" },
    { 0xD7BD, "vehomn_setrotation" },
    { 0xD7BE, "vehomn_setseatentity" },
    { 0xD7BF, "vehomn_settimepercent" },
    { 0xD7C0, "vehomn_setvehicle" },
    { 0xD7C1, "vehomn_showammo" },
    { 0xD7C2, "vehomn_showfuel" },
    { 0xD7C3, "vehomn_showhealth" },
    { 0xD7C4, "vehomn_showtime" },
    { 0xD7C5, "vehomn_showwarning" },
    { 0xD7C6, "vehomn_updatenextseatomnvars" },
    { 0xD7C7, "vehomn_updateomnvarsondamage" },
    { 0xD7C8, "vehomn_updateomnvarsonseatenter" },
    { 0xD7C9, "vehomn_updateomnvarsonseatexit" },
    { 0xD7CA, "vehspawnvol" },
    { 0xD7CB, "vel" },
    { 0xD7CC, "velo_array" },
    { 0xD7CD, "velo_forward" },
    { 0xD7CE, "velocity_bump" },
    { 0xD7CF, "velocity_increase" },
    { 0xD7D0, "veltomph" },
    { 0xD7D1, "vent_crawl_presentation" },
    { 0xD7D2, "vent_wait_interact" },
    { 0xD7D3, "verbose" },
    { 0xD7D4, "verify_effects_assignment" },
    { 0xD7D5, "verify_effects_assignment_print" },
    { 0xD7D6, "verifybombzones" },
    { 0xD7D7, "verifydedicatedconfiguration" },
    { 0xD7D8, "verifygamemodecallout" },
    { 0xD7D9, "versusdone" },
    { 0xD7DA, "very_longshot" },
    { 0xD7DB, "vest_intro_vo" },
    { 0xD7DC, "vest_required_end_time" },
    { 0xD7DD, "vest_required_start_time" },
    { 0xD7DE, "vest_required_wire" },
    { 0xD7DF, "vest_timer_countdown" },
    { 0xD7E0, "vests" },
    { 0xD7E1, "veteran_achievement" },
    { 0xD7E2, "vfx_doorgas" },
    { 0xD7E3, "vfx_intro_collapse" },
    { 0xD7E4, "vfx_stop_gas_cam" },
    { 0xD7E5, "vfxent" },
    { 0xD7E6, "vfxnamemod" },
    { 0xD7E7, "vfxradius" },
    { 0xD7E8, "vfxtag" },
    { 0xD7E9, "victim" },
    { 0xD7EA, "victim_damage_monitor" },
    { 0xD7EB, "victim_killed_fight1" },
    { 0xD7EC, "victim_killed_fight2" },
    { 0xD7ED, "victim_push_back" },
    { 0xD7EE, "victim_saved" },
    { 0xD7EF, "victim_saved_shield" },
    { 0xD7F0, "victimonground" },
    { 0xD7F1, "victims" },
    { 0xD7F2, "victimteam" },
    { 0xD7F3, "view_model" },
    { 0xD7F4, "viewblender" },
    { 0xD7F5, "viewblenderupdate" },
    { 0xD7F6, "viewchange" },
    { 0xD7F7, "viewclamps" },
    { 0xD7F8, "viewfx" },
    { 0xD7F9, "viewkickscale" },
    { 0xD7FA, "viewmodel" },
    { 0xD7FB, "viewoperationactivation" },
    { 0xD7FC, "viewoperationhint" },
    { 0xD7FD, "viewoperationinit" },
    { 0xD7FE, "viewtag" },
    { 0xD7FF, "vig_injuredmarine" },
    { 0xD800, "vig_roof_peek" },
    { 0xD801, "vig_sledgebreach" },
    { 0xD802, "vig_street_intro_init" },
    { 0xD803, "vig_street_intro_start" },
    { 0xD804, "vig_window_peek" },
    { 0xD805, "vig_window_peek_spawner" },
    { 0xD806, "vignette_actor_cleanup" },
    { 0xD807, "vignette_actor_init" },
    { 0xD808, "vignette_actor_stealth_filter" },
    { 0xD809, "vignette_drone_give_soul" },
    { 0xD80A, "vignette_interrupted" },
    { 0xD80B, "vindia_get_length" },
    { 0xD80C, "vindia_init" },
    { 0xD80D, "vindia_spawn" },
    { 0xD80E, "vindia_spotlight" },
    { 0xD80F, "vindia_target_mover" },
    { 0xD810, "vip" },
    { 0xD811, "vip_damage_monitor" },
    { 0xD812, "vip_dies_soon" },
    { 0xD813, "vip_endgame" },
    { 0xD814, "vip_followplayer" },
    { 0xD815, "vip_go_and_hide" },
    { 0xD816, "vip_idle_loop" },
    { 0xD817, "vip_onuse" },
    { 0xD818, "vip_parachute" },
    { 0xD819, "vip_parachute_nearby" },
    { 0xD81A, "vip_spawn" },
    { 0xD81B, "vip_spawn_parachute" },
    { 0xD81C, "vip_turnoff" },
    { 0xD81D, "vip_update_objective_on_landed" },
    { 0xD81E, "vip_use_fulton_start" },
    { 0xD81F, "vip_use_fulton_think" },
    { 0xD820, "vip_use_think" },
    { 0xD821, "vipdist" },
    { 0xD822, "vipextract" },
    { 0xD823, "vipextractzones" },
    { 0xD824, "vis_changed_time" },
    { 0xD825, "visen" },
    { 0xD826, "visfr" },
    { 0xD827, "visibility_thread" },
    { 0xD828, "visibilitylods" },
    { 0xD829, "visibilitymanuallycontrolled" },
    { 0xD82A, "visible" },
    { 0xD82B, "visiblelocations" },
    { 0xD82C, "visibleteam" },
    { 0xD82D, "visibletime" },
    { 0xD82E, "vision_set_init" },
    { 0xD82F, "vision_set_management" },
    { 0xD830, "vision_set_manager" },
    { 0xD831, "vision_set_override" },
    { 0xD832, "visionnakeddefault" },
    { 0xD833, "visionoverride" },
    { 0xD834, "visionset_pointer" },
    { 0xD835, "visionset_stack" },
    { 0xD836, "visionsetflag" },
    { 0xD837, "visionthermaldefault" },
    { 0xD838, "visited" },
    { 0xD839, "visor_anim" },
    { 0xD83A, "visor_overlay" },
    { 0xD83B, "vista_boat_drive" },
    { 0xD83C, "visual_range_sq" },
    { 0xD83D, "visualcallbacks" },
    { 0xD83E, "visualclearcallbacks" },
    { 0xD83F, "visualgroundoffset" },
    { 0xD840, "visualhighesttolowest" },
    { 0xD841, "visualpercents" },
    { 0xD842, "visuals" },
    { 0xD843, "vm" },
    { 0xD844, "vmexfilally" },
    { 0xD845, "vmhvt" },
    { 0xD846, "vmvip" },
    { 0xD847, "vnum" },
    { 0xD848, "vo" },
    { 0xD849, "vo_acquire_price_beyond_the_fence" },
    { 0xD84A, "vo_acquire_price_keep_on_him" },
    { 0xD84B, "vo_acquire_price_nowhere_left_to_run" },
    { 0xD84C, "vo_alias_data" },
    { 0xD84D, "vo_alley_griggs_fallback_smoke_dialogue" },
    { 0xD84E, "vo_alley_griggs_final_smoke_dialogue" },
    { 0xD84F, "vo_alley_griggs_go_to_mh_dialogue" },
    { 0xD850, "vo_alley_griggs_mg_warning" },
    { 0xD851, "vo_alley_marine_pinned_down_dialogue" },
    { 0xD852, "vo_alley_marine_technical_arrive_dialogue" },
    { 0xD853, "vo_alley_mg_initial_callout_dialogue" },
    { 0xD854, "vo_alley_push_up_nag_dialogue" },
    { 0xD855, "vo_alley_scripted_push_up_dialogue" },
    { 0xD856, "vo_alley_stealth_butcher_alerted_fail" },
    { 0xD857, "vo_alley_stealth_cover_blown" },
    { 0xD858, "vo_alley_stealth_enemies_alerted" },
    { 0xD859, "vo_alley_stealth_enemies_dead" },
    { 0xD85A, "vo_alley_stealth_move_to_bar_door" },
    { 0xD85B, "vo_alley_stealth_move_to_bar_door_nag" },
    { 0xD85C, "vo_alley_stealth_price_ambush" },
    { 0xD85D, "vo_alley_stealth_price_at_door" },
    { 0xD85E, "vo_alley_stealth_price_conversation" },
    { 0xD85F, "vo_alley_stealth_quickly_and_quietly" },
    { 0xD860, "vo_alley_throw_smoke_nag_dialogue" },
    { 0xD861, "vo_allies_moving_up" },
    { 0xD862, "vo_ally_warn_me" },
    { 0xD863, "vo_ambush_callouts" },
    { 0xD864, "vo_ambush_enter" },
    { 0xD865, "vo_apartment_civ_hallway" },
    { 0xD866, "vo_apartment_civ_shocked" },
    { 0xD867, "vo_apartment_civ_stairs" },
    { 0xD868, "vo_apartment_enforcer_grenade_taunt" },
    { 0xD869, "vo_apartment_enforcer_hallway_taunt" },
    { 0xD86A, "vo_apartment_price_flank_target" },
    { 0xD86B, "vo_apartment_price_grenade_aftermath" },
    { 0xD86C, "vo_apartment_price_spotted_target" },
    { 0xD86D, "vo_apartment_price_tell_player_to_hurry" },
    { 0xD86E, "vo_armen_bg_convo" },
    { 0xD86F, "vo_armory_01_approach" },
    { 0xD870, "vo_back_room_butcher_conversation" },
    { 0xD871, "vo_back_room_butcher_conversation_commentary" },
    { 0xD872, "vo_back_room_enemies_dead" },
    { 0xD873, "vo_back_room_enemy_engaged" },
    { 0xD874, "vo_back_room_player_blew_cover" },
    { 0xD875, "vo_back_room_player_rushed_door" },
    { 0xD876, "vo_back_room_price_dont_kill_butcher" },
    { 0xD877, "vo_back_room_price_on_your_mark" },
    { 0xD878, "vo_bar_shootout_approaching_kitchen" },
    { 0xD879, "vo_bar_shootout_enemies_cleared" },
    { 0xD87A, "vo_bar_shootout_entrance" },
    { 0xD87B, "vo_bar_shootout_kitchen_clear" },
    { 0xD87C, "vo_bar_shootout_through_door" },
    { 0xD87D, "vo_bar_street_civilians" },
    { 0xD87E, "vo_bar_street_enemies_cleared" },
    { 0xD87F, "vo_bar_street_enforcer_flee" },
    { 0xD880, "vo_bar_street_wheres_enforcer" },
    { 0xD881, "vo_beam_ally_close" },
    { 0xD882, "vo_beam_confirms" },
    { 0xD883, "vo_beam_cooldown" },
    { 0xD884, "vo_beam_hit" },
    { 0xD885, "vo_beam_negative" },
    { 0xD886, "vo_beam_nomark" },
    { 0xD887, "vo_body_drag_door" },
    { 0xD888, "vo_body_drag_dumpster" },
    { 0xD889, "vo_body_drag_dumpster_actor" },
    { 0xD88A, "vo_body_drag_dumpster_interrupt_think" },
    { 0xD88B, "vo_body_poke" },
    { 0xD88C, "vo_body_poking" },
    { 0xD88D, "vo_bookstore_walla" },
    { 0xD88E, "vo_break_chair_tipped_back" },
    { 0xD88F, "vo_break_cough" },
    { 0xD890, "vo_break_enough_of_this" },
    { 0xD891, "vo_break_exercise_face_me_nag" },
    { 0xD892, "vo_break_exercise_facewall_moving" },
    { 0xD893, "vo_break_exercise_facewall_nag" },
    { 0xD894, "vo_break_exercise_goto_corner_nag" },
    { 0xD895, "vo_break_exercise_left_corner_nag" },
    { 0xD896, "vo_break_exercise_not_that_corner" },
    { 0xD897, "vo_break_exercise_plans_to_escape" },
    { 0xD898, "vo_break_exercise_play_corner_dialog" },
    { 0xD899, "vo_break_exercise_shock_effort" },
    { 0xD89A, "vo_break_exercise_stay_in_corner" },
    { 0xD89B, "vo_break_exit_bed" },
    { 0xD89C, "vo_break_intro_hadir_beckon_from_bed" },
    { 0xD89D, "vo_break_intro_hadir_beckon_to_bars" },
    { 0xD89E, "vo_break_intro_hadir_calls_out" },
    { 0xD89F, "vo_break_intro_hadir_key_beckon" },
    { 0xD8A0, "vo_break_nag_out_of_cell" },
    { 0xD8A1, "vo_break_remind_dont_face_after_move" },
    { 0xD8A2, "vo_break_shoved" },
    { 0xD8A3, "vo_break_spit" },
    { 0xD8A4, "vo_break_tougher" },
    { 0xD8A5, "vo_break_try_steal_stunstick" },
    { 0xD8A6, "vo_break_wakeup" },
    { 0xD8A7, "vo_break_wboard_all_day_nag" },
    { 0xD8A8, "vo_break_wboard_azadeh_torture" },
    { 0xD8A9, "vo_break_wboard_breath_low" },
    { 0xD8AA, "vo_break_wboard_fail_breath" },
    { 0xD8AB, "vo_break_wboard_fail_wake1" },
    { 0xD8AC, "vo_break_wboard_fail_wake2" },
    { 0xD8AD, "vo_break_wboard_fail_wake3" },
    { 0xD8AE, "vo_break_wboard_hold_breath_sound_loop" },
    { 0xD8AF, "vo_break_wboard_hold_still" },
    { 0xD8B0, "vo_break_wboard_not_moving" },
    { 0xD8B1, "vo_break_wboard_obstructing_exit" },
    { 0xD8B2, "vo_break_wboard_passed" },
    { 0xD8B3, "vo_break_wboard_shove_remark" },
    { 0xD8B4, "vo_break_wboard_success_breath" },
    { 0xD8B5, "vo_break_wboard_waterboard_choke" },
    { 0xD8B6, "vo_break_wboard_waterboard_take_breath" },
    { 0xD8B7, "vo_bridge" },
    { 0xD8B8, "vo_bs_callout_to_guard_2" },
    { 0xD8B9, "vo_bs_climbing_stairs" },
    { 0xD8BA, "vo_bs_guards_discuss_punishment" },
    { 0xD8BB, "vo_bs_guards_enter" },
    { 0xD8BC, "vo_bs_guards_sounds_alert" },
    { 0xD8BD, "vo_bs_idle_lines" },
    { 0xD8BE, "vo_bs_radio_convo" },
    { 0xD8BF, "vo_bs_spotted" },
    { 0xD8C0, "vo_bs_stab_guard" },
    { 0xD8C1, "vo_bs_wait_reach_grate_or_timeout" },
    { 0xD8C2, "vo_bu_farah_screams" },
    { 0xD8C3, "vo_bu_post_breach" },
    { 0xD8C4, "vo_bu_smoke_fail" },
    { 0xD8C5, "vo_bu_spot_hadir" },
    { 0xD8C6, "vo_bu_spot_pow" },
    { 0xD8C7, "vo_bu_step_back" },
    { 0xD8C8, "vo_bu_try_open_gas_door_nag" },
    { 0xD8C9, "vo_bu_try_open_gas_lab" },
    { 0xD8CA, "vo_bu_two_enemies" },
    { 0xD8CB, "vo_bucket_is_empty" },
    { 0xD8CC, "vo_callouts" },
    { 0xD8CD, "vo_canal_aq_inbound" },
    { 0xD8CE, "vo_canal_civilian_driveby_warning" },
    { 0xD8CF, "vo_canal_enforcer_on_bridge" },
    { 0xD8D0, "vo_canal_enforcer_shoot_them" },
    { 0xD8D1, "vo_canal_price_into_alley" },
    { 0xD8D2, "vo_canal_price_rpg" },
    { 0xD8D3, "vo_canal_price_rpg_nag" },
    { 0xD8D4, "vo_categories" },
    { 0xD8D5, "vo_category_last_played_time" },
    { 0xD8D6, "vo_cb_chair_carry" },
    { 0xD8D7, "vo_cb_check_see_chair" },
    { 0xD8D8, "vo_cb_door_locked" },
    { 0xD8D9, "vo_cb_linger_no_chair" },
    { 0xD8DA, "vo_cb_look_at_drain" },
    { 0xD8DB, "vo_cb_looking_at_stairs" },
    { 0xD8DC, "vo_cb_trying_to_climb_window" },
    { 0xD8DD, "vo_cb_wait_see_chair" },
    { 0xD8DE, "vo_cb_window_view" },
    { 0xD8DF, "vo_ce_button_hint" },
    { 0xD8E0, "vo_ce_check_rock_in_volume" },
    { 0xD8E1, "vo_ce_check_rock_near_button" },
    { 0xD8E2, "vo_ce_dig_in_respawner" },
    { 0xD8E3, "vo_ce_enter_cell" },
    { 0xD8E4, "vo_ce_hit_button" },
    { 0xD8E5, "vo_ce_made_shiv" },
    { 0xD8E6, "vo_ce_nearly_hit_button" },
    { 0xD8E7, "vo_ce_opened_first_vent" },
    { 0xD8E8, "vo_ce_outside_cell_hint" },
    { 0xD8E9, "vo_ce_pickedup_first_rock" },
    { 0xD8EA, "vo_ce_pickup_spoon" },
    { 0xD8EB, "vo_ce_rock_hints" },
    { 0xD8EC, "vo_ce_vent_open_fail" },
    { 0xD8ED, "vo_chatter" },
    { 0xD8EE, "vo_check_hvt" },
    { 0xD8EF, "vo_check_hvt_final" },
    { 0xD8F0, "vo_civ_ambush_alex_dialogue" },
    { 0xD8F1, "vo_civ_ambush_ambusher_killed_dialogue" },
    { 0xD8F2, "vo_civ_ambush_ambusher_shoot_dialogue" },
    { 0xD8F3, "vo_civ_ambush_civ_react_dialogue" },
    { 0xD8F4, "vo_civ_ambush_civ_react_female_dialogue" },
    { 0xD8F5, "vo_civ_ambush_civ_react_male_dialogue" },
    { 0xD8F6, "vo_civ_ambush_friendly_hands_up_dialogue" },
    { 0xD8F7, "vo_civ_ambush_marine_hands_up_dialogue" },
    { 0xD8F8, "vo_civ_ambush_player_handsup_responsive_dialogue" },
    { 0xD8F9, "vo_civ_ambush_wounded_aq" },
    { 0xD8FA, "vo_civ_ambush_wounded_aq_init" },
    { 0xD8FB, "vo_civ_chatter" },
    { 0xD8FC, "vo_civ_death" },
    { 0xD8FD, "vo_civambush_alex_shoot_dialogue" },
    { 0xD8FE, "vo_civambush_alex_take_point" },
    { 0xD8FF, "vo_civambush_griggs_nag_dialogue" },
    { 0xD900, "vo_civambush_griggs_shoot_dialogue" },
    { 0xD901, "vo_civambush_griggs_stairwell_advance_dialogue" },
    { 0xD902, "vo_civambush_group_progress_dialogue" },
    { 0xD903, "vo_civambush_marine_intro_dialogue" },
    { 0xD904, "vo_civchatter" },
    { 0xD905, "vo_civkill" },
    { 0xD906, "vo_clear_carpark" },
    { 0xD907, "vo_collect_id" },
    { 0xD908, "vo_combat_start" },
    { 0xD909, "vo_convoy_a10_flyby_react_dialogue" },
    { 0xD90A, "vo_convoy_alex_tripwire_callout_dialogue" },
    { 0xD90B, "vo_convoy_griggs_ahead_nag_dialogue" },
    { 0xD90C, "vo_convoy_griggs_convoy_approach_dialogue" },
    { 0xD90D, "vo_convoy_griggs_move_out_dialogue" },
    { 0xD90E, "vo_convoy_griggs_move_out_dialogue_done" },
    { 0xD90F, "vo_convoy_griggs_tripwire_callout_dialogue" },
    { 0xD910, "vo_convoy_marine_convoy_greeter_dialogue" },
    { 0xD911, "vo_convoy_sledgehammer_dialogue" },
    { 0xD912, "vo_convoy_tripwire_nag_dialogue" },
    { 0xD913, "vo_convoy_tutorial_tripwire_disabled_dialogue" },
    { 0xD914, "vo_convoy_viper_arriving_dialogue" },
    { 0xD915, "vo_convoy_viper_arriving_dialogue_done" },
    { 0xD916, "vo_cr_enemies_fall_back" },
    { 0xD917, "vo_cr_kill_retreating" },
    { 0xD918, "vo_currently_playing" },
    { 0xD919, "vo_death_callout" },
    { 0xD91A, "vo_dialogue_prefix" },
    { 0xD91B, "vo_drag_scene_carry" },
    { 0xD91C, "vo_drag_scene_idle" },
    { 0xD91D, "vo_dragons_breath" },
    { 0xD91E, "vo_drone_confirms" },
    { 0xD91F, "vo_drone_cooldown" },
    { 0xD920, "vo_drone_friendlies_neg" },
    { 0xD921, "vo_drone_hit" },
    { 0xD922, "vo_drone_negative" },
    { 0xD923, "vo_drone_no_mark" },
    { 0xD924, "vo_drone_tutorial" },
    { 0xD925, "vo_enemy_underground_left" },
    { 0xD926, "vo_enemy_underground_left_internal" },
    { 0xD927, "vo_enter_lab_nag" },
    { 0xD928, "vo_escalation_patrollers" },
    { 0xD929, "vo_escape_indoors" },
    { 0xD92A, "vo_escape_outdoors" },
    { 0xD92B, "vo_evade_aq_molotov_taunt" },
    { 0xD92C, "vo_evade_aq_runby" },
    { 0xD92D, "vo_evade_aq_runby_taunt" },
    { 0xD92E, "vo_evade_butcher_taunt" },
    { 0xD92F, "vo_evade_police_dead" },
    { 0xD930, "vo_evade_police_deploy_flashbangs" },
    { 0xD931, "vo_evade_price_into_cafe" },
    { 0xD932, "vo_ex_all_dead_warehouse_nag" },
    { 0xD933, "vo_ex_ally_deaths" },
    { 0xD934, "vo_ex_barkov_escapes" },
    { 0xD935, "vo_ex_killed_sniper" },
    { 0xD936, "vo_ex_pa_russian_announcements" },
    { 0xD937, "vo_ex_reinforcements" },
    { 0xD938, "vo_ex_rpg_guy_fired" },
    { 0xD939, "vo_ex_spot_sniper" },
    { 0xD93A, "vo_ex_spotted_by_sniper" },
    { 0xD93B, "vo_expired" },
    { 0xD93C, "vo_extra_patrols" },
    { 0xD93D, "vo_fa_post_phosphorus" },
    { 0xD93E, "vo_face" },
    { 0xD93F, "vo_farah_hold_here" },
    { 0xD940, "vo_fe_burning_woods" },
    { 0xD941, "vo_ff_ambush" },
    { 0xD942, "vo_ff_combat" },
    { 0xD943, "vo_ff_exit_cellblock" },
    { 0xD944, "vo_ff_guards_at_door" },
    { 0xD945, "vo_ff_weaponlocker_nag" },
    { 0xD946, "vo_final_struggle" },
    { 0xD947, "vo_fo_callin_strike" },
    { 0xD948, "vo_fo_callout_checkpoint" },
    { 0xD949, "vo_fo_callout_railway" },
    { 0xD94A, "vo_fo_callout_suv" },
    { 0xD94B, "vo_fo_callout_truck" },
    { 0xD94C, "vo_fo_checkpoint" },
    { 0xD94D, "vo_fo_forest_walk" },
    { 0xD94E, "vo_fo_go_hot_admonishment" },
    { 0xD94F, "vo_fo_heli_complete" },
    { 0xD950, "vo_fo_overlook_kill_patrol" },
    { 0xD951, "vo_fo_overlook_killed_patrol" },
    { 0xD952, "vo_fo_overlook_player_kill_patrol" },
    { 0xD953, "vo_fo_overlook_reached_edge" },
    { 0xD954, "vo_fo_overlook_scope_around_linger" },
    { 0xD955, "vo_fo_overlook_scope_enter_chatter" },
    { 0xD956, "vo_fo_railyard" },
    { 0xD957, "vo_fo_spot_patrol" },
    { 0xD958, "vo_fo_suv_moving" },
    { 0xD959, "vo_fo_suv_patrol" },
    { 0xD95A, "vo_fo_target_calledin" },
    { 0xD95B, "vo_fo_target_hit" },
    { 0xD95C, "vo_fo_tower_only" },
    { 0xD95D, "vo_fo_turn_off_light" },
    { 0xD95E, "vo_fob_center_snipers" },
    { 0xD95F, "vo_fp_flashlight_nag" },
    { 0xD960, "vo_fp_going_hot" },
    { 0xD961, "vo_fp_patrol_eliminated" },
    { 0xD962, "vo_fp_patrol_incoming" },
    { 0xD963, "vo_friendly_fire_dialogue" },
    { 0xD964, "vo_functions" },
    { 0xD965, "vo_fusebox" },
    { 0xD966, "vo_gate" },
    { 0xD967, "vo_gauntlet_init_van_damage_nags" },
    { 0xD968, "vo_gauntlet_player_approach_enforcer" },
    { 0xD969, "vo_gauntlet_player_chase_enforcer" },
    { 0xD96A, "vo_gauntlet_player_in_van" },
    { 0xD96B, "vo_gauntlet_police_incoming" },
    { 0xD96C, "vo_gauntlet_price_get_in_van" },
    { 0xD96D, "vo_gauntlet_price_heading_for_river" },
    { 0xD96E, "vo_gauntlet_van_almost_leaves" },
    { 0xD96F, "vo_gauntlet_van_damage_warning" },
    { 0xD970, "vo_gauntlet_van_leaves" },
    { 0xD971, "vo_get_closest_available_marine" },
    { 0xD972, "vo_go_left_right_nags" },
    { 0xD973, "vo_groundfloor_alex_corner_dialogue" },
    { 0xD974, "vo_groundfloor_alex_tripwire_defused_dialogue" },
    { 0xD975, "vo_groundfloor_civilian_screams_dialogue" },
    { 0xD976, "vo_groundfloor_griggs_hallway_ambush_dialogue" },
    { 0xD977, "vo_hadir_tunnel" },
    { 0xD978, "vo_hallway_run" },
    { 0xD979, "vo_hallway_scene" },
    { 0xD97A, "vo_heli_attack" },
    { 0xD97B, "vo_heli_sees_player" },
    { 0xD97C, "vo_heli_threaten_player" },
    { 0xD97D, "vo_help_screams" },
    { 0xD97E, "vo_hill_bottom" },
    { 0xD97F, "vo_hill_charge" },
    { 0xD980, "vo_hill_mid" },
    { 0xD981, "vo_hill_top" },
    { 0xD982, "vo_hostage_approach" },
    { 0xD983, "vo_hostage_sequence_underground_left" },
    { 0xD984, "vo_hostage_walla" },
    { 0xD985, "vo_hvt_think" },
    { 0xD986, "vo_identify_hvt" },
    { 0xD987, "vo_increment_nag_counter" },
    { 0xD988, "vo_index" },
    { 0xD989, "vo_injured_loop" },
    { 0xD98A, "vo_interrogation_acquire_nikolai_nags" },
    { 0xD98B, "vo_interrogation_acquire_nikolai_remark" },
    { 0xD98C, "vo_interrogation_ads_no_target" },
    { 0xD98D, "vo_interrogation_door_intro_linger" },
    { 0xD98E, "vo_interrogation_dry_fire" },
    { 0xD98F, "vo_interrogation_dry_fire_nags" },
    { 0xD990, "vo_interrogation_enforcer_ads" },
    { 0xD991, "vo_interrogation_enforcer_death" },
    { 0xD992, "vo_interrogation_enforcer_defeated" },
    { 0xD993, "vo_interrogation_enforcer_melee" },
    { 0xD994, "vo_interrogation_enforcer_shot" },
    { 0xD995, "vo_interrogation_escort_halt" },
    { 0xD996, "vo_interrogation_escort_move" },
    { 0xD997, "vo_interrogation_escort_nikolai_nags" },
    { 0xD998, "vo_interrogation_escort_start" },
    { 0xD999, "vo_interrogation_exit_nags" },
    { 0xD99A, "vo_interrogation_exit_player" },
    { 0xD99B, "vo_interrogation_family_ads" },
    { 0xD99C, "vo_interrogation_family_aim" },
    { 0xD99D, "vo_interrogation_family_death" },
    { 0xD99E, "vo_interrogation_family_idle_loop" },
    { 0xD99F, "vo_interrogation_family_melee" },
    { 0xD9A0, "vo_interrogation_family_scream" },
    { 0xD9A1, "vo_interrogation_final_load_weapon" },
    { 0xD9A2, "vo_interrogation_final_phase" },
    { 0xD9A3, "vo_interrogation_intro_nikolai_nags" },
    { 0xD9A4, "vo_interrogation_lines_setup" },
    { 0xD9A5, "vo_interrogation_linger_ads" },
    { 0xD9A6, "vo_interrogation_linger_idle" },
    { 0xD9A7, "vo_interrogation_linger_no_shot" },
    { 0xD9A8, "vo_interrogation_nikolai_intro" },
    { 0xD9A9, "vo_interrogation_nikolai_van_open_remark" },
    { 0xD9AA, "vo_interrogation_price_ads" },
    { 0xD9AB, "vo_interrogation_room_enter" },
    { 0xD9AC, "vo_interrogation_room_intro" },
    { 0xD9AD, "vo_interrogation_son_death" },
    { 0xD9AE, "vo_interrogation_weapon_pickup" },
    { 0xD9AF, "vo_interrogation_wife_death" },
    { 0xD9B0, "vo_intro_griggs_nag_dialogue" },
    { 0xD9B1, "vo_intro_marine_oorah_dialogue" },
    { 0xD9B2, "vo_intro_nag_manager_1" },
    { 0xD9B3, "vo_intro_nag_manager_2" },
    { 0xD9B4, "vo_intro_nag_manager_3" },
    { 0xD9B5, "vo_intro_walla" },
    { 0xD9B6, "vo_is_playing" },
    { 0xD9B7, "vo_jammerdestroyed" },
    { 0xD9B8, "vo_jammerreturning" },
    { 0xD9B9, "vo_juggernaut" },
    { 0xD9BA, "vo_juggernaut_back_room_nag" },
    { 0xD9BB, "vo_juggernaut_damage" },
    { 0xD9BC, "vo_juggernaut_death" },
    { 0xD9BD, "vo_juggernaut_fire" },
    { 0xD9BE, "vo_juggernaut_kills" },
    { 0xD9BF, "vo_keep_up_nags" },
    { 0xD9C0, "vo_killcount" },
    { 0xD9C1, "vo_knockout_manager" },
    { 0xD9C2, "vo_knockout_manager_dialogue" },
    { 0xD9C3, "vo_knockout_manager_get_random" },
    { 0xD9C4, "vo_knockout_manager_reset_check" },
    { 0xD9C5, "vo_left_crash_react" },
    { 0xD9C6, "vo_length" },
    { 0xD9C7, "vo_light_enemies_convo" },
    { 0xD9C8, "vo_light_nag_if_not_shot" },
    { 0xD9C9, "vo_light_shot_enemy_chatter" },
    { 0xD9CA, "vo_light_tut" },
    { 0xD9CB, "vo_lilly_civ_react" },
    { 0xD9CC, "vo_lilly_execution" },
    { 0xD9CD, "vo_lillywhites_cleared" },
    { 0xD9CE, "vo_lobby_griggs_nag_dialogue" },
    { 0xD9CF, "vo_lobby_griggs_secure_lobby_dialogue" },
    { 0xD9D0, "vo_lobby_marine_civ_warning_dialogue" },
    { 0xD9D1, "vo_lobby_marines_secured_dialogue" },
    { 0xD9D2, "vo_mansion_escalation" },
    { 0xD9D3, "vo_marines_leaving_area_nag" },
    { 0xD9D4, "vo_mghall_alex_tripwire_l_defused_dialogue" },
    { 0xD9D5, "vo_mghall_alex_tripwire_r_defused_dialogue" },
    { 0xD9D6, "vo_mghall_enemy_trap_shout" },
    { 0xD9D7, "vo_mghall_griggs_gunner_dead_alex_dialogue" },
    { 0xD9D8, "vo_mghall_griggs_shoot_nag_1_dialogue" },
    { 0xD9D9, "vo_mghall_griggs_shoot_nag_2_dialogue" },
    { 0xD9DA, "vo_mghall_griggs_smoked_dialogue" },
    { 0xD9DB, "vo_mghall_marine_clear_dialogue" },
    { 0xD9DC, "vo_mghall_marine_reloading_dialogue" },
    { 0xD9DD, "vo_mghall_marines_intro_dialogue" },
    { 0xD9DE, "vo_mghall_smoked_dialogue_handler" },
    { 0xD9DF, "vo_mhbreach_alex_bedroom_clear_dialogue" },
    { 0xD9E0, "vo_mhbreach_alex_civ_down_dialogue" },
    { 0xD9E1, "vo_mhbreach_alex_kitchen_clear_dialogue" },
    { 0xD9E2, "vo_mhbreach_alex_staircase_dialogue" },
    { 0xD9E3, "vo_mhbreach_alex_stairs_climbing_dialogue" },
    { 0xD9E4, "vo_mhbreach_alex_tripwire_dialogue" },
    { 0xD9E5, "vo_mhbreach_griggs_breach_dialogue" },
    { 0xD9E6, "vo_mhbreach_marine_bedroom_clear_dialogue" },
    { 0xD9E7, "vo_mhbreach_marine_clear_dialogue" },
    { 0xD9E8, "vo_mhbreach_marine_defuse_nag_1_dialogue" },
    { 0xD9E9, "vo_mhbreach_marine_defuse_nag_2_dialogue" },
    { 0xD9EA, "vo_mhbreach_marine_ready" },
    { 0xD9EB, "vo_mission_end" },
    { 0xD9EC, "vo_ms_nag_sas_door" },
    { 0xD9ED, "vo_ms_sniper_alive" },
    { 0xD9EE, "vo_murderhole_alex_throws_smokes_dialogue" },
    { 0xD9EF, "vo_murderhole_griggs_alley_dialogue" },
    { 0xD9F0, "vo_murderhole_griggs_ied_dialogue" },
    { 0xD9F1, "vo_murderhole_griggs_smoke_advance_dialogue" },
    { 0xD9F2, "vo_murderhole_marine_throws_smokes_dialogue" },
    { 0xD9F3, "vo_murderhole_mg_dontshoot_nag_dialogue" },
    { 0xD9F4, "vo_murderhole_throw_smoke_nag_dialogue" },
    { 0xD9F5, "vo_nag_after_time" },
    { 0xD9F6, "vo_next_ambient" },
    { 0xD9F7, "vo_pipes_outdoor" },
    { 0xD9F8, "vo_played_waitforaidrop" },
    { 0xD9F9, "vo_player_crazy_fail" },
    { 0xD9FA, "vo_player_in_center_nags" },
    { 0xD9FB, "vo_player_in_mansion" },
    { 0xD9FC, "vo_player_sniping" },
    { 0xD9FD, "vo_player_wander_fail" },
    { 0xD9FE, "vo_player_wander_nag" },
    { 0xD9FF, "vo_post_bomb_walla" },
    { 0xDA00, "vo_post_gap_bomber" },
    { 0xDA01, "vo_prefix" },
    { 0xDA02, "vo_price_content_warning_nags" },
    { 0xDA03, "vo_price_kyle_content_warning" },
    { 0xDA04, "vo_price_lab_entrance_nags" },
    { 0xDA05, "vo_price_take_em_out" },
    { 0xDA06, "vo_price_warning_accepted" },
    { 0xDA07, "vo_price_warning_rejected" },
    { 0xDA08, "vo_priority_level" },
    { 0xDA09, "vo_pursuit_target_escaped_fail" },
    { 0xDA0A, "vo_pursuit_target_escaping_nag" },
    { 0xDA0B, "vo_pursuit_target_hurt_nag" },
    { 0xDA0C, "vo_pursuit_target_killed_fail" },
    { 0xDA0D, "vo_queue" },
    { 0xDA0E, "vo_radio_done" },
    { 0xDA0F, "vo_radio_start" },
    { 0xDA10, "vo_rappel" },
    { 0xDA11, "vo_rappel_ahead" },
    { 0xDA12, "vo_rb_breaching" },
    { 0xDA13, "vo_rb_reached_breach" },
    { 0xDA14, "vo_rb_ru_breach_guys" },
    { 0xDA15, "vo_rb_ru_breach_guys_pre_breach" },
    { 0xDA16, "vo_rc_mg_defeated" },
    { 0xDA17, "vo_rc_mg_grenade_hint" },
    { 0xDA18, "vo_rc_mg_hint" },
    { 0xDA19, "vo_rc_mg_reminder" },
    { 0xDA1A, "vo_rc_mg_suppress_reminder" },
    { 0xDA1B, "vo_rc_mg_suppressed" },
    { 0xDA1C, "vo_rc_mount_reminder" },
    { 0xDA1D, "vo_rc_set_mg_goal" },
    { 0xDA1E, "vo_rc_set_mg_suppress_goal" },
    { 0xDA1F, "vo_rci_mg_breach" },
    { 0xDA20, "vo_rci_player_tries_door" },
    { 0xDA21, "vo_rci_rus_radio_trans" },
    { 0xDA22, "vo_re_crawling_burner" },
    { 0xDA23, "vo_re_entrance_burner" },
    { 0xDA24, "vo_re_entrance_fire_damage" },
    { 0xDA25, "vo_re_pistol_burner" },
    { 0xDA26, "vo_re_tower_collapse" },
    { 0xDA27, "vo_resume_interrupted_dialog" },
    { 0xDA28, "vo_retreat_alex_mh_clear_dialogue" },
    { 0xDA29, "vo_retreat_alex_nags" },
    { 0xDA2A, "vo_retreat_exit_sprint_monitor" },
    { 0xDA2B, "vo_retreat_griggs_advance_bombardment_dialogue" },
    { 0xDA2C, "vo_retreat_griggs_advance_dialogue" },
    { 0xDA2D, "vo_retreat_griggs_advance_nags" },
    { 0xDA2E, "vo_retreat_helo_air_support_intro_dialogue" },
    { 0xDA2F, "vo_retreat_marine_advance_ambush_initial_dialogue" },
    { 0xDA30, "vo_retreat_marine_advance_reactions_dialogue" },
    { 0xDA31, "vo_retreat_marine_bombardment_reaction_dialogue" },
    { 0xDA32, "vo_retreat_marine_rpgs_clear_dialogue" },
    { 0xDA33, "vo_right_bomber_reaction" },
    { 0xDA34, "vo_rpg_guy" },
    { 0xDA35, "vo_searching" },
    { 0xDA36, "vo_skipped_first_location" },
    { 0xDA37, "vo_smoke_nag_dialogue" },
    { 0xDA38, "vo_snakecam_griggs_snakecam_ready_dialogue" },
    { 0xDA39, "vo_snakecam_griggs_snakecam_start_dialogue" },
    { 0xDA3A, "vo_snakecam_griggs_tripwire_start_dialogue" },
    { 0xDA3B, "vo_snakecam_hostage_dialogue" },
    { 0xDA3C, "vo_snakecam_wolf_dialogue" },
    { 0xDA3D, "vo_snakecam_wolf_speech_dialogue" },
    { 0xDA3E, "vo_sniper_bus_scene" },
    { 0xDA3F, "vo_sources" },
    { 0xDA40, "vo_stacy_killed" },
    { 0xDA41, "vo_stairs_balcony_guy" },
    { 0xDA42, "vo_stakeout_choose_weapon" },
    { 0xDA43, "vo_stakeout_civ_on_stairs_alerted" },
    { 0xDA44, "vo_stakeout_civ_on_stairs_casual" },
    { 0xDA45, "vo_stakeout_civ_on_stairs_killed" },
    { 0xDA46, "vo_stakeout_exit_apartment" },
    { 0xDA47, "vo_stakeout_fire_weapon_indoors" },
    { 0xDA48, "vo_stakeout_intro" },
    { 0xDA49, "vo_stakeout_move_to_street_level" },
    { 0xDA4A, "vo_stakeout_nikolai_gun_nag" },
    { 0xDA4B, "vo_stakeout_nikolai_stairs_nag" },
    { 0xDA4C, "vo_stakeout_pri_not_bad" },
    { 0xDA4D, "vo_stakeout_price_gun_nag" },
    { 0xDA4E, "vo_stakeout_price_in_here" },
    { 0xDA4F, "vo_stakeout_price_stairs_nag" },
    { 0xDA50, "vo_stakeout_start_down_stairs" },
    { 0xDA51, "vo_stealth_again_holster_weapon_nag" },
    { 0xDA52, "vo_struct_trig" },
    { 0xDA53, "vo_suffix" },
    { 0xDA54, "vo_suppress_alias" },
    { 0xDA55, "vo_suppress_count" },
    { 0xDA56, "vo_system" },
    { 0xDA57, "vo_system_busy" },
    { 0xDA58, "vo_system_playing_vo" },
    { 0xDA59, "vo_table" },
    { 0xDA5A, "vo_tall_grass" },
    { 0xDA5B, "vo_timeout" },
    { 0xDA5C, "vo_timeout_manager" },
    { 0xDA5D, "vo_tripwire_next_callout_time" },
    { 0xDA5E, "vo_ts_call_shotgun" },
    { 0xDA5F, "vo_ts_shotgun_nag" },
    { 0xDA60, "vo_ts_wrong_vehicle" },
    { 0xDA61, "vo_tunnel_callout" },
    { 0xDA62, "vo_tunnel_nags" },
    { 0xDA63, "vo_type" },
    { 0xDA64, "vo_underground_rescue_right" },
    { 0xDA65, "vo_underground_right_walla" },
    { 0xDA66, "vo_unkown_car" },
    { 0xDA67, "vo_use_beam_nag" },
    { 0xDA68, "vo_use_beam_nags" },
    { 0xDA69, "vo_use_drone_nags" },
    { 0xDA6A, "vo_via_flag" },
    { 0xDA6B, "vo_via_trigger" },
    { 0xDA6C, "vo_walla_charge" },
    { 0xDA6D, "vo_walla_crawl_soldiers" },
    { 0xDA6E, "vo_walla_detonation_react_01" },
    { 0xDA6F, "vo_walla_detonation_react_02" },
    { 0xDA70, "vo_walla_emergency_responders" },
    { 0xDA71, "vo_walla_expl_react" },
    { 0xDA72, "vo_walla_guards_alert" },
    { 0xDA73, "vo_walla_play_guard_alert" },
    { 0xDA74, "vo_walla_truck_gate_charge" },
    { 0xDA75, "vo_warn_missiles" },
    { 0xDA76, "vo_warn_nonsuppressed" },
    { 0xDA77, "vo_wc_all_dead" },
    { 0xDA78, "vo_wc_catwalk_defender" },
    { 0xDA79, "vo_wc_catwalk_defender_moved" },
    { 0xDA7A, "vo_wc_entered_main_warehouse" },
    { 0xDA7B, "vo_wc_first_contact" },
    { 0xDA7C, "vo_wc_first_runner" },
    { 0xDA7D, "vo_wc_head_inside_nag" },
    { 0xDA7E, "vo_wc_hear_enemies" },
    { 0xDA7F, "vo_wc_kill_runner1" },
    { 0xDA80, "vo_wc_laststand" },
    { 0xDA81, "vo_wc_shelf_runner" },
    { 0xDA82, "vo_wc_shelf_runner_killed" },
    { 0xDA83, "vo_wdg_approach_gas_truck" },
    { 0xDA84, "vo_wdg_discover_russians_callout" },
    { 0xDA85, "vo_wdg_found_button" },
    { 0xDA86, "vo_wdg_found_gas" },
    { 0xDA87, "vo_wdg_nag_exit" },
    { 0xDA88, "vo_wdg_nag_find_power" },
    { 0xDA89, "vo_wdg_tried_door_button" },
    { 0xDA8A, "vo_we_alpha1_enter_warehouse" },
    { 0xDA8B, "vo_we_bravo2_enter_warehouse" },
    { 0xDA8C, "vo_we_bravo3_enter_warehouse" },
    { 0xDA8D, "vo_we_door_approach" },
    { 0xDA8E, "vo_we_nag_enter_warehouse" },
    { 0xDA8F, "vo_we_open_door" },
    { 0xDA90, "vo_we_power_off" },
    { 0xDA91, "vo_wolf_alex_start_dialogue" },
    { 0xDA92, "vo_wolf_alex_tripwire_approach_dialogue" },
    { 0xDA93, "vo_wolf_alex_tripwire_cleared_dialogue" },
    { 0xDA94, "vo_wolf_alex_tripwire_encountered_dialogue" },
    { 0xDA95, "vo_wolf_aq_takedown_alerted_dialogue" },
    { 0xDA96, "vo_wolf_escape_entrance" },
    { 0xDA97, "vo_wolf_fail_timer_nag" },
    { 0xDA98, "vo_wolf_fail_timer_radio_nag" },
    { 0xDA99, "vo_wolf_marine_balcony_advance_dialogue" },
    { 0xDA9A, "vo_wolf_marine_tripwire_triggered_dialogue" },
    { 0xDA9B, "vo_wolf_snakecam_dialogue" },
    { 0xDA9C, "vo_wolf_wolf_tripwire_cleared_speech_dialogue" },
    { 0xDA9D, "vo_woods" },
    { 0xDA9E, "vodestroyed" },
    { 0xDA9F, "vogone" },
    { 0xDAA0, "voice" },
    { 0xDAA1, "voice_is_british_based" },
    { 0xDAA2, "voicecanburst" },
    { 0xDAA3, "voiceid" },
    { 0xDAA4, "voiceindex" },
    { 0xDAA5, "voicelastindex" },
    { 0xDAA6, "voicelines" },
    { 0xDAA7, "voicemaxindex" },
    { 0xDAA8, "void" },
    { 0xDAA9, "vol" },
    { 0xDAAA, "vol_create_and_validate_node" },
    { 0xDAAB, "vol_create_cover_nodes_from_grid_point" },
    { 0xDAAC, "vol_increase_x_coordinate" },
    { 0xDAAD, "vol_increase_y_coordinate" },
    { 0xDAAE, "vol_increase_z_coordinate" },
    { 0xDAAF, "vol_validate_grid_pos" },
    { 0xDAB0, "volume" },
    { 0xDAB1, "volume_intersection_test" },
    { 0xDAB2, "volumes" },
    { 0xDAB3, "volumetricanisotropy" },
    { 0xDAB4, "vopenedangles" },
    { 0xDAB5, "votestokick" },
    { 0xDAB6, "votimedout" },
    { 0xDAB7, "votimeendingsoon" },
    { 0xDAB8, "votimeout" },
    { 0xDAB9, "votimer" },
    { 0xDABA, "voxelrootnodesize" },
    { 0xDABB, "vpoint" },
    { 0xDABC, "vspawner" },
    { 0xDABD, "vtclassname" },
    { 0xDABE, "vtmodel" },
    { 0xDABF, "vtoverride" },
    { 0xDAC0, "vttype" },
    { 0xDAC1, "wait_01_max" },
    { 0xDAC2, "wait_01_min" },
    { 0xDAC3, "wait_02_max" },
    { 0xDAC4, "wait_02_min" },
    { 0xDAC5, "wait_after_max_spawn" },
    { 0xDAC6, "wait_all_spawns_dead" },
    { 0xDAC7, "wait_all_spawns_dead_and_time" },
    { 0xDAC8, "wait_all_vo_sources_finish_speaking" },
    { 0xDAC9, "wait_and_delete" },
    { 0xDACA, "wait_and_force_weapon_switch" },
    { 0xDACB, "wait_and_give_perk" },
    { 0xDACC, "wait_and_give_player_xp" },
    { 0xDACD, "wait_and_kill_underbarrel_grenade_launcher_monitors" },
    { 0xDACE, "wait_and_play_tutorial_message" },
    { 0xDACF, "wait_any_delay_pausable" },
    { 0xDAD0, "wait_any_delay_type" },
    { 0xDAD1, "wait_any_func_array" },
    { 0xDAD2, "wait_any_input" },
    { 0xDAD3, "wait_any_input_with_stick" },
    { 0xDAD4, "wait_any_trip_defused" },
    { 0xDAD5, "wait_assign_friendnames" },
    { 0xDAD6, "wait_at_spawn_counts" },
    { 0xDAD7, "wait_attic_enemy_death" },
    { 0xDAD8, "wait_barkov_grabs_farah" },
    { 0xDAD9, "wait_barkov_hits_farah" },
    { 0xDADA, "wait_between_shot_round" },
    { 0xDADB, "wait_between_shots" },
    { 0xDADC, "wait_check_player_anim_interference" },
    { 0xDADD, "wait_check_player_anim_interference_group" },
    { 0xDADE, "wait_clear_friendname" },
    { 0xDADF, "wait_combat_cooldown" },
    { 0xDAE0, "wait_combat_exit" },
    { 0xDAE1, "wait_do_waterboard_point" },
    { 0xDAE2, "wait_end_transition" },
    { 0xDAE3, "wait_enemy_deaths_or_clear" },
    { 0xDAE4, "wait_enter_and_leave" },
    { 0xDAE5, "wait_extraction_timer" },
    { 0xDAE6, "wait_finish_speaking" },
    { 0xDAE7, "wait_first_contact" },
    { 0xDAE8, "wait_flag_or_ai_death" },
    { 0xDAE9, "wait_floor_clear" },
    { 0xDAEA, "wait_fly_drone" },
    { 0xDAEB, "wait_for_ai_dead" },
    { 0xDAEC, "wait_for_ai_spawned" },
    { 0xDAED, "wait_for_all_extracts" },
    { 0xDAEE, "wait_for_all_group_dead" },
    { 0xDAEF, "wait_for_all_keycards" },
    { 0xDAF0, "wait_for_all_multi_group_dead" },
    { 0xDAF1, "wait_for_all_players_or_timeout" },
    { 0xDAF2, "wait_for_all_players_ready" },
    { 0xDAF3, "wait_for_an_unlocked_trigger" },
    { 0xDAF4, "wait_for_any_button_press" },
    { 0xDAF5, "wait_for_any_sat_death" },
    { 0xDAF6, "wait_for_bomb_detonator_to_stop_moving" },
    { 0xDAF7, "wait_for_boss_death" },
    { 0xDAF8, "wait_for_break_in_chatter" },
    { 0xDAF9, "wait_for_buffer_time_to_pass" },
    { 0xDAFA, "wait_for_chained_oil_fire_to_go_out" },
    { 0xDAFB, "wait_for_combat_start" },
    { 0xDAFC, "wait_for_convoy_reach_node" },
    { 0xDAFD, "wait_for_crate_drop_to_ground" },
    { 0xDAFE, "wait_for_cs_flag" },
    { 0xDAFF, "wait_for_deletables" },
    { 0xDB00, "wait_for_distant_explosion" },
    { 0xDB01, "wait_for_door_anim_end" },
    { 0xDB02, "wait_for_door_breach" },
    { 0xDB03, "wait_for_door_cut" },
    { 0xDB04, "wait_for_door_cut_long" },
    { 0xDB05, "wait_for_dropped_weapon_or_timeout" },
    { 0xDB06, "wait_for_either_flag_or_time_elapses" },
    { 0xDB07, "wait_for_either_trigger" },
    { 0xDB08, "wait_for_escort_start" },
    { 0xDB09, "wait_for_event_complete" },
    { 0xDB0A, "wait_for_exit_revive_use_hold_think" },
    { 0xDB0B, "wait_for_first_lead_pickup" },
    { 0xDB0C, "wait_for_first_player_connect" },
    { 0xDB0D, "wait_for_flag_or_time_elapses" },
    { 0xDB0E, "wait_for_flag_or_timeout" },
    { 0xDB0F, "wait_for_flags" },
    { 0xDB10, "wait_for_get_phone" },
    { 0xDB11, "wait_for_global_respawn_timer" },
    { 0xDB12, "wait_for_good_buildings_num" },
    { 0xDB13, "wait_for_group_cleared" },
    { 0xDB14, "wait_for_gunship_used" },
    { 0xDB15, "wait_for_guy_to_die_or_get_in_position" },
    { 0xDB16, "wait_for_hack" },
    { 0xDB17, "wait_for_hit" },
    { 0xDB18, "wait_for_hood_repair_done" },
    { 0xDB19, "wait_for_hostage_at_extract" },
    { 0xDB1A, "wait_for_hvt_near_exfil" },
    { 0xDB1B, "wait_for_interaction_func" },
    { 0xDB1C, "wait_for_interaction_triggered" },
    { 0xDB1D, "wait_for_jugg_death" },
    { 0xDB1E, "wait_for_killanimscript_or_time" },
    { 0xDB1F, "wait_for_manifest_searched" },
    { 0xDB20, "wait_for_mantle_inside" },
    { 0xDB21, "wait_for_mlp1_mission_ready" },
    { 0xDB22, "wait_for_mlp4_mission_ready" },
    { 0xDB23, "wait_for_near_extract" },
    { 0xDB24, "wait_for_not_using_remote" },
    { 0xDB25, "wait_for_notetrack_shock" },
    { 0xDB26, "wait_for_notify_or_timeout" },
    { 0xDB27, "wait_for_objective_complete" },
    { 0xDB28, "wait_for_open_door" },
    { 0xDB29, "wait_for_package_interact" },
    { 0xDB2A, "wait_for_passengers" },
    { 0xDB2B, "wait_for_pickup" },
    { 0xDB2C, "wait_for_pilot_pickup" },
    { 0xDB2D, "wait_for_player_nearby" },
    { 0xDB2E, "wait_for_player_pickup" },
    { 0xDB2F, "wait_for_player_to_take_weapon" },
    { 0xDB30, "wait_for_player_view" },
    { 0xDB31, "wait_for_players_near" },
    { 0xDB32, "wait_for_players_near_obj" },
    { 0xDB33, "wait_for_players_to_call" },
    { 0xDB34, "wait_for_pre_game_period" },
    { 0xDB35, "wait_for_prerequisites_complete" },
    { 0xDB36, "wait_for_question_nag" },
    { 0xDB37, "wait_for_repair_done" },
    { 0xDB38, "wait_for_repeating_event" },
    { 0xDB39, "wait_for_script_noteworthy_trigger" },
    { 0xDB3A, "wait_for_section_cut" },
    { 0xDB3B, "wait_for_section_cut_long" },
    { 0xDB3C, "wait_for_self_revive" },
    { 0xDB3D, "wait_for_sentry_acquire_target" },
    { 0xDB3E, "wait_for_soldier_at_heli" },
    { 0xDB3F, "wait_for_sounddone_or_death" },
    { 0xDB40, "wait_for_spawn_loop_to_finish" },
    { 0xDB41, "wait_for_spawners_created" },
    { 0xDB42, "wait_for_start_extraction" },
    { 0xDB43, "wait_for_strike_init_complete" },
    { 0xDB44, "wait_for_super_button_pressed" },
    { 0xDB45, "wait_for_tank_deaths" },
    { 0xDB46, "wait_for_targetname_trigger" },
    { 0xDB47, "wait_for_trigger" },
    { 0xDB48, "wait_for_trigger_or_timeout" },
    { 0xDB49, "wait_for_trigger_think" },
    { 0xDB4A, "wait_for_truck_or_player" },
    { 0xDB4B, "wait_for_truck_or_player_trigger" },
    { 0xDB4C, "wait_for_tutorial_unpause" },
    { 0xDB4D, "wait_for_van_interact" },
    { 0xDB4E, "wait_for_vip_near_heli" },
    { 0xDB4F, "wait_func" },
    { 0xDB50, "wait_get_corpse" },
    { 0xDB51, "wait_give_gun" },
    { 0xDB52, "wait_goalpos" },
    { 0xDB53, "wait_goalpos_or_msg" },
    { 0xDB54, "wait_grab_tile" },
    { 0xDB55, "wait_guys_all_reach_node" },
    { 0xDB56, "wait_guys_any_reach_node" },
    { 0xDB57, "wait_hadir_goal_or_flag" },
    { 0xDB58, "wait_hadir_sees_armory" },
    { 0xDB59, "wait_hide_bowl" },
    { 0xDB5A, "wait_hide_key" },
    { 0xDB5B, "wait_hunt_exit" },
    { 0xDB5C, "wait_if_fail_calltrain" },
    { 0xDB5D, "wait_in_position_or_timeout" },
    { 0xDB5E, "wait_infil_player_anim" },
    { 0xDB5F, "wait_last_nag_finished" },
    { 0xDB60, "wait_lock_view_to_hadir" },
    { 0xDB61, "wait_look_up_or_timeout" },
    { 0xDB62, "wait_lookat" },
    { 0xDB63, "wait_lookat_ads" },
    { 0xDB64, "wait_lookat_ads_or_timeout" },
    { 0xDB65, "wait_lookat_armory" },
    { 0xDB66, "wait_lookat_or_timeout" },
    { 0xDB67, "wait_lookaway" },
    { 0xDB68, "wait_mourn_father" },
    { 0xDB69, "wait_moving_backward" },
    { 0xDB6A, "wait_moving_forward" },
    { 0xDB6B, "wait_near" },
    { 0xDB6C, "wait_no_vehicles_and_time" },
    { 0xDB6D, "wait_node_radius" },
    { 0xDB6E, "wait_nodes" },
    { 0xDB6F, "wait_not_hidden_for_time" },
    { 0xDB70, "wait_notify" },
    { 0xDB71, "wait_on_living" },
    { 0xDB72, "wait_open_view" },
    { 0xDB73, "wait_or_skip" },
    { 0xDB74, "wait_play_end_bink" },
    { 0xDB75, "wait_player_jumping" },
    { 0xDB76, "wait_player_near" },
    { 0xDB77, "wait_player_not_looking" },
    { 0xDB78, "wait_plus_minus_vo_bucket_duration" },
    { 0xDB79, "wait_primary_equipment_button_down" },
    { 0xDB7A, "wait_primary_equipment_button_pressed" },
    { 0xDB7B, "wait_primary_equipment_button_up" },
    { 0xDB7C, "wait_progress_delay" },
    { 0xDB7D, "wait_pull_arm" },
    { 0xDB7E, "wait_random_time" },
    { 0xDB7F, "wait_ready_truck_wreck" },
    { 0xDB80, "wait_remaining_time_or_player_input" },
    { 0xDB81, "wait_restore_player_perk" },
    { 0xDB82, "wait_rpg_impact" },
    { 0xDB83, "wait_scene_on_screen_and_visible_flag" },
    { 0xDB84, "wait_scene_on_screen_distance" },
    { 0xDB85, "wait_scene_on_screen_flag" },
    { 0xDB86, "wait_searchlight_destroyed" },
    { 0xDB87, "wait_secondary_equipment_button_down" },
    { 0xDB88, "wait_secondary_equipment_button_pressed" },
    { 0xDB89, "wait_secondary_equipment_button_up" },
    { 0xDB8A, "wait_see_player" },
    { 0xDB8B, "wait_set_initial_player_count" },
    { 0xDB8C, "wait_shot_warning" },
    { 0xDB8D, "wait_show_bomb" },
    { 0xDB8E, "wait_show_cinematic_bars" },
    { 0xDB8F, "wait_soldier_death" },
    { 0xDB90, "wait_spawn_clacker_and_bomb" },
    { 0xDB91, "wait_stacy_nag_time" },
    { 0xDB92, "wait_start_choking" },
    { 0xDB93, "wait_state" },
    { 0xDB94, "wait_tanto_nag" },
    { 0xDB95, "wait_then_fn" },
    { 0xDB96, "wait_thread_end" },
    { 0xDB97, "wait_till_agent_funcs_defined" },
    { 0xDB98, "wait_till_lookat" },
    { 0xDB99, "wait_till_player_near" },
    { 0xDB9A, "wait_till_players_near_center" },
    { 0xDB9B, "wait_time" },
    { 0xDB9C, "wait_time_from_active_count" },
    { 0xDB9D, "wait_time_in_ms" },
    { 0xDB9E, "wait_times" },
    { 0xDB9F, "wait_to_be_revived" },
    { 0xDBA0, "wait_to_create_team" },
    { 0xDBA1, "wait_to_deposit_driver" },
    { 0xDBA2, "wait_to_enable_use" },
    { 0xDBA3, "wait_to_get_to_main_road" },
    { 0xDBA4, "wait_to_pickup_players" },
    { 0xDBA5, "wait_to_set_can_spawn_ambush_suicide_bomber_flag" },
    { 0xDBA6, "wait_to_set_player_currency" },
    { 0xDBA7, "wait_to_spawn" },
    { 0xDBA8, "wait_to_spawn_convoy_3" },
    { 0xDBA9, "wait_to_spawn_soldiers" },
    { 0xDBAA, "wait_toggle_clip" },
    { 0xDBAB, "wait_trigger_destructible_skylight" },
    { 0xDBAC, "wait_trip_defused" },
    { 0xDBAD, "wait_trip_defused_or_timeout" },
    { 0xDBAE, "wait_truck_door_interact" },
    { 0xDBAF, "wait_turn_off_lights" },
    { 0xDBB0, "wait_turn_off_rotor_wash" },
    { 0xDBB1, "wait_until_an_enemy_is_in_safe_area" },
    { 0xDBB2, "wait_until_anim_finishes" },
    { 0xDBB3, "wait_until_done_speaking" },
    { 0xDBB4, "wait_until_interrogation" },
    { 0xDBB5, "wait_until_players_at_station" },
    { 0xDBB6, "wait_until_vehicle_at_station" },
    { 0xDBB7, "wait_until_vision_check_satisfied_or_disabled" },
    { 0xDBB8, "wait_update_hadir_objective" },
    { 0xDBB9, "wait_upper_cell_door_button_switch" },
    { 0xDBBA, "wait_variables_initialized" },
    { 0xDBBB, "wait_vo_bucket_finish_or_interrupt" },
    { 0xDBBC, "wait_vo_line_finish" },
    { 0xDBBD, "wait_vo_source_finish_speaking" },
    { 0xDBBE, "wait_waterboard_cloth_applied" },
    { 0xDBBF, "wait_weapon_fire_cooldown" },
    { 0xDBC0, "wait_while_exfil_arrives" },
    { 0xDBC1, "waitaftershot" },
    { 0xDBC2, "waitandapplyxp" },
    { 0xDBC3, "waitanddetonate" },
    { 0xDBC4, "waitandnominatepotg" },
    { 0xDBC5, "waitandspawnclient" },
    { 0xDBC6, "waitandwatchradarsweep" },
    { 0xDBC7, "waitattachflag" },
    { 0xDBC8, "waitballlongdurationwithgameendtimeupdate" },
    { 0xDBC9, "waitbetweenbomberwaves" },
    { 0xDBCA, "waitbetweenspawnwaves" },
    { 0xDBCB, "waitbetweenspawnwaveswithtimeout" },
    { 0xDBCC, "waitclassselected" },
    { 0xDBCD, "waitcountdown" },
    { 0xDBCE, "waitcycles" },
    { 0xDBCF, "waitdelay" },
    { 0xDBD0, "waitdoextraction" },
    { 0xDBD1, "waitedtime" },
    { 0xDBD2, "waitedtospawn" },
    { 0xDBD3, "waitfor_death" },
    { 0xDBD4, "waitfor_save" },
    { 0xDBD5, "waitfor_train_explode" },
    { 0xDBD6, "waitforallplayersnearlz" },
    { 0xDBD7, "waitforallplayersnearpoint" },
    { 0xDBD8, "waitforanyplayersnearpoint" },
    { 0xDBD9, "waitforarrivedatvehicle" },
    { 0xDBDA, "waitforattackbuttoninput" },
    { 0xDBDB, "waitforbombreset" },
    { 0xDBDC, "waitforc130andforcespawnallplayers" },
    { 0xDBDD, "waitforc130destroyed" },
    { 0xDBDE, "waitforclassselect" },
    { 0xDBDF, "waitforcoverapproach" },
    { 0xDBE0, "waitforcoverapproach_mp" },
    { 0xDBE1, "waitfordeath" },
    { 0xDBE2, "waitfordooropen" },
    { 0xDBE3, "waitforentervehicle" },
    { 0xDBE4, "waitforexitvehicle" },
    { 0xDBE5, "waitforfacesound" },
    { 0xDBE6, "waitforflags" },
    { 0xDBE7, "waitforgamestartspectate" },
    { 0xDBE8, "waitforhealthregendelay" },
    { 0xDBE9, "waitforhitmarkerspostgame" },
    { 0xDBEA, "waitforhvtonboard" },
    { 0xDBEB, "waitforhvtrelease" },
    { 0xDBEC, "waitforinitialplayerloadspawnflag" },
    { 0xDBED, "waitforintrodone" },
    { 0xDBEE, "waitformatchbegin" },
    { 0xDBEF, "waitformoralesdropnearpoint" },
    { 0xDBF0, "waitformoralesguardgoinghot" },
    { 0xDBF1, "waitformoralesnearexfil" },
    { 0xDBF2, "waitformorerecordingtimeforscene" },
    { 0xDBF3, "waitfornewsaboteurspawn" },
    { 0xDBF4, "waitforobjectiveactivate" },
    { 0xDBF5, "waitforoneplayernearpoint" },
    { 0xDBF6, "waitforoverridematchstartdvar" },
    { 0xDBF7, "waitforoverridematchstartnotify" },
    { 0xDBF8, "waitforpartnerdelete" },
    { 0xDBF9, "waitforpathchange" },
    { 0xDBFA, "waitforplayerping" },
    { 0xDBFB, "waitforplayers" },
    { 0xDBFC, "waitforplayersclosetoleader" },
    { 0xDBFD, "waitforplayersonboard" },
    { 0xDBFE, "waitforpoweruseupdate" },
    { 0xDBFF, "waitforragdoll" },
    { 0xDC00, "waitforrecordingandfinalize" },
    { 0xDC01, "waitforreset" },
    { 0xDC02, "waitforsecondarypain" },
    { 0xDC03, "waitforsharpturn" },
    { 0xDC04, "waitforsharpturn_mp" },
    { 0xDC05, "waitforspawn" },
    { 0xDC06, "waitforspawnselection" },
    { 0xDC07, "waitforsquadthenleave" },
    { 0xDC08, "waitfortransientloading" },
    { 0xDC09, "waitfortriggernotify" },
    { 0xDC0A, "waitforturn" },
    { 0xDC0B, "waitforvehicleorplayernearpoint" },
    { 0xDC0C, "waitforvehiclestodeletethenspawninitial" },
    { 0xDC0D, "waitforversusmenudone" },
    { 0xDC0E, "waitforweapononuse" },
    { 0xDC0F, "waitill_path_end_watcher" },
    { 0xDC10, "waitilll_player_vehicle_pass_vehicle_node" },
    { 0xDC11, "waiting" },
    { 0xDC12, "waiting_for_door_cut" },
    { 0xDC13, "waiting_to_spawn" },
    { 0xDC14, "waitingfordoor" },
    { 0xDC15, "waitingforresponse" },
    { 0xDC16, "waitingforstealthstatechange" },
    { 0xDC17, "waitingtodeactivate" },
    { 0xDC18, "waitingtoselectclass" },
    { 0xDC19, "waitingtospawn" },
    { 0xDC1A, "waitingtospawnamortize" },
    { 0xDC1B, "waitinlaststand" },
    { 0xDC1C, "waitinspectator" },
    { 0xDC1D, "waitloadoutdone" },
    { 0xDC1E, "waitlongdurationwithgameendtimeupdate" },
    { 0xDC1F, "waitlongdurationwithhostmigrationpause" },
    { 0xDC20, "waitlzextractarrival" },
    { 0xDC21, "waitmsg" },
    { 0xDC22, "waitmsg_process_action" },
    { 0xDC23, "waitnode_trigger_debug" },
    { 0xDC24, "waitnode_trigger_delay_speed_clear" },
    { 0xDC25, "waitnode_trigger_think" },
    { 0xDC26, "waitonpowerbutton" },
    { 0xDC27, "waitontargetordeath" },
    { 0xDC28, "waitpopfov" },
    { 0xDC29, "waitprematchdone" },
    { 0xDC2A, "waitreplaysmokefxfornewplayer" },
    { 0xDC2B, "waitrespawnbutton" },
    { 0xDC2C, "waitrestoreperks" },
    { 0xDC2D, "waits" },
    { 0xDC2E, "waitsetstop" },
    { 0xDC2F, "waitskipkillcambutton" },
    { 0xDC30, "waitskipkillcambuttonduringdeathtimer" },
    { 0xDC31, "waitskipkillcamduringdeathtimer" },
    { 0xDC32, "waitskipkillcamkbm" },
    { 0xDC33, "waitsuppresstimeout" },
    { 0xDC34, "waitthenenablezone" },
    { 0xDC35, "waitthenendgame" },
    { 0xDC36, "waitthengivecyberweapon" },
    { 0xDC37, "waitthenplaynewobj" },
    { 0xDC38, "waitthensethealthregentweakable" },
    { 0xDC39, "waitthensetspawnomnvar" },
    { 0xDC3A, "waitthensetstatgroupreadonly" },
    { 0xDC3B, "waitthenshowfirsthqsplash" },
    { 0xDC3C, "waitthenshowtimer" },
    { 0xDC3D, "waitthenstopcrankedbombtimer" },
    { 0xDC3E, "waitthenunpinobj" },
    { 0xDC3F, "waittill_abort_func_ends" },
    { 0xDC40, "waittill_ai_group_dead" },
    { 0xDC41, "waittill_alive_count" },
    { 0xDC42, "waittill_all_in_array" },
    { 0xDC43, "waittill_all_spawns_dead_and_time" },
    { 0xDC44, "waittill_and_return_ent" },
    { 0xDC45, "waittill_anim_finish_or_interrupted" },
    { 0xDC46, "waittill_animend" },
    { 0xDC47, "waittill_any" },
    { 0xDC48, "waittill_any_damage" },
    { 0xDC49, "waittill_any_ents" },
    { 0xDC4A, "waittill_any_ents_array" },
    { 0xDC4B, "waittill_any_ents_or_timeout_return" },
    { 0xDC4C, "waittill_any_ents_return" },
    { 0xDC4D, "waittill_any_fact_update" },
    { 0xDC4E, "waittill_any_in_array_or_timeout" },
    { 0xDC4F, "waittill_any_in_array_or_timeout_no_endon_death" },
    { 0xDC50, "waittill_any_in_array_return" },
    { 0xDC51, "waittill_any_in_array_return_no_endon_death" },
    { 0xDC52, "waittill_any_or_timeout" },
    { 0xDC53, "waittill_any_return" },
    { 0xDC54, "waittill_any_return_no_endon_death" },
    { 0xDC55, "waittill_any_timeout" },
    { 0xDC56, "waittill_any_timeout_no_endon_death" },
    { 0xDC57, "waittill_any_triggered_return_triggerer" },
    { 0xDC58, "waittill_any_two" },
    { 0xDC59, "waittill_array_alive_count_or_timeout" },
    { 0xDC5A, "waittill_backup_death" },
    { 0xDC5B, "waittill_both_or_timeout" },
    { 0xDC5C, "waittill_car_death" },
    { 0xDC5D, "waittill_checkin_weapons" },
    { 0xDC5E, "waittill_color_change" },
    { 0xDC5F, "waittill_confirm_or_cancel" },
    { 0xDC60, "waittill_damage_thread" },
    { 0xDC61, "waittill_dead" },
    { 0xDC62, "waittill_dead_or_dying" },
    { 0xDC63, "waittill_dead_or_dying_thread" },
    { 0xDC64, "waittill_dead_thread" },
    { 0xDC65, "waittill_dead_timeout" },
    { 0xDC66, "waittill_death_for_achievement" },
    { 0xDC67, "waittill_death_or_flag" },
    { 0xDC68, "waittill_door_open_or_notifies" },
    { 0xDC69, "waittill_either" },
    { 0xDC6A, "waittill_either_function" },
    { 0xDC6B, "waittill_either_function_internal" },
    { 0xDC6C, "waittill_emp_beacon_planted" },
    { 0xDC6D, "waittill_entitiesarewithindistance" },
    { 0xDC6E, "waittill_entitiesarewithindistancesquared" },
    { 0xDC6F, "waittill_entity_in_range" },
    { 0xDC70, "waittill_entity_in_range_or_timeout" },
    { 0xDC71, "waittill_entity_out_of_range" },
    { 0xDC72, "waittill_entityisbehindentitydistance" },
    { 0xDC73, "waittill_entityislateralentitydistance" },
    { 0xDC74, "waittill_explodestring" },
    { 0xDC75, "waittill_finish_moving" },
    { 0xDC76, "waittill_fire_reached_shaft_level" },
    { 0xDC77, "waittill_first_interact_or_bash" },
    { 0xDC78, "waittill_full_or_timeout" },
    { 0xDC79, "waittill_func" },
    { 0xDC7A, "waittill_func_ends" },
    { 0xDC7B, "waittill_func_or_timeout" },
    { 0xDC7C, "waittill_gestureconditionsmet" },
    { 0xDC7D, "waittill_go_hot" },
    { 0xDC7E, "waittill_grenade_danger" },
    { 0xDC7F, "waittill_grenade_fire" },
    { 0xDC80, "waittill_grenade_throw" },
    { 0xDC81, "waittill_group_gestureconditionsmet" },
    { 0xDC82, "waittill_heli_in_air" },
    { 0xDC83, "waittill_hud_event_notify" },
    { 0xDC84, "waittill_hvt_at_vehicle" },
    { 0xDC85, "waittill_in_range" },
    { 0xDC86, "waittill_lookat_price_or_door_or_delay" },
    { 0xDC87, "waittill_match_or_timeout" },
    { 0xDC88, "waittill_match_or_timeout_return" },
    { 0xDC89, "waittill_melee_or_interact" },
    { 0xDC8A, "waittill_missile_fire" },
    { 0xDC8B, "waittill_morales_ends_delete_trucks" },
    { 0xDC8C, "waittill_msg" },
    { 0xDC8D, "waittill_multiple" },
    { 0xDC8E, "waittill_multiple_ents" },
    { 0xDC8F, "waittill_near_struct" },
    { 0xDC90, "waittill_nodialogueplaying" },
    { 0xDC91, "waittill_nonagsplaying" },
    { 0xDC92, "waittill_nonai_isnt_blocking_tank" },
    { 0xDC93, "waittill_notetrack_or_damage" },
    { 0xDC94, "waittill_notify" },
    { 0xDC95, "waittill_notify_and_time" },
    { 0xDC96, "waittill_notify_or_timeout" },
    { 0xDC97, "waittill_notify_or_timeout_hostmigration_pause" },
    { 0xDC98, "waittill_notify_or_timeout_return" },
    { 0xDC99, "waittill_notify_proc" },
    { 0xDC9A, "waittill_num_and_all_spawns_dead_and_time" },
    { 0xDC9B, "waittill_offhand_box_accessed" },
    { 0xDC9C, "waittill_or_timeout" },
    { 0xDC9D, "waittill_out_of_range" },
    { 0xDC9E, "waittill_planted" },
    { 0xDC9F, "waittill_player_aims_at_bus_scene" },
    { 0xDCA0, "waittill_player_alive" },
    { 0xDCA1, "waittill_player_close_or_death" },
    { 0xDCA2, "waittill_player_exits" },
    { 0xDCA3, "waittill_player_exits_cam" },
    { 0xDCA4, "waittill_player_hidden" },
    { 0xDCA5, "waittill_player_is_close_and_sees" },
    { 0xDCA6, "waittill_player_isdefined" },
    { 0xDCA7, "waittill_player_jump_or_timeout" },
    { 0xDCA8, "waittill_player_leaves_b1" },
    { 0xDCA9, "waittill_player_look_bomber" },
    { 0xDCAA, "waittill_player_lookat" },
    { 0xDCAB, "waittill_player_lookat_failsafe" },
    { 0xDCAC, "waittill_player_lookat_for_time" },
    { 0xDCAD, "waittill_player_looks_at_hallway" },
    { 0xDCAE, "waittill_player_looks_or_timeout" },
    { 0xDCAF, "waittill_player_moves_or_timeout" },
    { 0xDCB0, "waittill_player_sees_me_or_timeout" },
    { 0xDCB1, "waittill_player_stops_rotating" },
    { 0xDCB2, "waittill_player_stops_rotating_or_timeout" },
    { 0xDCB3, "waittill_player_switched_weapons" },
    { 0xDCB4, "waittill_player_weapon_holstered" },
    { 0xDCB5, "waittill_player0_isdefined" },
    { 0xDCB6, "waittill_playeroutsideradius" },
    { 0xDCB7, "waittill_players_on_roof" },
    { 0xDCB8, "waittill_price_aims_or_guy_dies" },
    { 0xDCB9, "waittill_propanes_exploded" },
    { 0xDCBA, "waittill_push_stopped" },
    { 0xDCBB, "waittill_reach_path_end_node" },
    { 0xDCBC, "waittill_reaching_time_stamp" },
    { 0xDCBD, "waittill_remainingenemycount" },
    { 0xDCBE, "waittill_remainingenemycountortimeout" },
    { 0xDCBF, "waittill_return" },
    { 0xDCC0, "waittill_return_to_colornode" },
    { 0xDCC1, "waittill_return_to_truck" },
    { 0xDCC2, "waittill_second_interact_or_bash" },
    { 0xDCC3, "waittill_see_first_vehicle_long_enough" },
    { 0xDCC4, "waittill_sniper" },
    { 0xDCC5, "waittill_spawn_notify_after_count" },
    { 0xDCC6, "waittill_spawned" },
    { 0xDCC7, "waittill_stable" },
    { 0xDCC8, "waittill_string" },
    { 0xDCC9, "waittill_string_no_endon_death" },
    { 0xDCCA, "waittill_struct_in_fov" },
    { 0xDCCB, "waittill_struct_or_self_within_fov" },
    { 0xDCCC, "waittill_struct_within_fov" },
    { 0xDCCD, "waittill_struct_within_fov_2" },
    { 0xDCCE, "waittill_subgoal" },
    { 0xDCCF, "waittill_succeed_fail_end" },
    { 0xDCD0, "waittill_tag_calculated_on_path_grid" },
    { 0xDCD1, "waittill_targetname_volume_dead_then_set_flag" },
    { 0xDCD2, "waittill_technical_turns_or_timeout" },
    { 0xDCD3, "waittill_time" },
    { 0xDCD4, "waittill_timeout_proc" },
    { 0xDCD5, "waittill_trigger_activated_or_player_death" },
    { 0xDCD6, "waittill_trigger_or_dead" },
    { 0xDCD7, "waittill_trigger_pipes" },
    { 0xDCD8, "waittill_triggered_current" },
    { 0xDCD9, "waittill_true_goal" },
    { 0xDCDA, "waittill_turret_is_released" },
    { 0xDCDB, "waittill_usebutton_released_or_time" },
    { 0xDCDC, "waittill_vehicle_node_reached" },
    { 0xDCDD, "waittill_vehicle_node_reached_targetname" },
    { 0xDCDE, "waittill_volume_dead" },
    { 0xDCDF, "waittill_volume_dead_or_dying" },
    { 0xDCE0, "waittill_volume_dead_then_set_flag" },
    { 0xDCE1, "waittill_window_event" },
    { 0xDCE2, "waittill_within_fov_from_dist" },
    { 0xDCE3, "waittillallarenasshutdown" },
    { 0xDCE4, "waittillarriveatdestination" },
    { 0xDCE5, "waittillarriveathvt" },
    { 0xDCE6, "waittillballhostmigrationstarts" },
    { 0xDCE7, "waittillballoonready" },
    { 0xDCE8, "waittillcanspawnclient" },
    { 0xDCE9, "waittillcompromised" },
    { 0xDCEA, "waittillconvoydead" },
    { 0xDCEB, "waittilldeath" },
    { 0xDCEC, "waittilldeathorpaindeath" },
    { 0xDCED, "waittilldeletedordeath" },
    { 0xDCEE, "waittillenabled" },
    { 0xDCEF, "waittillgrenadedrops" },
    { 0xDCF0, "waittillgulagmatchend" },
    { 0xDCF1, "waittillhealthlow" },
    { 0xDCF2, "waittillhostmigrationdone" },
    { 0xDCF3, "waittillhostmigrationstarts" },
    { 0xDCF4, "waittillkillcamover" },
    { 0xDCF5, "waittillmatch_any_return" },
    { 0xDCF6, "waittillmatch_notify" },
    { 0xDCF7, "waittillmatch_string" },
    { 0xDCF8, "waittillnextloottime" },
    { 0xDCF9, "waittillnotifyorflag" },
    { 0xDCFA, "waittillobjectiveevent" },
    { 0xDCFB, "waittillobjectivereplaced" },
    { 0xDCFC, "waittillphysicsmodelstops" },
    { 0xDCFD, "waittillplayercanloot" },
    { 0xDCFE, "waittillplayerdoneskydivingac130" },
    { 0xDCFF, "waittillplayersleavearea" },
    { 0xDD00, "waittillrecoveredhealth" },
    { 0xDD01, "waittillreloadfinished" },
    { 0xDD02, "waittillrestartordistance" },
    { 0xDD03, "waittillscriptchange" },
    { 0xDD04, "waittillslowprocessallowed" },
    { 0xDD05, "waittillthread" },
    { 0xDD06, "waittillthread_proc" },
    { 0xDD07, "waittilltoofarz" },
    { 0xDD08, "waittime" },
    { 0xDD09, "waittime_process_action" },
    { 0xDD0A, "waittimebetweenregen" },
    { 0xDD0B, "waittooverridegraceperiod" },
    { 0xDD0C, "waittoplayinfildialog" },
    { 0xDD0D, "waittoprocess" },
    { 0xDD0E, "waittoresumemovement" },
    { 0xDD0F, "waittorunqueuedtaunts" },
    { 0xDD10, "waittoshameplayer" },
    { 0xDD11, "waittospawnbtmbombs" },
    { 0xDD12, "waittospawnjuggcrate" },
    { 0xDD13, "waittospawnvip" },
    { 0xDD14, "waittostarthelidown" },
    { 0xDD15, "waituntilfinishedwithdeployweapon" },
    { 0xDD16, "waituntillnotetrack_internal" },
    { 0xDD17, "waituntilnotetrack" },
    { 0xDD18, "waituntilnotetrack_safe" },
    { 0xDD19, "waituntilnotinbadplace" },
    { 0xDD1A, "waituntilunmarked" },
    { 0xDD1B, "waituntilunmarkedinternal" },
    { 0xDD1C, "waituntilwaverelease" },
    { 0xDD1D, "wake_snipers" },
    { 0xDD1E, "wake_up" },
    { 0xDD1F, "wakeup_if_chased" },
    { 0xDD20, "walk_accuracy" },
    { 0xDD21, "walk_and_talk" },
    { 0xDD22, "walk_and_talk_hemisphere" },
    { 0xDD23, "walk_and_talk_requested" },
    { 0xDD24, "walk_and_talk_target" },
    { 0xDD25, "walk_override_weights" },
    { 0xDD26, "walk_overrideanim" },
    { 0xDD27, "walk_to_dad" },
    { 0xDD28, "walkandtalkdonotetracks" },
    { 0xDD29, "walkdist_reset" },
    { 0xDD2A, "walkdist_zero" },
    { 0xDD2B, "walking_vig_handler" },
    { 0xDD2C, "walkto_1f_anims" },
    { 0xDD2D, "walkto_1f_price_anims" },
    { 0xDD2E, "walkto_boy" },
    { 0xDD2F, "walkto_door_anims" },
    { 0xDD30, "walkto_mom" },
    { 0xDD31, "walkto_tunnels" },
    { 0xDD32, "walkto_tunnels_anim" },
    { 0xDD33, "wall" },
    { 0xDD34, "wall_actors" },
    { 0xDD35, "wall_buys" },
    { 0xDD36, "wall_info" },
    { 0xDD37, "wall_kill_reveal" },
    { 0xDD38, "wall_run_attach_anim" },
    { 0xDD39, "wall_run_current_node_index" },
    { 0xDD3A, "wall_run_direction" },
    { 0xDD3B, "wall_run_double_jumping" },
    { 0xDD3C, "wall_run_yaw" },
    { 0xDD3D, "wall_truck" },
    { 0xDD3E, "wall_truck_civ_exit_points" },
    { 0xDD3F, "wall_truck_civ_hiding_spots" },
    { 0xDD40, "wall_truck_civs" },
    { 0xDD41, "wall_truck_wall_post" },
    { 0xDD42, "wall_truck_wall_post_2" },
    { 0xDD43, "wall_truck_wall_pre" },
    { 0xDD44, "wall_units" },
    { 0xDD45, "wall_units_required" },
    { 0xDD46, "wall_weapon_list" },
    { 0xDD47, "walla_apt_wounded" },
    { 0xDD48, "walla_bar_street" },
    { 0xDD49, "walla_cafe_reinforcements" },
    { 0xDD4A, "walla_canal_civs_01" },
    { 0xDD4B, "walla_canal_civs_02" },
    { 0xDD4C, "walla_deck" },
    { 0xDD4D, "walla_man_and_woman_hallway" },
    { 0xDD4E, "walla_mom_child_hallway" },
    { 0xDD4F, "walla_van_accident" },
    { 0xDD50, "wallbuyinteractions" },
    { 0xDD51, "wallprompt" },
    { 0xDD52, "wallrunnotehandler" },
    { 0xDD53, "wallrunterminate" },
    { 0xDD54, "wallscenenodeang" },
    { 0xDD55, "wallscenenodepos" },
    { 0xDD56, "wander_fail_volumes" },
    { 0xDD57, "wander_nag_volumes" },
    { 0xDD58, "wants_to_fire" },
    { 0xDD59, "wantsafespawn" },
    { 0xDD5A, "wantshotgun" },
    { 0xDD5B, "wantstocrouch" },
    { 0xDD5C, "warehouse_audio_rolling_door_open" },
    { 0xDD5D, "warehouse_cascade" },
    { 0xDD5E, "warehouse_discover_gas_ally_cleanup" },
    { 0xDD5F, "warehouse_discover_gas_catchup" },
    { 0xDD60, "warehouse_discover_gas_exit_door" },
    { 0xDD61, "warehouse_discover_gas_main" },
    { 0xDD62, "warehouse_discover_gas_start" },
    { 0xDD63, "warehouse_discover_gas_teleport_allies" },
    { 0xDD64, "warehouse_enter_catchup" },
    { 0xDD65, "warehouse_enter_main" },
    { 0xDD66, "warehouse_enter_start" },
    { 0xDD67, "warehouse_enter_teleport" },
    { 0xDD68, "warehouse_garage_door_open_audio" },
    { 0xDD69, "warehouse_laststand_spawn_func" },
    { 0xDD6A, "warehouse_sun_settings" },
    { 0xDD6B, "warehousegate" },
    { 0xDD6C, "warehousegateopenref" },
    { 0xDD6D, "warehouselighttable" },
    { 0xDD6E, "warning_shots_at_gate" },
    { 0xDD6F, "warning_sweep_destination" },
    { 0xDD70, "warning_sweep_origin" },
    { 0xDD71, "warning_time" },
    { 0xDD72, "warningcinderblockradii" },
    { 0xDD73, "warningcooldowntime" },
    { 0xDD74, "warningcooldowntimers" },
    { 0xDD75, "warningfunctions" },
    { 0xDD76, "warningidmap" },
    { 0xDD77, "warningnames" },
    { 0xDD78, "warningradiisq" },
    { 0xDD79, "warningradiusoverridefunctions" },
    { 0xDD7A, "warningrumbletypes" },
    { 0xDD7B, "warningsoundentities" },
    { 0xDD7C, "warningsoundindex" },
    { 0xDD7D, "warningsounds" },
    { 0xDD7E, "warningtimers" },
    { 0xDD7F, "warp_struct_cooldown" },
    { 0xDD80, "warp_to_last_good_pos" },
    { 0xDD81, "warpend" },
    { 0xDD82, "warpstart" },
    { 0xDD83, "was_branch" },
    { 0xDD84, "was_headshot" },
    { 0xDD85, "was_opened_halfway" },
    { 0xDD86, "was_recent_pain" },
    { 0xDD87, "was_used" },
    { 0xDD88, "was_using_turret" },
    { 0xDD89, "wasads" },
    { 0xDD8A, "wasaimeleedbyplayer" },
    { 0xDD8B, "wasaimingdownsightsondamage" },
    { 0xDD8C, "wasaliveatmatchstart" },
    { 0xDD8D, "waschained" },
    { 0xDD8E, "wasdamaged" },
    { 0xDD8F, "wasdamagedbyexplosive" },
    { 0xDD90, "wasdamagedbyoffhandshield" },
    { 0xDD91, "wasdamagedfrombulletpenetration" },
    { 0xDD92, "wasdamagedfrombulletricochet" },
    { 0xDD93, "wasindent" },
    { 0xDD94, "waslastround" },
    { 0xDD95, "wasleftunoccupied" },
    { 0xDD96, "wasmajoritycapprogress" },
    { 0xDD97, "wasonlyround" },
    { 0xDD98, "waspartjustdismembered" },
    { 0xDD99, "wasrefunded" },
    { 0xDD9A, "wasrevivespawn" },
    { 0xDD9B, "wasstalemate" },
    { 0xDD9C, "wasswitchingteamsforonplayerkilled" },
    { 0xDD9D, "wasti" },
    { 0xDD9E, "wasuncontested" },
    { 0xDD9F, "waswinning" },
    { 0xDDA0, "watch_agent_death" },
    { 0xDDA1, "watch_aim_target_think" },
    { 0xDDA2, "watch_armory_clear" },
    { 0xDDA3, "watch_bot_died_during_crate" },
    { 0xDDA4, "watch_bot_died_during_revive" },
    { 0xDDA5, "watch_dpad" },
    { 0xDDA6, "watch_end_switchblade" },
    { 0xDDA7, "watch_final_spawners" },
    { 0xDDA8, "watch_for_ai_events" },
    { 0xDDA9, "watch_for_ai_nearby" },
    { 0xDDAA, "watch_for_alarm_triggered" },
    { 0xDDAB, "watch_for_all_groups_dead" },
    { 0xDDAC, "watch_for_all_passengers_dead" },
    { 0xDDAD, "watch_for_ambush_rpg_death" },
    { 0xDDAE, "watch_for_bad_path" },
    { 0xDDAF, "watch_for_bulletwhizby" },
    { 0xDDB0, "watch_for_c130_called" },
    { 0xDDB1, "watch_for_death" },
    { 0xDDB2, "watch_for_decoys_tracked" },
    { 0xDDB3, "watch_for_disguise_vehicle_death" },
    { 0xDDB4, "watch_for_disguised_player_death" },
    { 0xDDB5, "watch_for_disguised_player_disconnect" },
    { 0xDDB6, "watch_for_disguised_player_enter_vehicle" },
    { 0xDDB7, "watch_for_disguised_player_last_stand" },
    { 0xDDB8, "watch_for_dropped_weapons" },
    { 0xDDB9, "watch_for_escape_door_breached" },
    { 0xDDBA, "watch_for_eye_remove" },
    { 0xDDBB, "watch_for_hintstring_updates" },
    { 0xDDBC, "watch_for_host_migration" },
    { 0xDDBD, "watch_for_intro_completion" },
    { 0xDDBE, "watch_for_kidnapper_death" },
    { 0xDDBF, "watch_for_lethal_weapons" },
    { 0xDDC0, "watch_for_module_endons" },
    { 0xDDC1, "watch_for_nearby_disable" },
    { 0xDDC2, "watch_for_nuke_planted" },
    { 0xDDC3, "watch_for_objective_failure" },
    { 0xDDC4, "watch_for_objective_reached" },
    { 0xDDC5, "watch_for_objective_reached_by_all_players" },
    { 0xDDC6, "watch_for_obstacles_think" },
    { 0xDDC7, "watch_for_parachute_death" },
    { 0xDDC8, "watch_for_parachute_deployed" },
    { 0xDDC9, "watch_for_phj_spawners_triggered" },
    { 0xDDCA, "watch_for_plane_spawners" },
    { 0xDDCB, "watch_for_player_convoy" },
    { 0xDDCC, "watch_for_player_damage" },
    { 0xDDCD, "watch_for_player_out_of_range" },
    { 0xDDCE, "watch_for_player_trigger" },
    { 0xDDCF, "watch_for_players" },
    { 0xDDD0, "watch_for_players_beyond_point" },
    { 0xDDD1, "watch_for_players_beyond_point_internal" },
    { 0xDDD2, "watch_for_players_in_plane" },
    { 0xDDD3, "watch_for_players_mhc_smokers" },
    { 0xDDD4, "watch_for_players_mhc_spawners" },
    { 0xDDD5, "watch_for_retreat" },
    { 0xDDD6, "watch_for_scouts" },
    { 0xDDD7, "watch_for_scouts_loop" },
    { 0xDDD8, "watch_for_smokers" },
    { 0xDDD9, "watch_for_spawn_min_required" },
    { 0xDDDA, "watch_for_spawner_triggered" },
    { 0xDDDB, "watch_for_spawners" },
    { 0xDDDC, "watch_for_super_button" },
    { 0xDDDD, "watch_for_team_undefined" },
    { 0xDDDE, "watch_for_thermite_triggered" },
    { 0xDDDF, "watch_for_timer_on_plane" },
    { 0xDDE0, "watch_for_tree_death" },
    { 0xDDE1, "watch_for_vehicle_stuck" },
    { 0xDDE2, "watch_for_victim_death" },
    { 0xDDE3, "watch_for_weaponsfire" },
    { 0xDDE4, "watch_for_zombie_touch" },
    { 0xDDE5, "watch_goal_aborted" },
    { 0xDDE6, "watch_node_base_chance" },
    { 0xDDE7, "watch_node_chance" },
    { 0xDDE8, "watch_node_clear_data" },
    { 0xDDE9, "watch_nodes" },
    { 0xDDEA, "watch_nodes_aborted" },
    { 0xDDEB, "watch_nodes_stop" },
    { 0xDDEC, "watch_nodes_visible_crouch" },
    { 0xDDED, "watch_nodes_visible_prone" },
    { 0xDDEE, "watch_out_of_ammo" },
    { 0xDDEF, "watch_players_connecting" },
    { 0xDDF0, "watch_remove_rig" },
    { 0xDDF1, "watch_scriptable" },
    { 0xDDF2, "watch_tag_destination" },
    { 0xDDF3, "watch_target_health" },
    { 0xDDF4, "watchafk" },
    { 0xDDF5, "watchairstrikeowner" },
    { 0xDDF6, "watchallcrateusability" },
    { 0xDDF7, "watcharbitraryuptriggerenter" },
    { 0xDDF8, "watcharbitraryuptriggerexit" },
    { 0xDDF9, "watchatminedetonation" },
    { 0xDDFA, "watchatminehitonpayload" },
    { 0xDDFB, "watchaxeautopickup" },
    { 0xDDFC, "watchaxetimeout" },
    { 0xDDFD, "watchaxeuse" },
    { 0xDDFE, "watchbetbutton" },
    { 0xDDFF, "watchbetclear" },
    { 0xDE00, "watchbetplaced" },
    { 0xDE01, "watchbombtimer" },
    { 0xDE02, "watchbulletoutline" },
    { 0xDE03, "watchbulletoutlinecleanup" },
    { 0xDE04, "watchbuttondown" },
    { 0xDE05, "watchbuttonpressed" },
    { 0xDE06, "watchbuttonpressedend" },
    { 0xDE07, "watchbuttonpressedinternal" },
    { 0xDE08, "watchbuttonpressendondisconnect" },
    { 0xDE09, "watchbuttonup" },
    { 0xDE0A, "watchc4altdetonate" },
    { 0xDE0B, "watchc4altdetonation" },
    { 0xDE0C, "watchc4detonation" },
    { 0xDE0D, "watchc4implode" },
    { 0xDE0E, "watchc4stuck" },
    { 0xDE0F, "watchcameratracks" },
    { 0xDE10, "watchcarryobjectweaponswitch" },
    { 0xDE11, "watchchangeweapon" },
    { 0xDE12, "watchclosetogoal" },
    { 0xDE13, "watchcombatspeedscaler" },
    { 0xDE14, "watchconcussiongrenadeexplode" },
    { 0xDE15, "watchcrankedbombtimer" },
    { 0xDE16, "watchcrankedendgame" },
    { 0xDE17, "watchcrankedhostmigration" },
    { 0xDE18, "watchcrankedplayerhostmigration" },
    { 0xDE19, "watchcratedestroyearly" },
    { 0xDE1A, "watchcratedestroyearlyinternal" },
    { 0xDE1B, "watchcrateimpact" },
    { 0xDE1C, "watchcrateimpactfrequency" },
    { 0xDE1D, "watchcratesettle" },
    { 0xDE1E, "watchcratesettleinternal" },
    { 0xDE1F, "watchcrateuse" },
    { 0xDE20, "watchcrateuseinternal" },
    { 0xDE21, "watchdamagecycle" },
    { 0xDE22, "watchdeath" },
    { 0xDE23, "watchdeployablemarkerplacement" },
    { 0xDE24, "watchdeployweaponanimtransition" },
    { 0xDE25, "watchdeployweaponfired" },
    { 0xDE26, "watchdestructibletvs" },
    { 0xDE27, "watchdevoverridematchstart" },
    { 0xDE28, "watchdisconnect" },
    { 0xDE29, "watchdistancefromentity" },
    { 0xDE2A, "watchdistancefromstaticpoint" },
    { 0xDE2B, "watchdropcratefrommanualheli" },
    { 0xDE2C, "watchdropcratefrommanualheliinternal" },
    { 0xDE2D, "watchdropcratefromscriptedheli" },
    { 0xDE2E, "watchdropcratefromscriptedheliinternal" },
    { 0xDE2F, "watchdropcratesearly" },
    { 0xDE30, "watchdropweapons" },
    { 0xDE31, "watchdvars" },
    { 0xDE32, "watchearlyexit" },
    { 0xDE33, "watchearlyout" },
    { 0xDE34, "watchendconditions" },
    { 0xDE35, "watchendgame" },
    { 0xDE36, "watchenemyvelocity" },
    { 0xDE37, "watchentitiesinradius" },
    { 0xDE38, "watchentitydeath" },
    { 0xDE39, "watchequipmentonspawn" },
    { 0xDE3A, "watchequipmentpickup" },
    { 0xDE3B, "watcher_2f_clear" },
    { 0xDE3C, "watcher_for_core_pickup" },
    { 0xDE3D, "watcherforremovingdeployable" },
    { 0xDE3E, "watchexplosiveusable" },
    { 0xDE3F, "watchfastcrouch" },
    { 0xDE40, "watchfinalkillcamcleanup" },
    { 0xDE41, "watchfireteamleaderdisconnect" },
    { 0xDE42, "watchflagenduse" },
    { 0xDE43, "watchflagtimerpause" },
    { 0xDE44, "watchforafk" },
    { 0xDE45, "watchforallpayloadspawners" },
    { 0xDE46, "watchforambushend" },
    { 0xDE47, "watchforammouse" },
    { 0xDE48, "watchforapcdeath" },
    { 0xDE49, "watchforapctrigger" },
    { 0xDE4A, "watchforbasicplayerevents" },
    { 0xDE4B, "watchforbulletwhizby" },
    { 0xDE4C, "watchforcameralaunch" },
    { 0xDE4D, "watchforcameralookatothercameras" },
    { 0xDE4E, "watchforcancelduringgesture" },
    { 0xDE4F, "watchforcancelduringweaponswitch" },
    { 0xDE50, "watchforcapture" },
    { 0xDE51, "watchforconnectedplayers" },
    { 0xDE52, "watchforcorrectsequencecompletion" },
    { 0xDE53, "watchforcratecapture" },
    { 0xDE54, "watchforcurrentcamerahack" },
    { 0xDE55, "watchfordamage" },
    { 0xDE56, "watchfordeath" },
    { 0xDE57, "watchfordebugcompletion" },
    { 0xDE58, "watchfordelete" },
    { 0xDE59, "watchfordeletesmokeflarevisualmarker" },
    { 0xDE5A, "watchfordoorenttriggered" },
    { 0xDE5B, "watchfordoublejump" },
    { 0xDE5C, "watchfordrophintstring" },
    { 0xDE5D, "watchforearlyexit" },
    { 0xDE5E, "watchforempapply" },
    { 0xDE5F, "watchforendgame" },
    { 0xDE60, "watchforenemydistance" },
    { 0xDE61, "watchforexfilactive" },
    { 0xDE62, "watchforgameend" },
    { 0xDE63, "watchforguardclosetoplayers" },
    { 0xDE64, "watchforhelideath" },
    { 0xDE65, "watchforhelideletion" },
    { 0xDE66, "watchforhelitriptimeout" },
    { 0xDE67, "watchforhostagedroppos" },
    { 0xDE68, "watchforimpact" },
    { 0xDE69, "watchforinvalidweapon" },
    { 0xDE6A, "watchforjuggdeathdisconnect" },
    { 0xDE6B, "watchforjuggernautend" },
    { 0xDE6C, "watchforjuggproximityscore" },
    { 0xDE6D, "watchforjuggstop" },
    { 0xDE6E, "watchforkidnapkilltimeout" },
    { 0xDE6F, "watchforlaststand" },
    { 0xDE70, "watchforlookathackcam" },
    { 0xDE71, "watchforlosttarget" },
    { 0xDE72, "watchforluinotifyweaponreset" },
    { 0xDE73, "watchformanualweaponend" },
    { 0xDE74, "watchformeleeduringweaponswitch" },
    { 0xDE75, "watchforminewarning" },
    { 0xDE76, "watchforminplayersmatchstart" },
    { 0xDE77, "watchformiss" },
    { 0xDE78, "watchformoralesdroppedinpool" },
    { 0xDE79, "watchformoralesnearpointarray" },
    { 0xDE7A, "watchformoralesnearstruct" },
    { 0xDE7B, "watchfornearbyplayers" },
    { 0xDE7C, "watchfornearfriendliesandrevive" },
    { 0xDE7D, "watchfornotifies" },
    { 0xDE7E, "watchforobjectivefailure" },
    { 0xDE7F, "watchforoverseerskilled" },
    { 0xDE80, "watchforpayloadconvoygroup" },
    { 0xDE81, "watchforpayloadongoal" },
    { 0xDE82, "watchforpayloadspawngroup" },
    { 0xDE83, "watchforperkremoval" },
    { 0xDE84, "watchforpings" },
    { 0xDE85, "watchforplayerdeath" },
    { 0xDE86, "watchforplayerexit" },
    { 0xDE87, "watchforplayerfirepress" },
    { 0xDE88, "watchforplayerlookat" },
    { 0xDE89, "watchforplayermovementevents" },
    { 0xDE8A, "watchforplayernearbcrumb" },
    { 0xDE8B, "watchforplayerproximity" },
    { 0xDE8C, "watchforplayersgettingclose" },
    { 0xDE8D, "watchforplayersnearleader6" },
    { 0xDE8E, "watchforplayerzonechange" },
    { 0xDE8F, "watchforpostkilllanding" },
    { 0xDE90, "watchforrallypointdeath" },
    { 0xDE91, "watchforrespawn" },
    { 0xDE92, "watchforrpgambush" },
    { 0xDE93, "watchforrpgimpact" },
    { 0xDE94, "watchforsaboteurdeath" },
    { 0xDE95, "watchforscavengedammo" },
    { 0xDE96, "watchforsoldierkilled" },
    { 0xDE97, "watchforsquadleaddissconnect" },
    { 0xDE98, "watchforstalledpos" },
    { 0xDE99, "watchforstep4chaseplayerstopool" },
    { 0xDE9A, "watchforstep5rushplayertimer" },
    { 0xDE9B, "watchforstopambient6waves" },
    { 0xDE9C, "watchforstopwaves" },
    { 0xDE9D, "watchforsupersprintenhancedused" },
    { 0xDE9E, "watchforsuperusebegin" },
    { 0xDE9F, "watchforsuppressiondelete" },
    { 0xDEA0, "watchforupdatenotify" },
    { 0xDEA1, "watchforusermessageevents" },
    { 0xDEA2, "watchforvehiclesuspendedstate" },
    { 0xDEA3, "watchforversusdone" },
    { 0xDEA4, "watchforvipdamaged" },
    { 0xDEA5, "watchforvipdeath" },
    { 0xDEA6, "watchforwalkstopwaves" },
    { 0xDEA7, "watchforweaponchange" },
    { 0xDEA8, "watchforweapondropped" },
    { 0xDEA9, "watchforweaponfire" },
    { 0xDEAA, "watchgameend" },
    { 0xDEAB, "watchgameendleave" },
    { 0xDEAC, "watchgameinactive" },
    { 0xDEAD, "watchgamestart" },
    { 0xDEAE, "watchgametimer" },
    { 0xDEAF, "watchgasgrenadeexplode" },
    { 0xDEB0, "watchgastrigger" },
    { 0xDEB1, "watchglproxy" },
    { 0xDEB2, "watchgrenadeaxepickup" },
    { 0xDEB3, "watchgrenadedeath" },
    { 0xDEB4, "watchgrenadesheldatdeath" },
    { 0xDEB5, "watchgrenadethrows" },
    { 0xDEB6, "watchgrenadetowardsplayer" },
    { 0xDEB7, "watchgrenadetowardsplayerinternal" },
    { 0xDEB8, "watchgrenadetowardsplayertimeout" },
    { 0xDEB9, "watchgrenadeusage" },
    { 0xDEBA, "watchguardevadedamage" },
    { 0xDEBB, "watchgunsmithdebugui" },
    { 0xDEBC, "watchhardlineassists" },
    { 0xDEBD, "watchheadicon" },
    { 0xDEBE, "watchhealend" },
    { 0xDEBF, "watchhelideath" },
    { 0xDEC0, "watchhelidestroyearly" },
    { 0xDEC1, "watchhelidestroyearlyinternal" },
    { 0xDEC2, "watchhighlightfadetime" },
    { 0xDEC3, "watchhostagedrop" },
    { 0xDEC4, "watchhostmigration" },
    { 0xDEC5, "watchhostmigrationfinishedinit" },
    { 0xDEC6, "watchhostmigrationlifetime" },
    { 0xDEC7, "watchhostmigrationstartedinit" },
    { 0xDEC8, "watchhoverend" },
    { 0xDEC9, "watchhvts" },
    { 0xDECA, "watchiconupdater" },
    { 0xDECB, "watchinfiljumpanim" },
    { 0xDECC, "watchintrocleared" },
    { 0xDECD, "watchinvalidweaponchange" },
    { 0xDECE, "watchinvalidweaponswitchduringdisableweapon" },
    { 0xDECF, "watchjackalcratepickup" },
    { 0xDED0, "watchjavelinusage" },
    { 0xDED1, "watchjuggernautweaponammo" },
    { 0xDED2, "watchjuggernautweaponenduse" },
    { 0xDED3, "watchjuggernautweaponswitch" },
    { 0xDED4, "watchjugghealth" },
    { 0xDED5, "watchjuggprogress" },
    { 0xDED6, "watchjuggtimeout" },
    { 0xDED7, "watchlauncherusage" },
    { 0xDED8, "watchlethaldelay" },
    { 0xDED9, "watchlethaldelaycancel" },
    { 0xDEDA, "watchlethaldelayfeedbackplayer" },
    { 0xDEDB, "watchlethaldelayplayer" },
    { 0xDEDC, "watchlifepackboostlifetime" },
    { 0xDEDD, "watchlifepackdeath" },
    { 0xDEDE, "watchlifepackkills" },
    { 0xDEDF, "watchlifepacklifetime" },
    { 0xDEE0, "watchlifepackoutlinestate" },
    { 0xDEE1, "watchlifepackowner" },
    { 0xDEE2, "watchlifepackuse" },
    { 0xDEE3, "watchlifepackuserdeath" },
    { 0xDEE4, "watchlightswitchuse" },
    { 0xDEE5, "watchmapselectexit" },
    { 0xDEE6, "watchmapselectweapon" },
    { 0xDEE7, "watchmarkedui" },
    { 0xDEE8, "watchmarkeractivate" },
    { 0xDEE9, "watchmelee" },
    { 0xDEEA, "watchminimap" },
    { 0xDEEB, "watchmissilelaunch" },
    { 0xDEEC, "watchmissileusage" },
    { 0xDEED, "watchmodechange" },
    { 0xDEEE, "watchnukeimpact" },
    { 0xDEEF, "watchnukeweaponenduse" },
    { 0xDEF0, "watchnukeweaponswitch" },
    { 0xDEF1, "watchobjuse" },
    { 0xDEF2, "watchoffhandcancel" },
    { 0xDEF3, "watchoffhandfired" },
    { 0xDEF4, "watchoobcooldown" },
    { 0xDEF5, "watchooboutoftime" },
    { 0xDEF6, "watchoobsuppressiontrigger" },
    { 0xDEF7, "watchoobsuppressiontriggerexit" },
    { 0xDEF8, "watchoobsupressiontriggerenter" },
    { 0xDEF9, "watchoobtrigger" },
    { 0xDEFA, "watchoobtriggerenter" },
    { 0xDEFB, "watchoobtriggerexit" },
    { 0xDEFC, "watchoobtriggers" },
    { 0xDEFD, "watchoutlineremoveonkillstreakend" },
    { 0xDEFE, "watchoutlineremoveonplayerend" },
    { 0xDEFF, "watchoutofrangestrength" },
    { 0xDF00, "watchownerdeath" },
    { 0xDF01, "watchownerstatus" },
    { 0xDF02, "watchownertimeoutdeath" },
    { 0xDF03, "watchpainted" },
    { 0xDF04, "watchpaintedagain" },
    { 0xDF05, "watchpatroltarget" },
    { 0xDF06, "watchpendingscenetimeout" },
    { 0xDF07, "watchphasespeedendshift" },
    { 0xDF08, "watchphasespeedshift" },
    { 0xDF09, "watchpickup" },
    { 0xDF0A, "watchpickupcomplete" },
    { 0xDF0B, "watchplaybackbegin" },
    { 0xDF0C, "watchplaybackend" },
    { 0xDF0D, "watchplayeradstoolong" },
    { 0xDF0E, "watchplayerconnect" },
    { 0xDF0F, "watchplayerconnected" },
    { 0xDF10, "watchplayerdeath" },
    { 0xDF11, "watchplayerfailtoshoot" },
    { 0xDF12, "watchplayerfiredpistol" },
    { 0xDF13, "watchplayergunsmithdebugui" },
    { 0xDF14, "watchplayerkillstreakdeath" },
    { 0xDF15, "watchplayerkillstreakdisconnect" },
    { 0xDF16, "watchplayerkillstreakearlyexit" },
    { 0xDF17, "watchplayerkillstreakemp" },
    { 0xDF18, "watchplayerkillstreakend" },
    { 0xDF19, "watchplayerkillstreakswitchteam" },
    { 0xDF1A, "watchplayerkillstreaktimeout" },
    { 0xDF1B, "watchplayerleavingcalloutarea" },
    { 0xDF1C, "watchplayermelee" },
    { 0xDF1D, "watchplayeronground" },
    { 0xDF1E, "watchplayersspawning" },
    { 0xDF1F, "watchplayersuperdelayweapon" },
    { 0xDF20, "watchplayersuperdelayweaponspawn" },
    { 0xDF21, "watchplayerusebuttonpressed" },
    { 0xDF22, "watchprematchdone" },
    { 0xDF23, "watchproximityrevivefail" },
    { 0xDF24, "watchpushtriggers" },
    { 0xDF25, "watchradialgesture" },
    { 0xDF26, "watchradialgestureactivation" },
    { 0xDF27, "watchrallytriggeruse" },
    { 0xDF28, "watchrangefinderend" },
    { 0xDF29, "watchrapidtagpickup" },
    { 0xDF2A, "watchreloading" },
    { 0xDF2B, "watchrevengedeath" },
    { 0xDF2C, "watchrevengedisconnected" },
    { 0xDF2D, "watchrevengekill" },
    { 0xDF2E, "watchrevengevictimdisconnected" },
    { 0xDF2F, "watchsamproximity" },
    { 0xDF30, "watchsentryshockpickup" },
    { 0xDF31, "watchshockdamage" },
    { 0xDF32, "watchslowmo" },
    { 0xDF33, "watchsniperboltactionkills" },
    { 0xDF34, "watchsniperboltactionkills_ondeath" },
    { 0xDF35, "watchsniperuse" },
    { 0xDF36, "watchstingerproximity" },
    { 0xDF37, "watchstoprevenge" },
    { 0xDF38, "watchstuckinnozone" },
    { 0xDF39, "watchsuperdelay" },
    { 0xDF3A, "watchsuperdelaycancel" },
    { 0xDF3B, "watchsuperdisableplayer" },
    { 0xDF3C, "watchsuperdisableweapon" },
    { 0xDF3D, "watchsuperlottery" },
    { 0xDF3E, "watchsupertrophynotify" },
    { 0xDF3F, "watchsupplypackdeath" },
    { 0xDF40, "watchsupplypackuse" },
    { 0xDF41, "watchtarget" },
    { 0xDF42, "watchtargetchange" },
    { 0xDF43, "watchtargethealth" },
    { 0xDF44, "watchtargetlockedontobyprojectile" },
    { 0xDF45, "watchtargetmarkerentstatus" },
    { 0xDF46, "watchteammatesnearjugg" },
    { 0xDF47, "watchthermalinputchange" },
    { 0xDF48, "watchthrowingknifescavenge" },
    { 0xDF49, "watchtimerpause" },
    { 0xDF4A, "watchtofirerocketatpayload" },
    { 0xDF4B, "watchtoughenup" },
    { 0xDF4C, "watchtoughenupgameend" },
    { 0xDF4D, "watchtoughenuplifetime" },
    { 0xDF4E, "watchtoughenuplightarmorend" },
    { 0xDF4F, "watchtoughenupplayerbegin" },
    { 0xDF50, "watchtoughenupplayerend" },
    { 0xDF51, "watchturretdeployfailed" },
    { 0xDF52, "watchtvdamage" },
    { 0xDF53, "watchvehicledeath" },
    { 0xDF54, "watchvehicleforrallypointactivation" },
    { 0xDF55, "watchvehiclesuspend" },
    { 0xDF56, "watchvisibility" },
    { 0xDF57, "watchvisibilityinternal" },
    { 0xDF58, "watchvisordeath" },
    { 0xDF59, "watchweaponchange" },
    { 0xDF5A, "watchweaponchanged" },
    { 0xDF5B, "watchweaponfired" },
    { 0xDF5C, "watchweaponperkupdates" },
    { 0xDF5D, "watchweaponpickup" },
    { 0xDF5E, "watchweapontabletcallinpos" },
    { 0xDF5F, "watchweapontabletstop" },
    { 0xDF60, "watchweaponusage" },
    { 0xDF61, "water_barrel" },
    { 0xDF62, "water_barrel_death" },
    { 0xDF63, "water_barrel_init" },
    { 0xDF64, "waterbarrelshoulddie" },
    { 0xDF65, "waterboard" },
    { 0xDF66, "waterboard_anim" },
    { 0xDF67, "waterboard_check_barkov_resistance" },
    { 0xDF68, "waterboard_check_breath_fx" },
    { 0xDF69, "waterboard_check_facing" },
    { 0xDF6A, "waterboard_check_near_passout_fx" },
    { 0xDF6B, "waterboard_check_still_in_danger_zone" },
    { 0xDF6C, "waterboard_check_took_breath" },
    { 0xDF6D, "waterboard_clamp_then_spring_cam" },
    { 0xDF6E, "waterboard_clamp_to_waterboard_view" },
    { 0xDF6F, "waterboard_cloth_removed" },
    { 0xDF70, "waterboard_debug_display" },
    { 0xDF71, "waterboard_has_moved_head" },
    { 0xDF72, "waterboard_has_taken_breath" },
    { 0xDF73, "waterboard_march_check" },
    { 0xDF74, "waterboard_player_first_tilt" },
    { 0xDF75, "waterboard_player_pour_start" },
    { 0xDF76, "waterboard_pour_effects" },
    { 0xDF77, "waterboard_pour_setup" },
    { 0xDF78, "waterboard_rumble" },
    { 0xDF79, "waterboard_sfx" },
    { 0xDF7A, "waterboard_splash_effects" },
    { 0xDF7B, "waterboard_tilt_forward" },
    { 0xDF7C, "waterboard_tutorial" },
    { 0xDF7D, "waterboarddebug1" },
    { 0xDF7E, "waterboarddebug10" },
    { 0xDF7F, "waterboarddebug2" },
    { 0xDF80, "waterboarddebug3" },
    { 0xDF81, "waterboarddebug4" },
    { 0xDF82, "waterboarddebug5" },
    { 0xDF83, "waterboarddebug6" },
    { 0xDF84, "waterboarddebug7" },
    { 0xDF85, "waterboarddebug8" },
    { 0xDF86, "waterboarddebug9" },
    { 0xDF87, "waterboardindex" },
    { 0xDF88, "waterboarding_dof_barkov" },
    { 0xDF89, "waterdeletez" },
    { 0xDF8A, "waterfx" },
    { 0xDF8B, "waterimpactlife" },
    { 0xDF8C, "wave_1_autosave_manager" },
    { 0xDF8D, "wave_1_enemy_battle_line_update" },
    { 0xDF8E, "wave_1_enemy_behavior" },
    { 0xDF8F, "wave_1_enemy_reinforcements" },
    { 0xDF90, "wave_1_exploder_manager" },
    { 0xDF91, "wave_1_field_infantry" },
    { 0xDF92, "wave_1_guys" },
    { 0xDF93, "wave_1_technical_01" },
    { 0xDF94, "wave_1_technical_enemy_behavior_01" },
    { 0xDF95, "wave_1_technical_gunner_spawn_func" },
    { 0xDF96, "wave_2_enemy_behavior" },
    { 0xDF97, "wave_2_enemy_mortar" },
    { 0xDF98, "wave_2_nerf_friendlies" },
    { 0xDF99, "wave_3_building_enemy_behavior" },
    { 0xDF9A, "wave_3_player_on_roof_watcher" },
    { 0xDF9B, "wave_4_corner_enemy_behavior" },
    { 0xDF9C, "wave_4_street_enemy_behavior" },
    { 0xDF9D, "wave_4_technical_02" },
    { 0xDF9E, "wave_4_technical_03" },
    { 0xDF9F, "wave_4_technical_03_enemy_behavior" },
    { 0xDFA0, "wave_4_technical_09" },
    { 0xDFA1, "wave_4_technical_10" },
    { 0xDFA2, "wave_5_enemy_mortar" },
    { 0xDFA3, "wave_5_enemy_mortar_replacement" },
    { 0xDFA4, "wave_5_mortar_run_enemy_behavior" },
    { 0xDFA5, "wave_5_street_enemy_behavior" },
    { 0xDFA6, "wave_6_drivers" },
    { 0xDFA7, "wave_6_technical_04" },
    { 0xDFA8, "wave_6_technical_04_enemy_behavior" },
    { 0xDFA9, "wave_6_technical_05" },
    { 0xDFAA, "wave_6_technical_05_enemy_behavior" },
    { 0xDFAB, "wave_6_technical_06" },
    { 0xDFAC, "wave_6_technical_06_enemy_behavior" },
    { 0xDFAD, "wave_6_technical_07" },
    { 0xDFAE, "wave_6_technical_07_enemy_behavior" },
    { 0xDFAF, "wave_6_technical_08" },
    { 0xDFB0, "wave_6_technical_08_enemy_behavior" },
    { 0xDFB1, "wave_6_technical_08_gunner_behavior" },
    { 0xDFB2, "wave_cooldown_active" },
    { 0xDFB3, "wave_cooldown_time" },
    { 0xDFB4, "wave_difficulty" },
    { 0xDFB5, "wave_difficulty_update" },
    { 0xDFB6, "wave_go_kamikaze" },
    { 0xDFB7, "wave_max_spawns" },
    { 0xDFB8, "wave_neil_battery_pickup" },
    { 0xDFB9, "wave_neil_battery_placed" },
    { 0xDFBA, "wave_neil_floppy_pickup" },
    { 0xDFBB, "wave_neil_floppy_placed" },
    { 0xDFBC, "wave_neil_head_pickup" },
    { 0xDFBD, "wave_neil_head_placed" },
    { 0xDFBE, "wave_num" },
    { 0xDFBF, "wave_num_when_joined" },
    { 0xDFC0, "wave_outline" },
    { 0xDFC1, "wave_perc_increase" },
    { 0xDFC2, "wave_reference" },
    { 0xDFC3, "wave_reference_override" },
    { 0xDFC4, "wave_reinforce" },
    { 0xDFC5, "wave_single_progression" },
    { 0xDFC6, "wave_spawn" },
    { 0xDFC7, "wave_spawn_proc" },
    { 0xDFC8, "wave_spawn_time" },
    { 0xDFC9, "wave_spawner_overrides" },
    { 0xDFCA, "wave_spawning_throttle" },
    { 0xDFCB, "wave_table" },
    { 0xDFCC, "wave_time" },
    { 0xDFCD, "wave_time_between_spawns" },
    { 0xDFCE, "wave_use_vehicles" },
    { 0xDFCF, "wave1_enemies" },
    { 0xDFD0, "wave1_targs" },
    { 0xDFD1, "wave1guys" },
    { 0xDFD2, "wave2_targs" },
    { 0xDFD3, "wave3_targs" },
    { 0xDFD4, "wave4_targs" },
    { 0xDFD5, "wavedelay" },
    { 0xDFD6, "waveplayerspawnindex" },
    { 0xDFD7, "wavesheldwithweapon" },
    { 0xDFD8, "wavespawnindex" },
    { 0xDFD9, "wavespawntimer" },
    { 0xDFDA, "wavessurvivedthroughweapon" },
    { 0xDFDB, "waveswithweapons" },
    { 0xDFDC, "wavetimerwatcher" },
    { 0xDFDD, "waypoint" },
    { 0xDFDE, "waypoint_alpha" },
    { 0xDFDF, "waypoint_delete" },
    { 0xDFE0, "waypoint_index" },
    { 0xDFE1, "waypoint_init" },
    { 0xDFE2, "waypoint_size" },
    { 0xDFE3, "waypoint_volume" },
    { 0xDFE4, "waypointbgtype" },
    { 0xDFE5, "waypointcolors" },
    { 0xDFE6, "waypointobjnum" },
    { 0xDFE7, "waypointpulses" },
    { 0xDFE8, "waypointshader" },
    { 0xDFE9, "waypointstring" },
    { 0xDFEA, "wboardvobreathlowcount" },
    { 0xDFEB, "wboardvofailbreathcount" },
    { 0xDFEC, "wboardvoholdstillcount" },
    { 0xDFED, "wboardvonotmovingcount" },
    { 0xDFEE, "wboardvosuccessbreathcount" },
    { 0xDFEF, "weak_spot" },
    { 0xDFF0, "weak_spot_destroyed" },
    { 0xDFF1, "weapcoltfireblur" },
    { 0xDFF2, "weapfireblureffect" },
    { 0xDFF3, "weapfireradialblur" },
    { 0xDFF4, "weapon_akimbo_prop_think" },
    { 0xDFF5, "weapon_board" },
    { 0xDFF6, "weapon_build_models" },
    { 0xDFF7, "weapon_check" },
    { 0xDFF8, "weapon_clip_delete" },
    { 0xDFF9, "weapon_col" },
    { 0xDFFA, "weapon_drop_cooldown" },
    { 0xDFFB, "weapon_empty" },
    { 0xDFFC, "weapon_fire_3f_enemy1_vo" },
    { 0xDFFD, "weapon_fire_3f_enemy2_vo" },
    { 0xDFFE, "weapon_fire_monitor" },
    { 0xDFFF, "weapon_fire_vo_cooldown" },
    { 0xE000, "weapon_function_hack" },
    { 0xE001, "weapon_genade_launcher" },
    { 0xE002, "weapon_has_ranks" },
    { 0xE003, "weapon_hassight" },
    { 0xE004, "weapon_hint_func" },
    { 0xE005, "weapon_is_a_cp_mod" },
    { 0xE006, "weapon_is_a_vehicle_weapon" },
    { 0xE007, "weapon_is_cp_loot" },
    { 0xE008, "weapon_is_dlc_melee" },
    { 0xE009, "weapon_is_dlc2_melee" },
    { 0xE00A, "weapon_issilenced" },
    { 0xE00B, "weapon_knock_off_room_monitor" },
    { 0xE00C, "weapon_levels" },
    { 0xE00D, "weapon_locs" },
    { 0xE00E, "weapon_monitor" },
    { 0xE00F, "weapon_name" },
    { 0xE010, "weapon_name_log" },
    { 0xE011, "weapon_no_unlimited_check" },
    { 0xE012, "weapon_obj" },
    { 0xE013, "weapon_object" },
    { 0xE014, "weapon_passive_xp_multiplier" },
    { 0xE015, "weapon_passives" },
    { 0xE016, "weapon_progression_enabled" },
    { 0xE017, "weapon_pump_action_shotgun" },
    { 0xE018, "weapon_purchase_disabled" },
    { 0xE019, "weapon_rank_event" },
    { 0xE01A, "weapon_rank_event_table" },
    { 0xE01B, "weapon_should_get_xp" },
    { 0xE01C, "weapon_state_func" },
    { 0xE01D, "weapon_stats_override_name_func" },
    { 0xE01E, "weapon_stow" },
    { 0xE01F, "weapon_switch_monitor" },
    { 0xE020, "weapon_table" },
    { 0xE021, "weapon_think" },
    { 0xE022, "weapon_upgrade" },
    { 0xE023, "weapon_upgrade_hint_logic" },
    { 0xE024, "weapon_upgrade_interaction" },
    { 0xE025, "weapon_upgrade_path" },
    { 0xE026, "weapon_watch_hint" },
    { 0xE027, "weaponaffinityextralauncher" },
    { 0xE028, "weaponaffinityspeedboost" },
    { 0xE029, "weaponarray" },
    { 0xE02A, "weaponasset" },
    { 0xE02B, "weaponassetnamemap" },
    { 0xE02C, "weaponattachcustomtoidmap" },
    { 0xE02D, "weaponattachdefaultmap" },
    { 0xE02E, "weaponattachdefaulttoidmap" },
    { 0xE02F, "weaponattachmentperkupdate" },
    { 0xE030, "weaponattachments" },
    { 0xE031, "weaponattachremoveextraattachments" },
    { 0xE032, "weaponbypassspawnprotection" },
    { 0xE033, "weaponcanmelee" },
    { 0xE034, "weaponcanstoreaccuracystats" },
    { 0xE035, "weaponcategories" },
    { 0xE036, "weaponchangecallbacks" },
    { 0xE037, "weaponclassdata" },
    { 0xE038, "weaponclasses" },
    { 0xE039, "weaponcleanupmanualturret" },
    { 0xE03A, "weaponcleanupsentryturret" },
    { 0xE03B, "weaponconfigs" },
    { 0xE03C, "weapondamagetracepassed" },
    { 0xE03D, "weapondetonatedextraction" },
    { 0xE03E, "weapondetonatedtomastrike" },
    { 0xE03F, "weapondrop_beginsuper" },
    { 0xE040, "weapondrop_createdrop" },
    { 0xE041, "weapondrop_deploydrone" },
    { 0xE042, "weapondrop_dronedelivery" },
    { 0xE043, "weapondrop_givedropweapon" },
    { 0xE044, "weapondrop_init" },
    { 0xE045, "weapondrop_physics_callback_monitor" },
    { 0xE046, "weapondrop_physics_timeout" },
    { 0xE047, "weapondrop_used" },
    { 0xE048, "weapondropfunction" },
    { 0xE049, "weaponenabled" },
    { 0xE04A, "weaponexistsinstatstable" },
    { 0xE04B, "weaponfiredairstrike" },
    { 0xE04C, "weaponfirednuke" },
    { 0xE04D, "weaponfiredtomastrike" },
    { 0xE04E, "weaponfirepush" },
    { 0xE04F, "weaponfullstring" },
    { 0xE050, "weapongivenac130" },
    { 0xE051, "weapongivenairstrike" },
    { 0xE052, "weapongivenchoppergunner" },
    { 0xE053, "weapongivencruisepredator" },
    { 0xE054, "weapongivendeathswitch" },
    { 0xE055, "weapongivendronehive" },
    { 0xE056, "weapongivendronestrike" },
    { 0xE057, "weapongivengunship" },
    { 0xE058, "weapongivenhelperdrone" },
    { 0xE059, "weapongivenhoverjet" },
    { 0xE05A, "weapongivennuke" },
    { 0xE05B, "weapongivenremotetank" },
    { 0xE05C, "weapongiventomastrike" },
    { 0xE05D, "weapongivenwp" },
    { 0xE05E, "weapongroupmap" },
    { 0xE05F, "weaponhasattachment" },
    { 0xE060, "weaponhaslockon" },
    { 0xE061, "weaponhaspassive" },
    { 0xE062, "weaponhasranks" },
    { 0xE063, "weaponhasselectableoptic" },
    { 0xE064, "weaponhasvariants" },
    { 0xE065, "weaponhitsperattack" },
    { 0xE066, "weaponicon" },
    { 0xE067, "weaponignoresblastshield" },
    { 0xE068, "weaponitems" },
    { 0xE069, "weaponkickrecoil" },
    { 0xE06A, "weaponkills" },
    { 0xE06B, "weaponkitinitialized" },
    { 0xE06C, "weaponlasercalls" },
    { 0xE06D, "weaponlist" },
    { 0xE06E, "weaponlocallowed" },
    { 0xE06F, "weaponlocker" },
    { 0xE070, "weaponlootmapdata" },
    { 0xE071, "weaponmap_toattachdefaults" },
    { 0xE072, "weaponmap_toperk" },
    { 0xE073, "weaponmap_tospeed" },
    { 0xE074, "weaponmapdata" },
    { 0xE075, "weaponmapfunc" },
    { 0xE076, "weaponmaxval" },
    { 0xE077, "weaponnumbermap" },
    { 0xE078, "weaponobj" },
    { 0xE079, "weaponobtained" },
    { 0xE07A, "weaponoffset" },
    { 0xE07B, "weaponoverride" },
    { 0xE07C, "weaponpassives" },
    { 0xE07D, "weaponpassivesinit" },
    { 0xE07E, "weaponpassivespeedmod" },
    { 0xE07F, "weaponpassivespeedonkillmod" },
    { 0xE080, "weaponperkmap" },
    { 0xE081, "weaponperkupdate" },
    { 0xE082, "weaponpos" },
    { 0xE083, "weaponposdropping" },
    { 0xE084, "weaponranktable" },
    { 0xE085, "weaponrankxpmultipliers" },
    { 0xE086, "weaponrarities" },
    { 0xE087, "weaponrefs" },
    { 0xE088, "weaponreloadtime" },
    { 0xE089, "weaponrootcache" },
    { 0xE08A, "weapons" },
    { 0xE08B, "weapons_init" },
    { 0xE08C, "weapons_table_init" },
    { 0xE08D, "weapons_tracking_init" },
    { 0xE08E, "weapons_up" },
    { 0xE08F, "weapons_with_ir" },
    { 0xE090, "weaponsdisabledwhilereviving" },
    { 0xE091, "weaponsetupfuncs" },
    { 0xE092, "weaponshouldgetxp" },
    { 0xE093, "weaponsinit" },
    { 0xE094, "weaponslockerref" },
    { 0xE095, "weaponslot" },
    { 0xE096, "weaponsound" },
    { 0xE097, "weaponspawn" },
    { 0xE098, "weaponspeed" },
    { 0xE099, "weaponstats_reset" },
    { 0xE09A, "weaponstowfunction" },
    { 0xE09B, "weaponsupportslaserir" },
    { 0xE09C, "weaponsused" },
    { 0xE09D, "weaponswapwatcher" },
    { 0xE09E, "weaponswitchendedairstrike" },
    { 0xE09F, "weaponswitchendednuke" },
    { 0xE0A0, "weaponswitchendedsupportbox" },
    { 0xE0A1, "weaponswitchendedtomastrike" },
    { 0xE0A2, "weapontouse" },
    { 0xE0A3, "weapontracking_init" },
    { 0xE0A4, "weapontweaks" },
    { 0xE0A5, "weapontype" },
    { 0xE0A6, "weaponunlocksvialoot" },
    { 0xE0A7, "weaponuse" },
    { 0xE0A8, "weaponused" },
    { 0xE0A9, "weaponusepistolflinch" },
    { 0xE0AA, "weaponusesniperflinch" },
    { 0xE0AB, "weaponxpearned" },
    { 0xE0AC, "weaponxpenabled" },
    { 0xE0AD, "weaponxpscale" },
    { 0xE0AE, "wearing_armor" },
    { 0xE0AF, "wearing_helmet" },
    { 0xE0B0, "wearing_rat_king_eye" },
    { 0xE0B1, "weight" },
    { 0xE0B2, "weighted_array_randomize" },
    { 0xE0B3, "wepmodel" },
    { 0xE0B4, "wet_level" },
    { 0xE0B5, "what_power_is_in_slot" },
    { 0xE0B6, "wheel_tags" },
    { 0xE0B7, "wheels" },
    { 0xE0B8, "wheelson_engine_audio_game_end" },
    { 0xE0B9, "wheelson_enginesfx" },
    { 0xE0BA, "wheelson_start_engine_audio" },
    { 0xE0BB, "wheelson_stop_engine_audio" },
    { 0xE0BC, "where_am_i" },
    { 0xE0BD, "wherethehellami" },
    { 0xE0BE, "whichone" },
    { 0xE0BF, "while_simple" },
    { 0xE0C0, "whimper_loop" },
    { 0xE0C1, "white_helmet_01_mayhem" },
    { 0xE0C2, "white_helmet_02_mayhem" },
    { 0xE0C3, "white_helmet_03_mayhem" },
    { 0xE0C4, "white_helmet_04_mayhem" },
    { 0xE0C5, "white_helmet_vo" },
    { 0xE0C6, "white_phosphorus_damage_area" },
    { 0xE0C7, "white_phosphorus_getmapselectpoint" },
    { 0xE0C8, "white_phosphorus_startmapselectsequence" },
    { 0xE0C9, "whiz" },
    { 0xE0CA, "whizby_listener" },
    { 0xE0CB, "whizbyblurrampdown" },
    { 0xE0CC, "whizbyblurrampup" },
    { 0xE0CD, "whizbyblurshoweffect" },
    { 0xE0CE, "whizbyevent" },
    { 0xE0CF, "whizbyplayers" },
    { 0xE0D0, "whizbythink" },
    { 0xE0D1, "wife_react_death" },
    { 0xE0D2, "wifeanimnode" },
    { 0xE0D3, "wildcards" },
    { 0xE0D4, "wildfire_watcher" },
    { 0xE0D5, "willinfil" },
    { 0xE0D6, "wincondition" },
    { 0xE0D7, "wind" },
    { 0xE0D8, "wind_getrandomdirectionindex" },
    { 0xE0D9, "wind_index" },
    { 0xE0DA, "wind_setdirection" },
    { 0xE0DB, "winddirectionaimstring" },
    { 0xE0DC, "winddirectionaimstrings" },
    { 0xE0DD, "winddirectionindex" },
    { 0xE0DE, "winddirections" },
    { 0xE0DF, "winddirectionscardinal" },
    { 0xE0E0, "winddirectionsextreme" },
    { 0xE0E1, "winddirectionstring" },
    { 0xE0E2, "winddirectionstrings" },
    { 0xE0E3, "windmilllinkcol" },
    { 0xE0E4, "windobject" },
    { 0xE0E5, "window_back_left_corner_dead" },
    { 0xE0E6, "window_back_left_dead" },
    { 0xE0E7, "window_back_right_corner_dead" },
    { 0xE0E8, "window_back_right_dead" },
    { 0xE0E9, "window_destroy" },
    { 0xE0EA, "window_down_height" },
    { 0xE0EB, "window_entrances" },
    { 0xE0EC, "window_farahreachlogic" },
    { 0xE0ED, "window_farahskipreachlogic" },
    { 0xE0EE, "window_final_vol" },
    { 0xE0EF, "window_front_left_dead" },
    { 0xE0F0, "window_front_right_dead" },
    { 0xE0F1, "window_main" },
    { 0xE0F2, "window_melee_valid" },
    { 0xE0F3, "window_passby_helis_1" },
    { 0xE0F4, "window_passby_helis_2" },
    { 0xE0F5, "window_start" },
    { 0xE0F6, "windowandguy" },
    { 0xE0F7, "windowguys" },
    { 0xE0F8, "windowsceneref" },
    { 0xE0F9, "windshield_back_dead" },
    { 0xE0FA, "windshield_front_dead" },
    { 0xE0FB, "wingamebytype" },
    { 0xE0FC, "wingamescharge" },
    { 0xE0FD, "wingamestop3" },
    { 0xE0FE, "wingman" },
    { 0xE0FF, "wingman_getgoalpos" },
    { 0xE100, "wingman_think" },
    { 0xE101, "winlimit" },
    { 0xE102, "winner" },
    { 0xE103, "winners" },
    { 0xE104, "winningshot" },
    { 0xE105, "winrule" },
    { 0xE106, "wire" },
    { 0xE107, "wire_color" },
    { 0xE108, "wire_color_shown_on_bomb_detonator" },
    { 0xE109, "wire_currently_looking_at" },
    { 0xE10A, "wire_cut_button_press_watch" },
    { 0xE10B, "wire_look_at_hint" },
    { 0xE10C, "wire_look_at_marker" },
    { 0xE10D, "wire_look_at_markers" },
    { 0xE10E, "wire_look_at_think" },
    { 0xE10F, "wire_model" },
    { 0xE110, "wire_outline_active_and_waittill_not" },
    { 0xE111, "wire_sparks" },
    { 0xE112, "wire_type" },
    { 0xE113, "wires" },
    { 0xE114, "wires_cut" },
    { 0xE115, "withbounce" },
    { 0xE116, "within_bounds" },
    { 0xE117, "within_distance" },
    { 0xE118, "within_distance2d" },
    { 0xE119, "within_fov" },
    { 0xE11A, "within_fov_2d" },
    { 0xE11B, "within_fov_of_players" },
    { 0xE11C, "within_player_fov" },
    { 0xE11D, "within_player_fov_2d" },
    { 0xE11E, "withindistancetoenemy" },
    { 0xE11F, "withinswitchtopistoldist" },
    { 0xE120, "wmexfilally" },
    { 0xE121, "wmhostage" },
    { 0xE122, "wobblemagnitude" },
    { 0xE123, "wobbleoffset" },
    { 0xE124, "wolf" },
    { 0xE125, "wolf_actors_idle" },
    { 0xE126, "wolf_background_apc_1_sound" },
    { 0xE127, "wolf_background_apc_2_sound" },
    { 0xE128, "wolf_background_apc_3_sound" },
    { 0xE129, "wolf_background_apc_4_sound" },
    { 0xE12A, "wolf_balcony_apc_handler" },
    { 0xE12B, "wolf_balcony_player_clip_handler" },
    { 0xE12C, "wolf_barricade_clip" },
    { 0xE12D, "wolf_barricade_lookat_monitor" },
    { 0xE12E, "wolf_barricade_lookat_timeout" },
    { 0xE12F, "wolf_bomb_clacker_setup" },
    { 0xE130, "wolf_bomb_tablet" },
    { 0xE131, "wolf_bomb_tablet_pickup" },
    { 0xE132, "wolf_bomb_tablet_setup" },
    { 0xE133, "wolf_bomb_vest" },
    { 0xE134, "wolf_bomb_vest_defuse_anim" },
    { 0xE135, "wolf_bomb_vest_defuse_dof" },
    { 0xE136, "wolf_bomb_vest_defuse_looked_at_any_wire" },
    { 0xE137, "wolf_bomb_vest_farah_defuse_enter_anim" },
    { 0xE138, "wolf_bomb_vest_farah_defuse_enter_anim_loop" },
    { 0xE139, "wolf_bomb_vest_think" },
    { 0xE13A, "wolf_cameraman" },
    { 0xE13B, "wolf_cameraman_camera_handler" },
    { 0xE13C, "wolf_cameraman_handler" },
    { 0xE13D, "wolf_cameraman_struct" },
    { 0xE13E, "wolf_catchup" },
    { 0xE13F, "wolf_clacker" },
    { 0xE140, "wolf_clear_window_barricade" },
    { 0xE141, "wolf_damage_monitor" },
    { 0xE142, "wolf_damage_watcher" },
    { 0xE143, "wolf_death_angles" },
    { 0xE144, "wolf_death_detect_molotov_wolf_kill" },
    { 0xE145, "wolf_death_detect_player_escapes_wolf" },
    { 0xE146, "wolf_death_detect_player_shoot_vest" },
    { 0xE147, "wolf_death_detect_player_shoots_next_to_wolf" },
    { 0xE148, "wolf_death_detect_player_too_close_to_wolf" },
    { 0xE149, "wolf_death_detect_player_wolf_kill" },
    { 0xE14A, "wolf_death_eye" },
    { 0xE14B, "wolf_death_fail_due_to_damage" },
    { 0xE14C, "wolf_death_farah_points_out_vest_vo" },
    { 0xE14D, "wolf_death_intro" },
    { 0xE14E, "wolf_death_intro_farah_anim" },
    { 0xE14F, "wolf_death_intro_wolf_monologue" },
    { 0xE150, "wolf_death_origin" },
    { 0xE151, "wolf_death_player_cleared_door" },
    { 0xE152, "wolf_defuse_anim" },
    { 0xE153, "wolf_dialog_struct" },
    { 0xE154, "wolf_dies_in_last_frame" },
    { 0xE155, "wolf_door_a_explosion" },
    { 0xE156, "wolf_door_b_explosion" },
    { 0xE157, "wolf_door_light" },
    { 0xE158, "wolf_escape_door_nags" },
    { 0xE159, "wolf_escapes_fx" },
    { 0xE15A, "wolf_escapes_vo" },
    { 0xE15B, "wolf_execute_struct" },
    { 0xE15C, "wolf_executes_hostage" },
    { 0xE15D, "wolf_executioner" },
    { 0xE15E, "wolf_executioner_handler" },
    { 0xE15F, "wolf_executioner_struct" },
    { 0xE160, "wolf_fail_and_save_manager" },
    { 0xE161, "wolf_fail_state_active" },
    { 0xE162, "wolf_fail_timer_logic" },
    { 0xE163, "wolf_flank_tripwire_door" },
    { 0xE164, "wolf_flank_tripwire_door_ajar_handler" },
    { 0xE165, "wolf_flank_tripwire_door_dialogue" },
    { 0xE166, "wolf_flank_tripwire_door_monitor" },
    { 0xE167, "wolf_friendly_fire_think" },
    { 0xE168, "wolf_guard_behavior_setup" },
    { 0xE169, "wolf_guard_grenade_alert" },
    { 0xE16A, "wolf_guard_shooting_alert" },
    { 0xE16B, "wolf_guard_sighting_alert" },
    { 0xE16C, "wolf_guard_sighting_force" },
    { 0xE16D, "wolf_guards_breach_reaction_flag" },
    { 0xE16E, "wolf_guards_breach_reaction_notify" },
    { 0xE16F, "wolf_handler" },
    { 0xE170, "wolf_hostage_1" },
    { 0xE171, "wolf_hostage_1_struct" },
    { 0xE172, "wolf_hostage_2" },
    { 0xE173, "wolf_hostage_2_struct" },
    { 0xE174, "wolf_hostage_3" },
    { 0xE175, "wolf_hostage_3_struct" },
    { 0xE176, "wolf_hostage_check_damage" },
    { 0xE177, "wolf_hostage_handler" },
    { 0xE178, "wolf_hostage_ignoreme_monitor" },
    { 0xE179, "wolf_hostage_takedown_monitor" },
    { 0xE17A, "wolf_hostages" },
    { 0xE17B, "wolf_killed" },
    { 0xE17C, "wolf_killed_fail_state" },
    { 0xE17D, "wolf_los_handler" },
    { 0xE17E, "wolf_machete_prop" },
    { 0xE17F, "wolf_machete_struct" },
    { 0xE180, "wolf_main" },
    { 0xE181, "wolf_nag_count" },
    { 0xE182, "wolf_nag_counter" },
    { 0xE183, "wolf_objective" },
    { 0xE184, "wolf_outside_room_farah_nag" },
    { 0xE185, "wolf_pa_cur_index" },
    { 0xE186, "wolf_pa_emitter" },
    { 0xE187, "wolf_pa_move_to_next_speaker_monitor" },
    { 0xE188, "wolf_pa_queue" },
    { 0xE189, "wolf_pa_think" },
    { 0xE18A, "wolf_pa_vo" },
    { 0xE18B, "wolf_player_demeanor_manager" },
    { 0xE18C, "wolf_player_weapon_fired_monitor" },
    { 0xE18D, "wolf_post_defuse_alex_farah_vo" },
    { 0xE18E, "wolf_proxy_cameraman" },
    { 0xE18F, "wolf_proxy_cameraman_handler" },
    { 0xE190, "wolf_proxy_cameraman_struct" },
    { 0xE191, "wolf_proxy_execute_hostage" },
    { 0xE192, "wolf_proxy_execute_hostage_hostage_animation" },
    { 0xE193, "wolf_proxy_execute_hostage_wolf_proxy_animation" },
    { 0xE194, "wolf_proxy_execute_struct" },
    { 0xE195, "wolf_proxy_executioner" },
    { 0xE196, "wolf_proxy_executioner_handler" },
    { 0xE197, "wolf_proxy_executioner_struct" },
    { 0xE198, "wolf_proxy_handler" },
    { 0xE199, "wolf_proxy_hostage_1" },
    { 0xE19A, "wolf_proxy_hostage_1_struct" },
    { 0xE19B, "wolf_proxy_hostage_2" },
    { 0xE19C, "wolf_proxy_hostage_2_struct" },
    { 0xE19D, "wolf_proxy_hostage_3" },
    { 0xE19E, "wolf_proxy_hostage_3_struct" },
    { 0xE19F, "wolf_proxy_talk_struct" },
    { 0xE1A0, "wolf_raised_flinch" },
    { 0xE1A1, "wolf_room_barrels_explode" },
    { 0xE1A2, "wolf_room_heli_1" },
    { 0xE1A3, "wolf_room_heli_manager" },
    { 0xE1A4, "wolf_room_pre_breach_door" },
    { 0xE1A5, "wolf_room_pre_breach_scene" },
    { 0xE1A6, "wolf_scene_door" },
    { 0xE1A7, "wolf_scene_light_fill" },
    { 0xE1A8, "wolf_scene_light_key" },
    { 0xE1A9, "wolf_scene_light_rim" },
    { 0xE1AA, "wolf_scene_light_rim_lf" },
    { 0xE1AB, "wolf_scene_lights" },
    { 0xE1AC, "wolf_scene_lights_node" },
    { 0xE1AD, "wolf_speaker" },
    { 0xE1AE, "wolf_speaker_destroyed_think" },
    { 0xE1AF, "wolf_speakers" },
    { 0xE1B0, "wolf_start" },
    { 0xE1B1, "wolf_start_setup_farah" },
    { 0xE1B2, "wolf_takedown" },
    { 0xE1B3, "wolf_takedown_cam_start" },
    { 0xE1B4, "wolf_takedown_hint_check" },
    { 0xE1B5, "wolf_takedown_hint_manager" },
    { 0xE1B6, "wolf_takedown_input_lerp" },
    { 0xE1B7, "wolf_takedown_monitor" },
    { 0xE1B8, "wolf_takedown_rumble_handler" },
    { 0xE1B9, "wolf_takedown_scene_hide_names" },
    { 0xE1BA, "wolf_timer_fail_state" },
    { 0xE1BB, "wolf_tripwire_approach_monitor" },
    { 0xE1BC, "wolf_tripwire_handler" },
    { 0xE1BD, "wolf_tripwire_hint_handler" },
    { 0xE1BE, "wolf_tripwire_hint_timeout" },
    { 0xE1BF, "wolf_tripwire_player_weapon_monitor" },
    { 0xE1C0, "wolf_tripwire_set_vo_done" },
    { 0xE1C1, "wolf_tripwire_trigger_immediate" },
    { 0xE1C2, "wolf_truck" },
    { 0xE1C3, "wolf_tunnel_approach_vo" },
    { 0xE1C4, "wolf_tunnel_deadbodies" },
    { 0xE1C5, "wolf_tunnel_deadbody" },
    { 0xE1C6, "wolf_tunnel_explode" },
    { 0xE1C7, "wolf_tunnel_farah_movement_and_vo" },
    { 0xE1C8, "wolf_tunnel_fire_trig" },
    { 0xE1C9, "wolf_tunnel_first_frame" },
    { 0xE1CA, "wolf_vest" },
    { 0xE1CB, "wolf_vest_defuse_failed" },
    { 0xE1CC, "wolf_vest_led_flash_think" },
    { 0xE1CD, "wolfdoor_key_light" },
    { 0xE1CE, "wolfroom_light_on" },
    { 0xE1CF, "woman_ground_handler" },
    { 0xE1D0, "woman_hiding_handler" },
    { 0xE1D1, "woman_onlook_vo2" },
    { 0xE1D2, "woman_onlook_vo2_thread" },
    { 0xE1D3, "woman_onlooker" },
    { 0xE1D4, "woman_onlooker_vo" },
    { 0xE1D5, "women_get_guns_from_locker" },
    { 0xE1D6, "women_get_guns_from_locker_no_azadeh" },
    { 0xE1D7, "women_get_guns_from_open_locker" },
    { 0xE1D8, "women_move_through_warehouse" },
    { 0xE1D9, "women_move_to_gun_locker" },
    { 0xE1DA, "women_spot_farah" },
    { 0xE1DB, "wood" },
    { 0xE1DC, "woods_catchup" },
    { 0xE1DD, "woods_gate_enemy_audio" },
    { 0xE1DE, "woods_hide_moon" },
    { 0xE1DF, "woods_main" },
    { 0xE1E0, "woods_price_nvgs" },
    { 0xE1E1, "woods_start" },
    { 0xE1E2, "working_fov" },
    { 0xE1E3, "worldmarkerid" },
    { 0xE1E4, "worldmarkerpos" },
    { 0xE1E5, "worldmarkerthink" },
    { 0xE1E6, "worldmaxspawnedloot" },
    { 0xE1E7, "worldmodel" },
    { 0xE1E8, "worldobjidpool" },
    { 0xE1E9, "worldplaced" },
    { 0xE1EA, "worldtolocalcoords" },
    { 0xE1EB, "worlduseicons" },
    { 0xE1EC, "worthydamageratio" },
    { 0xE1ED, "wounded_aq_to_patrol" },
    { 0xE1EE, "wounded_drag_pistol_swap" },
    { 0xE1EF, "wounded_drag_shoot" },
    { 0xE1F0, "wp_addplayertostatusradiuslist" },
    { 0xE1F1, "wp_addtoactivewplist" },
    { 0xE1F2, "wp_createplane" },
    { 0xE1F3, "wp_death" },
    { 0xE1F4, "wp_death_quick" },
    { 0xE1F5, "wp_degenhealth" },
    { 0xE1F6, "wp_delaydisorientplayersinrange" },
    { 0xE1F7, "wp_deliverpayloads" },
    { 0xE1F8, "wp_enterpayloadaudio" },
    { 0xE1F9, "wp_exitpayloadaudio" },
    { 0xE1FA, "wp_explosions" },
    { 0xE1FB, "wp_finishdeployment" },
    { 0xE1FC, "wp_fireairburst" },
    { 0xE1FD, "wp_fireflaregroup" },
    { 0xE1FE, "wp_firesmoke" },
    { 0xE1FF, "wp_getflarepositions" },
    { 0xE200, "wp_gethealthdebuffamount" },
    { 0xE201, "wp_getmapselectioninfo" },
    { 0xE202, "wp_getplayerswithinrange" },
    { 0xE203, "wp_getsmokevisionset" },
    { 0xE204, "wp_handlepayloadtyperelease" },
    { 0xE205, "wp_hasresistperk" },
    { 0xE206, "wp_isinanywpzone" },
    { 0xE207, "wp_isinwpzone" },
    { 0xE208, "wp_monitorsmokevisionset" },
    { 0xE209, "wp_movekillcam" },
    { 0xE20A, "wp_playcorpsetableburningfx" },
    { 0xE20B, "wp_projwatchimpact" },
    { 0xE20C, "wp_removefromactivewplist" },
    { 0xE20D, "wp_removeplane" },
    { 0xE20E, "wp_removeplayerfromallstatusradiuslists" },
    { 0xE20F, "wp_removeplayerfromstatusradiuslist" },
    { 0xE210, "wp_resetstatuseffect" },
    { 0xE211, "wp_startblindplayer" },
    { 0xE212, "wp_startburnplayer" },
    { 0xE213, "wp_startdeploy" },
    { 0xE214, "wp_startdisorientplayer" },
    { 0xE215, "wp_startdisorientplayeronspawn" },
    { 0xE216, "wp_startdofshiftforplayer" },
    { 0xE217, "wp_stopblindplayer" },
    { 0xE218, "wp_stopburnplayer" },
    { 0xE219, "wp_stopdisorientonplayerdeath" },
    { 0xE21A, "wp_stopdisorientplayer" },
    { 0xE21B, "wp_stopstatuseffectondeath" },
    { 0xE21C, "wp_testpayloads" },
    { 0xE21D, "wp_watchblindeffect" },
    { 0xE21E, "wp_watchburneffect" },
    { 0xE21F, "wp_watchdisorienteffect" },
    { 0xE220, "wp_watchend" },
    { 0xE221, "wp_watchfordeathstate" },
    { 0xE222, "wp_watchforflareimpacts" },
    { 0xE223, "wp_watchforimpactstate" },
    { 0xE224, "wp_watchforprojectiledeaths" },
    { 0xE225, "wp_watchunsuccessfulzones" },
    { 0xE226, "wpblinding" },
    { 0xE227, "wpburning" },
    { 0xE228, "wpdisorient" },
    { 0xE229, "wphealthblock" },
    { 0xE22A, "wpinprogress" },
    { 0xE22B, "wrap" },
    { 0xE22C, "wrap_text" },
    { 0xE22D, "wristrocket_begineffects" },
    { 0xE22E, "wristrocket_cleanuponownerdisconnect" },
    { 0xE22F, "wristrocket_cleanuponparentdeath" },
    { 0xE230, "wristrocket_createrocket" },
    { 0xE231, "wristrocket_delete" },
    { 0xE232, "wristrocket_endeffects" },
    { 0xE233, "wristrocket_explode" },
    { 0xE234, "wristrocket_set" },
    { 0xE235, "wristrocket_unset" },
    { 0xE236, "wristrocket_watcheffects" },
    { 0xE237, "wristrocket_watcheffectsracedeath" },
    { 0xE238, "wristrocket_watcheffectsracegrenadefired" },
    { 0xE239, "wristrocket_watcheffectsracegrenadepullback" },
    { 0xE23A, "wristrocket_watcheffectsraceheldoffhandbreak" },
    { 0xE23B, "wristrocket_watcheffectsracesuperstarted" },
    { 0xE23C, "wristrocket_watcheffectsraceunset" },
    { 0xE23D, "wristrocket_watchfuse" },
    { 0xE23E, "wristrocket_watchstuck" },
    { 0xE23F, "wristrocketcooksuicideexplodecheck" },
    { 0xE240, "wristrocketinit" },
    { 0xE241, "wristrocketused" },
    { 0xE242, "write_clientmatchdata_for_player" },
    { 0xE243, "write_consumable_used" },
    { 0xE244, "write_global_clientmatchdata" },
    { 0xE245, "write_global_clientmatchdata_func" },
    { 0xE246, "write_log" },
    { 0xE247, "write_struct_to_map" },
    { 0xE248, "writebestscores" },
    { 0xE249, "writebufferedstats" },
    { 0xE24A, "writecurrentrotationteamscore" },
    { 0xE24B, "writekdhistorystats" },
    { 0xE24C, "writepetwatchplayerdata" },
    { 0xE24D, "writeplayerinfo" },
    { 0xE24E, "writeplayerrotationscoretomatchdataongameend" },
    { 0xE24F, "writeplayerstat" },
    { 0xE250, "writesegmentdata" },
    { 0xE251, "writesppmstats" },
    { 0xE252, "wrong_rooftop_nag" },
    { 0xE253, "wrong_way_warning" },
    { 0xE254, "x_dir_fails" },
    { 0xE255, "x_done" },
    { 0xE256, "x_magnitude" },
    { 0xE257, "xanim" },
    { 0xE258, "xanim_name" },
    { 0xE259, "xanim_string" },
    { 0xE25A, "xoffset" },
    { 0xE25B, "xp" },
    { 0xE25C, "xpadding" },
    { 0xE25D, "xpscale" },
    { 0xE25E, "xpscoreevent" },
    { 0xE25F, "xptonextrank" },
    { 0xE260, "xy" },
    { 0xE261, "y_dir_fails" },
    { 0xE262, "y_done" },
    { 0xE263, "y_magnitude" },
    { 0xE264, "yard_enemy_handler" },
    { 0xE265, "yaw" },
    { 0xE266, "yaw_collision_check" },
    { 0xE267, "yawdiffto2468" },
    { 0xE268, "yawmax" },
    { 0xE269, "yawmin" },
    { 0xE26A, "yegor" },
    { 0xE26B, "yegor_dialog_struct" },
    { 0xE26C, "yegor_exit" },
    { 0xE26D, "yegoranimnode" },
    { 0xE26E, "yellow_guy_look_up" },
    { 0xE26F, "yellow_path_makeup" },
    { 0xE270, "yellow_wire" },
    { 0xE271, "yoffset" },
    { 0xE272, "youngfarrah_pistol_reaction" },
    { 0xE273, "youngfarrah_pistol_reaction_proc" },
    { 0xE274, "youngfarrahbreathlogic" },
    { 0xE275, "youngfarrahfatigue" },
    { 0xE276, "youngfarrahprecache" },
    { 0xE277, "youngfarrahsetup" },
    { 0xE278, "ypadding" },
    { 0xE279, "yurteri_wh03_model" },
    { 0xE27A, "z_done" },
    { 0xE27B, "z_is_excessive" },
    { 0xE27C, "z_magnitude" },
    { 0xE27D, "zap_model" },
    { 0xE27E, "zd30_ambush_nest_called_out" },
    { 0xE27F, "zd30_autosave_condition" },
    { 0xE280, "zd30_debug" },
    { 0xE281, "zd30_debug_mg_last_target_print_time" },
    { 0xE282, "zd30_is_flashed" },
    { 0xE283, "zd30_player_max_health" },
    { 0xE284, "zd30_player_max_health_shaft" },
    { 0xE285, "zd30_player_max_health_storage" },
    { 0xE286, "zd30_player_max_health_tunnels" },
    { 0xE287, "zdt_rush_guy" },
    { 0xE288, "zero_angle" },
    { 0xE289, "zerocomponent" },
    { 0xE28A, "ziptie" },
    { 0xE28B, "zm_powershud_clearpower" },
    { 0xE28C, "zoffset" },
    { 0xE28D, "zom_player_damage_flash" },
    { 0xE28E, "zom_player_health_overlay_watcher" },
    { 0xE28F, "zombgone_hint_displayed" },
    { 0xE290, "zombie_3dtext_handler" },
    { 0xE291, "zombie_charges" },
    { 0xE292, "zombie_current_quest_step_index" },
    { 0xE293, "zombie_fake_stealth" },
    { 0xE294, "zombie_max_rank" },
    { 0xE295, "zombie_quest_complete_up_to_quest_step_index" },
    { 0xE296, "zombie_quests" },
    { 0xE297, "zombie_ranks" },
    { 0xE298, "zombie_ranks_table" },
    { 0xE299, "zombie_revive_success_analytics_func" },
    { 0xE29A, "zombie_stealth_table" },
    { 0xE29B, "zombie_stealth_values" },
    { 0xE29C, "zombie_xp" },
    { 0xE29D, "zombieattachfunction" },
    { 0xE29E, "zombieawarenesslevel" },
    { 0xE29F, "zombieendgameanalytics" },
    { 0xE2A0, "zombiemovespeed" },
    { 0xE2A1, "zombies_endgameencounterscorefunc" },
    { 0xE2A2, "zombies_perks" },
    { 0xE2A3, "zombiescriptedstealth" },
    { 0xE2A4, "zone" },
    { 0xE2A5, "zone_oncontested" },
    { 0xE2A6, "zone_ondisableobjective" },
    { 0xE2A7, "zone_onpinnedstate" },
    { 0xE2A8, "zone_onuncontested" },
    { 0xE2A9, "zone_onunoccupied" },
    { 0xE2AA, "zone_onunpinnedstate" },
    { 0xE2AB, "zone_onuse" },
    { 0xE2AC, "zone_onusebegin" },
    { 0xE2AD, "zone_onuseend" },
    { 0xE2AE, "zone_onuseupdate" },
    { 0xE2AF, "zone_stompprogressreward" },
    { 0xE2B0, "zoneactivationdelay" },
    { 0xE2B1, "zoneadditivescoring" },
    { 0xE2B2, "zonecapturetime" },
    { 0xE2B3, "zonecount" },
    { 0xE2B4, "zonedestroyedbytimer" },
    { 0xE2B5, "zoneduration" },
    { 0xE2B6, "zoneendtime" },
    { 0xE2B7, "zonemovetime" },
    { 0xE2B8, "zonerandomlocationorder" },
    { 0xE2B9, "zones" },
    { 0xE2BA, "zoneselectiondelay" },
    { 0xE2BB, "zonetimeout" },
    { 0xE2BC, "zonetimerwait" },
    { 0xE2BD, "zonetrigger" },
    { 0xE2BE, "zoomedin" },
    { 0xE2BF, "zpatrolpointscoring" },
    { 0xE2C0, "zuluinit" },
    { 0xE2C1, "aiasm/civilian_cp_mp" },
    { 0xE2C2, "aiasm/corner_cover_lean_shoot_cp_mp" },
    { 0xE2C3, "aiasm/corner_cover_lean_shoot_lw_mp" },
    { 0xE2C4, "aiasm/gesture_cp_mp" },
    { 0xE2C5, "aiasm/gesture_lw_mp" },
    { 0xE2C6, "aiasm/shoot_cp_mp" },
    { 0xE2C7, "aiasm/shoot_lw_mp" },
    { 0xE2C8, "aiasm/soldier_cp_mp" },
    { 0xE2C9, "aiasm/soldier_lw_mp" },
    { 0xE2CA, "aiasm/suicidebomber_cp_mp" },
    { 0xE2CB, "behaviortree/riotshield_cp" },
    { 0xE2CC, "behaviortree/soldier_agent_lw" },
    { 0xE2CD, "character/character_cp_al_qatala_desert_9_rpg" },
    { 0xE2CE, "character/character_cp_al_qatala_desert_ar_tmtyl" },
    { 0xE2CF, "character/character_cp_bombvest_hostage" },
    { 0xE2D0, "character/character_cp_hero_hadir_urban" },
    { 0xE2D1, "character/character_cp_usmc_basic_ar_1" },
    { 0xE2D2, "character/character_cp_usmc_basic_ar_2" },
    { 0xE2D3, "character/character_cp_usmc_basic_ar_3" },
    { 0xE2D4, "character/character_cp_usmc_basic_ar_4" },
    { 0xE2D5, "character/character_cp_usmc_basic_lmg" },
    { 0xE2D6, "character/character_iw8_cp_al_qatala_urban_bombvest" },
    { 0xE2D7, "character/character_iw8_russian_army_1_trial" },
    { 0xE2D8, "character/character_opforce_juggernaut_br" },
    { 0xE2D9, "character/character_opforce_juggernaut_trial" },
    { 0xE2DA, "character/character_spetsnaz_ar_nvg_cp" },
    { 0xE2DB, "character/character_spetsnaz_ar_nvg_fixed_cp" },
    { 0xE2DC, "character/character_spetsnaz_ar_trial" },
    { 0xE2DD, "character/character_spetsnaz_cqc_nvg_cp" },
    { 0xE2DE, "character/character_spetsnaz_cqc_trial" },
    { 0xE2DF, "character/character_spetsnaz_dmr_cp_nvg" },
    { 0xE2E0, "character/character_spetsnaz_dmr_trial" },
    { 0xE2E1, "character/character_spetsnaz_gasmask_ar_cp" },
    { 0xE2E2, "character/character_spetsnaz_gasmask_ar_trial" },
    { 0xE2E3, "character/character_spetsnaz_gasmask_cqc_cp" },
    { 0xE2E4, "character/character_spetsnaz_gasmask_cqc_trial" },
    { 0xE2E5, "character/character_spetsnaz_gasmask_lmg_cp" },
    { 0xE2E6, "character/character_spetsnaz_gasmask_lmg_trial" },
    { 0xE2E7, "character/character_spetsnaz_gasmask_nohelmet_ar_cp" },
    { 0xE2E8, "character/character_spetsnaz_gasmask_nohelmet_cqc_cp" },
    { 0xE2E9, "character/character_spetsnaz_gasmask_nohelmet_lmg_cp" },
    { 0xE2EA, "character/character_spetsnaz_lmg_cp_nvg" },
    { 0xE2EB, "character/character_spetsnaz_lmg_trial" },
    { 0xE2EC, "character/character_spetsnaz_riotshield_cp" },
    { 0xE2ED, "character/civ_tugofwar_male_cp" },
    { 0xE2EE, "xmodelalias/heads_al_qatala_tmtyl" },
    { 0xE2EF, "scripts/common/create_script_utility" },
    { 0xE2F0, "scripts/cp/animation_suite" },
    { 0xE2F1, "scripts/cp/astar" },
    { 0xE2F2, "scripts/cp/calloutmarkerping_cp" },
    { 0xE2F3, "scripts/cp/challenges_cp" },
    { 0xE2F4, "scripts/cp/compass" },
    { 0xE2F5, "scripts/cp/coop_escape" },
    { 0xE2F6, "scripts/cp/cp_aitype_structs_ally_usmc" },
    { 0xE2F7, "scripts/cp/cp_awards" },
    { 0xE2F8, "scripts/cp/cp_challenge" },
    { 0xE2F9, "scripts/cp/cp_checkpoint" },
    { 0xE2FA, "scripts/cp/cp_circuit_breaker" },
    { 0xE2FB, "scripts/cp/cp_enemy_drone_turret" },
    { 0xE2FC, "scripts/cp/cp_enemy_sentry_turret" },
    { 0xE2FD, "scripts/cp/cp_enemy_tank" },
    { 0xE2FE, "scripts/cp/cp_events" },
    { 0xE2FF, "scripts/cp/cp_gastrap" },
    { 0xE300, "scripts/cp/cp_manned_turret" },
    { 0xE301, "scripts/cp/cp_matchdata" },
    { 0xE302, "scripts/cp/cp_missilelauncher" },
    { 0xE303, "scripts/cp/cp_points" },
    { 0xE304, "scripts/cp/cp_rank" },
    { 0xE305, "scripts/cp/cp_scriptmover_util" },
    { 0xE306, "scripts/cp/execution" },
    { 0xE307, "scripts/cp/so_globallogic" },
    { 0xE308, "scripts/cp/so_laststand" },
    { 0xE309, "scripts/cp/so_trigger" },
    { 0xE30A, "scripts/cp/so_utility" },
    { 0xE30B, "scripts/cp/so_utility_code" },
    { 0xE30C, "scripts/cp/whizby" },
    { 0xE30D, "scripts/cp_mp/auto_ascender_solo" },
    { 0xE30E, "scripts/cp_mp/calloutmarkerping" },
    { 0xE30F, "scripts/cp_mp/challenges" },
    { 0xE310, "scripts/cp_mp/crossbow" },
    { 0xE311, "scripts/cp_mp/dragonsbreath" },
    { 0xE312, "scripts/cp_mp/xmike109" },
    { 0xE313, "scripts/mp/ammorestock" },
    { 0xE314, "scripts/mp/brclientmatchdata" },
    { 0xE315, "scripts/mp/brmatchdata" },
    { 0xE316, "scripts/mp/calloutmarkerping_mp" },
    { 0xE317, "scripts/mp/carriable" },
    { 0xE318, "scripts/mp/challenges_mp" },
    { 0xE319, "scripts/mp/mp_agent_damage" },
    { 0xE31A, "scripts/aitypes/riotshield/riotshield" },
    { 0xE31B, "scripts/asm/soldier/cp" },
    { 0xE31C, "scripts/asm/soldier/ground_turret" },
    { 0xE31D, "scripts/cp/agents/agents" },
    { 0xE31E, "scripts/cp/agents/gametype_cp_specops" },
    { 0xE31F, "scripts/cp/agents/gametype_cp_wave_sv" },
    { 0xE320, "scripts/cp/drone/emp_drone" },
    { 0xE321, "scripts/cp/equipment/cp_adrenaline" },
    { 0xE322, "scripts/cp/equipment/cp_decoy_grenade" },
    { 0xE323, "scripts/cp/equipment/cp_incendiarylauncher" },
    { 0xE324, "scripts/cp/helicopter/chopper_boss" },
    { 0xE325, "scripts/cp/helicopter/utility" },
    { 0xE326, "scripts/cp/killstreaks/nuke_cp" },
    { 0xE327, "scripts/cp/laser_traps/cp_laser_traps" },
    { 0xE328, "scripts/cp/stealth/manager" },
    { 0xE329, "scripts/cp/utility/auto_ascender_ai" },
    { 0xE32A, "scripts/cp/utility/cp_controlled_callbacks" },
    { 0xE32B, "scripts/cp/utility/cp_safehouse_util" },
    { 0xE32C, "scripts/cp/utility/script" },
    { 0xE32D, "scripts/cp/vehicles/cargo_truck_mg_cp" },
    { 0xE32E, "scripts/cp/vehicles/little_bird_mg_cp" },
    { 0xE32F, "scripts/cp/vehicles/vehicle_compass_cp" },
    { 0xE330, "scripts/cp/vehicles/vehicle_damage_cp" },
    { 0xE331, "scripts/cp_mp/killstreaks/nuke" },
    { 0xE332, "scripts/cp_mp/utility/callback_group" },
    { 0xE333, "scripts/cp_mp/utility/omnvar_utility" },
    { 0xE334, "scripts/cp_mp/utility/scriptable_door_utility" },
    { 0xE335, "scripts/cp_mp/utility/train_utility" },
    { 0xE336, "scripts/cp_mp/vehicles/cargo_truck_mg" },
    { 0xE337, "scripts/cp_mp/vehicles/little_bird_mg" },
    { 0xE338, "scripts/cp_mp/vehicles/vehicle_collision" },
    { 0xE339, "scripts/cp_mp/vehicles/vehicle_compass" },
    { 0xE33A, "scripts/mp/equipment/binoculars" },
    { 0xE33B, "scripts/mp/equipment/fulton" },
    { 0xE33C, "scripts/mp/killstreaks/nuke_mp" },
    { 0xE33D, "scripts/mp/subway/fast_travel_subway_car" },
    { 0xE33E, "scripts/mp/subway/fast_travel_subway_station" },
    { 0xE33F, "scripts/mp/trials/mp_cave_am_create_script" },
    { 0xE340, "scripts/mp/trials/mp_emporium_create_script_floorislava" },
    { 0xE341, "scripts/mp/trials/mp_euphrates_create_script" },
    { 0xE342, "scripts/mp/trials/mp_euphrates_create_script_gunnonlinear" },
    { 0xE343, "scripts/mp/trials/mp_harbor_floorislava_create_script" },
    { 0xE344, "scripts/mp/trials/mp_m_cornfield_floor_is_lava_create_script" },
    { 0xE345, "scripts/mp/trials/mp_m_king_create_script" },
    { 0xE346, "scripts/mp/trials/mp_m_trench_create_script_gunnonlinear" },
    { 0xE347, "scripts/mp/trials/mp_oilrig_create_script" },
    { 0xE348, "scripts/mp/trials/mp_t_reflex_create_script_quadrace" },
    { 0xE349, "scripts/mp/trials/mp_trial_helicopter_port_create_a_script" },
    { 0xE34A, "scripts/mp/trials/mp_trials_patches_petrograd" },
    { 0xE34B, "scripts/mp/trials/mp_trl_boneyard_gw_race" },
    { 0xE34C, "scripts/mp/trials/mp_trl_create_a_script_race_euphrates" },
    { 0xE34D, "scripts/mp/trials/mp_trl_floorislava" },
    { 0xE34E, "scripts/mp/trials/mp_trl_gunslinger" },
    { 0xE34F, "scripts/mp/trials/mp_trl_gunslinger_crash_create_script" },
    { 0xE350, "scripts/mp/trials/mp_trl_gunslinger_knife_create_script" },
    { 0xE351, "scripts/mp/trials/mp_trl_gunslinger_memory_create_script" },
    { 0xE352, "scripts/mp/trials/mp_trl_quarry_raceislava_trial_create_a_script" },
    { 0xE353, "scripts/mp/trials/trial_arm_course" },
    { 0xE354, "scripts/mp/trials/trial_enemy_sentry_turret" },
    { 0xE355, "scripts/mp/trials/trial_gun_course" },
    { 0xE356, "scripts/mp/trials/trial_jugg" },
    { 0xE357, "scripts/mp/trials/trial_pitcher" },
    { 0xE358, "scripts/mp/trials/trial_race" },
    { 0xE359, "scripts/mp/trials/trial_sniper" },
    { 0xE35A, "scripts/mp/trials/trial_target_utility" },
    { 0xE35B, "scripts/mp/trials/trial_utility" },
    { 0xE35C, "scripts/mp/vehicles/cargo_truck_mg_mp" },
    { 0xE35D, "scripts/mp/vehicles/little_bird_mg_mp" },
    { 0xE35E, "scripts/mp/vehicles/vehicle_compass_mp" },
    { 0xE35F, "scripts/mp/vehicles/vehicle_damage_mp" },
    { 0xE360, "scripts/asm/soldier/mp/melee" },
    { 0xE361, "scripts/cp_mp/vehicles/customization/battle_tracks" },
    { 0xE362, "__ending_origin" },
    { 0xE363, "_accessreaderscriptableused" },
    { 0xE364, "_applydvarstosettings" },
    { 0xE365, "_applysalesdiscount" },
    { 0xE366, "_attachmentblocks" },
    { 0xE367, "_blankfunc" },
    { 0xE368, "_branalytics_addevent" },
    { 0xE369, "_branalytics_addeventallowed" },
    { 0xE36A, "_branalytics_addeventdelayed" },
    { 0xE36B, "_branalytics_geteventtimestamp" },
    { 0xE36C, "_branalytics_headerplayer" },
    { 0xE36D, "_branalytics_headerplayerposrow" },
    { 0xE36E, "_calloutmarkerping_checkforbuybackrequest" },
    { 0xE36F, "_calloutmarkerping_handleluinotify_acknowledged" },
    { 0xE370, "_calloutmarkerping_handleluinotify_acknowledgedcancel" },
    { 0xE371, "_calloutmarkerping_handleluinotify_added" },
    { 0xE372, "_calloutmarkerping_handleluinotify_brinventoryslotrequest" },
    { 0xE373, "_calloutmarkerping_handleluinotify_cleared" },
    { 0xE374, "_calloutmarkerping_handleluinotify_enemyrepinged" },
    { 0xE375, "_calloutmarkerping_handleluinotify_mappingdeletemarker" },
    { 0xE376, "_calloutmarkerping_isdropcrate" },
    { 0xE377, "_calloutmarkerping_isenemy" },
    { 0xE378, "_calloutmarkerping_iskiosk" },
    { 0xE379, "_calloutmarkerping_isplunderextract" },
    { 0xE37A, "_calloutmarkerping_isvehicleoccupiedbyenemy" },
    { 0xE37B, "_calloutmarkerping_onpingchallenge" },
    { 0xE37C, "_calloutmarkerping_poolidisdanger" },
    { 0xE37D, "_calloutmarkerping_poolidisentity" },
    { 0xE37E, "_calloutmarkerping_poolidisloot" },
    { 0xE37F, "_calloutmarkerping_predicted_isanypingactive" },
    { 0xE380, "_calloutmarkerping_predicted_listenfornotifies" },
    { 0xE381, "_calloutmarkerping_predicted_log" },
    { 0xE382, "_calloutmarkerping_predicted_timeout" },
    { 0xE383, "_calloutmarkerping_scriptableisusable" },
    { 0xE384, "_calloutmarkerping_shouldremovecalloutifwholesquadinvehicle" },
    { 0xE385, "_cancelputawayonuseend" },
    { 0xE386, "_cleanuptabletallows" },
    { 0xE387, "_closepurchasemenuwithresponse" },
    { 0xE388, "_codecomputerscriptableused" },
    { 0xE389, "_codephonescriptableused" },
    { 0xE38A, "_computerrebootsequence_start" },
    { 0xE38B, "_dangercircledurationforplayer" },
    { 0xE38C, "_debug_rooftop_activesat" },
    { 0xE38D, "_debug_rooftop_heli_start" },
    { 0xE38E, "_debug_rooftop_raid_exfil" },
    { 0xE38F, "_debug_rooftopobjstart" },
    { 0xE390, "_determinelocationarray" },
    { 0xE391, "_donewithcorpse" },
    { 0xE392, "_findgivearmoramountanddropleftovers" },
    { 0xE393, "_findnewlocaleplacement" },
    { 0xE394, "_getactualcost" },
    { 0xE395, "_getdeathstatecode" },
    { 0xE396, "_getequipmentammotomax" },
    { 0xE397, "_getlocationscircleinfluencedwithnoise" },
    { 0xE398, "_getplunderextractlocations" },
    { 0xE399, "_getrandomlocations" },
    { 0xE39A, "_getsingleplunderextractlocations" },
    { 0xE39B, "_goto_goal_and_snipe" },
    { 0xE39C, "_handlefieldupgradepurchase" },
    { 0xE39D, "_handlekillstreakpurchase" },
    { 0xE39E, "_handlespecialpurchase" },
    { 0xE39F, "_handlevehiclepurchase" },
    { 0xE3A0, "_handlevehiclerepair" },
    { 0xE3A1, "_hidesafecircleui" },
    { 0xE3A2, "_initignoredtabspergamemode" },
    { 0xE3A3, "_initsalesdiscount" },
    { 0xE3A4, "_ispointinbadarea" },
    { 0xE3A5, "_keypadscriptableused" },
    { 0xE3A6, "_keypadscriptableused_bunkeralt" },
    { 0xE3A7, "_killstreakneedslocationselection" },
    { 0xE3A8, "_loadout_setcopyloadoutomvnaronspawn" },
    { 0xE3A9, "_locationselectioninterrupt" },
    { 0xE3AA, "_luidecision" },
    { 0xE3AB, "_maphint_cheese2scriptableused" },
    { 0xE3AC, "_maphint_cheesescriptableused" },
    { 0xE3AD, "_maphint_computerscriptableused" },
    { 0xE3AE, "_maphint_keypadscriptableused" },
    { 0xE3AF, "_maphint_offerscriptableused" },
    { 0xE3B0, "_maphint_phonescriptableused" },
    { 0xE3B1, "_maxoutequipmentammo" },
    { 0xE3B2, "_onmatchstartbr" },
    { 0xE3B3, "_ontabletgiven" },
    { 0xE3B4, "_phonemorsesinglescriptableused" },
    { 0xE3B5, "_playerwaittillcinematiccompleteinternal" },
    { 0xE3B6, "_precalcsafecirclecenters" },
    { 0xE3B7, "_proximitywatcher" },
    { 0xE3B8, "_purchasemenuclosedbyclient" },
    { 0xE3B9, "_questtimerwait" },
    { 0xE3BA, "_redbuttonused_internal" },
    { 0xE3BB, "_runmovequestlocale" },
    { 0xE3BC, "_safecircledurationforplayer" },
    { 0xE3BD, "_setclientkillstreakavailability" },
    { 0xE3BE, "_setclientkillstreakindexes" },
    { 0xE3BF, "_setplayerteamrank" },
    { 0xE3C0, "_start_rooftop_obj" },
    { 0xE3C1, "_start_rooftop_raid_exfil" },
    { 0xE3C2, "_start_rooftop_raid_heli" },
    { 0xE3C3, "_start_rooftop_raid_sats" },
    { 0xE3C4, "_start_spawn_modules" },
    { 0xE3C5, "_startragdollwithvehiclefeature" },
    { 0xE3C6, "_stop_spawn_modules" },
    { 0xE3C7, "_tablethide" },
    { 0xE3C8, "_testing_ending" },
    { 0xE3C9, "_tmtyl_bomber_squadafterspawnfunc" },
    { 0xE3CA, "_tmtylsquadafterspawnfunc" },
    { 0xE3CB, "_tryusehoverjetfromstructinternal" },
    { 0xE3CC, "_unlinkcorpsefromvehicle" },
    { 0xE3CD, "_utilflare_flareexplode" },
    { 0xE3CE, "_utilflare_isvalidflaretype" },
    { 0xE3CF, "_utilflare_lerpflare" },
    { 0xE3D0, "_validateitempurchase" },
    { 0xE3D1, "_waitforlui" },
    { 0xE3D2, "_watchforcircleclosure" },
    { 0xE3D3, "_watchtoautoclosemenu" },
    { 0xE3D4, "_x1opsassignnpctoteam" },
    { 0xE3D5, "_x1opsnpcpulsecheckteamnearby" },
    { 0xE3D6, "_x1opsnpcwaittilluse" },
    { 0xE3D7, "_x1opsplayerredactalltacmaplocation" },
    { 0xE3D8, "_x1opsplayerunredacttacmaplocation" },
    { 0xE3D9, "_x1opsunassignnpcfromteam" },
    { 0xE3DA, "abandonbrsquadleader" },
    { 0xE3DB, "abandonedtimeoutcallback" },
    { 0xE3DC, "abandonedtimeoutdelay" },
    { 0xE3DD, "abandonedtimeoutoverride" },
    { 0xE3DE, "abilities" },
    { 0xE3DF, "abilitykey" },
    { 0xE3E0, "abilityleft" },
    { 0xE3E1, "abshotfootlastposition" },
    { 0xE3E2, "absolutevelocity" },
    { 0xE3E3, "ac130_flight_path" },
    { 0xE3E4, "access_card" },
    { 0xE3E5, "accesscard" },
    { 0xE3E6, "accesscardsspawned_red" },
    { 0xE3E7, "accessoryattachmentfem" },
    { 0xE3E8, "accessorybig" },
    { 0xE3E9, "accessoryface" },
    { 0xE3EA, "accessoryfem" },
    { 0xE3EB, "accessoryfemband" },
    { 0xE3EC, "accessorylogicbyindex" },
    { 0xE3ED, "accessreaderscriptableused" },
    { 0xE3EE, "accuracy_bonus_factor" },
    { 0xE3EF, "achievement_id" },
    { 0xE3F0, "achievementtrackerforkills" },
    { 0xE3F1, "activate_additional_ammo_crates" },
    { 0xE3F2, "activate_all_targets" },
    { 0xE3F3, "activate_battle_station" },
    { 0xE3F4, "activate_c4_for_pick_up" },
    { 0xE3F5, "activate_chopper_boss_ammo_crates" },
    { 0xE3F6, "activate_control_station" },
    { 0xE3F7, "activate_control_station_interaction" },
    { 0xE3F8, "activate_destructible_cinderblock" },
    { 0xE3F9, "activate_destructible_cinderblocks" },
    { 0xE3FA, "activate_emp_drone_func" },
    { 0xE3FB, "activate_emp_drone_pick_up" },
    { 0xE3FC, "activate_escape_maze" },
    { 0xE3FD, "activate_front_trigger_hurt" },
    { 0xE3FE, "activate_gas_trap" },
    { 0xE3FF, "activate_gas_trap_cloud" },
    { 0xE400, "activate_gas_trap_cloud_parent" },
    { 0xE401, "activate_gas_trap_puddles" },
    { 0xE402, "activate_gasmask" },
    { 0xE403, "activate_javelin_ammo_refill" },
    { 0xE404, "activate_javelin_pick_up" },
    { 0xE405, "activate_laser_from_struct" },
    { 0xE406, "activate_laser_shut_down_button" },
    { 0xE407, "activate_laser_shut_down_interaction" },
    { 0xE408, "activate_laser_trap" },
    { 0xE409, "activate_laser_trap_parent" },
    { 0xE40A, "activate_minigun" },
    { 0xE40B, "activate_out_of_bounds_triggers" },
    { 0xE40C, "activate_precision_use_lua" },
    { 0xE40D, "activate_pressure_sensor" },
    { 0xE40E, "activate_punchcard" },
    { 0xE40F, "activate_scavenger_bag" },
    { 0xE410, "activate_scout_drone" },
    { 0xE411, "activate_seq_button" },
    { 0xE412, "activate_server_for_interact" },
    { 0xE413, "activate_station" },
    { 0xE414, "activate_stealth_settings" },
    { 0xE415, "activate_subway_fast_travel" },
    { 0xE416, "activate_subway_track_trigger_hurt" },
    { 0xE417, "activate_subway_track_trigger_hurt_internal" },
    { 0xE418, "activate_switch_cooldown" },
    { 0xE419, "activate_target" },
    { 0xE41A, "activate_target_group" },
    { 0xE41B, "activate_timed_laser_trap" },
    { 0xE41C, "activate_timed_laser_traps" },
    { 0xE41D, "activate_track_timer" },
    { 0xE41E, "activate_track_timers" },
    { 0xE41F, "activate_trap_from_interaction" },
    { 0xE420, "activate_trap_object" },
    { 0xE421, "activate_trophy_protection" },
    { 0xE422, "activate_upload_station" },
    { 0xE423, "activate_upload_station_for_interact" },
    { 0xE424, "activate_vehicle_spawner" },
    { 0xE425, "activatedtime" },
    { 0xE426, "activatefunc" },
    { 0xE427, "activategastrap" },
    { 0xE428, "activatemeleeblood" },
    { 0xE429, "activatemusictrigger" },
    { 0xE42A, "active_cs_files" },
    { 0xE42B, "active_drones" },
    { 0xE42C, "active_fob_think" },
    { 0xE42D, "active_healthpacks" },
    { 0xE42E, "active_neurotoxin_clouds" },
    { 0xE42F, "active_relic_bang_and_boom" },
    { 0xE430, "activeadvanceduavcount" },
    { 0xE431, "activeairstrikes" },
    { 0xE432, "activeclosingpool" },
    { 0xE433, "activecurrstate" },
    { 0xE434, "activeintelchallengekeys" },
    { 0xE435, "activenumber" },
    { 0xE436, "activeparachuters" },
    { 0xE437, "activeparachutersfactionvo" },
    { 0xE438, "activestate" },
    { 0xE439, "actorid" },
    { 0xE43A, "actorloopanim" },
    { 0xE43B, "actorrope" },
    { 0xE43C, "actorropeplayscene" },
    { 0xE43D, "actorthinkpath_default" },
    { 0xE43E, "actualstarttime" },
    { 0xE43F, "add_ai_rider_to_decho" },
    { 0xE440, "add_client_back_to_mask_after_delay" },
    { 0xE441, "add_collision_to_hack_point" },
    { 0xE442, "add_head_icon_on_allies" },
    { 0xE443, "add_module_ai_spawn_func_to_module" },
    { 0xE444, "add_neurotoxin_damage_area" },
    { 0xE445, "add_object_to_trap_room_ents" },
    { 0xE446, "add_outline" },
    { 0xE447, "add_pack_camanim" },
    { 0xE448, "add_pack_characteranim" },
    { 0xE449, "add_pack_fx" },
    { 0xE44A, "add_pack_modelanim" },
    { 0xE44B, "add_pack_playeranim" },
    { 0xE44C, "add_pack_startfunc" },
    { 0xE44D, "add_pilot_setup" },
    { 0xE44E, "add_player_to_focus_fire_attacker_list" },
    { 0xE44F, "add_practice_bots" },
    { 0xE450, "add_rider_to_decho" },
    { 0xE451, "add_scriptable_setup" },
    { 0xE452, "add_spawn_disable_struct" },
    { 0xE453, "add_stealth_logic_to_group" },
    { 0xE454, "add_struct" },
    { 0xE455, "add_to_bomb_detonator_waiting_for_pick_up_array" },
    { 0xE456, "add_to_emp_drone_target_list" },
    { 0xE457, "add_to_ents_to_clean_up" },
    { 0xE458, "add_to_fulton_actor_players" },
    { 0xE459, "add_to_fulton_actors" },
    { 0xE45A, "add_to_mine_list" },
    { 0xE45B, "add_to_score_message" },
    { 0xE45C, "add_to_spawn_count_from_group" },
    { 0xE45D, "add_to_spawnflags" },
    { 0xE45E, "add_to_spotlight_array" },
    { 0xE45F, "add_track_points" },
    { 0xE460, "add_trigger_to_oob_system" },
    { 0xE461, "add_veh_spawners_to_passive_wave_spawning" },
    { 0xE462, "add_wave_overrides_to_module" },
    { 0xE463, "addaccesscard" },
    { 0xE464, "addaliasarraytoqueue" },
    { 0xE465, "addallkillstreaksunlocked" },
    { 0xE466, "addallkillstreaksunlockedinonelife" },
    { 0xE467, "addbattlepassxpmultiplier" },
    { 0xE468, "adddroponplayerdeath" },
    { 0xE469, "addedcollision" },
    { 0xE46A, "addexecutionquip" },
    { 0xE46B, "addglobalbattlepassxpmultiplier" },
    { 0xE46C, "addincoming" },
    { 0xE46D, "additionalrecondronetargets" },
    { 0xE46E, "addjuggernautcharge" },
    { 0xE46F, "addjuggfunctionality" },
    { 0xE470, "addjuggsettings" },
    { 0xE471, "addlaststandoverheadiconcallback" },
    { 0xE472, "addleadobjective" },
    { 0xE473, "addplatepouch" },
    { 0xE474, "addplayerasexpiredlootleader" },
    { 0xE475, "addplayeraslootleader" },
    { 0xE476, "addplundercarrycredit" },
    { 0xE477, "addpostlaunchspawns" },
    { 0xE478, "addpowerbutton" },
    { 0xE479, "addproptolist" },
    { 0xE47A, "addquestrewardtier" },
    { 0xE47B, "addquestrewardtierframeend" },
    { 0xE47C, "addscriptedspawnpoints" },
    { 0xE47D, "addselfrevivetoken" },
    { 0xE47E, "addspawnlocation" },
    { 0xE47F, "addspecialistbonus" },
    { 0xE480, "addspecialistbonuspickup" },
    { 0xE481, "addspecialistdialog" },
    { 0xE482, "addteabagcharge" },
    { 0xE483, "addtenkillcharge" },
    { 0xE484, "addthrowingknifecharge" },
    { 0xE485, "addtoc130infil" },
    { 0xE486, "addtodismembermentlist" },
    { 0xE487, "addtolittlebirdmglist" },
    { 0xE488, "addtop3brcharge" },
    { 0xE489, "addtovoqueue" },
    { 0xE48A, "addupperrighthudelem" },
    { 0xE48B, "addvehicularmanslaughtercharge" },
    { 0xE48C, "addwatch2v2topscore" },
    { 0xE48D, "addzombiepowerbutton" },
    { 0xE48E, "adjust_angles_for_heli_path" },
    { 0xE48F, "adjust_damage_based_on_weaponclass" },
    { 0xE490, "adjust_heartbeat_sensor_settings" },
    { 0xE491, "adjust_player_pos_memory_array_size" },
    { 0xE492, "adjustactivespawnlogic" },
    { 0xE493, "adjusteventdistributionpadding" },
    { 0xE494, "adjustlootleadermarkcount" },
    { 0xE495, "adjustmatchtimerpausedstatefromleadchange" },
    { 0xE496, "adjustmatchtimerpausedstatefromscore" },
    { 0xE497, "adjustshipmentspawns" },
    { 0xE498, "adjustuniqueitemposition" },
    { 0xE499, "adjustzoneactivationdelayforlargemaps" },
    { 0xE49A, "adrenaline_crate_player_at_max_ammo" },
    { 0xE49B, "adrenaline_crate_spawn" },
    { 0xE49C, "adrenaline_crate_use" },
    { 0xE49D, "adsoff" },
    { 0xE49E, "adson" },
    { 0xE49F, "advance_bomb_wire_list" },
    { 0xE4A0, "advanced_supply_drop_marker_sfx" },
    { 0xE4A1, "advanced_supply_drop_refund_on_death" },
    { 0xE4A2, "affect_hvt_healthdrain" },
    { 0xE4A3, "afkroundcounted" },
    { 0xE4A4, "after_hit_by_emp_func" },
    { 0xE4A5, "after_spawn_func" },
    { 0xE4A6, "agent_pickup_hostage_scene" },
    { 0xE4A7, "agent_pickup_hostage_scene_body" },
    { 0xE4A8, "agentclasscallback" },
    { 0xE4A9, "agentsinsphere" },
    { 0xE4AA, "agentsnear" },
    { 0xE4AB, "agenttargetloadout" },
    { 0xE4AC, "agentthink" },
    { 0xE4AD, "aggressive_melee_active" },
    { 0xE4AE, "aggressive_melee_charge_init" },
    { 0xE4AF, "aggressively_chase_down_target" },
    { 0xE4B0, "aggro_player_weight" },
    { 0xE4B1, "ai_aggro_goal_shrink" },
    { 0xE4B2, "ai_anim_relative" },
    { 0xE4B3, "ai_array" },
    { 0xE4B4, "ai_ascender_animin" },
    { 0xE4B5, "ai_ascender_animloop" },
    { 0xE4B6, "ai_ascender_animout" },
    { 0xE4B7, "ai_ascender_doanims" },
    { 0xE4B8, "ai_ascender_getclosestascender" },
    { 0xE4B9, "ai_ascender_getclosestdescender" },
    { 0xE4BA, "ai_ascender_getstartpos" },
    { 0xE4BB, "ai_ascender_giveascender" },
    { 0xE4BC, "ai_ascender_takeascender" },
    { 0xE4BD, "ai_ascender_use" },
    { 0xE4BE, "ai_counter_gate" },
    { 0xE4BF, "ai_damage_monitor" },
    { 0xE4C0, "ai_deaf_event_active" },
    { 0xE4C1, "ai_delete_after_level_notify" },
    { 0xE4C2, "ai_die_if_far_away" },
    { 0xE4C3, "ai_dismount_turret" },
    { 0xE4C4, "ai_dropgren_model" },
    { 0xE4C5, "ai_dropgren_override_hide" },
    { 0xE4C6, "ai_dropgren_override_hint" },
    { 0xE4C7, "ai_dropgren_override_string" },
    { 0xE4C8, "ai_dropgren_weapontype" },
    { 0xE4C9, "ai_excluder" },
    { 0xE4CA, "ai_extra_think" },
    { 0xE4CB, "ai_fire_at_chopper" },
    { 0xE4CC, "ai_flash_swap" },
    { 0xE4CD, "ai_force_damage_hit" },
    { 0xE4CE, "ai_give_flashlight" },
    { 0xE4CF, "ai_goal_distribution" },
    { 0xE4D0, "ai_goal_distribution_debug" },
    { 0xE4D1, "ai_goal_update_population" },
    { 0xE4D2, "ai_goto_ascender_and_wait" },
    { 0xE4D3, "ai_ground_set_goal_radii" },
    { 0xE4D4, "ai_ground_think" },
    { 0xE4D5, "ai_hold_behavior" },
    { 0xE4D6, "ai_hold_debug" },
    { 0xE4D7, "ai_hold_debug_internal" },
    { 0xE4D8, "ai_hold_free" },
    { 0xE4D9, "ai_hold_positions" },
    { 0xE4DA, "ai_hold_positions_freed" },
    { 0xE4DB, "ai_hold_wake_behavior" },
    { 0xE4DC, "ai_hold_wake_watch" },
    { 0xE4DD, "ai_ignore_all_until_goal" },
    { 0xE4DE, "ai_is_juggernaut" },
    { 0xE4DF, "ai_juggernaut_think" },
    { 0xE4E0, "ai_molotov_swap" },
    { 0xE4E1, "ai_molotov_swapp" },
    { 0xE4E2, "ai_molotov_used" },
    { 0xE4E3, "ai_offhandfiremanager" },
    { 0xE4E4, "ai_operate_turret" },
    { 0xE4E5, "ai_push_forward_watcher" },
    { 0xE4E6, "ai_push_to_position" },
    { 0xE4E7, "ai_pushes_terminal" },
    { 0xE4E8, "ai_raising_alarm" },
    { 0xE4E9, "ai_roof_think" },
    { 0xE4EA, "ai_rush_players_thread" },
    { 0xE4EB, "ai_semtex_swapp" },
    { 0xE4EC, "ai_shooting_timer" },
    { 0xE4ED, "ai_shooting_watch" },
    { 0xE4EE, "ai_spawn_intel_extras" },
    { 0xE4EF, "ai_stop_shooting_watch" },
    { 0xE4F0, "ai_truck_rider_think" },
    { 0xE4F1, "ai_washitbyvehicle" },
    { 0xE4F2, "ai_weapons_free" },
    { 0xE4F3, "aigroundturret_cancel" },
    { 0xE4F4, "aigroundturret_dismountcompleted" },
    { 0xE4F5, "aigroundturret_mountcompleted" },
    { 0xE4F6, "aigroundturret_requestmount" },
    { 0xE4F7, "aigroundturret_shouldbegindismountturret" },
    { 0xE4F8, "aigroundturret_shouldcompletedismount" },
    { 0xE4F9, "aigroundturret_shouldmountturret" },
    { 0xE4FA, "aigroundturretref" },
    { 0xE4FB, "aigroundturretstate" },
    { 0xE4FC, "airdop_brloadoutcratefirstactivation" },
    { 0xE4FD, "airdrop_applyimmediatejuggernaut" },
    { 0xE4FE, "airdrop_bronloadoutcratedestroyed" },
    { 0xE4FF, "airdrop_crushchicken" },
    { 0xE500, "airdrop_givecrateuseweapon" },
    { 0xE501, "airdrop_playdeploydialog" },
    { 0xE502, "airdrop_specialcasecanusecrate" },
    { 0xE503, "airdrop_watchforcrateuseend" },
    { 0xE504, "airdropbasecashamount" },
    { 0xE505, "airduct_locations" },
    { 0xE506, "airfield_safehouse_edit_loadout" },
    { 0xE507, "airfield_safehouse_loot" },
    { 0xE508, "airholder" },
    { 0xE509, "airlock" },
    { 0xE50A, "airlock_back_blocker" },
    { 0xE50B, "airlock_button_l" },
    { 0xE50C, "airlock_button_r" },
    { 0xE50D, "airlock_button_think" },
    { 0xE50E, "airlock_callbutton_think" },
    { 0xE50F, "airlock_callbuttons" },
    { 0xE510, "airlock_doors" },
    { 0xE511, "airlock_front_blocker" },
    { 0xE512, "airlock_pivot" },
    { 0xE513, "airlock_positions" },
    { 0xE514, "airlock_show_back_doors" },
    { 0xE515, "airlock_show_doors" },
    { 0xE516, "airlock_show_front_doors" },
    { 0xE517, "airlock_show_room_doors" },
    { 0xE518, "airlock_slot" },
    { 0xE519, "airlock_slot_think" },
    { 0xE51A, "airlock_stop" },
    { 0xE51B, "airstrike_addactivestrike" },
    { 0xE51C, "airstrike_canbeused" },
    { 0xE51D, "airstrike_movewithplane" },
    { 0xE51E, "airstrike_removeactivestrike" },
    { 0xE51F, "airstrike_watchdeployweaponchange" },
    { 0xE520, "airstrike_watchgameend" },
    { 0xE521, "airstrike_watchownerdisown" },
    { 0xE522, "airstrikebetweentwopoints" },
    { 0xE523, "airstrikecount" },
    { 0xE524, "airstrikeid" },
    { 0xE525, "aitype_counts" },
    { 0xE526, "alcove_trig" },
    { 0xE527, "alertforspawngroupdirection" },
    { 0xE528, "alivejuggernauts" },
    { 0xE529, "all_alive_ai_hunt_players" },
    { 0xE52A, "all_alive_players" },
    { 0xE52B, "all_alive_players_entites" },
    { 0xE52C, "all_alive_players_entities" },
    { 0xE52D, "all_alive_players_near_exfil" },
    { 0xE52E, "all_but_one_player_downed" },
    { 0xE52F, "all_but_one_player_in_vehicle" },
    { 0xE530, "all_end_checkpoints_activated" },
    { 0xE531, "all_gas_trap_structs" },
    { 0xE532, "all_modes" },
    { 0xE533, "all_obit_models" },
    { 0xE534, "all_players_are_in_trap_room_entrance" },
    { 0xE535, "all_players_pushed_past_pos" },
    { 0xE536, "all_players_skip_last_stand" },
    { 0xE537, "all_players_within_distance2d" },
    { 0xE538, "all_players_within_distance2d_and_below_height" },
    { 0xE539, "all_waves" },
    { 0xE53A, "allammoboxes" },
    { 0xE53B, "allassassin_applyquest" },
    { 0xE53C, "allassassin_getsortedteams" },
    { 0xE53D, "allassassin_give" },
    { 0xE53E, "allassassin_givewait" },
    { 0xE53F, "allassassin_init" },
    { 0xE540, "allassassin_initteamlist" },
    { 0xE541, "allassassin_initteamlist_timed" },
    { 0xE542, "allassassin_oninstanceremoved" },
    { 0xE543, "allassassin_teamcompare" },
    { 0xE544, "allassassin_teams" },
    { 0xE545, "allassassin_timeout_end" },
    { 0xE546, "allassassin_update" },
    { 0xE547, "allassassin_update_timed" },
    { 0xE548, "allassassin_updatecircle" },
    { 0xE549, "allassassin_updatewait" },
    { 0xE54A, "allfobtriggers" },
    { 0xE54B, "allies_push_up" },
    { 0xE54C, "allies_respawns" },
    { 0xE54D, "allies_spawn_function" },
    { 0xE54E, "allnodes" },
    { 0xE54F, "allow_ascender_use" },
    { 0xE550, "allow_br_loot_to_br_marked" },
    { 0xE551, "allow_cp_munitions" },
    { 0xE552, "allow_deleteme_on_path" },
    { 0xE553, "allow_deleteme_path" },
    { 0xE554, "allow_earthquake" },
    { 0xE555, "allow_forward_factor" },
    { 0xE556, "allow_hotjoining" },
    { 0xE557, "allow_momentum" },
    { 0xE558, "allow_nvgs" },
    { 0xE559, "allow_offhand_throwback" },
    { 0xE55A, "allow_pickup_atmine" },
    { 0xE55B, "allow_player_basejumping" },
    { 0xE55C, "allow_player_minimapforcedisable" },
    { 0xE55D, "allow_player_skip_deathshield" },
    { 0xE55E, "allow_player_skip_laststand" },
    { 0xE55F, "allowassassinationdamage" },
    { 0xE560, "allowattackfromexposednonode" },
    { 0xE561, "allowed_gametypes" },
    { 0xE562, "allowed_objectives" },
    { 0xE563, "allowednormaldemeanor" },
    { 0xE564, "allowfultondropondeath" },
    { 0xE565, "allowleaderboardstatsupdates" },
    { 0xE566, "allowmeleevehicledamage" },
    { 0xE567, "allowmodestructs" },
    { 0xE568, "allownvgsatmatchstart" },
    { 0xE569, "allowobjectiveuseaftermatchstart" },
    { 0xE56A, "allowreuseofalldropbags" },
    { 0xE56B, "allowskydivecutparachute" },
    { 0xE56C, "allowunresolvedcollision" },
    { 0xE56D, "allowvipdamage" },
    { 0xE56E, "allplayers_clearphysicaldof" },
    { 0xE56F, "allplayers_setfov" },
    { 0xE570, "allplayers_setphysicaldof" },
    { 0xE571, "allsupportboxes" },
    { 0xE572, "ally1_intro_dialogue" },
    { 0xE573, "ally_charge_dialogue" },
    { 0xE574, "ally_damage_thread" },
    { 0xE575, "ally_initial_spawners" },
    { 0xE576, "ally_manager" },
    { 0xE577, "ally_movement_defend_0" },
    { 0xE578, "ally_spawns" },
    { 0xE579, "alternate_breach_anim_func" },
    { 0xE57A, "alternatebrcircle" },
    { 0xE57B, "alwaysdoskyspawnontacinsert" },
    { 0xE57C, "alwayssnowfight" },
    { 0xE57D, "ambush_lmg_guy" },
    { 0xE57E, "ambusher_spawn_func" },
    { 0xE57F, "ammo_box_spawn" },
    { 0xE580, "ammo_boxes" },
    { 0xE581, "ammo_buy_point_loop" },
    { 0xE582, "ammo_cache_delete" },
    { 0xE583, "ammo_cache_setup" },
    { 0xE584, "ammo_cache_think" },
    { 0xE585, "ammo_cache_used" },
    { 0xE586, "ammo_crate_spawn" },
    { 0xE587, "ammo_crate_think" },
    { 0xE588, "ammo_crate_trial_think" },
    { 0xE589, "ammo_crate_use" },
    { 0xE58A, "ammo_crates" },
    { 0xE58B, "ammo_manager" },
    { 0xE58C, "ammo_restock" },
    { 0xE58D, "ammobox_addrandomweapon" },
    { 0xE58E, "ammobox_bufferedattachmentweapon" },
    { 0xE58F, "ammobox_canweaponacceptmoreattachments" },
    { 0xE590, "ammobox_canweaponuserandomattachments" },
    { 0xE591, "ammobox_checkclearbufferedattachmentweapon" },
    { 0xE592, "ammobox_clearbufferedattachmentweapon" },
    { 0xE593, "ammobox_getbufferedattachment" },
    { 0xE594, "ammobox_getbufferedattachmentsourceweapon" },
    { 0xE595, "ammobox_getbufferedattachmentweapon" },
    { 0xE596, "ammobox_giverandomattachment" },
    { 0xE597, "ammobox_onplayerholduse" },
    { 0xE598, "ammobox_showattachmentflyout" },
    { 0xE599, "ammobox_tryuse" },
    { 0xE59A, "ammobox_tryuseinternal" },
    { 0xE59B, "ammobox_updateheadicononjointeam" },
    { 0xE59C, "ammoids" },
    { 0xE59D, "ammorestock_customlocale6cleanup" },
    { 0xE59E, "ammorestock_disableusefortime" },
    { 0xE59F, "ammorestock_used" },
    { 0xE5A0, "ammostructreplenish" },
    { 0xE5A1, "ammotype" },
    { 0xE5A2, "amounttotal" },
    { 0xE5A3, "amped_victim_starttime" },
    { 0xE5A4, "amped_wid" },
    { 0xE5A5, "ampeddelta" },
    { 0xE5A6, "analytics_init" },
    { 0xE5A7, "analytics_lui_mission_end_dlog" },
    { 0xE5A8, "anchoredwidgetid" },
    { 0xE5A9, "angle_molotov_mortar" },
    { 0xE5AA, "anglesoffset" },
    { 0xE5AB, "angvels" },
    { 0xE5AC, "anim_guy_keep_hidden" },
    { 0xE5AD, "anim_offset" },
    { 0xE5AE, "anim_override" },
    { 0xE5AF, "anim_pause_fracs" },
    { 0xE5B0, "anim_ref" },
    { 0xE5B1, "anim_scene_stance_override" },
    { 0xE5B2, "anim_spawnposition_override" },
    { 0xE5B3, "anim_trafficking_play_scene" },
    { 0xE5B4, "anim_weapon" },
    { 0xE5B5, "animatedprop_setanim" },
    { 0xE5B6, "animatedprop_setup" },
    { 0xE5B7, "animatedprop_startanim" },
    { 0xE5B8, "animscripted_clear" },
    { 0xE5B9, "animscripted_loop" },
    { 0xE5BA, "animscripted_loop_earlyend" },
    { 0xE5BB, "animscripted_loop_for_time" },
    { 0xE5BC, "animscripted_loop_n_times" },
    { 0xE5BD, "animscripted_loop_relative" },
    { 0xE5BE, "animscripted_single" },
    { 0xE5BF, "animscripted_single_arrive_at" },
    { 0xE5C0, "animscripted_single_earlyend" },
    { 0xE5C1, "animscripted_single_relative" },
    { 0xE5C2, "anin_playvo_func" },
    { 0xE5C3, "announcedomplatespawns" },
    { 0xE5C4, "announceplayercountlandmarks" },
    { 0xE5C5, "antennae" },
    { 0xE5C6, "any_alive_player_in_kill_zone_or_under_bridge_zone" },
    { 0xE5C7, "any_enemy_nearby" },
    { 0xE5C8, "any_player_in_laststand" },
    { 0xE5C9, "any_player_nearby_same_floor" },
    { 0xE5CA, "any_player_pushed_past_pos" },
    { 0xE5CB, "any_player_within_distance2d" },
    { 0xE5CC, "any_player_within_distance3d" },
    { 0xE5CD, "any_rider_still_alive_at_seat" },
    { 0xE5CE, "anyone_can_see_spawner" },
    { 0xE5CF, "anyoneisinmarkingrange" },
    { 0xE5D0, "anyplayersinlaststandhold" },
    { 0xE5D1, "apachepilotpool" },
    { 0xE5D2, "apc_horn" },
    { 0xE5D3, "apc_rus_adjustdriverturretammo" },
    { 0xE5D4, "apc_rus_damagecancriticalhit" },
    { 0xE5D5, "apc_rus_driverturretreload" },
    { 0xE5D6, "apc_rus_initcollision" },
    { 0xE5D7, "apc_rus_initdamage" },
    { 0xE5D8, "apc_rus_initomnvars" },
    { 0xE5D9, "apc_rus_monitordriverturretfire" },
    { 0xE5DA, "apc_rus_monitordriverturretreload" },
    { 0xE5DB, "apc_rus_postmoddamagecallback" },
    { 0xE5DC, "apc_rus_update" },
    { 0xE5DD, "apc_rus_updatedriverturretammoui" },
    { 0xE5DE, "apc_shoot_at_target" },
    { 0xE5DF, "apc_target_enemies" },
    { 0xE5E0, "apce_p1" },
    { 0xE5E1, "apcrespawntime" },
    { 0xE5E2, "apcturret" },
    { 0xE5E3, "appliednukethreads" },
    { 0xE5E4, "apply_common_combat_settings" },
    { 0xE5E5, "apply_track_settings" },
    { 0xE5E6, "applyanglesoffset" },
    { 0xE5E7, "applycirclesetdvars" },
    { 0xE5E8, "applycirclesettings" },
    { 0xE5E9, "applylocaledefaults" },
    { 0xE5EA, "applylocaledvars" },
    { 0xE5EB, "applyminigunrestrictions" },
    { 0xE5EC, "applymovingcircles" },
    { 0xE5ED, "applyprematchplotarmor" },
    { 0xE5EE, "applyquest" },
    { 0xE5EF, "applyxyzoffset" },
    { 0xE5F0, "aq_ontimerexpired" },
    { 0xE5F1, "aq_ontimerupdate" },
    { 0xE5F2, "aq_playerdisconnect" },
    { 0xE5F3, "aq_playerremoved" },
    { 0xE5F4, "aq_targethudenabled" },
    { 0xE5F5, "are_achievements_allowed" },
    { 0xE5F6, "are_all_alive_players_touching_plane" },
    { 0xE5F7, "are_all_hvts_eliminated" },
    { 0xE5F8, "are_all_players_in_region" },
    { 0xE5F9, "are_equal" },
    { 0xE5FA, "are_players_in_volume" },
    { 0xE5FB, "are_players_nearby_turret" },
    { 0xE5FC, "are_relics_active" },
    { 0xE5FD, "area1_targets" },
    { 0xE5FE, "area1_targets_mount" },
    { 0xE5FF, "area_structs" },
    { 0xE600, "area_vehicle_spawning" },
    { 0xE601, "areanygulagfightsactive" },
    { 0xE602, "areas_remaining" },
    { 0xE603, "arena_bot_get_total_gun_ammo" },
    { 0xE604, "arena_bot_out_of_ammo" },
    { 0xE605, "arena_bot_pickup_weapon" },
    { 0xE606, "arena_bot_seek_dropped_weapon" },
    { 0xE607, "arena_bot_think_seek_dropped_weapons" },
    { 0xE608, "arena_should_stop_seeking_weapon" },
    { 0xE609, "arena_turret_op" },
    { 0xE60A, "arena_turret_op_debug" },
    { 0xE60B, "arena_turret_op_internal" },
    { 0xE60C, "arenaballs" },
    { 0xE60D, "arenaflag_objectivehide" },
    { 0xE60E, "arenaflag_objectiveshow" },
    { 0xE60F, "arenaflag_onuncontested" },
    { 0xE610, "arenaflag_previewflag" },
    { 0xE611, "arenaflag_setcaptured" },
    { 0xE612, "arenaflag_setenabled" },
    { 0xE613, "arenaflag_setvisible" },
    { 0xE614, "arenaflag_setvisibledisableinternal" },
    { 0xE615, "arenaflag_setvisibleplayer" },
    { 0xE616, "arenaflag_showflagoutline" },
    { 0xE617, "arenaflag_showflagoutlineplayer" },
    { 0xE618, "arenaknivesout" },
    { 0xE619, "arenaloadouts_getoverrideweaponswithgroup" },
    { 0xE61A, "arenapickupattachments" },
    { 0xE61B, "arenastpday" },
    { 0xE61C, "arenavday" },
    { 0xE61D, "areplayersnear" },
    { 0xE61E, "argshave" },
    { 0xE61F, "armor_nag" },
    { 0xE620, "armor_piercing" },
    { 0xE621, "armor_target_vo" },
    { 0xE622, "armorbox_used" },
    { 0xE623, "armorbox_usedcallback" },
    { 0xE624, "armored_basic_combat" },
    { 0xE625, "armorqueued" },
    { 0xE626, "armorstructreplenish" },
    { 0xE627, "armorweapon" },
    { 0xE628, "armorylights" },
    { 0xE629, "armoryswitches" },
    { 0xE62A, "arms1think" },
    { 0xE62B, "arms2think" },
    { 0xE62C, "arms4think" },
    { 0xE62D, "arms_race_p1" },
    { 0xE62E, "armsdealer_loadout_interaction" },
    { 0xE62F, "armsrace_c4_charge_detonate_think" },
    { 0xE630, "armsrace_c4_charge_think" },
    { 0xE631, "armsrace_c4_plant_spot_reset_on_failed_plant" },
    { 0xE632, "armsrace_c4_planter_attack" },
    { 0xE633, "armsrace_c4_planter_backlot" },
    { 0xE634, "armsrace_c4_planter_internal" },
    { 0xE635, "armsrace_c4_planter_parking" },
    { 0xE636, "armsrace_c4_planter_super" },
    { 0xE637, "armsrace_caches_defended" },
    { 0xE638, "armsrace_phase_hold_behavior" },
    { 0xE639, "armsrace_phase_hold_behavior_internal" },
    { 0xE63A, "array_contains_solution" },
    { 0xE63B, "array_convert_keys_to_ints" },
    { 0xE63C, "array_init_distribute" },
    { 0xE63D, "array_init_fill" },
    { 0xE63E, "array_of_light_targetnames" },
    { 0xE63F, "array_sort_by_script_index" },
    { 0xE640, "array_spawn_safe" },
    { 0xE641, "ascender_deathwatcher" },
    { 0xE642, "ascender_disableplayeruse" },
    { 0xE643, "ascender_entrance" },
    { 0xE644, "ascender_entrance_2" },
    { 0xE645, "ascender_weapon" },
    { 0xE646, "ascenderinstantstop" },
    { 0xE647, "ascendermodelview" },
    { 0xE648, "ascendermodelworld" },
    { 0xE649, "ascendermsgfunc" },
    { 0xE64A, "ascenders" },
    { 0xE64B, "ascendersoloscriptableused" },
    { 0xE64C, "ascenderstart" },
    { 0xE64D, "ascendsolostarts" },
    { 0xE64E, "ascendsolostructs" },
    { 0xE64F, "asm_animhasfacialoverridemp" },
    { 0xE650, "asm_playfacialanim_mp" },
    { 0xE651, "asm_playfacialaniminternalmp" },
    { 0xE652, "asm_setanimscripted" },
    { 0xE653, "assassination_target" },
    { 0xE654, "assassinationcontract_complete" },
    { 0xE655, "assassinationcontract_get" },
    { 0xE656, "assassinationtimewarning" },
    { 0xE657, "assault1_riverbed" },
    { 0xE658, "assault2_fob" },
    { 0xE659, "assault3_hangar" },
    { 0xE65A, "assault_update_hint_logic" },
    { 0xE65B, "assaultkill" },
    { 0xE65C, "assertcirclesettings" },
    { 0xE65D, "assign_loadout_weapons" },
    { 0xE65E, "assign_lowest_full_slot_to_active" },
    { 0xE65F, "assign_nearby_jammer_as_pursuit_target" },
    { 0xE660, "assignclientmatchdataid" },
    { 0xE661, "assigncodecomputersdisplaycodes" },
    { 0xE662, "assigned_ai" },
    { 0xE663, "assigned_ai_index" },
    { 0xE664, "assigned_to_player" },
    { 0xE665, "assignedteam" },
    { 0xE666, "assignintelchallenges" },
    { 0xE667, "assignkilledplayermodifiers" },
    { 0xE668, "assignscriptablemodels" },
    { 0xE669, "assignspectatortospectatetryagain" },
    { 0xE66A, "assignvehiclestoteams" },
    { 0xE66B, "assistsgiven" },
    { 0xE66C, "associate_digit_display_model" },
    { 0xE66D, "astar_get_path" },
    { 0xE66E, "astar_node_radius_override" },
    { 0xE66F, "at_mine_movingplatform_update" },
    { 0xE670, "atcapacitycallback" },
    { 0xE671, "atmines_delete" },
    { 0xE672, "attach_turret" },
    { 0xE673, "attachdrill" },
    { 0xE674, "attached_bag" },
    { 0xE675, "attachedlights" },
    { 0xE676, "attachedvelocity" },
    { 0xE677, "attachment" },
    { 0xE678, "attachmentisselectable" },
    { 0xE679, "attachmentisselectablerootname" },
    { 0xE67A, "attachmentmap_attachtoblocks" },
    { 0xE67B, "attachmentmap_baseattachtocategory" },
    { 0xE67C, "attachmentmap_toblocks" },
    { 0xE67D, "attachmentmap_tocategory" },
    { 0xE67E, "attachmentmap_uniqueattachtocategory" },
    { 0xE67F, "attachmentsourceweapon" },
    { 0xE680, "attachmentweapon" },
    { 0xE681, "attack_heli" },
    { 0xE682, "attack_next_available_time" },
    { 0xE683, "attack_player_cooldown" },
    { 0xE684, "attacked_by_chopper" },
    { 0xE685, "attackerinitammo" },
    { 0xE686, "attackerisinflictor" },
    { 0xE687, "attackerisinflictorforradiusexplosiveweapon" },
    { 0xE688, "attackerregenammo" },
    { 0xE689, "attackerswaittime" },
    { 0xE68A, "attackfactormod" },
    { 0xE68B, "attackpressed" },
    { 0xE68C, "attempted_to_use_gunship" },
    { 0xE68D, "attraction_sr_range_hud" },
    { 0xE68E, "atv" },
    { 0xE68F, "atv_horn" },
    { 0xE690, "atv_initcollision" },
    { 0xE691, "atv_initdamage" },
    { 0xE692, "atv_initomnvars" },
    { 0xE693, "atv_outline" },
    { 0xE694, "atv_trail" },
    { 0xE695, "atv_vehicle" },
    { 0xE696, "atvanglesarray" },
    { 0xE697, "atvoriginsarray" },
    { 0xE698, "aud_breached_exit_wind" },
    { 0xE699, "aud_interior_plane_audio_zones" },
    { 0xE69A, "audio_c4_plant_sfx_sequence" },
    { 0xE69B, "audio_enablepa" },
    { 0xE69C, "audio_fade_in_ext_walla" },
    { 0xE69D, "audio_fire_loop_start" },
    { 0xE69E, "audio_gauntlet_leave_sfx_transition" },
    { 0xE69F, "audio_heli_end_fade_out" },
    { 0xE6A0, "audio_heli_fade_up" },
    { 0xE6A1, "audio_jugg_death" },
    { 0xE6A2, "audio_jugg_spawn" },
    { 0xE6A3, "audio_panodes" },
    { 0xE6A4, "audio_play_bodyfalls_for_htf_anims" },
    { 0xE6A5, "audio_play_littlebird_sfx" },
    { 0xE6A6, "audio_player_delete_mud_loop" },
    { 0xE6A7, "audio_player_spawn_mud_loop" },
    { 0xE6A8, "audio_player_start_mud_loop" },
    { 0xE6A9, "audio_player_stop_mud_loop" },
    { 0xE6AA, "audio_railyard_fires" },
    { 0xE6AB, "audio_shf_kill_hangar_lights" },
    { 0xE6AC, "audio_start_obj_room_fires" },
    { 0xE6AD, "audio_stop_obj_room_fires" },
    { 0xE6AE, "auto_move_on_first_proxy" },
    { 0xE6AF, "auto_respawn_timer" },
    { 0xE6B0, "autoapplyquest" },
    { 0xE6B1, "autoassignfirstquest" },
    { 0xE6B2, "autoassignlowteamconsistent" },
    { 0xE6B3, "autoassignquest" },
    { 0xE6B4, "autobankedteams" },
    { 0xE6B5, "autobankteamplunder" },
    { 0xE6B6, "autodisabletacmapsetting" },
    { 0xE6B7, "autofeeder" },
    { 0xE6B8, "autorespawnwaittime" },
    { 0xE6B9, "autostartcircle" },
    { 0xE6BA, "autostructnum" },
    { 0xE6BB, "available_time" },
    { 0xE6BC, "avangvel" },
    { 0xE6BD, "avlinvel" },
    { 0xE6BE, "avoidclosetodefenderflag" },
    { 0xE6BF, "avoidclosetodefenderflagspawn" },
    { 0xE6C0, "avoids_recently_cleared_area" },
    { 0xE6C1, "awardbunker11blueprint" },
    { 0xE6C2, "awardmasterychallenge" },
    { 0xE6C3, "awardnoweaponxp" },
    { 0xE6C4, "awardobjtimeforcarrier" },
    { 0xE6C5, "awardstadiumblueprint" },
    { 0xE6C6, "back_door_enemy_watcher" },
    { 0xE6C7, "back_field_clip" },
    { 0xE6C8, "back_struct" },
    { 0xE6C9, "back_vector" },
    { 0xE6CA, "backendevent" },
    { 0xE6CB, "backfire" },
    { 0xE6CC, "backhatch_delayshow" },
    { 0xE6CD, "backpack_dummy_spawn" },
    { 0xE6CE, "backtruck" },
    { 0xE6CF, "backup_deposit" },
    { 0xE6D0, "backup_plane_locations" },
    { 0xE6D1, "backwallkeypad" },
    { 0xE6D2, "badpathnodes" },
    { 0xE6D3, "bagentinitialized" },
    { 0xE6D4, "baitedbydecoy" },
    { 0xE6D5, "ballistics_weaponswitchmonitor" },
    { 0xE6D6, "ballistsglobalsettings" },
    { 0xE6D7, "ballon_deposit_nag_stopper" },
    { 0xE6D8, "balloon_deposit" },
    { 0xE6D9, "balloon_deposit_cash_nags" },
    { 0xE6DA, "balloon_deposit_cash_vo_explanation" },
    { 0xE6DB, "balloon_deposit_monitor" },
    { 0xE6DC, "balloon_hint_logic" },
    { 0xE6DD, "balloons" },
    { 0xE6DE, "ballowexecutions" },
    { 0xE6DF, "baloon_deposit_death_check" },
    { 0xE6E0, "bankingoverlimitwillendot" },
    { 0xE6E1, "bankplunderextractinstantly" },
    { 0xE6E2, "barelem" },
    { 0xE6E3, "barkov_crawl_scene_nostab" },
    { 0xE6E4, "barkov_execution_path" },
    { 0xE6E5, "barkov_shooting_path_nostab" },
    { 0xE6E6, "barrel_think" },
    { 0xE6E7, "base_angles" },
    { 0xE6E8, "base_assault_intro_vo" },
    { 0xE6E9, "basic_combat" },
    { 0xE6EA, "battle_station_combat_logic" },
    { 0xE6EB, "battle_stations" },
    { 0xE6EC, "battle_tracks_clearbattletracks" },
    { 0xE6ED, "battle_tracks_createdefaultlisteningzone" },
    { 0xE6EE, "battle_tracks_createexternallisteningzone" },
    { 0xE6EF, "battle_tracks_getbattletracksid" },
    { 0xE6F0, "battle_tracks_getmusicstate" },
    { 0xE6F1, "battle_tracks_getnewtogglestate" },
    { 0xE6F2, "battle_tracks_getplayerdataenum" },
    { 0xE6F3, "battle_tracks_getsfxalias" },
    { 0xE6F4, "battle_tracks_gettogglestate" },
    { 0xE6F5, "battle_tracks_gettrackindex" },
    { 0xE6F6, "battle_tracks_hasemptybattletracks" },
    { 0xE6F7, "battle_tracks_hidetogglewidget" },
    { 0xE6F8, "battle_tracks_isbattletracksowner" },
    { 0xE6F9, "battle_tracks_monitorstandingonvehicles" },
    { 0xE6FA, "battle_tracks_onentervehicle" },
    { 0xE6FB, "battle_tracks_onexitvehicle" },
    { 0xE6FC, "battle_tracks_playbattletrackstoalloccupants" },
    { 0xE6FD, "battle_tracks_playbattletrackstoplayer" },
    { 0xE6FE, "battle_tracks_playbattletrackswhenstandingonvehicle" },
    { 0xE6FF, "battle_tracks_playerinlisteningzone" },
    { 0xE700, "battle_tracks_playerinlisteningzoneinternal" },
    { 0xE701, "battle_tracks_playerinsidezone" },
    { 0xE702, "battle_tracks_playerselectrandomtracks" },
    { 0xE703, "battle_tracks_setmusicstate" },
    { 0xE704, "battle_tracks_settogglestate" },
    { 0xE705, "battle_tracks_shouldplaybattletrackswhenstandingonvehicle" },
    { 0xE706, "battle_tracks_shouldstartbattletracks" },
    { 0xE707, "battle_tracks_standingonsamevehiclewithsametracksowner" },
    { 0xE708, "battle_tracks_standingonvehicletimeout" },
    { 0xE709, "battle_tracks_stopbattletracksforplayer" },
    { 0xE70A, "battle_tracks_stopbattletracksfromstandingonvehicle" },
    { 0xE70B, "battle_tracks_stopbattletrackstoalloccupants" },
    { 0xE70C, "battle_tracks_stopbattletrackswhenstandingonvehicle" },
    { 0xE70D, "battle_tracks_stoptogglethink" },
    { 0xE70E, "battle_tracks_toggleoffstate" },
    { 0xE70F, "battle_tracks_toggleonstate" },
    { 0xE710, "battle_tracks_togglestateis" },
    { 0xE711, "battle_tracks_togglethink" },
    { 0xE712, "battle_tracks_tryinittogglestate" },
    { 0xE713, "battle_tracks_tryplayingbattletrackswhenstandingonvehicle" },
    { 0xE714, "battle_tracks_trystopdrivertogglethink" },
    { 0xE715, "battle_tracks_updatebattletracks" },
    { 0xE716, "battle_tracks_updatebattletracksfromplayerdata" },
    { 0xE717, "battle_tracks_updateexternallisteningzone" },
    { 0xE718, "battle_tracks_updatetogglestate" },
    { 0xE719, "battle_tracks_vehicleallowlisteningoutsideoccupancy" },
    { 0xE71A, "battle_tracks_vehicleoccupancyenter" },
    { 0xE71B, "battlepassxpmultipliers" },
    { 0xE71C, "battletracks" },
    { 0xE71D, "battletracksidstandingonvehicle" },
    { 0xE71E, "battletracksmusicstate" },
    { 0xE71F, "battletracksmusicstatestandingonvehicle" },
    { 0xE720, "battletracksowner" },
    { 0xE721, "bbeingelectrocuted" },
    { 0xE722, "bdiedonce" },
    { 0xE723, "bdroppingshield" },
    { 0xE724, "beacon" },
    { 0xE725, "beaker_end_time" },
    { 0xE726, "beardone" },
    { 0xE727, "bears" },
    { 0xE728, "bearsetup" },
    { 0xE729, "bearsred" },
    { 0xE72A, "bearwatch" },
    { 0xE72B, "begin_spectate" },
    { 0xE72C, "begin_vo" },
    { 0xE72D, "being_hacked" },
    { 0xE72E, "being_kicked_from_inactivity" },
    { 0xE72F, "being_pickedup" },
    { 0xE730, "below_player_eye_allowance" },
    { 0xE731, "bestplayer" },
    { 0xE732, "besttime" },
    { 0xE733, "besttimestate" },
    { 0xE734, "bettermissiontierbonuses" },
    { 0xE735, "bhadriotshield" },
    { 0xE736, "bhasriotshieldattached" },
    { 0xE737, "bhasthermitestucktoshield" },
    { 0xE738, "big_door_watcher" },
    { 0xE739, "bigtimer" },
    { 0xE73A, "binding" },
    { 0xE73B, "bindingpc" },
    { 0xE73C, "bink_save_hack" },
    { 0xE73D, "binoculars_addheadicon" },
    { 0xE73E, "binoculars_addmarkpoints" },
    { 0xE73F, "binoculars_addtolosqueue" },
    { 0xE740, "binoculars_cansee" },
    { 0xE741, "binoculars_checkexpirationtimer" },
    { 0xE742, "binoculars_checkpendingtimer" },
    { 0xE743, "binoculars_cleanupheadiconondisconnect" },
    { 0xE744, "binoculars_clearexpirationtimer" },
    { 0xE745, "binoculars_clearpendingtimer" },
    { 0xE746, "binoculars_clearuidata" },
    { 0xE747, "binoculars_endadslogic" },
    { 0xE748, "binoculars_getfov" },
    { 0xE749, "binoculars_getmaxrange" },
    { 0xE74A, "binoculars_getpendingendtime" },
    { 0xE74B, "binoculars_getpendingtime" },
    { 0xE74C, "binoculars_giveassistpoints" },
    { 0xE74D, "binoculars_hascoldblooded" },
    { 0xE74E, "binoculars_hidetargetmarker" },
    { 0xE74F, "binoculars_init" },
    { 0xE750, "binoculars_isads" },
    { 0xE751, "binoculars_istargetinbroadfov" },
    { 0xE752, "binoculars_istargetinrange" },
    { 0xE753, "binoculars_iswithinprojectiondistance" },
    { 0xE754, "binoculars_iswithinprojectiondistance_compute" },
    { 0xE755, "binoculars_ongive" },
    { 0xE756, "binoculars_onstateenterfunc" },
    { 0xE757, "binoculars_onstateexitfunc" },
    { 0xE758, "binoculars_onstateinvalidenter" },
    { 0xE759, "binoculars_onstateinvalidexit" },
    { 0xE75A, "binoculars_onstateinvalidupdate" },
    { 0xE75B, "binoculars_onstatelospendingenter" },
    { 0xE75C, "binoculars_onstatelospendingexit" },
    { 0xE75D, "binoculars_onstatelospendingupdate" },
    { 0xE75E, "binoculars_onstatemarkedenter" },
    { 0xE75F, "binoculars_onstatemarkedexit" },
    { 0xE760, "binoculars_onstatemarkedupdate" },
    { 0xE761, "binoculars_onstatemarkpendingenter" },
    { 0xE762, "binoculars_onstatemarkpendingexit" },
    { 0xE763, "binoculars_onstatemarkpendingupdate" },
    { 0xE764, "binoculars_onstateunmarkedenter" },
    { 0xE765, "binoculars_onstateunmarkedexit" },
    { 0xE766, "binoculars_onstateunmarkedupdate" },
    { 0xE767, "binoculars_onstateupdatefunc" },
    { 0xE768, "binoculars_ontake" },
    { 0xE769, "binoculars_processlosqueue" },
    { 0xE76A, "binoculars_processlosqueuehigh" },
    { 0xE76B, "binoculars_processlosqueuelow" },
    { 0xE76C, "binoculars_processtargetdata" },
    { 0xE76D, "binoculars_processtargetlos" },
    { 0xE76E, "binoculars_registertargetstate" },
    { 0xE76F, "binoculars_removeheadicon" },
    { 0xE770, "binoculars_runadslogic" },
    { 0xE771, "binoculars_setcurrentstate" },
    { 0xE772, "binoculars_setexpirationtimer" },
    { 0xE773, "binoculars_setpendingtimer" },
    { 0xE774, "binoculars_settargetmarkerstate" },
    { 0xE775, "binoculars_setuidata" },
    { 0xE776, "binoculars_showtargetmarker" },
    { 0xE777, "binoculars_targetismarked" },
    { 0xE778, "binoculars_targetisvalid" },
    { 0xE779, "binoculars_targetisvalidmark" },
    { 0xE77A, "binoculars_updateheadiconvisibility" },
    { 0xE77B, "binoculars_updateheadiconvisibilityforplayer" },
    { 0xE77C, "binoculars_updateprojectiondistance" },
    { 0xE77D, "binoculars_updatetargetmarker" },
    { 0xE77E, "binoculars_updateuidata" },
    { 0xE77F, "binoculars_used" },
    { 0xE780, "binoculars_watchforads" },
    { 0xE781, "binoculars_watchraceadsoff" },
    { 0xE782, "binoculars_watchraceadson" },
    { 0xE783, "binoculars_watchracedeath" },
    { 0xE784, "binoculars_watchracelaststand" },
    { 0xE785, "binoculars_watchracetake" },
    { 0xE786, "binocularsinited" },
    { 0xE787, "binocularsstate" },
    { 0xE788, "binocularsstruct" },
    { 0xE789, "bintheplane" },
    { 0xE78A, "birds_in_square_monitor" },
    { 0xE78B, "bischildthread" },
    { 0xE78C, "biscodefunc" },
    { 0xE78D, "bisdeaf" },
    { 0xE78E, "bisoverwatch" },
    { 0xE78F, "bisthread" },
    { 0xE790, "bistrexactive" },
    { 0xE791, "bits" },
    { 0xE792, "black_screen_overlay" },
    { 0xE793, "blade_trigger_think" },
    { 0xE794, "blank_relic_func" },
    { 0xE795, "bleedout_heartbeat_sfx_logic" },
    { 0xE796, "bleedout_logic" },
    { 0xE797, "blend_movespeedscale_cpso" },
    { 0xE798, "blink_train_test" },
    { 0xE799, "blink_wheelson_chosen_spawn" },
    { 0xE79A, "blinkblackoverlay" },
    { 0xE79B, "blinking_light_thread" },
    { 0xE79C, "bloadinghvt" },
    { 0xE79D, "blockachievementstimestamp" },
    { 0xE79E, "blockade_barbwires" },
    { 0xE79F, "blockade_barrier_clip" },
    { 0xE7A0, "blockade_gate" },
    { 0xE7A1, "blockade_gate_explode_sequence" },
    { 0xE7A2, "blockade_get_bomb_icon_on_cell_phone" },
    { 0xE7A3, "blockclasschange" },
    { 0xE7A4, "blockdrive" },
    { 0xE7A5, "blocked" },
    { 0xE7A6, "blockeddoor" },
    { 0xE7A7, "blockeddoubledoor" },
    { 0xE7A8, "blockedvariantidsmap" },
    { 0xE7A9, "blockingcover" },
    { 0xE7AA, "blockreviveanimation" },
    { 0xE7AB, "blookforvehicles" },
    { 0xE7AC, "blueprint_chancebase" },
    { 0xE7AD, "blueprint_chancepercontract" },
    { 0xE7AE, "blueprint_maxpermatch" },
    { 0xE7AF, "blueprintcreatingteam" },
    { 0xE7B0, "blueprintextract_beforepickupspawned" },
    { 0xE7B1, "blueprintextract_cleanupwhennoavailablelocales" },
    { 0xE7B2, "blueprintextract_createtempobjective" },
    { 0xE7B3, "blueprintextract_onpickupcreated" },
    { 0xE7B4, "blueprintextract_setunlockablelootid" },
    { 0xE7B5, "blueprintextract_shouldgivereward" },
    { 0xE7B6, "blueprintextract_trygetreward" },
    { 0xE7B7, "blueprintextractchance" },
    { 0xE7B8, "blueprintextractspawns" },
    { 0xE7B9, "bmoendgameot" },
    { 0xE7BA, "bmoovertime" },
    { 0xE7BB, "bnoself" },
    { 0xE7BC, "boardroomdoorcodeentrysuccess" },
    { 0xE7BD, "boardroomopen" },
    { 0xE7BE, "body0" },
    { 0xE7BF, "bodyonly_guy_in_car_damage_monitor" },
    { 0xE7C0, "bolt_trytopickup" },
    { 0xE7C1, "bolt_watchpickup" },
    { 0xE7C2, "boltdeleteonnote" },
    { 0xE7C3, "boltdeletethread" },
    { 0xE7C4, "boltnumber" },
    { 0xE7C5, "boltsinflight" },
    { 0xE7C6, "boltunlink" },
    { 0xE7C7, "boltunlinkonnote" },
    { 0xE7C8, "bomb_carrier" },
    { 0xE7C9, "bomb_case_detonator_control_think" },
    { 0xE7CA, "bomb_case_detonator_think" },
    { 0xE7CB, "bomb_case_detonator_timer_bar_think" },
    { 0xE7CC, "bomb_case_detonator_wire_color_change_think" },
    { 0xE7CD, "bomb_case_explode_vfx_sequence" },
    { 0xE7CE, "bomb_count_down_end_time_stamp_ms" },
    { 0xE7CF, "bomb_detonator_bomb_type" },
    { 0xE7D0, "bomb_detonator_holder" },
    { 0xE7D1, "bomb_detonator_interact" },
    { 0xE7D2, "bomb_detonator_waiting_for_pick_up" },
    { 0xE7D3, "bomb_hostage_play_anim" },
    { 0xE7D4, "bomb_interaction_ent" },
    { 0xE7D5, "bomb_label" },
    { 0xE7D6, "bomb_on_vehicle_clean_up_monior" },
    { 0xE7D7, "bomb_plant_allowed" },
    { 0xE7D8, "bomb_planted" },
    { 0xE7D9, "bomb_sites" },
    { 0xE7DA, "bomb_sites_spawn" },
    { 0xE7DB, "bomb_use_player" },
    { 0xE7DC, "bomb_use_watcher" },
    { 0xE7DD, "bomb_vest_controller_holder" },
    { 0xE7DE, "bomb_vest_detonator_control_think" },
    { 0xE7DF, "bomb_vest_detonator_think" },
    { 0xE7E0, "bomb_vest_explodes" },
    { 0xE7E1, "bomb_vest_success_fail_think" },
    { 0xE7E2, "bomb_vest_timer_frozen" },
    { 0xE7E3, "bomb_vest_timer_red_starting_frame" },
    { 0xE7E4, "bomb_vest_timer_remaining_num_of_frame" },
    { 0xE7E5, "bomb_vest_timer_remaining_time_ms" },
    { 0xE7E6, "bomb_vest_timer_total_num_of_frame" },
    { 0xE7E7, "bomb_vest_timer_yellow_starting_frame" },
    { 0xE7E8, "bomb_vests_explode" },
    { 0xE7E9, "bomb_wires_to_cut" },
    { 0xE7EA, "bomber" },
    { 0xE7EB, "bomber_damage_thread" },
    { 0xE7EC, "bomber_death_thread" },
    { 0xE7ED, "bomber_death_watcher" },
    { 0xE7EE, "bomber_delay_thread" },
    { 0xE7EF, "bomber_disable_movement_for_time" },
    { 0xE7F0, "bomber_radiusdamage" },
    { 0xE7F1, "bomber_shouldusetraversals" },
    { 0xE7F2, "bomber_spawn_origin_array_init" },
    { 0xE7F3, "bomber_spawn_origins" },
    { 0xE7F4, "bomber_spawner" },
    { 0xE7F5, "bomber_spawns" },
    { 0xE7F6, "bomber_test" },
    { 0xE7F7, "bomber_think" },
    { 0xE7F8, "bomber_vip_wait_to_engage" },
    { 0xE7F9, "bomberexplodeheight" },
    { 0xE7FA, "bombers_spawn_manager" },
    { 0xE7FB, "bombpuzzle_setup_marker_vfx" },
    { 0xE7FC, "bombradialfill" },
    { 0xE7FD, "bombs_setup" },
    { 0xE7FE, "bombsdefused" },
    { 0xE7FF, "bombzone_is_active" },
    { 0xE800, "bombzone_picked" },
    { 0xE801, "bombzone_press_use" },
    { 0xE802, "bonus_target" },
    { 0xE803, "bonus_target_domage" },
    { 0xE804, "bonus_target_hit" },
    { 0xE805, "bonus_target_score" },
    { 0xE806, "bonus_targets" },
    { 0xE807, "bonusdeathplunder" },
    { 0xE808, "bonusdeathplunderot" },
    { 0xE809, "bonuskillscharge" },
    { 0xE80A, "bonuskillstreakcharge" },
    { 0xE80B, "bonusobjectivescorecharge" },
    { 0xE80C, "bonustimeapplied" },
    { 0xE80D, "bonuswingamescharge" },
    { 0xE80E, "bootcampmodewatcher" },
    { 0xE80F, "borntime" },
    { 0xE810, "boss_fight_combat" },
    { 0xE811, "boss_fight_combat_cave" },
    { 0xE812, "boss_fight_combat_forest" },
    { 0xE813, "boss_fight_combat_laser_trap" },
    { 0xE814, "boss_one_minion_watcher" },
    { 0xE815, "boss_two_minion_watcher" },
    { 0xE816, "boss_wave" },
    { 0xE817, "bot1" },
    { 0xE818, "bot_abort_emp_pickup" },
    { 0xE819, "bot_abort_tactical_goal_for_revive" },
    { 0xE81A, "bot_add_destination_spot" },
    { 0xE81B, "bot_add_landing_spot" },
    { 0xE81C, "bot_affirm" },
    { 0xE81D, "bot_allowed_to_try_last_loadout" },
    { 0xE81E, "bot_allowed_weapons" },
    { 0xE81F, "bot_arena_think" },
    { 0xE820, "bot_br_circle_think" },
    { 0xE821, "bot_brtdm_think" },
    { 0xE822, "bot_cache_entrances_to_other_radios" },
    { 0xE823, "bot_cache_entrances_to_other_zones" },
    { 0xE824, "bot_cache_entrances_to_zones" },
    { 0xE825, "bot_can_switch_to_attacker" },
    { 0xE826, "bot_can_switch_to_defender" },
    { 0xE827, "bot_can_tag_interact_with" },
    { 0xE828, "bot_capture_hq_zone" },
    { 0xE829, "bot_capture_koth_zone" },
    { 0xE82A, "bot_choose_attack_role" },
    { 0xE82B, "bot_choose_attack_zone" },
    { 0xE82C, "bot_choose_defend_role" },
    { 0xE82D, "bot_choose_defend_zone" },
    { 0xE82E, "bot_clear_hq_zone" },
    { 0xE82F, "bot_ctf_ai_director_update" },
    { 0xE830, "bot_ctf_can_switch_to_defender" },
    { 0xE831, "bot_ctf_enemy_team_flag_is_picked_up" },
    { 0xE832, "bot_ctf_flag_is_home_of_team" },
    { 0xE833, "bot_ctf_flag_picked_up_of_team" },
    { 0xE834, "bot_ctf_get_node_chance" },
    { 0xE835, "bot_ctf_my_team_flag_is_picked_up" },
    { 0xE836, "bot_ctf_player_always_attacker" },
    { 0xE837, "bot_ctf_player_has_flag" },
    { 0xE838, "bot_ctf_recover_flag" },
    { 0xE839, "bot_cur_loadout_num" },
    { 0xE83A, "bot_custom_classes_allowed" },
    { 0xE83B, "bot_dd_ai_director_update" },
    { 0xE83C, "bot_dd_clear_role" },
    { 0xE83D, "bot_dd_set_role" },
    { 0xE83E, "bot_dd_start" },
    { 0xE83F, "bot_dd_think" },
    { 0xE840, "bot_default_class_random" },
    { 0xE841, "bot_destination_spots" },
    { 0xE842, "bot_difficulty_adjust" },
    { 0xE843, "bot_disable_movement_for_time" },
    { 0xE844, "bot_fixup_pathnode_issues" },
    { 0xE845, "bot_flag_ai_director_update" },
    { 0xE846, "bot_gametype_allied_attackers_for_team" },
    { 0xE847, "bot_gametype_allied_defenders_for_team" },
    { 0xE848, "bot_gametype_allowed_to_switch_to_attacker" },
    { 0xE849, "bot_gametype_allowed_to_switch_to_defender" },
    { 0xE84A, "bot_gametype_attacker_defender_ai_director_update" },
    { 0xE84B, "bot_gametype_attacker_limit_for_team" },
    { 0xE84C, "bot_gametype_defender_limit_for_team" },
    { 0xE84D, "bot_gametype_get_allied_attackers_for_team" },
    { 0xE84E, "bot_gametype_get_allied_defenders_for_team" },
    { 0xE84F, "bot_gametype_get_num_players_on_team" },
    { 0xE850, "bot_gametype_get_players_by_role" },
    { 0xE851, "bot_gametype_human_player_always_attacker" },
    { 0xE852, "bot_gametype_human_player_always_considered_attacker" },
    { 0xE853, "bot_gametype_human_player_always_considered_defender" },
    { 0xE854, "bot_gametype_human_player_always_defender" },
    { 0xE855, "bot_gametype_initialize_attacker_defender_role" },
    { 0xE856, "bot_gametype_radios_precached" },
    { 0xE857, "bot_gametype_set_role" },
    { 0xE858, "bot_gametype_zones_precached" },
    { 0xE859, "bot_get_active_tactical_goals_of_type" },
    { 0xE85A, "bot_get_angles_to_goal" },
    { 0xE85B, "bot_get_distance_to_goal" },
    { 0xE85C, "bot_get_flag_carrier" },
    { 0xE85D, "bot_get_human_picked_class" },
    { 0xE85E, "bot_get_landing_spot" },
    { 0xE85F, "bot_get_low_on_all_ammo" },
    { 0xE860, "bot_get_num_teammates_capturing_zone" },
    { 0xE861, "bot_get_player_enemy" },
    { 0xE862, "bot_get_stored_custom_classes" },
    { 0xE863, "bot_get_stored_launcher_class" },
    { 0xE864, "bot_get_tdef_flag" },
    { 0xE865, "bot_get_teammates_capturing_zone" },
    { 0xE866, "bot_give_weapon" },
    { 0xE867, "bot_go_to_destination" },
    { 0xE868, "bot_gulag_think" },
    { 0xE869, "bot_gun_pick_personality_from_weapon" },
    { 0xE86A, "bot_has_player_enemy" },
    { 0xE86B, "bot_has_streak_in_crate" },
    { 0xE86C, "bot_hp_allow_predictive_capping" },
    { 0xE86D, "bot_hq_start" },
    { 0xE86E, "bot_hq_think" },
    { 0xE86F, "bot_is_capturing_hq_zone" },
    { 0xE870, "bot_is_capturing_zone" },
    { 0xE871, "bot_is_in_gas" },
    { 0xE872, "bot_is_protecting_hq_zone" },
    { 0xE873, "bot_item_matches_purpose" },
    { 0xE874, "bot_killstreak_setup_func" },
    { 0xE875, "bot_known_flag_carrier_loc" },
    { 0xE876, "bot_koth_think" },
    { 0xE877, "bot_landing_spots" },
    { 0xE878, "bot_last_loadout_num" },
    { 0xE879, "bot_loadout" },
    { 0xE87A, "bot_loadout_choose_from_custom_default_class" },
    { 0xE87B, "bot_loadout_team" },
    { 0xE87C, "bot_match_rules_invalidate_loadout" },
    { 0xE87D, "bot_modify_behavior_from_loadout" },
    { 0xE87E, "bot_modify_behavior_from_tweakables" },
    { 0xE87F, "bot_nag" },
    { 0xE880, "bot_nags" },
    { 0xE881, "bot_next_difficulty_type_index" },
    { 0xE882, "bot_on_player_death" },
    { 0xE883, "bot_parachute_into_map" },
    { 0xE884, "bot_pick_dd_zone_with_fewer_defenders" },
    { 0xE885, "bot_pick_new_loadout_next_spawn" },
    { 0xE886, "bot_pick_new_zone" },
    { 0xE887, "bot_pickup_origin" },
    { 0xE888, "bot_protect_hq_zone" },
    { 0xE889, "bot_set_difficultysetting" },
    { 0xE88A, "bot_set_zone_nodes" },
    { 0xE88B, "bot_shotguns" },
    { 0xE88C, "bot_should_cap_next_zone" },
    { 0xE88D, "bot_snipers" },
    { 0xE88E, "bot_spawned_this_round" },
    { 0xE88F, "bot_start" },
    { 0xE890, "bot_tdef_think" },
    { 0xE891, "bot_thanks" },
    { 0xE892, "bot_try_switch_attack_zone" },
    { 0xE893, "bot_try_use_ambush_item" },
    { 0xE894, "bot_update_difficultysetttings" },
    { 0xE895, "bot_verify_and_cache_bombzones" },
    { 0xE896, "botdisablekillstreaks" },
    { 0xE897, "botisonplayerteam" },
    { 0xE898, "botloadoutfavoritecamoprimary" },
    { 0xE899, "botloadoutfavoritecamosecondary" },
    { 0xE89A, "botpickskinid" },
    { 0xE89B, "bots_create_landing_spots" },
    { 0xE89C, "bots_seek_player" },
    { 0xE89D, "bots_with_player_enemy" },
    { 0xE89E, "botstopmovingonlaststand" },
    { 0xE89F, "bottompercentagetoadjusteconomy" },
    { 0xE8A0, "bounceshot" },
    { 0xE8A1, "boundary" },
    { 0xE8A2, "box_used_common_setup" },
    { 0xE8A3, "bpullout" },
    { 0xE8A4, "br_add_player_commands" },
    { 0xE8A5, "br_allowdropspawnafterprematch" },
    { 0xE8A6, "br_allowloadout" },
    { 0xE8A7, "br_alt_mode_impulse_player" },
    { 0xE8A8, "br_alt_mode_inflation" },
    { 0xE8A9, "br_ammo_player_is_maxed_out" },
    { 0xE8AA, "br_ammo_player_max_out" },
    { 0xE8AB, "br_ammo_update_ammotype_weapons" },
    { 0xE8AC, "br_ammorestock_playeruse" },
    { 0xE8AD, "br_armor_plate_amount_equipped_set" },
    { 0xE8AE, "br_armor_plate_broken_remove" },
    { 0xE8AF, "br_armor_plate_used" },
    { 0xE8B0, "br_armor_repair_end" },
    { 0xE8B1, "br_badcircleareas" },
    { 0xE8B2, "br_bunker_alt" },
    { 0xE8B3, "br_c130spawndone" },
    { 0xE8B4, "br_challenges" },
    { 0xE8B5, "br_checkforlaststandfinish" },
    { 0xE8B6, "br_checkforlaststandwipe" },
    { 0xE8B7, "br_circle_closing_music" },
    { 0xE8B8, "br_circle_init_func" },
    { 0xE8B9, "br_circlecenters" },
    { 0xE8BA, "br_circleradiizero" },
    { 0xE8BB, "br_circleshowdelaydanger" },
    { 0xE8BC, "br_circleshowdelaysafe" },
    { 0xE8BD, "br_clearinventory" },
    { 0xE8BE, "br_contractxpearned" },
    { 0xE8BF, "br_danger_circle_closing_music" },
    { 0xE8C0, "br_delaynojip" },
    { 0xE8C1, "br_displayperkinfo" },
    { 0xE8C2, "br_domheight" },
    { 0xE8C3, "br_endgamesplashcallback" },
    { 0xE8C4, "br_ending" },
    { 0xE8C5, "br_ending_debugmode" },
    { 0xE8C6, "br_ending_delay" },
    { 0xE8C7, "br_ending_init" },
    { 0xE8C8, "br_getprimaryandsecondaryweapons" },
    { 0xE8C9, "br_getrandomlootweapon" },
    { 0xE8CA, "br_give_starting_ammo" },
    { 0xE8CB, "br_give_weapon_ammo" },
    { 0xE8CC, "br_give_weapon_clip" },
    { 0xE8CD, "br_giveselectedclass" },
    { 0xE8CE, "br_hasautopickup" },
    { 0xE8CF, "br_highlightlaststandfinishplayers" },
    { 0xE8D0, "br_insert_armor" },
    { 0xE8D1, "br_is_allowed_armor_insert" },
    { 0xE8D2, "br_iseliminated" },
    { 0xE8D3, "br_isininfil" },
    { 0xE8D4, "br_isplayerbeforeinitialinfildeploy" },
    { 0xE8D5, "br_itemrarity" },
    { 0xE8D6, "br_kiosk" },
    { 0xE8D7, "br_laststandfinishplayerisincapacitated" },
    { 0xE8D8, "br_latejoininfilready" },
    { 0xE8D9, "br_latejoinloadscreen" },
    { 0xE8DA, "br_lerp_minimap_zoom" },
    { 0xE8DB, "br_loadout_option" },
    { 0xE8DC, "br_mapboundsfull" },
    { 0xE8DD, "br_movingcirclecount" },
    { 0xE8DE, "br_movingcirclegulagcloseoffset" },
    { 0xE8DF, "br_movingcirclemovedistmax" },
    { 0xE8E0, "br_movingcirclemovedistmin" },
    { 0xE8E1, "br_onvehicledeath" },
    { 0xE8E2, "br_pe_chopper_crate_index" },
    { 0xE8E3, "br_pe_chopper_crates" },
    { 0xE8E4, "br_pe_chopper_damage_time" },
    { 0xE8E5, "br_pe_data" },
    { 0xE8E6, "br_pelletmaxdamage" },
    { 0xE8E7, "br_pickupalreadyhavespecialistbonus" },
    { 0xE8E8, "br_pickupdenyalreadyhaveplatepouch" },
    { 0xE8E9, "br_pickupdenyalreadyhavequest" },
    { 0xE8EA, "br_pickupdenyalreadyhaverevive" },
    { 0xE8EB, "br_pickupdenyarmorfull" },
    { 0xE8EC, "br_pickupdenyjuggernaut" },
    { 0xE8ED, "br_pickupdenyparachuting" },
    { 0xE8EE, "br_pickupdenyplunderpickup" },
    { 0xE8EF, "br_pickupdenyweaponpickupap" },
    { 0xE8F0, "br_pickups_init" },
    { 0xE8F1, "br_plunder_site_use_parts" },
    { 0xE8F2, "br_plunder_site_use_states" },
    { 0xE8F3, "br_practice_match" },
    { 0xE8F4, "br_prematchspawnlocations" },
    { 0xE8F5, "br_remove_player_commands" },
    { 0xE8F6, "br_selectdropbagclass" },
    { 0xE8F7, "br_should_continue_adding_armor" },
    { 0xE8F8, "br_skipending" },
    { 0xE8F9, "br_squadrevivestatus" },
    { 0xE8FA, "br_standard_loadout" },
    { 0xE8FB, "br_tacmap_icon" },
    { 0xE8FC, "br_toggle_armor_allows" },
    { 0xE8FD, "br_updategameevents" },
    { 0xE8FE, "br_use_armor_plate" },
    { 0xE8FF, "br_wait_for_complete_reload" },
    { 0xE900, "br_watch_armor_cancel_notifys" },
    { 0xE901, "br_watch_armor_weapon" },
    { 0xE902, "brallowclasschoicefunc" },
    { 0xE903, "branalytics_bonusxp_debugdata" },
    { 0xE904, "branalytics_circleenter" },
    { 0xE905, "branalytics_circleexit" },
    { 0xE906, "branalytics_delayedshowtablets" },
    { 0xE907, "branalytics_disconnect" },
    { 0xE908, "branalytics_dropbagdeployed" },
    { 0xE909, "branalytics_dropbagdestroyed" },
    { 0xE90A, "branalytics_dropbagused" },
    { 0xE90B, "branalytics_economy_snapshot" },
    { 0xE90C, "branalytics_endgame" },
    { 0xE90D, "branalytics_gulagend" },
    { 0xE90E, "branalytics_gulagstart" },
    { 0xE90F, "branalytics_init" },
    { 0xE910, "branalytics_inittablets" },
    { 0xE911, "branalytics_invalidtablet" },
    { 0xE912, "branalytics_inventory_snapshot" },
    { 0xE913, "branalytics_kiosk_menu_event" },
    { 0xE914, "branalytics_kiosk_purchaseitem" },
    { 0xE915, "branalytics_kiosk_purchaseloadout" },
    { 0xE916, "branalytics_landing" },
    { 0xE917, "branalytics_missionend" },
    { 0xE918, "branalytics_missionstart" },
    { 0xE919, "branalytics_planepath" },
    { 0xE91A, "branalytics_playercount" },
    { 0xE91B, "branalytics_plunder_extraction_failure" },
    { 0xE91C, "branalytics_plunder_extraction_success" },
    { 0xE91D, "branalytics_plunder_placed_into_extraction" },
    { 0xE91E, "branalytics_publiceventended" },
    { 0xE91F, "branalytics_publiceventstarted" },
    { 0xE920, "branalytics_respawn" },
    { 0xE921, "branalytics_secondwind" },
    { 0xE922, "branalytics_selfrevive" },
    { 0xE923, "branalytics_seteventdelayedstate" },
    { 0xE924, "branalytics_spawntablet" },
    { 0xE925, "branalytics_teameliminated" },
    { 0xE926, "branalytics_validation" },
    { 0xE927, "branalytics_vehiclespawned" },
    { 0xE928, "brareloadoutdropbagsdelayed" },
    { 0xE929, "brattractions" },
    { 0xE92A, "brbonusxpallowed" },
    { 0xE92B, "brc130airdropcrateactivatecallback" },
    { 0xE92C, "brc130airdropcratecapturecallback" },
    { 0xE92D, "brc130airdropcratedestroycallback" },
    { 0xE92E, "brc130airdropcratephysicsoncallback" },
    { 0xE92F, "brcirclebattlechatter" },
    { 0xE930, "brcirclecoughnexttime" },
    { 0xE931, "brcircleradialedgespawn" },
    { 0xE932, "brclampdamage" },
    { 0xE933, "brclampdamagealtmodegg" },
    { 0xE934, "brclampstepdamage" },
    { 0xE935, "brclearscoreboardstats" },
    { 0xE936, "brclosealldoors" },
    { 0xE937, "brdisabledamagestattracking" },
    { 0xE938, "brdisablefinalkillcam" },
    { 0xE939, "brdoesloadoutoptiongivecustomweaponsimmediately" },
    { 0xE93A, "brdoesloadoutoptiongivestandardloadoutimmediately" },
    { 0xE93B, "brdoesloadoutoptionrequireclassselection" },
    { 0xE93C, "brdoesloadoutoptionusedropbags" },
    { 0xE93D, "brdownedbyairstriketime" },
    { 0xE93E, "breadcrumb_update_func" },
    { 0xE93F, "break_window_glass" },
    { 0xE940, "breakable_gate_clip" },
    { 0xE941, "breakarmor" },
    { 0xE942, "breaker" },
    { 0xE943, "breakerstate" },
    { 0xE944, "breakgasmaskbr" },
    { 0xE945, "brenableagents" },
    { 0xE946, "brevent1" },
    { 0xE947, "brevent1playerthink" },
    { 0xE948, "brevent1playervalid" },
    { 0xE949, "brevent2" },
    { 0xE94A, "brevent3" },
    { 0xE94B, "brevent4" },
    { 0xE94C, "breventflagclear" },
    { 0xE94D, "breventflagset" },
    { 0xE94E, "breventsinit" },
    { 0xE94F, "brexfilanimname" },
    { 0xE950, "brgametype" },
    { 0xE951, "brgetloadoutammomax" },
    { 0xE952, "brgetloadoutammomultiplier" },
    { 0xE953, "brgetloadoutdropbagsdelayseconds" },
    { 0xE954, "brgetloadoutoptionforname" },
    { 0xE955, "brgetloadoutoptionstandardloadoutindex" },
    { 0xE956, "brgetoperatorteam" },
    { 0xE957, "brgivestartfieldupgrade" },
    { 0xE958, "brgulagdamagefilter" },
    { 0xE959, "brhandleinvulnerability" },
    { 0xE95A, "bridge_one_death_func" },
    { 0xE95B, "bridge_tank_move_sfx" },
    { 0xE95C, "bridge_three_death_func" },
    { 0xE95D, "bridge_two_death_func" },
    { 0xE95E, "brinfilsmokesuffix" },
    { 0xE95F, "brinitloadoutoption" },
    { 0xE960, "briotshieldinitialized" },
    { 0xE961, "briskillstreakallowed" },
    { 0xE962, "brjugg_cleanupents" },
    { 0xE963, "brjugg_dropfunc" },
    { 0xE964, "brjugg_dropondeath" },
    { 0xE965, "brjugg_droponplayerdeath" },
    { 0xE966, "brjugg_initdialog" },
    { 0xE967, "brjugg_initdroplocations" },
    { 0xE968, "brjugg_initexternalfeatures" },
    { 0xE969, "brjugg_initfeatures" },
    { 0xE96A, "brjugg_initpostmain" },
    { 0xE96B, "brjugg_managedeliveries" },
    { 0xE96C, "brjugg_oncrateactivate" },
    { 0xE96D, "brjugg_oncratedestroy" },
    { 0xE96E, "brjugg_oncrateuse" },
    { 0xE96F, "brjugg_onplayerkilled" },
    { 0xE970, "brjugg_ontimelimit" },
    { 0xE971, "brjugg_playerwelcomesplashes" },
    { 0xE972, "brjugg_setconfig" },
    { 0xE973, "brjugg_setjuggwatchers" },
    { 0xE974, "brjugg_startdelivery" },
    { 0xE975, "brjugg_watchgasdamage" },
    { 0xE976, "brjugg_watchheatreduction" },
    { 0xE977, "brjugg_watchoverheat" },
    { 0xE978, "brjugg_watchplayercounttostart" },
    { 0xE979, "brjugg_watchstartnotify" },
    { 0xE97A, "brjugg_watchtimerstart" },
    { 0xE97B, "brjuggernautcrateactivatecallback" },
    { 0xE97C, "brjuggernautcratecapturecallback" },
    { 0xE97D, "brjuggernautcratedestroycallback" },
    { 0xE97E, "brjuggernautcratephysicsoncallback" },
    { 0xE97F, "brjuggsettings" },
    { 0xE980, "brkickedfromplane" },
    { 0xE981, "brkillchainchance" },
    { 0xE982, "brkillstreakbeginusefunc" },
    { 0xE983, "brking_addtoc130infil" },
    { 0xE984, "brking_cleanupents" },
    { 0xE985, "brking_createc130pathstruct" },
    { 0xE986, "brking_getcenterofcircle" },
    { 0xE987, "brking_getcirclepercentmoved" },
    { 0xE988, "brking_getrandompointinmovingcircle" },
    { 0xE989, "brking_getspawnpoint" },
    { 0xE98A, "brking_givepoints" },
    { 0xE98B, "brking_initdialog" },
    { 0xE98C, "brking_initexternalfeatures" },
    { 0xE98D, "brking_initfeatures" },
    { 0xE98E, "brking_initpostmain" },
    { 0xE98F, "brking_ispointinmovingcircle" },
    { 0xE990, "brking_kickplayersatcircleedge" },
    { 0xE991, "brking_managecircles" },
    { 0xE992, "brking_managecratedrops" },
    { 0xE993, "brking_movenextcirclecenter" },
    { 0xE994, "brking_oncrateuse" },
    { 0xE995, "brking_onplayerconnect" },
    { 0xE996, "brking_onplayerkilled" },
    { 0xE997, "brking_ontimelimit" },
    { 0xE998, "brking_playerwelcomesplashes" },
    { 0xE999, "brking_rankupdate" },
    { 0xE99A, "brking_updateteamscore" },
    { 0xE99B, "brking_watchcircletimers" },
    { 0xE99C, "brleaderdialogplayer" },
    { 0xE99D, "brleaderdialogteam" },
    { 0xE99E, "brleaderdialogteamexcludeplayer" },
    { 0xE99F, "brloadoutcratedestroycallback" },
    { 0xE9A0, "brloadoutcratefirstactivation" },
    { 0xE9A1, "brloadoutcratepostcapture" },
    { 0xE9A2, "brloadoutupdateammo" },
    { 0xE9A3, "brloot_ammo" },
    { 0xE9A4, "brlootchoppercrateactivatecallback" },
    { 0xE9A5, "brlootchoppercratecapturecallback" },
    { 0xE9A6, "brlootchoppercratedestroycallback" },
    { 0xE9A7, "brmayconsiderplayerdead" },
    { 0xE9A8, "brmini_addtoc130infil" },
    { 0xE9A9, "brmini_cleanupents" },
    { 0xE9AA, "brmini_createc130pathstruct" },
    { 0xE9AB, "brmini_initdialog" },
    { 0xE9AC, "brmini_initexternalfeatures" },
    { 0xE9AD, "brmini_initfeatures" },
    { 0xE9AE, "brmini_initpostmain" },
    { 0xE9AF, "brmini_kickplayersatcircleedge" },
    { 0xE9B0, "brmini_ontimelimit" },
    { 0xE9B1, "brmini_playerwelcomesplashes" },
    { 0xE9B2, "brmissionscompleted" },
    { 0xE9B3, "brmissiontypescompleted" },
    { 0xE9B4, "brmodeaddtoteamlives" },
    { 0xE9B5, "brmoderemovefromteamlives" },
    { 0xE9B6, "brmodevalidatekillstreakslot" },
    { 0xE9B7, "brmodevariantrewardcullfunc" },
    { 0xE9B8, "brmodifyvehicledamage" },
    { 0xE9B9, "brneverlanded" },
    { 0xE9BA, "broadcast_carry_items" },
    { 0xE9BB, "broadcast_currency" },
    { 0xE9BC, "broadcast_health" },
    { 0xE9BD, "bronattackerdamagenottracked" },
    { 0xE9BE, "bronloadoutcratedestroyed" },
    { 0xE9BF, "brpickupscriptableid" },
    { 0xE9C0, "brplacementchallengeallowed" },
    { 0xE9C1, "brplayerhudoutlineforteammates" },
    { 0xE9C2, "brplayerhudoutlineforteammatessafe" },
    { 0xE9C3, "brplayerhudoutlineforteammatesupdate" },
    { 0xE9C4, "brplayerhudoutlineupdatefromnotify" },
    { 0xE9C5, "brplayerkilledspawn" },
    { 0xE9C6, "brpreplayerdamaged" },
    { 0xE9C7, "brprewaitandspawnclient" },
    { 0xE9C8, "brprewaitandspawnclientcleanup" },
    { 0xE9C9, "brradialspawnorigin" },
    { 0xE9CA, "brrebirth_brmayconsiderplayerdead" },
    { 0xE9CB, "brrebirth_cleanupents" },
    { 0xE9CC, "brrebirth_initdialog" },
    { 0xE9CD, "brrebirth_initexternalfeatures" },
    { 0xE9CE, "brrebirth_initfeatures" },
    { 0xE9CF, "brrebirth_initpostmain" },
    { 0xE9D0, "brrebirth_ontimelimit" },
    { 0xE9D1, "brrebirth_playernakeddroploadout" },
    { 0xE9D2, "brrebirth_respawn" },
    { 0xE9D3, "brrebirth_triggerrespawnoverlay" },
    { 0xE9D4, "brrebirth_tryrespawn" },
    { 0xE9D5, "brregendelayspeed" },
    { 0xE9D6, "brregenhealthadd" },
    { 0xE9D7, "brsingleuse" },
    { 0xE9D8, "brskipplayerkillcams" },
    { 0xE9D9, "brspawnplayersending" },
    { 0xE9DA, "brtdm_config" },
    { 0xE9DB, "brtruck_cleanupents" },
    { 0xE9DC, "brtruck_initdialog" },
    { 0xE9DD, "brtruck_initexternalfeatures" },
    { 0xE9DE, "brtruck_initfeatures" },
    { 0xE9DF, "brtruck_initpostmain" },
    { 0xE9E0, "brtruck_ontimelimit" },
    { 0xE9E1, "brtruck_playerwelcomesplashes" },
    { 0xE9E2, "brush" },
    { 0xE9E3, "brvalidatekillcam" },
    { 0xE9E4, "brvictiminlaststand" },
    { 0xE9E5, "brwatchforminplayersmatchstart" },
    { 0xE9E6, "bshouldreturnvalue" },
    { 0xE9E7, "buddyspawnplayer" },
    { 0xE9E8, "bufferedammoboxdata" },
    { 0xE9E9, "build_our_weapon" },
    { 0xE9EA, "build_vehicle_drop_off_list" },
    { 0xE9EB, "build_wheelson_duration" },
    { 0xE9EC, "buildblueprintpickupweapon" },
    { 0xE9ED, "building_magic_grenade_damage" },
    { 0xE9EE, "building_magic_grenade_kill_watch" },
    { 0xE9EF, "building_magic_grenade_watch" },
    { 0xE9F0, "building_magic_grenades" },
    { 0xE9F1, "building_push_start" },
    { 0xE9F2, "building_roof_chopper_reenforce" },
    { 0xE9F3, "building_roof_chopper_reenforce_watch" },
    { 0xE9F4, "building_roof_jugg_behavior" },
    { 0xE9F5, "building_roof_jugg_protect_roof_then_chase" },
    { 0xE9F6, "buildloadoutindices" },
    { 0xE9F7, "buildrespawnlist" },
    { 0xE9F8, "buildspecialdaypickupweapon" },
    { 0xE9F9, "buildweapon_blueprint" },
    { 0xE9FA, "buildweapon_blueprintwithcustomattachments" },
    { 0xE9FB, "buildweaponfromrandomcategory" },
    { 0xE9FC, "bullet" },
    { 0xE9FD, "bunker11_mistsdoors" },
    { 0xE9FE, "bunker11_mistswindow" },
    { 0xE9FF, "bunker11puzzleactive" },
    { 0xEA00, "bunker11vo" },
    { 0xEA01, "bunker_initinteraction" },
    { 0xEA02, "bunker_loot_vaults" },
    { 0xEA03, "bunker_numberstation" },
    { 0xEA04, "bunker_spawning" },
    { 0xEA05, "bunker_waitforuse" },
    { 0xEA06, "bunkeralt_damagedeathdisconnectwatch" },
    { 0xEA07, "bunkeralt_playeridlewatch" },
    { 0xEA08, "bunkeralt_playerinteractwithkeypadloop" },
    { 0xEA09, "bunkercounteruav" },
    { 0xEA0A, "bunkerinteriorkeypads" },
    { 0xEA0B, "bunkermusicstarted" },
    { 0xEA0C, "bunkernum" },
    { 0xEA0D, "bunkeropened" },
    { 0xEA0E, "bunkervaults" },
    { 0xEA0F, "burndowntime" },
    { 0xEA10, "burnfxstates" },
    { 0xEA11, "burningdown" },
    { 0xEA12, "burningpartlogic" },
    { 0xEA13, "burningstate" },
    { 0xEA14, "burst_fire_turret" },
    { 0xEA15, "busbpulledout" },
    { 0xEA16, "bush_concealment_monitor" },
    { 0xEA17, "bush_onplayerconnect" },
    { 0xEA18, "bush_trig" },
    { 0xEA19, "bush_trig_debug" },
    { 0xEA1A, "bush_zones" },
    { 0xEA1B, "button" },
    { 0xEA1C, "button_sequence" },
    { 0xEA1D, "buttonmashcount" },
    { 0xEA1E, "buttonmodel" },
    { 0xEA1F, "buttonnotify" },
    { 0xEA20, "buy_menu_closed" },
    { 0xEA21, "buy_point_init" },
    { 0xEA22, "buy_point_loop" },
    { 0xEA23, "buy_point_think" },
    { 0xEA24, "buy_points" },
    { 0xEA25, "buy_points_objectives_handler" },
    { 0xEA26, "buystationsusepaddingdistribution" },
    { 0xEA27, "buystationtrig" },
    { 0xEA28, "bwasjuggernaut" },
    { 0xEA29, "c130_crate" },
    { 0xEA2A, "c130_door_badplace_id" },
    { 0xEA2B, "c130_drop" },
    { 0xEA2C, "c130_lights" },
    { 0xEA2D, "c130airdrop_createpath" },
    { 0xEA2E, "c130airdrop_createpathstruct" },
    { 0xEA2F, "c130airdrop_deleteatlifetime" },
    { 0xEA30, "c130airdrop_dropcrates" },
    { 0xEA31, "c130airdrop_findvaliddroplocation" },
    { 0xEA32, "c130airdrop_getteamaveragepos" },
    { 0xEA33, "c130airdrop_getvalidteaminlastplace" },
    { 0xEA34, "c130airdrop_heightoverride" },
    { 0xEA35, "c130airdrop_isnearotherdrop" },
    { 0xEA36, "c130airdrop_managedrop" },
    { 0xEA37, "c130airdrop_oncrateuse" },
    { 0xEA38, "c130airdrop_spawn" },
    { 0xEA39, "c130airdrop_startdelivery" },
    { 0xEA3A, "c130deliveriesinprogress" },
    { 0xEA3B, "c130deliverydirection" },
    { 0xEA3C, "c130successfulairdrops" },
    { 0xEA3D, "c4_charge_detonate_think" },
    { 0xEA3E, "c4_crate_player_at_max_ammo" },
    { 0xEA3F, "c4_crate_spawn" },
    { 0xEA40, "c4_crate_update_hint_logic_alt" },
    { 0xEA41, "c4_crate_use" },
    { 0xEA42, "c4_obj_and_progress" },
    { 0xEA43, "c4_obj_and_progress_clear" },
    { 0xEA44, "c4_pick_up_listener" },
    { 0xEA45, "c4_placed_bc" },
    { 0xEA46, "c4_placing_bc" },
    { 0xEA47, "c4vehiclecooperator" },
    { 0xEA48, "c4vehiclemultkill" },
    { 0xEA49, "cac_getaccessorylogic" },
    { 0xEA4A, "cac_getweaponattachmentid" },
    { 0xEA4B, "cache1_defender_after_spawn" },
    { 0xEA4C, "cachedomnars" },
    { 0xEA4D, "cacheentity" },
    { 0xEA4E, "caclulate_track_distance" },
    { 0xEA4F, "calchelicoptertrailpoint" },
    { 0xEA50, "calculate_path_struct" },
    { 0xEA51, "calculate_teleport_data_for_player" },
    { 0xEA52, "calculate_zone_node_extents" },
    { 0xEA53, "calculateandsettotalfuel" },
    { 0xEA54, "calculateandvalidatefuelstability" },
    { 0xEA55, "calculateaveragevelocities" },
    { 0xEA56, "calculatebrbonusxp" },
    { 0xEA57, "calculateclientmatchdataextrainfopayload" },
    { 0xEA58, "calculateeventstarttime" },
    { 0xEA59, "calculatehelispawndata" },
    { 0xEA5A, "calculatehelitimetoarrive" },
    { 0xEA5B, "calculatehelitimetoflysec" },
    { 0xEA5C, "calculatenumteamswithplayers" },
    { 0xEA5D, "calculateobjectivesheld" },
    { 0xEA5E, "calculatepurchasexp" },
    { 0xEA5F, "calculatespawndisttodefenderflagstart" },
    { 0xEA60, "calculateweaponmatchbonus" },
    { 0xEA61, "calculatewinningteam" },
    { 0xEA62, "call_exfil" },
    { 0xEA63, "call_for_reinforcements" },
    { 0xEA64, "call_func_on_death" },
    { 0xEA65, "call_in_carepackage" },
    { 0xEA66, "callback" },
    { 0xEA67, "callback_create" },
    { 0xEA68, "callback_frontendplayeractive" },
    { 0xEA69, "callback_playeractive" },
    { 0xEA6A, "callback_subscribe" },
    { 0xEA6B, "callback_trigger" },
    { 0xEA6C, "callback_unsubscribe" },
    { 0xEA6D, "callbackplayeractive" },
    { 0xEA6E, "calldropbag" },
    { 0xEA6F, "called50percentprogress" },
    { 0xEA70, "called75percentprogress" },
    { 0xEA71, "called90percentprogress" },
    { 0xEA72, "calloutmarkerping_canplayerping" },
    { 0xEA73, "calloutmarkerping_cp_getcpvehiclevocallout" },
    { 0xEA74, "calloutmarkerping_cp_setupcptimeouts" },
    { 0xEA75, "calloutmarkerping_enemytodangerdecaycreate" },
    { 0xEA76, "calloutmarkerping_gettimeoutforpoolid" },
    { 0xEA77, "calloutmarkerping_initcommon" },
    { 0xEA78, "calloutmarkerping_islethalequipment" },
    { 0xEA79, "calloutmarkerping_islootquesttablet" },
    { 0xEA7A, "calloutmarkerping_ismunitionsbox" },
    { 0xEA7B, "calloutmarkerping_navigationcancelproximity" },
    { 0xEA7C, "calloutmarkerping_playteamsoundfx" },
    { 0xEA7D, "calloutmarkerping_removeallcalloutsforallplayers" },
    { 0xEA7E, "calloutmarkerping_removeallcalloutsforplayer" },
    { 0xEA7F, "calloutmarkerping_removevehiclecalloutonspecialconditions" },
    { 0xEA80, "calloutmarkerping_requestinventoryslotindex" },
    { 0xEA81, "calloutmarkerping_sendmayday" },
    { 0xEA82, "calloutmarkerping_squadleaderbeaconcreate" },
    { 0xEA83, "calloutmarkerping_squadleaderbeaconkillforplayer" },
    { 0xEA84, "calloutmarkerping_squadleaderbeaconplayerfirstlanded" },
    { 0xEA85, "calloutmarkerping_squadleaderbeaconshouldcreate" },
    { 0xEA86, "calloutmarkerping_watchentitydeathorenemydisconnect" },
    { 0xEA87, "calloutmarkerping_watchplayerdeathordisconnect" },
    { 0xEA88, "calloutmarkerping_watchwhenmissioncompletes" },
    { 0xEA89, "calloutmarkerping_watchwhenobjectivedeleted" },
    { 0xEA8A, "calloutmarkerping_watchwhenobjectivestartsprogress" },
    { 0xEA8B, "calloutmarkerpingvo_calculatesounddebouncelength" },
    { 0xEA8C, "calloutmarkerpingvo_canplaywithspamavoidance" },
    { 0xEA8D, "calloutmarkerpingvo_createcalloutbattlechatter" },
    { 0xEA8E, "calloutmarkerpingvo_debouncegarbagecollector" },
    { 0xEA8F, "calloutmarkerpingvo_doesoperatorsupportalias" },
    { 0xEA90, "calloutmarkerpingvo_getaffirmaliasstringloot" },
    { 0xEA91, "calloutmarkerpingvo_getcalloutaliasstringentity" },
    { 0xEA92, "calloutmarkerpingvo_getcalloutaliasstringloot" },
    { 0xEA93, "calloutmarkerpingvo_getcalloutaliasstringvehicle" },
    { 0xEA94, "calloutmarkerpingvo_getcalloutaliasstringworld" },
    { 0xEA95, "calloutmarkerpingvo_getfulloperatorvoaliasfromsimplealias2d" },
    { 0xEA96, "calloutmarkerpingvo_getfulloperatorvoaliasfromsimplealias3d" },
    { 0xEA97, "calloutmarkerpingvo_getmaxsoundaliaslength" },
    { 0xEA98, "calloutmarkerpingvo_handleraddnewelement" },
    { 0xEA99, "calloutmarkerpingvo_handlerdoescontainpoolelement" },
    { 0xEA9A, "calloutmarkerpingvo_play" },
    { 0xEA9B, "calloutmarkerpingvo_playpredictivepingacknowledged" },
    { 0xEA9C, "calloutmarkerpingvo_playpredictivepingacknowledgedcancel" },
    { 0xEA9D, "calloutmarkerpingvo_playpredictivepingadded" },
    { 0xEA9E, "calloutmarkerpingvo_playpredictivepingcleared" },
    { 0xEA9F, "calloutmarkerpingvo_playpredictivepinginventoryrequest" },
    { 0xEAA0, "calloutmarkerpingvohandlerpool" },
    { 0xEAA1, "callouts" },
    { 0xEAA2, "callprecisionairstrikeonlocation" },
    { 0xEAA3, "cam" },
    { 0xEAA4, "camera_character_gamebattles" },
    { 0xEAA5, "camera_character_preview_select" },
    { 0xEAA6, "camera_character_preview_select_detail" },
    { 0xEAA7, "camera_loadout_showcase_armory" },
    { 0xEAA8, "camera_loadout_showcase_preview_barrel_alt2" },
    { 0xEAA9, "camera_loadout_showcase_preview_charm_alt4" },
    { 0xEAAA, "camera_loadout_showcase_preview_large_sticker" },
    { 0xEAAB, "camera_loadout_showcase_preview_large_sticker_alt1" },
    { 0xEAAC, "camera_loadout_showcase_preview_large_sticker_alt2" },
    { 0xEAAD, "camera_loadout_showcase_preview_large_sticker_alt3" },
    { 0xEAAE, "camera_loadout_showcase_preview_large_stock_alt1" },
    { 0xEAAF, "camera_loadout_showcase_preview_small_sticker" },
    { 0xEAB0, "camera_loadout_showcase_preview_sticker" },
    { 0xEAB1, "camera_loadout_showcase_preview_sticker_alt1" },
    { 0xEAB2, "camera_loadout_showcase_preview_sticker_alt2" },
    { 0xEAB3, "camera_loadout_showcase_preview_sticker_alt3" },
    { 0xEAB4, "camera_loadout_showcase_preview_sticker_alt4" },
    { 0xEAB5, "cameraentlinktag" },
    { 0xEAB6, "cameraentmoving" },
    { 0xEAB7, "camoname" },
    { 0xEAB8, "camoset" },
    { 0xEAB9, "camper_damage_thread" },
    { 0xEABA, "camsetorbit" },
    { 0xEABB, "can_activate_battle_station" },
    { 0xEABC, "can_be_interrupted" },
    { 0xEABD, "can_be_seen_by_any_player" },
    { 0xEABE, "can_be_shot_again" },
    { 0xEABF, "can_combat_action_be_interrupted" },
    { 0xEAC0, "can_killstreak_be_detected" },
    { 0xEAC1, "can_man_turret" },
    { 0xEAC2, "can_node_be_added" },
    { 0xEAC3, "can_path_to_target" },
    { 0xEAC4, "can_play_ending" },
    { 0xEAC5, "can_spawn_extras" },
    { 0xEAC6, "can_spawn_heli_group" },
    { 0xEAC7, "can_station_be_selected" },
    { 0xEAC8, "can_support_mindia8_min_spawn" },
    { 0xEAC9, "can_trex_apply_to_player" },
    { 0xEACA, "can_use_super_func" },
    { 0xEACB, "cancelallmissions" },
    { 0xEACC, "cancelchecklinktotrain" },
    { 0xEACD, "cancelgivequest" },
    { 0xEACE, "cancelled" },
    { 0xEACF, "cancelupcomingpublicevents" },
    { 0xEAD0, "candles" },
    { 0xEAD1, "cankeepusingbomb" },
    { 0xEAD2, "canlock" },
    { 0xEAD3, "canlogchangeweapon" },
    { 0xEAD4, "canopendoor" },
    { 0xEAD5, "canparachutebecut" },
    { 0xEAD6, "canplaycircleclosedialog" },
    { 0xEAD7, "canplaycircleopendialog" },
    { 0xEAD8, "canplaygasmaskgesturebr" },
    { 0xEAD9, "canplaykillstreakdialog" },
    { 0xEADA, "canprogressingunrank" },
    { 0xEADB, "canqueuearmorbydefault" },
    { 0xEADC, "canrecordsegmentstats" },
    { 0xEADD, "canseecantshoottime" },
    { 0xEADE, "canseedangercircleui" },
    { 0xEADF, "canseesafecircleui" },
    { 0xEAE0, "cansnapcamera" },
    { 0xEAE1, "cansolospawn" },
    { 0xEAE2, "canspawnitemname" },
    { 0xEAE3, "canspawnontacinsert" },
    { 0xEAE4, "canstartusingbomb" },
    { 0xEAE5, "cansticktoent" },
    { 0xEAE6, "cantakedamage" },
    { 0xEAE7, "capacity" },
    { 0xEAE8, "capsule_contents" },
    { 0xEAE9, "capsulepass" },
    { 0xEAEA, "capturetrigger" },
    { 0xEAEB, "car_collision" },
    { 0xEAEC, "car_think" },
    { 0xEAED, "card_angles" },
    { 0xEAEE, "card_origin" },
    { 0xEAEF, "cardstruct" },
    { 0xEAF0, "care_packages_unusable_think" },
    { 0xEAF1, "care_pkg" },
    { 0xEAF2, "carepackage_drop_from_heli" },
    { 0xEAF3, "carepackage_drops" },
    { 0xEAF4, "carepackage_get_dropped_entities" },
    { 0xEAF5, "carepackage_glowsticks" },
    { 0xEAF6, "carepackage_id" },
    { 0xEAF7, "carepackage_index" },
    { 0xEAF8, "carepackage_set_collision_model" },
    { 0xEAF9, "carepackage_set_useable" },
    { 0xEAFA, "carepackage_set_visible_model" },
    { 0xEAFB, "carepackage_spawn" },
    { 0xEAFC, "carepackage_unlink_from_heli" },
    { 0xEAFD, "carepackage_waittill_settle" },
    { 0xEAFE, "cargo_truck" },
    { 0xEAFF, "cargo_truck_horn" },
    { 0xEB00, "cargo_truck_initcollision" },
    { 0xEB01, "cargo_truck_initdamage" },
    { 0xEB02, "cargo_truck_initomnvars" },
    { 0xEB03, "cargo_truck_mg_addgunnerdamagemod" },
    { 0xEB04, "cargo_truck_mg_cp_create" },
    { 0xEB05, "cargo_truck_mg_cp_createfromstructs" },
    { 0xEB06, "cargo_truck_mg_cp_init" },
    { 0xEB07, "cargo_truck_mg_cp_initlate" },
    { 0xEB08, "cargo_truck_mg_cp_spawncallback" },
    { 0xEB09, "cargo_truck_mg_create" },
    { 0xEB0A, "cargo_truck_mg_creategunnerturret" },
    { 0xEB0B, "cargo_truck_mg_deathcallback" },
    { 0xEB0C, "cargo_truck_mg_deletenextframe" },
    { 0xEB0D, "cargo_truck_mg_enterend" },
    { 0xEB0E, "cargo_truck_mg_enterendinternal" },
    { 0xEB0F, "cargo_truck_mg_enterstart" },
    { 0xEB10, "cargo_truck_mg_exitend" },
    { 0xEB11, "cargo_truck_mg_exitendinternal" },
    { 0xEB12, "cargo_truck_mg_explode" },
    { 0xEB13, "cargo_truck_mg_getspawnstructscallback" },
    { 0xEB14, "cargo_truck_mg_gunnerdamagemodignorefunc" },
    { 0xEB15, "cargo_truck_mg_init" },
    { 0xEB16, "cargo_truck_mg_initcollision" },
    { 0xEB17, "cargo_truck_mg_initdamage" },
    { 0xEB18, "cargo_truck_mg_initfx" },
    { 0xEB19, "cargo_truck_mg_initinteract" },
    { 0xEB1A, "cargo_truck_mg_initlate" },
    { 0xEB1B, "cargo_truck_mg_initoccupancy" },
    { 0xEB1C, "cargo_truck_mg_initomnvars" },
    { 0xEB1D, "cargo_truck_mg_initspawning" },
    { 0xEB1E, "cargo_truck_mg_mp_init" },
    { 0xEB1F, "cargo_truck_mg_mp_ondeathrespawncallback" },
    { 0xEB20, "cargo_truck_mg_mp_spawncallback" },
    { 0xEB21, "cargo_truck_mg_reenter" },
    { 0xEB22, "cargo_truck_mg_removegunnerdamagemod" },
    { 0xEB23, "cargobaywatch" },
    { 0xEB24, "carnage_enemydummycleanup" },
    { 0xEB25, "carpunchcount" },
    { 0xEB26, "carpunchers" },
    { 0xEB27, "carriable_can_pickup" },
    { 0xEB28, "carriable_damage_wait" },
    { 0xEB29, "carriable_detonate_neurotoxin" },
    { 0xEB2A, "carriable_detonate_propane" },
    { 0xEB2B, "carriable_error_messsage_watch" },
    { 0xEB2C, "carriable_explode" },
    { 0xEB2D, "carriable_fuse_light_watch" },
    { 0xEB2E, "carriable_fuse_ui" },
    { 0xEB2F, "carriable_inactive_delete_wait" },
    { 0xEB30, "carriable_init" },
    { 0xEB31, "carriable_lightfuse" },
    { 0xEB32, "carriable_physics_launch" },
    { 0xEB33, "carriable_physics_launch_drop" },
    { 0xEB34, "carriable_pickup" },
    { 0xEB35, "carriable_pickup_wait" },
    { 0xEB36, "carriable_player_death_watch" },
    { 0xEB37, "carriable_player_state_drop_watch" },
    { 0xEB38, "carriable_ready" },
    { 0xEB39, "carriable_respawn" },
    { 0xEB3A, "carriable_set_dropped" },
    { 0xEB3B, "carriable_throw_watch" },
    { 0xEB3C, "carriable_watch_for_physics_collison" },
    { 0xEB3D, "carriable_weapon_change_watch" },
    { 0xEB3E, "carriablemagicgrenades" },
    { 0xEB3F, "carriabletype" },
    { 0xEB40, "carriabletypes" },
    { 0xEB41, "carriedpunchcard" },
    { 0xEB42, "carrier_cleanup" },
    { 0xEB43, "carrier_remove_carriable_weapon" },
    { 0xEB44, "carry_ref" },
    { 0xEB45, "carryingplayer" },
    { 0xEB46, "carryitem2omnvar" },
    { 0xEB47, "carryiteminfo" },
    { 0xEB48, "carryitemomnvar" },
    { 0xEB49, "carryobjects_onjuggernaut" },
    { 0xEB4A, "cash_hud_bink" },
    { 0xEB4B, "cashleader_trackdeath" },
    { 0xEB4C, "cashleaderbag_attach" },
    { 0xEB4D, "cashleaderbag_detach" },
    { 0xEB4E, "cashmetrics" },
    { 0xEB4F, "cashtorefund" },
    { 0xEB50, "cashtypes" },
    { 0xEB51, "castrewardvalue" },
    { 0xEB52, "categorytogroup" },
    { 0xEB53, "cause" },
    { 0xEB54, "cave_barrels" },
    { 0xEB55, "cave_combat" },
    { 0xEB56, "cave_initial_enemy_goto_struct_on_spawn_and_wait_till_seen" },
    { 0xEB57, "cbreakers" },
    { 0xEB58, "cdlgametuning" },
    { 0xEB59, "celebration_end" },
    { 0xEB5A, "cellspawns" },
    { 0xEB5B, "center_node" },
    { 0xEB5C, "center_struct" },
    { 0xEB5D, "centers" },
    { 0xEB5E, "challengeandeventglobals" },
    { 0xEB5F, "challengeevaluator" },
    { 0xEB60, "challenges_init" },
    { 0xEB61, "challengesdisabled" },
    { 0xEB62, "challengestarttime" },
    { 0xEB63, "challengetimersenabled" },
    { 0xEB64, "challengetimersenabledforplayer" },
    { 0xEB65, "challengetrackerforjuggkills" },
    { 0xEB66, "change_apc_label" },
    { 0xEB67, "change_fronttruck_label" },
    { 0xEB68, "change_goal_radius_weapons_free" },
    { 0xEB69, "change_goal_radius_weapons_free_internal" },
    { 0xEB6A, "change_keypad_display_digit" },
    { 0xEB6B, "change_stealth_state_to_combat_warpper" },
    { 0xEB6C, "change_yaw_angle" },
    { 0xEB6D, "changecirclestateatlowtime" },
    { 0xEB6E, "changepropkey" },
    { 0xEB6F, "changesleft" },
    { 0xEB70, "changetimertoovertimetimer" },
    { 0xEB71, "changing_loadout" },
    { 0xEB72, "chase" },
    { 0xEB73, "chase_hvt_vo" },
    { 0xEB74, "chassis" },
    { 0xEB75, "check_bonus_leads_xp" },
    { 0xEB76, "check_cannot_spawn_tank" },
    { 0xEB77, "check_carrier_status" },
    { 0xEB78, "check_crate_unreachable" },
    { 0xEB79, "check_digit_models_to_create" },
    { 0xEB7A, "check_dropped_locations_and_offset" },
    { 0xEB7B, "check_for_at_set_final_wave" },
    { 0xEB7C, "check_for_damage_scalar_change" },
    { 0xEB7D, "check_for_early_impact" },
    { 0xEB7E, "check_for_execution_allows" },
    { 0xEB7F, "check_for_moody_traversal" },
    { 0xEB80, "check_for_nearby_packages" },
    { 0xEB81, "check_for_solo" },
    { 0xEB82, "check_for_trexremoval" },
    { 0xEB83, "check_for_vehicle_in_front" },
    { 0xEB84, "check_for_vehicle_trace" },
    { 0xEB85, "check_if_frozen" },
    { 0xEB86, "check_if_player_is_downed" },
    { 0xEB87, "check_if_players_are_not_in_plane" },
    { 0xEB88, "check_lbravo_hover_retreat" },
    { 0xEB89, "check_maze_ai_state" },
    { 0xEB8A, "check_missile_fire_vo" },
    { 0xEB8B, "check_missiles_reloaded_vo" },
    { 0xEB8C, "check_player_used_tacmap" },
    { 0xEB8D, "check_trigger_spawnflags" },
    { 0xEB8E, "checkammopickup" },
    { 0xEB8F, "checkamorused" },
    { 0xEB90, "checkandreportchallengetimer" },
    { 0xEB91, "checkarmorpickup" },
    { 0xEB92, "checkbluemassacre" },
    { 0xEB93, "checkcarpuncherprogress" },
    { 0xEB94, "checkcarpuncherprogressgeneric" },
    { 0xEB95, "checkcarryobjectpickupcheck" },
    { 0xEB96, "checkcodeentered" },
    { 0xEB97, "checkdamagesourcerelicswat" },
    { 0xEB98, "checked_missiles" },
    { 0xEB99, "checkfinalkillachievements" },
    { 0xEB9A, "checkforactiveobjicon" },
    { 0xEB9B, "checkforammoquickdrop" },
    { 0xEB9C, "checkforarenaloadoutoverride" },
    { 0xEB9D, "checkforcorrectinstance" },
    { 0xEB9E, "checkforlaststandfinish" },
    { 0xEB9F, "checkforlaststandwipe" },
    { 0xEBA0, "checkformatchend" },
    { 0xEBA1, "checkforovertime" },
    { 0xEBA2, "checkforsubgametypeoverrides" },
    { 0xEBA3, "checkgraymassacre" },
    { 0xEBA4, "checkgreenmassacre" },
    { 0xEBA5, "checkifplayerrewardsareenabled" },
    { 0xEBA6, "checkifteamrewardsareenabled" },
    { 0xEBA7, "checkifvalidpropspectate" },
    { 0xEBA8, "checkkillrespawn" },
    { 0xEBA9, "checklethalequipmentachievement" },
    { 0xEBAA, "checklinktotrain" },
    { 0xEBAB, "checklinktotraininternal" },
    { 0xEBAC, "checkmapflagangles" },
    { 0xEBAD, "checkpairs" },
    { 0xEBAE, "checkpoint_add_carepackage" },
    { 0xEBAF, "checkpoint_add_carepackage_munitions" },
    { 0xEBB0, "checkpoint_add_spawnpoint" },
    { 0xEBB1, "checkpoint_carepackage_munitions_role_init" },
    { 0xEBB2, "checkpoint_carepackage_munitions_role_think" },
    { 0xEBB3, "checkpoint_carepackage_munitions_think" },
    { 0xEBB4, "checkpoint_carepackage_think" },
    { 0xEBB5, "checkpoint_carepkg_spawns" },
    { 0xEBB6, "checkpoint_carepkg_spawns_func" },
    { 0xEBB7, "checkpoint_create_carepackage" },
    { 0xEBB8, "checkpoint_create_carepackage_munitions" },
    { 0xEBB9, "checkpoint_edit_loadout" },
    { 0xEBBA, "checkpoint_edit_munitions" },
    { 0xEBBB, "checkpoint_edit_munitions_icon_init" },
    { 0xEBBC, "checkpoint_edit_munitions_limit_init" },
    { 0xEBBD, "checkpoint_edit_munitions_limiter" },
    { 0xEBBE, "checkpoint_edit_role" },
    { 0xEBBF, "checkpoint_edit_role_limiter" },
    { 0xEBC0, "checkpoint_fx" },
    { 0xEBC1, "checkpoint_fx_play" },
    { 0xEBC2, "checkpoint_fx_set" },
    { 0xEBC3, "checkpoint_get_item" },
    { 0xEBC4, "checkpoint_name" },
    { 0xEBC5, "checkpoint_next_fx" },
    { 0xEBC6, "checkpoint_next_fx_play" },
    { 0xEBC7, "checkpoint_next_fx_set" },
    { 0xEBC8, "checkpoint_objective" },
    { 0xEBC9, "checkpoint_objective_id" },
    { 0xEBCA, "checkpoint_overwatch" },
    { 0xEBCB, "checkpoint_player_spawns" },
    { 0xEBCC, "checkpoint_player_spawns_func" },
    { 0xEBCD, "checkpoint_register" },
    { 0xEBCE, "checkpoint_release_spawnpoint" },
    { 0xEBCF, "checkpoint_set" },
    { 0xEBD0, "checkpoint_trigger" },
    { 0xEBD1, "checkpoints_count" },
    { 0xEBD2, "checkpoints_init" },
    { 0xEBD3, "checkpointstruct" },
    { 0xEBD4, "checkredmassacre" },
    { 0xEBD5, "checkreload" },
    { 0xEBD6, "checkrequiredteamstreamcount" },
    { 0xEBD7, "checkshouldplaymusic" },
    { 0xEBD8, "checksolospawnselections" },
    { 0xEBD9, "checkstayingbehindcover" },
    { 0xEBDA, "checkunscoredspawnpoint" },
    { 0xEBDB, "checkuseconditioninthink" },
    { 0xEBDC, "checkweaponswitch" },
    { 0xEBDD, "checkyellowmassacre" },
    { 0xEBDE, "cheese" },
    { 0xEBDF, "cheeselocs" },
    { 0xEBE0, "cheeseprompt" },
    { 0xEBE1, "cheesewedge" },
    { 0xEBE2, "cheesewedgeprompt" },
    { 0xEBE3, "chestorigin" },
    { 0xEBE4, "choose_and_drop_tank_near_hostage" },
    { 0xEBE5, "choose_and_play_vo_from_array" },
    { 0xEBE6, "choose_spawners_from_matching_volumes" },
    { 0xEBE7, "choose_two_spots" },
    { 0xEBE8, "chooseanim_arrival_forcode" },
    { 0xEBE9, "chooseanim_vehicleturret" },
    { 0xEBEA, "chooseanim_vehicleturretdeath" },
    { 0xEBEB, "choosebestpropforkillcam" },
    { 0xEBEC, "choosecrouchorstandtac" },
    { 0xEBED, "choosedropbagmodel" },
    { 0xEBEE, "choosefinalkillcam" },
    { 0xEBEF, "choosegulagloadouttable" },
    { 0xEBF0, "choosejuggernautcratemodel" },
    { 0xEBF1, "choosepubliceventtype" },
    { 0xEBF2, "chopper_boss" },
    { 0xEBF3, "chopper_boss_combat" },
    { 0xEBF4, "chopper_boss_combat_actions" },
    { 0xEBF5, "chopper_boss_damage_monitor" },
    { 0xEBF6, "chopper_boss_destroyed_func" },
    { 0xEBF7, "chopper_boss_drone_target_array" },
    { 0xEBF8, "chopper_boss_explosion" },
    { 0xEBF9, "chopper_boss_fight_spawn_watcher" },
    { 0xEBFA, "chopper_boss_fight_stage_trigger_think" },
    { 0xEBFB, "chopper_boss_fight_trigger_think" },
    { 0xEBFC, "chopper_boss_loc" },
    { 0xEBFD, "chopper_boss_player_monitor" },
    { 0xEBFE, "chopper_boss_players_connect_monitor" },
    { 0xEBFF, "chopper_boss_target_tag" },
    { 0xEC00, "chopper_can_see" },
    { 0xEC01, "chopper_carepackage" },
    { 0xEC02, "chopper_carepackage_pilot_selected" },
    { 0xEC03, "chopper_carepackage_set_useable" },
    { 0xEC04, "chopper_death_callback" },
    { 0xEC05, "chopper_glow_sticks" },
    { 0xEC06, "chopper_gunner" },
    { 0xEC07, "chopper_gunner_assignedtargetmarkers_onnewai" },
    { 0xEC08, "chopper_gunner_assigntargetmarkers" },
    { 0xEC09, "chopper_kill" },
    { 0xEC0A, "chopper_kill_person" },
    { 0xEC0B, "chopper_kill_vehicle" },
    { 0xEC0C, "chopper_lights" },
    { 0xEC0D, "chopper_playfx" },
    { 0xEC0E, "chopper_respawn_timer" },
    { 0xEC0F, "chopper_sound_fade_and_delete" },
    { 0xEC10, "chopper_watch_death" },
    { 0xEC11, "chopperexfil_introsound" },
    { 0xEC12, "chopperexfil_music_sh025" },
    { 0xEC13, "chopperexfil_music_start" },
    { 0xEC14, "chopperexfil_pack" },
    { 0xEC15, "chopperexfil_set_brcircle" },
    { 0xEC16, "chopperexfil_sfx_before_sh070" },
    { 0xEC17, "chopperexfil_sh010_start" },
    { 0xEC18, "chopperexfil_sh020_start" },
    { 0xEC19, "chopperexfil_sh025_start" },
    { 0xEC1A, "chopperexfil_sh030_start" },
    { 0xEC1B, "chopperexfil_sh040_start" },
    { 0xEC1C, "chopperexfil_sh050_start" },
    { 0xEC1D, "chopperexfil_sh060_start" },
    { 0xEC1E, "chopperexfil_sh070_start" },
    { 0xEC1F, "chopperexfil_sitting_wind" },
    { 0xEC20, "chopperexfil_skip_ascend0" },
    { 0xEC21, "chopperexfil_skip_ascend1" },
    { 0xEC22, "chopperexfil_skip_ascend2" },
    { 0xEC23, "chopperexfil_slamtoblack" },
    { 0xEC24, "chopperexif_fx_init" },
    { 0xEC25, "choppergunner_handledangerzone" },
    { 0xEC26, "choppergunner_refillmissiles" },
    { 0xEC27, "choppergunner_waitintroanimtime" },
    { 0xEC28, "choppergunner_watchexplosioninfluencepoint" },
    { 0xEC29, "choppergunner_watchintrodisown" },
    { 0xEC2A, "choppergunner_watchownerexitaction" },
    { 0xEC2B, "chopperoccupied" },
    { 0xEC2C, "choppersupport_canattackactivetarget" },
    { 0xEC2D, "choppersupport_isplayeractive" },
    { 0xEC2E, "choppersupport_issmallpatrolmap" },
    { 0xEC2F, "choppersupport_modifydamage_trial" },
    { 0xEC30, "choppersupport_watchforlaststand" },
    { 0xEC31, "choppersupport_watchleash" },
    { 0xEC32, "choppersupport_watchleashrange" },
    { 0xEC33, "choppersupport_watchtargetrange" },
    { 0xEC34, "chosen" },
    { 0xEC35, "chosen_airlock_door" },
    { 0xEC36, "chosencodephones" },
    { 0xEC37, "chuckerlogic" },
    { 0xEC38, "cinderblock_damage_monitor" },
    { 0xEC39, "circle" },
    { 0xEC3A, "circle_acceleration" },
    { 0xEC3B, "circle_back_to_combat" },
    { 0xEC3C, "circle_defaults" },
    { 0xEC3D, "circle_speed" },
    { 0xEC3E, "circleclosestarttime" },
    { 0xEC3F, "circleclosing" },
    { 0xEC40, "circleorigin" },
    { 0xEC41, "circlepeekcleanup" },
    { 0xEC42, "circlepeeks" },
    { 0xEC43, "circleposattime" },
    { 0xEC44, "circleradius" },
    { 0xEC45, "circlerunning" },
    { 0xEC46, "circlesettingsassert" },
    { 0xEC47, "circlesetup" },
    { 0xEC48, "circletestaroundplayer" },
    { 0xEC49, "circletimernext" },
    { 0xEC4A, "circletimestruct" },
    { 0xEC4B, "circuitbreakerswitchesinit" },
    { 0xEC4C, "civ_death" },
    { 0xEC4D, "civ_thread" },
    { 0xEC4E, "civcontroller" },
    { 0xEC4F, "civilians_killed_stat_row" },
    { 0xEC50, "clampstepbulletdamage" },
    { 0xEC51, "classify_players_based_on_laststand" },
    { 0xEC52, "claymore_blockdamageuntilframeend" },
    { 0xEC53, "claymore_crate_player_at_max_ammo" },
    { 0xEC54, "claymore_crate_spawn" },
    { 0xEC55, "claymore_crate_update_hint_logic_alt" },
    { 0xEC56, "claymore_crate_use" },
    { 0xEC57, "claymore_forceclampangles" },
    { 0xEC58, "claymore_load_spawning" },
    { 0xEC59, "claymore_stunned" },
    { 0xEC5A, "claymoreshitby" },
    { 0xEC5B, "clean_and_spawn_carriables" },
    { 0xEC5C, "clean_enemy_ai" },
    { 0xEC5D, "clean_up_combat_action" },
    { 0xEC5E, "clean_up_eliminate_drone" },
    { 0xEC5F, "clean_up_ents" },
    { 0xEC60, "clean_up_func" },
    { 0xEC61, "clean_up_laser_trap_ents" },
    { 0xEC62, "clean_up_minigun" },
    { 0xEC63, "clean_up_none" },
    { 0xEC64, "clean_up_rocket" },
    { 0xEC65, "clean_up_search" },
    { 0xEC66, "clean_up_steam" },
    { 0xEC67, "clean_up_steam_triggers" },
    { 0xEC68, "clean_up_strafe" },
    { 0xEC69, "clean_up_vandalize" },
    { 0xEC6A, "cleanup_corpses" },
    { 0xEC6B, "cleanup_fake_ai_on_death" },
    { 0xEC6C, "cleanup_goal_population" },
    { 0xEC6D, "cleanup_lights" },
    { 0xEC6E, "cleanup_loot_pickups" },
    { 0xEC6F, "cleanup_spawned_exposed_node" },
    { 0xEC70, "cleanup_target_stats" },
    { 0xEC71, "cleanup_target_stats_thermal" },
    { 0xEC72, "cleanup_trap_room" },
    { 0xEC73, "cleanup_triggers" },
    { 0xEC74, "cleanupafterweaponswitch" },
    { 0xEC75, "cleanupallbutxcratesforteam" },
    { 0xEC76, "cleanupallclones" },
    { 0xEC77, "cleanuparenamolotovs" },
    { 0xEC78, "cleanupexplosionleftovers" },
    { 0xEC79, "cleanupfunc" },
    { 0xEC7A, "cleanupkeybindings" },
    { 0xEC7B, "cleanupkeybindingsondeath" },
    { 0xEC7C, "cleanupkillcamlogic" },
    { 0xEC7D, "cleanuplinkent" },
    { 0xEC7E, "cleanupmolotovs" },
    { 0xEC7F, "cleanuppropcontrolshud" },
    { 0xEC80, "cleanuppropcontrolshudondeath" },
    { 0xEC81, "cleanupswaploadoutflags" },
    { 0xEC82, "cleanupvehicleoutline" },
    { 0xEC83, "clear_all_remaining" },
    { 0xEC84, "clear_and_give_killstreak_loadout_assault" },
    { 0xEC85, "clear_and_give_killstreak_loadout_demo" },
    { 0xEC86, "clear_and_give_killstreak_loadout_recon" },
    { 0xEC87, "clear_and_give_killstreak_loadout_support" },
    { 0xEC88, "clear_bomb_vest_controller_holder" },
    { 0xEC89, "clear_cypher_icon" },
    { 0xEC8A, "clear_goal_when_heli_gone" },
    { 0xEC8B, "clear_hint_objective" },
    { 0xEC8C, "clear_keypad_currentdisplay_models" },
    { 0xEC8D, "clear_kill_off_flags_after_unload" },
    { 0xEC8E, "clear_kill_off_flags_after_unload_wait" },
    { 0xEC8F, "clear_legacy_pickup_munitions" },
    { 0xEC90, "clear_lights_based_on_targetname" },
    { 0xEC91, "clear_look_at_ent" },
    { 0xEC92, "clear_mortar_settings" },
    { 0xEC93, "clear_my_munition_slot" },
    { 0xEC94, "clear_padding_disables" },
    { 0xEC95, "clear_player_class_and_super" },
    { 0xEC96, "clear_players_breadcrumbs_to_safe_house" },
    { 0xEC97, "clear_players_from_door_way" },
    { 0xEC98, "clear_players_from_door_way_think" },
    { 0xEC99, "clear_prev_goal" },
    { 0xEC9A, "clear_remaining_objective" },
    { 0xEC9B, "clear_three_room_screens" },
    { 0xEC9C, "clear_tier_lights" },
    { 0xEC9D, "clear_tier_lights_all" },
    { 0xEC9E, "clear_trap_console_activation" },
    { 0xEC9F, "clear_trap_flag" },
    { 0xECA0, "clear_up_objective_after_delay" },
    { 0xECA1, "clear_vehicles" },
    { 0xECA2, "clear_vehicles_from_mlp1" },
    { 0xECA3, "clearandrestoreinfectedtacinsert" },
    { 0xECA4, "clearaveragevelocities" },
    { 0xECA5, "clearbrinventory" },
    { 0xECA6, "clearcurrenthintforced" },
    { 0xECA7, "clearhint" },
    { 0xECA8, "clearinfilstateatinfilend" },
    { 0xECA9, "clearlethalonunresolvedcollision" },
    { 0xECAA, "clearplayerwind" },
    { 0xECAB, "clearsixthsense" },
    { 0xECAC, "clearsoundsubmixfadetoblackamb" },
    { 0xECAD, "clearsoundsubmixmpbrinfilac130" },
    { 0xECAE, "clearsoundsubmixmpbrinfilanim" },
    { 0xECAF, "clearspaceforscriptableinstance" },
    { 0xECB0, "clearsplashqueue" },
    { 0xECB1, "client_activate" },
    { 0xECB2, "client_hint" },
    { 0xECB3, "clientmatchdata_logplayerdeath" },
    { 0xECB4, "clients" },
    { 0xECB5, "clients_hacked" },
    { 0xECB6, "clip_ent" },
    { 0xECB7, "clip_mover" },
    { 0xECB8, "clipleft" },
    { 0xECB9, "clipright" },
    { 0xECBA, "clocksounds" },
    { 0xECBB, "clone" },
    { 0xECBC, "clone_brushmodel_to_script_model" },
    { 0xECBD, "cloned_collision" },
    { 0xECBE, "clonedeath" },
    { 0xECBF, "clonekey" },
    { 0xECC0, "cloneprop" },
    { 0xECC1, "clonesleft" },
    { 0xECC2, "close_assassination_door" },
    { 0xECC3, "close_c130crate_gate" },
    { 0xECC4, "close_doors" },
    { 0xECC5, "close_exit_doors" },
    { 0xECC6, "close_gunshop_door" },
    { 0xECC7, "close_kioskgate" },
    { 0xECC8, "close_safehouse_doors" },
    { 0xECC9, "close_silo_entrance_doors" },
    { 0xECCA, "close_teleport_room_door" },
    { 0xECCB, "close_trap_room_door" },
    { 0xECCC, "close_tut_gate" },
    { 0xECCD, "closed_position" },
    { 0xECCE, "closedangles" },
    { 0xECCF, "closedcenter" },
    { 0xECD0, "closedpos" },
    { 0xECD1, "closeelevatordoors" },
    { 0xECD2, "closenukecrate" },
    { 0xECD3, "closeobjectiveiconid" },
    { 0xECD4, "closeplundergate" },
    { 0xECD5, "closepos" },
    { 0xECD6, "closerightblimadoor" },
    { 0xECD7, "closescriptabledoors" },
    { 0xECD8, "closest_target" },
    { 0xECD9, "closestplayer" },
    { 0xECDA, "closestquad" },
    { 0xECDB, "cloud_cover" },
    { 0xECDC, "cloudanimfx" },
    { 0xECDD, "cloudcoverfx" },
    { 0xECDE, "cloudorigin" },
    { 0xECDF, "cloudref" },
    { 0xECE0, "cluster_child_spawnpoint_scoring" },
    { 0xECE1, "code" },
    { 0xECE2, "code_generation_init" },
    { 0xECE3, "codecomputerscriptableused" },
    { 0xECE4, "codecorrectlyenteredbyanyone" },
    { 0xECE5, "codeentered" },
    { 0xECE6, "codeloc" },
    { 0xECE7, "codenumber" },
    { 0xECE8, "codephonescodeenteredringingfrenzy" },
    { 0xECE9, "codephonescriptableused" },
    { 0xECEA, "col" },
    { 0xECEB, "col_checkiflocaleisavailable" },
    { 0xECEC, "col_circletick" },
    { 0xECED, "col_createcircleobjectiveicon" },
    { 0xECEE, "col_createquestlocale" },
    { 0xECEF, "col_localethink_itemspawn" },
    { 0xECF0, "col_localethink_objectivevisibility" },
    { 0xECF1, "col_removelocaleinstance" },
    { 0xECF2, "col_removequestinstance" },
    { 0xECF3, "collbrush" },
    { 0xECF4, "collect_intel_anim" },
    { 0xECF5, "collectall" },
    { 0xECF6, "collecteditems" },
    { 0xECF7, "collection_num" },
    { 0xECF8, "collision_damage_watcher" },
    { 0xECF9, "collisioncheck" },
    { 0xECFA, "collorigin1" },
    { 0xECFB, "collorigin2" },
    { 0xECFC, "colmaps" },
    { 0xECFD, "colmodel" },
    { 0xECFE, "colorise_toggle_onto" },
    { 0xECFF, "colorise_warnings" },
    { 0xED00, "colorise_warnings_clear" },
    { 0xED01, "combat_action" },
    { 0xED02, "combatrecordequipmentused" },
    { 0xED03, "combatrecordincrementkillstreakextrastat" },
    { 0xED04, "combatrecordsupermisc" },
    { 0xED05, "combined_alias" },
    { 0xED06, "combined_counters_groups" },
    { 0xED07, "combo_duration_calculate" },
    { 0xED08, "combo_progression" },
    { 0xED09, "combo_reset" },
    { 0xED0A, "commandwatcher" },
    { 0xED0B, "comms_crates" },
    { 0xED0C, "compare_higher_score" },
    { 0xED0D, "comparekillcounts" },
    { 0xED0E, "compareplundercounts" },
    { 0xED0F, "comparescore" },
    { 0xED10, "comparescriptindexobscuredspawns" },
    { 0xED11, "comparescriptindexsmalltolarge" },
    { 0xED12, "compareteamscores" },
    { 0xED13, "compass" },
    { 0xED14, "complete_hack_console" },
    { 0xED15, "complete_trap_room" },
    { 0xED16, "complete_vault_assault_retrieve_saw" },
    { 0xED17, "completecollectionquest" },
    { 0xED18, "completed_areas" },
    { 0xED19, "completedmounttut" },
    { 0xED1A, "completeobjstr" },
    { 0xED1B, "completepayloadexfilobjective" },
    { 0xED1C, "completepayloadpunish" },
    { 0xED1D, "completesecretstashquest" },
    { 0xED1E, "completesmokinggunquest" },
    { 0xED1F, "completetimedrunquest" },
    { 0xED20, "completex1finquest" },
    { 0xED21, "completex1stashquest" },
    { 0xED22, "compound_objective" },
    { 0xED23, "computer_animation_off" },
    { 0xED24, "computer_debugtestloop" },
    { 0xED25, "computer_force_player_to_exit" },
    { 0xED26, "computer_interaction_start" },
    { 0xED27, "computer_interface_think_internal" },
    { 0xED28, "computer_listener_all" },
    { 0xED29, "computer_objective" },
    { 0xED2A, "computer_player_listener" },
    { 0xED2B, "computer_prompt_pressed" },
    { 0xED2C, "computermakingnose" },
    { 0xED2D, "computerrebootsequence_init" },
    { 0xED2E, "computerrebootused" },
    { 0xED2F, "computerscriptable" },
    { 0xED30, "concussionimmune" },
    { 0xED31, "concussionused" },
    { 0xED32, "concusspushstart" },
    { 0xED33, "cone" },
    { 0xED34, "confirm_good_pickup_location" },
    { 0xED35, "confirmed_pilot" },
    { 0xED36, "connect_circlar_path" },
    { 0xED37, "connect_init" },
    { 0xED38, "connected_search_node" },
    { 0xED39, "connected_vandalize_node" },
    { 0xED3A, "connectedplayercount" },
    { 0xED3B, "consecutive_kills" },
    { 0xED3C, "console_being_hacked" },
    { 0xED3D, "contestedtime" },
    { 0xED3E, "contract_death_cash_flag" },
    { 0xED3F, "contributingplayers" },
    { 0xED40, "control_room_button" },
    { 0xED41, "control_room_button_green" },
    { 0xED42, "control_station" },
    { 0xED43, "control_station_interact" },
    { 0xED44, "controlledcallbacks" },
    { 0xED45, "controlledcallbacksqueue" },
    { 0xED46, "controls_linkto_safe" },
    { 0xED47, "controls_unlink_safe" },
    { 0xED48, "controlslinked" },
    { 0xED49, "convert_remaining_to_ai" },
    { 0xED4A, "convoy4_actively_hacking" },
    { 0xED4B, "convoy4_failed_extract" },
    { 0xED4C, "convoy4_module_snipers" },
    { 0xED4D, "convoy4_mortar_guys" },
    { 0xED4E, "convoy4_roof_jugg" },
    { 0xED4F, "convoy4_roof_rpgs" },
    { 0xED50, "convoy_anim_sequence" },
    { 0xED51, "convoy_handle_stuck_compromise" },
    { 0xED52, "convoy_left_gulag_monitor" },
    { 0xED53, "convoy_pos" },
    { 0xED54, "convoy_start_5b" },
    { 0xED55, "convoy_turret" },
    { 0xED56, "cooldownsec" },
    { 0xED57, "coop_escort_get_vehicle_driver_hint_string_func" },
    { 0xED58, "coop_escort_try_start_driving_func" },
    { 0xED59, "coop_handle_invuln_ac130" },
    { 0xED5A, "cop_car_initdamage" },
    { 0xED5B, "cop_car_initomnvars" },
    { 0xED5C, "copy_wave_settings_from_module" },
    { 0xED5D, "copycirclearraystartingat" },
    { 0xED5E, "copyplayerplundereventdata" },
    { 0xED5F, "corner0to2dist" },
    { 0xED60, "corner3to0dist" },
    { 0xED61, "correctcodeentered" },
    { 0xED62, "cosfov" },
    { 0xED63, "cosmeticattachment" },
    { 0xED64, "countdownendcallback" },
    { 0xED65, "countdowntimer" },
    { 0xED66, "countlefthand" },
    { 0xED67, "course_triggers_expl" },
    { 0xED68, "courtyard_intel_sequence" },
    { 0xED69, "cover_guys_debug" },
    { 0xED6A, "coverreloadnotetrackhandler" },
    { 0xED6B, "covertransitionrate" },
    { 0xED6C, "coverupbrokenmodels" },
    { 0xED6D, "coverupmodels" },
    { 0xED6E, "cp_arms_dealer_sound_load" },
    { 0xED6F, "cp_dntsk_raid_sound_load" },
    { 0xED70, "cp_dntsk_raid_specific_init" },
    { 0xED71, "cp_dwn_twn_2_sound_load" },
    { 0xED72, "cp_friendlyfire_enabled" },
    { 0xED73, "cp_is_point_in_front" },
    { 0xED74, "cp_is_point_on_right" },
    { 0xED75, "cp_landlord_sound_load" },
    { 0xED76, "cp_raid_complex_behavior" },
    { 0xED77, "cp_smuggler_sound_load" },
    { 0xED78, "cp_vehicle_damage_monitor" },
    { 0xED79, "cpcpammoarmorcratecapturecallback" },
    { 0xED7A, "cpoperationcrateactivatecallback" },
    { 0xED7B, "cpoperationcratecapturecallback" },
    { 0xED7C, "cprooftopcratecapturecallback" },
    { 0xED7D, "cpvehiclename" },
    { 0xED7E, "cqb_laser_guy" },
    { 0xED7F, "cqb_laser_guy_internal" },
    { 0xED80, "crankedprogressuiupdater" },
    { 0xED81, "crashoffset" },
    { 0xED82, "crate_equipment" },
    { 0xED83, "crate_falling_collision" },
    { 0xED84, "crate_follow_text" },
    { 0xED85, "crate_index" },
    { 0xED86, "crate_model_anim_setup" },
    { 0xED87, "crate_munitions" },
    { 0xED88, "crate_obj_offset" },
    { 0xED89, "crate_objectives" },
    { 0xED8A, "crate_set_flag_on_use" },
    { 0xED8B, "crate_vo_play_on_first_use" },
    { 0xED8C, "crate_weapons" },
    { 0xED8D, "cratecleanup" },
    { 0xED8E, "cratephysicsoff" },
    { 0xED8F, "cratephysicson" },
    { 0xED90, "cratephysicsoncallback" },
    { 0xED91, "crates_delete_early" },
    { 0xED92, "crateusefunc" },
    { 0xED93, "create" },
    { 0xED94, "create_agent_definition" },
    { 0xED95, "create_ai_type_override" },
    { 0xED96, "create_ambient_vehicle" },
    { 0xED97, "create_ammo_crate_objectives" },
    { 0xED98, "create_animpack" },
    { 0xED99, "create_apc_vehicle_interaction" },
    { 0xED9A, "create_badplace_extraction" },
    { 0xED9B, "create_bomb_wire_info" },
    { 0xED9C, "create_cam" },
    { 0xED9D, "create_chopper_boss" },
    { 0xED9E, "create_circular_path_around" },
    { 0xED9F, "create_crate_objectives" },
    { 0xEDA0, "create_cursor_hint_forced" },
    { 0xEDA1, "create_cypher_piece" },
    { 0xEDA2, "create_debug_model_for_spawnpoint" },
    { 0xEDA3, "create_digit_models" },
    { 0xEDA4, "create_disconnectplayer" },
    { 0xEDA5, "create_execution_devgui" },
    { 0xEDA6, "create_exfil_animstruct" },
    { 0xEDA7, "create_fake_loot_model_from_struct" },
    { 0xEDA8, "create_head_icon_for_crate" },
    { 0xEDA9, "create_heartbeat_sensor_pick_up" },
    { 0xEDAA, "create_heartbeat_sensor_pick_ups" },
    { 0xEDAB, "create_heli_stuct" },
    { 0xEDAC, "create_intel_model" },
    { 0xEDAD, "create_juggernaut_spawner" },
    { 0xEDAE, "create_keycard_for_reader" },
    { 0xEDAF, "create_laser_point_to_point" },
    { 0xEDB0, "create_laser_trap" },
    { 0xEDB1, "create_model_at" },
    { 0xEDB2, "create_mp_version_of_vehicle" },
    { 0xEDB3, "create_name_fx" },
    { 0xEDB4, "create_name_fx_base" },
    { 0xEDB5, "create_nav_obstacle_for_wheelson" },
    { 0xEDB6, "create_opaque_ai_contents" },
    { 0xEDB7, "create_oscilloscope" },
    { 0xEDB8, "create_oscilloscope_screen" },
    { 0xEDB9, "create_passengers_unload_groups" },
    { 0xEDBA, "create_player_rig_laser_panel" },
    { 0xEDBB, "create_primary_weapon_obj_from_custom_loadout" },
    { 0xEDBC, "create_puddle_triggers" },
    { 0xEDBD, "create_race" },
    { 0xEDBE, "create_rig_for_usb_animation" },
    { 0xEDBF, "create_rocket_death_fx" },
    { 0xEDC0, "create_saw_interaction" },
    { 0xEDC1, "create_score_message" },
    { 0xEDC2, "create_script_wait_for_flags" },
    { 0xEDC3, "create_seatids_override" },
    { 0xEDC4, "create_silencer_pick_up" },
    { 0xEDC5, "create_silencer_pick_ups" },
    { 0xEDC6, "create_smoke_occluder" },
    { 0xEDC7, "create_solution_digit_mark" },
    { 0xEDC8, "create_struct" },
    { 0xEDC9, "create_struct_at" },
    { 0xEDCA, "create_temp_infil_structs" },
    { 0xEDCB, "create_thrust_fire" },
    { 0xEDCC, "create_traversal_node_and_link" },
    { 0xEDCD, "create_trial_weapon_spawn" },
    { 0xEDCE, "create_trophy_station" },
    { 0xEDCF, "create_tut_loot_struct" },
    { 0xEDD0, "create_usb_anim_rig" },
    { 0xEDD1, "create_vault_assault_loadout_selection" },
    { 0xEDD2, "create_vehicle_interact" },
    { 0xEDD3, "create_vehicle_occupancy_data" },
    { 0xEDD4, "create_vehicle_omnvars_data" },
    { 0xEDD5, "create_vehicle_vehicledata" },
    { 0xEDD6, "create_weapon_pick_up" },
    { 0xEDD7, "create_weapon_pick_ups" },
    { 0xEDD8, "createagenttargetloadout" },
    { 0xEDD9, "createalldestinationvfx" },
    { 0xEDDA, "createallhistorydestinations" },
    { 0xEDDB, "createandstartlights" },
    { 0xEDDC, "createapcturret" },
    { 0xEDDD, "createattractionicontrigger" },
    { 0xEDDE, "createc130pathstruct" },
    { 0xEDDF, "createcallbacks" },
    { 0xEDE0, "createdefaultrectangularzone" },
    { 0xEDE1, "createdestinationvfx" },
    { 0xEDE2, "createdevguientryforkidnapper" },
    { 0xEDE3, "createextractionlocation" },
    { 0xEDE4, "createflagstart" },
    { 0xEDE5, "creategulagarenaloadout" },
    { 0xEDE6, "creategulagjailloadout" },
    { 0xEDE7, "creategulagloadoutarry" },
    { 0xEDE8, "createheliextractobjectiveicons" },
    { 0xEDE9, "createhistorydestination" },
    { 0xEDEA, "createhudelem" },
    { 0xEDEB, "createhudstring" },
    { 0xEDEC, "createhudtimer" },
    { 0xEDED, "createinvalidcirclearea" },
    { 0xEDEE, "createjuggdroplocation" },
    { 0xEDEF, "createkillchallengeevent" },
    { 0xEDF0, "createnagarray" },
    { 0xEDF1, "createnukecrate" },
    { 0xEDF2, "createobjectivelist" },
    { 0xEDF3, "createplayerplundereventdata" },
    { 0xEDF4, "createprematchloadout" },
    { 0xEDF5, "createpropspecatehud" },
    { 0xEDF6, "createpropspeclist" },
    { 0xEDF7, "createquestcircle" },
    { 0xEDF8, "createquestobjicon" },
    { 0xEDF9, "createrectangularzonebasedonent" },
    { 0xEDFA, "createscreeneffectext" },
    { 0xEDFB, "createscript_covernodes" },
    { 0xEDFC, "createscriptedspawnpoint" },
    { 0xEDFD, "createserverfontstring" },
    { 0xEDFE, "createsmokesignalfx" },
    { 0xEDFF, "createspawncamera" },
    { 0xEE00, "createstreakinfo_ai_turret" },
    { 0xEE01, "createteamdefenderflag" },
    { 0xEE02, "createteamdefenderflagbase" },
    { 0xEE03, "createvisualsinfo" },
    { 0xEE04, "createzombieloadout" },
    { 0xEE05, "critical_messages" },
    { 0xEE06, "crossbow" },
    { 0xEE07, "crossbowbolts" },
    { 0xEE08, "crossbowimpactwatcher" },
    { 0xEE09, "crossbowusageloop" },
    { 0xEE0A, "cruise_predator_direction_override" },
    { 0xEE0B, "cruisepredator_assigntargetmarkers" },
    { 0xEE0C, "cruisepredator_detachplayerfromintro" },
    { 0xEE0D, "cruisepredator_watchgameend" },
    { 0xEE0E, "cruisepredator_watchintropoddisown" },
    { 0xEE0F, "cruisepredator_watchownerdisownaction" },
    { 0xEE10, "crushing_players" },
    { 0xEE11, "cs_add_to_struct_array" },
    { 0xEE12, "cs_flags_init" },
    { 0xEE13, "cs_setup_arrays" },
    { 0xEE14, "csm_alg" },
    { 0xEE15, "ctf_bot_attacker_limit_for_team" },
    { 0xEE16, "ctf_bot_defender_limit_for_team" },
    { 0xEE17, "ctfnukeended" },
    { 0xEE18, "ctgs_buildstatstrackerstruct" },
    { 0xEE19, "ctgs_comparestats" },
    { 0xEE1A, "ctgs_compareweaponxp" },
    { 0xEE1B, "ctgs_recordmatchstats" },
    { 0xEE1C, "ctgs_statstracker" },
    { 0xEE1D, "cull_list_of_players" },
    { 0xEE1E, "cumulative_damage_expire_time" },
    { 0xEE1F, "cumulative_damage_monitor" },
    { 0xEE20, "cumulative_damage_to_chopper_boss" },
    { 0xEE21, "cur_goal_struct" },
    { 0xEE22, "cur_vision" },
    { 0xEE23, "cur_wave_start_time" },
    { 0xEE24, "curr_airlock_pos" },
    { 0xEE25, "current_ally_volume" },
    { 0xEE26, "current_anim_ref" },
    { 0xEE27, "current_automated_respawn_timer_value" },
    { 0xEE28, "current_button_counter" },
    { 0xEE29, "current_button_progress" },
    { 0xEE2A, "current_carrier" },
    { 0xEE2B, "current_carrier_time" },
    { 0xEE2C, "current_checkpoint" },
    { 0xEE2D, "current_count_down" },
    { 0xEE2E, "current_cypher_pieces" },
    { 0xEE2F, "current_puddle_count" },
    { 0xEE30, "current_respawn_point" },
    { 0xEE31, "current_respawn_point_override" },
    { 0xEE32, "current_safehouse_spawn_structs" },
    { 0xEE33, "current_shield_tagattach" },
    { 0xEE34, "current_spawner" },
    { 0xEE35, "current_steps" },
    { 0xEE36, "current_struct" },
    { 0xEE37, "current_tablet" },
    { 0xEE38, "current_trigger" },
    { 0xEE39, "current_volume_allies" },
    { 0xEE3A, "current_volume_enemy" },
    { 0xEE3B, "current_volume_num" },
    { 0xEE3C, "current_zone" },
    { 0xEE3D, "currentability" },
    { 0xEE3E, "currentbestdist" },
    { 0xEE3F, "currentbestpos" },
    { 0xEE40, "currentcarrier" },
    { 0xEE41, "currentclientmatchdataid" },
    { 0xEE42, "currentdebugweapon" },
    { 0xEE43, "currentdebugweaponindex" },
    { 0xEE44, "currentdestination" },
    { 0xEE45, "currentdestindex" },
    { 0xEE46, "currentgametypestopsclock" },
    { 0xEE47, "currentgroupindex" },
    { 0xEE48, "currentgunshipweapon" },
    { 0xEE49, "currenthint" },
    { 0xEE4A, "currenthudy" },
    { 0xEE4B, "currentindex" },
    { 0xEE4C, "currentinteldialog" },
    { 0xEE4D, "currentintelflag" },
    { 0xEE4E, "currentintelindex" },
    { 0xEE4F, "currentlabel" },
    { 0xEE50, "currentmultikill" },
    { 0xEE51, "currentnumber" },
    { 0xEE52, "currentpoint" },
    { 0xEE53, "currentrewarddropindex" },
    { 0xEE54, "currentsol" },
    { 0xEE55, "currentsolsign" },
    { 0xEE56, "currenttime" },
    { 0xEE57, "currenttime_bonus" },
    { 0xEE58, "currentvalue" },
    { 0xEE59, "currlocation" },
    { 0xEE5A, "custom_damage_handler" },
    { 0xEE5B, "custom_damageshield" },
    { 0xEE5C, "custom_damageshield_cooldown" },
    { 0xEE5D, "custom_death_active" },
    { 0xEE5E, "custom_death_func" },
    { 0xEE5F, "custom_explode_mine" },
    { 0xEE60, "custom_ground_vehicle_death_func" },
    { 0xEE61, "custom_helicopter_firendly_dmg_func" },
    { 0xEE62, "custom_loadout_index" },
    { 0xEE63, "custom_putongroundfunc" },
    { 0xEE64, "custom_shouldtakedamage" },
    { 0xEE65, "custompassengerwaitfunc" },
    { 0xEE66, "customspeed" },
    { 0xEE67, "customturret" },
    { 0xEE68, "customusefunc" },
    { 0xEE69, "cutscenedone" },
    { 0xEE6A, "cyber_bot_pickup_emp" },
    { 0xEE6B, "cyberteamspawnsetids" },
    { 0xEE6C, "cycle_thrust_fx" },
    { 0xEE6D, "cypher_current_string" },
    { 0xEE6E, "cypher_iconid" },
    { 0xEE6F, "cypher_id_pool" },
    { 0xEE70, "cypher_signal_strength_nag" },
    { 0xEE71, "cypher_vo_complete" },
    { 0xEE72, "cypher_vo_hack_progress" },
    { 0xEE73, "cypher_vo_intro" },
    { 0xEE74, "damage_area" },
    { 0xEE75, "damage_data" },
    { 0xEE76, "damage_empty_vehicles_infrontofme" },
    { 0xEE77, "damage_enemies_in_trigger" },
    { 0xEE78, "damage_feedback_watch" },
    { 0xEE79, "damage_from_above" },
    { 0xEE7A, "damage_func" },
    { 0xEE7B, "damage_multiplier" },
    { 0xEE7C, "damage_per_second" },
    { 0xEE7D, "damage_players_on_blades" },
    { 0xEE7E, "damage_players_on_bottom" },
    { 0xEE7F, "damage_players_on_top" },
    { 0xEE80, "damage_players_when_enter_trigger" },
    { 0xEE81, "damage_shield_reduction" },
    { 0xEE82, "damage_stage_final_watcher" },
    { 0xEE83, "damage_taken" },
    { 0xEE84, "damageby" },
    { 0xEE85, "damageclonewatch" },
    { 0xEE86, "damagedisabledfeedback" },
    { 0xEE87, "damageendtime" },
    { 0xEE88, "damagefactor" },
    { 0xEE89, "damagefactorhigh" },
    { 0xEE8A, "damagefactorlow" },
    { 0xEE8B, "damagefactormedium" },
    { 0xEE8C, "damagepercent" },
    { 0xEE8D, "damagepercenthigh" },
    { 0xEE8E, "damagepercentlow" },
    { 0xEE8F, "damagepercentmedium" },
    { 0xEE90, "damageshield_cooldown" },
    { 0xEE91, "damageshield_threshold" },
    { 0xEE92, "damageshield_time" },
    { 0xEE93, "damageskipburndown" },
    { 0xEE94, "damageskipburndownhigh" },
    { 0xEE95, "damageskipburndownlow" },
    { 0xEE96, "damageskipburndownmedium" },
    { 0xEE97, "damagestate" },
    { 0xEE98, "damagestatedata" },
    { 0xEE99, "damagestateref" },
    { 0xEE9A, "damagethisround" },
    { 0xEE9B, "dangercircleenthidefromplayers" },
    { 0xEE9C, "dangercircletick_carriable" },
    { 0xEE9D, "dangernotifyplayer" },
    { 0xEE9E, "dangernotifyplayersinrange" },
    { 0xEE9F, "dangernotifyresetforplayer" },
    { 0xEEA0, "dangerzoneids" },
    { 0xEEA1, "dangerzoneskipequipment" },
    { 0xEEA2, "data_pickup_logic" },
    { 0xEEA3, "data_pickup_logic_new" },
    { 0xEEA4, "datakey" },
    { 0xEEA5, "deactivate_battle_station" },
    { 0xEEA6, "deactivate_front_trigger_hurt" },
    { 0xEEA7, "deactivate_gas_trap" },
    { 0xEEA8, "deactivate_gas_trap_cloud" },
    { 0xEEA9, "deactivate_gas_trap_cloud_parent" },
    { 0xEEAA, "deactivate_gas_trap_puddles" },
    { 0xEEAB, "deactivate_gas_trap_trigger" },
    { 0xEEAC, "deactivate_hacked_console" },
    { 0xEEAD, "deactivate_laser_from_struct" },
    { 0xEEAE, "deactivate_laser_trap" },
    { 0xEEAF, "deactivate_laser_trap_parent" },
    { 0xEEB0, "deactivate_minigun" },
    { 0xEEB1, "deactivate_station" },
    { 0xEEB2, "deactivate_stealth_settings" },
    { 0xEEB3, "deactivate_target" },
    { 0xEEB4, "deactivate_track_timers" },
    { 0xEEB5, "deactivate_trap_object" },
    { 0xEEB6, "deactivategastrap" },
    { 0xEEB7, "deactive_trophy_protection" },
    { 0xEEB8, "dead_target_count" },
    { 0xEEB9, "deadblue" },
    { 0xEEBA, "deadgray" },
    { 0xEEBB, "deadgreen" },
    { 0xEEBC, "deadmans_cash_pickup" },
    { 0xEEBD, "deadpair" },
    { 0xEEBE, "deadred" },
    { 0xEEBF, "deadyellow" },
    { 0xEEC0, "deafen_ai" },
    { 0xEEC1, "deafen_ai_near_pa_for_duration" },
    { 0xEEC2, "deal_damage_after_time" },
    { 0xEEC3, "death_explode" },
    { 0xEEC4, "death_impulse" },
    { 0xEEC5, "death_info_func" },
    { 0xEEC6, "death_killstreak_watcher" },
    { 0xEEC7, "deathcashcollected" },
    { 0xEEC8, "deathnoise" },
    { 0xEEC9, "deathsdoorsfx" },
    { 0xEECA, "deavtivate_destructible_cinderblock" },
    { 0xEECB, "debug_ai_aggro" },
    { 0xEECC, "debug_blockade_phone_drop" },
    { 0xEECD, "debug_bunkerpuzzledebugdraw" },
    { 0xEECE, "debug_bunkertestaccesscardlocs" },
    { 0xEECF, "debug_calculatecashonground" },
    { 0xEED0, "debug_chopper_boss" },
    { 0xEED1, "debug_chopper_boss_combat" },
    { 0xEED2, "debug_consoles" },
    { 0xEED3, "debug_display_track_tilts" },
    { 0xEED4, "debug_display_veh_hit" },
    { 0xEED5, "debug_escape_silo" },
    { 0xEED6, "debug_forest_combat" },
    { 0xEED7, "debug_freight_lift" },
    { 0xEED8, "debug_gates" },
    { 0xEED9, "debug_hintadjustmentthink" },
    { 0xEEDA, "debug_interaction_status" },
    { 0xEEDB, "debug_interaction_toggle" },
    { 0xEEDC, "debug_intro_start" },
    { 0xEEDD, "debug_jugg_health" },
    { 0xEEDE, "debug_jugg_maze" },
    { 0xEEDF, "debug_kill_ent_after_time" },
    { 0xEEE0, "debug_kill_tromeo" },
    { 0xEEE1, "debug_listing_helis" },
    { 0xEEE2, "debug_mine_caves" },
    { 0xEEE3, "debug_nuke_vault" },
    { 0xEEE4, "debug_pipe_room" },
    { 0xEEE5, "debug_pre_start_coop_escape" },
    { 0xEEE6, "debug_printcode" },
    { 0xEEE7, "debug_reach_exhaust_waste" },
    { 0xEEE8, "debug_reach_icbm_launch" },
    { 0xEEE9, "debug_reach_pipe_room" },
    { 0xEEEA, "debug_reach_wind_room" },
    { 0xEEEB, "debug_run_helicopter_boss" },
    { 0xEEEC, "debug_safehouse_gunshop_start" },
    { 0xEEED, "debug_safehouse_regroup_start" },
    { 0xEEEE, "debug_shoot_offset" },
    { 0xEEEF, "debug_show2dvotext" },
    { 0xEEF0, "debug_showcardlocs" },
    { 0xEEF1, "debug_silo_jump" },
    { 0xEEF2, "debug_silo_thrust" },
    { 0xEEF3, "debug_spawn_crate_on_train" },
    { 0xEEF4, "debug_spawnallaccesscards" },
    { 0xEEF5, "debug_spawncover_badnodetest" },
    { 0xEEF6, "debug_spawning" },
    { 0xEEF7, "debug_spawnrewardstest" },
    { 0xEEF8, "debug_start_numbers_threaded" },
    { 0xEEF9, "debug_start_silo_elevator" },
    { 0xEEFA, "debug_state" },
    { 0xEEFB, "debug_swivelroom_start" },
    { 0xEEFC, "debug_test_kill_kidnapper" },
    { 0xEEFD, "debug_trans_1_start" },
    { 0xEEFE, "debug_trap_room" },
    { 0xEEFF, "debug_trap_toggle" },
    { 0xEF00, "debug_unlock_silo" },
    { 0xEF01, "debug_vault_assault_retrieve_saw_obj_start" },
    { 0xEF02, "debug_warpplayer_monitor" },
    { 0xEF03, "debugextractsite" },
    { 0xEF04, "debugforcesre1" },
    { 0xEF05, "debugforcesre2" },
    { 0xEF06, "debugnextpropindex" },
    { 0xEF07, "debugpayloadobjectivesstart_infil" },
    { 0xEF08, "debugprintteams" },
    { 0xEF09, "debugprintvipstates" },
    { 0xEF0A, "debugthink" },
    { 0xEF0B, "debugtimedelta" },
    { 0xEF0C, "debugtype" },
    { 0xEF0D, "decide_new_code" },
    { 0xEF0E, "decoy_aicanseeanyplayer" },
    { 0xEF0F, "decoy_aiseenplayerrecently" },
    { 0xEF10, "decoy_canseeplayer" },
    { 0xEF11, "decoy_clearaithreatbiasgroup" },
    { 0xEF12, "decoy_delaystoptrackingassist" },
    { 0xEF13, "decoy_giveassistpoint" },
    { 0xEF14, "decoy_ignoredbyenemy" },
    { 0xEF15, "decoyassists" },
    { 0xEF16, "decrement_num_of_frame_frozen" },
    { 0xEF17, "default_class_chosen" },
    { 0xEF18, "default_compare" },
    { 0xEF19, "default_player_connect_black_screen" },
    { 0xEF1A, "default_suicidebomber_combat" },
    { 0xEF1B, "defaultbreakeraction" },
    { 0xEF1C, "defaultclassindex" },
    { 0xEF1D, "defcon_alarms_stop" },
    { 0xEF1E, "defcon_models_cleanup" },
    { 0xEF1F, "defend_death_counter" },
    { 0xEF20, "defend_main" },
    { 0xEF21, "defend_spawn_crates" },
    { 0xEF22, "defend_start" },
    { 0xEF23, "defend_wave_1" },
    { 0xEF24, "defend_wave_2" },
    { 0xEF25, "defend_wave_3" },
    { 0xEF26, "defend_wave_4" },
    { 0xEF27, "defenderflag" },
    { 0xEF28, "defenderflag_bflagstart" },
    { 0xEF29, "defenderflag_starts" },
    { 0xEF2A, "defenderflagbase" },
    { 0xEF2B, "defenderflagbases" },
    { 0xEF2C, "defenderflagpickupscorefrozen" },
    { 0xEF2D, "defenderflagreset" },
    { 0xEF2E, "defendkill" },
    { 0xEF2F, "defense_wave_send_support" },
    { 0xEF30, "defensefactormod" },
    { 0xEF31, "define_as_level_infil_driver" },
    { 0xEF32, "define_trial_mission_init_func" },
    { 0xEF33, "defuse_nag" },
    { 0xEF34, "defuse_spawners" },
    { 0xEF35, "defusebomb" },
    { 0xEF36, "degrees_to_radians" },
    { 0xEF37, "delay_activate_damage_trigger" },
    { 0xEF38, "delay_add_to_chopper_boss_drone_target_array" },
    { 0xEF39, "delay_camera_normal" },
    { 0xEF3A, "delay_delete_alerted_icon" },
    { 0xEF3B, "delay_delete_reinforcement_called_icon" },
    { 0xEF3C, "delay_delete_rpg_missile" },
    { 0xEF3D, "delay_delete_tv_station_boss_icon" },
    { 0xEF3E, "delay_end_alarm_sound" },
    { 0xEF3F, "delay_end_common_combat" },
    { 0xEF40, "delay_end_soldiers_spawns" },
    { 0xEF41, "delay_enter_combat_after_investigating_grenade" },
    { 0xEF42, "delay_explosion_fx" },
    { 0xEF43, "delay_give_lethal_grenade" },
    { 0xEF44, "delay_give_tactical_grenade" },
    { 0xEF45, "delay_hide_player_clip" },
    { 0xEF46, "delay_kick_inactive_player" },
    { 0xEF47, "delay_loading_screen_omnvar" },
    { 0xEF48, "delay_makeuseable" },
    { 0xEF49, "delay_music_reinforcements" },
    { 0xEF4A, "delay_notify_player_target_hit" },
    { 0xEF4B, "delay_play_depart_vo" },
    { 0xEF4C, "delay_push_player_clear_door_way" },
    { 0xEF4D, "delay_put_players_in_black_screen" },
    { 0xEF4E, "delay_put_vehicles_on_compass" },
    { 0xEF4F, "delay_safe_spawn_chopper_boss" },
    { 0xEF50, "delay_set_bomber_traversals" },
    { 0xEF51, "delay_show_backpack" },
    { 0xEF52, "delay_show_balloon" },
    { 0xEF53, "delay_show_marker_to_tv_station" },
    { 0xEF54, "delay_show_player_clip" },
    { 0xEF55, "delay_spawn_nav_repulsor" },
    { 0xEF56, "delay_spawn_room_soldiers" },
    { 0xEF57, "delay_spawn_tanks" },
    { 0xEF58, "delay_start_escort_enter_vehicle_objective" },
    { 0xEF59, "delay_start_escort_protect_hvi_objective" },
    { 0xEF5A, "delay_start_infiltrate_objective" },
    { 0xEF5B, "delay_start_player_grenade_fire_monitor" },
    { 0xEF5C, "delay_start_player_weapon_fired_monitor" },
    { 0xEF5D, "delay_suspend_vehicle_convoy" },
    { 0xEF5E, "delay_then_run_wave_override" },
    { 0xEF5F, "delay_thirdpersoncamera" },
    { 0xEF60, "delay_turn_laser_trap_back_on" },
    { 0xEF61, "delay_turn_off_red_lights_along_track" },
    { 0xEF62, "delay_turn_off_tum_display" },
    { 0xEF63, "delay_turn_on_headlights" },
    { 0xEF64, "delay_vehicle_to_push_explode_sequence" },
    { 0xEF65, "delaydestroyhudelem" },
    { 0xEF66, "delaydropbags" },
    { 0xEF67, "delayed_depositing" },
    { 0xEF68, "delayed_explosion_things" },
    { 0xEF69, "delayedattach" },
    { 0xEF6A, "delayeddetach" },
    { 0xEF6B, "delayeddetachbreak" },
    { 0xEF6C, "delayedeventtypes" },
    { 0xEF6D, "delayedshowtablets" },
    { 0xEF6E, "delayedunsetbettermissionrewards" },
    { 0xEF6F, "delayeventfired" },
    { 0xEF70, "delaystreamtomovingplane" },
    { 0xEF71, "delete_after_flank_trigger_spawns" },
    { 0xEF72, "delete_after_objective_a" },
    { 0xEF73, "delete_ai" },
    { 0xEF74, "delete_airlock_ents" },
    { 0xEF75, "delete_bad_trucks" },
    { 0xEF76, "delete_breach_engine_loop_after_time" },
    { 0xEF77, "delete_corpses" },
    { 0xEF78, "delete_covernodes" },
    { 0xEF79, "delete_crate_objectives" },
    { 0xEF7A, "delete_door_clip" },
    { 0xEF7B, "delete_dropped_weapon" },
    { 0xEF7C, "delete_elevator" },
    { 0xEF7D, "delete_enemies_if_reaching_max_ai" },
    { 0xEF7E, "delete_ent" },
    { 0xEF7F, "delete_entarray" },
    { 0xEF80, "delete_ents_to_clean_up" },
    { 0xEF81, "delete_exfil_ai_structs" },
    { 0xEF82, "delete_fan_blades" },
    { 0xEF83, "delete_furthest_respawn_enemy" },
    { 0xEF84, "delete_headicon" },
    { 0xEF85, "delete_headicon_on_death" },
    { 0xEF86, "delete_intro_lights" },
    { 0xEF87, "delete_intro_lights_after_delay" },
    { 0xEF88, "delete_keypad_display_models" },
    { 0xEF89, "delete_laser_entities" },
    { 0xEF8A, "delete_light" },
    { 0xEF8B, "delete_me" },
    { 0xEF8C, "delete_name_fx" },
    { 0xEF8D, "delete_objective_on_death" },
    { 0xEF8E, "delete_objective_on_death_safe" },
    { 0xEF8F, "delete_old_gate" },
    { 0xEF90, "delete_on_death_or_dissconnect" },
    { 0xEF91, "delete_on_exit_icon_trigger_pre_race" },
    { 0xEF92, "delete_on_track_delete" },
    { 0xEF93, "delete_on_unloaded" },
    { 0xEF94, "delete_pipe_ents" },
    { 0xEF95, "delete_players_black_screen" },
    { 0xEF96, "delete_race" },
    { 0xEF97, "delete_script_object" },
    { 0xEF98, "delete_silo_lights" },
    { 0xEF99, "delete_smoke_fx" },
    { 0xEF9A, "delete_starting_boxes" },
    { 0xEF9B, "delete_structs_on_self_death" },
    { 0xEF9C, "delete_subway_car" },
    { 0xEF9D, "delete_track" },
    { 0xEF9E, "delete_trapfunc" },
    { 0xEF9F, "delete_undeployed_subway_cars" },
    { 0xEFA0, "delete_wire_blocker_on_trigger" },
    { 0xEFA1, "deleteable" },
    { 0xEFA2, "deleteallglass" },
    { 0xEFA3, "deletecircle" },
    { 0xEFA4, "deletecrateimmediate" },
    { 0xEFA5, "deletehistoryhud" },
    { 0xEFA6, "deleteobjective" },
    { 0xEFA7, "deletepropsifatmax" },
    { 0xEFA8, "deletequestcircle" },
    { 0xEFA9, "deletequestobjicon" },
    { 0xEFAA, "deletescavengerhud" },
    { 0xEFAB, "deletescriptableinstance" },
    { 0xEFAC, "deletescriptableinstanceaftertime" },
    { 0xEFAD, "deletescriptableinstanceaftertime_proc" },
    { 0xEFAE, "deletesecretstashhud" },
    { 0xEFAF, "deletesmokinggunhud" },
    { 0xEFB0, "deletesolospawnstruct" },
    { 0xEFB1, "deletesoundents" },
    { 0xEFB2, "deletesquadspawnstruct" },
    { 0xEFB3, "deletetimedrunhud" },
    { 0xEFB4, "deletetmtylheadicon" },
    { 0xEFB5, "deletex1finhud" },
    { 0xEFB6, "deletex1stashhud" },
    { 0xEFB7, "demo_debug_nuke" },
    { 0xEFB8, "demo_update_hint_logic" },
    { 0xEFB9, "demoforcesre" },
    { 0xEFBA, "demotehvt" },
    { 0xEFBB, "denyascendmessagejugg" },
    { 0xEFBC, "denyascendmessagelaststand" },
    { 0xEFBD, "depletiondelay" },
    { 0xEFBE, "depletionrate" },
    { 0xEFBF, "deploy_balloon_nags" },
    { 0xEFC0, "deploy_emp_drone" },
    { 0xEFC1, "deploy_subway_car_at_station" },
    { 0xEFC2, "deploy_subway_cars_on_track" },
    { 0xEFC3, "deploy_suicide_truck_in_blockade" },
    { 0xEFC4, "deploy_suicide_truck_in_farm" },
    { 0xEFC5, "deploy_suicide_truck_in_lumber_yard" },
    { 0xEFC6, "deploy_wp" },
    { 0xEFC7, "deployable_cover_cancel" },
    { 0xEFC8, "deployed" },
    { 0xEFC9, "deployingplayer" },
    { 0xEFCA, "deposit_from_compromised_convoy_delayed" },
    { 0xEFCB, "deposit_from_compromised_convoy_delayed_failsafe" },
    { 0xEFCC, "deregistergasmaskscriptableatframeend" },
    { 0xEFCD, "deregisterscriptableinstance" },
    { 0xEFCE, "descendpos" },
    { 0xEFCF, "descendsolostarts" },
    { 0xEFD0, "desired_landing_spot" },
    { 0xEFD1, "destinations" },
    { 0xEFD2, "destorder" },
    { 0xEFD3, "destpoint" },
    { 0xEFD4, "destprogress" },
    { 0xEFD5, "destroy_bad_traversals" },
    { 0xEFD6, "destroy_intro_tank" },
    { 0xEFD7, "destroy_jammer_relocate" },
    { 0xEFD8, "destroy_lmgs" },
    { 0xEFD9, "destroy_vehicle_if_driver_dies" },
    { 0xEFDA, "destroy_vehicle_on_pilot_death" },
    { 0xEFDB, "destroy_vehicles" },
    { 0xEFDC, "destroyaward" },
    { 0xEFDD, "destroyawardlaunchonly" },
    { 0xEFDE, "destroycrateinbadtrigger" },
    { 0xEFDF, "destroypropspecatehud" },
    { 0xEFE0, "destroyscoreevent" },
    { 0xEFE1, "destroyscorelaunchonly" },
    { 0xEFE2, "destructable_car" },
    { 0xEFE3, "destructiblecarlightssetup" },
    { 0xEFE4, "destructiblevehiclesetup" },
    { 0xEFE5, "detachriotshield" },
    { 0xEFE6, "determine_starting_breadcrumb" },
    { 0xEFE7, "determinetrackingcircleoffset" },
    { 0xEFE8, "determinetrackingcirclesize" },
    { 0xEFE9, "determinewinnertype" },
    { 0xEFEA, "detonatedripfx" },
    { 0xEFEB, "detonatefunc" },
    { 0xEFEC, "detonatefx" },
    { 0xEFED, "detonatefxair" },
    { 0xEFEE, "detonatesound" },
    { 0xEFEF, "detonatingplayer" },
    { 0xEFF0, "detonation_code_omnvar_value" },
    { 0xEFF1, "detonation_color_omnvar_value" },
    { 0xEFF2, "detonation_time" },
    { 0xEFF3, "devscriptedtests" },
    { 0xEFF4, "devspectateenemyteam1" },
    { 0xEFF5, "devspectateenemyteam2" },
    { 0xEFF6, "devspectateloc" },
    { 0xEFF7, "devspectatetest" },
    { 0xEFF8, "devspectatetesthost" },
    { 0xEFF9, "diablecachesaroundorigin" },
    { 0xEFFA, "dialog_grenade_missed" },
    { 0xEFFB, "dialog_grenade_update" },
    { 0xEFFC, "dialog_hurry" },
    { 0xEFFD, "dialog_intro" },
    { 0xEFFE, "dialog_kill_watcher_civ" },
    { 0xEFFF, "dialog_low_health" },
    { 0xF000, "dialog_monitor_getoffground" },
    { 0xF001, "dialog_monitor_hurry" },
    { 0xF002, "dialog_monitor_shieldraise" },
    { 0xF003, "dialog_monitor_shieldstow" },
    { 0xF004, "dialog_monitor_waitreload" },
    { 0xF005, "dialog_mount_nag_watcher" },
    { 0xF006, "dialog_play_shieldstow" },
    { 0xF007, "dialog_reachnextcheckpoint" },
    { 0xF008, "dialog_start" },
    { 0xF009, "dialog_system" },
    { 0xF00A, "dialog_target_down" },
    { 0xF00B, "dialog_wait_ready" },
    { 0xF00C, "dialog_wait_ready_civ" },
    { 0xF00D, "dialog_wait_think" },
    { 0xF00E, "dialog_wait_think_civ" },
    { 0xF00F, "dialogqueue" },
    { 0xF010, "dialogueindex" },
    { 0xF011, "dialoguelines" },
    { 0xF012, "did_ads_hint" },
    { 0xF013, "didgasmaskpipschange" },
    { 0xF014, "died_poorly_funcs" },
    { 0xF015, "difficulty_allowseekafterthreshold" },
    { 0xF016, "difficulty_init" },
    { 0xF017, "difficulty_think" },
    { 0xF018, "difficulty_update_time" },
    { 0xF019, "difficultytabledata" },
    { 0xF01A, "diode_light_think" },
    { 0xF01B, "directimpactkill" },
    { 0xF01C, "disable_all_turrets_permanently" },
    { 0xF01D, "disable_back_light" },
    { 0xF01E, "disable_bomb_detonator_interactivity" },
    { 0xF01F, "disable_cinematic_skip" },
    { 0xF020, "disable_collect_leads" },
    { 0xF021, "disable_flag" },
    { 0xF022, "disable_fulton_group_interactions" },
    { 0xF023, "disable_health_regen" },
    { 0xF024, "disable_heli_lights" },
    { 0xF025, "disable_hilltop_roof_traversal" },
    { 0xF026, "disable_hotjoining_after_time" },
    { 0xF027, "disable_hvt_pickup" },
    { 0xF028, "disable_ignore_if_near_player" },
    { 0xF029, "disable_ignore_on_getto" },
    { 0xF02A, "disable_jip" },
    { 0xF02B, "disable_longdeath_post_stealth" },
    { 0xF02C, "disable_map_ammo_munitions" },
    { 0xF02D, "disable_map_munitions" },
    { 0xF02E, "disable_near_snake_cam_after_door_open" },
    { 0xF02F, "disable_near_snake_cam_after_open" },
    { 0xF030, "disable_oob_immunity_on_riders" },
    { 0xF031, "disable_outline_on_atv_use" },
    { 0xF032, "disable_pickuphostage_interaction" },
    { 0xF033, "disable_player_collision_damage" },
    { 0xF034, "disable_purchase_munitions" },
    { 0xF035, "disable_reaper_drone" },
    { 0xF036, "disable_recent_area_memory" },
    { 0xF037, "disable_respawn_tokens" },
    { 0xF038, "disable_snake_cams_when_doors_open" },
    { 0xF039, "disable_spawner" },
    { 0xF03A, "disable_spawnpoints_in_hangar" },
    { 0xF03B, "disable_stealth_reinforcement_icon" },
    { 0xF03C, "disable_super_in_turret" },
    { 0xF03D, "disable_timer" },
    { 0xF03E, "disable_usability_for_duration" },
    { 0xF03F, "disable_weapon_swap_until_swap_finished" },
    { 0xF040, "disableallarmorykiosks" },
    { 0xF041, "disablealltablets" },
    { 0xF042, "disableannouncer" },
    { 0xF043, "disablearmorykiosk" },
    { 0xF044, "disablebunker11cachelocations" },
    { 0xF045, "disabled_permanently" },
    { 0xF046, "disabled_seats_for_vehicle" },
    { 0xF047, "disabledamagefilter" },
    { 0xF048, "disabledamagestattracking" },
    { 0xF049, "disabledamagestattrackingfunc" },
    { 0xF04A, "disabledcurrstate" },
    { 0xF04B, "disabledebugdialogue" },
    { 0xF04C, "disabledfeatures" },
    { 0xF04D, "disabledstate" },
    { 0xF04E, "disabledvehicles" },
    { 0xF04F, "disablefeature" },
    { 0xF050, "disableheavystatedamagefloor" },
    { 0xF051, "disablelootbunkercachelocations" },
    { 0xF052, "disablemount" },
    { 0xF053, "disableonemilannounce" },
    { 0xF054, "disablepercentageannouncements" },
    { 0xF055, "disablepersonalnuke" },
    { 0xF056, "disablepersupdates" },
    { 0xF057, "disableplayerkillrewards" },
    { 0xF058, "disableplayerrewards" },
    { 0xF059, "disablespawncamera" },
    { 0xF05A, "disablespawningforplayer" },
    { 0xF05B, "disablespawningforplayerfunc" },
    { 0xF05C, "disablesuperammo" },
    { 0xF05D, "disabletargetmarkergroups" },
    { 0xF05E, "disableteamkillrewards" },
    { 0xF05F, "disableteamrewards" },
    { 0xF060, "disableuseotherplayerspents" },
    { 0xF061, "disablewinonscore" },
    { 0xF062, "disallow_player_mantles" },
    { 0xF063, "disconnecting" },
    { 0xF064, "dismount_after_accum_damage" },
    { 0xF065, "dismount_after_accum_damage_internal" },
    { 0xF066, "display_already_have_weapon_message" },
    { 0xF067, "display_current_cypher_to_player" },
    { 0xF068, "display_cypher_updated" },
    { 0xF069, "display_dont_have_weapon_message" },
    { 0xF06A, "display_fx_names_after_plane_spawns" },
    { 0xF06B, "display_headicon_to_players" },
    { 0xF06C, "display_hint_for_all" },
    { 0xF06D, "display_hint_for_player" },
    { 0xF06E, "display_hint_for_player_single" },
    { 0xF06F, "display_hint_forced" },
    { 0xF070, "display_hint_single" },
    { 0xF071, "display_message_to_guilty_player" },
    { 0xF072, "display_message_to_teammates" },
    { 0xF073, "display_mission_failed_text" },
    { 0xF074, "display_ping_hint_with_radial_check" },
    { 0xF075, "display_ready_for_sequence" },
    { 0xF076, "display_reinforcement_called_icon" },
    { 0xF077, "display_relics_splash" },
    { 0xF078, "display_timer" },
    { 0xF079, "display_wave_num" },
    { 0xF07A, "display_welcome" },
    { 0xF07B, "display_who_broke_stealth_message" },
    { 0xF07C, "displaycodeindex" },
    { 0xF07D, "displaycodes" },
    { 0xF07E, "displaydelayedmissioncompletesplash" },
    { 0xF07F, "displayplunderloss" },
    { 0xF080, "displaysplashtoplayers" },
    { 0xF081, "displaysplashtoplayersinradius" },
    { 0xF082, "displaysquadmessagetoplayer" },
    { 0xF083, "displaysquadmessagetoteam" },
    { 0xF084, "displaywelcome" },
    { 0xF085, "dist_miles" },
    { 0xF086, "dist_sq_to_ref" },
    { 0xF087, "dist_to_line" },
    { 0xF088, "dist_to_line_seg" },
    { 0xF089, "distance_weight" },
    { 0xF08A, "distort_fx" },
    { 0xF08B, "distsqtodefenderfalgstart" },
    { 0xF08C, "distsqtodefenderflagstart" },
    { 0xF08D, "divide_living_ai" },
    { 0xF08E, "dlog_analytics_init" },
    { 0xF08F, "dmg_trig" },
    { 0xF090, "dmz_bot_callback_func" },
    { 0xF091, "dmz_numteamswithplayers" },
    { 0xF092, "dmzextractcost" },
    { 0xF093, "dmzextractcostdecrease" },
    { 0xF094, "dmzlootleaderupdateonpickup" },
    { 0xF095, "dmzminextractcost" },
    { 0xF096, "dmztut_endgame" },
    { 0xF097, "dmztut_endgametransition" },
    { 0xF098, "dmztut_endgamewithreward" },
    { 0xF099, "dmztut_luicallback" },
    { 0xF09A, "dmztutdropcash" },
    { 0xF09B, "dmztutendgame" },
    { 0xF09C, "dmzwincost" },
    { 0xF09D, "do_ads_hint" },
    { 0xF09E, "do_ascender_entrance" },
    { 0xF09F, "do_cache_2_prep" },
    { 0xF0A0, "do_camera_zoom_out" },
    { 0xF0A1, "do_complete_escape_zoom_out" },
    { 0xF0A2, "do_convoy_moving_vo" },
    { 0xF0A3, "do_custom_evade_start" },
    { 0xF0A4, "do_exfil_vo" },
    { 0xF0A5, "do_func" },
    { 0xF0A6, "do_ghost_skit" },
    { 0xF0A7, "do_hack_sequence" },
    { 0xF0A8, "do_heli_takeoff_vo" },
    { 0xF0A9, "do_kidnapping_anims" },
    { 0xF0AA, "do_laser_panel_anim_sequence" },
    { 0xF0AB, "do_manual_splash_damage_when_frag_explodes" },
    { 0xF0AC, "do_not_unload" },
    { 0xF0AD, "do_player_rescued_anim" },
    { 0xF0AE, "do_secured_player_vo" },
    { 0xF0AF, "do_spawn_vo_callout" },
    { 0xF0B0, "do_wave_spawning_while_players_return_to_safehouse" },
    { 0xF0B1, "doapcdamagevo" },
    { 0xF0B2, "doarmsracelocationnags" },
    { 0xF0B3, "doarmsraceopencachenags" },
    { 0xF0B4, "dobreakeractivation" },
    { 0xF0B5, "docache4voskits" },
    { 0xF0B6, "doclocksound" },
    { 0xF0B7, "docustommusicloopafternuke" },
    { 0xF0B8, "doendofmatchotsequence" },
    { 0xF0B9, "doesstreakinfomatchequippedstreak" },
    { 0xF0BA, "doexfilallyidle" },
    { 0xF0BB, "doextractionevent" },
    { 0xF0BC, "dogtag_collected" },
    { 0xF0BD, "dogtag_collected_lap" },
    { 0xF0BE, "dogtag_visibility_watcher" },
    { 0xF0BF, "dohudplunderpulse" },
    { 0xF0C0, "dohudplunderroll" },
    { 0xF0C1, "dohudplunderrollsound" },
    { 0xF0C2, "doingcheck" },
    { 0xF0C3, "dointerrogationvo" },
    { 0xF0C4, "dointrovo" },
    { 0xF0C5, "dokidnapsequence" },
    { 0xF0C6, "doleaderinterrogationnag" },
    { 0xF0C7, "dom" },
    { 0xF0C8, "dom_ontimerexpired" },
    { 0xF0C9, "domassairetreat" },
    { 0xF0CA, "domflag_hideiconfromplayer" },
    { 0xF0CB, "domflag_onbeginuse" },
    { 0xF0CC, "domflag_showicontoplayer" },
    { 0xF0CD, "domflag_usecondition" },
    { 0xF0CE, "domflagupdateiconsframeend" },
    { 0xF0CF, "domgulagsounds" },
    { 0xF0D0, "domlocale_onentergulag" },
    { 0xF0D1, "domlocale_onrespawn" },
    { 0xF0D2, "domoralesnags" },
    { 0xF0D3, "domplatecapturetime" },
    { 0xF0D4, "domtablet_init" },
    { 0xF0D5, "donetsksubmap" },
    { 0xF0D6, "donotwatchabandoned" },
    { 0xF0D7, "dont_disable" },
    { 0xF0D8, "dont_kill_off_old" },
    { 0xF0D9, "dont_shoot_parachutes" },
    { 0xF0DA, "dont_update_volume" },
    { 0xF0DB, "dontcallpostplunder" },
    { 0xF0DC, "dontclose" },
    { 0xF0DD, "dontdeleteonseatenter" },
    { 0xF0DE, "dontshowscoreevent" },
    { 0xF0DF, "dontspawncargotruck" },
    { 0xF0E0, "dontspawnjeep" },
    { 0xF0E1, "door2" },
    { 0xF0E2, "door_anim" },
    { 0xF0E3, "door_is_frozen" },
    { 0xF0E4, "door_is_open_at_least" },
    { 0xF0E5, "door_parts" },
    { 0xF0E6, "door_set_frozen" },
    { 0xF0E7, "doorisclosed" },
    { 0xF0E8, "doors_opened_music" },
    { 0xF0E9, "doorstate" },
    { 0xF0EA, "dooutrovo" },
    { 0xF0EB, "dopunishhelivocalls" },
    { 0xF0EC, "dorestartvo" },
    { 0xF0ED, "doreturnvo" },
    { 0xF0EE, "dorpgambushvo" },
    { 0xF0EF, "doteamcirclebattlechatter" },
    { 0xF0F0, "doteamextractedupdate" },
    { 0xF0F1, "doteleporttosafehouse" },
    { 0xF0F2, "dotmtylgroup" },
    { 0xF0F3, "dotooclosetominenags" },
    { 0xF0F4, "double_agent" },
    { 0xF0F5, "double_wood_stack" },
    { 0xF0F6, "dovoforleaderinterrogated" },
    { 0xF0F7, "downangles" },
    { 0xF0F8, "downed_player" },
    { 0xF0F9, "downed_reviver_watch_for_return_to_usability" },
    { 0xF0FA, "downedwithbombweapon" },
    { 0xF0FB, "download_paused_watcher" },
    { 0xF0FC, "download_progress" },
    { 0xF0FD, "downtown_gw_ambient_sound_load" },
    { 0xF0FE, "downtown_helicopter_start" },
    { 0xF0FF, "dragonsbreathdamage" },
    { 0xF100, "dragonsbreathhitloccollection" },
    { 0xF101, "draw_cross_forever" },
    { 0xF102, "draw_debug_sphere" },
    { 0xF103, "draw_door_forwards" },
    { 0xF104, "draw_line_orgtoent" },
    { 0xF105, "drawprematchareas" },
    { 0xF106, "drone_death_cleanup" },
    { 0xF107, "drone_instant_killed_monitor" },
    { 0xF108, "drone_movement_vector_monitor" },
    { 0xF109, "drone_out_of_bound_monitor" },
    { 0xF10A, "drone_turret_canseetarget" },
    { 0xF10B, "drone_turrets" },
    { 0xF10C, "drones_spawning" },
    { 0xF10D, "drop_grenade_internal" },
    { 0xF10E, "drop_in_progress" },
    { 0xF10F, "drop_intel_on_death_regardless" },
    { 0xF110, "drop_jugg_crate" },
    { 0xF111, "drop_jugg_suit_on_death" },
    { 0xF112, "drop_locations" },
    { 0xF113, "drop_max" },
    { 0xF114, "drop_minigun" },
    { 0xF115, "drop_new_carepackage" },
    { 0xF116, "drop_percent" },
    { 0xF117, "drop_platform" },
    { 0xF118, "drop_priorities" },
    { 0xF119, "drop_saw_think" },
    { 0xF11A, "drop_scavenger_bag" },
    { 0xF11B, "drop_structs" },
    { 0xF11C, "drop_support_crate_intro" },
    { 0xF11D, "drop_support_crates" },
    { 0xF11E, "drop_type" },
    { 0xF11F, "drop_usb_stick" },
    { 0xF120, "drop_weapon_scripted" },
    { 0xF121, "dropaccesscard" },
    { 0xF122, "dropallunusableitems" },
    { 0xF123, "dropangles" },
    { 0xF124, "dropbrammoboxes" },
    { 0xF125, "dropbrattackerperkammo" },
    { 0xF126, "dropbrc130airdropcrate" },
    { 0xF127, "dropbrcustompickupitem" },
    { 0xF128, "dropbrequipment" },
    { 0xF129, "dropbrgasmask" },
    { 0xF12A, "dropbrhealthpack" },
    { 0xF12B, "dropbrkillstreak" },
    { 0xF12C, "dropbrlootchoppercrate" },
    { 0xF12D, "dropbrlootchoppercrateforpublicevent" },
    { 0xF12E, "dropbrmissiontablet" },
    { 0xF12F, "dropbrplatepouch" },
    { 0xF130, "dropbrprimaryweapons" },
    { 0xF131, "dropbrselfrevivetoken" },
    { 0xF132, "dropbrsuper" },
    { 0xF133, "dropbrsuperfulton" },
    { 0xF134, "dropbrweapon" },
    { 0xF135, "dropcashdeny" },
    { 0xF136, "dropcircle" },
    { 0xF137, "dropcondensedplunder" },
    { 0xF138, "dropcount" },
    { 0xF139, "dropcpcratefromscriptedheli" },
    { 0xF13A, "dropcratefrommanualheli_cp" },
    { 0xF13B, "dropdeliveryatpos" },
    { 0xF13C, "dropfunc" },
    { 0xF13D, "dropjuggbox" },
    { 0xF13E, "dropjuggernautcrate" },
    { 0xF13F, "dropkit_crate_logic" },
    { 0xF140, "dropkit_marker_hints" },
    { 0xF141, "dropmenu_tut" },
    { 0xF142, "dropminigunondeath" },
    { 0xF143, "dropoff" },
    { 0xF144, "dropoff_point_spawner" },
    { 0xF145, "dropoff_sound_hvt_handler" },
    { 0xF146, "dropoff_sound_playervm_handler" },
    { 0xF147, "dropoff_sound_playerwm_handler" },
    { 0xF148, "droporigin" },
    { 0xF149, "dropped_weapon" },
    { 0xF14A, "dropped_weapon_cleanup" },
    { 0xF14B, "dropped_weapon_cleanup_internal" },
    { 0xF14C, "droppedgasmasks" },
    { 0xF14D, "dropping_minigun" },
    { 0xF14E, "droppoint" },
    { 0xF14F, "dropradius" },
    { 0xF150, "dropshield" },
    { 0xF151, "dropspecialistbonus" },
    { 0xF152, "droptogroundmultitrace" },
    { 0xF153, "dropzone" },
    { 0xF154, "dummy_backpack" },
    { 0xF155, "dummy_hint" },
    { 0xF156, "dummy_model" },
    { 0xF157, "dvarlocations" },
    { 0xF158, "dwell_aggro" },
    { 0xF159, "dyn_door" },
    { 0xF15A, "dynamic_door" },
    { 0xF15B, "earnednuke" },
    { 0xF15C, "earnperiodicxp" },
    { 0xF15D, "edit_loadout_think" },
    { 0xF15E, "eggbear" },
    { 0xF15F, "eggbox" },
    { 0xF160, "eggdebug" },
    { 0xF161, "eggrolls" },
    { 0xF162, "eggs" },
    { 0xF163, "eggsetup" },
    { 0xF164, "eggtrigger" },
    { 0xF165, "egress_landlord_vo" },
    { 0xF166, "ejectplayerfromturret" },
    { 0xF167, "elements_hidden" },
    { 0xF168, "elevator_doors_open" },
    { 0xF169, "elevator_init" },
    { 0xF16A, "elevator_lights_toggle" },
    { 0xF16B, "elevator_lower" },
    { 0xF16C, "elevator_manager" },
    { 0xF16D, "elevator_model" },
    { 0xF16E, "elevator_raise" },
    { 0xF16F, "elevator_silo_lights" },
    { 0xF170, "elevator_trigger_wait_for_spawn" },
    { 0xF171, "elevatordoors" },
    { 0xF172, "elim_hud" },
    { 0xF173, "eliminate_drone" },
    { 0xF174, "eliminate_drone_attack_max_cooldown" },
    { 0xF175, "eliminate_drone_attack_min_cooldown" },
    { 0xF176, "eliminate_drone_internal" },
    { 0xF177, "eliminate_drone_minigun_speed" },
    { 0xF178, "eliminate_drone_spotlight_speed" },
    { 0xF179, "eliminatedhudmonitor" },
    { 0xF17A, "eliminateplayer" },
    { 0xF17B, "embassy_level_init" },
    { 0xF17C, "embassy_main" },
    { 0xF17D, "emergency_cleanupents" },
    { 0xF17E, "emissive" },
    { 0xF17F, "emp_drone" },
    { 0xF180, "emp_drone_clean_up" },
    { 0xF181, "emp_drone_clean_up_func" },
    { 0xF182, "emp_drone_damage_monitor" },
    { 0xF183, "emp_drone_pick_up_use_think" },
    { 0xF184, "emp_drone_proximity_explode" },
    { 0xF185, "emp_drone_should_take_damage" },
    { 0xF186, "emp_drone_success_use" },
    { 0xF187, "emp_effect_duration" },
    { 0xF188, "emp_nearby_targets" },
    { 0xF189, "emp_target_list" },
    { 0xF18A, "emp_target_monitor" },
    { 0xF18B, "empdrone_gameendedthink" },
    { 0xF18C, "empdrone_killstreaktargetthink" },
    { 0xF18D, "empendearly" },
    { 0xF18E, "empty_collision_handler" },
    { 0xF18F, "empty_function" },
    { 0xF190, "empty_vo_func" },
    { 0xF191, "enable_keypad_interaction" },
    { 0xF192, "enable_lbravo_player_infil" },
    { 0xF193, "enable_leaderboard" },
    { 0xF194, "enable_motionblur" },
    { 0xF195, "enable_nvgs" },
    { 0xF196, "enable_oob_immunity_on_riders" },
    { 0xF197, "enable_spawner" },
    { 0xF198, "enable_spawner_after_vehicle_death" },
    { 0xF199, "enable_super" },
    { 0xF19A, "enable_super_when_leaving_turret" },
    { 0xF19B, "enable_traversals_for_bombers" },
    { 0xF19C, "enabledbasejumping" },
    { 0xF19D, "enabledfeatures" },
    { 0xF19E, "enabledminimapdisable" },
    { 0xF19F, "enabledskipdeathshield" },
    { 0xF1A0, "enabledskiplaststand" },
    { 0xF1A1, "enablefeature" },
    { 0xF1A2, "enablejuggernautcrateobjective" },
    { 0xF1A3, "enablesplitscreen" },
    { 0xF1A4, "end_breach_fx_structs" },
    { 0xF1A5, "end_chopper_boss" },
    { 0xF1A6, "end_escape_silo" },
    { 0xF1A7, "end_flares" },
    { 0xF1A8, "end_freight_lift" },
    { 0xF1A9, "end_game_cheer" },
    { 0xF1AA, "end_game_tutorial_func" },
    { 0xF1AB, "end_game_win" },
    { 0xF1AC, "end_gates" },
    { 0xF1AD, "end_health" },
    { 0xF1AE, "end_intro_obj" },
    { 0xF1AF, "end_jugg_maze" },
    { 0xF1B0, "end_leave_cave" },
    { 0xF1B1, "end_loop_emp_spark_vfx" },
    { 0xF1B2, "end_mine_caves" },
    { 0xF1B3, "end_ml_p3_exfil" },
    { 0xF1B4, "end_module_if_weapons_free" },
    { 0xF1B5, "end_node" },
    { 0xF1B6, "end_nuke" },
    { 0xF1B7, "end_nuke_vault" },
    { 0xF1B8, "end_origin" },
    { 0xF1B9, "end_origin_final" },
    { 0xF1BA, "end_paratroopers_group" },
    { 0xF1BB, "end_pipe_room" },
    { 0xF1BC, "end_reach_exhaust_waste" },
    { 0xF1BD, "end_reach_icbm_launch" },
    { 0xF1BE, "end_reach_pipe_room" },
    { 0xF1BF, "end_reach_wind_room" },
    { 0xF1C0, "end_silo_elevator" },
    { 0xF1C1, "end_silo_jump" },
    { 0xF1C2, "end_silo_thrust" },
    { 0xF1C3, "end_slow_mode_safe" },
    { 0xF1C4, "end_swivelroom_obj" },
    { 0xF1C5, "end_this_module" },
    { 0xF1C6, "end_trans_1_obj" },
    { 0xF1C7, "end_unlock_silo" },
    { 0xF1C8, "end_wave_spawn_ahead_of_completion" },
    { 0xF1C9, "endac130infilanimsinternal" },
    { 0xF1CA, "endcameraangles" },
    { 0xF1CB, "endcameradebug_think" },
    { 0xF1CC, "endcameraorigins" },
    { 0xF1CD, "endgame_camera" },
    { 0xF1CE, "endgame_finitewaves_camera" },
    { 0xF1CF, "endgame_finitewaves_music" },
    { 0xF1D0, "endgame_finitewaves_vo" },
    { 0xF1D1, "endgame_luidecisionreceived" },
    { 0xF1D2, "endgame_stars" },
    { 0xF1D3, "endgametutorial_func" },
    { 0xF1D4, "endgamevo" },
    { 0xF1D5, "ending_fade_in" },
    { 0xF1D6, "ending_fade_out" },
    { 0xF1D7, "ending_mortars" },
    { 0xF1D8, "ending_player_disconnect_thread" },
    { 0xF1D9, "ending_viewing_players_setup" },
    { 0xF1DA, "ending_winning_players_setup" },
    { 0xF1DB, "ending_zplanes" },
    { 0xF1DC, "endingph" },
    { 0xF1DD, "endingpropspecate" },
    { 0xF1DE, "endmatchcamerastriggered" },
    { 0xF1DF, "endmatchcameratransitions" },
    { 0xF1E0, "endofmatchdatasent" },
    { 0xF1E1, "endoperatorsfxondisconnect" },
    { 0xF1E2, "endprematchskydiving" },
    { 0xF1E3, "endptui" },
    { 0xF1E4, "endround_timescalefactor" },
    { 0xF1E5, "endsuperdisableweaponbr" },
    { 0xF1E6, "endturretonplayerstatus" },
    { 0xF1E7, "enemies_validate_life" },
    { 0xF1E8, "enemy_aggro_at_closest_player" },
    { 0xF1E9, "enemy_ai_enter_alert_due_to_grenade_explode" },
    { 0xF1EA, "enemy_claymore_watchfortrigger" },
    { 0xF1EB, "enemy_clear_scrambler" },
    { 0xF1EC, "enemy_close_in_on_player" },
    { 0xF1ED, "enemy_damage_monitoring" },
    { 0xF1EE, "enemy_failsafe_ifonedidntspawn" },
    { 0xF1EF, "enemy_fallback_logic" },
    { 0xF1F0, "enemy_goto_struct_on_spawn" },
    { 0xF1F1, "enemy_groups" },
    { 0xF1F2, "enemy_is_visible" },
    { 0xF1F3, "enemy_lbravo_flyby" },
    { 0xF1F4, "enemy_left_monitor" },
    { 0xF1F5, "enemy_mine_damaged_think" },
    { 0xF1F6, "enemy_mine_proximity_think" },
    { 0xF1F7, "enemy_mines_init" },
    { 0xF1F8, "enemy_molotov_launch" },
    { 0xF1F9, "enemy_monitor_reload" },
    { 0xF1FA, "enemy_monitor_trialending" },
    { 0xF1FB, "enemy_move_up_and_ignore" },
    { 0xF1FC, "enemy_push_players_logic" },
    { 0xF1FD, "enemy_respawn_manager" },
    { 0xF1FE, "enemy_right_monitor" },
    { 0xF1FF, "enemy_rushdown_player" },
    { 0xF200, "enemy_sentry_debug" },
    { 0xF201, "enemy_signal_flare" },
    { 0xF202, "enemy_spawners" },
    { 0xF203, "enemy_spawnnewscrambler" },
    { 0xF204, "enemy_targets_headshot" },
    { 0xF205, "enemy_think" },
    { 0xF206, "enemy_traversal_management" },
    { 0xF207, "enemy_validate_node_proximity" },
    { 0xF208, "enemy_vehicle_setup" },
    { 0xF209, "enemy_waittill_seen" },
    { 0xF20A, "enemygunship_attackgoal" },
    { 0xF20B, "enemygunship_firerounds" },
    { 0xF20C, "enemygunship_getfiretime" },
    { 0xF20D, "enemygunship_getnearbytargets" },
    { 0xF20E, "enemygunship_getshotgoal" },
    { 0xF20F, "enemygunship_handlemissiledetection" },
    { 0xF210, "enemygunship_spawngunship" },
    { 0xF211, "enemygunship_updatedebugflashlight" },
    { 0xF212, "enemygunship_watchdamage" },
    { 0xF213, "enemygunship_watchdebuglocation" },
    { 0xF214, "enemygunship_watchexfilsequencestart" },
    { 0xF215, "enemygunship_watchplanedistance" },
    { 0xF216, "enemygunship_watchtargets" },
    { 0xF217, "enemygunship_watchweaponimpact" },
    { 0xF218, "enemyhasuavkill" },
    { 0xF219, "enemymarker" },
    { 0xF21A, "engagementcount" },
    { 0xF21B, "engagementtime" },
    { 0xF21C, "ent_cleanup" },
    { 0xF21D, "ent_delete_by_targetname" },
    { 0xF21E, "ent_model" },
    { 0xF21F, "enter_combat_after_call" },
    { 0xF220, "enter_combat_after_call_internal" },
    { 0xF221, "enter_combat_callback" },
    { 0xF222, "enter_combat_maze_ai" },
    { 0xF223, "enter_combat_space" },
    { 0xF224, "enter_laser_panel_anim_sequence" },
    { 0xF225, "enter_maze_ai_combat" },
    { 0xF226, "enter_numbers_debug_start" },
    { 0xF227, "enter_numbers_end" },
    { 0xF228, "enter_numbers_init" },
    { 0xF229, "enter_numbers_start" },
    { 0xF22A, "entercodenumber" },
    { 0xF22B, "enterpos" },
    { 0xF22C, "entisalivevehicle" },
    { 0xF22D, "entisvehicle" },
    { 0xF22E, "entity_movingplatform_update" },
    { 0xF22F, "entityhit" },
    { 0xF230, "entityhittype" },
    { 0xF231, "entityplunderbankalldeposited" },
    { 0xF232, "entityplunderlosealldeposited" },
    { 0xF233, "entmantling" },
    { 0xF234, "entmantlingcrate" },
    { 0xF235, "entmantlingendtime" },
    { 0xF236, "entry_open" },
    { 0xF237, "ents_to_clean_up" },
    { 0xF238, "eomawardplayerxp" },
    { 0xF239, "equip_random_grenade" },
    { 0xF23A, "equip_trophies" },
    { 0xF23B, "equipgasmaskbr" },
    { 0xF23C, "equipmentscriptableused" },
    { 0xF23D, "equipmentuse" },
    { 0xF23E, "equipname" },
    { 0xF23F, "equipprimarypickup" },
    { 0xF240, "equipsecondarypickup" },
    { 0xF241, "escape_if_player_is_in_hangar" },
    { 0xF242, "escort_a" },
    { 0xF243, "escort_b" },
    { 0xF244, "escort_friendly_ai_riders" },
    { 0xF245, "escort_intro_pre_anim_wait" },
    { 0xF246, "escort_vehicle_push_clip" },
    { 0xF247, "escort_vehicle_push_volume" },
    { 0xF248, "evade_start_targetname" },
    { 0xF249, "evaluateallaccolades" },
    { 0xF24A, "evaluatecontrolledcallback" },
    { 0xF24B, "evaluatefobspawns" },
    { 0xF24C, "evaluationcallback" },
    { 0xF24D, "eventcallback" },
    { 0xF24E, "exclude_me" },
    { 0xF24F, "excludedteams" },
    { 0xF250, "execute_combat_action" },
    { 0xF251, "execution_debug" },
    { 0xF252, "execution_obstacle" },
    { 0xF253, "executioncashmultiplier" },
    { 0xF254, "executionquip" },
    { 0xF255, "exfil" },
    { 0xF256, "exfil_clear_objective" },
    { 0xF257, "exfil_enemy_spawning" },
    { 0xF258, "exfil_heli_landing" },
    { 0xF259, "exfil_objective" },
    { 0xF25A, "exfil_regroup_spot" },
    { 0xF25B, "exfil_retreat" },
    { 0xF25C, "exfil_sequence" },
    { 0xF25D, "exfil_smoke_vfx" },
    { 0xF25E, "exfil_spawners_triggered" },
    { 0xF25F, "exfil_spawnfunc" },
    { 0xF260, "exfil_spawning_logic" },
    { 0xF261, "exfil_speed" },
    { 0xF262, "exfil_spots_objs_settings" },
    { 0xF263, "exfilallyturning" },
    { 0xF264, "exfilchopper" },
    { 0xF265, "exfill_chopper_dialogue" },
    { 0xF266, "exfill_vehicle" },
    { 0xF267, "existingkills" },
    { 0xF268, "exit_laser_panel_anim_sequence" },
    { 0xF269, "exit_laststand_usability" },
    { 0xF26A, "exit_level" },
    { 0xF26B, "exit_open" },
    { 0xF26C, "exitdriver" },
    { 0xF26D, "exittype" },
    { 0xF26E, "exitvehicle_oldturnrate" },
    { 0xF26F, "exitvehicledelay" },
    { 0xF270, "expected_card" },
    { 0xF271, "expirationtimer" },
    { 0xF272, "expiredbydeath" },
    { 0xF273, "expiredlootleaderenabled" },
    { 0xF274, "expiredlootleaderinstance" },
    { 0xF275, "expiredlootleadermarks" },
    { 0xF276, "expiredlootleaders" },
    { 0xF277, "exploboltexplode" },
    { 0xF278, "explode_fx" },
    { 0xF279, "exploder_ref" },
    { 0xF27A, "explosion_init" },
    { 0xF27B, "explosionspots" },
    { 0xF27C, "explosive_barrel" },
    { 0xF27D, "explosive_barrels" },
    { 0xF27E, "explosive_cars" },
    { 0xF27F, "explosivemodoverride" },
    { 0xF280, "explozone" },
    { 0xF281, "exposed_node" },
    { 0xF282, "exposed_to_chopper_boss_time" },
    { 0xF283, "extactioncancel" },
    { 0xF284, "extactioncomplete" },
    { 0xF285, "extactionstart" },
    { 0xF286, "extendcirclelist" },
    { 0xF287, "exterior_goal_func" },
    { 0xF288, "extra_bomb_explode_vfx_func" },
    { 0xF289, "extra_collision" },
    { 0xF28A, "extra_delay" },
    { 0xF28B, "extra_enemies" },
    { 0xF28C, "extra_glow_sticks_init" },
    { 0xF28D, "extra_riders_func" },
    { 0xF28E, "extra_riders_getin_anim_func" },
    { 0xF28F, "extra_riders_intro_scene_func" },
    { 0xF290, "extract_dialogue_played" },
    { 0xF291, "extract_ismissionweapon" },
    { 0xF292, "extract_ontimerexpired" },
    { 0xF293, "extract_removemissionweapon" },
    { 0xF294, "extractcallback" },
    { 0xF295, "extractcountdown" },
    { 0xF296, "extractcountdownmsg" },
    { 0xF297, "extractgroundpos" },
    { 0xF298, "extracthelipadusecallback" },
    { 0xF299, "extracthelipadwatchforhelileaving" },
    { 0xF29A, "extracthideiconfromplayer" },
    { 0xF29B, "extracting" },
    { 0xF29C, "extractingplayers" },
    { 0xF29D, "extraction_balloon_num_completed" },
    { 0xF29E, "extraction_balloon_total_plunder" },
    { 0xF29F, "extraction_helicoptor_num_completed" },
    { 0xF2A0, "extraction_helicoptor_total_plunder" },
    { 0xF2A1, "extractioncomplete" },
    { 0xF2A2, "extractionlocation" },
    { 0xF2A3, "extractionlocations" },
    { 0xF2A4, "extractionmethod" },
    { 0xF2A5, "extractiontime" },
    { 0xF2A6, "extractlocale_checkiflocaleisavailable" },
    { 0xF2A7, "extractlocale_circletick" },
    { 0xF2A8, "extractlocale_createquestlocale" },
    { 0xF2A9, "extractlocale_islocaleavailable" },
    { 0xF2AA, "extractlocale_onentergulag" },
    { 0xF2AB, "extractlocale_onrespawn" },
    { 0xF2AC, "extractlocale_removelocaleinstance" },
    { 0xF2AD, "extractmissionhelipadmodel" },
    { 0xF2AE, "extractmissionhelipadscriptable" },
    { 0xF2AF, "extractplayers" },
    { 0xF2B0, "extractplunder" },
    { 0xF2B1, "extractplunderhelihealth" },
    { 0xF2B2, "extractplunderheliinvulnerable" },
    { 0xF2B3, "extractposition" },
    { 0xF2B4, "extractquest_alwaysallowdeposit" },
    { 0xF2B5, "extractquest_helipadid" },
    { 0xF2B6, "extractquest_missionitem" },
    { 0xF2B7, "extractquest_missionweapon" },
    { 0xF2B8, "extractquest_removequestinstance" },
    { 0xF2B9, "extractquest_unlockablelootid" },
    { 0xF2BA, "extractshowicontoplayer" },
    { 0xF2BB, "extractsilentcountdown" },
    { 0xF2BC, "extracttablet_init" },
    { 0xF2BD, "extractthink" },
    { 0xF2BE, "extractunlockablechance" },
    { 0xF2BF, "extractunlockablelootid" },
    { 0xF2C0, "extractupdatehud" },
    { 0xF2C1, "extractupdateicons" },
    { 0xF2C2, "extractupdateiconsframeend" },
    { 0xF2C3, "extrascore4" },
    { 0xF2C4, "extratimeincreasecount" },
    { 0xF2C5, "extratimeincreasecountcap" },
    { 0xF2C6, "extraweapons" },
    { 0xF2C7, "eyeoffnotehandler" },
    { 0xF2C8, "eyeonnotehandler" },
    { 0xF2C9, "f" },
    { 0xF2CA, "f11lights" },
    { 0xF2CB, "f11onarmoryswitchon" },
    { 0xF2CC, "f11scriptlightinit" },
    { 0xF2CD, "f11scriptlighttoggle" },
    { 0xF2CE, "f14_3pastcodes" },
    { 0xF2CF, "f14_current_inputamt" },
    { 0xF2D0, "f14_current_inputseq" },
    { 0xF2D1, "f14_keypadnumstr" },
    { 0xF2D2, "faceenemyspawn" },
    { 0xF2D3, "facial_clear" },
    { 0xF2D4, "fade_cover" },
    { 0xF2D5, "fadeoutinspectatorsofplayer" },
    { 0xF2D6, "fadeoutoverlay" },
    { 0xF2D7, "fadeoverlay" },
    { 0xF2D8, "fadetoblackforxsec" },
    { 0xF2D9, "fadetogearingup" },
    { 0xF2DA, "fail_mission_if_killed" },
    { 0xF2DB, "fail_on_transmission_timeout" },
    { 0xF2DC, "failcollectionquest" },
    { 0xF2DD, "failedmission" },
    { 0xF2DE, "failedtext" },
    { 0xF2DF, "failhistoryquest" },
    { 0xF2E0, "failsafe_door_breach_frozen" },
    { 0xF2E1, "failsafe_door_breach_frozen_player" },
    { 0xF2E2, "failsafe_triggered" },
    { 0xF2E3, "failsecretstashquest" },
    { 0xF2E4, "failsmokinggunquest" },
    { 0xF2E5, "failstringsetup" },
    { 0xF2E6, "failtimedrunquest" },
    { 0xF2E7, "failx1finquest" },
    { 0xF2E8, "failx1stashquest" },
    { 0xF2E9, "fake_agent_model_setup" },
    { 0xF2EA, "fake_digit_pool" },
    { 0xF2EB, "fake_exploder" },
    { 0xF2EC, "fake_hit_target_monitor" },
    { 0xF2ED, "fake_magic_grenade_kill_watch" },
    { 0xF2EE, "fake_magic_grenade_watch" },
    { 0xF2EF, "fake_magic_grenade_watch_individual" },
    { 0xF2F0, "fake_model" },
    { 0xF2F1, "fake_trigger_think" },
    { 0xF2F2, "fakeprops" },
    { 0xF2F3, "fallback_index" },
    { 0xF2F4, "falling_xyratio" },
    { 0xF2F5, "fananim" },
    { 0xF2F6, "farah_disable_ai_color_before_hallway_takedown" },
    { 0xF2F7, "farah_nobraids_body" },
    { 0xF2F8, "farah_nobraids_body_reset" },
    { 0xF2F9, "farah_says_cut_wire_green" },
    { 0xF2FA, "farah_says_cut_wire_red" },
    { 0xF2FB, "farah_says_cut_wire_yellow" },
    { 0xF2FC, "farms2_gw_ambient_sound_load" },
    { 0xF2FD, "farobjectiveiconid" },
    { 0xF2FE, "fast_revive_time" },
    { 0xF2FF, "fast_rope_over_black" },
    { 0xF300, "ffsm_introsetup" },
    { 0xF301, "ffsm_isgulagrespawn" },
    { 0xF302, "ffsm_landed_stateenter" },
    { 0xF303, "ffsm_nextstreamhinttime" },
    { 0xF304, "ffsm_onground_stateenter" },
    { 0xF305, "ffsm_parachuteopen_stateenter" },
    { 0xF306, "ffsm_skydive_stateenter" },
    { 0xF307, "ffsm_state" },
    { 0xF308, "fiftypercent_music" },
    { 0xF309, "fight_on_jammer_2_bridge" },
    { 0xF30A, "fillmaxarmorplate" },
    { 0xF30B, "filtervehiclespawnstructs" },
    { 0xF30C, "filtervehiclespawnstructsfunc" },
    { 0xF30D, "final_radius_think" },
    { 0xF30E, "final_switch_think" },
    { 0xF30F, "final_wave" },
    { 0xF310, "finale" },
    { 0xF311, "finale_main" },
    { 0xF312, "finale_setup" },
    { 0xF313, "finalkillcamplaybackbegin" },
    { 0xF314, "finalsurvivorcount" },
    { 0xF315, "finalthreeuav" },
    { 0xF316, "find_ai_spawner" },
    { 0xF317, "find_and_run_elevator_spawngroup" },
    { 0xF318, "find_free_drop_location" },
    { 0xF319, "find_plunder" },
    { 0xF31A, "find_supply_station" },
    { 0xF31B, "findanyaliveplayer" },
    { 0xF31C, "findavailableteam" },
    { 0xF31D, "findclearflightyaw" },
    { 0xF31E, "findenemytype" },
    { 0xF31F, "findeventforchosenweight" },
    { 0xF320, "findfirstaliveplayer" },
    { 0xF321, "findgunsmithattachments" },
    { 0xF322, "findloadoutperks" },
    { 0xF323, "findminmaxangleovertime" },
    { 0xF324, "findnewplunderextractsite" },
    { 0xF325, "findquestplacement" },
    { 0xF326, "findteamwithnoplayers" },
    { 0xF327, "findvalidspectateprop" },
    { 0xF328, "fine_drop_pos" },
    { 0xF329, "finish" },
    { 0xF32A, "finishlinevfx" },
    { 0xF32B, "finishreviveplayer" },
    { 0xF32C, "fire_a_rocket_to_target" },
    { 0xF32D, "fire_minigun" },
    { 0xF32E, "fire_rate" },
    { 0xF32F, "fire_rockets_to_target" },
    { 0xF330, "fire_rpg_to_target" },
    { 0xF331, "fire_sfx_org" },
    { 0xF332, "fired_missiles" },
    { 0xF333, "fireoffsplashforplayer" },
    { 0xF334, "firesalediscount" },
    { 0xF335, "firesaleforplayers" },
    { 0xF336, "firespoutwatch" },
    { 0xF337, "firestation_jugg_spawn" },
    { 0xF338, "firestation_jugg_test" },
    { 0xF339, "firing_start_locs" },
    { 0xF33A, "first_bleedout" },
    { 0xF33B, "first_convoy" },
    { 0xF33C, "first_convoy_lmgs" },
    { 0xF33D, "first_interaction" },
    { 0xF33E, "first_move" },
    { 0xF33F, "first_pressure_switch_triggered" },
    { 0xF340, "first_switch" },
    { 0xF341, "first_time" },
    { 0xF342, "firstinfectedsplash" },
    { 0xF343, "firstteam" },
    { 0xF344, "fivecontracts" },
    { 0xF345, "fix_badcover_atend" },
    { 0xF346, "fix_collision" },
    { 0xF347, "fix_collisiontwo" },
    { 0xF348, "fix_door_clip" },
    { 0xF349, "fix_wall_traversal" },
    { 0xF34A, "fixcollision" },
    { 0xF34B, "fixsuperforbr" },
    { 0xF34C, "fixuppickuporigin" },
    { 0xF34D, "fixupscriptableorigin" },
    { 0xF34E, "fixupsupersandtacticalsforgunfightmaps" },
    { 0xF34F, "fixuptrigspostship" },
    { 0xF350, "flag0" },
    { 0xF351, "flag1" },
    { 0xF352, "flag_bot_attacker_limit_for_team" },
    { 0xF353, "flag_bot_defender_limit_for_team" },
    { 0xF354, "flag_num_players_on_team" },
    { 0xF355, "flag_on_vip_cash_collect" },
    { 0xF356, "flag_progression" },
    { 0xF357, "flag_set_role" },
    { 0xF358, "flagactivationdelay" },
    { 0xF359, "flagattachradar" },
    { 0xF35A, "flagender" },
    { 0xF35B, "flaglockedtimer" },
    { 0xF35C, "flagonexit" },
    { 0xF35D, "flagonrevive" },
    { 0xF35E, "flagpickupchecks" },
    { 0xF35F, "flagradarmover" },
    { 0xF360, "flagwatchradarownerlost" },
    { 0xF361, "flame_emitter" },
    { 0xF362, "flare_activated" },
    { 0xF363, "flare_setup" },
    { 0xF364, "flare_thread" },
    { 0xF365, "flarecooldown" },
    { 0xF366, "flareready" },
    { 0xF367, "flares" },
    { 0xF368, "flares_from_structs" },
    { 0xF369, "flash_crate_player_at_max_ammo" },
    { 0xF36A, "flash_crate_spawn" },
    { 0xF36B, "flash_crate_update_hint_logic_alt" },
    { 0xF36C, "flash_crate_use" },
    { 0xF36D, "flash_group" },
    { 0xF36E, "flash_icon_extraction" },
    { 0xF36F, "flashbang_ai" },
    { 0xF370, "flashenemies" },
    { 0xF371, "flashentercode" },
    { 0xF372, "flashimmune" },
    { 0xF373, "flashing_lives_screens" },
    { 0xF374, "flashlockpropkey" },
    { 0xF375, "flashtheprops" },
    { 0xF376, "flickerlights" },
    { 0xF377, "flightyaw" },
    { 0xF378, "flip_target" },
    { 0xF379, "flip_time" },
    { 0xF37A, "flood_spawn_till_flag" },
    { 0xF37B, "floor1lights" },
    { 0xF37C, "floor2lights" },
    { 0xF37D, "floor_gas" },
    { 0xF37E, "fluctuatevalues" },
    { 0xF37F, "fly_over_path" },
    { 0xF380, "fly_over_start" },
    { 0xF381, "fly_path" },
    { 0xF382, "fly_to_end_point" },
    { 0xF383, "fly_to_laser_trap_start_pos" },
    { 0xF384, "fly_to_loc" },
    { 0xF385, "fly_to_node" },
    { 0xF386, "fly_toward_retreat_struct" },
    { 0xF387, "flytime" },
    { 0xF388, "fn_damage_pack" },
    { 0xF389, "fn_spec_op_post_customization" },
    { 0xF38A, "fnanimatedprop_setanim" },
    { 0xF38B, "fnanimatedprop_setup" },
    { 0xF38C, "fnanimatedprop_startanim" },
    { 0xF38D, "fnchildscorefunc" },
    { 0xF38E, "fndropweapon" },
    { 0xF38F, "fngetplayerdrone" },
    { 0xF390, "fnhidefoundintel" },
    { 0xF391, "fnlookforvehicles" },
    { 0xF392, "fnoffhandfire" },
    { 0xF393, "fntrapactivation" },
    { 0xF394, "fntrapdeactivation" },
    { 0xF395, "fob" },
    { 0xF396, "fob_bombs" },
    { 0xF397, "fob_think" },
    { 0xF398, "focus_fire_attacker_timeout" },
    { 0xF399, "focus_fire_attackers" },
    { 0xF39A, "focus_fire_headicon" },
    { 0xF39B, "focus_fire_icon_delete_think" },
    { 0xF39C, "focus_fire_icon_objective_id" },
    { 0xF39D, "focus_fire_is_activated" },
    { 0xF39E, "focus_fire_outline_enabled" },
    { 0xF39F, "focus_fire_outline_id" },
    { 0xF3A0, "fogenabled" },
    { 0xF3A1, "follow_players_when_close" },
    { 0xF3A2, "footprint_mask_clipheight" },
    { 0xF3A3, "forbiddencachespawns" },
    { 0xF3A4, "force_ai_to_drop_thermites" },
    { 0xF3A5, "force_bleedout_all_downed_players" },
    { 0xF3A6, "force_call_lz" },
    { 0xF3A7, "force_dismount" },
    { 0xF3A8, "force_group_thermites" },
    { 0xF3A9, "force_interrupt_all_current_combat_actions" },
    { 0xF3AA, "force_interrupt_current_combat_action" },
    { 0xF3AB, "force_kill_off_other_ai" },
    { 0xF3AC, "force_maze_ai_state" },
    { 0xF3AD, "force_players_out_of_vehicle" },
    { 0xF3AE, "force_remove_stim" },
    { 0xF3AF, "force_spawn_all_dead_players" },
    { 0xF3B0, "force_teleport_downedplayer" },
    { 0xF3B1, "force_teleport_player_into_plane" },
    { 0xF3B2, "force_thermites" },
    { 0xF3B3, "force_var_to_array" },
    { 0xF3B4, "forceabshotfoot" },
    { 0xF3B5, "forcearmordropondeath" },
    { 0xF3B6, "forced_aitype_armored" },
    { 0xF3B7, "forced_aitypes" },
    { 0xF3B8, "forced_bleedout" },
    { 0xF3B9, "forced_kill_off" },
    { 0xF3BA, "forced_laststand_weapon" },
    { 0xF3BB, "forced_revive" },
    { 0xF3BC, "forcedisablelaststand" },
    { 0xF3BD, "forceexplosivedeath" },
    { 0xF3BE, "forceextractscriptable" },
    { 0xF3BF, "forcefail" },
    { 0xF3C0, "forcegivekillstreak" },
    { 0xF3C1, "forcehideottimer" },
    { 0xF3C2, "forcejumpnearobjective" },
    { 0xF3C3, "forceotlogictorun" },
    { 0xF3C4, "forcestuckdamage" },
    { 0xF3C5, "forcestuckdamageclear" },
    { 0xF3C6, "forceunsetdemeanor" },
    { 0xF3C7, "forest_barrel_damage_watch" },
    { 0xF3C8, "forest_barrels" },
    { 0xF3C9, "forest_combat" },
    { 0xF3CA, "forest_fire_setup" },
    { 0xF3CB, "frag_crate_player_at_max_ammo" },
    { 0xF3CC, "frag_crate_spawn" },
    { 0xF3CD, "frag_crate_use" },
    { 0xF3CE, "free_landing_spots" },
    { 0xF3CF, "freefall_start" },
    { 0xF3D0, "freefallfromplanestatemachine" },
    { 0xF3D1, "freeze_bomb_case_timer" },
    { 0xF3D2, "freeze_bomb_vest_timer" },
    { 0xF3D3, "freeze_timer_at_max_time_bomb_case" },
    { 0xF3D4, "freeze_timer_at_max_time_bomb_vest" },
    { 0xF3D5, "freight_lift" },
    { 0xF3D6, "freight_lift_attacker" },
    { 0xF3D7, "freight_lift_attacker_internal" },
    { 0xF3D8, "freight_lift_build" },
    { 0xF3D9, "freight_lift_button_activation" },
    { 0xF3DA, "freight_lift_combat" },
    { 0xF3DB, "freight_lift_dogtag_revive" },
    { 0xF3DC, "freight_lift_door_switch" },
    { 0xF3DD, "freight_lift_run" },
    { 0xF3DE, "freight_lift_waittill_occupied" },
    { 0xF3DF, "freight_lift_waittill_progress" },
    { 0xF3E0, "fridgeusethink" },
    { 0xF3E1, "friendly_convoy_intro_decho_idle_animation" },
    { 0xF3E2, "friendly_dmg_text_cooldown" },
    { 0xF3E3, "friendly_exit" },
    { 0xF3E4, "friendly_hvi_vehicle_extra_riders" },
    { 0xF3E5, "friendly_hvi_vehicle_extra_riders_getin_scene" },
    { 0xF3E6, "friendly_hvi_vehicle_extra_riders_intro_scene" },
    { 0xF3E7, "friendlyfire_allowed" },
    { 0xF3E8, "friendlyfiredeath" },
    { 0xF3E9, "friendlyicon" },
    { 0xF3EA, "friendlystatuschangedcallback" },
    { 0xF3EB, "friendlystatusdirty" },
    { 0xF3EC, "from" },
    { 0xF3ED, "front_struct" },
    { 0xF3EE, "front_vector" },
    { 0xF3EF, "frontend4" },
    { 0xF3F0, "frontend5lobby" },
    { 0xF3F1, "fronttruck" },
    { 0xF3F2, "fuckwithgravity" },
    { 0xF3F3, "fuel_stability_event_init" },
    { 0xF3F4, "fuel_stability_event_start" },
    { 0xF3F5, "fuelsequencestability" },
    { 0xF3F6, "fullweaponname" },
    { 0xF3F7, "fullweaponobj" },
    { 0xF3F8, "fulton" },
    { 0xF3F9, "fulton_ac130_model" },
    { 0xF3FA, "fulton_actors" },
    { 0xF3FB, "fulton_actors_players" },
    { 0xF3FC, "fulton_cancreate" },
    { 0xF3FD, "fulton_check_for_moving_platform" },
    { 0xF3FE, "fulton_crate_model_playclosedidle" },
    { 0xF3FF, "fulton_create" },
    { 0xF400, "fulton_deletenextframe" },
    { 0xF401, "fulton_destroy" },
    { 0xF402, "fulton_exfil_model" },
    { 0xF403, "fulton_handledamage" },
    { 0xF404, "fulton_handlefataldamage" },
    { 0xF405, "fulton_hostage_vo" },
    { 0xF406, "fulton_hostageent" },
    { 0xF407, "fulton_init" },
    { 0xF408, "fulton_initanims" },
    { 0xF409, "fulton_initrepository" },
    { 0xF40A, "fulton_interactions_disabled" },
    { 0xF40B, "fulton_open" },
    { 0xF40C, "fulton_openidle" },
    { 0xF40D, "fulton_planted" },
    { 0xF40E, "fulton_refundsuper" },
    { 0xF40F, "fulton_repositoryatcapacitycallback" },
    { 0xF410, "fulton_repositorycountdownendcallback" },
    { 0xF411, "fulton_repositoryextractcallback" },
    { 0xF412, "fulton_repositoryusecallback" },
    { 0xF413, "fulton_used" },
    { 0xF414, "func_load_difficulty_table" },
    { 0xF415, "fusefx" },
    { 0xF416, "fuselit" },
    { 0xF417, "fusesound" },
    { 0xF418, "fx_ent_index" },
    { 0xF419, "fx_ents" },
    { 0xF41A, "fx_model" },
    { 0xF41B, "fx_obj" },
    { 0xF41C, "fx_thermal" },
    { 0xF41D, "fx_thermal_end" },
    { 0xF41E, "fxangles" },
    { 0xF41F, "fxent2" },
    { 0xF420, "fxgreen" },
    { 0xF421, "fxorigin" },
    { 0xF422, "fxorigintag" },
    { 0xF423, "fxorigintagb" },
    { 0xF424, "fxred" },
    { 0xF425, "fxrings" },
    { 0xF426, "g" },
    { 0xF427, "game_end_watcher" },
    { 0xF428, "gameendfreezemovement" },
    { 0xF429, "gameending" },
    { 0xF42A, "gameflagexists" },
    { 0xF42B, "gameisending" },
    { 0xF42C, "gamemodemolotovfunc" },
    { 0xF42D, "gamemodeoverridemeleeviewkickscale" },
    { 0xF42E, "gamemodeoverriderestockrechargeperupdate" },
    { 0xF42F, "gamemodespawnprotectedcallback" },
    { 0xF430, "gameplay_main" },
    { 0xF431, "gameskill_init" },
    { 0xF432, "gameskill_set_player" },
    { 0xF433, "gamestatedisplaymonitor" },
    { 0xF434, "gametypefilter" },
    { 0xF435, "gametypekillsperhouravg" },
    { 0xF436, "gametypekillspermatchmax" },
    { 0xF437, "gametypeoverrideassassinsearchparams" },
    { 0xF438, "gametypeoverridedomsearchparams" },
    { 0xF439, "gametypeoverridescavsearchparams" },
    { 0xF43A, "gametyperoundendscoresetomnvar" },
    { 0xF43B, "gametypeweaponxpmodifier" },
    { 0xF43C, "garbage_bin_clip" },
    { 0xF43D, "gas_at_computer" },
    { 0xF43E, "gas_attack" },
    { 0xF43F, "gas_attack_deploy" },
    { 0xF440, "gas_badplace" },
    { 0xF441, "gas_cloud_vfx" },
    { 0xF442, "gas_emit_vfx" },
    { 0xF443, "gas_flyby_plane" },
    { 0xF444, "gas_fx" },
    { 0xF445, "gas_linger_large_vfx" },
    { 0xF446, "gas_linger_vfx" },
    { 0xF447, "gas_payloads" },
    { 0xF448, "gas_sequence_activated" },
    { 0xF449, "gas_trap_cloud_structs" },
    { 0xF44A, "gas_trap_damage_trigger" },
    { 0xF44B, "gas_trap_structs" },
    { 0xF44C, "gas_trap_weapon" },
    { 0xF44D, "gas_trigger" },
    { 0xF44E, "gas_trigger_player_think" },
    { 0xF44F, "gas_trigger_think" },
    { 0xF450, "gas_triggers_init" },
    { 0xF451, "gas_tryplaycoughaudio" },
    { 0xF452, "gas_vfx_and_triggers" },
    { 0xF453, "gas_vfx_range_think" },
    { 0xF454, "gasfx" },
    { 0xF455, "gasfxair" },
    { 0xF456, "gasfxground" },
    { 0xF457, "gasgrenade_crate_player_at_max_ammo" },
    { 0xF458, "gasgrenade_crate_spawn" },
    { 0xF459, "gasgrenade_crate_use" },
    { 0xF45A, "gasmask_onpickupcreated" },
    { 0xF45B, "gasmask_resist" },
    { 0xF45C, "gasmaskcarryinfo" },
    { 0xF45D, "gasmaskhealthperpip" },
    { 0xF45E, "gasmaskmaxhealth" },
    { 0xF45F, "gasmasktype" },
    { 0xF460, "gasmodel" },
    { 0xF461, "gastrap_dmg_trig" },
    { 0xF462, "gastrapstruct" },
    { 0xF463, "gasvfxstructs" },
    { 0xF464, "gate_closes" },
    { 0xF465, "gate_flares_think" },
    { 0xF466, "gate_swings_open" },
    { 0xF467, "gates_combat" },
    { 0xF468, "gates_puzzle" },
    { 0xF469, "gatherstadiumlocs" },
    { 0xF46A, "gcd" },
    { 0xF46B, "generate_achievementid" },
    { 0xF46C, "generate_bomb_wire_list" },
    { 0xF46D, "generate_cypher" },
    { 0xF46E, "generate_grenade_types_via_dvar" },
    { 0xF46F, "generate_randomized_primary_weapon_objs" },
    { 0xF470, "generate_solution" },
    { 0xF471, "generatecodestoshow" },
    { 0xF472, "generatenumbercode" },
    { 0xF473, "generatenumbercode_array" },
    { 0xF474, "generatespawnpoint" },
    { 0xF475, "generic_waittill_button_press" },
    { 0xF476, "genuine_cypher_pieces" },
    { 0xF477, "gesture_checker" },
    { 0xF478, "get_active_bombzones" },
    { 0xF479, "get_active_station_names" },
    { 0xF47A, "get_actor_stance" },
    { 0xF47B, "get_actual_grenade_name" },
    { 0xF47C, "get_ai_hearing_bomb_plant_sound" },
    { 0xF47D, "get_ai_spawner" },
    { 0xF47E, "get_ai_within_range" },
    { 0xF47F, "get_aitypes_and_weights_from_call_counter" },
    { 0xF480, "get_alertreset_alias" },
    { 0xF481, "get_alive_able_players" },
    { 0xF482, "get_alive_bots" },
    { 0xF483, "get_alive_nonspecating_players" },
    { 0xF484, "get_alive_players" },
    { 0xF485, "get_all_doors_ai_should_open" },
    { 0xF486, "get_all_players_enemy_info" },
    { 0xF487, "get_all_players_enemy_info_new" },
    { 0xF488, "get_allowed_population" },
    { 0xF489, "get_allowed_vehicle_types_from_spawnpoint" },
    { 0xF48A, "get_allowed_vehicle_types_from_wave" },
    { 0xF48B, "get_allykilled_alias" },
    { 0xF48C, "get_alt_weapon" },
    { 0xF48D, "get_any_player_has_respawn" },
    { 0xF48E, "get_any_player_spectating" },
    { 0xF48F, "get_area_clear_alias" },
    { 0xF490, "get_armsrace_interaction_loc" },
    { 0xF491, "get_associated_keycard" },
    { 0xF492, "get_audio_approved_length_extender_for_non_english_vo" },
    { 0xF493, "get_available_unique_id" },
    { 0xF494, "get_axis_vehicles" },
    { 0xF495, "get_base_focus_fire_multipler" },
    { 0xF496, "get_baseaccuracy" },
    { 0xF497, "get_battle_station_combat_action_default" },
    { 0xF498, "get_bcrumbstruct_proximity" },
    { 0xF499, "get_best_goal_closest_to_any_player" },
    { 0xF49A, "get_best_goal_position" },
    { 0xF49B, "get_best_heli_struct" },
    { 0xF49C, "get_bomb_case_omnvar_value_based_on_color" },
    { 0xF49D, "get_bomb_icon_on_cell_phone_func" },
    { 0xF49E, "get_bomb_interaction_ent_cut_hint" },
    { 0xF49F, "get_bomb_vest_id_vfx" },
    { 0xF4A0, "get_bombzone_node_to_defuse_on" },
    { 0xF4A1, "get_bombzone_node_to_plant_on" },
    { 0xF4A2, "get_bonus_targets" },
    { 0xF4A3, "get_br_jugg_setting" },
    { 0xF4A4, "get_bulletwhizby_alias" },
    { 0xF4A5, "get_car_stop_struct" },
    { 0xF4A6, "get_carry_item_omnvar" },
    { 0xF4A7, "get_cave_combat_logic" },
    { 0xF4A8, "get_center_loc_among_target_players" },
    { 0xF4A9, "get_checking_area_alias" },
    { 0xF4AA, "get_chopper_boss_combat_action" },
    { 0xF4AB, "get_chopper_minigun_start_node" },
    { 0xF4AC, "get_chopperexfil_transient" },
    { 0xF4AD, "get_circle_back_nodes_on_same_side" },
    { 0xF4AE, "get_circle_back_start_node" },
    { 0xF4AF, "get_closest_attackable_player" },
    { 0xF4B0, "get_closest_available_player_new" },
    { 0xF4B1, "get_closest_destination" },
    { 0xF4B2, "get_closest_enemy_near_turret" },
    { 0xF4B3, "get_closest_living_player_not_in_laststand" },
    { 0xF4B4, "get_closest_munitions" },
    { 0xF4B5, "get_closest_origin_index" },
    { 0xF4B6, "get_closest_player_dist" },
    { 0xF4B7, "get_closest_spawns" },
    { 0xF4B8, "get_closest_unclaimed_destination" },
    { 0xF4B9, "get_closest_valid_player" },
    { 0xF4BA, "get_closest_visible_drone" },
    { 0xF4BB, "get_combat_action" },
    { 0xF4BC, "get_combat_alias" },
    { 0xF4BD, "get_combat_station_next_combat_action" },
    { 0xF4BE, "get_comp_dist_for_info_loop" },
    { 0xF4BF, "get_connected_nodes_targetname_array" },
    { 0xF4C0, "get_consecutive_def" },
    { 0xF4C1, "get_control_station_side_array" },
    { 0xF4C2, "get_convoy_vehicle_get_in_scene_name" },
    { 0xF4C3, "get_corpse_array" },
    { 0xF4C4, "get_correct_bomb_wire_pair" },
    { 0xF4C5, "get_coverblown_alias" },
    { 0xF4C6, "get_cumulative_damage_expire_time" },
    { 0xF4C7, "get_current_ai_cap" },
    { 0xF4C8, "get_current_armor_ammo" },
    { 0xF4C9, "get_current_building_obj_struct" },
    { 0xF4CA, "get_current_bush_zone" },
    { 0xF4CB, "get_current_station_signage_structs" },
    { 0xF4CC, "get_cypher_verbal_string_from_id" },
    { 0xF4CD, "get_defuse_time" },
    { 0xF4CE, "get_depletion_delay" },
    { 0xF4CF, "get_depletion_rate" },
    { 0xF4D0, "get_destination_in_current_circle" },
    { 0xF4D1, "get_destinations_in_current_circle" },
    { 0xF4D2, "get_difficulty_for_difficulty_type" },
    { 0xF4D3, "get_dist_to_closest_player" },
    { 0xF4D4, "get_distance_to_closest_teammate" },
    { 0xF4D5, "get_driver_interaction_hint_string" },
    { 0xF4D6, "get_drone_movement_vector" },
    { 0xF4D7, "get_drone_target_loc" },
    { 0xF4D8, "get_drop_location" },
    { 0xF4D9, "get_dropkit_price" },
    { 0xF4DA, "get_dropoff_point_spawner" },
    { 0xF4DB, "get_emp_effect_duration" },
    { 0xF4DC, "get_end_ang" },
    { 0xF4DD, "get_ending_struct" },
    { 0xF4DE, "get_enter_leave_station_time" },
    { 0xF4DF, "get_evade_start_structs_in_front" },
    { 0xF4E0, "get_explosion_alias" },
    { 0xF4E1, "get_extra_focus_fire_multipler" },
    { 0xF4E2, "get_fake_digit_from_pool" },
    { 0xF4E3, "get_farthest_living_player_not_in_laststand" },
    { 0xF4E4, "get_focus_fire_damage_multiplier" },
    { 0xF4E5, "get_focus_fire_icon_image" },
    { 0xF4E6, "get_focus_fire_multipler" },
    { 0xF4E7, "get_footstep_alias" },
    { 0xF4E8, "get_footstepsprint_alias" },
    { 0xF4E9, "get_force_push_direction" },
    { 0xF4EA, "get_forest_combat_logic" },
    { 0xF4EB, "get_freight_lift_spawnpoints" },
    { 0xF4EC, "get_friendly_convoy_vehicle" },
    { 0xF4ED, "get_gas_martyr_grenade_types" },
    { 0xF4EE, "get_goal_radius" },
    { 0xF4EF, "get_grenade_force" },
    { 0xF4F0, "get_grenade_fuse_time" },
    { 0xF4F1, "get_grenade_settings_from_group" },
    { 0xF4F2, "get_grenadedanger_alias" },
    { 0xF4F3, "get_ground_normal" },
    { 0xF4F4, "get_guilty_player_name" },
    { 0xF4F5, "get_gunshot_alias" },
    { 0xF4F6, "get_gunshotteammate_alias" },
    { 0xF4F7, "get_has_combined_counters_alias" },
    { 0xF4F8, "get_health_multiplier_relic_mythic" },
    { 0xF4F9, "get_health_stage" },
    { 0xF4FA, "get_heli_intro_vo" },
    { 0xF4FB, "get_heli_structs" },
    { 0xF4FC, "get_highest_priority_goal_position" },
    { 0xF4FD, "get_hover_attack_direction" },
    { 0xF4FE, "get_huntfirstlost_alias" },
    { 0xF4FF, "get_id_based_on_task" },
    { 0xF500, "get_intel_location_vo" },
    { 0xF501, "get_intel_pickup_vo" },
    { 0xF502, "get_intel_ref" },
    { 0xF503, "get_intermission_time" },
    { 0xF504, "get_invalid_seats_from_module_struct" },
    { 0xF505, "get_investigate_alias" },
    { 0xF506, "get_landing_spots_in_current_circle" },
    { 0xF507, "get_laser_combat_logic" },
    { 0xF508, "get_last_callout_time" },
    { 0xF509, "get_last_stand_id" },
    { 0xF50A, "get_least_used_node_close_to_pos" },
    { 0xF50B, "get_length_from_table" },
    { 0xF50C, "get_linked_struct_with_script_noteworthy" },
    { 0xF50D, "get_linked_structs_with_script_noteworthy" },
    { 0xF50E, "get_living_agent_count" },
    { 0xF50F, "get_living_agents" },
    { 0xF510, "get_lostsight_alias" },
    { 0xF511, "get_martyrdom_grenade_types" },
    { 0xF512, "get_max_ai_from_infil_name" },
    { 0xF513, "get_max_ai_per_site" },
    { 0xF514, "get_max_charges" },
    { 0xF515, "get_max_from_call_count" },
    { 0xF516, "get_minigun_path" },
    { 0xF517, "get_model_for_color_wire_cut" },
    { 0xF518, "get_module_call_count" },
    { 0xF519, "get_module_struct_from_level" },
    { 0xF51A, "get_mortar_targets" },
    { 0xF51B, "get_most_recent_danger_ping" },
    { 0xF51C, "get_most_recent_location_ping" },
    { 0xF51D, "get_most_recent_ping" },
    { 0xF51E, "get_moves_till_stop" },
    { 0xF51F, "get_nearby_enemy_in_tvstation" },
    { 0xF520, "get_nearest_point_near_objective" },
    { 0xF521, "get_new_wire_look_at_marker_currently_looking_at" },
    { 0xF522, "get_next_available_wire_for_bomb" },
    { 0xF523, "get_next_cypher_id_from_pool" },
    { 0xF524, "get_next_open_stop" },
    { 0xF525, "get_next_rein_group" },
    { 0xF526, "get_next_spawn_index" },
    { 0xF527, "get_next_station_on_track" },
    { 0xF528, "get_next_station_on_track_after_index" },
    { 0xF529, "get_next_track_index" },
    { 0xF52A, "get_node_closest_to_target_loc" },
    { 0xF52B, "get_num_dogtag_in_kill_zone_or_under_bridge_zone" },
    { 0xF52C, "get_num_of_valid_players" },
    { 0xF52D, "get_num_of_wire_to_cut" },
    { 0xF52E, "get_objective_label" },
    { 0xF52F, "get_offset_from_stance" },
    { 0xF530, "get_omnvar_value_based_on_bomb_label" },
    { 0xF531, "get_other_active_zone" },
    { 0xF532, "get_paired_bombvest_chair" },
    { 0xF533, "get_pathstruct" },
    { 0xF534, "get_pavelow_boss_info" },
    { 0xF535, "get_pipe_room_spawnpoint" },
    { 0xF536, "get_player_aggro_score" },
    { 0xF537, "get_player_array" },
    { 0xF538, "get_player_closest_to_any_goal" },
    { 0xF539, "get_player_cumulative_damage" },
    { 0xF53A, "get_player_defusing_zone" },
    { 0xF53B, "get_player_drone" },
    { 0xF53C, "get_player_enemy" },
    { 0xF53D, "get_player_info_proc" },
    { 0xF53E, "get_player_munition_currency" },
    { 0xF53F, "get_player_planting_zone" },
    { 0xF540, "get_player_recent_pos_adjusted_with_exposure" },
    { 0xF541, "get_player_velo_array" },
    { 0xF542, "get_player_who_most_likely_broke_stealth" },
    { 0xF543, "get_player_who_most_recently_fired_weapon" },
    { 0xF544, "get_player_who_most_recently_threw_grenade" },
    { 0xF545, "get_players_at_zone" },
    { 0xF546, "get_players_in_mortar_range" },
    { 0xF547, "get_players_inside_the_plane" },
    { 0xF548, "get_players_not_targeted_by_other_battle_station" },
    { 0xF549, "get_positions_around_vector" },
    { 0xF54A, "get_power_charges_in_slot" },
    { 0xF54B, "get_power_max_charge_in_slot" },
    { 0xF54C, "get_power_name_in_slot" },
    { 0xF54D, "get_power_ref_from_weapon" },
    { 0xF54E, "get_precision_use_parameters" },
    { 0xF54F, "get_priority_player" },
    { 0xF550, "get_prohibited_weapons_back" },
    { 0xF551, "get_proximity_alias" },
    { 0xF552, "get_push_force_direction" },
    { 0xF553, "get_random_circle_direction" },
    { 0xF554, "get_random_impact_point" },
    { 0xF555, "get_random_impact_point_on_line" },
    { 0xF556, "get_random_leftover_letter" },
    { 0xF557, "get_random_notnegative" },
    { 0xF558, "get_random_primary_weapon_obj" },
    { 0xF559, "get_random_search_node" },
    { 0xF55A, "get_random_starting_station_name_on_track" },
    { 0xF55B, "get_random_station_names_on_track" },
    { 0xF55C, "get_randomize_bomb_label_list" },
    { 0xF55D, "get_recent_spawn_time_threshold" },
    { 0xF55E, "get_recently_shot_at_by_rpg" },
    { 0xF55F, "get_reinforcement_icon_image" },
    { 0xF560, "get_remaining_bots" },
    { 0xF561, "get_request_backup_alias" },
    { 0xF562, "get_respawning_players" },
    { 0xF563, "get_rid_of_minigun" },
    { 0xF564, "get_rpg_location_z_offset" },
    { 0xF565, "get_rpg_weapon" },
    { 0xF566, "get_rpg_weapon_def" },
    { 0xF567, "get_russian_code_from_id" },
    { 0xF568, "get_safe_set_spawn_weapons" },
    { 0xF569, "get_search_node_closest_to_spotlight_goal_node" },
    { 0xF56A, "get_search_node_closest_to_target_loc" },
    { 0xF56B, "get_search_turret_target_player" },
    { 0xF56C, "get_shootable_scriptables" },
    { 0xF56D, "get_showing_bomb_wire_pair_to_player" },
    { 0xF56E, "get_sight_alias" },
    { 0xF56F, "get_sight_dist_for_laststand_check" },
    { 0xF570, "get_sight_dist_for_taccover_check" },
    { 0xF571, "get_sight_dist_for_vehicle_check" },
    { 0xF572, "get_silencedshot_alias" },
    { 0xF573, "get_silo_jump_spawnpoint" },
    { 0xF574, "get_silo_thrust_spawnpoint" },
    { 0xF575, "get_smallest_cumulative_damage" },
    { 0xF576, "get_smoke_grenade_start_pos" },
    { 0xF577, "get_spaced_out_station_names_on_track" },
    { 0xF578, "get_spawn_delay" },
    { 0xF579, "get_spawncount_from_groupnames" },
    { 0xF57A, "get_specific_truck" },
    { 0xF57B, "get_spotlight_goal_node" },
    { 0xF57C, "get_start_ang" },
    { 0xF57D, "get_starting_ai_per_site" },
    { 0xF57E, "get_station_controller_struct" },
    { 0xF57F, "get_station_index_in_active_stations" },
    { 0xF580, "get_station_index_on_track" },
    { 0xF581, "get_station_names_on_track" },
    { 0xF582, "get_station_track_available_time_stamp" },
    { 0xF583, "get_stay_at_station_time" },
    { 0xF584, "get_stealth_alert_music_alias" },
    { 0xF585, "get_stealth_breaking_guilty_player_name" },
    { 0xF586, "get_stealth_broken_music_alias" },
    { 0xF587, "get_strafe_target_loc" },
    { 0xF588, "get_subway_car_available_to_deploy" },
    { 0xF589, "get_subway_train_hit_damage" },
    { 0xF58A, "get_subway_train_hit_damage_multiplier" },
    { 0xF58B, "get_successful_vehicle_spawns_from_module" },
    { 0xF58C, "get_surface_point" },
    { 0xF58D, "get_swivel_spawnpoint" },
    { 0xF58E, "get_tag_to_target" },
    { 0xF58F, "get_target_group" },
    { 0xF590, "get_target_located" },
    { 0xF591, "get_target_retreat_struct" },
    { 0xF592, "get_target_spotted_alias" },
    { 0xF593, "get_teaminquiry_alias" },
    { 0xF594, "get_tier_reward_for_total_time" },
    { 0xF595, "get_to_z_and_fly_off" },
    { 0xF596, "get_too_far_dist_sq" },
    { 0xF597, "get_total_from_call_count" },
    { 0xF598, "get_total_successful_vehicle_spawns_from_module" },
    { 0xF599, "get_track_controller_struct" },
    { 0xF59A, "get_track_end_struct" },
    { 0xF59B, "get_track_location_index" },
    { 0xF59C, "get_track_setting" },
    { 0xF59D, "get_track_star_time_from_col" },
    { 0xF59E, "get_track_star_times" },
    { 0xF59F, "get_track_start_struct" },
    { 0xF5A0, "get_track_timer_struct" },
    { 0xF5A1, "get_train_travel_time_between_stations" },
    { 0xF5A2, "get_trap_room_spawnpoints" },
    { 0xF5A3, "get_turret_target_pos" },
    { 0xF5A4, "get_tv_station_infil_rider_start_targetname" },
    { 0xF5A5, "get_type_to_drop" },
    { 0xF5A6, "get_unique_id" },
    { 0xF5A7, "get_valid_seats" },
    { 0xF5A8, "get_valid_starting_station_name_on_track" },
    { 0xF5A9, "get_veh_spawn_test_spawners" },
    { 0xF5AA, "get_vehicle_ai_spawner" },
    { 0xF5AB, "get_vehicle_driver_hint_string_func" },
    { 0xF5AC, "get_vehicle_getin_anim" },
    { 0xF5AD, "get_vehicle_idle_anim" },
    { 0xF5AE, "get_vehicle_node_to_wait_for_lbravo_based_on_group" },
    { 0xF5AF, "get_vehicle_riders" },
    { 0xF5B0, "get_vehicle_unloadable_riders" },
    { 0xF5B1, "get_wait_between_stations_time" },
    { 0xF5B2, "get_wave_cur_count" },
    { 0xF5B3, "get_wave_data" },
    { 0xF5B4, "get_wave_info" },
    { 0xF5B5, "get_wave_low_threshold" },
    { 0xF5B6, "get_wave_max_count" },
    { 0xF5B7, "get_wave_spawn_count" },
    { 0xF5B8, "get_wave_spawn_total" },
    { 0xF5B9, "get_wave_targetname" },
    { 0xF5BA, "get_weapon_ammo_matched" },
    { 0xF5BB, "get_weapon_in_power_slot" },
    { 0xF5BC, "get_within_sight_angles" },
    { 0xF5BD, "getaccessorylogicbyindex" },
    { 0xF5BE, "getactiveforteam" },
    { 0xF5BF, "getactiveteamcount" },
    { 0xF5C0, "getallactivequestsforteam" },
    { 0xF5C1, "getallextractspawninstances" },
    { 0xF5C2, "getallselectableattachments" },
    { 0xF5C3, "getallspawninstances" },
    { 0xF5C4, "getaltbunkerkeypadindexforscriptable" },
    { 0xF5C5, "getanglesfacingorigin" },
    { 0xF5C6, "getanglesfromsurfacenormal" },
    { 0xF5C7, "getanimsforplanefacing" },
    { 0xF5C8, "getarenaomnvarbitpackinginfo" },
    { 0xF5C9, "getarenapickupattachmentoverrides" },
    { 0xF5CA, "getattachmentoverride" },
    { 0xF5CB, "getattractionomnvarbitpackinginfo" },
    { 0xF5CC, "getatvspawns" },
    { 0xF5CD, "getaverageangularvelocity" },
    { 0xF5CE, "getaveragelinearvelocity" },
    { 0xF5CF, "getbankedplunder" },
    { 0xF5D0, "getbattlepassxpmultiplier" },
    { 0xF5D1, "getbattlepassxpultipliertotal" },
    { 0xF5D2, "getbeingrevivedinternal" },
    { 0xF5D3, "getbestcameraindex" },
    { 0xF5D4, "getbestintersectionpt" },
    { 0xF5D5, "getbestsepctatecandidatefromlist" },
    { 0xF5D6, "getbestspectatecandidate" },
    { 0xF5D7, "getblockedweaponvariantidsmap" },
    { 0xF5D8, "getblueprintforpickupweapon" },
    { 0xF5D9, "getboltmodel" },
    { 0xF5DA, "getbombteam" },
    { 0xF5DB, "getbrendsplashpostgamestate" },
    { 0xF5DC, "getbrgametypedata" },
    { 0xF5DD, "getbrplayersnoteliminated" },
    { 0xF5DE, "getbunkernamefromkeypadscriptableinstance" },
    { 0xF5DF, "getburnfxstatepriority" },
    { 0xF5E0, "getc130airdropheight" },
    { 0xF5E1, "getc130knownsafeheight" },
    { 0xF5E2, "getcargotruckspawns" },
    { 0xF5E3, "getcash" },
    { 0xF5E4, "getcashnags" },
    { 0xF5E5, "getchallengegamemode" },
    { 0xF5E6, "getcircleclosetime" },
    { 0xF5E7, "getcircleindexforpoint" },
    { 0xF5E8, "getcirclerangemax" },
    { 0xF5E9, "getcirclerangemin" },
    { 0xF5EA, "getcirclesize" },
    { 0xF5EB, "getclearpathflightyaw" },
    { 0xF5EC, "getclocksoundaliasfortimeleft" },
    { 0xF5ED, "getclosestmatchingmasterlootnode" },
    { 0xF5EE, "getclosestplayerforreward" },
    { 0xF5EF, "getcodecomputerdisplaycode" },
    { 0xF5F0, "getcombatrecordsupermisc" },
    { 0xF5F1, "getcoremapdropzones" },
    { 0xF5F2, "getcorpstablestate" },
    { 0xF5F3, "getcost" },
    { 0xF5F4, "getcpcratedropcaststart" },
    { 0xF5F5, "getcpscriptedhelidropheight" },
    { 0xF5F6, "getcrateusetime" },
    { 0xF5F7, "getcrossbowammotype" },
    { 0xF5F8, "getcrossbowimpactfunc" },
    { 0xF5F9, "getcurrentxp" },
    { 0xF5FA, "getdefaultstreamhinttimeoutms" },
    { 0xF5FB, "getdefaultweaponbasename" },
    { 0xF5FC, "getdismembermentlist" },
    { 0xF5FD, "getdomneutralizeomnvarvalue" },
    { 0xF5FE, "getdomplateradius" },
    { 0xF5FF, "getdropbagdelay" },
    { 0xF600, "getdropbagspawntypeenum" },
    { 0xF601, "getdroplocationnearcurrentcircle" },
    { 0xF602, "getdropposition" },
    { 0xF603, "getemptyloadout" },
    { 0xF604, "getexpectednumberofteams" },
    { 0xF605, "getextractionpadent" },
    { 0xF606, "getextractionposition" },
    { 0xF607, "getextractionsites" },
    { 0xF608, "getfilterformodifier" },
    { 0xF609, "getfirespoutlaunchvectors" },
    { 0xF60A, "getflagradarowner" },
    { 0xF60B, "getfullweaponobjforpickup" },
    { 0xF60C, "getfullweaponobjforscriptablepartname" },
    { 0xF60D, "getfullweaponobjfromscriptablename" },
    { 0xF60E, "getgametypekillsperhouravg" },
    { 0xF60F, "getgametypekillspermatchmaximum" },
    { 0xF610, "getgametypeweaponxpmultiplier" },
    { 0xF611, "getgamewinnerfunc" },
    { 0xF612, "getgamewinnerprop" },
    { 0xF613, "getggweapontablelootvariants" },
    { 0xF614, "getglobalbattlepassxpmultiplier" },
    { 0xF615, "getgulagclosedcircleindex" },
    { 0xF616, "getheliflyheight" },
    { 0xF617, "gethelinextgroupafterwait" },
    { 0xF618, "gethelispawns" },
    { 0xF619, "gethighestscore" },
    { 0xF61A, "gethightestpriotiryactiveburnstate" },
    { 0xF61B, "gethillspawnshutofforigin" },
    { 0xF61C, "gethillspawnshutoffradius" },
    { 0xF61D, "gethost" },
    { 0xF61E, "getignoreprops" },
    { 0xF61F, "getinfectedairdropposition" },
    { 0xF620, "getinfilplayers" },
    { 0xF621, "getinitialwinningteam" },
    { 0xF622, "getintermissionspawnpointoverride" },
    { 0xF623, "getintorzero" },
    { 0xF624, "getinventoryslotscriptabletypeinfo" },
    { 0xF625, "getinventoryslotvo" },
    { 0xF626, "getitemcount" },
    { 0xF627, "getitemdropinfo" },
    { 0xF628, "getjeepspawns" },
    { 0xF629, "getjuggdamagescale" },
    { 0xF62A, "getjuggmazebutton" },
    { 0xF62B, "getjuggmazespawnpoint" },
    { 0xF62C, "getkeypadcodelengthfromomnvar" },
    { 0xF62D, "getkeypadomnvarbitpackinginfo" },
    { 0xF62E, "getkeypadstatefromomnvar" },
    { 0xF62F, "getkillstreakairstrikeheightent" },
    { 0xF630, "getkioskyawoffsetoverride" },
    { 0xF631, "getknivesoutsetting" },
    { 0xF632, "getkothlocations" },
    { 0xF633, "getlinktarget" },
    { 0xF634, "getlivingplayersonteam" },
    { 0xF635, "getlocalestruct" },
    { 0xF636, "getlocalestructarray" },
    { 0xF637, "getlocationnameforpoint" },
    { 0xF638, "getlootname" },
    { 0xF639, "getlootteamleader" },
    { 0xF63A, "getlowermessageindex" },
    { 0xF63B, "getmapbaselinetempurature" },
    { 0xF63C, "getmaxnumplayerslogging" },
    { 0xF63D, "getmaxoutofboundsbrtime" },
    { 0xF63E, "getminigundamagescale" },
    { 0xF63F, "getnearbyaliveplayer" },
    { 0xF640, "getnearestbombsiteteam" },
    { 0xF641, "getnemesis" },
    { 0xF642, "getnextcircleindex" },
    { 0xF643, "getnextcombatareaid" },
    { 0xF644, "getnexthelimodule" },
    { 0xF645, "getnextpayloadspawnmodule" },
    { 0xF646, "getnextprop" },
    { 0xF647, "getnextrpgspawnmodule" },
    { 0xF648, "getnextsafecircleorigin" },
    { 0xF649, "getnextsafecircleradius" },
    { 0xF64A, "getnextspectatecandidatefromchain" },
    { 0xF64B, "getnumbersspawnpoint" },
    { 0xF64C, "getnumbersspawnpoint_late" },
    { 0xF64D, "getnumdrops" },
    { 0xF64E, "getobjectiveflag" },
    { 0xF64F, "getoffsetspawnoriginmultitrace" },
    { 0xF650, "getoldestdogtags" },
    { 0xF651, "getoperatorbrinfilsmokesuffix" },
    { 0xF652, "getoperatorclothtype" },
    { 0xF653, "getoperatorexecutionquip" },
    { 0xF654, "getoperators" },
    { 0xF655, "getoperatorspecificaccessoryweapon" },
    { 0xF656, "getoriginidentifierstringnoz" },
    { 0xF657, "getoverlordaliasfortimeleft" },
    { 0xF658, "getoverridedvarexceptmatchrulesvalues" },
    { 0xF659, "getoverridedvarfloatexceptmatchrulesvalues" },
    { 0xF65A, "getoverridedvarintexceptmatchrulesvalues" },
    { 0xF65B, "getovertimelength" },
    { 0xF65C, "getpackeddata" },
    { 0xF65D, "getplanepathsaferadiusfromcenter" },
    { 0xF65E, "getplatformrankxpmultiplier" },
    { 0xF65F, "getplatformweaponrankxpmultiplier" },
    { 0xF660, "getplunderextractionsites" },
    { 0xF661, "getplundernamebyamount" },
    { 0xF662, "getpresettruckspawns" },
    { 0xF663, "getpreviousplacement" },
    { 0xF664, "getprophealth" },
    { 0xF665, "getpropnextstartlocation" },
    { 0xF666, "getpropsize" },
    { 0xF667, "getpropspawnlocation" },
    { 0xF668, "getpubliceventchance" },
    { 0xF669, "getpubliceventcount" },
    { 0xF66A, "getquestinstancedatasafe" },
    { 0xF66B, "getquestperkbonus" },
    { 0xF66C, "getquestplunderreward" },
    { 0xF66D, "getquestplunderrewardinstance" },
    { 0xF66E, "getquestreward_checkforvalueoverride" },
    { 0xF66F, "getquestrewardbuildgroupref" },
    { 0xF670, "getquestrewardgroupindex" },
    { 0xF671, "getquestrewardgroupstablerewards" },
    { 0xF672, "getquestrewardscalerstablescaleinfo" },
    { 0xF673, "getquestrewardsgrouptable" },
    { 0xF674, "getquestrewardstabletype" },
    { 0xF675, "getquestrewardstablevalue" },
    { 0xF676, "getquestrewardstablevaluecolumnindex" },
    { 0xF677, "getquestrewardtier" },
    { 0xF678, "getquestscaledvalue" },
    { 0xF679, "getquestscalervalue" },
    { 0xF67A, "getquesttablerewardgroup" },
    { 0xF67B, "getquesttimefrac" },
    { 0xF67C, "getquestunlockableindexfromlootid" },
    { 0xF67D, "getquestweaponxpreward" },
    { 0xF67E, "getquestweaponxprewardinstance" },
    { 0xF67F, "getquestxpreward" },
    { 0xF680, "getquestxprewardinstance" },
    { 0xF681, "getquickdropammocount" },
    { 0xF682, "getquickdropammotype" },
    { 0xF683, "getquickdroparmorcount" },
    { 0xF684, "getquickdropitemcount" },
    { 0xF685, "getquickdropplundercount" },
    { 0xF686, "getquickdropweapon" },
    { 0xF687, "getrandomextractunlockablelootid" },
    { 0xF688, "getrandomkeyfromweaponweightsarray" },
    { 0xF689, "getrandompointinboundscircle" },
    { 0xF68A, "getrandompointinboundssafecircle" },
    { 0xF68B, "getrandompointincirclenearby" },
    { 0xF68C, "getrandompointincirclewithindistance" },
    { 0xF68D, "getrandompointinsafecircle" },
    { 0xF68E, "getrandompointinsafecirclenearby" },
    { 0xF68F, "getrandomprematchequipment" },
    { 0xF690, "getrandomweaponfromgroup" },
    { 0xF691, "getrewardvaluetype" },
    { 0xF692, "getridofkillstreakdeployweapon" },
    { 0xF693, "getsafeoriginaroundpoint" },
    { 0xF694, "getscrapassistplayers" },
    { 0xF695, "getsearchparams" },
    { 0xF696, "getserachparams" },
    { 0xF697, "getserverroomspawnpoint" },
    { 0xF698, "getsetplundercountdatanosplash" },
    { 0xF699, "getsixthsensedirection" },
    { 0xF69A, "getsolospawnstruct" },
    { 0xF69B, "getspawncamerablendtime" },
    { 0xF69C, "getspecialdaycamos" },
    { 0xF69D, "getspecialdaycosmetics" },
    { 0xF69E, "getspecialdaystickers" },
    { 0xF69F, "getspectatorsofplayer" },
    { 0xF6A0, "getspreadpelletspershot" },
    { 0xF6A1, "getsquadspawnlocations" },
    { 0xF6A2, "getsquadspawnstruct" },
    { 0xF6A3, "getstancetop" },
    { 0xF6A4, "getstartparachutespawnpoint" },
    { 0xF6A5, "getstreamedinplayercount" },
    { 0xF6A6, "getsubgametype" },
    { 0xF6A7, "getsuperrefforsuperextraweapon" },
    { 0xF6A8, "getsuperweapondisabledammobr" },
    { 0xF6A9, "gettacroverspawns" },
    { 0xF6AA, "getteamcarriedplunder" },
    { 0xF6AB, "getteamcontenders" },
    { 0xF6AC, "getteamfactionsfrommap" },
    { 0xF6AD, "getteamplunder" },
    { 0xF6AE, "getteamplunderhud" },
    { 0xF6AF, "getteamscoreplacements" },
    { 0xF6B0, "getteamspawnbots" },
    { 0xF6B1, "getteamtokens" },
    { 0xF6B2, "getteamtokenshud" },
    { 0xF6B3, "getterminalhint" },
    { 0xF6B4, "getthermalscopeperweaponclass" },
    { 0xF6B5, "getthirdpersonheightoffsetforsize" },
    { 0xF6B6, "getthirdpersonrangeforsize" },
    { 0xF6B7, "gettimetogulagclosed" },
    { 0xF6B8, "getting_pushed" },
    { 0xF6B9, "gettingupfromlaststand" },
    { 0xF6BA, "gettouchingspraylocaletriggers" },
    { 0xF6BB, "gettruckspawns" },
    { 0xF6BC, "gettruegroundposition" },
    { 0xF6BD, "getvalidatedspawnorgangles" },
    { 0xF6BE, "getvehicleplayercamo" },
    { 0xF6BF, "getvehicleplayerhorn" },
    { 0xF6C0, "getvehicleplayertrail" },
    { 0xF6C1, "getvehicleplayerturretcamo" },
    { 0xF6C2, "getvehiclespawns" },
    { 0xF6C3, "getvolength" },
    { 0xF6C4, "getweaponrandomvariantid" },
    { 0xF6C5, "getweaponvariantids" },
    { 0xF6C6, "getweightedsum" },
    { 0xF6C7, "getwincost" },
    { 0xF6C8, "getxmike109ammotype" },
    { 0xF6C9, "getxmike109impactfunc" },
    { 0xF6CA, "getzeroarray" },
    { 0xF6CB, "ghostridewhip" },
    { 0xF6CC, "give_ammo_to_stock" },
    { 0xF6CD, "give_and_switch_to_primary_weapon" },
    { 0xF6CE, "give_and_switch_to_secondary_weapon" },
    { 0xF6CF, "give_clip_of_ammo" },
    { 0xF6D0, "give_deployable_crate" },
    { 0xF6D1, "give_equipment_from_loadout" },
    { 0xF6D2, "give_fists" },
    { 0xF6D3, "give_full_stoppingpower_clip" },
    { 0xF6D4, "give_intel_data" },
    { 0xF6D5, "give_killstreak_airstrike" },
    { 0xF6D6, "give_killstreak_cluster" },
    { 0xF6D7, "give_killstreak_sentry" },
    { 0xF6D8, "give_launchers_xmags" },
    { 0xF6D9, "give_munition_currency" },
    { 0xF6DA, "give_nvgs_after_delay" },
    { 0xF6DB, "give_objective_xp_to_all_players" },
    { 0xF6DC, "give_operator_based_on_task" },
    { 0xF6DD, "give_periodic_jugg_pulses" },
    { 0xF6DE, "give_player_class_abilities" },
    { 0xF6DF, "give_player_grenade_on_respawn" },
    { 0xF6E0, "give_player_juggernaut" },
    { 0xF6E1, "give_player_knife_on_respawn" },
    { 0xF6E2, "give_player_saw" },
    { 0xF6E3, "give_primary_attachments_only" },
    { 0xF6E4, "give_punchcard" },
    { 0xF6E5, "give_radar_to_team" },
    { 0xF6E6, "give_random_munition" },
    { 0xF6E7, "give_respawn_flare" },
    { 0xF6E8, "give_reward_based_on_task" },
    { 0xF6E9, "give_saw_to_player" },
    { 0xF6EA, "give_scout_drone" },
    { 0xF6EB, "give_secondary_attachments_only" },
    { 0xF6EC, "give_super_ammo_after_loadout_given" },
    { 0xF6ED, "give_weapon_alt_clip_ammo_hack" },
    { 0xF6EE, "give_xp_to_all_players_hack" },
    { 0xF6EF, "giveachievementpilotkill" },
    { 0xF6F0, "giveachievementsmoke" },
    { 0xF6F1, "giveachievementwildfire" },
    { 0xF6F2, "giveammo" },
    { 0xF6F3, "givearmorvalue" },
    { 0xF6F4, "giveawardfake" },
    { 0xF6F5, "givebmodevloadouts" },
    { 0xF6F6, "givebrbonusxp" },
    { 0xF6F7, "givebrweaponxp" },
    { 0xF6F8, "givecustomloadout" },
    { 0xF6F9, "givelaststandifneeded" },
    { 0xF6FA, "giveloadouteverytime" },
    { 0xF6FB, "givematchplacementchallenge" },
    { 0xF6FC, "given_achievement" },
    { 0xF6FD, "givephteamscore" },
    { 0xF6FE, "giveplayerpoints" },
    { 0xF6FF, "givepointsandxp" },
    { 0xF700, "givequest" },
    { 0xF701, "givequestreward" },
    { 0xF702, "givequestrewardgroup" },
    { 0xF703, "givequestrewardref" },
    { 0xF704, "givequestrewards" },
    { 0xF705, "givequestrewardsinstance" },
    { 0xF706, "givequestsplash" },
    { 0xF707, "giverandomloadoutindex" },
    { 0xF708, "giverewards" },
    { 0xF709, "givespecialistbonusifneeded" },
    { 0xF70A, "givestandardtableloadout" },
    { 0xF70B, "givestartingarmor" },
    { 0xF70C, "givesuperpointsonprematchdone" },
    { 0xF70D, "giveteampoints" },
    { 0xF70E, "giveweaponxpfromtimebr" },
    { 0xF70F, "givewincondition" },
    { 0xF710, "givexpwithtext" },
    { 0xF711, "glgrenade" },
    { 0xF712, "glgrenadeparent" },
    { 0xF713, "glint" },
    { 0xF714, "glintfx" },
    { 0xF715, "global_relic_amped_func" },
    { 0xF716, "global_relic_landlocked_func" },
    { 0xF717, "global_relic_squadlink_func" },
    { 0xF718, "global_relic_team_prox_func" },
    { 0xF719, "global_stealth_broken_func" },
    { 0xF71A, "global_variables" },
    { 0xF71B, "globalrelicsfunc" },
    { 0xF71C, "globalstruct" },
    { 0xF71D, "go_investigate_loc" },
    { 0xF71E, "go_patrol_the_maze" },
    { 0xF71F, "go_to_combat" },
    { 0xF720, "go_to_exit_spots" },
    { 0xF721, "go_to_node_callback" },
    { 0xF722, "goal_ar" },
    { 0xF723, "goal_default" },
    { 0xF724, "goal_shotgun" },
    { 0xF725, "goal_smg" },
    { 0xF726, "goalradiustarget" },
    { 0xF727, "goalstruct" },
    { 0xF728, "goalyaw" },
    { 0xF729, "going_to" },
    { 0xF72A, "goliath_init" },
    { 0xF72B, "goodjobplayer" },
    { 0xF72C, "goodwork" },
    { 0xF72D, "goto_goal_and_snipe" },
    { 0xF72E, "grab_entities_inside" },
    { 0xF72F, "grab_players_inside" },
    { 0xF730, "greenlight" },
    { 0xF731, "grenade_chances" },
    { 0xF732, "grenade_effect" },
    { 0xF733, "grenade_exploded_during_stealth_listener" },
    { 0xF734, "grenade_menu_kill" },
    { 0xF735, "grenade_obj" },
    { 0xF736, "grenade_owner_name" },
    { 0xF737, "grenade_structs" },
    { 0xF738, "grenade_trail_modifier" },
    { 0xF739, "grenade_types" },
    { 0xF73A, "grenadebox_think" },
    { 0xF73B, "grenadeboxes_init" },
    { 0xF73C, "grenadehealthatdeathframeupdatecallback" },
    { 0xF73D, "grenadestuckkill" },
    { 0xF73E, "ground_detection_think" },
    { 0xF73F, "ground_spawners" },
    { 0xF740, "ground_trigger_pipes_room" },
    { 0xF741, "groundentity" },
    { 0xF742, "groundentrance_effects" },
    { 0xF743, "groundfloor_rear_gunner_handler" },
    { 0xF744, "groundtriggers" },
    { 0xF745, "groundz" },
    { 0xF746, "group_hold_free" },
    { 0xF747, "group_reset_goalradius" },
    { 0xF748, "group_unset_ignoreall_after_notify" },
    { 0xF749, "group_unset_jugg_ignoreall_after_notify" },
    { 0xF74A, "group_unset_jugg_standstill" },
    { 0xF74B, "groupindex" },
    { 0xF74C, "grouptorewards" },
    { 0xF74D, "guard_door_clip" },
    { 0xF74E, "guard_shack_mantle" },
    { 0xF74F, "guard_spawners" },
    { 0xF750, "gulag_intro_vo" },
    { 0xF751, "gulag_think" },
    { 0xF752, "gulag_tutorial_vo" },
    { 0xF753, "gulagfadefromblackspectatorsofplayer" },
    { 0xF754, "gulagfadetoblackspectatorsofplayer" },
    { 0xF755, "gulagfixuparena" },
    { 0xF756, "gulagholding" },
    { 0xF757, "gulagindex" },
    { 0xF758, "gulagisfaded" },
    { 0xF759, "gulagisspawnpositionreasonablysafe" },
    { 0xF75A, "gulagisspawnpositionwithindangercircle" },
    { 0xF75B, "gulagisspawnpositionwithinsafecircle" },
    { 0xF75C, "gulaglaststandholdremove" },
    { 0xF75D, "gulagloading" },
    { 0xF75E, "gulagloadoutindex" },
    { 0xF75F, "gulagloadouts" },
    { 0xF760, "gulagloadouttable" },
    { 0xF761, "gulagmatchclocksounds" },
    { 0xF762, "gulagplayerlost" },
    { 0xF763, "gulagplayerwatchfordeath" },
    { 0xF764, "gulagstreamexit" },
    { 0xF765, "gulagtableloadout" },
    { 0xF766, "gulagwinnerloadout" },
    { 0xF767, "gulagwinnerrestoregunandammo" },
    { 0xF768, "gulagwinnerrestoreloadout" },
    { 0xF769, "gulagwinnertableloadout" },
    { 0xF76A, "gun_buildoverrideattachmentlist" },
    { 0xF76B, "gun_course_forward" },
    { 0xF76C, "gun_create_fake" },
    { 0xF76D, "gun_createrandomweapon" },
    { 0xF76E, "gun_game_primary_weapon" },
    { 0xF76F, "gun_remove_fake" },
    { 0xF770, "gunbutt" },
    { 0xF771, "gunless" },
    { 0xF772, "gunnerdamagemodifier" },
    { 0xF773, "gunship_assignedtargetmarkers_onnewai" },
    { 0xF774, "gunship_detachplayerfromintro" },
    { 0xF775, "gunship_getbombingpoint" },
    { 0xF776, "gunship_origin_override" },
    { 0xF777, "gunship_watchgameend" },
    { 0xF778, "gunship_watchintrodisown" },
    { 0xF779, "gunship_watchownerexitaction" },
    { 0xF77A, "guy_pushes_building" },
    { 0xF77B, "guy_pushes_terminal" },
    { 0xF77C, "gw_fobs_init" },
    { 0xF77D, "gwinputtypesused" },
    { 0xF77E, "gwperifvfx_plumes" },
    { 0xF77F, "gwsiege_config" },
    { 0xF780, "h" },
    { 0xF781, "hack_addkilltriggers" },
    { 0xF782, "hack_airport_combat_init" },
    { 0xF783, "hack_console_activation_func" },
    { 0xF784, "hack_index" },
    { 0xF785, "hack_laser_trap_control" },
    { 0xF786, "hack_started" },
    { 0xF787, "hackclientomnvarclamp" },
    { 0xF788, "hacking_lua_notify_func" },
    { 0xF789, "hacking_player_nearby" },
    { 0xF78A, "hacking_vo" },
    { 0xF78B, "hackomnvarclamp" },
    { 0xF78C, "hacks_needed" },
    { 0xF78D, "hacks_started" },
    { 0xF78E, "half_size" },
    { 0xF78F, "halfheight" },
    { 0xF790, "hallway_jugg_spawner" },
    { 0xF791, "hallway_soldier_spawner" },
    { 0xF792, "handle_carry_special_item" },
    { 0xF793, "handle_ground_spawning" },
    { 0xF794, "handle_just_keep_moving" },
    { 0xF795, "handle_leads_collected_hideiconbuilding" },
    { 0xF796, "handle_nav_bounds_buildings" },
    { 0xF797, "handle_no_ammo_mun" },
    { 0xF798, "handle_respawn_via_c130" },
    { 0xF799, "handle_roof_spawning" },
    { 0xF79A, "handle_set_respawn_overrides" },
    { 0xF79B, "handle_settings_for_techo_group" },
    { 0xF79C, "handle_tank_spawning" },
    { 0xF79D, "handle_train_collision_items" },
    { 0xF79E, "handle_train_veh_collision" },
    { 0xF79F, "handle_truck_spawning" },
    { 0xF7A0, "handlebmoendgamesplash" },
    { 0xF7A1, "handlebrdefeatedpostgamestate" },
    { 0xF7A2, "handlecommand" },
    { 0xF7A3, "handlecommand_br" },
    { 0xF7A4, "handlecommandfuncs" },
    { 0xF7A5, "handledeathfromabove" },
    { 0xF7A6, "handledevcommand_publicevents" },
    { 0xF7A7, "handledropbags" },
    { 0xF7A8, "handleendgamenonwinnersplash" },
    { 0xF7A9, "handleendgamespectatingsplash" },
    { 0xF7AA, "handleenemygunshipdamage" },
    { 0xF7AB, "handleeventcallback" },
    { 0xF7AC, "handleexitsquadeliminatedstate" },
    { 0xF7AD, "handleexplosivepickup" },
    { 0xF7AE, "handlefocusfire" },
    { 0xF7AF, "handlefriendlyvisibility" },
    { 0xF7B0, "handleheadshotkillrewardbullets" },
    { 0xF7B1, "handleimpact" },
    { 0xF7B2, "handlelaststandweapongivepipeline" },
    { 0xF7B3, "handlelfo" },
    { 0xF7B4, "handlematchscoreboardinfo" },
    { 0xF7B5, "handlemeleekillrewardbullets" },
    { 0xF7B6, "handlemeleekillsteelballs" },
    { 0xF7B7, "handlemythic" },
    { 0xF7B8, "handlenavobstacles" },
    { 0xF7B9, "handlenokillstreaks" },
    { 0xF7BA, "handleownervisibility" },
    { 0xF7BB, "handlepersistentgungame" },
    { 0xF7BC, "handlepersistentlandlocked" },
    { 0xF7BD, "handlepersistentrelicsquadlink" },
    { 0xF7BE, "handlepersistentteamproximity" },
    { 0xF7BF, "handleplunderendgamesplash" },
    { 0xF7C0, "handleprop" },
    { 0xF7C1, "handlerelicampedonkill" },
    { 0xF7C2, "handlerelicmartyrdom" },
    { 0xF7C3, "handlerelicmartyrdom_common" },
    { 0xF7C4, "handlerelicmartyrdomfrag" },
    { 0xF7C5, "handlerelicmartyrdomgas" },
    { 0xF7C6, "handlerelicshieldsonlyonkill" },
    { 0xF7C7, "handleriotshielddamage" },
    { 0xF7C8, "handlerocketkillsgiverockets" },
    { 0xF7C9, "handlesoloexclusionils" },
    { 0xF7CA, "handleteamplacement" },
    { 0xF7CB, "handleteamvisibility" },
    { 0xF7CC, "handletrex" },
    { 0xF7CD, "handleweaponreloadammodrop" },
    { 0xF7CE, "hangar_doors_opening_quadrace" },
    { 0xF7CF, "hangar_juggs" },
    { 0xF7D0, "hanging_crate_think" },
    { 0xF7D1, "has_access_card" },
    { 0xF7D2, "has_ammo_drain_passive" },
    { 0xF7D3, "has_balloon" },
    { 0xF7D4, "has_been_turned_on" },
    { 0xF7D5, "has_current_combat_action" },
    { 0xF7D6, "has_drop_kit_marker" },
    { 0xF7D7, "has_filled_amped_bar" },
    { 0xF7D8, "has_focus_fire_headicon" },
    { 0xF7D9, "has_focus_fire_objective" },
    { 0xF7DA, "has_headicon" },
    { 0xF7DB, "has_intel" },
    { 0xF7DC, "has_keycard" },
    { 0xF7DD, "has_module_met_max_vehicles" },
    { 0xF7DE, "has_no_focus_fire_attackers" },
    { 0xF7DF, "has_relic_amped_victim_filled_bar" },
    { 0xF7E0, "has_relic_amped_victim_survived_time" },
    { 0xF7E1, "has_saw" },
    { 0xF7E2, "has_sequence_been_entered_correctly" },
    { 0xF7E3, "has_started_cache_defenses" },
    { 0xF7E4, "has_tac_vis" },
    { 0xF7E5, "has_target_player" },
    { 0xF7E6, "has_target_player_with_battle_stations" },
    { 0xF7E7, "has_termal" },
    { 0xF7E8, "has_zone" },
    { 0xF7E9, "hasaccesscard" },
    { 0xF7EA, "hasactivepunchcard" },
    { 0xF7EB, "hasanykillstreak" },
    { 0xF7EC, "hasbeeninprisonarea" },
    { 0xF7ED, "hasbettermissionrewards" },
    { 0xF7EE, "hasbrspecialistbonus" },
    { 0xF7EF, "hasdonestartmusic" },
    { 0xF7F0, "hasdropped" },
    { 0xF7F1, "hasexiteddriver" },
    { 0xF7F2, "hashitplayer" },
    { 0xF7F3, "hasmaxammo" },
    { 0xF7F4, "hasminigun" },
    { 0xF7F5, "hasnolethalequipment" },
    { 0xF7F6, "haspackage" },
    { 0xF7F7, "haspassedsquadleader" },
    { 0xF7F8, "hasplatepouch" },
    { 0xF7F9, "hasscrapassist" },
    { 0xF7FA, "hasseendiscountsplash" },
    { 0xF7FB, "hasseenendgamesplash" },
    { 0xF7FC, "hasselfrevivetoken" },
    { 0xF7FD, "hasspawnweapons" },
    { 0xF7FE, "hasspecialistbonus" },
    { 0xF7FF, "hassquadmatepassengers" },
    { 0xF800, "hastargetmarker" },
    { 0xF801, "hatch_model_linkto_train" },
    { 0xF802, "hatsforgoats" },
    { 0xF803, "have_civilian" },
    { 0xF804, "have_custom_evade_start" },
    { 0xF805, "have_players_reached_points" },
    { 0xF806, "have_players_reached_points_endon_weapons_free" },
    { 0xF807, "have_target_hud_turned_on" },
    { 0xF808, "havefuellevelsreachedoptimalvalue" },
    { 0xF809, "headequiptoggleloopbr" },
    { 0xF80A, "headicon_image" },
    { 0xF80B, "headicon_range" },
    { 0xF80C, "headicon_time_left" },
    { 0xF80D, "headicon_z_offset" },
    { 0xF80E, "headiconbox" },
    { 0xF80F, "headiconfaction" },
    { 0xF810, "headlesscustomizationops" },
    { 0xF811, "headlessinfilplayers" },
    { 0xF812, "headlessinfils" },
    { 0xF813, "headlessloadoutindexprimary" },
    { 0xF814, "headlessloadoutindexsecondary" },
    { 0xF815, "headlessoperatorcustomization" },
    { 0xF816, "headlessopindex" },
    { 0xF817, "headlightleft" },
    { 0xF818, "headlightright" },
    { 0xF819, "headoffset" },
    { 0xF81A, "headshot_distance" },
    { 0xF81B, "healdamage" },
    { 0xF81C, "health_bar_player_connect_monitor" },
    { 0xF81D, "health_reduction" },
    { 0xF81E, "health_remaining_max" },
    { 0xF81F, "healthpack_health" },
    { 0xF820, "healthpool" },
    { 0xF821, "heardparachuteoverheadtime" },
    { 0xF822, "heartbeat_sensor_pick_up_monitor" },
    { 0xF823, "heatcounter" },
    { 0xF824, "heavy_enemy_spawning_pause_monitor" },
    { 0xF825, "heavydamageaward" },
    { 0xF826, "heavydamageawardlaunchonly" },
    { 0xF827, "heavydamagescoreevent" },
    { 0xF828, "heavydamagescorelaunchonly" },
    { 0xF829, "heavystatehealthadd" },
    { 0xF82A, "heli_activate_instruct" },
    { 0xF82B, "heli_anim" },
    { 0xF82C, "heli_approach_instruct" },
    { 0xF82D, "heli_arrived" },
    { 0xF82E, "heli_assault2_death_watcher" },
    { 0xF82F, "heli_assault3_death_watcher" },
    { 0xF830, "heli_assault3_fob_death_watcher" },
    { 0xF831, "heli_assault3_hangar_death_watcher" },
    { 0xF832, "heli_audio" },
    { 0xF833, "heli_boss" },
    { 0xF834, "heli_boss_logic" },
    { 0xF835, "heli_boss_shoot" },
    { 0xF836, "heli_bosses" },
    { 0xF837, "heli_bravo_main_snd_ent" },
    { 0xF838, "heli_can_shoot" },
    { 0xF839, "heli_carrier_logic" },
    { 0xF83A, "heli_check_player_below_starts" },
    { 0xF83B, "heli_convert" },
    { 0xF83C, "heli_convertforplayerfunc" },
    { 0xF83D, "heli_counter" },
    { 0xF83E, "heli_delayedpadstateupdate" },
    { 0xF83F, "heli_deposit_instruct" },
    { 0xF840, "heli_extraction" },
    { 0xF841, "heli_fire_at_players" },
    { 0xF842, "heli_flyloop" },
    { 0xF843, "heli_go_to_exfil_point" },
    { 0xF844, "heli_goto_pos" },
    { 0xF845, "heli_group_nextspawntime" },
    { 0xF846, "heli_gunner_logic" },
    { 0xF847, "heli_hover_between_points" },
    { 0xF848, "heli_intro" },
    { 0xF849, "heli_intro_vo_done" },
    { 0xF84A, "heli_isleaving" },
    { 0xF84B, "heli_killed" },
    { 0xF84C, "heli_land_logic" },
    { 0xF84D, "heli_landing_volumes" },
    { 0xF84E, "heli_leaving_monitor" },
    { 0xF84F, "heli_lookat_monitor" },
    { 0xF850, "heli_orbit_logic" },
    { 0xF851, "heli_outro" },
    { 0xF852, "heli_rpg_enemy_run_away" },
    { 0xF853, "heli_rpg_enemy_think" },
    { 0xF854, "heli_screenshake" },
    { 0xF855, "heli_setup_and_attack_logic" },
    { 0xF856, "heli_starts_addstart" },
    { 0xF857, "heli_starts_clear" },
    { 0xF858, "heli_starts_restrict_to" },
    { 0xF859, "heli_watch_for_fly_away" },
    { 0xF85A, "heli_yaw" },
    { 0xF85B, "heliatcapacitycallback" },
    { 0xF85C, "helibankplunder" },
    { 0xF85D, "helicircleindex" },
    { 0xF85E, "helicleanup" },
    { 0xF85F, "helicopter_death_lockon_clear" },
    { 0xF860, "helicopter_firendly_dmg_text_display" },
    { 0xF861, "helicountdownendcallback" },
    { 0xF862, "helicrash" },
    { 0xF863, "helicratedelete" },
    { 0xF864, "helidelete" },
    { 0xF865, "helidestroyed" },
    { 0xF866, "helidestroyvehiclestouchnotify" },
    { 0xF867, "helidestroyvehiclestouchtrace" },
    { 0xF868, "helidisabled" },
    { 0xF869, "helidisapateextractvfx" },
    { 0xF86A, "helidrivable" },
    { 0xF86B, "helidrivabledeath" },
    { 0xF86C, "helidrivabledeathall" },
    { 0xF86D, "helidrivableenablesiteondeath" },
    { 0xF86E, "helidrivableenablesiteonflyaway" },
    { 0xF86F, "helidrivablemission" },
    { 0xF870, "helidrivablethink" },
    { 0xF871, "heliexfilthink" },
    { 0xF872, "heliexplode" },
    { 0xF873, "heliextractarrivewait" },
    { 0xF874, "heliextractcallback" },
    { 0xF875, "heliextractwait" },
    { 0xF876, "heligotoplunderrepository" },
    { 0xF877, "helihint_activate" },
    { 0xF878, "helihint_activate_vo" },
    { 0xF879, "helihint_deposit" },
    { 0xF87A, "helihint_deposit_vo" },
    { 0xF87B, "helihint_gotopad" },
    { 0xF87C, "helihint_gotopad_vo" },
    { 0xF87D, "helihint_logic" },
    { 0xF87E, "helihint_wait" },
    { 0xF87F, "helilandingorigin" },
    { 0xF880, "helileave" },
    { 0xF881, "helilifetime" },
    { 0xF882, "helimakeexfilwait" },
    { 0xF883, "helipad" },
    { 0xF884, "helipad_activated" },
    { 0xF885, "helipad_getheli" },
    { 0xF886, "helipadscriptable" },
    { 0xF887, "heliplayloopanim" },
    { 0xF888, "heliplayloopbadanim" },
    { 0xF889, "heliplayloopropeanim" },
    { 0xF88A, "helirpgenemy" },
    { 0xF88B, "helis_assault2" },
    { 0xF88C, "helis_assault2_check_size" },
    { 0xF88D, "helis_assault3" },
    { 0xF88E, "helis_assault3_check_size" },
    { 0xF88F, "helis_assault3_fob" },
    { 0xF890, "helis_assault3_fob_check_size" },
    { 0xF891, "helis_assault3_hangar" },
    { 0xF892, "helis_assault3_hangar_check_size" },
    { 0xF893, "helisetteamextractionhud" },
    { 0xF894, "helistoreplunder" },
    { 0xF895, "helitrig" },
    { 0xF896, "heliwaitatplunderrepository" },
    { 0xF897, "helperdrone_forcereconcontrolsoff" },
    { 0xF898, "helperdrone_isbeingpingedbydrone" },
    { 0xF899, "helperdrone_monitorcollision" },
    { 0xF89A, "helperdrone_notifyenemyplayersinrange" },
    { 0xF89B, "helperdrone_watchaltitude" },
    { 0xF89C, "helperdrone_watchscramblereffectdist" },
    { 0xF89D, "herodrop" },
    { 0xF89E, "hide_bomb_case_timer" },
    { 0xF89F, "hide_found_intel" },
    { 0xF8A0, "hide_headicon" },
    { 0xF8A1, "hide_health_bar_to_players" },
    { 0xF8A2, "hide_hud_on_game_end" },
    { 0xF8A3, "hide_minimap_on_spawn" },
    { 0xF8A4, "hide_name_fx_from_players" },
    { 0xF8A5, "hide_player_clip" },
    { 0xF8A6, "hide_plunderboxes" },
    { 0xF8A7, "hide_rocket_fuel_readings_to_player" },
    { 0xF8A8, "hideallunselectedextractpads" },
    { 0xF8A9, "hideassassinationtargethud" },
    { 0xF8AA, "hideconesifinfil" },
    { 0xF8AB, "hidedangercircle" },
    { 0xF8AC, "hidedeathicon" },
    { 0xF8AD, "hideextractionobjectivefromteam" },
    { 0xF8AE, "hidehistoryhudfromplayer" },
    { 0xF8AF, "hidehudclear" },
    { 0xF8B0, "hidehudintermission" },
    { 0xF8B1, "hideintelinstancefromplayer" },
    { 0xF8B2, "hideintelscriptablesfromplayer" },
    { 0xF8B3, "hideleaderhashuntilpercent" },
    { 0xF8B4, "hideplacementuntilpercent" },
    { 0xF8B5, "hidequestcirclefromplayer" },
    { 0xF8B6, "hidequestcircletoall" },
    { 0xF8B7, "hidequestobjiconfromplayer" },
    { 0xF8B8, "hiderespawntimer" },
    { 0xF8B9, "hidesafecircle" },
    { 0xF8BA, "hidescavengerhudfromplayer" },
    { 0xF8BB, "hidesecretstashhudfromplayer" },
    { 0xF8BC, "hidesmokinggunhudfromplayer" },
    { 0xF8BD, "hidetimedrunhudfromplayer" },
    { 0xF8BE, "hidex1finhudfromplayer" },
    { 0xF8BF, "hidex1stashhudfromplayer" },
    { 0xF8C0, "hiding_munitions_purchase" },
    { 0xF8C1, "highesttraceindex" },
    { 0xF8C2, "highlight_atvs_until_router" },
    { 0xF8C3, "highlighttoteam" },
    { 0xF8C4, "highlighttoteamonce" },
    { 0xF8C5, "hint_escape_maze" },
    { 0xF8C6, "hint_gasmask" },
    { 0xF8C7, "hint_obj_id" },
    { 0xF8C8, "hint_obj_name" },
    { 0xF8C9, "hint_outline_target_think" },
    { 0xF8CA, "hint_seq_button" },
    { 0xF8CB, "hint_target_think" },
    { 0xF8CC, "hintmdl" },
    { 0xF8CD, "hints_vo_audio" },
    { 0xF8CE, "hinttext" },
    { 0xF8CF, "his_completemission" },
    { 0xF8D0, "his_detectplayers" },
    { 0xF8D1, "his_ontimerexpired" },
    { 0xF8D2, "his_playerdisconnect" },
    { 0xF8D3, "his_removequestinstance" },
    { 0xF8D4, "his_respawn" },
    { 0xF8D5, "hit" },
    { 0xF8D6, "hit_by_emp_func" },
    { 0xF8D7, "hit_by_emp_internal" },
    { 0xF8D8, "hit_by_emp_monitor" },
    { 0xF8D9, "hit_pilot_head" },
    { 0xF8DA, "hitbytrain" },
    { 0xF8DB, "hitleashrange" },
    { 0xF8DC, "hitslocs" },
    { 0xF8DD, "hitsperattackforclass" },
    { 0xF8DE, "hitsperattackforvehicle" },
    { 0xF8DF, "hold_while_juggheli_alive" },
    { 0xF8E0, "holdallflagstimer" },
    { 0xF8E1, "holdoutafterspawnfunc" },
    { 0xF8E2, "holoeffect" },
    { 0xF8E3, "hoopty_initdamage" },
    { 0xF8E4, "hoopty_initomnvars" },
    { 0xF8E5, "hoopty_truck_initdamage" },
    { 0xF8E6, "hoopty_truck_initomnvars" },
    { 0xF8E7, "hostage_callout_saveme_time" },
    { 0xF8E8, "hostage_carrier_oob" },
    { 0xF8E9, "hostage_confirm_good_angles" },
    { 0xF8EA, "hostage_room_enemy_watcher" },
    { 0xF8EB, "hostage_vo" },
    { 0xF8EC, "hostagetemppistol" },
    { 0xF8ED, "hostattackfactormod" },
    { 0xF8EE, "hostdamagefactorhigh" },
    { 0xF8EF, "hostdamagefactorlow" },
    { 0xF8F0, "hostdamagefactormedium" },
    { 0xF8F1, "hostdamagepercenthigh" },
    { 0xF8F2, "hostdamagepercentlow" },
    { 0xF8F3, "hostdamagepercentmedium" },
    { 0xF8F4, "hostdefensefactormod" },
    { 0xF8F5, "hostoverride" },
    { 0xF8F6, "hostskipburndownhigh" },
    { 0xF8F7, "hostskipburndownlow" },
    { 0xF8F8, "hostskipburndownmedium" },
    { 0xF8F9, "hostvictimattackfactormod" },
    { 0xF8FA, "hostvictimdamagefactorhigh" },
    { 0xF8FB, "hostvictimdamagefactorlow" },
    { 0xF8FC, "hostvictimdamagefactormedium" },
    { 0xF8FD, "hostvictimdamagepercenthigh" },
    { 0xF8FE, "hostvictimdamagepercentlow" },
    { 0xF8FF, "hostvictimdamagepercentmedium" },
    { 0xF900, "hostvictimdefensefactormod" },
    { 0xF901, "hostvictimoverride" },
    { 0xF902, "hostvictimskipburndownhigh" },
    { 0xF903, "hostvictimskipburndownlow" },
    { 0xF904, "hostvictimskipburndownmedium" },
    { 0xF905, "hotfootabsloops" },
    { 0xF906, "hotfootdisttraveledsq" },
    { 0xF907, "hotfootlastposition" },
    { 0xF908, "hotfootreset" },
    { 0xF909, "hours" },
    { 0xF90A, "house_enter_animate_and_kill_player" },
    { 0xF90B, "hover_accel" },
    { 0xF90C, "hover_attack_direction" },
    { 0xF90D, "hover_attack_directions" },
    { 0xF90E, "hover_pattern_internal" },
    { 0xF90F, "hover_radius" },
    { 0xF910, "hover_speed" },
    { 0xF911, "hoverjet_watchgameend" },
    { 0xF912, "hoverpos" },
    { 0xF913, "hud_lap_scoreboard" },
    { 0xF914, "hud_racetrack_info" },
    { 0xF915, "hud_racetrack_timer" },
    { 0xF916, "hud_set_progress" },
    { 0xF917, "hud_set_timers" },
    { 0xF918, "hud_timer_reward_tiers" },
    { 0xF919, "hud_x_offset" },
    { 0xF91A, "hud_y_offset" },
    { 0xF91B, "hudattractionobj" },
    { 0xF91C, "hudcost" },
    { 0xF91D, "hudcoststring" },
    { 0xF91E, "huddopulse" },
    { 0xF91F, "hudelementsetupandposition" },
    { 0xF920, "hudextractmax" },
    { 0xF921, "hudextractnum" },
    { 0xF922, "hudglobalkillcount" },
    { 0xF923, "hudglobalkillcountmax" },
    { 0xF924, "hudkothbesttime" },
    { 0xF925, "hudkothbesttimelabel" },
    { 0xF926, "hudkothtimer" },
    { 0xF927, "hudnumconsumed" },
    { 0xF928, "hudnumtoconsume" },
    { 0xF929, "hudplunderstart" },
    { 0xF92A, "hudplunderstring" },
    { 0xF92B, "hudsbredeploy" },
    { 0xF92C, "hudzombie" },
    { 0xF92D, "humanpowersenabled" },
    { 0xF92E, "humanspawninair" },
    { 0xF92F, "hunters_killed_by_targets" },
    { 0xF930, "hunterswonending" },
    { 0xF931, "hurt_enabled" },
    { 0xF932, "hurt_trigger_active" },
    { 0xF933, "hurt_trigger_manage_dog_tag" },
    { 0xF934, "hurtplayersinbunker" },
    { 0xF935, "hvi_escort_exit" },
    { 0xF936, "hvi_escort_intro" },
    { 0xF937, "hvi_patrol_exit" },
    { 0xF938, "hvi_patrol_intro" },
    { 0xF939, "hvi_vehicle_rider_special_setup" },
    { 0xF93A, "hvt_anim_and_close_doors" },
    { 0xF93B, "hvt_can_lose_health" },
    { 0xF93C, "hvt_death_player_vo" },
    { 0xF93D, "hvt_delayed_cig" },
    { 0xF93E, "hvt_drop_from_truck_to_ground" },
    { 0xF93F, "hvt_key_dropped" },
    { 0xF940, "hvt_key_picked_up" },
    { 0xF941, "hvt_visual_callout" },
    { 0xF942, "hvt_visual_leaving_callout" },
    { 0xF943, "hvt_waittill_pickup_players_gobackup" },
    { 0xF944, "hvtboardingside" },
    { 0xF945, "hvtlist" },
    { 0xF946, "i_am_seeing_this_player" },
    { 0xF947, "i_see_laststand_player_watcher" },
    { 0xF948, "i_see_player_drone_watcher" },
    { 0xF949, "i_see_player_shield_watcher" },
    { 0xF94A, "i_see_player_vehicle_watcher" },
    { 0xF94B, "icon_trigger_enter" },
    { 0xF94C, "icon_trigger_exit" },
    { 0xF94D, "iconovertime" },
    { 0xF94E, "icontrigger" },
    { 0xF94F, "idflags_br_armor_break" },
    { 0xF950, "idflags_br_armor_hit" },
    { 0xF951, "idflags_hyper_burst_round" },
    { 0xF952, "idflags_no_dismemberment" },
    { 0xF953, "idflags_penetration_player_only" },
    { 0xF954, "idflags_source_left_hand" },
    { 0xF955, "idle_sfx" },
    { 0xF956, "idmask" },
    { 0xF957, "ignore" },
    { 0xF958, "ignore_fire_armor_check" },
    { 0xF959, "ignore_player_silencer" },
    { 0xF95A, "ignore_spawn_scoring_pois" },
    { 0xF95B, "ignoreafkcheck" },
    { 0xF95C, "ignoreattractions" },
    { 0xF95D, "ignoredeathsdoor" },
    { 0xF95E, "ignorefallback" },
    { 0xF95F, "ignoregulagredeploysplash" },
    { 0xF960, "ignorereset" },
    { 0xF961, "ignorevehicleexplosivedamage" },
    { 0xF962, "illumination_flare_init" },
    { 0xF963, "immediatecleanup" },
    { 0xF964, "immune_against_kick_for_inactivity" },
    { 0xF965, "impact_vfx" },
    { 0xF966, "impactfunc_carbon" },
    { 0xF967, "impactfunc_explo" },
    { 0xF968, "impactfunc_fire" },
    { 0xF969, "impactfunc_null" },
    { 0xF96A, "impactfunc_stun" },
    { 0xF96B, "impactshoulddestroyent" },
    { 0xF96C, "impactwatcher" },
    { 0xF96D, "impairedkill" },
    { 0xF96E, "implement_cointoss" },
    { 0xF96F, "impulsefx" },
    { 0xF970, "in_realism_mode" },
    { 0xF971, "in_world_scriptables_visible" },
    { 0xF972, "incendiary_pickup_watcher" },
    { 0xF973, "incomingcallback" },
    { 0xF974, "incomingremovedcallback" },
    { 0xF975, "incorrectcodeentered" },
    { 0xF976, "incorrectswitch" },
    { 0xF977, "increase_accuracy_after_delay" },
    { 0xF978, "increase_hp_from_relic_mythic" },
    { 0xF979, "increase_max_count_per_kill" },
    { 0xF97A, "increase_repair_script_maxdist" },
    { 0xF97B, "increase_sequence_tier" },
    { 0xF97C, "increase_total_count_per_module_call" },
    { 0xF97D, "increase_wave_ai_killed_counter" },
    { 0xF97E, "increase_wave_ai_spawned_counter" },
    { 0xF97F, "increment_factor" },
    { 0xF980, "increment_player_participation" },
    { 0xF981, "increment_timer" },
    { 0xF982, "incrementalrespawnpunish" },
    { 0xF983, "incrementalrespawnpunishmax" },
    { 0xF984, "incrementobjectiveachievementkill" },
    { 0xF985, "indanger" },
    { 0xF986, "infectbonusscore" },
    { 0xF987, "infectbonussuperonspawn" },
    { 0xF988, "infectbonussuperontacinsert" },
    { 0xF989, "infected_music" },
    { 0xF98A, "infectedairdroppositions" },
    { 0xF98B, "infecteddisablenvg" },
    { 0xF98C, "infectednightmode" },
    { 0xF98D, "infectedsupertwo" },
    { 0xF98E, "infectjugg_setconfig" },
    { 0xF98F, "infectparachuteheightoffset" },
    { 0xF990, "infectsetradaronnumsurvivors" },
    { 0xF991, "infil_chopper_dialogue" },
    { 0xF992, "infil_chopper_path_flags_manager" },
    { 0xF993, "infil_complete" },
    { 0xF994, "infil_driver" },
    { 0xF995, "infil_heli_jump_ahead" },
    { 0xF996, "infil_lbravo_damage_monitor" },
    { 0xF997, "infil_lbravo_is_alive" },
    { 0xF998, "infil_light_dvars" },
    { 0xF999, "infil_name" },
    { 0xF99A, "infil_plane_vo" },
    { 0xF99B, "infilcinematicactive" },
    { 0xF99C, "infilcoveroverlay" },
    { 0xF99D, "infilparachutevfx" },
    { 0xF99E, "infilplaneyaw" },
    { 0xF99F, "infilsactive" },
    { 0xF9A0, "infiltransistioning" },
    { 0xF9A1, "infilvideocompletecallback" },
    { 0xF9A2, "infilvideoplay" },
    { 0xF9A3, "infilvideopreload" },
    { 0xF9A4, "infilvideowaituntilcomplete" },
    { 0xF9A5, "infilweaponraise" },
    { 0xF9A6, "infinite_chopper" },
    { 0xF9A7, "ingame" },
    { 0xF9A8, "init_ai" },
    { 0xF9A9, "init_ai_kill_params_for_events" },
    { 0xF9AA, "init_ai_spawners" },
    { 0xF9AB, "init_ai_spawns" },
    { 0xF9AC, "init_ai_weapons" },
    { 0xF9AD, "init_airdrop_anims" },
    { 0xF9AE, "init_airlock" },
    { 0xF9AF, "init_airlock_buttons" },
    { 0xF9B0, "init_airlock_callbuttons" },
    { 0xF9B1, "init_airrop_vehicle_anims" },
    { 0xF9B2, "init_ammo_boxes" },
    { 0xF9B3, "init_and_start_whack_a_mole_sequence_data" },
    { 0xF9B4, "init_bomb_objective" },
    { 0xF9B5, "init_bomb_sites" },
    { 0xF9B6, "init_bombs" },
    { 0xF9B7, "init_bot_game_cyber" },
    { 0xF9B8, "init_br_jugg_setting" },
    { 0xF9B9, "init_cardprinter" },
    { 0xF9BA, "init_carepackages" },
    { 0xF9BB, "init_chopper_boss" },
    { 0xF9BC, "init_chopper_boss_battle" },
    { 0xF9BD, "init_civs" },
    { 0xF9BE, "init_client" },
    { 0xF9BF, "init_cp_aiparachute" },
    { 0xF9C0, "init_cp_execution" },
    { 0xF9C1, "init_cp_vehicle" },
    { 0xF9C2, "init_create_script_for_level" },
    { 0xF9C3, "init_createfx" },
    { 0xF9C4, "init_cs_oob_triggers" },
    { 0xF9C5, "init_death_animations" },
    { 0xF9C6, "init_defend_global_spawn_function" },
    { 0xF9C7, "init_door_ent_flags" },
    { 0xF9C8, "init_drop_locations" },
    { 0xF9C9, "init_ent_flag" },
    { 0xF9CA, "init_equipment" },
    { 0xF9CB, "init_escape_maze" },
    { 0xF9CC, "init_escape_silo" },
    { 0xF9CD, "init_exfil" },
    { 0xF9CE, "init_exit_doors" },
    { 0xF9CF, "init_fake_magic_grenades" },
    { 0xF9D0, "init_fan_blades" },
    { 0xF9D1, "init_first_button" },
    { 0xF9D2, "init_for_final_sequence" },
    { 0xF9D3, "init_freight_lift" },
    { 0xF9D4, "init_gas_trap_cloud" },
    { 0xF9D5, "init_gas_trap_cloud_parent" },
    { 0xF9D6, "init_gas_trap_damage_triggers" },
    { 0xF9D7, "init_gas_trap_room" },
    { 0xF9D8, "init_gas_vents" },
    { 0xF9D9, "init_gasmask" },
    { 0xF9DA, "init_gastrap" },
    { 0xF9DB, "init_gates" },
    { 0xF9DC, "init_global_cp_script_funcs" },
    { 0xF9DD, "init_ground_vehicle" },
    { 0xF9DE, "init_hack_console" },
    { 0xF9DF, "init_hacking_consoles" },
    { 0xF9E0, "init_hacking_consoles_internal" },
    { 0xF9E1, "init_infectgroundwarvehicles" },
    { 0xF9E2, "init_infil" },
    { 0xF9E3, "init_intel" },
    { 0xF9E4, "init_internal" },
    { 0xF9E5, "init_intro_anims" },
    { 0xF9E6, "init_intro_armor" },
    { 0xF9E7, "init_intro_heli_anims" },
    { 0xF9E8, "init_intro_obj" },
    { 0xF9E9, "init_jugg_maze" },
    { 0xF9EA, "init_key" },
    { 0xF9EB, "init_keypad_display_digits" },
    { 0xF9EC, "init_killstreak_data_for_challenges" },
    { 0xF9ED, "init_laser" },
    { 0xF9EE, "init_laser_panel_anims" },
    { 0xF9EF, "init_laser_trap" },
    { 0xF9F0, "init_laser_traps" },
    { 0xF9F1, "init_lbravo_spawn_after_level_restart" },
    { 0xF9F2, "init_leave_cave" },
    { 0xF9F3, "init_lethal_boxes" },
    { 0xF9F4, "init_level_drop_structs" },
    { 0xF9F5, "init_loadout_selection_structs" },
    { 0xF9F6, "init_loot_structs" },
    { 0xF9F7, "init_manned_turret" },
    { 0xF9F8, "init_manned_turret_settings" },
    { 0xF9F9, "init_map_data" },
    { 0xF9FA, "init_marquees" },
    { 0xF9FB, "init_mine_caves" },
    { 0xF9FC, "init_minigun_lifetime_shot_count" },
    { 0xF9FD, "init_nuke_vault" },
    { 0xF9FE, "init_nuke_vault_oil_puddles" },
    { 0xF9FF, "init_nuke_vault_scriptables" },
    { 0xFA00, "init_oscilloscopes" },
    { 0xFA01, "init_out_of_bounds_triggers" },
    { 0xFA02, "init_patches" },
    { 0xFA03, "init_petrograd_bsp_patch" },
    { 0xFA04, "init_pipe_room_obj" },
    { 0xFA05, "init_pipe_traps" },
    { 0xFA06, "init_placed_equipment" },
    { 0xFA07, "init_player_achievements" },
    { 0xFA08, "init_player_characters" },
    { 0xFA09, "init_player_falling_anims" },
    { 0xFA0A, "init_player_health" },
    { 0xFA0B, "init_player_plane_exit_anims" },
    { 0xFA0C, "init_post_bsp_entities" },
    { 0xFA0D, "init_post_bsp_fx" },
    { 0xFA0E, "init_preset_solutions" },
    { 0xFA0F, "init_pushable_minecart" },
    { 0xFA10, "init_range" },
    { 0xFA11, "init_range_target_show_damage" },
    { 0xFA12, "init_range_targets" },
    { 0xFA13, "init_ranges" },
    { 0xFA14, "init_reach_exhaust_waste" },
    { 0xFA15, "init_reach_icbm_launch" },
    { 0xFA16, "init_reach_pipe_room" },
    { 0xFA17, "init_reach_wind_room" },
    { 0xFA18, "init_relic_aggressive_melee" },
    { 0xFA19, "init_relic_ammo_drain" },
    { 0xFA1A, "init_relic_amped" },
    { 0xFA1B, "init_relic_bang_and_boom" },
    { 0xFA1C, "init_relic_damage_from_above" },
    { 0xFA1D, "init_relic_dfa" },
    { 0xFA1E, "init_relic_dogtags" },
    { 0xFA1F, "init_relic_doomslayer" },
    { 0xFA20, "init_relic_doubletap" },
    { 0xFA21, "init_relic_explodedmg" },
    { 0xFA22, "init_relic_fastbleedout" },
    { 0xFA23, "init_relic_focus_fire" },
    { 0xFA24, "init_relic_gas_martyr" },
    { 0xFA25, "init_relic_grounded" },
    { 0xFA26, "init_relic_gun_game" },
    { 0xFA27, "init_relic_headbullets" },
    { 0xFA28, "init_relic_healthpacks" },
    { 0xFA29, "init_relic_hideobjicons" },
    { 0xFA2A, "init_relic_landlocked" },
    { 0xFA2B, "init_relic_laststand" },
    { 0xFA2C, "init_relic_laststandmelee" },
    { 0xFA2D, "init_relic_lfo" },
    { 0xFA2E, "init_relic_martyrdom" },
    { 0xFA2F, "init_relic_mythic" },
    { 0xFA30, "init_relic_no_ammo_mun" },
    { 0xFA31, "init_relic_nobulletdamage" },
    { 0xFA32, "init_relic_noks" },
    { 0xFA33, "init_relic_noluck" },
    { 0xFA34, "init_relic_noregen" },
    { 0xFA35, "init_relic_nuketimer" },
    { 0xFA36, "init_relic_oneclip" },
    { 0xFA37, "init_relic_punchbullets" },
    { 0xFA38, "init_relic_rocket_kill_ammo" },
    { 0xFA39, "init_relic_shieldsonly" },
    { 0xFA3A, "init_relic_squadlink" },
    { 0xFA3B, "init_relic_steelballs" },
    { 0xFA3C, "init_relic_team_proximity" },
    { 0xFA3D, "init_relic_thirdperson" },
    { 0xFA3E, "init_relic_trex" },
    { 0xFA3F, "init_relic_vampire" },
    { 0xFA40, "init_relic_vars" },
    { 0xFA41, "init_respawns" },
    { 0xFA42, "init_rpg_spawns" },
    { 0xFA43, "init_safehouse_gunshop" },
    { 0xFA44, "init_season3_intel_challenges" },
    { 0xFA45, "init_sentry_traps" },
    { 0xFA46, "init_seq_button" },
    { 0xFA47, "init_server" },
    { 0xFA48, "init_shooting_targets" },
    { 0xFA49, "init_silo_elevator" },
    { 0xFA4A, "init_silo_jump_obj" },
    { 0xFA4B, "init_silo_platforms" },
    { 0xFA4C, "init_silo_thrust_obj" },
    { 0xFA4D, "init_spawn_modules" },
    { 0xFA4E, "init_standard_range" },
    { 0xFA4F, "init_structs" },
    { 0xFA50, "init_structs_mp_br_mechanics" },
    { 0xFA51, "init_structs_mp_don3" },
    { 0xFA52, "init_subway_cars" },
    { 0xFA53, "init_swivelroom_currsolution_marquee" },
    { 0xFA54, "init_swivelroom_obj" },
    { 0xFA55, "init_swivelroom_variables" },
    { 0xFA56, "init_tactical_boxes" },
    { 0xFA57, "init_tape_machine_animations" },
    { 0xFA58, "init_timed_laser_trap_trigger" },
    { 0xFA59, "init_timer" },
    { 0xFA5A, "init_track" },
    { 0xFA5B, "init_track_point" },
    { 0xFA5C, "init_track_settings" },
    { 0xFA5D, "init_tracks" },
    { 0xFA5E, "init_train_arrays" },
    { 0xFA5F, "init_trans_1_obj" },
    { 0xFA60, "init_trap_room" },
    { 0xFA61, "init_trap_room_debug" },
    { 0xFA62, "init_trap_room_doors" },
    { 0xFA63, "init_trap_room_interactions" },
    { 0xFA64, "init_trap_room_obj" },
    { 0xFA65, "init_trap_room_spawning_module" },
    { 0xFA66, "init_trap_room_traps" },
    { 0xFA67, "init_trap_room_vfx" },
    { 0xFA68, "init_trap_room_wave" },
    { 0xFA69, "init_trigger_spawn" },
    { 0xFA6A, "init_trigger_spawners" },
    { 0xFA6B, "init_turrets" },
    { 0xFA6C, "init_tut_doors" },
    { 0xFA6D, "init_unlock_silo" },
    { 0xFA6E, "init_usb_animations" },
    { 0xFA6F, "init_vault_assault_infil" },
    { 0xFA70, "init_vault_assault_retrieve_saw" },
    { 0xFA71, "init_vo_arrays" },
    { 0xFA72, "init_warning_levels" },
    { 0xFA73, "init_weapon_box_caches" },
    { 0xFA74, "init_weapon_placements" },
    { 0xFA75, "init_weapon_spawns" },
    { 0xFA76, "init_weapon_variant_spawns" },
    { 0xFA77, "init_wind_tunnels" },
    { 0xFA78, "initarmor" },
    { 0xFA79, "initarmsraceanims" },
    { 0xFA7A, "initbattleroyalec130airdropcratedata" },
    { 0xFA7B, "initbattleroyalejuggernautcratedata" },
    { 0xFA7C, "initbattleroyalelootchoppercratedata" },
    { 0xFA7D, "initbrc130airdropdropanims" },
    { 0xFA7E, "initbrmechanics" },
    { 0xFA7F, "initbunker" },
    { 0xFA80, "initbunker11keypad" },
    { 0xFA81, "initbunkeranims" },
    { 0xFA82, "initbunkerbackwallkeypads" },
    { 0xFA83, "initbunkerdoor" },
    { 0xFA84, "initbunkerdooreffects" },
    { 0xFA85, "initbunkervfx" },
    { 0xFA86, "initcallbacks" },
    { 0xFA87, "initcarriables" },
    { 0xFA88, "initcashtracking" },
    { 0xFA89, "initchallengeandeventglobals" },
    { 0xFA8A, "initcircledata" },
    { 0xFA8B, "initcirclepoststarttocircleindex" },
    { 0xFA8C, "initcircuitbreakers" },
    { 0xFA8D, "initcpammoarmorcrate" },
    { 0xFA8E, "initcprooftopcrate" },
    { 0xFA8F, "initcrossbowusage" },
    { 0xFA90, "initdialog" },
    { 0xFA91, "initdismembermentlist" },
    { 0xFA92, "initdragonsbreathusage" },
    { 0xFA93, "initdropbagvo" },
    { 0xFA94, "initdroplocations" },
    { 0xFA95, "initendcameralocations" },
    { 0xFA96, "initevents" },
    { 0xFA97, "initextractionlocations" },
    { 0xFA98, "initheadlessoperatorcustomization" },
    { 0xFA99, "initheliextractanims" },
    { 0xFA9A, "inithelipropanims" },
    { 0xFA9B, "inithelirepository" },
    { 0xFA9C, "initial_allies" },
    { 0xFA9D, "initial_angles" },
    { 0xFA9E, "initial_enemy_spawner" },
    { 0xFA9F, "initial_forward" },
    { 0xFAA0, "initial_right" },
    { 0xFAA1, "initial_timer" },
    { 0xFAA2, "initialize_create_script" },
    { 0xFAA3, "initialize_create_script_file" },
    { 0xFAA4, "initialize_flag_role" },
    { 0xFAA5, "initialize_laser_trap_entity" },
    { 0xFAA6, "initialize_registered_create_script_files" },
    { 0xFAA7, "initialize_switches_pattern" },
    { 0xFAA8, "initialize_water_trap" },
    { 0xFAA9, "initializeaardata" },
    { 0xFAAA, "initializerocketfuelreadings" },
    { 0xFAAB, "initiallandingcomplete" },
    { 0xFAAC, "initialprespawn" },
    { 0xFAAD, "initialwinningteam" },
    { 0xFAAE, "initindividualgastrap" },
    { 0xFAAF, "initleaderboardstat" },
    { 0xFAB0, "initlethalmaxoffsetmap" },
    { 0xFAB1, "initlocationcircle" },
    { 0xFAB2, "initlocs_bunkertest" },
    { 0xFAB3, "initlocs_codeprovidingphones" },
    { 0xFAB4, "initlocs_computer" },
    { 0xFAB5, "initlocs_donetsk" },
    { 0xFAB6, "initlocs_keypads" },
    { 0xFAB7, "initlocs_morsephones" },
    { 0xFAB8, "initlocs_nonmorsephones" },
    { 0xFAB9, "initlocs_phones" },
    { 0xFABA, "initlocs_radio" },
    { 0xFABB, "initlocs_test" },
    { 0xFABC, "initlootvaultkeypad" },
    { 0xFABD, "initnonbr" },
    { 0xFABE, "initnonbunkerdoorkeypad" },
    { 0xFABF, "initnonbunkerdoors" },
    { 0xFAC0, "initoperationcratedata" },
    { 0xFAC1, "initoperatorunlocks" },
    { 0xFAC2, "initpayloadpunish" },
    { 0xFAC3, "initplayerplunderevents" },
    { 0xFAC4, "initplunderpads" },
    { 0xFAC5, "initpostmain" },
    { 0xFAC6, "initprematchc130" },
    { 0xFAC7, "initprematchspawnlocations" },
    { 0xFAC8, "initpropcircles" },
    { 0xFAC9, "initscriptablemanagement" },
    { 0xFACA, "initsharedomnvars" },
    { 0xFACB, "initship" },
    { 0xFACC, "initsolospawnstruct" },
    { 0xFACD, "initspawnsoverridefunc" },
    { 0xFACE, "initspawnswar" },
    { 0xFACF, "initsquadspawnstruct" },
    { 0xFAD0, "initstandardloadout" },
    { 0xFAD1, "initteamdatafields" },
    { 0xFAD2, "initthermometerwatch" },
    { 0xFAD3, "inittmtylapproach" },
    { 0xFAD4, "initturretinteraction" },
    { 0xFAD5, "inittutzones" },
    { 0xFAD6, "initusage" },
    { 0xFAD7, "initvehicles" },
    { 0xFAD8, "initvo" },
    { 0xFAD9, "inmapbounds" },
    { 0xFADA, "inner" },
    { 0xFADB, "inneurotoxintimestamp" },
    { 0xFADC, "insertingarmorplate" },
    { 0xFADD, "inside_bush" },
    { 0xFADE, "insidecuavbunker" },
    { 0xFADF, "instance" },
    { 0xFAE0, "instant_revive_buffer" },
    { 0xFAE1, "instant_revived" },
    { 0xFAE2, "instantbleedoutsquadwipe" },
    { 0xFAE3, "intel_active" },
    { 0xFAE4, "intel_collect_vo_func" },
    { 0xFAE5, "intel_collected" },
    { 0xFAE6, "intel_guys" },
    { 0xFAE7, "intel_loc" },
    { 0xFAE8, "intel_location_vo" },
    { 0xFAE9, "intel_pickup_vo" },
    { 0xFAEA, "intel_pieces" },
    { 0xFAEB, "intel_spawn" },
    { 0xFAEC, "intel_spawn_listener" },
    { 0xFAED, "intel_use_logic" },
    { 0xFAEE, "intel_used_logic" },
    { 0xFAEF, "intelchallengesdata" },
    { 0xFAF0, "intelprogress" },
    { 0xFAF1, "intelused" },
    { 0xFAF2, "interaction_get_cost" },
    { 0xFAF3, "interaction_is_floor_is_lava_client" },
    { 0xFAF4, "interaction_is_jugg_maze_button" },
    { 0xFAF5, "interaction_point_has_changed" },
    { 0xFAF6, "interactionusethink" },
    { 0xFAF7, "interior_door_interaction" },
    { 0xFAF8, "interiordoor" },
    { 0xFAF9, "intermissionspawnorigin" },
    { 0xFAFA, "intermissionspawntime" },
    { 0xFAFB, "internal_isplayerindanger_think" },
    { 0xFAFC, "interruptbombplanting" },
    { 0xFAFD, "intro_addplayer" },
    { 0xFAFE, "intro_drive_along_path" },
    { 0xFAFF, "intro_driver_logic" },
    { 0xFB00, "intro_enemy_respawner" },
    { 0xFB01, "intro_fadeup" },
    { 0xFB02, "intro_heli" },
    { 0xFB03, "intro_heli_add_player" },
    { 0xFB04, "intro_heli_animate_player" },
    { 0xFB05, "intro_moveplayercliphack" },
    { 0xFB06, "intro_ride" },
    { 0xFB07, "intro_safehouse_edit_loadout" },
    { 0xFB08, "intro_safehouse_loot" },
    { 0xFB09, "intro_spawn_enemies" },
    { 0xFB0A, "intro_techos_deposit_backseats" },
    { 0xFB0B, "intro_techos_deposit_fullcar" },
    { 0xFB0C, "introarmor" },
    { 0xFB0D, "introcinematic" },
    { 0xFB0E, "intstruct" },
    { 0xFB0F, "invalid_for_teleport" },
    { 0xFB10, "investigate_someone_using_bomb" },
    { 0xFB11, "invuln_to_veh_crush" },
    { 0xFB12, "invulnerable_airdropmultiple_ac130s" },
    { 0xFB13, "is_a_player_near" },
    { 0xFB14, "is_ai_facing_point" },
    { 0xFB15, "is_ai_in_stealth" },
    { 0xFB16, "is_ambient" },
    { 0xFB17, "is_any_player_in_region" },
    { 0xFB18, "is_any_player_in_safehouse" },
    { 0xFB19, "is_area_in_verdansk" },
    { 0xFB1A, "is_ascender_use_allowed" },
    { 0xFB1B, "is_at_mine_moving" },
    { 0xFB1C, "is_attack_available" },
    { 0xFB1D, "is_available_for_hack" },
    { 0xFB1E, "is_bomb_use_allowed" },
    { 0xFB1F, "is_correct_wire_color" },
    { 0xFB20, "is_correct_wire_color_sync" },
    { 0xFB21, "is_cover_node" },
    { 0xFB22, "is_cp_raid" },
    { 0xFB23, "is_cs_script_origin" },
    { 0xFB24, "is_cs_scriptable" },
    { 0xFB25, "is_current_solution_correct" },
    { 0xFB26, "is_dead" },
    { 0xFB27, "is_defending_bombzone" },
    { 0xFB28, "is_done_speaking" },
    { 0xFB29, "is_dropping_hostage" },
    { 0xFB2A, "is_eliminate_drone_attack_available" },
    { 0xFB2B, "is_enemy_dangerous" },
    { 0xFB2C, "is_enemy_of_type" },
    { 0xFB2D, "is_exploder" },
    { 0xFB2E, "is_far_from_team" },
    { 0xFB2F, "is_first_time_high_tier" },
    { 0xFB30, "is_goal_crowded" },
    { 0xFB31, "is_greater_than_equal_to" },
    { 0xFB32, "is_helicopter_player_occupied" },
    { 0xFB33, "is_hostage_oob" },
    { 0xFB34, "is_in_gas" },
    { 0xFB35, "is_in_kill_zone_or_under_bridge_zone" },
    { 0xFB36, "is_inflictor_a_carepackage" },
    { 0xFB37, "is_instant_use_munition" },
    { 0xFB38, "is_kidnapping_player" },
    { 0xFB39, "is_killstreak_valid_for_swat" },
    { 0xFB3A, "is_lower" },
    { 0xFB3B, "is_main_pilot" },
    { 0xFB3C, "is_minimap_forcedisabled" },
    { 0xFB3D, "is_module_active" },
    { 0xFB3E, "is_moving_platform_train" },
    { 0xFB3F, "is_object_allowed_in_gametype" },
    { 0xFB40, "is_on" },
    { 0xFB41, "is_one_player_near_point2d" },
    { 0xFB42, "is_opened" },
    { 0xFB43, "is_operations_gametype" },
    { 0xFB44, "is_player_damage_disabled" },
    { 0xFB45, "is_player_in_aggro" },
    { 0xFB46, "is_player_in_focus_fire_attacker_list" },
    { 0xFB47, "is_player_part_exposed_to_chopper_boss" },
    { 0xFB48, "is_player_valid_for_team_proximity" },
    { 0xFB49, "is_playing_vo" },
    { 0xFB4A, "is_point_in_cylinder" },
    { 0xFB4B, "is_position_open" },
    { 0xFB4C, "is_raid_gamemode" },
    { 0xFB4D, "is_relic_active" },
    { 0xFB4E, "is_relic_collat_dmg_active" },
    { 0xFB4F, "is_relic_swat_active" },
    { 0xFB50, "is_riding_hel" },
    { 0xFB51, "is_riding_heli" },
    { 0xFB52, "is_same_combat_action" },
    { 0xFB53, "is_scriptable_healthy" },
    { 0xFB54, "is_so_stars_enabled" },
    { 0xFB55, "is_spawner_position_valid" },
    { 0xFB56, "is_specops_gametype" },
    { 0xFB57, "is_station_active" },
    { 0xFB58, "is_station_track_available" },
    { 0xFB59, "is_stealth_sequence_activated" },
    { 0xFB5A, "is_subway_car_deployed" },
    { 0xFB5B, "is_suicidebomber" },
    { 0xFB5C, "is_tmtyl_interrogationvo_playing" },
    { 0xFB5D, "is_train_ent" },
    { 0xFB5E, "is_trials_level" },
    { 0xFB5F, "is_two_hit_melee_weapon" },
    { 0xFB60, "is_using_stealth_debug" },
    { 0xFB61, "is_valid_station_name" },
    { 0xFB62, "is_valid_track_name" },
    { 0xFB63, "is_vandalize_attack_available" },
    { 0xFB64, "is_wave_exist" },
    { 0xFB65, "is_wave_gametype" },
    { 0xFB66, "is_wave_hud_enabled" },
    { 0xFB67, "isaccesscard" },
    { 0xFB68, "isairlockdoor" },
    { 0xFB69, "isakimbo" },
    { 0xFB6A, "isakimbomeleeweapon" },
    { 0xFB6B, "isallowedweapon" },
    { 0xFB6C, "isaltbunkerscriptable" },
    { 0xFB6D, "isangleoffset" },
    { 0xFB6E, "isanyplayertouching" },
    { 0xFB6F, "isanytutorialorbotpracticematch" },
    { 0xFB70, "isapcblockedbyplayer" },
    { 0xFB71, "isassaultdrone" },
    { 0xFB72, "isassaulting" },
    { 0xFB73, "isattachmentgrenadelauncher" },
    { 0xFB74, "isattachmentselectfire" },
    { 0xFB75, "isattachmentvariantinvalid" },
    { 0xFB76, "isattachmentvariantlocked" },
    { 0xFB77, "isautouse" },
    { 0xFB78, "isballisticspecial" },
    { 0xFB79, "isbecomingzombie" },
    { 0xFB7A, "isbestplayertime" },
    { 0xFB7B, "isblindedby" },
    { 0xFB7C, "isblocked" },
    { 0xFB7D, "isbossheli" },
    { 0xFB7E, "isbotmedicrole" },
    { 0xFB7F, "isbotpracticematch" },
    { 0xFB80, "isbrgametypefuncdefined" },
    { 0xFB81, "isbrsquadleader" },
    { 0xFB82, "isbulletpenetration" },
    { 0xFB83, "isbunkeraltenabled" },
    { 0xFB84, "isburstweapon" },
    { 0xFB85, "iscacprimaryweapongroup" },
    { 0xFB86, "iscacsecondaryweapongroup" },
    { 0xFB87, "iscaliberattachment" },
    { 0xFB88, "iscarriablescriptable" },
    { 0xFB89, "iscash" },
    { 0xFB8A, "iscloseto" },
    { 0xFB8B, "iscodecorrect" },
    { 0xFB8C, "iscontender" },
    { 0xFB8D, "iscopiedclass" },
    { 0xFB8E, "iscrossbowbolt" },
    { 0xFB8F, "iscrossbowdamage" },
    { 0xFB90, "iscrossbowspecial" },
    { 0xFB91, "isdeathshieldskippingenabled" },
    { 0xFB92, "isdevbuild" },
    { 0xFB93, "isdisconnecting" },
    { 0xFB94, "isdisconnectplayer" },
    { 0xFB95, "isdmzbotpracticematch" },
    { 0xFB96, "isdmztutorial" },
    { 0xFB97, "isdonetskmap" },
    { 0xFB98, "isdonetsksubmap" },
    { 0xFB99, "isdooropened" },
    { 0xFB9A, "isdragonsbreath" },
    { 0xFB9B, "isdragonsbreathweapon" },
    { 0xFB9C, "isdroppablepickup" },
    { 0xFB9D, "isdying" },
    { 0xFB9E, "iseligibleforteamrevive" },
    { 0xFB9F, "isempdamage" },
    { 0xFBA0, "isenemyteamagent" },
    { 0xFBA1, "isenemyteamplayer" },
    { 0xFBA2, "isenvironmentalscriptableinflictor" },
    { 0xFBA3, "isequipmentselectable" },
    { 0xFBA4, "isexcessivescoreboosting" },
    { 0xFBA5, "isfeaturedisabled" },
    { 0xFBA6, "isfeatureenabled" },
    { 0xFBA7, "isffprotectedaction" },
    { 0xFBA8, "isfirstactivation" },
    { 0xFBA9, "isflagcarrymode" },
    { 0xFBAA, "isforcekillstreakprogressweapon" },
    { 0xFBAB, "isfriendlyfireprotectedperiod" },
    { 0xFBAC, "isfromkillstreak" },
    { 0xFBAD, "isfuelreadingoptimal" },
    { 0xFBAE, "isgivingup" },
    { 0xFBAF, "isgrenade" },
    { 0xFBB0, "isgroundwarcoremode" },
    { 0xFBB1, "isgroundwardom" },
    { 0xFBB2, "isgroundwarinfected" },
    { 0xFBB3, "isgroundwarsiege" },
    { 0xFBB4, "isgulagpaused" },
    { 0xFBB5, "isgunlessweapon" },
    { 0xFBB6, "ishelperdrone" },
    { 0xFBB7, "ishost" },
    { 0xFBB8, "ishotjoiningplayer" },
    { 0xFBB9, "isincircle" },
    { 0xFBBA, "isinlaststand" },
    { 0xFBBB, "isinrewardflow" },
    { 0xFBBC, "iskillstreakdeployweapon" },
    { 0xFBBD, "iskillstreakvehicle" },
    { 0xFBBE, "iskillstreakvehicleinflictor" },
    { 0xFBBF, "iskilltradedamage" },
    { 0xFBC0, "iskingofthehillactive" },
    { 0xFBC1, "iskioskfiresaleactiveforplayer" },
    { 0xFBC2, "islargebrmap" },
    { 0xFBC3, "islaststandbleedoutdmg" },
    { 0xFBC4, "islaststandskippingenabled" },
    { 0xFBC5, "isloadinggulag" },
    { 0xFBC6, "isloadoutindexdefault" },
    { 0xFBC7, "islocked" },
    { 0xFBC8, "islongshotspecial" },
    { 0xFBC9, "ismeleeoverrideweapon" },
    { 0xFBCA, "isminigunweapon" },
    { 0xFBCB, "ismortartargeted" },
    { 0xFBCC, "ismountconfigenabled" },
    { 0xFBCD, "ismountdisabled" },
    { 0xFBCE, "isnearactivejugg" },
    { 0xFBCF, "isnearajuggdrop" },
    { 0xFBD0, "isnokillstreakprogressweapon" },
    { 0xFBD1, "isnonequippable" },
    { 0xFBD2, "isnonnvgnightmap" },
    { 0xFBD3, "isonlastkill" },
    { 0xFBD4, "isonturret" },
    { 0xFBD5, "isopenable" },
    { 0xFBD6, "isoutside" },
    { 0xFBD7, "isparachutespawning" },
    { 0xFBD8, "ispayloadautomaticallymoving" },
    { 0xFBD9, "ispayloadpaused" },
    { 0xFBDA, "ispickupblueprintloadouts" },
    { 0xFBDB, "isplacementplayerobstructed" },
    { 0xFBDC, "isplanejump" },
    { 0xFBDD, "isplatepouch" },
    { 0xFBDE, "isplayerbrsquadleader" },
    { 0xFBDF, "isplayerindanger_think" },
    { 0xFBE0, "isplayerinorgoingtogulag" },
    { 0xFBE1, "isplayerinsiderectangularzone" },
    { 0xFBE2, "isplayerinsiderectangularzonebasedonent" },
    { 0xFBE3, "isplayerloading" },
    { 0xFBE4, "isplayermatched" },
    { 0xFBE5, "isplayeronground" },
    { 0xFBE6, "isplayeronintelchallenge" },
    { 0xFBE7, "isplayerusingtablet" },
    { 0xFBE8, "isplayervalidrespawntarget" },
    { 0xFBE9, "isplayinganim" },
    { 0xFBEA, "isplunderextractionenabled" },
    { 0xFBEB, "ispointincurrentcircle" },
    { 0xFBEC, "ispointinnextsafecircle" },
    { 0xFBED, "ispointinsidecircle" },
    { 0xFBEE, "ispointnearcurrentsafecircle" },
    { 0xFBEF, "ispointnearsoloascenderline" },
    { 0xFBF0, "ispointpaststart2d" },
    { 0xFBF1, "ispresstofirstspawnmode" },
    { 0xFBF2, "isprogressionlevel" },
    { 0xFBF3, "isprogressionmismatch" },
    { 0xFBF4, "isprophunt" },
    { 0xFBF5, "isprophuntgametype" },
    { 0xFBF6, "ispubliceventoftypeactive" },
    { 0xFBF7, "isquestinstancealocale" },
    { 0xFBF8, "isquesttablet" },
    { 0xFBF9, "israndomarloadouts" },
    { 0xFBFA, "israndomblueprintsloadouts" },
    { 0xFBFB, "israndomcustomblueprintsloadouts" },
    { 0xFBFC, "israndomlmgloadouts" },
    { 0xFBFD, "israndomnoattachmentloadouts" },
    { 0xFBFE, "israndompistolloadouts" },
    { 0xFBFF, "israndomshotgunloadouts" },
    { 0xFC00, "israndomsmgloadouts" },
    { 0xFC01, "israndomsniperloadouts" },
    { 0xFC02, "isrearcriticaldamage" },
    { 0xFC03, "isredeploykeepweapons" },
    { 0xFC04, "isremotekillstreaktabletweapon" },
    { 0xFC05, "isrespawningfromtoken" },
    { 0xFC06, "isrevivepickup" },
    { 0xFC07, "issameteamagent" },
    { 0xFC08, "issameteamplayer" },
    { 0xFC09, "isscriptedagentdamage" },
    { 0xFC0A, "isselectable" },
    { 0xFC0B, "isselfreviving" },
    { 0xFC0C, "isshield" },
    { 0xFC0D, "isshuttingdown" },
    { 0xFC0E, "issidecriticaldamage" },
    { 0xFC0F, "issidehouseobjective" },
    { 0xFC10, "issilencedbarrel" },
    { 0xFC11, "issilencerattach" },
    { 0xFC12, "isskydivestatedisabled" },
    { 0xFC13, "issmallsplashdamage" },
    { 0xFC14, "issmokinggun" },
    { 0xFC15, "issnipersemi" },
    { 0xFC16, "isspawningstopped" },
    { 0xFC17, "isspecialcaseweapon" },
    { 0xFC18, "isspecialistbonus" },
    { 0xFC19, "isspecialiststreak" },
    { 0xFC1A, "isspreadweapon" },
    { 0xFC1B, "isstandardsandbox" },
    { 0xFC1C, "isstunnedby" },
    { 0xFC1D, "issubgametype" },
    { 0xFC1E, "istacticalbc" },
    { 0xFC1F, "isteameliminated" },
    { 0xFC20, "isteamextracted" },
    { 0xFC21, "isteamonlycrate" },
    { 0xFC22, "isteamplacementsbmmmode" },
    { 0xFC23, "isteamvoplaying" },
    { 0xFC24, "istempsfxent" },
    { 0xFC25, "isthrowingknifeequipment" },
    { 0xFC26, "istrialslevel" },
    { 0xFC27, "istripwiredamagetype" },
    { 0xFC28, "istutorial" },
    { 0xFC29, "istwohandedoffhand" },
    { 0xFC2A, "isused" },
    { 0xFC2B, "isuseobject" },
    { 0xFC2C, "isusingammobox" },
    { 0xFC2D, "isusingremotekillstreak" },
    { 0xFC2E, "isusingtacmap" },
    { 0xFC2F, "isvalidanimsuiteentity" },
    { 0xFC30, "isvalidattachmentunlock" },
    { 0xFC31, "isvalidcustomweapon" },
    { 0xFC32, "isvalidinflictorc4vehicle" },
    { 0xFC33, "isvalidkillcam" },
    { 0xFC34, "isvalidpointinbounds" },
    { 0xFC35, "isvalidpos" },
    { 0xFC36, "isvalidspectatetarget" },
    { 0xFC37, "isvehicleindanger" },
    { 0xFC38, "isverdansksubmap" },
    { 0xFC39, "isweaponsilenced" },
    { 0xFC3A, "isweaponuihidden" },
    { 0xFC3B, "isweaponvariantlocked" },
    { 0xFC3C, "iswithinplanepathsaferadius" },
    { 0xFC3D, "iswztrain" },
    { 0xFC3E, "isx1ops" },
    { 0xFC3F, "isxmike109damage" },
    { 0xFC40, "isxmike109explosivedamage" },
    { 0xFC41, "isxmike109explosiveheadshot" },
    { 0xFC42, "isxmike109projectile" },
    { 0xFC43, "item_collision_ignorefutureevent" },
    { 0xFC44, "itemname" },
    { 0xFC45, "itemproxtriggerthink" },
    { 0xFC46, "itemsinworld" },
    { 0xFC47, "itemslotindex" },
    { 0xFC48, "iw8_ship_hack_add_flag_node" },
    { 0xFC49, "iwbestscore" },
    { 0xFC4A, "jailbreakeventplayer" },
    { 0xFC4B, "jailloadout" },
    { 0xFC4C, "jailtime" },
    { 0xFC4D, "jailtimeoutend" },
    { 0xFC4E, "jailtimeouthud" },
    { 0xFC4F, "jammer_vo_played_time" },
    { 0xFC50, "javelin_ammo_refill_use_monitor" },
    { 0xFC51, "javelin_forceclear" },
    { 0xFC52, "javelin_interact_monitor" },
    { 0xFC53, "jeep" },
    { 0xFC54, "jeep_horn" },
    { 0xFC55, "jeep_initcollision" },
    { 0xFC56, "jeep_initdamage" },
    { 0xFC57, "jeep_initomnvars" },
    { 0xFC58, "joininprogresstimeout" },
    { 0xFC59, "jug_encounter_test" },
    { 0xFC5A, "jug_reinforce" },
    { 0xFC5B, "jug_spawn_func" },
    { 0xFC5C, "jug_trig_spawn" },
    { 0xFC5D, "jug_trigger_spawn" },
    { 0xFC5E, "jugg_addtoactivejugglist" },
    { 0xFC5F, "jugg_assault3_check_size" },
    { 0xFC60, "jugg_canparachute" },
    { 0xFC61, "jugg_canreload" },
    { 0xFC62, "jugg_canuseweaponpickups" },
    { 0xFC63, "jugg_combo" },
    { 0xFC64, "jugg_disableoverlayonentergulag" },
    { 0xFC65, "jugg_dmg_debug" },
    { 0xFC66, "jugg_enter_combat_callback" },
    { 0xFC67, "jugg_get_closest_attackable_player" },
    { 0xFC68, "jugg_get_priority_player" },
    { 0xFC69, "jugg_getminigunweapon" },
    { 0xFC6A, "jugg_go_to_node_callback" },
    { 0xFC6B, "jugg_health_debug" },
    { 0xFC6C, "jugg_idle_until_shot_or_near" },
    { 0xFC6D, "jugg_managestockammo" },
    { 0xFC6E, "jugg_maze_killtrigger" },
    { 0xFC6F, "jugg_modifyfalldamage" },
    { 0xFC70, "jugg_modifyherodroptoplayerdamage" },
    { 0xFC71, "jugg_modifyvehicletoplayerdamage" },
    { 0xFC72, "jugg_objective_struct" },
    { 0xFC73, "jugg_protect_jammer" },
    { 0xFC74, "jugg_protect_jammer_internal" },
    { 0xFC75, "jugg_pursue_players" },
    { 0xFC76, "jugg_pursue_target" },
    { 0xFC77, "jugg_removefromactivejugglist" },
    { 0xFC78, "jugg_setherodropscriptable" },
    { 0xFC79, "jugg_source" },
    { 0xFC7A, "jugg_strip_old_weapons" },
    { 0xFC7B, "jugg_watchammo" },
    { 0xFC7C, "jugg_watchearlyexit" },
    { 0xFC7D, "jugg_watchfordoors" },
    { 0xFC7E, "jugg_watchforfire" },
    { 0xFC7F, "jugg_watchforremovejugg" },
    { 0xFC80, "jugg_watchherodrop" },
    { 0xFC81, "jugg_watchmanualreload" },
    { 0xFC82, "juggcanusecrate" },
    { 0xFC83, "juggdroplocations" },
    { 0xFC84, "juggerbear" },
    { 0xFC85, "juggernaut_damage_override" },
    { 0xFC86, "juggernaut_damage_thread" },
    { 0xFC87, "juggernaut_death_test" },
    { 0xFC88, "juggernaut_death_watcher" },
    { 0xFC89, "juggernaut_dmg_modifier" },
    { 0xFC8A, "juggernaut_getavoidanceposition" },
    { 0xFC8B, "juggernaut_kill_assists_included" },
    { 0xFC8C, "juggernaut_kills_tracker" },
    { 0xFC8D, "juggernaut_logic" },
    { 0xFC8E, "juggernaut_pincer" },
    { 0xFC8F, "juggernaut_setupexecute" },
    { 0xFC90, "juggernaut_shouldexecute" },
    { 0xFC91, "juggernaut_state" },
    { 0xFC92, "juggernaut_update_hint_logic" },
    { 0xFC93, "juggernautchallengedone" },
    { 0xFC94, "juggernautoutsidegoalradius" },
    { 0xFC95, "juggernauts_spawned" },
    { 0xFC96, "juggheli_spawner_exfil" },
    { 0xFC97, "juggheli_spawner_jammer5_1" },
    { 0xFC98, "juggheli_spawner_jammer5_2" },
    { 0xFC99, "juggheli_spawner_jammer5_3" },
    { 0xFC9A, "juggheli_spawner_jammer5_4" },
    { 0xFC9B, "juggmazedogtagrevive" },
    { 0xFC9C, "jump_music" },
    { 0xFC9D, "jumpcomandsregistered" },
    { 0xFC9E, "jumped" },
    { 0xFC9F, "jumpscenenode" },
    { 0xFCA0, "justbecamehvt" },
    { 0xFCA1, "keep_firing_minigun" },
    { 0xFCA2, "keep_requesting_spawners" },
    { 0xFCA3, "keep_trying_to_kill_off_ai" },
    { 0xFCA4, "keephudhiddentillfadein" },
    { 0xFCA5, "keeprightdooropen" },
    { 0xFCA6, "keepstreamposfresh" },
    { 0xFCA7, "keepviewingthe747" },
    { 0xFCA8, "key_activate" },
    { 0xFCA9, "key_drop_on_client_death_disconnect" },
    { 0xFCAA, "key_hint" },
    { 0xFCAB, "key_position" },
    { 0xFCAC, "keyboard_make_usable" },
    { 0xFCAD, "keyboard_monitor_disable" },
    { 0xFCAE, "keycardlocs" },
    { 0xFCAF, "keycardlocs_chosen" },
    { 0xFCB0, "keypad_activate_func" },
    { 0xFCB1, "keypad_check_levelinput" },
    { 0xFCB2, "keypad_confirm_code_correct" },
    { 0xFCB3, "keypad_damagedeathdisconnectwatch" },
    { 0xFCB4, "keypad_disable_for_time" },
    { 0xFCB5, "keypad_increase_failnum" },
    { 0xFCB6, "keypad_input_clear" },
    { 0xFCB7, "keypad_input_greaterthan_limit" },
    { 0xFCB8, "keypad_playeridlewatch" },
    { 0xFCB9, "keypad_playerinteractwithkeypadloop" },
    { 0xFCBA, "keypadkeys" },
    { 0xFCBB, "keypadscriptableused" },
    { 0xFCBC, "keypadscriptableused_altbunker" },
    { 0xFCBD, "keypadsetup" },
    { 0xFCBE, "keywatcher" },
    { 0xFCBF, "kickafkplayer" },
    { 0xFCC0, "kicknullmusicondeath" },
    { 0xFCC1, "kickplayer" },
    { 0xFCC2, "kickplayersatcircleedge" },
    { 0xFCC3, "kidnapperdebug" },
    { 0xFCC4, "kill_all_enemies" },
    { 0xFCC5, "kill_drone_turret" },
    { 0xFCC6, "kill_frequency_watcher" },
    { 0xFCC7, "kill_furthest_enemy" },
    { 0xFCC8, "kill_off_all_escort_friendly_ai_riders" },
    { 0xFCC9, "kill_off_non_essential_ai" },
    { 0xFCCA, "kill_off_remaining_ai" },
    { 0xFCCB, "kill_rate_too_slow" },
    { 0xFCCC, "kill_rate_watcher" },
    { 0xFCCD, "kill_sentries" },
    { 0xFCCE, "kill_spawngroups_near_safehouse" },
    { 0xFCCF, "kill_tac_covers" },
    { 0xFCD0, "kill_trig" },
    { 0xFCD1, "kill_vip" },
    { 0xFCD2, "killable_targets" },
    { 0xFCD3, "killandvision" },
    { 0xFCD4, "killcam_timescalefactor" },
    { 0xFCD5, "killed_by_chopper" },
    { 0xFCD6, "killed_enemies" },
    { 0xFCD7, "killedenemy" },
    { 0xFCD8, "killentireenemyteam" },
    { 0xFCD9, "killleaderaftertimeout" },
    { 0xFCDA, "killnemesis" },
    { 0xFCDB, "killoff_vis_passed" },
    { 0xFCDC, "killplayerinstant" },
    { 0xFCDD, "killprojectileafterdelay" },
    { 0xFCDE, "killstreak_additional_targets" },
    { 0xFCDF, "killstreak_aquired" },
    { 0xFCE0, "killstreak_cooldown_start" },
    { 0xFCE1, "killstreak_createobjective_engineer" },
    { 0xFCE2, "killstreak_loadout_state" },
    { 0xFCE3, "killstreak_update_hint_logic" },
    { 0xFCE4, "killstreak_wave_spawns" },
    { 0xFCE5, "killstreaks" },
    { 0xFCE6, "killstreaktoscorestreak_killtoscore" },
    { 0xFCE7, "killstreaktoscorestreak_scoretokill" },
    { 0xFCE8, "killstreakweaponfiredcontinue" },
    { 0xFCE9, "killthrowingknifefire" },
    { 0xFCEA, "kilo121_hack" },
    { 0xFCEB, "kingslayer" },
    { 0xFCEC, "kingslayerdeaths" },
    { 0xFCED, "kingslayerkills" },
    { 0xFCEE, "kiosk_num_purchases" },
    { 0xFCEF, "kiosk_spent_total" },
    { 0xFCF0, "kioskfiresaledoneforplayer" },
    { 0xFCF1, "kioskfixupproneplayers" },
    { 0xFCF2, "kioskreviveplayer" },
    { 0xFCF3, "kiosksearchradiusidealmax" },
    { 0xFCF4, "kiosksearchradiusidealmin" },
    { 0xFCF5, "kiosksearchradiusmax" },
    { 0xFCF6, "kiosksearchradiusmin" },
    { 0xFCF7, "kiosksetupfiresaleforplayer" },
    { 0xFCF8, "knock_player_forward" },
    { 0xFCF9, "kothlaststarttime" },
    { 0xFCFA, "kothtotaltime" },
    { 0xFCFB, "ks_airdropcratearmor" },
    { 0xFCFC, "ks_airdropcrateusetime" },
    { 0xFCFD, "ks_airdroppercircle" },
    { 0xFCFE, "ks_circleclosetime" },
    { 0xFCFF, "ks_circlecount" },
    { 0xFD00, "ks_circledelaytime" },
    { 0xFD01, "ks_circleminimapradius" },
    { 0xFD02, "ks_circlemovedist" },
    { 0xFD03, "ks_circlemoving" },
    { 0xFD04, "ks_circleradius" },
    { 0xFD05, "ks_killleaders" },
    { 0xFD06, "ks_pointbonusforteam" },
    { 0xFD07, "ks_pointkingsgetnobonus" },
    { 0xFD08, "ks_pointsperkingslain" },
    { 0xFD09, "ks_pointstowin" },
    { 0xFD0A, "kstargetlocation" },
    { 0xFD0B, "labelpc" },
    { 0xFD0C, "labels" },
    { 0xFD0D, "labelsused" },
    { 0xFD0E, "land_usability_disabled" },
    { 0xFD0F, "landing_damage_watcher" },
    { 0xFD10, "landmine_trigger_origin" },
    { 0xFD11, "lap" },
    { 0xFD12, "lap_index" },
    { 0xFD13, "laps_data" },
    { 0xFD14, "large_transport_initdamage" },
    { 0xFD15, "large_transport_initomnvars" },
    { 0xFD16, "laser_activate" },
    { 0xFD17, "laser_control_station_use_monitor" },
    { 0xFD18, "laser_end_ent_thermal" },
    { 0xFD19, "laser_end_pos" },
    { 0xFD1A, "laser_func" },
    { 0xFD1B, "laser_fx" },
    { 0xFD1C, "laser_hint" },
    { 0xFD1D, "laser_pursue_players" },
    { 0xFD1E, "laser_pursue_players_internal" },
    { 0xFD1F, "laser_reset_position" },
    { 0xFD20, "laser_show_position" },
    { 0xFD21, "laser_shut_down_button" },
    { 0xFD22, "laser_shut_down_interact_monitor" },
    { 0xFD23, "laser_sights" },
    { 0xFD24, "laser_start_ent_thermal" },
    { 0xFD25, "laser_switch_manager" },
    { 0xFD26, "laser_trap_combat" },
    { 0xFD27, "laser_trap_control_station_interaction_array" },
    { 0xFD28, "laser_trap_structs" },
    { 0xFD29, "laser_trap_triggers" },
    { 0xFD2A, "laser_traps" },
    { 0xFD2B, "laser_traps_saved_origins" },
    { 0xFD2C, "laser_vfx_start_pos" },
    { 0xFD2D, "laser_vfx_think" },
    { 0xFD2E, "last_akimbo_ammo_taken" },
    { 0xFD2F, "last_attack_time" },
    { 0xFD30, "last_attacker" },
    { 0xFD31, "last_bag_drop_time" },
    { 0xFD32, "last_exfil_nag" },
    { 0xFD33, "last_good_drop_pos" },
    { 0xFD34, "last_gren_drop_time" },
    { 0xFD35, "last_grenade_fire_time" },
    { 0xFD36, "last_heli" },
    { 0xFD37, "last_molotov_throw_time" },
    { 0xFD38, "last_phone_check_fail" },
    { 0xFD39, "last_rpg_fire" },
    { 0xFD3A, "last_say_times" },
    { 0xFD3B, "last_saydefuse_time" },
    { 0xFD3C, "last_spawned_time" },
    { 0xFD3D, "last_stand_clear_pilot_picker" },
    { 0xFD3E, "last_stand_sfx" },
    { 0xFD3F, "last_target" },
    { 0xFD40, "last_time_calc_defuser" },
    { 0xFD41, "last_unresolved_collision_time" },
    { 0xFD42, "last_vampire_feedback" },
    { 0xFD43, "last_vampire_sound" },
    { 0xFD44, "last_vo_time" },
    { 0xFD45, "last_weapon_fired_time" },
    { 0xFD46, "lastactivateinstruct" },
    { 0xFD47, "lastapproachinstruct" },
    { 0xFD48, "lastascenderusetime" },
    { 0xFD49, "lastbored" },
    { 0xFD4A, "lastboredscore" },
    { 0xFD4B, "lastcircleeventtime" },
    { 0xFD4C, "lastcrossbowhadstoppingpower" },
    { 0xFD4D, "lastdeathheadicon" },
    { 0xFD4E, "lastdeathheadiconforenemy" },
    { 0xFD4F, "lastdepositinstruct" },
    { 0xFD50, "lastdialogfinishedtime" },
    { 0xFD51, "lastdirty" },
    { 0xFD52, "lastdirtyscore" },
    { 0xFD53, "lastdropedtime" },
    { 0xFD54, "lastdroppableweaponchanged" },
    { 0xFD55, "lastgoodjobplayer" },
    { 0xFD56, "lastgunkilltime" },
    { 0xFD57, "lastheatupdate" },
    { 0xFD58, "lasthungry" },
    { 0xFD59, "lasthungryscore" },
    { 0xFD5A, "lastlocationcallouttime" },
    { 0xFD5B, "lastmissionendtime" },
    { 0xFD5C, "lastmovingplatform" },
    { 0xFD5D, "lastplunderbankindex" },
    { 0xFD5E, "lastplundereventtype" },
    { 0xFD5F, "lastpropchangetime" },
    { 0xFD60, "lastseentime" },
    { 0xFD61, "lastspawnpos" },
    { 0xFD62, "lastspawnvocallouttimes" },
    { 0xFD63, "lastspectatedplayer" },
    { 0xFD64, "laststand_damage_shield" },
    { 0xFD65, "laststand_dogtag_monitor" },
    { 0xFD66, "laststand_dogtags" },
    { 0xFD67, "laststand_hack" },
    { 0xFD68, "laststand_player_in_focus" },
    { 0xFD69, "laststandallowed" },
    { 0xFD6A, "laststandattacker" },
    { 0xFD6B, "laststandattackermodifiers" },
    { 0xFD6C, "laststanddowneddata" },
    { 0xFD6D, "laststandfinisherdone" },
    { 0xFD6E, "laststandforceback" },
    { 0xFD6F, "laststandforcebackendtime" },
    { 0xFD70, "laststandgiveloadoutonrevive" },
    { 0xFD71, "laststandid" },
    { 0xFD72, "laststandkillteamifdowndisable" },
    { 0xFD73, "laststandmeansofdeath" },
    { 0xFD74, "laststandobstacleid" },
    { 0xFD75, "laststandobstacleorigin" },
    { 0xFD76, "laststandoutlineid" },
    { 0xFD77, "laststandplayers" },
    { 0xFD78, "laststandrevivedecayscale" },
    { 0xFD79, "laststandweapon" },
    { 0xFD7A, "laststandweapondelay" },
    { 0xFD7B, "laststandweaponobj" },
    { 0xFD7C, "lastteamused" },
    { 0xFD7D, "lasttimedamagecalledout" },
    { 0xFD7E, "lasttimespawngroupcalled" },
    { 0xFD7F, "lasttuttxt" },
    { 0xFD80, "lastunruly" },
    { 0xFD81, "lastunrulyscore" },
    { 0xFD82, "lastweaponfiretimeend" },
    { 0xFD83, "lastweaponfiretimestart" },
    { 0xFD84, "lastweaponswitchnag" },
    { 0xFD85, "lategame_buytimer_set" },
    { 0xFD86, "latejoinersanimstruct" },
    { 0xFD87, "latespawnsnatchtoc130" },
    { 0xFD88, "latetoinfil" },
    { 0xFD89, "launch_smoke_mortar" },
    { 0xFD8A, "launcher_second_techo" },
    { 0xFD8B, "launcherfired" },
    { 0xFD8C, "lb_dmg_factor_driverless_collision" },
    { 0xFD8D, "lb_dmg_factor_fuselage" },
    { 0xFD8E, "lb_dmg_factor_landing_gear" },
    { 0xFD8F, "lb_dmg_factor_main_rotor" },
    { 0xFD90, "lb_dmg_factor_tail_rotor" },
    { 0xFD91, "lb_dmg_factor_tail_stabilizer" },
    { 0xFD92, "lb_impulse_dmg_factor_low" },
    { 0xFD93, "lb_impulse_dmg_factor_mid_high" },
    { 0xFD94, "lb_impulse_dmg_factor_mid_low" },
    { 0xFD95, "lb_impulse_dmg_threshold_low" },
    { 0xFD96, "lb_impulse_dmg_threshold_mid" },
    { 0xFD97, "lb_impulse_dmg_threshold_top" },
    { 0xFD98, "lb_mg_dmg_factor_driverless_collision" },
    { 0xFD99, "lb_mg_dmg_factor_fuselage" },
    { 0xFD9A, "lb_mg_dmg_factor_landing_gear" },
    { 0xFD9B, "lb_mg_dmg_factor_main_rotor" },
    { 0xFD9C, "lb_mg_dmg_factor_tail_rotor" },
    { 0xFD9D, "lb_mg_dmg_factor_tail_stabilizer" },
    { 0xFD9E, "lb_mg_impulse_dmg_factor_low" },
    { 0xFD9F, "lb_mg_impulse_dmg_factor_mid_high" },
    { 0xFDA0, "lb_mg_impulse_dmg_factor_mid_low" },
    { 0xFDA1, "lb_mg_impulse_dmg_threshold_low" },
    { 0xFDA2, "lb_mg_impulse_dmg_threshold_mid" },
    { 0xFDA3, "lb_mg_impulse_dmg_threshold_top" },
    { 0xFDA4, "lb_mg_pitch_roll_dmg_factor" },
    { 0xFDA5, "lb_mg_pitch_roll_dmg_threshold" },
    { 0xFDA6, "lb_mg_wood_surf_dmg_scalar" },
    { 0xFDA7, "lb_pitch_roll_dmg_factor" },
    { 0xFDA8, "lb_pitch_roll_dmg_threshold" },
    { 0xFDA9, "lb_wood_surf_dmg_scalar" },
    { 0xFDAA, "lbravo_actor_keep_anim_loop" },
    { 0xFDAB, "lbravo_actorthinkpath" },
    { 0xFDAC, "lbravo_hover_attack_think" },
    { 0xFDAD, "lbravo_hover_rider_death_monitor" },
    { 0xFDAE, "lbravo_spawn_after_level_restart" },
    { 0xFDAF, "lbravo_spawner_jammer1" },
    { 0xFDB0, "lbravo_spawner_jammer1b" },
    { 0xFDB1, "lbravo_spawner_jammer2" },
    { 0xFDB2, "lbravo_spawner_jammer2b" },
    { 0xFDB3, "lbravo_spawner_jammer3" },
    { 0xFDB4, "lbravo_spawner_jammer3b" },
    { 0xFDB5, "lbravo_spawner_jammer4" },
    { 0xFDB6, "lbravo_spawner_jammer4b" },
    { 0xFDB7, "lbravo_spawner_safehouse1" },
    { 0xFDB8, "lbravo_spawner_safehouse2" },
    { 0xFDB9, "leader_charge_dialogue" },
    { 0xFDBA, "leader_intro_dialogue" },
    { 0xFDBB, "leaderboard_enabled" },
    { 0xFDBC, "leaderboarddata" },
    { 0xFDBD, "leaderinteractionthink" },
    { 0xFDBE, "leaderplunderstring" },
    { 0xFDBF, "leadmarkerdata" },
    { 0xFDC0, "leadmarkers" },
    { 0xFDC1, "leadmarkerthreshold" },
    { 0xFDC2, "leave_combat_space" },
    { 0xFDC3, "leave_pool_behind_after_deactivation" },
    { 0xFDC4, "leaveforplayer" },
    { 0xFDC5, "left_control" },
    { 0xFDC6, "left_side_spawn_adjuster" },
    { 0xFDC7, "lengthdelta" },
    { 0xFDC8, "lengthmod" },
    { 0xFDC9, "lethal_boxes" },
    { 0xFDCA, "lethal_crate_spawn" },
    { 0xFDCB, "lethal_equipmentmaskoffsets" },
    { 0xFDCC, "lethaldelayallows" },
    { 0xFDCD, "letters" },
    { 0xFDCE, "level_ammo_crate_spawn" },
    { 0xFDCF, "level_carepackage_drop" },
    { 0xFDD0, "level_carepackage_drop_defined" },
    { 0xFDD1, "level_carepackage_give_player_killstreak" },
    { 0xFDD2, "level_carepackage_give_player_killstreak_incendiary_launcher" },
    { 0xFDD3, "level_carepackage_player_used_logic" },
    { 0xFDD4, "level_check_current_drop_amount" },
    { 0xFDD5, "level_create_timer" },
    { 0xFDD6, "level_death_notify" },
    { 0xFDD7, "level_getspawnpoint" },
    { 0xFDD8, "level_killstreak_spawn" },
    { 0xFDD9, "level_light" },
    { 0xFDDA, "level_logic" },
    { 0xFDDB, "level_offhand_refill_spawn" },
    { 0xFDDC, "level_offhand_spawn" },
    { 0xFDDD, "level_respawn_func" },
    { 0xFDDE, "level_should_run_sp_stealth" },
    { 0xFDDF, "level_spawnplayer" },
    { 0xFDE0, "level_use_carepackage" },
    { 0xFDE1, "level_weapon_spawn" },
    { 0xFDE2, "levelobjectives" },
    { 0xFDE3, "levelonlaststandfunc" },
    { 0xFDE4, "lgbudgetingprobesize" },
    { 0xFDE5, "lgnoshadow" },
    { 0xFDE6, "lgsplittransients" },
    { 0xFDE7, "lgvadaptive" },
    { 0xFDE8, "lgvmergesufix" },
    { 0xFDE9, "lgwperifvfx_explosions" },
    { 0xFDEA, "lgwperifvfx_plumes" },
    { 0xFDEB, "light_switch" },
    { 0xFDEC, "light_tank_addgunnerdamagemod" },
    { 0xFDED, "light_tank_getmissileplayercommand" },
    { 0xFDEE, "light_tank_gunnerdamagemodignorefunc" },
    { 0xFDEF, "light_tank_initcollision" },
    { 0xFDF0, "light_tank_initdamage" },
    { 0xFDF1, "light_tank_initomnvars" },
    { 0xFDF2, "light_tank_monitordriverturretprojectilefire" },
    { 0xFDF3, "light_tank_monitorgunnerturretfire" },
    { 0xFDF4, "light_tank_removegunnerdamagemod" },
    { 0xFDF5, "light_tank_stopwatchingmissileinputchange" },
    { 0xFDF6, "light_tank_update" },
    { 0xFDF7, "light_tank_watchgameend" },
    { 0xFDF8, "light_tank_watchmissileinputchange" },
    { 0xFDF9, "light_tank_watchprojectileexplosion" },
    { 0xFDFA, "light_target_desactivate_check" },
    { 0xFDFB, "light_target_init" },
    { 0xFDFC, "light_target_update" },
    { 0xFDFD, "lighting" },
    { 0xFDFE, "lighting_gate" },
    { 0xFDFF, "lights_setup_plane" },
    { 0xFE00, "lightscriptable" },
    { 0xFE01, "lightsfloor01" },
    { 0xFE02, "lightsfloor02" },
    { 0xFE03, "lightsfx" },
    { 0xFE04, "lightsreset" },
    { 0xFE05, "lightsshot02" },
    { 0xFE06, "linecircleintersection2d" },
    { 0xFE07, "link_active" },
    { 0xFE08, "link_player_to_rig_laser_panel" },
    { 0xFE09, "linked_brush" },
    { 0xFE0A, "linked_model" },
    { 0xFE0B, "linked_mover" },
    { 0xFE0C, "linkedsaw" },
    { 0xFE0D, "linkedto" },
    { 0xFE0E, "linkedtoent" },
    { 0xFE0F, "linkedtotag" },
    { 0xFE10, "linker" },
    { 0xFE11, "linkoffset" },
    { 0xFE12, "linktooriginandangles" },
    { 0xFE13, "linktoplayer_linklogic" },
    { 0xFE14, "linvels" },
    { 0xFE15, "listen_for_adrenaline_use" },
    { 0xFE16, "listen_for_drone_ent" },
    { 0xFE17, "listen_for_emp_drone_ent" },
    { 0xFE18, "listen_for_revive" },
    { 0xFE19, "little_bird" },
    { 0xFE1A, "little_bird_horn" },
    { 0xFE1B, "little_bird_initcollision" },
    { 0xFE1C, "little_bird_initdamage" },
    { 0xFE1D, "little_bird_initomnvars" },
    { 0xFE1E, "little_bird_mg_collision_damage_watcher" },
    { 0xFE1F, "little_bird_mg_cp_create" },
    { 0xFE20, "little_bird_mg_cp_createfromstructs" },
    { 0xFE21, "little_bird_mg_cp_init" },
    { 0xFE22, "little_bird_mg_cp_initlate" },
    { 0xFE23, "little_bird_mg_cp_ondeathrespawncallback" },
    { 0xFE24, "little_bird_mg_cp_onentervehicle" },
    { 0xFE25, "little_bird_mg_cp_onexitvehicle" },
    { 0xFE26, "little_bird_mg_cp_spawncallback" },
    { 0xFE27, "little_bird_mg_cp_waitandspawn" },
    { 0xFE28, "little_bird_mg_create" },
    { 0xFE29, "little_bird_mg_creategunnerturret" },
    { 0xFE2A, "little_bird_mg_deathcallback" },
    { 0xFE2B, "little_bird_mg_deletenextframe" },
    { 0xFE2C, "little_bird_mg_enterend" },
    { 0xFE2D, "little_bird_mg_enterendinternal" },
    { 0xFE2E, "little_bird_mg_enterstart" },
    { 0xFE2F, "little_bird_mg_exitend" },
    { 0xFE30, "little_bird_mg_exitendinternal" },
    { 0xFE31, "little_bird_mg_explode" },
    { 0xFE32, "little_bird_mg_getspawnstructscallback" },
    { 0xFE33, "little_bird_mg_givetakegunnerturrettimeout" },
    { 0xFE34, "little_bird_mg_handleflarefire" },
    { 0xFE35, "little_bird_mg_handleflarerecharge" },
    { 0xFE36, "little_bird_mg_init" },
    { 0xFE37, "little_bird_mg_initcollision" },
    { 0xFE38, "little_bird_mg_initdamage" },
    { 0xFE39, "little_bird_mg_initfx" },
    { 0xFE3A, "little_bird_mg_initinteract" },
    { 0xFE3B, "little_bird_mg_initlate" },
    { 0xFE3C, "little_bird_mg_initoccupancy" },
    { 0xFE3D, "little_bird_mg_initomnvars" },
    { 0xFE3E, "little_bird_mg_initspawning" },
    { 0xFE3F, "little_bird_mg_mp_enterendinternal" },
    { 0xFE40, "little_bird_mg_mp_init" },
    { 0xFE41, "little_bird_mg_mp_initmines" },
    { 0xFE42, "little_bird_mg_mp_initspawning" },
    { 0xFE43, "little_bird_mg_mp_ondeathrespawncallback" },
    { 0xFE44, "little_bird_mg_mp_spawncallback" },
    { 0xFE45, "little_bird_mg_mp_waitandspawn" },
    { 0xFE46, "little_bird_mg_onenterheavydamagestate" },
    { 0xFE47, "little_bird_mg_onexitheavydamagestate" },
    { 0xFE48, "little_bird_mg_playercontrolmg" },
    { 0xFE49, "little_bird_mg_playerexitturret" },
    { 0xFE4A, "little_bird_mg_reenter" },
    { 0xFE4B, "little_bird_mg_takegunnerturret" },
    { 0xFE4C, "little_bird_mp_enterendinternal" },
    { 0xFE4D, "little_bird_mp_initmines" },
    { 0xFE4E, "little_bird_onenterheavydamagestate" },
    { 0xFE4F, "little_bird_onexitheavydamagestate" },
    { 0xFE50, "little_bird_trail" },
    { 0xFE51, "littlebirdsmg" },
    { 0xFE52, "livescount" },
    { 0xFE53, "lmg_guys" },
    { 0xFE54, "lmg_too_far_away" },
    { 0xFE55, "load_airfield" },
    { 0xFE56, "load_laser_fx" },
    { 0xFE57, "load_relics_from_playlistdvars" },
    { 0xFE58, "load_relics_vfx" },
    { 0xFE59, "load_sequence_3_vfx" },
    { 0xFE5A, "load_sequence_4_vfx" },
    { 0xFE5B, "loadandplayholoeffect" },
    { 0xFE5C, "loadout_copyclassstruct" },
    { 0xFE5D, "loadout_editglobalclassstruct" },
    { 0xFE5E, "loadout_finalizeweapons" },
    { 0xFE5F, "loadout_fixcopiedclassstruct" },
    { 0xFE60, "loadout_getglobalclassstruct" },
    { 0xFE61, "loadout_given" },
    { 0xFE62, "loadout_giveweaponobj" },
    { 0xFE63, "loadout_updateammo" },
    { 0xFE64, "loadout_updatebrammo" },
    { 0xFE65, "loadout_updateclassdefault_headlessgetweaponn" },
    { 0xFE66, "loadout_updateclassdefault_weapons" },
    { 0xFE67, "loadout_updateclassdefault_weaponsheadless" },
    { 0xFE68, "loadout_updateglobalclass" },
    { 0xFE69, "loadout_updateglobalclassgamemode" },
    { 0xFE6A, "loadout_updateglobalclassstruct" },
    { 0xFE6B, "loadout_updateweapondependentsettings" },
    { 0xFE6C, "loadoutaddblueprintattachments" },
    { 0xFE6D, "loadoutbrfieldupgrade" },
    { 0xFE6E, "loadoutcustomcost" },
    { 0xFE6F, "loadoutcustomfiresalediscount" },
    { 0xFE70, "loadoutcustomperkdiscount" },
    { 0xFE71, "loadoutdefaultcost" },
    { 0xFE72, "loadoutdefaultfiresalediscount" },
    { 0xFE73, "loadoutdefaultperkdiscount" },
    { 0xFE74, "loadoutdrop" },
    { 0xFE75, "loadoutexecutionquip" },
    { 0xFE76, "loadoutextraperksfromgamemode" },
    { 0xFE77, "loadoutprimaryaddblueprintattachments" },
    { 0xFE78, "loadoutsecondaryaddblueprintattachments" },
    { 0xFE79, "loadtables" },
    { 0xFE7A, "lobby_door_enemy_watcher" },
    { 0xFE7B, "lobby_patrol_enemy_watcher" },
    { 0xFE7C, "loc_exposed_to_chopper_boss" },
    { 0xFE7D, "local_waittill_any_return_6" },
    { 0xFE7E, "localangles" },
    { 0xFE7F, "locale_defaults" },
    { 0xFE80, "location_objective_remover" },
    { 0xFE81, "location_tracker" },
    { 0xFE82, "locationcircles" },
    { 0xFE83, "locationpad" },
    { 0xFE84, "locationsnames" },
    { 0xFE85, "locationtriggersetpaused" },
    { 0xFE86, "locationtriggerupdate" },
    { 0xFE87, "locindex" },
    { 0xFE88, "lock_player_stance" },
    { 0xFE89, "locked_proxylod" },
    { 0xFE8A, "lockedradialunfill" },
    { 0xFE8B, "locknonbunkerdoors" },
    { 0xFE8C, "lockontarget" },
    { 0xFE8D, "lockprop" },
    { 0xFE8E, "lockpropkey" },
    { 0xFE8F, "lockscriptabledoors" },
    { 0xFE90, "locstr" },
    { 0xFE91, "logannouncement" },
    { 0xFE92, "logchangeweapon" },
    { 0xFE93, "logcodcasterdamage" },
    { 0xFE94, "logendofround" },
    { 0xFE95, "logequipmentuse" },
    { 0xFE96, "logevent_challengeitemunlocked" },
    { 0xFE97, "logevent_downed" },
    { 0xFE98, "logevent_givecpweaponxp" },
    { 0xFE99, "logevent_kidnapevent" },
    { 0xFE9A, "logevent_kill" },
    { 0xFE9B, "logevent_munitionused" },
    { 0xFE9C, "logevent_playerregen" },
    { 0xFE9D, "logevent_servermatchend" },
    { 0xFE9E, "logevent_servermatchstart" },
    { 0xFE9F, "logevent_spawnselectionchoice" },
    { 0xFEA0, "logevent_spawnviaautorevive" },
    { 0xFEA1, "logevent_spawnviaplayer" },
    { 0xFEA2, "logevent_spawnviateamrevive" },
    { 0xFEA3, "logevent_superused" },
    { 0xFEA4, "logevent_xpearned" },
    { 0xFEA5, "logfriendlyfire" },
    { 0xFEA6, "loggamescore" },
    { 0xFEA7, "logloadoutcopy" },
    { 0xFEA8, "logplayermatchend" },
    { 0xFEA9, "logplayermatchstart" },
    { 0xFEAA, "logtrophysuccesful" },
    { 0xFEAB, "long_death_manager" },
    { 0xFEAC, "longdeathtracker" },
    { 0xFEAD, "longgulagstream" },
    { 0xFEAE, "longwaitradarsweep" },
    { 0xFEAF, "look_at_heli" },
    { 0xFEB0, "look_for_more_leads_vo" },
    { 0xFEB1, "lookforvehicles" },
    { 0xFEB2, "loop" },
    { 0xFEB3, "loop_emp_spark_vfx" },
    { 0xFEB4, "loop_respawn_ready_splash" },
    { 0xFEB5, "loop_station_closed_vo" },
    { 0xFEB6, "looping_path" },
    { 0xFEB7, "loopsound_origin" },
    { 0xFEB8, "loot_boxes" },
    { 0xFEB9, "loot_chopper_spawns" },
    { 0xFEBA, "loot_choppers" },
    { 0xFEBB, "loot_getitemcount" },
    { 0xFEBC, "loot_getitemcountlefthand" },
    { 0xFEBD, "loot_nag" },
    { 0xFEBE, "loot_on_pickup_success" },
    { 0xFEBF, "loot_setitemcount" },
    { 0xFEC0, "lootbunkersactive" },
    { 0xFEC1, "lootcachesearchparams" },
    { 0xFEC2, "lootcachesopened" },
    { 0xFEC3, "lootcachespawncontents" },
    { 0xFEC4, "lootchopper_cleanup" },
    { 0xFEC5, "lootchopper_createobjective" },
    { 0xFEC6, "lootchopper_droploot" },
    { 0xFEC7, "lootchopper_finddroplocation" },
    { 0xFEC8, "lootchopper_findunoccupiedpatrolzone" },
    { 0xFEC9, "lootchopper_getattackerdata" },
    { 0xFECA, "lootchopper_getspawnlocations" },
    { 0xFECB, "lootchopper_getzonebyindex" },
    { 0xFECC, "lootchopper_handledeathdamage" },
    { 0xFECD, "lootchopper_initcircleinfo" },
    { 0xFECE, "lootchopper_initspawninfo" },
    { 0xFECF, "lootchopper_isnearbyoccupiedspawns" },
    { 0xFED0, "lootchopper_managespawns" },
    { 0xFED1, "lootchopper_modifyweapondamage" },
    { 0xFED2, "lootchopper_oncrateuse" },
    { 0xFED3, "lootchopper_patrolzone" },
    { 0xFED4, "lootchopper_postmodifydamage" },
    { 0xFED5, "lootchopper_premodifydamage" },
    { 0xFED6, "lootchopper_setupdamagefunctionality" },
    { 0xFED7, "lootchopper_spawn" },
    { 0xFED8, "lootcontentsadjust_accesscardsred" },
    { 0xFED9, "lootcontentsadjusteconomy_bottomtier" },
    { 0xFEDA, "lootcontentsadjusteconomy_toptier" },
    { 0xFEDB, "lootcontentsadjustkillchain" },
    { 0xFEDC, "loothide" },
    { 0xFEDD, "lootid" },
    { 0xFEDE, "lootidtoindex" },
    { 0xFEDF, "lootleaderinstance" },
    { 0xFEE0, "lootleadermarkcount" },
    { 0xFEE1, "lootleadermarks" },
    { 0xFEE2, "lootleadermarksize" },
    { 0xFEE3, "lootleadermarksizedynamic" },
    { 0xFEE4, "lootleadermarksontopteams" },
    { 0xFEE5, "lootleadermarkstrongsize" },
    { 0xFEE6, "lootleadermarkstrongvalue" },
    { 0xFEE7, "lootleadermarkweaksize" },
    { 0xFEE8, "lootleadermarkweakvalue" },
    { 0xFEE9, "lootleaderoneperteam" },
    { 0xFEEA, "lootleaders" },
    { 0xFEEB, "lootleadersprev" },
    { 0xFEEC, "lootsource" },
    { 0xFEED, "lootspawnitem" },
    { 0xFEEE, "lootspawnitemlist" },
    { 0xFEEF, "lootstruct_offsets" },
    { 0xFEF0, "loscheckpassed" },
    { 0xFEF1, "loschecktime" },
    { 0xFEF2, "losqueuehigh" },
    { 0xFEF3, "losqueuehighindex" },
    { 0xFEF4, "losqueuelow" },
    { 0xFEF5, "losqueuelowindex" },
    { 0xFEF6, "lossendgame" },
    { 0xFEF7, "low_on_ammo" },
    { 0xFEF8, "low_roof_enemy_watcher" },
    { 0xFEF9, "lower_airlock" },
    { 0xFEFA, "lower_door_coll" },
    { 0xFEFB, "lower_target_when_close" },
    { 0xFEFC, "lowpopallowtweaks" },
    { 0xFEFD, "lowpopcheck" },
    { 0xFEFE, "lowpopstart" },
    { 0xFEFF, "lumberyard_suicide_truck_speed_manager" },
    { 0xFF00, "maderecentkill" },
    { 0xFF01, "magic_rpg_ending" },
    { 0xFF02, "magic_shield_fake" },
    { 0xFF03, "mainhouse_intel_sequence" },
    { 0xFF04, "make_airlock_interactions_usable" },
    { 0xFF05, "make_all_doors_solid" },
    { 0xFF06, "make_all_oscilloscopes_usable" },
    { 0xFF07, "make_armor_target" },
    { 0xFF08, "make_bomb_detonator_interact" },
    { 0xFF09, "make_building_ai_excluder" },
    { 0xFF0A, "make_c4_pick_up_interact" },
    { 0xFF0B, "make_chair_ai_spawner" },
    { 0xFF0C, "make_chopper_boss_look_at_ent" },
    { 0xFF0D, "make_combat_icon_on_ai" },
    { 0xFF0E, "make_control_station_interaction" },
    { 0xFF0F, "make_each_objective_scramble_radar" },
    { 0xFF10, "make_emp_config" },
    { 0xFF11, "make_emp_drone_pick_up_interact" },
    { 0xFF12, "make_exhaust_affect_players" },
    { 0xFF13, "make_fly_struct" },
    { 0xFF14, "make_focus_fire_headicon" },
    { 0xFF15, "make_focus_fire_icon_anchor" },
    { 0xFF16, "make_focus_fire_objective" },
    { 0xFF17, "make_hb_pick_up_interact" },
    { 0xFF18, "make_headicon_on_ai" },
    { 0xFF19, "make_heli_blade_patch_clip" },
    { 0xFF1A, "make_intel_model_usable" },
    { 0xFF1B, "make_javelin_ammo_refill_interact" },
    { 0xFF1C, "make_javelin_interact" },
    { 0xFF1D, "make_javelin_model" },
    { 0xFF1E, "make_laser_shutdown_interact" },
    { 0xFF1F, "make_outline_ents" },
    { 0xFF20, "make_path_node_on_circular_path" },
    { 0xFF21, "make_pilot_invincible" },
    { 0xFF22, "make_place_c4_interact" },
    { 0xFF23, "make_silencer_pick_up_interact" },
    { 0xFF24, "make_solution_struct" },
    { 0xFF25, "make_sure_loot_is_visible" },
    { 0xFF26, "make_trophy_explosion" },
    { 0xFF27, "make_usb_model_usable" },
    { 0xFF28, "make_use_prompt" },
    { 0xFF29, "makecrateusableforplayer" },
    { 0xFF2A, "makedroneguardscrambler" },
    { 0xFF2B, "makeextractionobjective" },
    { 0xFF2C, "makenukeweapon" },
    { 0xFF2D, "makepickup" },
    { 0xFF2E, "manage_fakebody_hides" },
    { 0xFF2F, "manage_health_stage_allows" },
    { 0xFF30, "manageafktracking" },
    { 0xFF31, "managecontrolledcallbacktimeout" },
    { 0xFF32, "managedropbags" },
    { 0xFF33, "managejumpmasterinfodisplay" },
    { 0xFF34, "manageminigunpickup" },
    { 0xFF35, "manageparachute" },
    { 0xFF36, "manageprematchfade" },
    { 0xFF37, "managerespawnfade" },
    { 0xFF38, "managevehiclehealthui" },
    { 0xFF39, "manageworldspawnedbolts" },
    { 0xFF3A, "manageworldspawnedprojectiles" },
    { 0xFF3B, "mangagedeathsdoor" },
    { 0xFF3C, "manifest_music_started" },
    { 0xFF3D, "manned_turret_createhintobject" },
    { 0xFF3E, "manned_turret_operator_validation_func" },
    { 0xFF3F, "manned_turret_spawn_func" },
    { 0xFF40, "manned_turret_spawned_nodes" },
    { 0xFF41, "mantlebrush" },
    { 0xFF42, "mantlekill" },
    { 0xFF43, "manual_turret_allowpickupofturret" },
    { 0xFF44, "manual_turret_canpickup" },
    { 0xFF45, "manual_turret_handlemovingplatform" },
    { 0xFF46, "manual_turret_laststandwatcher" },
    { 0xFF47, "manual_turret_munitionused" },
    { 0xFF48, "manual_turret_operate_by_nearby_enemies" },
    { 0xFF49, "manualadjustlittlebirdlocs" },
    { 0xFF4A, "manualturret_clearplacementinstructions" },
    { 0xFF4B, "manualturret_disablecrouchpronemantle" },
    { 0xFF4C, "manualturret_domonitoredweaponswitch" },
    { 0xFF4D, "manualturret_endturretuseonexecution" },
    { 0xFF4E, "manualturret_endturretuseonpush" },
    { 0xFF4F, "manualturret_moving_platform_death" },
    { 0xFF50, "manualturret_toggleallowplacementactions" },
    { 0xFF51, "manualturret_toggleallowuseactions" },
    { 0xFF52, "manualturret_watchdeathongameend" },
    { 0xFF53, "manualturret_watchturretusetimeout" },
    { 0xFF54, "map_dev_name_to_actual_station_name" },
    { 0xFF55, "mapcalloutsready" },
    { 0xFF56, "mapedgeextractionlocs" },
    { 0xFF57, "maphint_cheese2scriptableused" },
    { 0xFF58, "maphint_cheesescriptableused" },
    { 0xFF59, "maphint_computerscriptableused" },
    { 0xFF5A, "maphint_debugthink" },
    { 0xFF5B, "maphint_keypadscriptableused" },
    { 0xFF5C, "maphint_offerscriptableused" },
    { 0xFF5D, "maphint_phonescriptableused" },
    { 0xFF5E, "maphints" },
    { 0xFF5F, "maphitloctoburningpart" },
    { 0xFF60, "mapnamefilter" },
    { 0xFF61, "mark_armor" },
    { 0xFF62, "mark_as_bomb_vest_controller_holder" },
    { 0xFF63, "mark_available_for_hack" },
    { 0xFF64, "mark_coop_bomb_defusal_ended" },
    { 0xFF65, "mark_danger" },
    { 0xFF66, "mark_danger_timeout" },
    { 0xFF67, "mark_location" },
    { 0xFF68, "mark_loot" },
    { 0xFF69, "mark_phone_guy_once_all_spawned" },
    { 0xFF6A, "mark_remaining_as_died_poorly" },
    { 0xFF6B, "markdistanceoverride" },
    { 0xFF6C, "marked_for_no_death" },
    { 0xFF6D, "markedentities_removeentsbyindex" },
    { 0xFF6E, "markedentitieslifeindices" },
    { 0xFF6F, "markedfordelete" },
    { 0xFF70, "markingcoldblooded" },
    { 0xFF71, "markingendtime" },
    { 0xFF72, "markintelwithrecondrone" },
    { 0xFF73, "markplayeraseliminated" },
    { 0xFF74, "markplayeraseliminatedonkilled" },
    { 0xFF75, "marksenabled" },
    { 0xFF76, "match1playeromnvarupdated" },
    { 0xFF77, "matchdata_br_onmatchstart" },
    { 0xFF78, "matchdata_buildweaponrootlist" },
    { 0xFF79, "matchdata_level" },
    { 0xFF7A, "matchdata_logattachmentstat" },
    { 0xFF7B, "matchdata_logattackerkillevent" },
    { 0xFF7C, "matchdata_logaward" },
    { 0xFF7D, "matchdata_logchallenge" },
    { 0xFF7E, "matchdata_loggameevent" },
    { 0xFF7F, "matchdata_logkillstreakevent" },
    { 0xFF80, "matchdata_logmultikill" },
    { 0xFF81, "matchdata_logplayerdata" },
    { 0xFF82, "matchdata_logplayerdeath" },
    { 0xFF83, "matchdata_logplayerlife" },
    { 0xFF84, "matchdata_logscoreevent" },
    { 0xFF85, "matchdata_logvictimkillevent" },
    { 0xFF86, "matchdata_logweaponstat" },
    { 0xFF87, "matchdata_onmatchstart" },
    { 0xFF88, "matchdata_onroundend" },
    { 0xFF89, "matchdata_recordrecentlyplayeddata" },
    { 0xFF8A, "matching_correct_bomb_wire_pair" },
    { 0xFF8B, "matchrules_initialammo" },
    { 0xFF8C, "matchrules_oicweapon" },
    { 0xFF8D, "matchrules_oneshotkill" },
    { 0xFF8E, "matchrules_rewardammo" },
    { 0xFF8F, "matchslopekey" },
    { 0xFF90, "matchstart_dialogue" },
    { 0xFF91, "matchstartextractsitedelay" },
    { 0xFF92, "matchstarttimer_black_screen" },
    { 0xFF93, "max_ammo_check" },
    { 0xFF94, "max_dist_sq_from_node" },
    { 0xFF95, "max_extra_enemies" },
    { 0xFF96, "max_groups_per_player" },
    { 0xFF97, "max_projectile_check" },
    { 0xFF98, "max_pt" },
    { 0xFF99, "max_respawn" },
    { 0xFF9A, "max_rpg_groups" },
    { 0xFF9B, "max_spawns" },
    { 0xFF9C, "max_steps_before_stability_loss" },
    { 0xFF9D, "maxaccesscardspawns_red" },
    { 0xFF9E, "maxagents" },
    { 0xFF9F, "maxbetarank" },
    { 0xFFA0, "maxcastsperframe" },
    { 0xFFA1, "maxdogtags" },
    { 0xFFA2, "maxelderrank" },
    { 0xFFA3, "maxextractions" },
    { 0xFFA4, "maxkills" },
    { 0xFFA5, "maxlootleadermarkcount" },
    { 0xFFA6, "maxmuncurrencycap" },
    { 0xFFA7, "maxnumsites" },
    { 0xFFA8, "maxperkbonustier" },
    { 0xFFA9, "maxplunder" },
    { 0xFFAA, "maxplunderdropinovertime" },
    { 0xFFAB, "maxplunderdropondeath" },
    { 0xFFAC, "maxplunderextractions" },
    { 0xFFAD, "maxpools" },
    { 0xFFAE, "maxrangesq" },
    { 0xFFAF, "maxtagradius" },
    { 0xFFB0, "maxtagradiussq" },
    { 0xFFB1, "maxtagsvisible" },
    { 0xFFB2, "maxtimelimit" },
    { 0xFFB3, "maxtokensdropondeath" },
    { 0xFFB4, "maxvehicledamagedivisor" },
    { 0xFFB5, "maxweaponxpcap" },
    { 0xFFB6, "maxxpcap" },
    { 0xFFB7, "mayconsiderplayerdead" },
    { 0xFFB8, "maze_ai_setup" },
    { 0xFFB9, "med_transport_initdamage" },
    { 0xFFBA, "med_transport_initomnvars" },
    { 0xFFBB, "mediumstatehealthratio" },
    { 0xFFBC, "mercymatchending_nuke" },
    { 0xFFBD, "mercymatchending_time" },
    { 0xFFBE, "mercywintriggered" },
    { 0xFFBF, "method_for_calling_reinforcemen" },
    { 0xFFC0, "method_for_calling_reinforcement" },
    { 0xFFC1, "mid_air_explode" },
    { 0xFFC2, "mid_bosses" },
    { 0xFFC3, "mid_encounter_package_thread" },
    { 0xFFC4, "mid_roof_enemy_watcher" },
    { 0xFFC5, "midpoint_music" },
    { 0xFFC6, "midpos" },
    { 0xFFC7, "midtruck" },
    { 0xFFC8, "migratespectators" },
    { 0xFFC9, "milestonephasepercent_drops" },
    { 0xFFCA, "milestonephasepercent_helis" },
    { 0xFFCB, "milestonephasepercent_lzs" },
    { 0xFFCC, "milestonephasepercent_vips" },
    { 0xFFCD, "min_dist_sq_from_node" },
    { 0xFFCE, "min_player_health" },
    { 0xFFCF, "min_pt" },
    { 0xFFD0, "min_x" },
    { 0xFFD1, "min_y" },
    { 0xFFD2, "min_z" },
    { 0xFFD3, "minarmordropondeath" },
    { 0xFFD4, "mindia_exterior_sfx" },
    { 0xFFD5, "mine_cave_turrets" },
    { 0xFFD6, "mine_caves_ambush" },
    { 0xFFD7, "mine_caves_ambusher" },
    { 0xFFD8, "mine_caves_ambusher_internal" },
    { 0xFFD9, "mine_caves_barrels_damage_watch" },
    { 0xFFDA, "mine_caves_breakable_gate_individual" },
    { 0xFFDB, "mine_caves_breakable_gates" },
    { 0xFFDC, "mine_caves_cell_support" },
    { 0xFFDD, "mine_caves_cell_support_internal" },
    { 0xFFDE, "mine_caves_chopper" },
    { 0xFFDF, "mine_caves_end_support" },
    { 0xFFE0, "mine_caves_end_support_internal" },
    { 0xFFE1, "mine_caves_retreat" },
    { 0xFFE2, "mine_caves_runner" },
    { 0xFFE3, "mine_caves_runner_internal" },
    { 0xFFE4, "mine_caves_structs" },
    { 0xFFE5, "mine_caves_support_combat" },
    { 0xFFE6, "mine_caves_turret_1_support" },
    { 0xFFE7, "mine_caves_turret_1_support_internal" },
    { 0xFFE8, "mine_caves_turret_2_support" },
    { 0xFFE9, "mine_caves_turret_2_support_internal" },
    { 0xFFEA, "mine_caves_turret_clip_remove_on_death" },
    { 0xFFEB, "mine_caves_turret_config" },
    { 0xFFEC, "mine_caves_turret_damage_feedback" },
    { 0xFFED, "mine_caves_turret_op" },
    { 0xFFEE, "mine_caves_turret_op_internal" },
    { 0xFFEF, "mine_caves_turret_op_spawn" },
    { 0xFFF0, "mine_caves_turret_support_behavior" },
    { 0xFFF1, "mine_caves_turrets" },
    { 0xFFF2, "mine_caves_vo" },
    { 0xFFF3, "mine_caves_waittill_entered" },
    { 0xFFF4, "mine_destroyed_vfx" },
    { 0xFFF5, "mine_explosion_vfx" },
    { 0xFFF6, "mine_launch_vfx" },
    { 0xFFF7, "mine_light_vfx" },
    { 0xFFF8, "minecart" },
    { 0xFFF9, "minecart_anim_node" },
    { 0xFFFA, "minecart_run" },
    { 0xFFFB, "mini_map_origin_fix" },
    { 0xFFFC, "minigameapplyplayernamesettings" },
    { 0xFFFD, "minigamefinishcount" },
    { 0xFFFE, "minigameinfo" },
    { 0xFFFF, "minigamelosersettings" },
    { 0x10000, "minigamewinnersettings" },
    { 0x10001, "minigun_angles_offset" },
    { 0x10002, "minigun_attack_max_cooldown" },
    { 0x10003, "minigun_attack_min_cooldown" },
    { 0x10004, "minigun_internal" },
    { 0x10005, "minigun_is_firing" },
    { 0x10006, "minigun_manager" },
    { 0x10007, "minigun_model" },
    { 0x10008, "minigun_origin_offset" },
    { 0x10009, "minigun_right" },
    { 0x1000A, "minigun_shots_per_round" },
    { 0x1000B, "minigun_should_keep_firing" },
    { 0x1000C, "minigun_speed" },
    { 0x1000D, "minigun_start_locs" },
    { 0x1000E, "minigun_sweep_to_loc" },
    { 0x1000F, "minigun_sweep_to_loc_safe" },
    { 0x10010, "minigun_tag" },
    { 0x10011, "minigun_track_target" },
    { 0x10012, "minigun_track_target_delay" },
    { 0x10013, "minigun_track_target_think" },
    { 0x10014, "minigun_turret_info" },
    { 0x10015, "minigun_wait_between_shot_rounds" },
    { 0x10016, "minigun_wait_between_shots" },
    { 0x10017, "minigun_warning_time" },
    { 0x10018, "minigunbackup" },
    { 0x10019, "minplunderdropondeath" },
    { 0x1001A, "minplunderextractions" },
    { 0x1001B, "minshotstostage2acc" },
    { 0x1001C, "minshotstostage3acc" },
    { 0x1001D, "minsteps" },
    { 0x1001E, "mintokensdropondeath" },
    { 0x1001F, "missed_shots" },
    { 0x10020, "missedinfilplayerhandler" },
    { 0x10021, "missing_window_blockers" },
    { 0x10022, "missionbasetimer" },
    { 0x10023, "missionbonustimer" },
    { 0x10024, "missionid" },
    { 0x10025, "missionparticipation" },
    { 0x10026, "missions_clearinappropriaterewards" },
    { 0x10027, "missiontime" },
    { 0x10028, "mix" },
    { 0x10029, "mix_loot_pickups" },
    { 0x1002A, "mix_with_caps" },
    { 0x1002B, "ml_p1_func" },
    { 0x1002C, "ml_p1_intel_player_vo" },
    { 0x1002D, "ml_p2_fail_start" },
    { 0x1002E, "ml_p2_func" },
    { 0x1002F, "ml_p3_func" },
    { 0x10030, "ml_p3_to_safehouse_transition" },
    { 0x10031, "mlghitlocrequiresclamp" },
    { 0x10032, "mlgiconemptyflag" },
    { 0x10033, "mlgiconfullflag" },
    { 0x10034, "mlgmodifyheadshotdamage" },
    { 0x10035, "mlgpoint" },
    { 0x10036, "mlp2_front_truck" },
    { 0x10037, "mode_can_play_ending" },
    { 0x10038, "modeaddtoteamlives" },
    { 0x10039, "modeallowmeleevehicledamage" },
    { 0x1003A, "modeextendlatejoinerloadscreen" },
    { 0x1003B, "modegetforceoperatorcustomization" },
    { 0x1003C, "modeignorevehicleexplosivedamage" },
    { 0x1003D, "modeiskillstreakallowed" },
    { 0x1003E, "model_ent" },
    { 0x1003F, "model_parts" },
    { 0x10040, "modelaststandallowed" },
    { 0x10041, "modeloadoutupdateammo" },
    { 0x10042, "modelpart" },
    { 0x10043, "modemayconsiderplayerdead" },
    { 0x10044, "modeonexitlaststandfunc" },
    { 0x10045, "modeplayerkilledspawn" },
    { 0x10046, "modeplayerskipdialog" },
    { 0x10047, "moderemovefromteamlives" },
    { 0x10048, "moderestrictsarenakillstreaks" },
    { 0x10049, "modescorewinner" },
    { 0x1004A, "modespawn" },
    { 0x1004B, "modespawnclient" },
    { 0x1004C, "modespawnendofgame" },
    { 0x1004D, "modetype" },
    { 0x1004E, "modeupdateloadoutclass" },
    { 0x1004F, "modeusesgroundwarteamoobtriggers" },
    { 0x10050, "modevalidatekillcam" },
    { 0x10051, "modevalidatekillstreakslot" },
    { 0x10052, "modify_blast_shield_damage" },
    { 0x10053, "modify_juggernaut_damage" },
    { 0x10054, "modify_plunder_itemsinworld" },
    { 0x10055, "modifyakimboburstrenettidamagehack" },
    { 0x10056, "modifybrfalldamage" },
    { 0x10057, "modifybrgasdamage" },
    { 0x10058, "modifybrvehicledamage" },
    { 0x10059, "modifycrushdamage" },
    { 0x1005A, "modifydamagetohunter" },
    { 0x1005B, "modifydamagetoprop" },
    { 0x1005C, "modifydestructibledamage" },
    { 0x1005D, "modifyfalldamage" },
    { 0x1005E, "modifyplayer_damage" },
    { 0x1005F, "modifyscenenode" },
    { 0x10060, "modifytriggerlocation" },
    { 0x10061, "modifyvehicledamage" },
    { 0x10062, "modifyvehicletoplayerdamage" },
    { 0x10063, "mods_that_can_stun" },
    { 0x10064, "modsforclass" },
    { 0x10065, "modsforvehicle" },
    { 0x10066, "modular_spawning_vehicles" },
    { 0x10067, "module_call_counter" },
    { 0x10068, "module_has_data_for_call_count" },
    { 0x10069, "module_pause_funcs" },
    { 0x1006A, "module_set_goal_height" },
    { 0x1006B, "module_set_goal_radius" },
    { 0x1006C, "module_set_script_origin_other_on_ai" },
    { 0x1006D, "module_set_skip_basic_combat" },
    { 0x1006E, "module_unpause_funcs" },
    { 0x1006F, "module_vehicles_count" },
    { 0x10070, "module_wait_for_level_flag" },
    { 0x10071, "module_wait_for_level_flag_set_and_clear" },
    { 0x10072, "molotov_can_cast_this_frame" },
    { 0x10073, "molotov_cleanup_branch" },
    { 0x10074, "molotov_cleanup_pool" },
    { 0x10075, "molotov_clear_fx" },
    { 0x10076, "molotov_crate_player_at_max_ammo" },
    { 0x10077, "molotov_crate_spawn" },
    { 0x10078, "molotov_crate_update_hint_logic_alt" },
    { 0x10079, "molotov_crate_use" },
    { 0x1007A, "molotov_damage_over_time" },
    { 0x1007B, "molotov_delete_oldest_scriptable" },
    { 0x1007C, "molotov_delete_oldest_trigger" },
    { 0x1007D, "molotov_delete_pool_by_id" },
    { 0x1007E, "molotov_delete_scriptable" },
    { 0x1007F, "molotov_delete_trigger" },
    { 0x10080, "molotov_get_cast_level_data" },
    { 0x10081, "molotov_get_level_data" },
    { 0x10082, "molotov_get_pool_level_data" },
    { 0x10083, "molotov_get_unique_pool_id" },
    { 0x10084, "molotov_mortars" },
    { 0x10085, "molotov_register_cast" },
    { 0x10086, "molotov_register_scriptable" },
    { 0x10087, "molotov_register_trigger" },
    { 0x10088, "molotov_store_branch_ents" },
    { 0x10089, "molotov_trigger_timeout" },
    { 0x1008A, "molotov_watch_cleanup_pool" },
    { 0x1008B, "molotov_watch_cleanup_pool_internal" },
    { 0x1008C, "molotovrecentlyused" },
    { 0x1008D, "mon_clip" },
    { 0x1008E, "monitor" },
    { 0x1008F, "monitor_balloon_marker_throw" },
    { 0x10090, "monitor_balloons" },
    { 0x10091, "monitor_bush_trig" },
    { 0x10092, "monitor_death_thread" },
    { 0x10093, "monitor_dropkit_marker_throw" },
    { 0x10094, "monitor_dropmenu" },
    { 0x10095, "monitor_dropped_phones" },
    { 0x10096, "monitor_enemy_death" },
    { 0x10097, "monitor_flag_carrier" },
    { 0x10098, "monitor_fronttruck_death" },
    { 0x10099, "monitor_game_end_on_front_truck_death" },
    { 0x1009A, "monitor_hack_prox" },
    { 0x1009B, "monitor_heli_depsoit_or_timeout" },
    { 0x1009C, "monitor_inside_building" },
    { 0x1009D, "monitor_molotov_throws" },
    { 0x1009E, "monitor_outline_ents" },
    { 0x1009F, "monitor_player_close" },
    { 0x100A0, "monitor_player_found_supply_station" },
    { 0x100A1, "monitor_player_near_truck" },
    { 0x100A2, "monitor_player_opens_box" },
    { 0x100A3, "monitor_player_opens_box_backup" },
    { 0x100A4, "monitor_player_pinging" },
    { 0x100A5, "monitor_player_plunder" },
    { 0x100A6, "monitor_player_plundercount" },
    { 0x100A7, "monitor_special_spawns" },
    { 0x100A8, "monitor_target_death" },
    { 0x100A9, "monitor_traversal_cooldown" },
    { 0x100AA, "monitor_traversal_timer" },
    { 0x100AB, "monitor_traversal_watcher" },
    { 0x100AC, "monitor_truck" },
    { 0x100AD, "monitor_truck_stuck" },
    { 0x100AE, "monitor_victim_cash_drops" },
    { 0x100AF, "monitor_waypoint_objective_on_front_truck" },
    { 0x100B0, "monitoraveragevelocities" },
    { 0x100B1, "monitoraveragevelocityandupdate" },
    { 0x100B2, "monitorcontrolscallback" },
    { 0x100B3, "monitordriverexitbutton" },
    { 0x100B4, "monitorexitbutton" },
    { 0x100B5, "monitorextractionlocations" },
    { 0x100B6, "monitorhotfoot" },
    { 0x100B7, "monitorhvt_gooddroppos" },
    { 0x100B8, "monitorimpact" },
    { 0x100B9, "monitorimpactend" },
    { 0x100BA, "monitorimpactinternal" },
    { 0x100BB, "monitoringimpact" },
    { 0x100BC, "monitormountdisabled" },
    { 0x100BD, "monitormounted" },
    { 0x100BE, "monitorplayerimpact" },
    { 0x100BF, "monitorplayerimpactend" },
    { 0x100C0, "monitortacmapusage" },
    { 0x100C1, "monitortimers" },
    { 0x100C2, "monitorweaponfiretime" },
    { 0x100C3, "monitorweaponswitchbr" },
    { 0x100C4, "morales_laptop_initted" },
    { 0x100C5, "moraleslaptopthink" },
    { 0x100C6, "morsenumber" },
    { 0x100C7, "mortar_add_fov_user_scale" },
    { 0x100C8, "mortar_cooldown" },
    { 0x100C9, "mortar_getimpactspot" },
    { 0x100CA, "mortar_init" },
    { 0x100CB, "mortar_initmortars" },
    { 0x100CC, "mortar_remove_fov_user_scale" },
    { 0x100CD, "mortar_smoke_occlusions" },
    { 0x100CE, "mortar_start" },
    { 0x100CF, "mortar_wave" },
    { 0x100D0, "mortars" },
    { 0x100D1, "mortars_fire_logic" },
    { 0x100D2, "mortars_fire_projectile" },
    { 0x100D3, "mortars_get_available_players" },
    { 0x100D4, "mortars_get_enemies" },
    { 0x100D5, "mortars_get_player_targeted" },
    { 0x100D6, "mortars_set_player_targeted" },
    { 0x100D7, "mountain_one_death_func" },
    { 0x100D8, "mountain_three_death_func" },
    { 0x100D9, "mountain_two_death_func" },
    { 0x100DA, "mounted" },
    { 0x100DB, "mountstringtodlogenum" },
    { 0x100DC, "mounttrig" },
    { 0x100DD, "mousetraplocs" },
    { 0x100DE, "mousetraps" },
    { 0x100DF, "mousetrapsfound" },
    { 0x100E0, "mousetrapwatcher" },
    { 0x100E1, "move_and_delete_objects_cleararea" },
    { 0x100E2, "move_arena_startspawns" },
    { 0x100E3, "move_closest_chopper_boss_vandalize_node_down" },
    { 0x100E4, "move_door_to_pos" },
    { 0x100E5, "move_ent" },
    { 0x100E6, "move_entity" },
    { 0x100E7, "move_gate" },
    { 0x100E8, "move_hvt_from_under_heli" },
    { 0x100E9, "move_molotov_mortar" },
    { 0x100EA, "move_objective_icon" },
    { 0x100EB, "move_payload_to_back_of_super" },
    { 0x100EC, "move_platform" },
    { 0x100ED, "move_player_from_under_heli_and_kill" },
    { 0x100EE, "move_spawnpoints_to_ac130" },
    { 0x100EF, "move_spawnpoints_to_valid_positions" },
    { 0x100F0, "move_structs" },
    { 0x100F1, "move_to_car_stop" },
    { 0x100F2, "move_to_new_node" },
    { 0x100F3, "move_to_track_end" },
    { 0x100F4, "move_window_light" },
    { 0x100F5, "movedtoinfected" },
    { 0x100F6, "moveeffect" },
    { 0x100F7, "movelatejoinerstospectators" },
    { 0x100F8, "moveleadmarkers" },
    { 0x100F9, "movement_vector" },
    { 0x100FA, "movenavobstaclemonitor" },
    { 0x100FB, "moveplayertotoppos" },
    { 0x100FC, "moveplunderextractionsitesonuse" },
    { 0x100FD, "movequestcircle" },
    { 0x100FE, "movequestlocale" },
    { 0x100FF, "movequestobjicon" },
    { 0x10100, "mover_init" },
    { 0x10101, "mover_update" },
    { 0x10102, "movers_ref" },
    { 0x10103, "movetonewprop" },
    { 0x10104, "movetowithpause" },
    { 0x10105, "moving_platform_angles_offset" },
    { 0x10106, "moving_platform_offset" },
    { 0x10107, "movingplatform_playerlink" },
    { 0x10108, "movingplatform_playerunlink" },
    { 0x10109, "movingplatforment" },
    { 0x1010A, "mp_aniyah_patch" },
    { 0x1010B, "mp_backlot2_patch" },
    { 0x1010C, "mp_boneyard_gw_patch" },
    { 0x1010D, "mp_br_quarry_locations" },
    { 0x1010E, "mp_cave_am_patch" },
    { 0x1010F, "mp_crash2" },
    { 0x10110, "mp_deadzone_patch" },
    { 0x10111, "mp_donetsk_locations" },
    { 0x10112, "mp_downtown_gw_patch" },
    { 0x10113, "mp_emporium_hanging_crates" },
    { 0x10114, "mp_emporium_patch" },
    { 0x10115, "mp_euphrates_gunnonlinear_opendoor" },
    { 0x10116, "mp_euphrates_patches" },
    { 0x10117, "mp_farms2_gw_patch" },
    { 0x10118, "mp_hackney_yard_patch" },
    { 0x10119, "mp_harbor_patch" },
    { 0x1011A, "mp_hardhat_patch" },
    { 0x1011B, "mp_hideout_patch" },
    { 0x1011C, "mp_layover_patch" },
    { 0x1011D, "mp_m_cornfield_patch" },
    { 0x1011E, "mp_m_king_patch" },
    { 0x1011F, "mp_m_overunder_patch" },
    { 0x10120, "mp_m_speed_patch" },
    { 0x10121, "mp_m_speedball_patch" },
    { 0x10122, "mp_m_stack_patch" },
    { 0x10123, "mp_m_trench_patch" },
    { 0x10124, "mp_m_trench_patch_giveplayer_c4" },
    { 0x10125, "mp_oilrig_patches" },
    { 0x10126, "mp_piccadilly_patch" },
    { 0x10127, "mp_port2_gw_patch" },
    { 0x10128, "mp_raid_patch" },
    { 0x10129, "mp_runner_patch" },
    { 0x1012A, "mp_rust_patch" },
    { 0x1012B, "mp_shipment_patch" },
    { 0x1012C, "mp_speedball_check_trigger_pos" },
    { 0x1012D, "mp_t_gun_course_patch" },
    { 0x1012E, "mp_t_reflex_containers_collisions" },
    { 0x1012F, "mp_t_reflex_patch" },
    { 0x10130, "mp_vacant_patch" },
    { 0x10131, "mp_vacant_patch_thread" },
    { 0x10132, "mp_village2_patches" },
    { 0x10133, "mpweapon" },
    { 0x10134, "mud_sfx" },
    { 0x10135, "multieventdebug" },
    { 0x10136, "multieventdisabled" },
    { 0x10137, "multiplepubliceventsenabled" },
    { 0x10138, "munition_remover" },
    { 0x10139, "munition_slot_gunship_emptied_message" },
    { 0x1013A, "munition_source_getridof" },
    { 0x1013B, "munitions_override_time" },
    { 0x1013C, "munitions_override_waittill" },
    { 0x1013D, "music_timer_10seconds" },
    { 0x1013E, "musictriggerthink" },
    { 0x1013F, "nag_get_in_heli" },
    { 0x10140, "nag_player_remind_lore_vo" },
    { 0x10141, "nag_radius" },
    { 0x10142, "nagstilflag" },
    { 0x10143, "nakeddrophandleloadout" },
    { 0x10144, "name_fx" },
    { 0x10145, "namehud" },
    { 0x10146, "namelocations" },
    { 0x10147, "nearby_ai_combat_via_grenade" },
    { 0x10148, "nearby_ai_investigate_grenade" },
    { 0x10149, "need_respawn" },
    { 0x1014A, "needdefaultendgameflowonly" },
    { 0x1014B, "needs_antenna" },
    { 0x1014C, "needs_controller" },
    { 0x1014D, "needs_power" },
    { 0x1014E, "needs_radar" },
    { 0x1014F, "neurotoxin_damage_loop" },
    { 0x10150, "neurotoxin_damage_monitor" },
    { 0x10151, "neurotoxin_mask_monitor" },
    { 0x10152, "never_delete_suicide_bomber" },
    { 0x10153, "never_kill_off_after_stealth" },
    { 0x10154, "never_kill_off_old" },
    { 0x10155, "never_unloaded_from_vehicle" },
    { 0x10156, "neverspectate" },
    { 0x10157, "new_agent_def_main" },
    { 0x10158, "new_angles" },
    { 0x10159, "new_col_map" },
    { 0x1015A, "new_objective" },
    { 0x1015B, "new_objective_thread" },
    { 0x1015C, "new_rider_combat_logic" },
    { 0x1015D, "newhitlocs" },
    { 0x1015E, "next_drone_cd" },
    { 0x1015F, "next_mortar_vo" },
    { 0x10160, "next_subway_track_hurt_time" },
    { 0x10161, "next_threshold" },
    { 0x10162, "nextareanags" },
    { 0x10163, "nextbombplanttime" },
    { 0x10164, "nextcombatareaid" },
    { 0x10165, "nextdest" },
    { 0x10166, "nextfixupcheckms" },
    { 0x10167, "nexthealthtiercalledout" },
    { 0x10168, "nextplayertospectate" },
    { 0x10169, "nextscore" },
    { 0x1016A, "nextstar" },
    { 0x1016B, "nextswitch" },
    { 0x1016C, "nexttrackindex" },
    { 0x1016D, "ninetypercent_music" },
    { 0x1016E, "no_aerial_munitions" },
    { 0x1016F, "no_csm" },
    { 0x10170, "no_enemy_weapon_drops" },
    { 0x10171, "no_jugg_early_exit" },
    { 0x10172, "no_more_wire_to_cut" },
    { 0x10173, "no_previous_interaction_point" },
    { 0x10174, "nocrash" },
    { 0x10175, "nocrouch" },
    { 0x10176, "node_cansee_child" },
    { 0x10177, "node_fields_after_goal_skit" },
    { 0x10178, "node_get_children" },
    { 0x10179, "node_grid" },
    { 0x1017A, "node_is_valid" },
    { 0x1017B, "node_set_children" },
    { 0x1017C, "node_targetname" },
    { 0x1017D, "nodes_set_children" },
    { 0x1017E, "nodetype" },
    { 0x1017F, "nodropanim" },
    { 0x10180, "nogroundfoundtime" },
    { 0x10181, "nolandingdamage" },
    { 0x10182, "non_detectable_killstreaks" },
    { 0x10183, "nonbunkerdoors" },
    { 0x10184, "nonnvgnightmap" },
    { 0x10185, "noprone" },
    { 0x10186, "nopropsspectate" },
    { 0x10187, "normalspeed" },
    { 0x10188, "nospectatablepropswatch" },
    { 0x10189, "nosplash" },
    { 0x1018A, "nostand" },
    { 0x1018B, "notcanon" },
    { 0x1018C, "notetrack_listener_cattleprod_shock_player_at_gate" },
    { 0x1018D, "notify_planter_on_damage" },
    { 0x1018E, "notify_planter_on_whizby" },
    { 0x1018F, "notify_when_loadout_given" },
    { 0x10190, "notifycapturetoplayers" },
    { 0x10191, "notifyteamonvehicledeath" },
    { 0x10192, "notstand" },
    { 0x10193, "npcbodies" },
    { 0x10194, "nuclear_core_carrier_escaped" },
    { 0x10195, "nuclear_core_on_chopper" },
    { 0x10196, "nuke_abortkillcamonspawn" },
    { 0x10197, "nuke_addteamrankxpmultiplier" },
    { 0x10198, "nuke_cancel" },
    { 0x10199, "nuke_carrier_last_transform" },
    { 0x1019A, "nuke_core_time_warning_nag" },
    { 0x1019B, "nuke_core_tug_of_war" },
    { 0x1019C, "nuke_explposstruct" },
    { 0x1019D, "nuke_hostmigration_waitlongdurationwithpause" },
    { 0x1019E, "nuke_hostmigration_waittillhostmigrationdone" },
    { 0x1019F, "nuke_killplayer" },
    { 0x101A0, "nuke_killplayerwithattacker" },
    { 0x101A1, "nuke_mercyending_init" },
    { 0x101A2, "nuke_mercyending_think" },
    { 0x101A3, "nuke_playmushroombnk" },
    { 0x101A4, "nuke_removefadeonbnkplay" },
    { 0x101A5, "nuke_shouldnukeendgame" },
    { 0x101A6, "nuke_slamtoblack" },
    { 0x101A7, "nuke_startexfilcountdown" },
    { 0x101A8, "nuke_startmercycountdown" },
    { 0x101A9, "nuke_stoptheclock" },
    { 0x101AA, "nuke_timescalefactor" },
    { 0x101AB, "nuke_triggermercywin" },
    { 0x101AC, "nuke_vault_alarm" },
    { 0x101AD, "nuke_vault_alarm_on" },
    { 0x101AE, "nuke_vault_door" },
    { 0x101AF, "nuke_vault_door_alarm" },
    { 0x101B0, "nuke_vault_door_sounds" },
    { 0x101B1, "nuke_vault_escape" },
    { 0x101B2, "nuke_vault_jugg" },
    { 0x101B3, "nuke_vault_jugg_internal" },
    { 0x101B4, "nuke_vault_jugg_shoot_at_scriptables" },
    { 0x101B5, "nuke_vault_key" },
    { 0x101B6, "nuke_vault_oil_puddle_watch" },
    { 0x101B7, "nuke_vault_oilfire_player_vision" },
    { 0x101B8, "nuke_vault_oilfire_vfx_end_on_death" },
    { 0x101B9, "nuke_vault_oilfire_vision" },
    { 0x101BA, "nuke_vault_riotshield" },
    { 0x101BB, "nuke_vault_riotshield_internal" },
    { 0x101BC, "nuke_vault_runner" },
    { 0x101BD, "nuke_vault_runner_internal" },
    { 0x101BE, "nuke_vault_suicidebomber" },
    { 0x101BF, "nuke_vault_suicidebomber_internal" },
    { 0x101C0, "nuke_vault_suicidebombers" },
    { 0x101C1, "nukefridgewatcher" },
    { 0x101C2, "nukeplayer" },
    { 0x101C3, "num_hackers" },
    { 0x101C4, "num_nags" },
    { 0x101C5, "num_nodes_random_search" },
    { 0x101C6, "num_nodes_search_player" },
    { 0x101C7, "num_of_frame_frozen" },
    { 0x101C8, "num_of_subway_cars" },
    { 0x101C9, "num_players_by_truck" },
    { 0x101CA, "num_players_in_safehouse" },
    { 0x101CB, "num_rocket_per_attack" },
    { 0x101CC, "num_shot_taken_to_next_damage_state" },
    { 0x101CD, "num_times_stealth_broken_tv_station_interior" },
    { 0x101CE, "numactivejuggdrops" },
    { 0x101CF, "numarmorhealth" },
    { 0x101D0, "numberaudioalias" },
    { 0x101D1, "numbers" },
    { 0x101D2, "numbersroomdogtagrevive" },
    { 0x101D3, "numconsumed" },
    { 0x101D4, "numdepositers" },
    { 0x101D5, "numextractions" },
    { 0x101D6, "numfound" },
    { 0x101D7, "numhunters" },
    { 0x101D8, "numkilled" },
    { 0x101D9, "numnonrallyvehicles" },
    { 0x101DA, "numpropsperarea" },
    { 0x101DB, "numrequireddestinations" },
    { 0x101DC, "numsiegeflags" },
    { 0x101DD, "nvgvisionsetoverride" },
    { 0x101DE, "nvgwatcher" },
    { 0x101DF, "nvidiaansel_allowduringcinematic" },
    { 0x101E0, "nvidiaansel_overridecollisionradius" },
    { 0x101E1, "nvidiaansel_scriptdisable" },
    { 0x101E2, "obit_activation" },
    { 0x101E3, "obit_destroy_old_vehicles" },
    { 0x101E4, "obit_trigger_for_player" },
    { 0x101E5, "obj_a_behavior" },
    { 0x101E6, "obj_a_covers" },
    { 0x101E7, "obj_a_goals" },
    { 0x101E8, "obj_a_post_behavior" },
    { 0x101E9, "obj_a_roof_jugg" },
    { 0x101EA, "obj_caches_tanks" },
    { 0x101EB, "obj_caches_threaded_nags_vo" },
    { 0x101EC, "obj_cleanup" },
    { 0x101ED, "obj_destroy_tanks" },
    { 0x101EE, "obj_fob1" },
    { 0x101EF, "obj_fob1_juggs" },
    { 0x101F0, "obj_fob2" },
    { 0x101F1, "obj_hangar_bombs" },
    { 0x101F2, "obj_hangar_juggs" },
    { 0x101F3, "obj_heli_assault2" },
    { 0x101F4, "obj_heli_assault3_fob" },
    { 0x101F5, "obj_hvt_dead" },
    { 0x101F6, "obj_icon_revealed" },
    { 0x101F7, "obj_id" },
    { 0x101F8, "obj_leads_found_overall" },
    { 0x101F9, "obj_leads_spawned_overall" },
    { 0x101FA, "obj_overwatch_lmgs_remaining" },
    { 0x101FB, "obj_overwatch_tanks_ref" },
    { 0x101FC, "obj_ow_atvs_spawned" },
    { 0x101FD, "obj_payload_stage" },
    { 0x101FE, "obj_pregame" },
    { 0x101FF, "obj_riverbed" },
    { 0x10200, "obj_room_fire_01" },
    { 0x10201, "obj_room_fire_02" },
    { 0x10202, "obj_room_fire_03" },
    { 0x10203, "obj_room_fire_04" },
    { 0x10204, "obj_room_fire_05" },
    { 0x10205, "obj_room_fire_06" },
    { 0x10206, "obj_room_fire_07" },
    { 0x10207, "obj_room_fire_08" },
    { 0x10208, "obj_room_fire_09" },
    { 0x10209, "obj_room_fire_10" },
    { 0x1020A, "obj_room_fire_11" },
    { 0x1020B, "obj_running_exfil_wave" },
    { 0x1020C, "obj_smuggler_killed_early" },
    { 0x1020D, "obj_tugofwar_drain_speed" },
    { 0x1020E, "obj_vindia" },
    { 0x1020F, "object_is_valid" },
    { 0x10210, "objective_hide_for_mlg_spectator" },
    { 0x10211, "objective_locations" },
    { 0x10212, "objective_locations_logic" },
    { 0x10213, "objective_minimapupdate" },
    { 0x10214, "objective_origin" },
    { 0x10215, "objective_set_hot" },
    { 0x10216, "objective_show_for_mlg_spectator" },
    { 0x10217, "objective_timers_reset_both" },
    { 0x10218, "objectiveachievementkillcount" },
    { 0x10219, "objectivedescription" },
    { 0x1021A, "objectiveicon" },
    { 0x1021B, "objectiveids" },
    { 0x1021C, "objectiveloc" },
    { 0x1021D, "objectivelocations" },
    { 0x1021E, "objectives_amount" },
    { 0x1021F, "objectives_finale" },
    { 0x10220, "objectivespawner" },
    { 0x10221, "objectivetext" },
    { 0x10222, "objloc" },
    { 0x10223, "occupied_rpg_trig" },
    { 0x10224, "oceanrock" },
    { 0x10225, "off_max" },
    { 0x10226, "off_min" },
    { 0x10227, "offerloc" },
    { 0x10228, "offlight" },
    { 0x10229, "og_fov" },
    { 0x1022A, "og_mbradial" },
    { 0x1022B, "ogangles" },
    { 0x1022C, "ogflaresreservecount" },
    { 0x1022D, "oic_firstspawn" },
    { 0x1022E, "oic_guns" },
    { 0x1022F, "oic_hasspawned" },
    { 0x10230, "oic_loadouts" },
    { 0x10231, "oic_rewardammo" },
    { 0x10232, "oicvariantid" },
    { 0x10233, "oil_puddles" },
    { 0x10234, "oilfire_burning_player_watch" },
    { 0x10235, "old_accuracy" },
    { 0x10236, "old_getspawnpoint" },
    { 0x10237, "old_getspawnpoint_func" },
    { 0x10238, "old_goalheight" },
    { 0x10239, "old_health" },
    { 0x1023A, "old_load_hvt" },
    { 0x1023B, "old_maxhealth" },
    { 0x1023C, "old_spectator_func" },
    { 0x1023D, "oldbranchents" },
    { 0x1023E, "oldest_targeted_by_chopper_time" },
    { 0x1023F, "oldkey" },
    { 0x10240, "oldlatespawnplayer" },
    { 0x10241, "oldprogress" },
    { 0x10242, "omnvar_bit" },
    { 0x10243, "omnvardata" },
    { 0x10244, "omnvars" },
    { 0x10245, "omvar_code" },
    { 0x10246, "on_execution_begin" },
    { 0x10247, "on_killed_tutorial" },
    { 0x10248, "on_max" },
    { 0x10249, "on_min" },
    { 0x1024A, "onarmorboxusedbyplayer" },
    { 0x1024B, "onattackerdamagenottracked" },
    { 0x1024C, "oncacheopen" },
    { 0x1024D, "oncapture" },
    { 0x1024E, "oncollectitem" },
    { 0x1024F, "oncontractend" },
    { 0x10250, "oncontractstart" },
    { 0x10251, "oncooldown" },
    { 0x10252, "oncrankedhit" },
    { 0x10253, "oncrateactivate" },
    { 0x10254, "oncratedestroy" },
    { 0x10255, "oncrateuse" },
    { 0x10256, "ondamagepredamagemodrelicfocusfire" },
    { 0x10257, "ondamagepredamagemodrelics" },
    { 0x10258, "ondamagereliccollatdmg" },
    { 0x10259, "ondamagerelicdoomslayer" },
    { 0x1025A, "ondamagerelicfocusfire" },
    { 0x1025B, "ondamagerelicfromabove" },
    { 0x1025C, "ondamagereliclfo" },
    { 0x1025D, "ondamagerelicsquadlink" },
    { 0x1025E, "ondamagerelicsteelballs" },
    { 0x1025F, "ondamagerelicvampire" },
    { 0x10260, "ondefuse" },
    { 0x10261, "ondroprelics" },
    { 0x10262, "onenterbattlechatter" },
    { 0x10263, "onentercallback" },
    { 0x10264, "onenterfunc" },
    { 0x10265, "oneoffuavsweeps" },
    { 0x10266, "onexitcallback" },
    { 0x10267, "onexitfunc" },
    { 0x10268, "onexplode" },
    { 0x10269, "onfieldupgradeend" },
    { 0x1026A, "onfieldupgradeendbuffer" },
    { 0x1026B, "onfirstlandcallback" },
    { 0x1026C, "ongrenadeused" },
    { 0x1026D, "ongulagendmatch" },
    { 0x1026E, "onhack" },
    { 0x1026F, "onhelmetsniped" },
    { 0x10270, "onhotfootplayerkilled" },
    { 0x10271, "oninstanceremoved" },
    { 0x10272, "oninteractionstarted" },
    { 0x10273, "onjoinedteamcb" },
    { 0x10274, "onjoinspectators" },
    { 0x10275, "onjointeamnospectatorcallbacks" },
    { 0x10276, "onkillingblow" },
    { 0x10277, "onkillstreakavailable" },
    { 0x10278, "onkillstreakend" },
    { 0x10279, "onkioskpurchaseitem" },
    { 0x1027A, "onlaststandkillenemy" },
    { 0x1027B, "onlaststandrevive" },
    { 0x1027C, "onlineprimaryoverride" },
    { 0x1027D, "onloadout" },
    { 0x1027E, "onlowpopstart" },
    { 0x1027F, "onlyexecutefromthefront" },
    { 0x10280, "onmaprestart" },
    { 0x10281, "onmatchplacement" },
    { 0x10282, "onmatchstartbr" },
    { 0x10283, "onnewequipmentpickup" },
    { 0x10284, "onpickupitem" },
    { 0x10285, "onping" },
    { 0x10286, "onplant" },
    { 0x10287, "onplayerconnectrisk" },
    { 0x10288, "onplayerconnectstream" },
    { 0x10289, "onplayerdamaged_func" },
    { 0x1028A, "onplayereliminated_func" },
    { 0x1028B, "onplayerentergulag" },
    { 0x1028C, "onplayergetsplunder" },
    { 0x1028D, "onplayerjointeamnospectator" },
    { 0x1028E, "onplayerkillednew" },
    { 0x1028F, "onplayerrespawn" },
    { 0x10290, "onpostkillcamcallback" },
    { 0x10291, "onprematchfadedone" },
    { 0x10292, "onprematchfadedone2" },
    { 0x10293, "onprematchstarted2" },
    { 0x10294, "onquesttablethide" },
    { 0x10295, "onriotshieldstow_force" },
    { 0x10296, "onriskplayerdisconnect" },
    { 0x10297, "onriskplayerkilled" },
    { 0x10298, "onscavengerbagpickup" },
    { 0x10299, "onsoccerballreset" },
    { 0x1029A, "onspawn_fastspeed" },
    { 0x1029B, "onspawn_slowspeed" },
    { 0x1029C, "onspecialistbonusavailable" },
    { 0x1029D, "onspray" },
    { 0x1029E, "onsquadeliminatedplacement" },
    { 0x1029F, "onstim" },
    { 0x102A0, "onstompeenemyprogressupdate" },
    { 0x102A1, "onstun" },
    { 0x102A2, "onsupportboxusedbyplayer" },
    { 0x102A3, "onteamleadgained" },
    { 0x102A4, "onteamleadlost" },
    { 0x102A5, "onteammatereviveweaponswitchcomplete" },
    { 0x102A6, "onteammatereviveweapontaken" },
    { 0x102A7, "onteamproximitybecameinvalidplayer" },
    { 0x102A8, "onteamproximitysteppedclose" },
    { 0x102A9, "onteamproximitysteppedfar" },
    { 0x102AA, "onunlockitem" },
    { 0x102AB, "onupdatefunc" },
    { 0x102AC, "onuseitem" },
    { 0x102AD, "onusethanksbc" },
    { 0x102AE, "onweapondropcreated" },
    { 0x102AF, "onweapondroppickedup" },
    { 0x102B0, "onweapontaken" },
    { 0x102B1, "open_any_random_airlock_door" },
    { 0x102B2, "open_cac_slot" },
    { 0x102B3, "open_close_initial" },
    { 0x102B4, "open_close_loop" },
    { 0x102B5, "open_door_to_next_objective" },
    { 0x102B6, "open_doors" },
    { 0x102B7, "open_exit_doors" },
    { 0x102B8, "open_gunshop_door" },
    { 0x102B9, "open_selected_doors" },
    { 0x102BA, "open_sliding_door" },
    { 0x102BB, "open_spots_and_spawn_truck" },
    { 0x102BC, "open_starting_safehouse_door" },
    { 0x102BD, "open_teleport_room_door" },
    { 0x102BE, "open_this_door" },
    { 0x102BF, "open_trap_room_door" },
    { 0x102C0, "open_tut_gate" },
    { 0x102C1, "openaltbunker" },
    { 0x102C2, "openangles" },
    { 0x102C3, "openbunkerdoor" },
    { 0x102C4, "opened_position" },
    { 0x102C5, "openelevatordoors" },
    { 0x102C6, "opennukecrate" },
    { 0x102C7, "openpos" },
    { 0x102C8, "openrequested" },
    { 0x102C9, "openrightblimadoor" },
    { 0x102CA, "openscriptabledoors" },
    { 0x102CB, "operator_reward_id" },
    { 0x102CC, "operator_unlock_ids" },
    { 0x102CD, "operatorsfx" },
    { 0x102CE, "operatorsfxalias" },
    { 0x102CF, "optional_params" },
    { 0x102D0, "order_path_data" },
    { 0x102D1, "orderindex" },
    { 0x102D2, "org_in_bad_place" },
    { 0x102D3, "organizeproplist" },
    { 0x102D4, "origin_delta" },
    { 0x102D5, "original_disablelongdeath" },
    { 0x102D6, "original_health" },
    { 0x102D7, "original_meleechargedistvsplayer" },
    { 0x102D8, "originalangle" },
    { 0x102D9, "originalloc" },
    { 0x102DA, "originalownerteam" },
    { 0x102DB, "originalsubtype" },
    { 0x102DC, "oscar_hack" },
    { 0x102DD, "oscope_ampl" },
    { 0x102DE, "oscope_ampl_think" },
    { 0x102DF, "oscope_freq" },
    { 0x102E0, "oscope_freq_think" },
    { 0x102E1, "oscope_sign" },
    { 0x102E2, "oscope_sign_think" },
    { 0x102E3, "oscope_temp" },
    { 0x102E4, "oscope_temps_think" },
    { 0x102E5, "outer" },
    { 0x102E6, "outline_enemy_ai_for_duration" },
    { 0x102E7, "outline_ent_index" },
    { 0x102E8, "outline_ents" },
    { 0x102E9, "outline_grenade_box" },
    { 0x102EA, "outofboundstimebr" },
    { 0x102EB, "outofboundstriggersplanetrace" },
    { 0x102EC, "outofboundstriggersspawned" },
    { 0x102ED, "outofboundswatcher" },
    { 0x102EE, "outputfunc" },
    { 0x102EF, "outro_dialogue_logic" },
    { 0x102F0, "outro_enemy_spawning" },
    { 0x102F1, "outro_main" },
    { 0x102F2, "overheatcooldown" },
    { 0x102F3, "overheatlimit" },
    { 0x102F4, "overheatreductionamount" },
    { 0x102F5, "overheatreductionrate" },
    { 0x102F6, "overheatreductiontime" },
    { 0x102F7, "override_minimap_hide" },
    { 0x102F8, "override_supply_drop_vfx" },
    { 0x102F9, "overridecountdownmusic" },
    { 0x102FA, "overridefieldupgrade1" },
    { 0x102FB, "overridefieldupgrade2" },
    { 0x102FC, "overridepointsneeded" },
    { 0x102FD, "overrideviewkickscaledmr" },
    { 0x102FE, "overrideviewkickscalek98" },
    { 0x102FF, "overtime_music" },
    { 0x10300, "overtimebuiltintomatchtimer" },
    { 0x10301, "overtimecashmultiplier" },
    { 0x10302, "overwatch_player" },
    { 0x10303, "overwatch_soldiers_05_bombers" },
    { 0x10304, "overwatch_tank_backup" },
    { 0x10305, "overwatchent" },
    { 0x10306, "ow_current_scrambler_count" },
    { 0x10307, "ow_gunship_slot" },
    { 0x10308, "owner_name" },
    { 0x10309, "ownerxuid" },
    { 0x1030A, "p4_trigger" },
    { 0x1030B, "packarenaomnvardata" },
    { 0x1030C, "packclientmatchdata" },
    { 0x1030D, "packedbits" },
    { 0x1030E, "packextrascore0" },
    { 0x1030F, "packs" },
    { 0x10310, "packsplashparambits" },
    { 0x10311, "padcorner3to0dist" },
    { 0x10312, "paddedquadgridcenterpoints" },
    { 0x10313, "paddedquadgridradius2dsq" },
    { 0x10314, "padding_damage" },
    { 0x10315, "paired_lasers" },
    { 0x10316, "para_groups" },
    { 0x10317, "parachute_deploy" },
    { 0x10318, "parachute_get_path" },
    { 0x10319, "parachute_set_spawn_values" },
    { 0x1031A, "parachute_skydive" },
    { 0x1031B, "parachute_spawn" },
    { 0x1031C, "parachutecancutautodeploy" },
    { 0x1031D, "parachutecancutparachute" },
    { 0x1031E, "parachutecleanup" },
    { 0x1031F, "parachutedeploydelay" },
    { 0x10320, "parachuteoverheadwarningheight" },
    { 0x10321, "parachuteoverheadwarningprematchtimeoutms" },
    { 0x10322, "parachuteoverheadwarningradius" },
    { 0x10323, "parachuteoverheadwarningtimeoutms" },
    { 0x10324, "parachuteprelaststandfunc" },
    { 0x10325, "parachuteprelaststandfunction" },
    { 0x10326, "parachutestate" },
    { 0x10327, "paramarray" },
    { 0x10328, "paratrooper_vo_time" },
    { 0x10329, "parentweapon" },
    { 0x1032A, "partenum" },
    { 0x1032B, "participantplunder" },
    { 0x1032C, "participantweaponxp" },
    { 0x1032D, "participantxp" },
    { 0x1032E, "passes_final_capsule_check" },
    { 0x1032F, "pasystems" },
    { 0x10330, "patch_collisions_crates" },
    { 0x10331, "patch_ent_fixes" },
    { 0x10332, "patch_far_wait" },
    { 0x10333, "patch_mansion_holes" },
    { 0x10334, "patch_self_check" },
    { 0x10335, "patch_weapons_on_rack_cleararea" },
    { 0x10336, "patchable_collision" },
    { 0x10337, "patched_collision" },
    { 0x10338, "patchfix" },
    { 0x10339, "patchoutofboundstrigger" },
    { 0x1033A, "path_data" },
    { 0x1033B, "path_data_ordered" },
    { 0x1033C, "path_loop" },
    { 0x1033D, "path_timeout" },
    { 0x1033E, "pathblocker" },
    { 0x1033F, "pathdist" },
    { 0x10340, "pathexit" },
    { 0x10341, "pathstruct" },
    { 0x10342, "patrol_a" },
    { 0x10343, "patrol_b" },
    { 0x10344, "patrol_idle_getcellphone" },
    { 0x10345, "patrol_in_stealth" },
    { 0x10346, "patrol_think" },
    { 0x10347, "patrolfunc" },
    { 0x10348, "patrollocation" },
    { 0x10349, "patrolradius" },
    { 0x1034A, "patrolzone" },
    { 0x1034B, "pattern" },
    { 0x1034C, "pause_auto_respawn" },
    { 0x1034D, "pause_combat_logic" },
    { 0x1034E, "pause_wave_hud" },
    { 0x1034F, "pauseallgulagfights" },
    { 0x10350, "pausegulag" },
    { 0x10351, "pausemodetimer" },
    { 0x10352, "pavelow_boss" },
    { 0x10353, "pavelow_boss_after_hit_by_emp" },
    { 0x10354, "pavelow_boss_crash_sequence" },
    { 0x10355, "pavelow_boss_damage_func" },
    { 0x10356, "pavelow_boss_destroyed_watch" },
    { 0x10357, "pavelow_boss_explodes" },
    { 0x10358, "pavelow_boss_health_bar" },
    { 0x10359, "pavelow_boss_hit_by_emp" },
    { 0x1035A, "payload" },
    { 0x1035B, "pbexploitstarttime" },
    { 0x1035C, "pe_chopper_zones" },
    { 0x1035D, "pelletdmgpassed" },
    { 0x1035E, "pelletweaponvictimids" },
    { 0x1035F, "pendingtimer" },
    { 0x10360, "percentageplunderdrop" },
    { 0x10361, "percentagetokensdrop" },
    { 0x10362, "perform_fixes" },
    { 0x10363, "periodic_sound_events" },
    { 0x10364, "perkdiscount" },
    { 0x10365, "perkpackage_checkifready_callback" },
    { 0x10366, "perkpackage_giveoverridefieldupgrades" },
    { 0x10367, "perkpackage_resetoverridefieldupgrades" },
    { 0x10368, "perks_suppressasserts" },
    { 0x10369, "persistantgametypeteamassign" },
    { 0x1036A, "personalnukecostoverride" },
    { 0x1036B, "personalscorecount" },
    { 0x1036C, "personnel_platform" },
    { 0x1036D, "petobjectivefilter" },
    { 0x1036E, "petplundertimer" },
    { 0x1036F, "petrograd_interaction_delayed" },
    { 0x10370, "petrograd_interaction_think" },
    { 0x10371, "petrograd_interactions_init" },
    { 0x10372, "petrograd_lead_model" },
    { 0x10373, "petwatchtype" },
    { 0x10374, "ph" },
    { 0x10375, "ph_checkforovertime" },
    { 0x10376, "ph_endgame" },
    { 0x10377, "ph_loadouts" },
    { 0x10378, "ph_setfinalkillcamwinner" },
    { 0x10379, "phase_five_combat" },
    { 0x1037A, "phase_four_combat" },
    { 0x1037B, "phase_one_combat" },
    { 0x1037C, "phase_three_combat" },
    { 0x1037D, "phase_two_combat" },
    { 0x1037E, "phase_zero_combat" },
    { 0x1037F, "phaseindex" },
    { 0x10380, "phclass" },
    { 0x10381, "phcountdowntimer" },
    { 0x10382, "phfrozen" },
    { 0x10383, "phone" },
    { 0x10384, "phone_group_spawned" },
    { 0x10385, "phone_group_spawned_timeout" },
    { 0x10386, "phonehint" },
    { 0x10387, "phoneisnotringing" },
    { 0x10388, "phoneisringing" },
    { 0x10389, "phonemorsesinglescriptableused" },
    { 0x1038A, "phoneplayring" },
    { 0x1038B, "phonesfx" },
    { 0x1038C, "phonesringing_code" },
    { 0x1038D, "phonesringing_singlemorse" },
    { 0x1038E, "phsettings" },
    { 0x1038F, "phwhistletimer" },
    { 0x10390, "physicson" },
    { 0x10391, "physicssettled" },
    { 0x10392, "piccadilly_spawnpatchtriggers" },
    { 0x10393, "pick_flagcarrier" },
    { 0x10394, "pick_from_preset_solutions" },
    { 0x10395, "pick_up_data" },
    { 0x10396, "pickclassbr" },
    { 0x10397, "picked_up_weapon" },
    { 0x10398, "pickedpball" },
    { 0x10399, "pickedupcoreminigun" },
    { 0x1039A, "picking_up_minigun" },
    { 0x1039B, "pickprematchrandomloadout" },
    { 0x1039C, "pickrandomspawn" },
    { 0x1039D, "pickrandomvehiclespawn" },
    { 0x1039E, "pickup_gasmask" },
    { 0x1039F, "pickup_saw_and_start_mission" },
    { 0x103A0, "pickup_sound_hvt_handler" },
    { 0x103A1, "pickup_sound_playervm_handler" },
    { 0x103A2, "pickup_sound_playerwm_handler" },
    { 0x103A3, "pickup_timeout" },
    { 0x103A4, "pickup_truck_initdamage" },
    { 0x103A5, "pickup_truck_initomnvars" },
    { 0x103A6, "pickupchecks" },
    { 0x103A7, "pickuptrigger" },
    { 0x103A8, "pilot_anim_loop" },
    { 0x103A9, "pilot_clean_up_monitor" },
    { 0x103AA, "pilot_linkto_angles_offset" },
    { 0x103AB, "pilot_linkto_origin_offset" },
    { 0x103AC, "pilot_model" },
    { 0x103AD, "pilot_setups" },
    { 0x103AE, "pilot_tag" },
    { 0x103AF, "pindia_headlights" },
    { 0x103B0, "pindia_vehicle_registration" },
    { 0x103B1, "ping_response_time" },
    { 0x103B2, "pingedenemies" },
    { 0x103B3, "pingsystemactive" },
    { 0x103B4, "pipe_room_dogtag_revive" },
    { 0x103B5, "pistolslide" },
    { 0x103B6, "pistolweapon" },
    { 0x103B7, "pit_locations" },
    { 0x103B8, "pitch_max_angles" },
    { 0x103B9, "pitcher_lights" },
    { 0x103BA, "pity_timer_end_time" },
    { 0x103BB, "pkg_lbl_vo" },
    { 0x103BC, "place_bad_place_until_flag" },
    { 0x103BD, "place_traversal_badplace" },
    { 0x103BE, "place_weapon" },
    { 0x103BF, "place_weapons_at_pos" },
    { 0x103C0, "placementbonus" },
    { 0x103C1, "placementstatsset" },
    { 0x103C2, "placementupdatewait" },
    { 0x103C3, "placing_c4_interaction_use_monitor" },
    { 0x103C4, "plane" },
    { 0x103C5, "plane_collmap" },
    { 0x103C6, "plane_door_opened" },
    { 0x103C7, "plane_landing_fx" },
    { 0x103C8, "planewaittillcandrop" },
    { 0x103C9, "plant_add_zplanes_override" },
    { 0x103CA, "plant_bomb_cleanup_on_death" },
    { 0x103CB, "plant_enemy_claymore" },
    { 0x103CC, "plant_remove_zplanes_override" },
    { 0x103CD, "plate_dest" },
    { 0x103CE, "plate_index" },
    { 0x103CF, "platform_array" },
    { 0x103D0, "platform_cleanup_on_death" },
    { 0x103D1, "platform_model" },
    { 0x103D2, "play_3p_anim" },
    { 0x103D3, "play_3p_anim_non_animscene" },
    { 0x103D4, "play_ac130_approach_based_on" },
    { 0x103D5, "play_ac130_approach_scene" },
    { 0x103D6, "play_ai_taking_to_convoy_firsttime" },
    { 0x103D7, "play_airport_success_vo" },
    { 0x103D8, "play_airstrike_sequence" },
    { 0x103D9, "play_alarms_onto" },
    { 0x103DA, "play_alert_music_to_player" },
    { 0x103DB, "play_animation" },
    { 0x103DC, "play_animation_old" },
    { 0x103DD, "play_approach_building_two" },
    { 0x103DE, "play_armor_bink" },
    { 0x103DF, "play_authentication_error_window" },
    { 0x103E0, "play_bank_intro_vo" },
    { 0x103E1, "play_battle_chatter_vo" },
    { 0x103E2, "play_bcs" },
    { 0x103E3, "play_breach_anim" },
    { 0x103E4, "play_chopper_kill_vo" },
    { 0x103E5, "play_cinderblock_broken_fx" },
    { 0x103E6, "play_collected_key_vo" },
    { 0x103E7, "play_contract_announcer_maybe" },
    { 0x103E8, "play_counter_beep_sfx_on_bomb_vests" },
    { 0x103E9, "play_death_audio" },
    { 0x103EA, "play_death_sound_with_global_cooldown" },
    { 0x103EB, "play_disguise_vo" },
    { 0x103EC, "play_elevator_anim_when_group_is_spawned" },
    { 0x103ED, "play_ending" },
    { 0x103EE, "play_enemy_overlay_bink" },
    { 0x103EF, "play_exfil_hvt_vo" },
    { 0x103F0, "play_exfil_plane_vo" },
    { 0x103F1, "play_explosion_fx" },
    { 0x103F2, "play_extract_3mins" },
    { 0x103F3, "play_fake_vo_for_gunship" },
    { 0x103F4, "play_found_first_lead_vo" },
    { 0x103F5, "play_found_leads_counting" },
    { 0x103F6, "play_found_leads_counting_building_one" },
    { 0x103F7, "play_found_leads_counting_building_three" },
    { 0x103F8, "play_found_leads_counting_building_two" },
    { 0x103F9, "play_freefall_sequence" },
    { 0x103FA, "play_fulton_evac_on_player" },
    { 0x103FB, "play_gas_sequence" },
    { 0x103FC, "play_get_in_sequence" },
    { 0x103FD, "play_get_in_sequence_for_convoy_vehicle" },
    { 0x103FE, "play_go_to_safehouse" },
    { 0x103FF, "play_hack_reminder_goto1" },
    { 0x10400, "play_hack_reminder_goto2" },
    { 0x10401, "play_hit_marker_to_player" },
    { 0x10402, "play_hud_reminder_vo" },
    { 0x10403, "play_incoming_rpg_vo" },
    { 0x10404, "play_intel_collect_vo" },
    { 0x10405, "play_intro_getin_anim" },
    { 0x10406, "play_intro_hacking_vo" },
    { 0x10407, "play_landlord_infil_vo" },
    { 0x10408, "play_lighting_sequence" },
    { 0x10409, "play_loop_nagging_hostage_on_convoy" },
    { 0x1040A, "play_lz_vo" },
    { 0x1040B, "play_missile_target_marker_vfx_on_missile_target_ent" },
    { 0x1040C, "play_music_on_wave_reinforce" },
    { 0x1040D, "play_music_to_team" },
    { 0x1040E, "play_nag_intro_vo" },
    { 0x1040F, "play_nag_players_hvt_callouts" },
    { 0x10410, "play_nag_players_interact_fulton" },
    { 0x10411, "play_nag_players_place_hvt" },
    { 0x10412, "play_nags_from_array" },
    { 0x10413, "play_nuclear_core_vo" },
    { 0x10414, "play_onboard_plane_vo" },
    { 0x10415, "play_operator_reply_vo" },
    { 0x10416, "play_overlord_howcopy_vo" },
    { 0x10417, "play_patrol_sequence_based_on_first_vehicle" },
    { 0x10418, "play_player_approach" },
    { 0x10419, "play_player_disguise_vo" },
    { 0x1041A, "play_player_falling_anims" },
    { 0x1041B, "play_players_arrive_at_exfil" },
    { 0x1041C, "play_players_arrive_at_extraction" },
    { 0x1041D, "play_players_see_informant_before_aipickup" },
    { 0x1041E, "play_players_take_hvt_firsttime" },
    { 0x1041F, "play_priming_anim" },
    { 0x10420, "play_pullout_sequence" },
    { 0x10421, "play_quarry_intro_vo" },
    { 0x10422, "play_random_sound_event" },
    { 0x10423, "play_reset_priming_anim" },
    { 0x10424, "play_reset_sequences" },
    { 0x10425, "play_rooftop_success_vo" },
    { 0x10426, "play_scramble_for_player_until_cleared" },
    { 0x10427, "play_skit_and_watch_for_endons" },
    { 0x10428, "play_smoke_fx" },
    { 0x10429, "play_smoke_sequence_on_ent_looped" },
    { 0x1042A, "play_smuggler_arriving_vo" },
    { 0x1042B, "play_sound_countdown" },
    { 0x1042C, "play_sound_from_closest_player" },
    { 0x1042D, "play_sound_on_pa_systems" },
    { 0x1042E, "play_sparks_power" },
    { 0x1042F, "play_spotrep_capture_sfx" },
    { 0x10430, "play_station_closed_vo" },
    { 0x10431, "play_stealthy_disguise_vo" },
    { 0x10432, "play_tape_machine_animation" },
    { 0x10433, "play_tape_machine_animations" },
    { 0x10434, "play_thrust_fx" },
    { 0x10435, "play_track_damage_screen_vfx" },
    { 0x10436, "play_train_sequence" },
    { 0x10437, "play_train_speaker_vo" },
    { 0x10438, "play_train_speaker_vo_internal" },
    { 0x10439, "play_travel_vo" },
    { 0x1043A, "play_trialympic_flames" },
    { 0x1043B, "play_usb_anims" },
    { 0x1043C, "play_usb_anims_single" },
    { 0x1043D, "play_usb_pickup_gesture" },
    { 0x1043E, "play_vo_internal" },
    { 0x1043F, "play_vo_on_intel_pickup" },
    { 0x10440, "play_vo_or_timeout" },
    { 0x10441, "playac130animinternal" },
    { 0x10442, "playanim_aibegindismountturret" },
    { 0x10443, "playanim_aidismountturret" },
    { 0x10444, "playanim_aioperateturret" },
    { 0x10445, "playanim_mountturret" },
    { 0x10446, "playanim_vehicleturret" },
    { 0x10447, "playanim_vehicleturret_terminate" },
    { 0x10448, "playanimation" },
    { 0x10449, "playanimwithdooropen" },
    { 0x1044A, "playapache_dialogue" },
    { 0x1044B, "playapacheonly_dialogue" },
    { 0x1044C, "playbattlechattersound" },
    { 0x1044D, "playbattlechattersoundexpensive" },
    { 0x1044E, "playbattlechattersoundsplitscreen" },
    { 0x1044F, "playboxuseanimation" },
    { 0x10450, "playcrateimpactfx" },
    { 0x10451, "playdeathanim_groundturret" },
    { 0x10452, "playdeathsoundph" },
    { 0x10453, "played_fulton_crate_anim" },
    { 0x10454, "playedheliintrovo" },
    { 0x10455, "playedinfilmusic" },
    { 0x10456, "playedonesplash" },
    { 0x10457, "player_abilities_disable" },
    { 0x10458, "player_abilities_enable" },
    { 0x10459, "player_already_has_overwatch_gunship" },
    { 0x1045A, "player_ammo_crate_hint_watcher" },
    { 0x1045B, "player_ammo_think" },
    { 0x1045C, "player_at_power_max_ammo" },
    { 0x1045D, "player_broadcast" },
    { 0x1045E, "player_cam_disable" },
    { 0x1045F, "player_can_mount" },
    { 0x10460, "player_can_use_munitions" },
    { 0x10461, "player_carrying_rpg" },
    { 0x10462, "player_choppergunnericon" },
    { 0x10463, "player_closes_in" },
    { 0x10464, "player_complete_trial" },
    { 0x10465, "player_completed" },
    { 0x10466, "player_connect_fade_in_logic" },
    { 0x10467, "player_controls_failsafe" },
    { 0x10468, "player_current_primary_is_rpg" },
    { 0x10469, "player_damage_blood" },
    { 0x1046A, "player_death" },
    { 0x1046B, "player_deposited_heli" },
    { 0x1046C, "player_disable_invulnerability" },
    { 0x1046D, "player_enable_invulnerability" },
    { 0x1046E, "player_enemy" },
    { 0x1046F, "player_enemy_cooldown" },
    { 0x10470, "player_equip_primary" },
    { 0x10471, "player_equip_regen" },
    { 0x10472, "player_equip_secondary" },
    { 0x10473, "player_equipment_init" },
    { 0x10474, "player_equipment_use_stop" },
    { 0x10475, "player_exfil_struct" },
    { 0x10476, "player_exit" },
    { 0x10477, "player_exposed_to_chopper_boss" },
    { 0x10478, "player_fired_gun" },
    { 0x10479, "player_fired_gun_monitor" },
    { 0x1047A, "player_fov_default_1" },
    { 0x1047B, "player_fulton_evac_rumble" },
    { 0x1047C, "player_gassed_effects" },
    { 0x1047D, "player_get_carepackage_precision_airstrike" },
    { 0x1047E, "player_get_carepackage_sentry" },
    { 0x1047F, "player_get_primary_weapon_object" },
    { 0x10480, "player_get_secondary_weapon_object" },
    { 0x10481, "player_get_sniper_weapon_object" },
    { 0x10482, "player_give_chopper" },
    { 0x10483, "player_give_infinite_rocks" },
    { 0x10484, "player_give_intel_1_ks" },
    { 0x10485, "player_give_intel_2_ks" },
    { 0x10486, "player_give_intel_3_ks" },
    { 0x10487, "player_give_killstreak" },
    { 0x10488, "player_give_loadout" },
    { 0x10489, "player_grenade_fire_monitor" },
    { 0x1048A, "player_gun_game_next_weapon_think" },
    { 0x1048B, "player_gun_game_randomize_weapon_list_think" },
    { 0x1048C, "player_has_ammo_crate" },
    { 0x1048D, "player_has_grenade_crate" },
    { 0x1048E, "player_has_minigun" },
    { 0x1048F, "player_has_nvg" },
    { 0x10490, "player_has_primary_weapons_max_ammo" },
    { 0x10491, "player_has_primary_weapons_max_stock_ammo" },
    { 0x10492, "player_has_respawn_munition" },
    { 0x10493, "player_helis" },
    { 0x10494, "player_ignore_mover" },
    { 0x10495, "player_in_bush_monitor" },
    { 0x10496, "player_in_heli" },
    { 0x10497, "player_in_spawn_area" },
    { 0x10498, "player_infil_already_played" },
    { 0x10499, "player_infil_landlord" },
    { 0x1049A, "player_infil_lbravo" },
    { 0x1049B, "player_infil_played_or_skipped" },
    { 0x1049C, "player_is_at_buy_station" },
    { 0x1049D, "player_is_exposed" },
    { 0x1049E, "player_is_faux_dead" },
    { 0x1049F, "player_is_just_guessing" },
    { 0x104A0, "player_is_pressing_attack" },
    { 0x104A1, "player_is_trying_self_revive" },
    { 0x104A2, "player_isshooting" },
    { 0x104A3, "player_isusingtacmap" },
    { 0x104A4, "player_latespawn_safehouse" },
    { 0x104A5, "player_limitedammo" },
    { 0x104A6, "player_looking" },
    { 0x104A7, "player_max_exposure_time" },
    { 0x104A8, "player_maxhealth" },
    { 0x104A9, "player_move" },
    { 0x104AA, "player_munition_slots_full" },
    { 0x104AB, "player_name_who_broke_stealth" },
    { 0x104AC, "player_near_obit" },
    { 0x104AD, "player_on_helipad" },
    { 0x104AE, "player_on_right_side_of_subway_car" },
    { 0x104AF, "player_onspawn" },
    { 0x104B0, "player_origin_inside_front_zone" },
    { 0x104B1, "player_origin_inside_subway_car" },
    { 0x104B2, "player_parachute_watcher" },
    { 0x104B3, "player_pined_danger_feedback" },
    { 0x104B4, "player_pinged_armor_feedback" },
    { 0x104B5, "player_pushing_vehicle_monitor" },
    { 0x104B6, "player_reenable_collect_leads" },
    { 0x104B7, "player_respawn" },
    { 0x104B8, "player_respawn_struct" },
    { 0x104B9, "player_retry_thread" },
    { 0x104BA, "player_rig_create" },
    { 0x104BB, "player_rigs" },
    { 0x104BC, "player_sees_hvt_leaving_vo" },
    { 0x104BD, "player_sees_hvt_vo" },
    { 0x104BE, "player_set_weapon" },
    { 0x104BF, "player_setsunshadowsforzoom" },
    { 0x104C0, "player_spawn" },
    { 0x104C1, "player_standing_in_doorway" },
    { 0x104C2, "player_standing_on_train" },
    { 0x104C3, "player_tanks_spawned" },
    { 0x104C4, "player_test_ending_teleport" },
    { 0x104C5, "player_too_far" },
    { 0x104C6, "player_trigger_monitor" },
    { 0x104C7, "player_unresolved_collision_suspend" },
    { 0x104C8, "player_used_munition" },
    { 0x104C9, "player_using_rifle" },
    { 0x104CA, "player_vindia_spawn_monitor" },
    { 0x104CB, "player_vo_confirm_pickup" },
    { 0x104CC, "player_waitforlanded" },
    { 0x104CD, "player_waitfortacmapused" },
    { 0x104CE, "player_waittilljumpedfromc130" },
    { 0x104CF, "player_weapon_fired_monitor" },
    { 0x104D0, "player_xp" },
    { 0x104D1, "playerapplyjumpvelocity" },
    { 0x104D2, "playerattractiontriggerenter" },
    { 0x104D3, "playerattractiontriggerexit" },
    { 0x104D4, "playerbloodrestricted" },
    { 0x104D5, "playerbrsquadleaderscore" },
    { 0x104D6, "playercanbuyrespawn" },
    { 0x104D7, "playercanplaynotcriticalgesture" },
    { 0x104D8, "playercanseedangercircleworld" },
    { 0x104D9, "playercinematiccompletecallback" },
    { 0x104DA, "playercinematicfadein" },
    { 0x104DB, "playercinematicfadeout" },
    { 0x104DC, "playercleanupentondisconnect" },
    { 0x104DD, "playercleanupinfilondisconnect" },
    { 0x104DE, "playercleargulagomnvars" },
    { 0x104DF, "playerclearjailtimeouthud" },
    { 0x104E0, "playerclearspectatekillchainsystem" },
    { 0x104E1, "playerclearstreamhintorigin" },
    { 0x104E2, "playerconnectwatcher" },
    { 0x104E3, "playercreatehudelement" },
    { 0x104E4, "playerdatafield" },
    { 0x104E5, "playerdelaydisablezombie" },
    { 0x104E6, "playerenemypool" },
    { 0x104E7, "playerent" },
    { 0x104E8, "playerentercombatarea" },
    { 0x104E9, "playerentercombatareamessage" },
    { 0x104EA, "playerentersafearea" },
    { 0x104EB, "playerentersafeareamessage" },
    { 0x104EC, "playerexecutionsdisable" },
    { 0x104ED, "playerexecutionsenable" },
    { 0x104EE, "playerexitcombatarea" },
    { 0x104EF, "playerexitcombatareamessage" },
    { 0x104F0, "playerexitlaststand" },
    { 0x104F1, "playerexitsafearea" },
    { 0x104F2, "playerexitsafeareamessage" },
    { 0x104F3, "playerfadeobjdelete" },
    { 0x104F4, "playerfakesplash" },
    { 0x104F5, "playerforcespawn" },
    { 0x104F6, "playerforcespectatorclientwait" },
    { 0x104F7, "playerfriendlyto" },
    { 0x104F8, "playergetbestdropbagorigin" },
    { 0x104F9, "playergetbestrespawnmissionorigin" },
    { 0x104FA, "playergetbestrespawnteammate" },
    { 0x104FB, "playergetlaststandpistol" },
    { 0x104FC, "playergetplunderomnvarbitpackinginfo" },
    { 0x104FD, "playergetspawnpoint" },
    { 0x104FE, "playergetspectatingplayer" },
    { 0x104FF, "playergettotaltime" },
    { 0x10500, "playergetzombiespawnlocation" },
    { 0x10501, "playergoingintols" },
    { 0x10502, "playergulagautowinwait" },
    { 0x10503, "playergulaggetrespawnpoint" },
    { 0x10504, "playergulagvictorysetcontrols" },
    { 0x10505, "playerhandlecirclepickitem" },
    { 0x10506, "playerhandleredeploy" },
    { 0x10507, "playerhandlesandboxmenu" },
    { 0x10508, "playerhandlesponsor" },
    { 0x10509, "playerhastknife" },
    { 0x1050A, "playerhastrock" },
    { 0x1050B, "playerhealthomnvarwatcher" },
    { 0x1050C, "playerhudattractionobj" },
    { 0x1050D, "playerhudupdatenumconsumed" },
    { 0x1050E, "playerhumanconcusspush" },
    { 0x1050F, "playerhumanconcusspushcleanup" },
    { 0x10510, "playerhumanconcusspushplayer" },
    { 0x10511, "playerhumanhitground" },
    { 0x10512, "playerhumanpowers" },
    { 0x10513, "playerhumanprestream" },
    { 0x10514, "playerhunterpostloadout" },
    { 0x10515, "playericonfilter" },
    { 0x10516, "playericontriggerenter" },
    { 0x10517, "playericontriggerexit" },
    { 0x10518, "playerincrementscoreboardkills" },
    { 0x10519, "playerinitpersstats" },
    { 0x1051A, "playerinlaststandhold" },
    { 0x1051B, "playerisbecomingzombie" },
    { 0x1051C, "playeriscinematicblacklayeron" },
    { 0x1051D, "playeriscinematiclayeron" },
    { 0x1051E, "playerismatchedplayerready" },
    { 0x1051F, "playerismatchpending" },
    { 0x10520, "playerisprop" },
    { 0x10521, "playerisstreaming" },
    { 0x10522, "playeriszombie" },
    { 0x10523, "playerjailtimeout" },
    { 0x10524, "playerjailwaitvo" },
    { 0x10525, "playerkilled_washitbyvehicle" },
    { 0x10526, "playerkilledspawn" },
    { 0x10527, "playerkillstreakgetownerlookatignoreents" },
    { 0x10528, "playerlocationselectinterrupt" },
    { 0x10529, "playerlocationtriggerenter" },
    { 0x1052A, "playerlocationtriggerexit" },
    { 0x1052B, "playerlootleadervalidity" },
    { 0x1052C, "playermaxheath" },
    { 0x1052D, "playermonitorspectatorcycle" },
    { 0x1052E, "playernakeddroploadout" },
    { 0x1052F, "playernumlivesvo" },
    { 0x10530, "playerorigin" },
    { 0x10531, "playerpackdataintogulagomnvar" },
    { 0x10532, "playerpackdataintoomnvar" },
    { 0x10533, "playerparachutedetachresetomnvars" },
    { 0x10534, "playerplaydepositanim" },
    { 0x10535, "playerplaygestureweaponanim" },
    { 0x10536, "playerplayintrocinematic" },
    { 0x10537, "playerplunderbank" },
    { 0x10538, "playerplunderbankcallback" },
    { 0x10539, "playerplunderbankdeposit" },
    { 0x1053A, "playerplunderbankdepositcallback" },
    { 0x1053B, "playerplunderdeposit" },
    { 0x1053C, "playerplunderdepositcallback" },
    { 0x1053D, "playerplunderdrop" },
    { 0x1053E, "playerplunderevent" },
    { 0x1053F, "playerplundereventcallbacks" },
    { 0x10540, "playerplundereventomnvars" },
    { 0x10541, "playerplunderkioskpurchase" },
    { 0x10542, "playerplunderlose" },
    { 0x10543, "playerplunderlosecallback" },
    { 0x10544, "playerplunderlosedeposit" },
    { 0x10545, "playerplunderlosedepositcallback" },
    { 0x10546, "playerplunderpickup" },
    { 0x10547, "playerplunderpickupcallback" },
    { 0x10548, "playerpositivereinforcement" },
    { 0x10549, "playerpostsetplunder" },
    { 0x1054A, "playerpowerresetpowers" },
    { 0x1054B, "playerpowerrestartallcooldowns" },
    { 0x1054C, "playerpowersaddhudelem" },
    { 0x1054D, "playerpowerscleanup" },
    { 0x1054E, "playerpowerscleanuphud" },
    { 0x1054F, "playerpowerscleanupkeybindings" },
    { 0x10550, "playerpowerscleanuppowers" },
    { 0x10551, "playerpowershud" },
    { 0x10552, "playerpowersmonitorinput" },
    { 0x10553, "playerpowerssetupkeybindings" },
    { 0x10554, "playerpowerstartcooldown" },
    { 0x10555, "playerpowersupdateongamepadchange" },
    { 0x10556, "playerpowerswaittillinputreturn" },
    { 0x10557, "playerpreloadintrocinematic" },
    { 0x10558, "playerprespawngulagjail" },
    { 0x10559, "playerprestreamrespawnorigin" },
    { 0x1055A, "playerpulloutofgulagwin" },
    { 0x1055B, "playerpurchaselogic" },
    { 0x1055C, "playerpurchasenags" },
    { 0x1055D, "playerreadytospawn" },
    { 0x1055E, "playerredeploy" },
    { 0x1055F, "playerregendelayspeed" },
    { 0x10560, "playerregenhealthadd" },
    { 0x10561, "playerrespawncleanup" },
    { 0x10562, "players_approach_puzzle_monitor" },
    { 0x10563, "players_camera_fly_to_start_pos" },
    { 0x10564, "players_grenade_fire_monitor" },
    { 0x10565, "players_in_aggro" },
    { 0x10566, "players_in_correct_volume" },
    { 0x10567, "players_in_laststand" },
    { 0x10568, "players_inside" },
    { 0x10569, "players_monitor" },
    { 0x1056A, "players_not_in_laststand" },
    { 0x1056B, "players_recent_position_delay" },
    { 0x1056C, "players_weapon_fired_monitor" },
    { 0x1056D, "playerscoreeventref" },
    { 0x1056E, "playerscoreeventvalue" },
    { 0x1056F, "playersetarenaomnvarwithloadout" },
    { 0x10570, "playersetattractionbestplayer" },
    { 0x10571, "playersetattractionbesttime" },
    { 0x10572, "playersetattractionextradata" },
    { 0x10573, "playersetattractionlocationindex" },
    { 0x10574, "playersetattractionoff" },
    { 0x10575, "playersetattractionstateindex" },
    { 0x10576, "playersetattractiontime" },
    { 0x10577, "playersetattractiontype" },
    { 0x10578, "playersetcontrols" },
    { 0x10579, "playersetgulagdataomnvar" },
    { 0x1057A, "playersetignoreattractions" },
    { 0x1057B, "playersetisbecomingzombie" },
    { 0x1057C, "playersetispropgameextrainfo" },
    { 0x1057D, "playersetiszombie" },
    { 0x1057E, "playersetiszombieextrainfo" },
    { 0x1057F, "playersetkeypadcodelengthindex" },
    { 0x10580, "playersetkeypadstateindex" },
    { 0x10581, "playersetomnvarattraction" },
    { 0x10582, "playersetomnvargulag" },
    { 0x10583, "playersetomnvarkeypad" },
    { 0x10584, "playersetplunderomnvar" },
    { 0x10585, "playersetwasingulag" },
    { 0x10586, "playershooting" },
    { 0x10587, "playershouldrespawn" },
    { 0x10588, "playershowarenastartobjectivetext" },
    { 0x10589, "playershowskippromptcinematic" },
    { 0x1058A, "playerskipkioskuse" },
    { 0x1058B, "playerskiplootpickup" },
    { 0x1058C, "playersleftloop" },
    { 0x1058D, "playerspawn" },
    { 0x1058E, "playerspawndata" },
    { 0x1058F, "playerspawnendofgame" },
    { 0x10590, "playerspawnexfilchopper" },
    { 0x10591, "playerspawningasspectator" },
    { 0x10592, "playerspawnintermissionifneeded" },
    { 0x10593, "playersplash" },
    { 0x10594, "playerstartarenasetcontrols" },
    { 0x10595, "playerstartbesttimetracking" },
    { 0x10596, "playerstartbesttimeupdate" },
    { 0x10597, "playerstartjailsetcontrols" },
    { 0x10598, "playerstartpowers" },
    { 0x10599, "playerstartrecondronewait" },
    { 0x1059A, "playerstarttimetracking" },
    { 0x1059B, "playerstoptimerdelete" },
    { 0x1059C, "playerstreamhintdroptoground" },
    { 0x1059D, "playerstreamhintlocation" },
    { 0x1059E, "playerstreamhintlocationinternal" },
    { 0x1059F, "playerstreamwaittillcomplete" },
    { 0x105A0, "playersusing" },
    { 0x105A1, "playerswapteam" },
    { 0x105A2, "playerswithoutdismemberment" },
    { 0x105A3, "playertakeextractionplunder" },
    { 0x105A4, "playerteleportgulag" },
    { 0x105A5, "playerteleportprop" },
    { 0x105A6, "playerteleporttoloc" },
    { 0x105A7, "playerthrowsmokesignal" },
    { 0x105A8, "playertimedinvunerable" },
    { 0x105A9, "playertimestamp" },
    { 0x105AA, "playertimestart" },
    { 0x105AB, "playertospectate" },
    { 0x105AC, "playertouching" },
    { 0x105AD, "playertracking" },
    { 0x105AE, "playertryzombiespawn" },
    { 0x105AF, "playerumpedfromplane" },
    { 0x105B0, "playerunpackdatafromomnvar" },
    { 0x105B1, "playerupdatealivecounthuman" },
    { 0x105B2, "playerupdatebesttimehud" },
    { 0x105B3, "playerupdatehudstate" },
    { 0x105B4, "playerusehealslot" },
    { 0x105B5, "playerusingturret" },
    { 0x105B6, "playervisibilityrespawntags" },
    { 0x105B7, "playerwager" },
    { 0x105B8, "playerwaitforprestreaming" },
    { 0x105B9, "playerwaitilllongholdmelee" },
    { 0x105BA, "playerwaittillcinematiccomplete" },
    { 0x105BB, "playerwaittillspectatecycle" },
    { 0x105BC, "playerwaittillstreamhintcomplete" },
    { 0x105BD, "playerwaittospawn" },
    { 0x105BE, "playerwatchspectate" },
    { 0x105BF, "playerwelcomesplashes" },
    { 0x105C0, "playerwind" },
    { 0x105C1, "playeryaw" },
    { 0x105C2, "playerzombieaddhudelem" },
    { 0x105C3, "playerzombieapplyemp" },
    { 0x105C4, "playerzombiebacktohuman" },
    { 0x105C5, "playerzombiecleanup" },
    { 0x105C6, "playerzombiecleanuphud" },
    { 0x105C7, "playerzombiecleanupkeybindings" },
    { 0x105C8, "playerzombiecleanuppowers" },
    { 0x105C9, "playerzombiedelayturnonfx" },
    { 0x105CA, "playerzombiedestroyhud" },
    { 0x105CB, "playerzombiedovehicledamageimmunity" },
    { 0x105CC, "playerzombiedroploot" },
    { 0x105CD, "playerzombieemp" },
    { 0x105CE, "playerzombieempcleanup" },
    { 0x105CF, "playerzombieentergas" },
    { 0x105D0, "playerzombieexitgas" },
    { 0x105D1, "playerzombiegasthink" },
    { 0x105D2, "playerzombiegetrespawnbyteam" },
    { 0x105D3, "playerzombiehitground" },
    { 0x105D4, "playerzombiehud" },
    { 0x105D5, "playerzombieisingas" },
    { 0x105D6, "playerzombiejump" },
    { 0x105D7, "playerzombiejumpcleanup" },
    { 0x105D8, "playerzombiejumpmaxholdwarning" },
    { 0x105D9, "playerzombiejumpstop" },
    { 0x105DA, "playerzombielaststandrevive" },
    { 0x105DB, "playerzombiemonitorinput" },
    { 0x105DC, "playerzombiepingoutofgas" },
    { 0x105DD, "playerzombiepowers" },
    { 0x105DE, "playerzombiepowerstartcooldown" },
    { 0x105DF, "playerzombieprestream" },
    { 0x105E0, "playerzombierespawn" },
    { 0x105E1, "playerzombiesetradar" },
    { 0x105E2, "playerzombiesetuphud" },
    { 0x105E3, "playerzombiesetupkeybindings" },
    { 0x105E4, "playerzombiestatechange" },
    { 0x105E5, "playerzombiestreamwaittillcomplete" },
    { 0x105E6, "playerzombiesupersprint" },
    { 0x105E7, "playerzombiethermal" },
    { 0x105E8, "playerzombiethermalcleanup" },
    { 0x105E9, "playerzombiethermalupdate" },
    { 0x105EA, "playerzombieupdateongamepadchange" },
    { 0x105EB, "playerzombieupdatetagobjectives" },
    { 0x105EC, "playerzombievehiclehittoss" },
    { 0x105ED, "playerzombiewaittillinputreturn" },
    { 0x105EE, "playgotinfectedsoundcount" },
    { 0x105EF, "playimpactfx" },
    { 0x105F0, "playing_bomb_counter_beep" },
    { 0x105F1, "playing_stealth_alert_music" },
    { 0x105F2, "playingcoughdamagesound" },
    { 0x105F3, "playinggulagbink" },
    { 0x105F4, "playingmolotovwickfx" },
    { 0x105F5, "playingsound" },
    { 0x105F6, "playingthrowingknifewickfx" },
    { 0x105F7, "playingtutorialdialogue" },
    { 0x105F8, "playjailbreakvo" },
    { 0x105F9, "playjumpsoundtosquad" },
    { 0x105FA, "playkillstreakdeploydialog" },
    { 0x105FB, "playlandingbreath" },
    { 0x105FC, "playlinkfx" },
    { 0x105FD, "playmatchendcamera" },
    { 0x105FE, "playoverwatch_dialogue" },
    { 0x105FF, "playoverwatch_dialogue_with_endon" },
    { 0x10600, "playplundersound" },
    { 0x10601, "playplundersoundbyamount" },
    { 0x10602, "playscorestatusdialog" },
    { 0x10603, "playslamzoomflashcolor" },
    { 0x10604, "playtutsound" },
    { 0x10605, "playvointernal" },
    { 0x10606, "plunder_addanchoredwidgettorepositoryinstance" },
    { 0x10607, "plunder_allowallrepositoryuseforplayer" },
    { 0x10608, "plunder_allowrepositoryuse" },
    { 0x10609, "plunder_allowrepositoryuseforplayer" },
    { 0x1060A, "plunder_awarded_by_missions_total" },
    { 0x1060B, "plunder_clearrepositorywidgetforplayer" },
    { 0x1060C, "plunder_deregisterrepositoryinstance" },
    { 0x1060D, "plunder_economy_shapshot_loop" },
    { 0x1060E, "plunder_endgame_music" },
    { 0x1060F, "plunder_extraction_site_active" },
    { 0x10610, "plunder_fiftypercent_music" },
    { 0x10611, "plunder_getleveldataforrepository" },
    { 0x10612, "plunder_infils_ready" },
    { 0x10613, "plunder_initrepositories" },
    { 0x10614, "plunder_items_dropped" },
    { 0x10615, "plunder_items_picked_up" },
    { 0x10616, "plunder_ninetypercent_music" },
    { 0x10617, "plunder_overtime_music" },
    { 0x10618, "plunder_playercanuserepository" },
    { 0x10619, "plunder_playerrepositoryuseshouldsucceed" },
    { 0x1061A, "plunder_playerspawnedcallback" },
    { 0x1061B, "plunder_registerrepositoryinstance" },
    { 0x1061C, "plunder_removeanchoredwidgetfromrepositoryinstance" },
    { 0x1061D, "plunder_repositoryatcapacity" },
    { 0x1061E, "plunder_repositoryclearcountdown" },
    { 0x1061F, "plunder_repositoryenableuserestrictions" },
    { 0x10620, "plunder_repositoryendcountdown" },
    { 0x10621, "plunder_repositoryextract" },
    { 0x10622, "plunder_repositoryinstanceisregistered" },
    { 0x10623, "plunder_repositoryplayerplundereventcallback" },
    { 0x10624, "plunder_repositorysendcountdownmessage" },
    { 0x10625, "plunder_repositoryusecallback" },
    { 0x10626, "plunder_repositoryusecallbackinternal" },
    { 0x10627, "plunder_repositoryusescriptablecallback" },
    { 0x10628, "plunder_repositorywatchcountdown" },
    { 0x10629, "plunder_repositorywatchuse" },
    { 0x1062A, "plunder_sendrepositorywidgetomnvar" },
    { 0x1062B, "plunder_seventyfivepercent_music" },
    { 0x1062C, "plunder_tenpercent_music" },
    { 0x1062D, "plunder_thirtypercent_music" },
    { 0x1062E, "plunder_updateanchoredwidgetforplayers" },
    { 0x1062F, "plunder_updaterepositorywidgetforplayer" },
    { 0x10630, "plunder_value_dropped" },
    { 0x10631, "plunder_value_picked_up" },
    { 0x10632, "plunderatcapacity" },
    { 0x10633, "plundercountdownendtime" },
    { 0x10634, "plundercountdownmessagedata" },
    { 0x10635, "plundercountdownplayers" },
    { 0x10636, "plundercountdownupdatetime" },
    { 0x10637, "plundercountroll" },
    { 0x10638, "plunderdelta" },
    { 0x10639, "plundereventamount" },
    { 0x1063A, "plundereventtime" },
    { 0x1063B, "plundereventtotal" },
    { 0x1063C, "plunderextractalertnearby" },
    { 0x1063D, "plunderforextract" },
    { 0x1063E, "plunderfxondropthreashold" },
    { 0x1063F, "plunderinstanceid" },
    { 0x10640, "plunderlimit" },
    { 0x10641, "plundermusicfirst" },
    { 0x10642, "plundermusicfourth" },
    { 0x10643, "plundermusicsecond" },
    { 0x10644, "plundermusicthird" },
    { 0x10645, "plunderonfirstpickup" },
    { 0x10646, "plunderpads" },
    { 0x10647, "plunderrankupdate" },
    { 0x10648, "plunderrepositories" },
    { 0x10649, "plunderrepositoryref" },
    { 0x1064A, "plunderrepositoryrestricted" },
    { 0x1064B, "plunderrepositorywidget" },
    { 0x1064C, "plundersilentcountdownendtime" },
    { 0x1064D, "plundersoundamount" },
    { 0x1064E, "plunderstructreplenish" },
    { 0x1064F, "plundertimer" },
    { 0x10650, "plundertotal" },
    { 0x10651, "plundertutstarttime" },
    { 0x10652, "plunderupdatelootleadermarks" },
    { 0x10653, "plunderusable" },
    { 0x10654, "plunderusedisabledwhenempty" },
    { 0x10655, "plundervar" },
    { 0x10656, "pointblank_airstrike" },
    { 0x10657, "pointblank_tomahawk" },
    { 0x10658, "pointinsquare" },
    { 0x10659, "pointinsquarewidth" },
    { 0x1065A, "poke_the_player_after_faux_death" },
    { 0x1065B, "polarity" },
    { 0x1065C, "poolids" },
    { 0x1065D, "populate_bomb_wires_to_cut" },
    { 0x1065E, "populateproplist" },
    { 0x1065F, "population" },
    { 0x10660, "portable_radar" },
    { 0x10661, "position_ref" },
    { 0x10662, "positioncheck" },
    { 0x10663, "post_blockade_breadcrumb_struct" },
    { 0x10664, "post_blockade_combat_logic" },
    { 0x10665, "post_customization_func" },
    { 0x10666, "post_get_up_animation_function" },
    { 0x10667, "post_loadout_spawn_func" },
    { 0x10668, "post_race" },
    { 0x10669, "post_safeges_weapon" },
    { 0x1066A, "postgamehitmarkerwaittime" },
    { 0x1066B, "postgamestate" },
    { 0x1066C, "postkillcamplunderlost" },
    { 0x1066D, "postlaunchscenenodecorrection" },
    { 0x1066E, "postplunder" },
    { 0x1066F, "postshipmodifychevrons" },
    { 0x10670, "postspawn_assault3_bombers" },
    { 0x10671, "postspawn_initial_allies" },
    { 0x10672, "postspawn_juggernaut" },
    { 0x10673, "postspawn_rescued_allies" },
    { 0x10674, "postspawn_rpg" },
    { 0x10675, "postspawn_sniper" },
    { 0x10676, "postspawn_trucks" },
    { 0x10677, "postspawn_vindia" },
    { 0x10678, "postupdategameevents" },
    { 0x10679, "pour" },
    { 0x1067A, "power_checkifequipmentammofull" },
    { 0x1067B, "power_wave_mode_reset_playerdata" },
    { 0x1067C, "powered_on_model" },
    { 0x1067D, "poweron_warnings" },
    { 0x1067E, "powerscooldown" },
    { 0x1067F, "powershud" },
    { 0x10680, "ppkflagcarrier" },
    { 0x10681, "ppkteamnoflag" },
    { 0x10682, "ppkteamwithflag" },
    { 0x10683, "pre_defend_filler_bad_guys" },
    { 0x10684, "pre_get_in_anim_wait" },
    { 0x10685, "pre_laserpanel_weapon" },
    { 0x10686, "pre_race" },
    { 0x10687, "pre_race_needs_vehicle" },
    { 0x10688, "precache_hint_strings" },
    { 0x10689, "precacheitems" },
    { 0x1068A, "precomputeddropbagpos" },
    { 0x1068B, "precomputeddropbags" },
    { 0x1068C, "precomputedropbagpositions" },
    { 0x1068D, "predictandclearintermissionstreaming" },
    { 0x1068E, "pregeneratespawnpoints" },
    { 0x1068F, "preinfilstreamfunc" },
    { 0x10690, "prematchdialog" },
    { 0x10691, "prematchendtime" },
    { 0x10692, "prematchinfinitammo" },
    { 0x10693, "prematchinitblueprintloadouts" },
    { 0x10694, "prematchinitloadouts" },
    { 0x10695, "prematchinitx1blueprintloadouts" },
    { 0x10696, "prematchintiallandingcomplete" },
    { 0x10697, "prematchloadoutindex" },
    { 0x10698, "prematchloadouts" },
    { 0x10699, "prematchmusic" },
    { 0x1069A, "prematchplayedwelcomevo" },
    { 0x1069B, "prematchrandomloadout" },
    { 0x1069C, "prematchspawnoriginteamcount" },
    { 0x1069D, "premount_goalradius" },
    { 0x1069E, "prepare_mission_failed_text" },
    { 0x1069F, "prepdoorsforunload" },
    { 0x106A0, "prepickupweapon" },
    { 0x106A1, "prespawnspawn" },
    { 0x106A2, "pressure_overload_threshold" },
    { 0x106A3, "pressure_stability_event_init" },
    { 0x106A4, "pressure_stability_event_start" },
    { 0x106A5, "pressure_timeout" },
    { 0x106A6, "pressure_unstable" },
    { 0x106A7, "prestreaminglocation" },
    { 0x106A8, "prestreamingspectatetarget" },
    { 0x106A9, "pretrograd_interaction_effects" },
    { 0x106AA, "prev_weapon_taccover" },
    { 0x106AB, "prevbrbonusxp" },
    { 0x106AC, "prevcallback" },
    { 0x106AD, "preventleave" },
    { 0x106AE, "preventspawninto" },
    { 0x106AF, "previous_bullet_weapon" },
    { 0x106B0, "previous_spawn_points" },
    { 0x106B1, "previouscarepackagekillstreaks" },
    { 0x106B2, "previousplacements" },
    { 0x106B3, "prewaitandspawnclient" },
    { 0x106B4, "primesneeded" },
    { 0x106B5, "print_punchcard" },
    { 0x106B6, "print_spawner_score_for_factor" },
    { 0x106B7, "printallteamsplundercount" },
    { 0x106B8, "printcodechosen" },
    { 0x106B9, "printcodeentered" },
    { 0x106BA, "printdata" },
    { 0x106BB, "printer" },
    { 0x106BC, "printspawnmessage" },
    { 0x106BD, "pristinestatehealthadd" },
    { 0x106BE, "process_anim_ents" },
    { 0x106BF, "process_elevator_request" },
    { 0x106C0, "process_entities_inside_subway_car" },
    { 0x106C1, "process_events_and_challenges_on_death" },
    { 0x106C2, "process_minigun_nodes" },
    { 0x106C3, "process_players_inside_subway_car" },
    { 0x106C4, "process_should_do_pain" },
    { 0x106C5, "process_struct_angle_tilt" },
    { 0x106C6, "process_struct_path_tilts" },
    { 0x106C7, "processassist_regularcp" },
    { 0x106C8, "processcashpileovertimemultiplier" },
    { 0x106C9, "processcashpilevalueoverrides" },
    { 0x106CA, "processcommonplayerdataforplayer" },
    { 0x106CB, "processed_tilt" },
    { 0x106CC, "processedscoreevent" },
    { 0x106CD, "processedsplash" },
    { 0x106CE, "processlobbydataforclient" },
    { 0x106CF, "processmatchscoreboardinfo" },
    { 0x106D0, "processscrapassist" },
    { 0x106D1, "processsplashpriorityqueue" },
    { 0x106D2, "processuniquelootitem" },
    { 0x106D3, "processvoqueue" },
    { 0x106D4, "proggressionmismatchpopup" },
    { 0x106D5, "progress_obj" },
    { 0x106D6, "progression_deadzone" },
    { 0x106D7, "progression_main" },
    { 0x106D8, "progression_speed" },
    { 0x106D9, "progression_update" },
    { 0x106DA, "prohibited_weapon_list" },
    { 0x106DB, "prohibited_weapon_list_from_vehicle" },
    { 0x106DC, "projdistsq" },
    { 0x106DD, "project" },
    { 0x106DE, "project_to_line" },
    { 0x106DF, "project_to_line_seg" },
    { 0x106E0, "projectiledeleteonnote" },
    { 0x106E1, "projectiledeletethread" },
    { 0x106E2, "projectileimpactexplode" },
    { 0x106E3, "projectileimpactthermite" },
    { 0x106E4, "projectileunlink" },
    { 0x106E5, "projectileunlinkonnote" },
    { 0x106E6, "projectilewaittilstucktimeout" },
    { 0x106E7, "prompt" },
    { 0x106E8, "propability" },
    { 0x106E9, "propabilitykeysvisible" },
    { 0x106EA, "propaddtocircle" },
    { 0x106EB, "propaddtolocation" },
    { 0x106EC, "propanchor" },
    { 0x106ED, "propane_detonate_fiery_drips" },
    { 0x106EE, "propcamerazoom" },
    { 0x106EF, "propchange" },
    { 0x106F0, "propchangecount" },
    { 0x106F1, "propchangeto" },
    { 0x106F2, "propcircleindex" },
    { 0x106F3, "propcircles" },
    { 0x106F4, "propcleanup" },
    { 0x106F5, "propcleanupdelayed" },
    { 0x106F6, "propclonecleanup" },
    { 0x106F7, "propclonepower" },
    { 0x106F8, "propclones" },
    { 0x106F9, "propcontrolshud" },
    { 0x106FA, "propdeathfx" },
    { 0x106FB, "propdeductchange" },
    { 0x106FC, "propdeductclonechange" },
    { 0x106FD, "propdeductflash" },
    { 0x106FE, "propent" },
    { 0x106FF, "proper_damage" },
    { 0x10700, "propgetlocation" },
    { 0x10701, "propgiveteamscore" },
    { 0x10702, "prophaschangesleft" },
    { 0x10703, "prophasclonesleft" },
    { 0x10704, "prophasflashesleft" },
    { 0x10705, "propheight" },
    { 0x10706, "prophidetime" },
    { 0x10707, "propindex" },
    { 0x10708, "propinfo" },
    { 0x10709, "propinputwatch" },
    { 0x1070A, "propkilledend" },
    { 0x1070B, "proplist" },
    { 0x1070C, "proplocationindex" },
    { 0x1070D, "proplockunlock" },
    { 0x1070E, "propmatchslope" },
    { 0x1070F, "propminigamefinish" },
    { 0x10710, "propminigamescore_compare" },
    { 0x10711, "propminigamesetting" },
    { 0x10712, "propminigameupdates" },
    { 0x10713, "propminigameupdateshowloser" },
    { 0x10714, "propminigameupdateshowwinner" },
    { 0x10715, "propminigameupdateui" },
    { 0x10716, "propmoveunlock" },
    { 0x10717, "propnumclones" },
    { 0x10718, "propnumflashes" },
    { 0x10719, "proprange" },
    { 0x1071A, "propremovefromcircle" },
    { 0x1071B, "propremovefromlocation" },
    { 0x1071C, "proprotate" },
    { 0x1071D, "propsetchangesleft" },
    { 0x1071E, "propsetclonesleft" },
    { 0x1071F, "propsetflashesleft" },
    { 0x10720, "propsize" },
    { 0x10721, "propsizetext" },
    { 0x10722, "propspawnorigin" },
    { 0x10723, "propspectate" },
    { 0x10724, "propspectateendwatch" },
    { 0x10725, "propspectatekeys" },
    { 0x10726, "propspectating" },
    { 0x10727, "propspeedscale" },
    { 0x10728, "proptiebreaker" },
    { 0x10729, "propwaitminigamebuttonwatch" },
    { 0x1072A, "propwaitminigamecleanup" },
    { 0x1072B, "propwaitminigamecleanuponplayernotify" },
    { 0x1072C, "propwaitminigamefalltimer" },
    { 0x1072D, "propwaitminigamehudinit" },
    { 0x1072E, "propwaitminigamehudsetpoint" },
    { 0x1072F, "propwaitminigameinit" },
    { 0x10730, "propwaitminigamerun" },
    { 0x10731, "propwatchcleanupondisconnect" },
    { 0x10732, "propwatchcleanuponroundend" },
    { 0x10733, "propwatchdeath" },
    { 0x10734, "propwatchprematchsettings" },
    { 0x10735, "propwhistle" },
    { 0x10736, "propwhistletime" },
    { 0x10737, "protect_jammer" },
    { 0x10738, "protect_obj_a" },
    { 0x10739, "protect_obj_a_internal" },
    { 0x1073A, "proximity_explode" },
    { 0x1073B, "proxtrigger" },
    { 0x1073C, "proxy_include" },
    { 0x1073D, "proxy_trigger" },
    { 0x1073E, "publiceventsenabled" },
    { 0x1073F, "publiceventsmanager" },
    { 0x10740, "puddle_activated" },
    { 0x10741, "puddle_fx" },
    { 0x10742, "puddle_structs" },
    { 0x10743, "puddle_triggers" },
    { 0x10744, "puhostagerestoreweapon" },
    { 0x10745, "pulsing" },
    { 0x10746, "punchcard_use_think" },
    { 0x10747, "punishwavechaseplayers" },
    { 0x10748, "purchase_balloon_nags" },
    { 0x10749, "pursue_players_after_awhile" },
    { 0x1074A, "push_player_clear_of_door_way" },
    { 0x1074B, "push_player_down" },
    { 0x1074C, "push_players_back_and_deal_damage" },
    { 0x1074D, "pushdistributiontowardoppositecorner" },
    { 0x1074E, "pushpointoutofkothattractions" },
    { 0x1074F, "put_headicon_on_tv_station_boss" },
    { 0x10750, "put_objective_on_guy" },
    { 0x10751, "put_passenger_in_truck" },
    { 0x10752, "put_players_out_of_black_screen" },
    { 0x10753, "putinlaststand" },
    { 0x10754, "puzzle_mark_complete" },
    { 0x10755, "qm_intro_dialogue" },
    { 0x10756, "quadgridcenterpoints" },
    { 0x10757, "quadgridradius2dsq" },
    { 0x10758, "quadpoints" },
    { 0x10759, "quantity" },
    { 0x1075A, "quarry2_ambient_sound_load" },
    { 0x1075B, "quarry_brendgame" },
    { 0x1075C, "quarry_fight_across" },
    { 0x1075D, "quarry_fight_across_internal" },
    { 0x1075E, "quarry_hacks_count" },
    { 0x1075F, "quarry_intro1_chopper" },
    { 0x10760, "quarry_intro2_chopper" },
    { 0x10761, "quarry_mortar_guys" },
    { 0x10762, "quarry_mortar_guys_internal" },
    { 0x10763, "quarry_mortars" },
    { 0x10764, "quarry_train_model" },
    { 0x10765, "quarry_wave_spawn_scoring" },
    { 0x10766, "quest_assdistmax" },
    { 0x10767, "quest_assdistmin" },
    { 0x10768, "quest_domdistmax" },
    { 0x10769, "quest_domdistmin" },
    { 0x1076A, "quest_scavdistmax" },
    { 0x1076B, "quest_scavdistmin" },
    { 0x1076C, "quest_secretdistmax" },
    { 0x1076D, "quest_secretdistmin" },
    { 0x1076E, "questbasetimer" },
    { 0x1076F, "questbonustimer" },
    { 0x10770, "questcomplete" },
    { 0x10771, "questenabled" },
    { 0x10772, "questinstance" },
    { 0x10773, "questpointgetradius" },
    { 0x10774, "questrewardcirclepeek" },
    { 0x10775, "questrewarddropitems" },
    { 0x10776, "questrewardgroupexist" },
    { 0x10777, "questrewarduav" },
    { 0x10778, "questtimeradd" },
    { 0x10779, "questtimerinit" },
    { 0x1077A, "questtimerset" },
    { 0x1077B, "questtimerupdate" },
    { 0x1077C, "questtypes" },
    { 0x1077D, "queue_spawn" },
    { 0x1077E, "queued_up_to_respawn" },
    { 0x1077F, "quickdropaddtocache" },
    { 0x10780, "quickdropaddtoexisting" },
    { 0x10781, "quickdropall" },
    { 0x10782, "quickdropcache" },
    { 0x10783, "quickdropcachefindslot" },
    { 0x10784, "quickdropcachematchesplayer" },
    { 0x10785, "quickdropcleanupcache" },
    { 0x10786, "quickdropfinditemincache" },
    { 0x10787, "quickdropgetscriptableforcount" },
    { 0x10788, "quickdropitem" },
    { 0x10789, "quickdropnewitem" },
    { 0x1078A, "quickdropplaysound" },
    { 0x1078B, "quickdropremoveammofrominventory" },
    { 0x1078C, "quickdropremovearmorfrominventory" },
    { 0x1078D, "quickdropremovefrominventory" },
    { 0x1078E, "quickdropremoveplunderfrominventory" },
    { 0x1078F, "quickdropremoverespawntokenfrominventory" },
    { 0x10790, "quickdropremoveselfrevivetokenfrominventory" },
    { 0x10791, "quickdropremoveweaponfrominventory" },
    { 0x10792, "quit_game_in" },
    { 0x10793, "race" },
    { 0x10794, "race_calculate_stars" },
    { 0x10795, "race_countdown_update" },
    { 0x10796, "race_dogtag_init" },
    { 0x10797, "race_ent" },
    { 0x10798, "race_flow" },
    { 0x10799, "race_get_current_checkpoint" },
    { 0x1079A, "race_get_next_checkpoint" },
    { 0x1079B, "race_init" },
    { 0x1079C, "race_is_player_driving_vehicle" },
    { 0x1079D, "race_monitor_oob" },
    { 0x1079E, "race_monitor_out_of_vehicle" },
    { 0x1079F, "race_monitor_vehicle" },
    { 0x107A0, "race_requires_vehicle" },
    { 0x107A1, "race_set_checkpoint" },
    { 0x107A2, "race_set_next_checkpoint" },
    { 0x107A3, "race_set_player_safe" },
    { 0x107A4, "race_timer_update" },
    { 0x107A5, "race_ui_add_critical_message" },
    { 0x107A6, "race_ui_checkpoint" },
    { 0x107A7, "race_ui_critical_message_timer" },
    { 0x107A8, "race_ui_critical_message_update" },
    { 0x107A9, "race_ui_lap" },
    { 0x107AA, "race_ui_remove_critical_message" },
    { 0x107AB, "race_ui_show_record" },
    { 0x107AC, "race_ui_show_record_end" },
    { 0x107AD, "race_update_stars" },
    { 0x107AE, "race_wait_for_current_checkpoint" },
    { 0x107AF, "races" },
    { 0x107B0, "radar_sweeps" },
    { 0x107B1, "radialairstrike" },
    { 0x107B2, "radialhintinternal" },
    { 0x107B3, "radialmonitor" },
    { 0x107B4, "radiussq" },
    { 0x107B5, "ragdoll_on_vehicle_death" },
    { 0x107B6, "raid_mindia_unload_func" },
    { 0x107B7, "raid_objective_cleanup_func" },
    { 0x107B8, "raid_player_start_pos_array" },
    { 0x107B9, "raid_seq3_objectives_func" },
    { 0x107BA, "raid_seq4_objectives_func" },
    { 0x107BB, "raid_umike_unload_func" },
    { 0x107BC, "raid_vindia_unload_func" },
    { 0x107BD, "raise_airlock" },
    { 0x107BE, "rallypoint_showafterprematch" },
    { 0x107BF, "randgetpropsizetoallocate" },
    { 0x107C0, "randoexplodo" },
    { 0x107C1, "random_barrel_explosion" },
    { 0x107C2, "random_end" },
    { 0x107C3, "random_loot_override" },
    { 0x107C4, "randomcarepackagedrops" },
    { 0x107C5, "randomcorner" },
    { 0x107C6, "randomize_stealth_alert_music_array" },
    { 0x107C7, "randomize_stealth_broken_music_array" },
    { 0x107C8, "randomize_target" },
    { 0x107C9, "randomize_tv_station_player_start_pos" },
    { 0x107CA, "randomize_wires_on_bombs" },
    { 0x107CB, "randomize_zones" },
    { 0x107CC, "randomized_primary_weapon_index" },
    { 0x107CD, "randomized_primary_weapon_objs" },
    { 0x107CE, "randomly_play_tape_reel_anims" },
    { 0x107CF, "randomoffsetmortar" },
    { 0x107D0, "randomstartindex" },
    { 0x107D1, "range_struct" },
    { 0x107D2, "raritycamera" },
    { 0x107D3, "raritycamlarge" },
    { 0x107D4, "raritycammedium" },
    { 0x107D5, "raritycamsmall" },
    { 0x107D6, "raritycamwatch" },
    { 0x107D7, "ray_trace_trigger_radius_2d" },
    { 0x107D8, "raytraceoffset" },
    { 0x107D9, "re_open_station" },
    { 0x107DA, "reachhistorydestination" },
    { 0x107DB, "reader" },
    { 0x107DC, "reading" },
    { 0x107DD, "readytoleave" },
    { 0x107DE, "reaper_missile_reload_end_time" },
    { 0x107DF, "reaper_waitformissilereloadfinish" },
    { 0x107E0, "reaper_waitingformissilereload" },
    { 0x107E1, "rear_door_collision" },
    { 0x107E2, "rear_door_collision_brush" },
    { 0x107E3, "rear_minigun" },
    { 0x107E4, "rear_minigun_angles_offset" },
    { 0x107E5, "rear_minigun_attack_max_cooldown" },
    { 0x107E6, "rear_minigun_attack_min_cooldown" },
    { 0x107E7, "rear_minigun_model" },
    { 0x107E8, "rear_minigun_origin_offset" },
    { 0x107E9, "rear_minigun_shots_per_round" },
    { 0x107EA, "rear_minigun_speed" },
    { 0x107EB, "rear_minigun_tag" },
    { 0x107EC, "rear_minigun_track_target_delay" },
    { 0x107ED, "rear_minigun_turret_info" },
    { 0x107EE, "rear_minigun_wait_between_shot_rounds" },
    { 0x107EF, "rear_minigun_wait_between_shots" },
    { 0x107F0, "rear_minigun_warning_time" },
    { 0x107F1, "rear_spawn_type_adjuster" },
    { 0x107F2, "rear_spotlight" },
    { 0x107F3, "rear_spotlight_angles_offset" },
    { 0x107F4, "rear_spotlight_max_dist_sq_from_node" },
    { 0x107F5, "rear_spotlight_min_dist_sq_from_node" },
    { 0x107F6, "rear_spotlight_model" },
    { 0x107F7, "rear_spotlight_origin_offset" },
    { 0x107F8, "rear_spotlight_reach_goal_node_dist_sq" },
    { 0x107F9, "rear_spotlight_speed" },
    { 0x107FA, "rear_spotlight_tag" },
    { 0x107FB, "rear_spotlight_target_found_dist_sq" },
    { 0x107FC, "rear_spotlight_target_found_speed" },
    { 0x107FD, "rear_spotlight_turret_info" },
    { 0x107FE, "reason_stealth_broken" },
    { 0x107FF, "rebel_flood_spawn_wait" },
    { 0x10800, "rebirthloadout" },
    { 0x10801, "receivingampeddamage" },
    { 0x10802, "recent_position_monitor" },
    { 0x10803, "recent_spawn_threshold" },
    { 0x10804, "recentassaultcount" },
    { 0x10805, "recentc4vehiclekillcount" },
    { 0x10806, "recentghostridekillcount" },
    { 0x10807, "recently_spawned_vehicle" },
    { 0x10808, "recentunresolvedcollision" },
    { 0x10809, "recharge_equipment_init" },
    { 0x1080A, "recharge_equipment_think_init" },
    { 0x1080B, "recharge_equipment_update_slot" },
    { 0x1080C, "recharge_equipment_update_state" },
    { 0x1080D, "recharge_equipment_update_ui" },
    { 0x1080E, "rechargenvg" },
    { 0x1080F, "recievedcarepackagekillstreaks" },
    { 0x10810, "recon_update_hint_logic" },
    { 0x10811, "recondrone_watchsuperinternal" },
    { 0x10812, "recondronemarkedcb" },
    { 0x10813, "recondroneteammate" },
    { 0x10814, "recondronetracecontents" },
    { 0x10815, "recondronetraceoffset" },
    { 0x10816, "record" },
    { 0x10817, "record_finished_area" },
    { 0x10818, "recordedgameendstats" },
    { 0x10819, "recordinterval" },
    { 0x1081A, "recordkillstreakendstats" },
    { 0x1081B, "recordmolotov" },
    { 0x1081C, "recordrecentlyplayeddata" },
    { 0x1081D, "redbutton_init" },
    { 0x1081E, "redbuttonused" },
    { 0x1081F, "redeployspawn" },
    { 0x10820, "redeployspawns" },
    { 0x10821, "redlight" },
    { 0x10822, "redployanywhere" },
    { 0x10823, "redshirt_drop_off_behavior" },
    { 0x10824, "redshirt_dropoff" },
    { 0x10825, "redshirt_heli" },
    { 0x10826, "reduce_accuracy_while_stunned" },
    { 0x10827, "ref_angle_doors" },
    { 0x10828, "ref_anim" },
    { 0x10829, "ref_name" },
    { 0x1082A, "reflectbolt" },
    { 0x1082B, "reflectprojectile" },
    { 0x1082C, "refreshsquadspawnareaomnvars" },
    { 0x1082D, "refundondeath" },
    { 0x1082E, "regen_delay" },
    { 0x1082F, "regendelayreduce_delayedregen" },
    { 0x10830, "regendelayspeedfunc" },
    { 0x10831, "regenhealthaddfunc" },
    { 0x10832, "register_ai_spawners" },
    { 0x10833, "register_bank_cut_modules" },
    { 0x10834, "register_battle_station" },
    { 0x10835, "register_boss_objectives" },
    { 0x10836, "register_boss_spawners" },
    { 0x10837, "register_caves_objectives" },
    { 0x10838, "register_caves_spawners" },
    { 0x10839, "register_chopper_boss_combat_action" },
    { 0x1083A, "register_chopper_boss_combat_actions" },
    { 0x1083B, "register_combined_vehicles_threaded" },
    { 0x1083C, "register_disabled_seats_for_vehicle" },
    { 0x1083D, "register_fuel_stability_event" },
    { 0x1083E, "register_grenade_settings_for_module" },
    { 0x1083F, "register_initial_bank_modules" },
    { 0x10840, "register_invalid_seats_for_module_by_seat" },
    { 0x10841, "register_jugg_maze_interactions" },
    { 0x10842, "register_jugg_maze_objectives" },
    { 0x10843, "register_maze_ai_spawners" },
    { 0x10844, "register_module_died_poorly_func" },
    { 0x10845, "register_module_pause_unpause_funcs" },
    { 0x10846, "register_outer_room_spawners" },
    { 0x10847, "register_player_character" },
    { 0x10848, "register_respawn_functions" },
    { 0x10849, "register_script_model_animation" },
    { 0x1084A, "register_seat_data" },
    { 0x1084B, "register_seat_data_for_vehicle" },
    { 0x1084C, "register_sequence_3_objectives" },
    { 0x1084D, "register_sequence_4_objectives" },
    { 0x1084E, "register_subway_track" },
    { 0x1084F, "register_techo_seat_data" },
    { 0x10850, "register_trap_room_objectives" },
    { 0x10851, "register_valid_gametypes_for_create_script" },
    { 0x10852, "register_valid_objectives_for_create_script" },
    { 0x10853, "register_vehicle_as_ambient" },
    { 0x10854, "register_vehicle_max_ai" },
    { 0x10855, "register_vehicle_spawn_override" },
    { 0x10856, "register_vehicle_spawners" },
    { 0x10857, "register_vfx" },
    { 0x10858, "register_wave_spawner" },
    { 0x10859, "registeraccesscardlocs" },
    { 0x1085A, "registerarmsracevfx" },
    { 0x1085B, "registerbrgametypedata" },
    { 0x1085C, "registerbrgametypefunc" },
    { 0x1085D, "registerbrsquadleaderjumpcommands" },
    { 0x1085E, "registercarryobjectpickupcheck" },
    { 0x1085F, "registerchallenge" },
    { 0x10860, "registercontributingplayers" },
    { 0x10861, "registercontrolledcallback" },
    { 0x10862, "registerdonetskmap" },
    { 0x10863, "registerdonetsksubmap" },
    { 0x10864, "registered_checkpoint_funcs" },
    { 0x10865, "registered_checkpoints" },
    { 0x10866, "registereventcallback" },
    { 0x10867, "registerfalldamagedvars" },
    { 0x10868, "registerhandlecommand" },
    { 0x10869, "registerheadlessinfil" },
    { 0x1086A, "registerhint" },
    { 0x1086B, "registerhints" },
    { 0x1086C, "registerleveldataforvehicle" },
    { 0x1086D, "registerlocation" },
    { 0x1086E, "registerlocations" },
    { 0x1086F, "registermovequestlocale" },
    { 0x10870, "registernonnvgnightmap" },
    { 0x10871, "registeronentergulag" },
    { 0x10872, "registeronplayerdisconnect" },
    { 0x10873, "registeronplayerjointeamnospectatorcallback" },
    { 0x10874, "registeronrespawn" },
    { 0x10875, "registerontimerexpired" },
    { 0x10876, "registerontimerupdate" },
    { 0x10877, "registerpickupcreatedcallback" },
    { 0x10878, "registerpreviousprop" },
    { 0x10879, "registerpublicevent" },
    { 0x1087A, "registerpuzzleinteractions" },
    { 0x1087B, "registerquestcategorytablevalues" },
    { 0x1087C, "registerscriptableinstance" },
    { 0x1087D, "registersmallmap" },
    { 0x1087E, "registersuperextraweapon" },
    { 0x1087F, "registertabletinit" },
    { 0x10880, "registeruniquelootcallback" },
    { 0x10881, "regive_killstreak_after_use" },
    { 0x10882, "regroup_all_alive_players_to_plane" },
    { 0x10883, "regroup_at_truck" },
    { 0x10884, "regroup_points" },
    { 0x10885, "regroup_process_started" },
    { 0x10886, "regroup_think" },
    { 0x10887, "regroup_trigger" },
    { 0x10888, "regulateturretrateoffire" },
    { 0x10889, "reinforcement_icon_objective_id" },
    { 0x1088A, "reinforcement_manager" },
    { 0x1088B, "reinforcement_type" },
    { 0x1088C, "relativevelocity" },
    { 0x1088D, "release_ascendstruct_ondeath" },
    { 0x1088E, "release_mortar_operator" },
    { 0x1088F, "release_player_on_damage" },
    { 0x10890, "relic_ammo_drain_take_ammo" },
    { 0x10891, "relic_amped_clear_victim" },
    { 0x10892, "relic_amped_debug_explode_after_reviving" },
    { 0x10893, "relic_amped_debug_sim_kills" },
    { 0x10894, "relic_amped_do_explosion" },
    { 0x10895, "relic_amped_explosion_time" },
    { 0x10896, "relic_amped_in_warning" },
    { 0x10897, "relic_amped_is_player_valid_to_explode" },
    { 0x10898, "relic_amped_is_there_valid_new_victim" },
    { 0x10899, "relic_amped_last_kill_time" },
    { 0x1089A, "relic_amped_monitor" },
    { 0x1089B, "relic_amped_monitor_beeps" },
    { 0x1089C, "relic_amped_on_ai_kill" },
    { 0x1089D, "relic_amped_pause" },
    { 0x1089E, "relic_amped_paused" },
    { 0x1089F, "relic_amped_pick_new_victim" },
    { 0x108A0, "relic_amped_pick_random_valid_player" },
    { 0x108A1, "relic_amped_play_beep" },
    { 0x108A2, "relic_amped_reset_deathshield_on_revived" },
    { 0x108A3, "relic_amped_set_head_objective" },
    { 0x108A4, "relic_amped_show_timer" },
    { 0x108A5, "relic_amped_test_explode_other_player" },
    { 0x108A6, "relic_amped_victim" },
    { 0x108A7, "relic_amped_wait_till_revived" },
    { 0x108A8, "relic_award_bullets" },
    { 0x108A9, "relic_award_one_bullet" },
    { 0x108AA, "relic_bang_and_boom" },
    { 0x108AB, "relic_bang_and_boom_dropfunc" },
    { 0x108AC, "relic_bang_and_boom_think" },
    { 0x108AD, "relic_bang_and_boom_wait_for_pickup" },
    { 0x108AE, "relic_bullet_reward_hud_display" },
    { 0x108AF, "relic_count" },
    { 0x108B0, "relic_disable_health_regen" },
    { 0x108B1, "relic_dogtags" },
    { 0x108B2, "relic_doubletap_helper" },
    { 0x108B3, "relic_fastbleedout_returnfunc" },
    { 0x108B4, "relic_focusfire_modifyplayerdamage" },
    { 0x108B5, "relic_grounded_reload_monitor" },
    { 0x108B6, "relic_healthpacks" },
    { 0x108B7, "relic_healthpacks_globalfunc" },
    { 0x108B8, "relic_healthpacks_killfunc" },
    { 0x108B9, "relic_healthpacks_think" },
    { 0x108BA, "relic_healthpacks_wait_for_pickup" },
    { 0x108BB, "relic_landlocked_clear_message_on_player_return" },
    { 0x108BC, "relic_landlocked_do_explosion" },
    { 0x108BD, "relic_laststand_modifyplayerdamage" },
    { 0x108BE, "relic_mythic_can_do_pain" },
    { 0x108BF, "relic_mythic_do_pain" },
    { 0x108C0, "relic_mythic_modifyplayerdamage" },
    { 0x108C1, "relic_mythic_next_pain_time" },
    { 0x108C2, "relic_mythic_should_ai_play_pain" },
    { 0x108C3, "relic_mythic_should_bypass_pain_cooldown" },
    { 0x108C4, "relic_mythic_should_do_pain" },
    { 0x108C5, "relic_nobulletdamage_modifyplayerdamage" },
    { 0x108C6, "relic_nuketimer" },
    { 0x108C7, "relic_nuketimer_addtotimer" },
    { 0x108C8, "relic_nuketimer_gettimeformission" },
    { 0x108C9, "relic_nuketimer_globalthread" },
    { 0x108CA, "relic_nuketimer_playvo" },
    { 0x108CB, "relic_nuketimer_timer" },
    { 0x108CC, "relic_nuketimer_timer_init" },
    { 0x108CD, "relic_nuketimer_timerloop" },
    { 0x108CE, "relic_nuketimer_waitforcompleteobjectives" },
    { 0x108CF, "relic_nuketimer_waitforobjectives" },
    { 0x108D0, "relic_oneclip_monitor" },
    { 0x108D1, "relic_oneclip_stock_adjustment_monitor" },
    { 0x108D2, "relic_punchbullets_fire_fists" },
    { 0x108D3, "relic_punchbullets_track_previous_bullet_weapon" },
    { 0x108D4, "relic_shieldsonly_set_player_stats_after_spawn" },
    { 0x108D5, "relic_squadlink_add_visionset" },
    { 0x108D6, "relic_squadlink_flash_squadlink_icon" },
    { 0x108D7, "relic_squadlink_init_vfx" },
    { 0x108D8, "relic_squadlink_modifyplayerdamage" },
    { 0x108D9, "relic_squadlink_onbecameinvalidplayer" },
    { 0x108DA, "relic_squadlink_onsteppedclose" },
    { 0x108DB, "relic_squadlink_onsteppedfar" },
    { 0x108DC, "relic_squadlink_outline_monitor" },
    { 0x108DD, "relic_squadlink_remove_visionset" },
    { 0x108DE, "relic_squadlink_toofar_hud_logic" },
    { 0x108DF, "relic_squadlink_turn_team_headobjectives" },
    { 0x108E0, "relic_squadlink_vision_debuff" },
    { 0x108E1, "relic_squadlink_watch_for_visionset_end" },
    { 0x108E2, "relic_steelballs_dash" },
    { 0x108E3, "relic_steelballs_dodamage" },
    { 0x108E4, "relic_steelballs_health_boost" },
    { 0x108E5, "relic_steelballs_slide" },
    { 0x108E6, "relic_steelballs_stump" },
    { 0x108E7, "relic_steelballs_stump_monitor" },
    { 0x108E8, "relic_team_proximity_monitor" },
    { 0x108E9, "relic_third_person" },
    { 0x108EA, "relic_vampire" },
    { 0x108EB, "relic_vampire_feedback" },
    { 0x108EC, "relic_vampire_globalfunc" },
    { 0x108ED, "relics_monitor_on_player" },
    { 0x108EE, "relicsquadlink" },
    { 0x108EF, "relightingenabled" },
    { 0x108F0, "reload_currentsequence_button_handler" },
    { 0x108F1, "reload_handle_hintstring" },
    { 0x108F2, "reload_use_think" },
    { 0x108F3, "reload_use_trigger" },
    { 0x108F4, "reloadnotehandler" },
    { 0x108F5, "remaining_enemies_aggro" },
    { 0x108F6, "remapattachmentparentname" },
    { 0x108F7, "remaphardpointorder" },
    { 0x108F8, "remapobjkeysandscriptlabels" },
    { 0x108F9, "remappedhpzoneorder" },
    { 0x108FA, "remindermessage" },
    { 0x108FB, "remote_tank_think" },
    { 0x108FC, "remove_assault_class" },
    { 0x108FD, "remove_bad_loot_drops" },
    { 0x108FE, "remove_bank_lbravos" },
    { 0x108FF, "remove_carry_item" },
    { 0x10900, "remove_closest_chopper_boss_vandalize_node_down" },
    { 0x10901, "remove_crusader_class" },
    { 0x10902, "remove_dko_spawnflags" },
    { 0x10903, "remove_engineer_class" },
    { 0x10904, "remove_excluder_ai" },
    { 0x10905, "remove_fake_guy_from_list" },
    { 0x10906, "remove_flag_trig" },
    { 0x10907, "remove_flag_trigs" },
    { 0x10908, "remove_from_bomb_detonator_waiting_for_pick_up_array" },
    { 0x10909, "remove_from_spawnflags" },
    { 0x1090A, "remove_group_from_combined_module_counters" },
    { 0x1090B, "remove_hover_direction_and_try_issue_retreat" },
    { 0x1090C, "remove_hunter_class" },
    { 0x1090D, "remove_invulnerability" },
    { 0x1090E, "remove_last_used_node" },
    { 0x1090F, "remove_launcher_xmags" },
    { 0x10910, "remove_map_hint" },
    { 0x10911, "remove_marker_when_player_disconnects" },
    { 0x10912, "remove_marker_when_player_get_close" },
    { 0x10913, "remove_medic_class" },
    { 0x10914, "remove_munition_on_use" },
    { 0x10915, "remove_munitions_globally" },
    { 0x10916, "remove_munitions_in_radius" },
    { 0x10917, "remove_objective_on_flag" },
    { 0x10918, "remove_old_wheelsons" },
    { 0x10919, "remove_on_death" },
    { 0x1091A, "remove_outline" },
    { 0x1091B, "remove_padding_damage" },
    { 0x1091C, "remove_player_from_focus_fire_attacker_list" },
    { 0x1091D, "remove_player_rig_laser_panel" },
    { 0x1091E, "remove_prohibited_weapons" },
    { 0x1091F, "remove_punchcard" },
    { 0x10920, "remove_reduce_recoil" },
    { 0x10921, "remove_roof_nodes" },
    { 0x10922, "remove_soldier_armor" },
    { 0x10923, "remove_spawn_disable_struct" },
    { 0x10924, "remove_spawners_that_can_be_seen" },
    { 0x10925, "remove_specific_structs" },
    { 0x10926, "remove_stay_at_spawn_spawn_flag" },
    { 0x10927, "remove_steam_damage" },
    { 0x10928, "remove_tank_class" },
    { 0x10929, "remove_usability_crutch_on_death" },
    { 0x1092A, "remove_veh_spawners_from_passive_wave_spawning" },
    { 0x1092B, "removeaccesscard" },
    { 0x1092C, "removealldeathicons" },
    { 0x1092D, "removechevronsfromarray" },
    { 0x1092E, "removedeathicon" },
    { 0x1092F, "removeextracthelipad" },
    { 0x10930, "removefromdismembermentlist" },
    { 0x10931, "removefromlittlebirdmglistondeath" },
    { 0x10932, "removegasmaskbr" },
    { 0x10933, "removeincoming" },
    { 0x10934, "removeleadobjective" },
    { 0x10935, "removelinkdamagemodifieronlaststand" },
    { 0x10936, "removelinkdamagemodifierontimeout" },
    { 0x10937, "removematchingents_byclassname" },
    { 0x10938, "removematchingents_bycodeclassname" },
    { 0x10939, "removematchingents_bykey" },
    { 0x1093A, "removematchingents_bymodel" },
    { 0x1093B, "removeminigunrestrictions" },
    { 0x1093C, "removenonvipteamlocations" },
    { 0x1093D, "removepatchablecollision_delayed" },
    { 0x1093E, "removepickup" },
    { 0x1093F, "removeplatepouch" },
    { 0x10940, "removeplayerasexpiredlootleader" },
    { 0x10941, "removeplayeraslootleader" },
    { 0x10942, "removeriotshield" },
    { 0x10943, "removeselfrevivetoken" },
    { 0x10944, "removespawnprotectiononads" },
    { 0x10945, "removespawnprotectiononnotify" },
    { 0x10946, "removespawns" },
    { 0x10947, "removespawnselections" },
    { 0x10948, "removespecialistbonus" },
    { 0x10949, "removespecialistbonuspickup" },
    { 0x1094A, "removestructfromlevelarray" },
    { 0x1094B, "removestuckenemyondeathordisconnect" },
    { 0x1094C, "repair_grill_fixing_long_sfx" },
    { 0x1094D, "repair_grill_fixing_short_sfx" },
    { 0x1094E, "repair_grill_start_enter_foley_sfx" },
    { 0x1094F, "repair_grill_stop_exit_foley_sfx" },
    { 0x10950, "replace_access_card_on_deathordisconnect" },
    { 0x10951, "replace_sat_piece_on_deathordisconnect" },
    { 0x10952, "replace_turret" },
    { 0x10953, "request_crate_drop" },
    { 0x10954, "request_warning_level" },
    { 0x10955, "requested_veh_spawners" },
    { 0x10956, "requestgamerprofile" },
    { 0x10957, "required_tank_capacity" },
    { 0x10958, "requiredcardtype" },
    { 0x10959, "requiredplayercountoveride" },
    { 0x1095A, "reservedplacement" },
    { 0x1095B, "reset_ability_invulnerable" },
    { 0x1095C, "reset_attack_next_available_time" },
    { 0x1095D, "reset_attacks_next_available_time" },
    { 0x1095E, "reset_being_revived" },
    { 0x1095F, "reset_button_handler" },
    { 0x10960, "reset_button_init" },
    { 0x10961, "reset_current_step_count" },
    { 0x10962, "reset_doors" },
    { 0x10963, "reset_global_stealth_settings" },
    { 0x10964, "reset_map_dvars" },
    { 0x10965, "reset_minigun_shot_count" },
    { 0x10966, "reset_motionblur" },
    { 0x10967, "reset_nearby_spawn_times" },
    { 0x10968, "reset_progress" },
    { 0x10969, "reset_recharge_after_respawn" },
    { 0x1096A, "reset_restock_flag" },
    { 0x1096B, "reset_search_spot_light_nodes" },
    { 0x1096C, "reset_target_group" },
    { 0x1096D, "reset_timescalefactor" },
    { 0x1096E, "reset_totals_keep_type" },
    { 0x1096F, "reset_use_puzzle_effects" },
    { 0x10970, "reset_use_think" },
    { 0x10971, "reset_use_trigger" },
    { 0x10972, "reset_vandalize_nodes" },
    { 0x10973, "reset_wave_loadout" },
    { 0x10974, "resetafkchecks" },
    { 0x10975, "resetarenaomnvardata" },
    { 0x10976, "resetbreakertostate" },
    { 0x10977, "resetchallengetimer" },
    { 0x10978, "resetchallengetimers" },
    { 0x10979, "resetchemicalvalvevalues" },
    { 0x1097A, "resetcircuitbreakers" },
    { 0x1097B, "resetdangercircleorigin" },
    { 0x1097C, "resetmissilelaunchertargets" },
    { 0x1097D, "resetmlgobjectivestatusicon" },
    { 0x1097E, "resetpetstats" },
    { 0x1097F, "resetplayerdataforrespawningplayer" },
    { 0x10980, "resetplayermovespeedscale" },
    { 0x10981, "resetposition" },
    { 0x10982, "resetscorefeedcontrolomnvar" },
    { 0x10983, "resetstreamerposhint" },
    { 0x10984, "resetstuckthermite" },
    { 0x10985, "resetsuper" },
    { 0x10986, "resettimeronkill" },
    { 0x10987, "resettimeronpickup" },
    { 0x10988, "resetunresolvedcollision" },
    { 0x10989, "resetvisionsetnighttodefault" },
    { 0x1098A, "residuallight" },
    { 0x1098B, "respawn_after_death" },
    { 0x1098C, "respawn_delay" },
    { 0x1098D, "respawn_enemies" },
    { 0x1098E, "respawn_flare_used" },
    { 0x1098F, "respawn_flare_wavesv_used_playereffects" },
    { 0x10990, "respawn_index" },
    { 0x10991, "respawn_locations" },
    { 0x10992, "respawn_players_into_plane" },
    { 0x10993, "respawn_scriptible_carriable_wait" },
    { 0x10994, "respawn_solo" },
    { 0x10995, "respawn_state_greyout" },
    { 0x10996, "respawn_state_hidden" },
    { 0x10997, "respawn_state_ready" },
    { 0x10998, "respawn_trigger_think" },
    { 0x10999, "respawn_used_once" },
    { 0x1099A, "respawn_waits" },
    { 0x1099B, "respawncircleinterppct" },
    { 0x1099C, "respawndelay" },
    { 0x1099D, "respawndelayoverride" },
    { 0x1099E, "respawnfade" },
    { 0x1099F, "respawnheightoverride" },
    { 0x109A0, "respawningbr" },
    { 0x109A1, "respawnplayer" },
    { 0x109A2, "respawnplayers" },
    { 0x109A3, "respawns_on_failed_unload" },
    { 0x109A4, "respawntags" },
    { 0x109A5, "respawntagsfreed" },
    { 0x109A6, "respawntagvisibility" },
    { 0x109A7, "respawntimedisable" },
    { 0x109A8, "respawntokenclosewithgulag" },
    { 0x109A9, "respawntokendisabled" },
    { 0x109AA, "respawntokenenabled" },
    { 0x109AB, "restart_watcher" },
    { 0x109AC, "restartcircleelimination" },
    { 0x109AD, "restartwrapper" },
    { 0x109AE, "restock_dialoguesectionalogic" },
    { 0x109AF, "restore_ai_weapon" },
    { 0x109B0, "restorekillstreakplayerangles" },
    { 0x109B1, "restoreweaponstates" },
    { 0x109B2, "resttimems" },
    { 0x109B3, "resume_combat_logic" },
    { 0x109B4, "retreat_vehicle_collision_clear" },
    { 0x109B5, "retreatanddie" },
    { 0x109B6, "retrieve_data_objective" },
    { 0x109B7, "retry_no_votes" },
    { 0x109B8, "return_enemy_type_mask" },
    { 0x109B9, "return_num_if_under_vehicle_cap" },
    { 0x109BA, "return_same_module_as_next_module" },
    { 0x109BB, "returntoprop" },
    { 0x109BC, "revive_friendly" },
    { 0x109BD, "revive_icon_color_keep" },
    { 0x109BE, "revive_or_disconnect_monitor" },
    { 0x109BF, "revive_origin" },
    { 0x109C0, "revive_stim" },
    { 0x109C1, "revive_txt_hint" },
    { 0x109C2, "revive_vo_time" },
    { 0x109C3, "revive_wounded_in_handler" },
    { 0x109C4, "revive_wounded_out_handler" },
    { 0x109C5, "revive_wounded_out_handlerr" },
    { 0x109C6, "revivent_watchfordeath_safety" },
    { 0x109C7, "reviveteam" },
    { 0x109C8, "reviveweapon" },
    { 0x109C9, "revivingteammate" },
    { 0x109CA, "rewardangles" },
    { 0x109CB, "rewardmodifier" },
    { 0x109CC, "rewardorigin" },
    { 0x109CD, "rewards" },
    { 0x109CE, "rewardscriptable" },
    { 0x109CF, "rewardtotype" },
    { 0x109D0, "rewardtovalue" },
    { 0x109D1, "rider_models" },
    { 0x109D2, "rifle_lights" },
    { 0x109D3, "right_control" },
    { 0x109D4, "right_side_spawn_adjuster" },
    { 0x109D5, "ring" },
    { 0x109D6, "ringcodephoneconstantly" },
    { 0x109D7, "ringing" },
    { 0x109D8, "ringphoneoccasionally" },
    { 0x109D9, "rings" },
    { 0x109DA, "riotshield_checkshield" },
    { 0x109DB, "riotshield_common" },
    { 0x109DC, "riotshield_init_cp" },
    { 0x109DD, "riotshield_init_sp" },
    { 0x109DE, "riotshield_return" },
    { 0x109DF, "riotshieldclearvars" },
    { 0x109E0, "riotshieldiscurrentprimary" },
    { 0x109E1, "riotshieldmodeltag" },
    { 0x109E2, "riotshieldswitchaway" },
    { 0x109E3, "riotshieldswitchawaytimer" },
    { 0x109E4, "riotshieldtaken" },
    { 0x109E5, "risk_currentflagsactive" },
    { 0x109E6, "risk_currentflagstier" },
    { 0x109E7, "risk_currentlocsinuse" },
    { 0x109E8, "risk_flagspawncount" },
    { 0x109E9, "risk_flagspawncountchange" },
    { 0x109EA, "risk_flagspawndebugobjicons" },
    { 0x109EB, "risk_flagspawnmaxradius" },
    { 0x109EC, "risk_flagspawnminactivetospawn" },
    { 0x109ED, "risk_flagspawnmincount" },
    { 0x109EE, "risk_flagspawnminradius" },
    { 0x109EF, "risk_flagspawnradiuschange" },
    { 0x109F0, "risk_flagspawnshiftingcenter" },
    { 0x109F1, "risk_flagspawnshiftingpercent" },
    { 0x109F2, "risk_modifyflagstieronrespawn" },
    { 0x109F3, "riskspawn_debugdvar" },
    { 0x109F4, "riskspawn_debugobjective" },
    { 0x109F5, "riskspawn_flagcaptured" },
    { 0x109F6, "riskspawn_flagspawnbytier" },
    { 0x109F7, "riskspawn_getspawnlocations" },
    { 0x109F8, "riskspawn_getspawnlocationsbytier" },
    { 0x109F9, "riskspawn_initialset" },
    { 0x109FA, "risktokencount" },
    { 0x109FB, "risktokencountondeath" },
    { 0x109FC, "risktokencountroll" },
    { 0x109FD, "risktokenonuse" },
    { 0x109FE, "risktokens" },
    { 0x109FF, "risktokensbanked" },
    { 0x10A00, "risktokenstokeep" },
    { 0x10A01, "rocket_attack_max_cooldown" },
    { 0x10A02, "rocket_attack_min_cooldown" },
    { 0x10A03, "rocket_death_fx" },
    { 0x10A04, "rocket_fuel" },
    { 0x10A05, "rocket_fuel_stability" },
    { 0x10A06, "rocket_fuel_x1" },
    { 0x10A07, "rocket_fuel_x2" },
    { 0x10A08, "rocket_internal" },
    { 0x10A09, "rocket_missile" },
    { 0x10A0A, "rodwatcher" },
    { 0x10A0B, "role_edit" },
    { 0x10A0C, "role_interaction" },
    { 0x10A0D, "roof_combat_spawn_func" },
    { 0x10A0E, "roof_enemy_groups" },
    { 0x10A0F, "roof_lander_spawn_func" },
    { 0x10A10, "roof_rpg_behavior" },
    { 0x10A11, "roof_rpg_behavior_internal" },
    { 0x10A12, "roof_rpg_covers" },
    { 0x10A13, "roof_spawners" },
    { 0x10A14, "rooftop_active" },
    { 0x10A15, "rooftop_crate_usefunc" },
    { 0x10A16, "rooftop_objective" },
    { 0x10A17, "room_door_windows" },
    { 0x10A18, "room_doors" },
    { 0x10A19, "rootweapon" },
    { 0x10A1A, "ropeguy" },
    { 0x10A1B, "rotate_silo_gyro_lights" },
    { 0x10A1C, "rotateeffect" },
    { 0x10A1D, "rotateplayer" },
    { 0x10A1E, "rotatetocurrentangles" },
    { 0x10A1F, "rotatetowithpause" },
    { 0x10A20, "rotateviptoplayer" },
    { 0x10A21, "rotationentangles" },
    { 0x10A22, "rotationids" },
    { 0x10A23, "rotationrefsbyseatandweapon" },
    { 0x10A24, "rotations" },
    { 0x10A25, "round_at_max" },
    { 0x10A26, "round_enemies_fallback_logic" },
    { 0x10A27, "round_enemies_push_logic" },
    { 0x10A28, "round_enemy_stuck_logic" },
    { 0x10A29, "round_get_vehicles" },
    { 0x10A2A, "round_logic" },
    { 0x10A2B, "round_mortars_logic" },
    { 0x10A2C, "round_robin_spawners" },
    { 0x10A2D, "round_smoke_logic" },
    { 0x10A2E, "round_smoke_molotov_logic" },
    { 0x10A2F, "round_smoke_semtex_logic" },
    { 0x10A30, "round_spawn_bombers" },
    { 0x10A31, "round_spawn_enemies" },
    { 0x10A32, "round_spawn_vehicles" },
    { 0x10A33, "round_vehicle_logic" },
    { 0x10A34, "round_vehicle_path_logic" },
    { 0x10A35, "round_waittill_at_end_enemy_count" },
    { 0x10A36, "roundkillexecute" },
    { 0x10A37, "roundnumber" },
    { 0x10A38, "router_picked_up" },
    { 0x10A39, "router_placed" },
    { 0x10A3A, "router_use_obj" },
    { 0x10A3B, "routers_needed" },
    { 0x10A3C, "routers_picked_up" },
    { 0x10A3D, "rpg_attack_apc" },
    { 0x10A3E, "rpg_building_guys" },
    { 0x10A3F, "rpg_death_watcher" },
    { 0x10A40, "rpg_enemy_damage_debug" },
    { 0x10A41, "rpg_guys" },
    { 0x10A42, "rpg_guys_construction_spawners" },
    { 0x10A43, "rpg_max_range" },
    { 0x10A44, "rpg_shoot_at_trig_watch" },
    { 0x10A45, "rpg_shoot_at_trigs" },
    { 0x10A46, "rpg_think" },
    { 0x10A47, "rpgafterspawnfunc" },
    { 0x10A48, "rpggetclosetoapc" },
    { 0x10A49, "rpgs" },
    { 0x10A4A, "run_and_stop_group_after" },
    { 0x10A4B, "run_blima_exfil_sequence" },
    { 0x10A4C, "run_cleanup_funcs_for_unused_objectives" },
    { 0x10A4D, "run_common_functions_solider_stealth" },
    { 0x10A4E, "run_common_functions_stealth" },
    { 0x10A4F, "run_current_spawn_group" },
    { 0x10A50, "run_debug_start_objective" },
    { 0x10A51, "run_default_threads" },
    { 0x10A52, "run_died_poorly_funcs" },
    { 0x10A53, "run_elevator_spawners_event" },
    { 0x10A54, "run_func_on_each_player" },
    { 0x10A55, "run_global_functions_for_relics" },
    { 0x10A56, "run_guards_spawner" },
    { 0x10A57, "run_hotjoin_loadout_thread" },
    { 0x10A58, "run_hud_logic" },
    { 0x10A59, "run_juggheli_extraction" },
    { 0x10A5A, "run_kill_watcher" },
    { 0x10A5B, "run_laser_vfx_loop" },
    { 0x10A5C, "run_lbravo_spawner" },
    { 0x10A5D, "run_lbravos_safehouse" },
    { 0x10A5E, "run_maze_ai_common_function_stealth" },
    { 0x10A5F, "run_module_pause_funcs" },
    { 0x10A60, "run_module_unpause_funcs" },
    { 0x10A61, "run_openexfil_spawn" },
    { 0x10A62, "run_post_module_actions" },
    { 0x10A63, "run_spawn_module_till_kill_trig" },
    { 0x10A64, "run_spawnfuncs" },
    { 0x10A65, "run_stealth_funcs" },
    { 0x10A66, "run_suppression_logic" },
    { 0x10A67, "run_techo_spawner" },
    { 0x10A68, "run_techos_extraction" },
    { 0x10A69, "run_to_retreat_spot" },
    { 0x10A6A, "run_track_enemy_patrollers" },
    { 0x10A6B, "run_trap_room_combat" },
    { 0x10A6C, "run_vehicle_group_with_respawn_on_failed_unload" },
    { 0x10A6D, "runautocircle" },
    { 0x10A6E, "runbrgametypefunc" },
    { 0x10A6F, "runbrgametypefunc6" },
    { 0x10A70, "runcircles" },
    { 0x10A71, "runcontrolledcallback" },
    { 0x10A72, "rundomplateskybeam" },
    { 0x10A73, "rundrawprematchareas" },
    { 0x10A74, "runextractreroll" },
    { 0x10A75, "rungwperif_flak" },
    { 0x10A76, "rungwperif_largeexplosions" },
    { 0x10A77, "rungwperif_planes" },
    { 0x10A78, "rungwperif_plumes" },
    { 0x10A79, "rungwperif_tracers" },
    { 0x10A7A, "rungwperifeffets" },
    { 0x10A7B, "runheliextraction" },
    { 0x10A7C, "runjoininprogresstimeout" },
    { 0x10A7D, "runkilltriger" },
    { 0x10A7E, "runleadmarkers" },
    { 0x10A7F, "runlogicbasedoncircuitbreaker" },
    { 0x10A80, "runpain" },
    { 0x10A81, "runplunderextractsitetimer" },
    { 0x10A82, "runpubliceventoftype" },
    { 0x10A83, "runspawnmodule_isolated" },
    { 0x10A84, "russianletter" },
    { 0x10A85, "safe_to_authenticate" },
    { 0x10A86, "safechecknum" },
    { 0x10A87, "safecheckstring" },
    { 0x10A88, "safecheckweapon" },
    { 0x10A89, "safedestroy" },
    { 0x10A8A, "safedivide" },
    { 0x10A8B, "safefromnuke" },
    { 0x10A8C, "safehouse_create_loot" },
    { 0x10A8D, "safehouse_hotjoin_func" },
    { 0x10A8E, "safehouse_regroup" },
    { 0x10A8F, "safehouse_restart" },
    { 0x10A90, "safehouse_revive_and_move_players" },
    { 0x10A91, "safehouse_spawn" },
    { 0x10A92, "safehouse_struct" },
    { 0x10A93, "safehouse_vo_return_end" },
    { 0x10A94, "safehouse_vo_return_start" },
    { 0x10A95, "safehouse_vo_start" },
    { 0x10A96, "safesetalpha" },
    { 0x10A97, "sales_discount" },
    { 0x10A98, "sales_discount_items" },
    { 0x10A99, "sandbox_combat_area" },
    { 0x10A9A, "sandbox_combat_area_bits" },
    { 0x10A9B, "sandbox_safe_area" },
    { 0x10A9C, "sandbox_safe_area_count" },
    { 0x10A9D, "sandboxprintlinebold" },
    { 0x10A9E, "sandboxprintlineboldwait" },
    { 0x10A9F, "sappliedstages" },
    { 0x10AA0, "sat_activate" },
    { 0x10AA1, "sat_adjust_think" },
    { 0x10AA2, "sat_choose_missing_piece" },
    { 0x10AA3, "sat_computer_think_new" },
    { 0x10AA4, "sat_create_interaction" },
    { 0x10AA5, "sat_get_piece" },
    { 0x10AA6, "sat_get_signal_strength" },
    { 0x10AA7, "sat_hack_paused_monitor" },
    { 0x10AA8, "sat_handle_player_disconnect" },
    { 0x10AA9, "sat_loop" },
    { 0x10AAA, "sat_missing_pieces" },
    { 0x10AAB, "sat_piece" },
    { 0x10AAC, "sat_piece_think" },
    { 0x10AAD, "sat_play_unfolding_sounds" },
    { 0x10AAE, "sat_setup_access_card_pickup" },
    { 0x10AAF, "sat_setup_access_cards" },
    { 0x10AB0, "sat_setup_interactions" },
    { 0x10AB1, "sat_signal_lost_nag" },
    { 0x10AB2, "sat_signal_shift" },
    { 0x10AB3, "sat_sound_think" },
    { 0x10AB4, "sat_wait_for_access_card" },
    { 0x10AB5, "sat_wait_for_activated_think" },
    { 0x10AB6, "sat_wait_for_antenna" },
    { 0x10AB7, "sat_wait_for_connection_think" },
    { 0x10AB8, "sat_wait_for_controller" },
    { 0x10AB9, "sat_wait_for_piece_added" },
    { 0x10ABA, "sat_wait_for_power" },
    { 0x10ABB, "sat_wait_for_power_think" },
    { 0x10ABC, "sat_wait_for_radar" },
    { 0x10ABD, "sat_wait_for_signal_transfer" },
    { 0x10ABE, "sat_wait_for_transmission_start" },
    { 0x10ABF, "savedangles" },
    { 0x10AC0, "savedexecutionref" },
    { 0x10AC1, "saveendgamelocals" },
    { 0x10AC2, "saveweaponstates" },
    { 0x10AC3, "saw_2_angles" },
    { 0x10AC4, "saw_2_origin" },
    { 0x10AC5, "saw_3_angles" },
    { 0x10AC6, "saw_3_origin" },
    { 0x10AC7, "saw_4_angles" },
    { 0x10AC8, "saw_4_origin" },
    { 0x10AC9, "saw_angles" },
    { 0x10ACA, "saw_fallback_positions" },
    { 0x10ACB, "saw_head_icon" },
    { 0x10ACC, "saw_headicons" },
    { 0x10ACD, "saw_origin" },
    { 0x10ACE, "saw_pickup_think" },
    { 0x10ACF, "saw_remove_icon" },
    { 0x10AD0, "saw_watch_for_stop_interaction" },
    { 0x10AD1, "scale_off_bravo_audio" },
    { 0x10AD2, "scalertoscaleinfo" },
    { 0x10AD3, "scalesitesbyteams" },
    { 0x10AD4, "scavenger_cache_hint" },
    { 0x10AD5, "scavenger_vo_when_close" },
    { 0x10AD6, "scavengerlootcacheused" },
    { 0x10AD7, "sceneangles" },
    { 0x10AD8, "school_guards_behavior" },
    { 0x10AD9, "school_guards_behavior_internal" },
    { 0x10ADA, "school_guards_rpg_guys" },
    { 0x10ADB, "school_guards_rpg_shoot_into_windows" },
    { 0x10ADC, "school_guards_wake_behavior" },
    { 0x10ADD, "scn_infil_hackney_heli_npc1" },
    { 0x10ADE, "scn_infil_hackney_heli_npc2" },
    { 0x10ADF, "scn_infil_hackney_heli_npc3" },
    { 0x10AE0, "scn_infil_hackney_heli_npc4" },
    { 0x10AE1, "scn_infil_hackney_heli_npc5" },
    { 0x10AE2, "scn_infil_hackney_heli_npc6" },
    { 0x10AE3, "scn_infil_tango_npc_0_sfx" },
    { 0x10AE4, "scn_infil_tango_npc_1_sfx" },
    { 0x10AE5, "scn_infil_tango_npc_2_sfx" },
    { 0x10AE6, "scn_infil_tango_npc_3_sfx" },
    { 0x10AE7, "scn_infil_tango_npc_4_sfx" },
    { 0x10AE8, "scn_infil_tango_npc_5_sfx" },
    { 0x10AE9, "score_accuracy_think" },
    { 0x10AEA, "score_event_accuracy" },
    { 0x10AEB, "score_event_civilian_hit" },
    { 0x10AEC, "score_event_civilian_killed" },
    { 0x10AED, "score_event_enemy_killed" },
    { 0x10AEE, "score_event_fob_cleared" },
    { 0x10AEF, "score_event_headshot" },
    { 0x10AF0, "score_event_kill" },
    { 0x10AF1, "score_event_nuked" },
    { 0x10AF2, "score_event_turret_killed" },
    { 0x10AF3, "score_init" },
    { 0x10AF4, "score_message" },
    { 0x10AF5, "score_message_spawners" },
    { 0x10AF6, "score_spawner_relative_to_objective" },
    { 0x10AF7, "scoreeventnoweaponxp" },
    { 0x10AF8, "scoreleadchanged" },
    { 0x10AF9, "scorelimitreached" },
    { 0x10AFA, "scorerequiresbanking" },
    { 0x10AFB, "scout_drone" },
    { 0x10AFC, "scr_arm_numnonrallyvehicles" },
    { 0x10AFD, "scr_br_collection_findpath" },
    { 0x10AFE, "scramblebink" },
    { 0x10AFF, "scrambler_cleanup_player" },
    { 0x10B00, "scrapassistdamage" },
    { 0x10B01, "screen" },
    { 0x10B02, "screenent" },
    { 0x10B03, "screenent_a" },
    { 0x10B04, "screenent_b" },
    { 0x10B05, "screenent_c" },
    { 0x10B06, "screenent_d" },
    { 0x10B07, "script_deplay_post" },
    { 0x10B08, "script_end" },
    { 0x10B09, "script_gameobject" },
    { 0x10B0A, "script_gameobjetname" },
    { 0x10B0B, "script_model_pilot_kill_watch" },
    { 0x10B0C, "script_model_spawn_and_use" },
    { 0x10B0D, "script_model_spawn_and_use_logic" },
    { 0x10B0E, "script_struct_add" },
    { 0x10B0F, "script_struct_autotarget" },
    { 0x10B10, "scriptable_addautousecallback" },
    { 0x10B11, "scriptable_adddamagedcallback" },
    { 0x10B12, "scriptable_addusedcallbackbypart" },
    { 0x10B13, "scriptable_autouse_funcs" },
    { 0x10B14, "scriptable_callback" },
    { 0x10B15, "scriptable_carriable_damage" },
    { 0x10B16, "scriptable_carriable_damage_internal" },
    { 0x10B17, "scriptable_carriable_use" },
    { 0x10B18, "scriptable_damaged_funcs" },
    { 0x10B19, "scriptable_door_freeze_open" },
    { 0x10B1A, "scriptable_door_get_in_radius" },
    { 0x10B1B, "scriptable_door_is_double_door_pair" },
    { 0x10B1C, "scriptable_enginedamaged" },
    { 0x10B1D, "scriptable_reserved_count" },
    { 0x10B1E, "scriptable_setups" },
    { 0x10B1F, "scriptable_token_scriptable_touched_callback" },
    { 0x10B20, "scriptable_used_by_part_funcs" },
    { 0x10B21, "scriptablecount" },
    { 0x10B22, "scriptableinit" },
    { 0x10B23, "scriptablenousestate" },
    { 0x10B24, "scriptablescleanupbatchsize" },
    { 0x10B25, "scriptablescurid" },
    { 0x10B26, "scriptablesmax" },
    { 0x10B27, "scriptablesstartid" },
    { 0x10B28, "scriptableusepart" },
    { 0x10B29, "scriptableusestate" },
    { 0x10B2A, "scriptcircleat" },
    { 0x10B2B, "scriptdoordelete" },
    { 0x10B2C, "scripted_fov" },
    { 0x10B2D, "scripted_laser_func" },
    { 0x10B2E, "scriptedagentmodifieddamage" },
    { 0x10B2F, "scriptednode" },
    { 0x10B30, "scriptedphysicaldofenabled" },
    { 0x10B31, "scriptedspawnpointarray" },
    { 0x10B32, "scriptedspawnpointsonmigration" },
    { 0x10B33, "scriptedspawns" },
    { 0x10B34, "scriptflags" },
    { 0x10B35, "scriptgoalyaw" },
    { 0x10B36, "scriptmover_utils" },
    { 0x10B37, "scurrentobjective" },
    { 0x10B38, "search" },
    { 0x10B39, "search_acceleration" },
    { 0x10B3A, "search_activate_battle_station" },
    { 0x10B3B, "search_maneuver_think" },
    { 0x10B3C, "search_nodes" },
    { 0x10B3D, "search_speed" },
    { 0x10B3E, "search_target_think" },
    { 0x10B3F, "search_turret_fire_think" },
    { 0x10B40, "search_turret_no_target_stop_delay" },
    { 0x10B41, "search_update_delay" },
    { 0x10B42, "searchcircleorigin" },
    { 0x10B43, "searchcirclesize" },
    { 0x10B44, "searchforcecirclecenter" },
    { 0x10B45, "searchfortarget" },
    { 0x10B46, "searchfunc" },
    { 0x10B47, "searchradiusidealmax" },
    { 0x10B48, "searchradiusidealmin" },
    { 0x10B49, "searchradiusmax" },
    { 0x10B4A, "searchradiusmin" },
    { 0x10B4B, "sec_sys_struct_1" },
    { 0x10B4C, "sec_sys_struct_2" },
    { 0x10B4D, "sec_sys_struct_3" },
    { 0x10B4E, "secondaryweaponbackup" },
    { 0x10B4F, "secondsbeforeplacementupdates" },
    { 0x10B50, "secondwindthink" },
    { 0x10B51, "secretstashlootcacheused" },
    { 0x10B52, "see_air_killstreak_dist" },
    { 0x10B53, "see_equipment_dist" },
    { 0x10B54, "see_killstreak_dist" },
    { 0x10B55, "see_recently_override" },
    { 0x10B56, "seen_recently_spawner_time" },
    { 0x10B57, "select_back_door_spawners" },
    { 0x10B58, "select_back_one_spawners" },
    { 0x10B59, "select_back_two_spawners" },
    { 0x10B5A, "select_boss_one_spawners" },
    { 0x10B5B, "select_boss_two_spawners" },
    { 0x10B5C, "select_bridge_one_spawners" },
    { 0x10B5D, "select_bridge_three_spawners" },
    { 0x10B5E, "select_bridge_two_spawners" },
    { 0x10B5F, "select_bunker_courtyard_spawners" },
    { 0x10B60, "select_bunker_interior_four_spawners" },
    { 0x10B61, "select_bunker_interior_groups" },
    { 0x10B62, "select_bunker_interior_one_spawners" },
    { 0x10B63, "select_bunker_interior_three_spawners" },
    { 0x10B64, "select_bunker_interior_two_spawners" },
    { 0x10B65, "select_bunker_roof_spawners" },
    { 0x10B66, "select_bunker_server_one_spawners" },
    { 0x10B67, "select_bunker_server_two_spawners" },
    { 0x10B68, "select_chopper_boss_target_player" },
    { 0x10B69, "select_cliff_one_spawners" },
    { 0x10B6A, "select_cliff_two_spawners" },
    { 0x10B6B, "select_equipment_spawners" },
    { 0x10B6C, "select_hostage_room_one_spawners" },
    { 0x10B6D, "select_hostage_room_three_spawners" },
    { 0x10B6E, "select_hostage_room_two_spawners" },
    { 0x10B6F, "select_kitchen_spawners" },
    { 0x10B70, "select_lobby_door_one_spawners" },
    { 0x10B71, "select_lobby_door_two_spawners" },
    { 0x10B72, "select_lobby_patrol_spawners" },
    { 0x10B73, "select_low_roof_spawners" },
    { 0x10B74, "select_mid_roof_spawners" },
    { 0x10B75, "select_mountain_one_spawners" },
    { 0x10B76, "select_mountain_three_spawners" },
    { 0x10B77, "select_mountain_two_spawners" },
    { 0x10B78, "select_new_spotlight_goal_node" },
    { 0x10B79, "select_patrol_eight_spawners" },
    { 0x10B7A, "select_patrol_five_spawners" },
    { 0x10B7B, "select_patrol_four_spawners" },
    { 0x10B7C, "select_patrol_nine_spawners" },
    { 0x10B7D, "select_patrol_one_spawners" },
    { 0x10B7E, "select_patrol_seven_spawners" },
    { 0x10B7F, "select_patrol_six_spawners" },
    { 0x10B80, "select_patrol_three_spawners" },
    { 0x10B81, "select_patrol_two_spawners" },
    { 0x10B82, "select_players_in_killzone_first" },
    { 0x10B83, "select_players_in_killzone_only" },
    { 0x10B84, "select_players_not_in_killzone_only" },
    { 0x10B85, "select_random_card_location" },
    { 0x10B86, "select_reception_spawners" },
    { 0x10B87, "select_spot_light_nodes_from" },
    { 0x10B88, "select_stadium_one_spawners" },
    { 0x10B89, "select_stadium_three_spawners" },
    { 0x10B8A, "select_stadium_two_spawners" },
    { 0x10B8B, "select_stairway_spawners" },
    { 0x10B8C, "select_top_roof_spawners" },
    { 0x10B8D, "select_woods_one_spawners" },
    { 0x10B8E, "select_woods_three_spawners" },
    { 0x10B8F, "select_woods_two_spawners" },
    { 0x10B90, "selfrevivebuttonpresscleanup" },
    { 0x10B91, "selfrevivebuttonpressed" },
    { 0x10B92, "selfrevivemonitorrevivebuttonpressed" },
    { 0x10B93, "selfrevivethink" },
    { 0x10B94, "semtex_killstuckplayer" },
    { 0x10B95, "semtex_stuckplayer" },
    { 0x10B96, "semtex_used" },
    { 0x10B97, "send_all_ai_to_players" },
    { 0x10B98, "send_munition_used_notify" },
    { 0x10B99, "send_notify_after_player_tac_vis" },
    { 0x10B9A, "send_notify_to_module_struct" },
    { 0x10B9B, "send_wave_spawns_to_roof" },
    { 0x10B9C, "sendendofmatchdata" },
    { 0x10B9D, "sentry_init_done" },
    { 0x10B9E, "sentry_shouldshoot" },
    { 0x10B9F, "sentry_trap_structs" },
    { 0x10BA0, "sentryturret_allowpickupofturret" },
    { 0x10BA1, "sentryturret_canpickup" },
    { 0x10BA2, "sentryturret_watchgameend" },
    { 0x10BA3, "seq3_cleanup_leftovers" },
    { 0x10BA4, "seq3_computer_interaction" },
    { 0x10BA5, "seq3_computersused" },
    { 0x10BA6, "seq3_crate_usable" },
    { 0x10BA7, "seq3_cypher_tagorigin" },
    { 0x10BA8, "seq3_digits_display_array" },
    { 0x10BA9, "seq3_displaymodels" },
    { 0x10BAA, "seq3_elevator_init" },
    { 0x10BAB, "seq3_emergency_lights" },
    { 0x10BAC, "seq3_gate" },
    { 0x10BAD, "seq3_has_seen_tiers" },
    { 0x10BAE, "seq3_keyboards" },
    { 0x10BAF, "seq3_keypad_init" },
    { 0x10BB0, "seq3_monitor_2_spawned" },
    { 0x10BB1, "seq3_numbers_array" },
    { 0x10BB2, "seq3_puzzle_attempts" },
    { 0x10BB3, "seq3_puzzle_complete" },
    { 0x10BB4, "seq3_reset_switch" },
    { 0x10BB5, "seq3_russian_cypher_str" },
    { 0x10BB6, "seq3_sequence" },
    { 0x10BB7, "seq3_sequences" },
    { 0x10BB8, "seq3_sequences_correct" },
    { 0x10BB9, "seq3_spawners_intro" },
    { 0x10BBA, "seq3_tanksettings" },
    { 0x10BBB, "seq3_thermitetank_settings" },
    { 0x10BBC, "seq3_tier" },
    { 0x10BBD, "seq3_tvnums_str" },
    { 0x10BBE, "seq3_warning_room_a" },
    { 0x10BBF, "seq3_warning_room_b" },
    { 0x10BC0, "seq3_warning_room_c" },
    { 0x10BC1, "seq3_warning_tier" },
    { 0x10BC2, "seq3_wave_delay" },
    { 0x10BC3, "seq3_wheelson_starts" },
    { 0x10BC4, "sequence_interaction_activate" },
    { 0x10BC5, "sequence_interaction_hint" },
    { 0x10BC6, "sequence_interaction_init" },
    { 0x10BC7, "sequence_progression" },
    { 0x10BC8, "server_activate" },
    { 0x10BC9, "server_hint" },
    { 0x10BCA, "server_interact_used_think" },
    { 0x10BCB, "server_rack_clip" },
    { 0x10BCC, "server_structs" },
    { 0x10BCD, "server_triggered" },
    { 0x10BCE, "server_unlocked" },
    { 0x10BCF, "serverroomdogtagrevive" },
    { 0x10BD0, "serverroomrewardlocs" },
    { 0x10BD1, "serverroomrewardroll" },
    { 0x10BD2, "serverroomrewardspawn" },
    { 0x10BD3, "serverroomtvs" },
    { 0x10BD4, "set_achievements_blocker" },
    { 0x10BD5, "set_actualstarttime" },
    { 0x10BD6, "set_backup_location" },
    { 0x10BD7, "set_car_collision" },
    { 0x10BD8, "set_carry_item" },
    { 0x10BD9, "set_chopper_circle_speed" },
    { 0x10BDA, "set_chopper_search_speed" },
    { 0x10BDB, "set_chopper_spawn_speed" },
    { 0x10BDC, "set_chopper_strafe_speed" },
    { 0x10BDD, "set_chosen_spawner_from_uid" },
    { 0x10BDE, "set_combat_action" },
    { 0x10BDF, "set_corpse_detect_ranges" },
    { 0x10BE0, "set_cp_vehicle_health_values" },
    { 0x10BE1, "set_customizable_values" },
    { 0x10BE2, "set_disable_leave_truck" },
    { 0x10BE3, "set_distances_for_groups" },
    { 0x10BE4, "set_door_open" },
    { 0x10BE5, "set_dvars" },
    { 0x10BE6, "set_ending_pack" },
    { 0x10BE7, "set_flag_after_vo" },
    { 0x10BE8, "set_flag_via_event_structs" },
    { 0x10BE9, "set_focus_fire_params" },
    { 0x10BEA, "set_force_aitype_armored" },
    { 0x10BEB, "set_force_aitype_riotshield" },
    { 0x10BEC, "set_force_aitype_rpg" },
    { 0x10BED, "set_force_aitype_shotgun" },
    { 0x10BEE, "set_force_aitype_sniper" },
    { 0x10BEF, "set_force_aitype_suicidebomber" },
    { 0x10BF0, "set_guy_to_specific_node" },
    { 0x10BF1, "set_guy_to_specific_pos" },
    { 0x10BF2, "set_heavy_hitter" },
    { 0x10BF3, "set_heli_crash_override" },
    { 0x10BF4, "set_initial_goalheight" },
    { 0x10BF5, "set_initial_goalradius" },
    { 0x10BF6, "set_just_keep_moving" },
    { 0x10BF7, "set_level_weapons_free" },
    { 0x10BF8, "set_look_at_ent" },
    { 0x10BF9, "set_mark_distances" },
    { 0x10BFA, "set_maze_ai_state" },
    { 0x10BFB, "set_maze_ai_stealth_settings" },
    { 0x10BFC, "set_minigun_target_loc" },
    { 0x10BFD, "set_mission_ai_cap" },
    { 0x10BFE, "set_new_br_values" },
    { 0x10BFF, "set_no_crash" },
    { 0x10C00, "set_number_of_subway_cars_on_track" },
    { 0x10C01, "set_omnvar_for_icon" },
    { 0x10C02, "set_pitch_roll_for_ground_normal" },
    { 0x10C03, "set_player_camera" },
    { 0x10C04, "set_player_hurt_trigger" },
    { 0x10C05, "set_player_munition_currency" },
    { 0x10C06, "set_pressure_stability_reading" },
    { 0x10C07, "set_recent_spawn_time_threshold_override" },
    { 0x10C08, "set_relic_aggressive_melee" },
    { 0x10C09, "set_relic_aggressive_melee_params" },
    { 0x10C0A, "set_relic_ammo_drain" },
    { 0x10C0B, "set_relic_amped" },
    { 0x10C0C, "set_relic_bang_and_boom" },
    { 0x10C0D, "set_relic_damage_from_above" },
    { 0x10C0E, "set_relic_dfa" },
    { 0x10C0F, "set_relic_dogtags" },
    { 0x10C10, "set_relic_doomslayer" },
    { 0x10C11, "set_relic_doubletap" },
    { 0x10C12, "set_relic_doubletap_params" },
    { 0x10C13, "set_relic_doubletap_params_internal" },
    { 0x10C14, "set_relic_explodedmg" },
    { 0x10C15, "set_relic_fastbleedout" },
    { 0x10C16, "set_relic_focus_fire" },
    { 0x10C17, "set_relic_gas_martyr" },
    { 0x10C18, "set_relic_grounded" },
    { 0x10C19, "set_relic_gun_game" },
    { 0x10C1A, "set_relic_headbullets" },
    { 0x10C1B, "set_relic_healthpacks" },
    { 0x10C1C, "set_relic_hideobjicons" },
    { 0x10C1D, "set_relic_landlocked" },
    { 0x10C1E, "set_relic_laststand" },
    { 0x10C1F, "set_relic_laststandmelee" },
    { 0x10C20, "set_relic_lfo" },
    { 0x10C21, "set_relic_martyrdom" },
    { 0x10C22, "set_relic_mythic" },
    { 0x10C23, "set_relic_no_ammo_mun" },
    { 0x10C24, "set_relic_nobulletdamage" },
    { 0x10C25, "set_relic_noks" },
    { 0x10C26, "set_relic_noluck" },
    { 0x10C27, "set_relic_noregen" },
    { 0x10C28, "set_relic_nuketimer" },
    { 0x10C29, "set_relic_oneclip" },
    { 0x10C2A, "set_relic_punchbullets" },
    { 0x10C2B, "set_relic_rocket_kill_ammo" },
    { 0x10C2C, "set_relic_shieldsonly" },
    { 0x10C2D, "set_relic_squadlink" },
    { 0x10C2E, "set_relic_steelballs" },
    { 0x10C2F, "set_relic_steelballs_perks" },
    { 0x10C30, "set_relic_team_proximity" },
    { 0x10C31, "set_relic_thirdperson" },
    { 0x10C32, "set_relic_trex" },
    { 0x10C33, "set_relic_vampire" },
    { 0x10C34, "set_respawn_loc_delayed" },
    { 0x10C35, "set_respawn_points" },
    { 0x10C36, "set_scriptable_states" },
    { 0x10C37, "set_shouldrespawn" },
    { 0x10C38, "set_showing_bomb_wire_pair_to_player" },
    { 0x10C39, "set_slow_healthregen" },
    { 0x10C3A, "set_solution" },
    { 0x10C3B, "set_spawn_scoring_params_for_level" },
    { 0x10C3C, "set_spawner_type" },
    { 0x10C3D, "set_spotlight_target_loc" },
    { 0x10C3E, "set_start_cash" },
    { 0x10C3F, "set_station_track_available_time" },
    { 0x10C40, "set_stealth_enabled" },
    { 0x10C41, "set_strict_ff" },
    { 0x10C42, "set_subway_car_deployed" },
    { 0x10C43, "set_systems_init_flag" },
    { 0x10C44, "set_tank_target_player" },
    { 0x10C45, "set_thirdperson" },
    { 0x10C46, "set_tier_lights" },
    { 0x10C47, "set_total_successful_vehicle_spawns_from_module" },
    { 0x10C48, "set_track_operational_status" },
    { 0x10C49, "set_train_stopped" },
    { 0x10C4A, "set_trap_flag" },
    { 0x10C4B, "set_ui_omnvar_for_relics" },
    { 0x10C4C, "set_unloadtype_at_end_path" },
    { 0x10C4D, "set_up_blockade_gate_anims" },
    { 0x10C4E, "set_up_chopper_boss" },
    { 0x10C4F, "set_up_coop_push" },
    { 0x10C50, "set_up_minigun" },
    { 0x10C51, "set_up_pilots" },
    { 0x10C52, "set_up_rear_minigun" },
    { 0x10C53, "set_up_rear_spotlight" },
    { 0x10C54, "set_up_spotlight" },
    { 0x10C55, "set_up_subway_car" },
    { 0x10C56, "set_up_tv_station_for_stealth" },
    { 0x10C57, "set_vandalize_minigun_speed" },
    { 0x10C58, "set_vehicle_anims_apc" },
    { 0x10C59, "set_vehicle_anims_asierra" },
    { 0x10C5A, "set_vehicle_anims_blima" },
    { 0x10C5B, "set_vehicle_anims_decho" },
    { 0x10C5C, "set_vehicle_anims_decho_civ" },
    { 0x10C5D, "set_vehicle_anims_decho_police" },
    { 0x10C5E, "set_vehicle_anims_decho_rebel" },
    { 0x10C5F, "set_vehicle_anims_mkilo" },
    { 0x10C60, "set_vehicle_anims_mkilo23_ai_infil" },
    { 0x10C61, "set_vehicle_anims_palfa" },
    { 0x10C62, "set_vehicle_anims_ralfa" },
    { 0x10C63, "set_vehicle_anims_skilo" },
    { 0x10C64, "set_vehicle_anims_techo" },
    { 0x10C65, "set_vehicle_anims_tromeo" },
    { 0x10C66, "set_vehicle_anims_umike" },
    { 0x10C67, "set_vehicle_anims_vindia" },
    { 0x10C68, "set_vehicle_bulletshield" },
    { 0x10C69, "set_vehicle_templates_script_team" },
    { 0x10C6A, "set_warning_levels" },
    { 0x10C6B, "set_wave_num" },
    { 0x10C6C, "setaardata" },
    { 0x10C6D, "setallclientomnvarot" },
    { 0x10C6E, "setarenaomnvar" },
    { 0x10C6F, "setarenaomnvarhealthtype" },
    { 0x10C70, "setarenaomnvarplayertype" },
    { 0x10C71, "setbeingrevivedinternal" },
    { 0x10C72, "setbettermissionrewards" },
    { 0x10C73, "setbrjuggsettings" },
    { 0x10C74, "setbrokenoverlaymaterial" },
    { 0x10C75, "setburningdamage" },
    { 0x10C76, "setburningpartstate" },
    { 0x10C77, "setbuybackpingmessage" },
    { 0x10C78, "setcachedclientomnvar" },
    { 0x10C79, "setcachedgameomnvar" },
    { 0x10C7A, "setchainkillstreaks" },
    { 0x10C7B, "setcheckliststateforteam" },
    { 0x10C7C, "setchecklistsubversion" },
    { 0x10C7D, "setcodenumber" },
    { 0x10C7E, "setconfig" },
    { 0x10C7F, "setdeleteable" },
    { 0x10C80, "setdeleteabletimer" },
    { 0x10C81, "setdragonsbreathburning" },
    { 0x10C82, "setdragonsbreathcorpseflare" },
    { 0x10C83, "setdropbagdelay" },
    { 0x10C84, "setexfiltimer" },
    { 0x10C85, "setextractspawninstances" },
    { 0x10C86, "setextrascore4" },
    { 0x10C87, "setfaketispawnpoint" },
    { 0x10C88, "setfirsthistorydestination" },
    { 0x10C89, "setgameendflagsandnotifies" },
    { 0x10C8A, "setgun" },
    { 0x10C8B, "sethasrespawntokenextrainfo" },
    { 0x10C8C, "sethasselfrevivetokenextrainfo" },
    { 0x10C8D, "setheadicon_addclienttomask" },
    { 0x10C8E, "setheadicon_removeclientfrommask" },
    { 0x10C8F, "setherodropscriptable" },
    { 0x10C90, "sethistorydestination" },
    { 0x10C91, "setincomingcallback" },
    { 0x10C92, "setincomingremovedcallback" },
    { 0x10C93, "setjailtimeouthud" },
    { 0x10C94, "setlastdroppableweaponobj" },
    { 0x10C95, "setlethalonunresolvedcollision" },
    { 0x10C96, "setlocaledefaultvalue" },
    { 0x10C97, "setlowermessageomnvarref" },
    { 0x10C98, "setmapcirclesize" },
    { 0x10C99, "setmlgobjectivestatusicon" },
    { 0x10C9A, "setnewabilitycount" },
    { 0x10C9B, "setnewabilityhud" },
    { 0x10C9C, "setnexthistorydestination" },
    { 0x10C9D, "setobjectivecallbacks" },
    { 0x10C9E, "setobjectivelocations" },
    { 0x10C9F, "setobjectivestatusallicons" },
    { 0x10CA0, "setobjectivetypesomvarbit" },
    { 0x10CA1, "setoutputfunc" },
    { 0x10CA2, "setovertimeomnvarenabled" },
    { 0x10CA3, "setovertimeomnvarprogress" },
    { 0x10CA4, "setphteamscores" },
    { 0x10CA5, "setplacementstats" },
    { 0x10CA6, "setplacementxpshare" },
    { 0x10CA7, "setplayerbeingrevivedextrainfo" },
    { 0x10CA8, "setplayerbrsquadleader" },
    { 0x10CA9, "setplayerdownedextrainfo" },
    { 0x10CAA, "setplayergulagindex" },
    { 0x10CAB, "setplayeringulagarenaextrainfo" },
    { 0x10CAC, "setplayeringulagjailextrainfo" },
    { 0x10CAD, "setplayermostwantedextrainfo" },
    { 0x10CAE, "setplayerselfrevivingextrainfo" },
    { 0x10CAF, "setplayersquadindex" },
    { 0x10CB0, "setplayervargulagjail" },
    { 0x10CB1, "setplunderifunchanged" },
    { 0x10CB2, "setpostgamestate" },
    { 0x10CB3, "setpreviewuicircle" },
    { 0x10CB4, "setquestindexomnvar" },
    { 0x10CB5, "setquestindexteamomnvar" },
    { 0x10CB6, "setquestrewardtier" },
    { 0x10CB7, "setquestrewardtieromnvar" },
    { 0x10CB8, "setquestrewardtierteamomnvar" },
    { 0x10CB9, "setradarparamsonlatejoiner" },
    { 0x10CBA, "setreduceregendelayonkill" },
    { 0x10CBB, "setreduceregendelayonkills" },
    { 0x10CBC, "setroundwinstreakspecialcamos" },
    { 0x10CBD, "setsoundsubmixfadetoblackamb" },
    { 0x10CBE, "setspawninstances" },
    { 0x10CBF, "setspecialistbonus" },
    { 0x10CC0, "setsuperexpended" },
    { 0x10CC1, "setsuperisinuse" },
    { 0x10CC2, "setsuperweapondisabledbr" },
    { 0x10CC3, "settargetmarkerstate" },
    { 0x10CC4, "setteamasextracted" },
    { 0x10CC5, "setteamhealthhud" },
    { 0x10CC6, "setteamlastzombietime" },
    { 0x10CC7, "setteamplunderhud" },
    { 0x10CC8, "settings_group" },
    { 0x10CC9, "setup_backup_respawn_points_in_verdansk" },
    { 0x10CCA, "setup_bot_arena" },
    { 0x10CCB, "setup_bot_brtdm" },
    { 0x10CCC, "setup_bot_flag" },
    { 0x10CCD, "setup_bot_hq" },
    { 0x10CCE, "setup_comms_obj" },
    { 0x10CCF, "setup_comms_obj_a_goals_and_cover" },
    { 0x10CD0, "setup_comms_obj_b_goals_and_cover" },
    { 0x10CD1, "setup_comms_obj_crate" },
    { 0x10CD2, "setup_crates_to_mark" },
    { 0x10CD3, "setup_enemy_sentries" },
    { 0x10CD4, "setup_enemy_sentry" },
    { 0x10CD5, "setup_enemytype_on_spawner" },
    { 0x10CD6, "setup_functions" },
    { 0x10CD7, "setup_hacks" },
    { 0x10CD8, "setup_heli_starts" },
    { 0x10CD9, "setup_heli_starts_deep" },
    { 0x10CDA, "setup_intel" },
    { 0x10CDB, "setup_jugg_maze_kill_trigger" },
    { 0x10CDC, "setup_last_enemies_standing" },
    { 0x10CDD, "setup_level_for_nightvision" },
    { 0x10CDE, "setup_lights_in_region" },
    { 0x10CDF, "setup_manned_turret" },
    { 0x10CE0, "setup_minecart" },
    { 0x10CE1, "setup_next_advance" },
    { 0x10CE2, "setup_nuke_vault_door_open" },
    { 0x10CE3, "setup_player_killstreak_loadouts" },
    { 0x10CE4, "setup_player_marks" },
    { 0x10CE5, "setup_player_stealth" },
    { 0x10CE6, "setup_rarity_ui_images" },
    { 0x10CE7, "setup_soldier_stealth" },
    { 0x10CE8, "setup_target_anims" },
    { 0x10CE9, "setup_techo_lmgs" },
    { 0x10CEA, "setup_teleport_rooms" },
    { 0x10CEB, "setup_train_array" },
    { 0x10CEC, "setup_train_entarray" },
    { 0x10CED, "setup_train_entarray_composite" },
    { 0x10CEE, "setup_trap_consoles" },
    { 0x10CEF, "setup_tut_zones" },
    { 0x10CF0, "setup_vehicle_wave_by_player_count" },
    { 0x10CF1, "setup_volumes" },
    { 0x10CF2, "setup_wave_spawn_zone_disable" },
    { 0x10CF3, "setup_weapon_spawns" },
    { 0x10CF4, "setup_weapons_at_pos" },
    { 0x10CF5, "setupblueprintpickupweapons" },
    { 0x10CF6, "setupboardroomcode" },
    { 0x10CF7, "setupbobbingboatmultiple" },
    { 0x10CF8, "setupbrsquadleader" },
    { 0x10CF9, "setupcellspawn" },
    { 0x10CFA, "setupcirclepeek" },
    { 0x10CFB, "setupdamage" },
    { 0x10CFC, "setupdogtags" },
    { 0x10CFD, "setupdom" },
    { 0x10CFE, "setupdomendflag" },
    { 0x10CFF, "setupdomplates" },
    { 0x10D00, "setupelevatordoor" },
    { 0x10D01, "setupevenlydistributedpads" },
    { 0x10D02, "setupextractionsites" },
    { 0x10D03, "setupextractnumhud" },
    { 0x10D04, "setupfans" },
    { 0x10D05, "setupglobalkillcount" },
    { 0x10D06, "setupgulagtimer" },
    { 0x10D07, "setuphelilandingposition" },
    { 0x10D08, "setuphelitimer" },
    { 0x10D09, "setuphqs" },
    { 0x10D0A, "setuphudelemninfilblack" },
    { 0x10D0B, "setuphudelemninfilcover" },
    { 0x10D0C, "setuphumanpowers" },
    { 0x10D0D, "setuphunters" },
    { 0x10D0E, "setupinfectedairdroppositions" },
    { 0x10D0F, "setupkeybindings" },
    { 0x10D10, "setuplocalelocation" },
    { 0x10D11, "setupmapquadrantcornersandgrid" },
    { 0x10D12, "setupminimapmaze" },
    { 0x10D13, "setupmission" },
    { 0x10D14, "setupmissionwidget" },
    { 0x10D15, "setupoptimalreadinghint" },
    { 0x10D16, "setuppingspecificvars" },
    { 0x10D17, "setupprop" },
    { 0x10D18, "setupprops" },
    { 0x10D19, "setuproundstarthud" },
    { 0x10D1A, "setupsnowballs" },
    { 0x10D1B, "setupsoccerball" },
    { 0x10D1C, "setupspecialdaypickupweapons" },
    { 0x10D1D, "setupstartweaponsattachments" },
    { 0x10D1E, "setupteamplunderhud" },
    { 0x10D1F, "setupteamplunderleaderboard" },
    { 0x10D20, "setuptimelimit" },
    { 0x10D21, "setuptrain" },
    { 0x10D22, "setupweaponattachmentoverrides" },
    { 0x10D23, "setupx1timelimit" },
    { 0x10D24, "setupzombiepowers" },
    { 0x10D25, "setupzombierespawnglobaltimer" },
    { 0x10D26, "setvalidreviveposition" },
    { 0x10D27, "setweaponcarry" },
    { 0x10D28, "setwind" },
    { 0x10D29, "seventyfivepercent_music" },
    { 0x10D2A, "sfx_br_flare_phosphorus" },
    { 0x10D2B, "sfx_ext_walla" },
    { 0x10D2C, "sfx_infil_hackney_heli1_rope" },
    { 0x10D2D, "sfx_infil_hackney_heli2_rope" },
    { 0x10D2E, "sfx_last_roll" },
    { 0x10D2F, "sfx_misc_field_expl" },
    { 0x10D30, "sfx_revive_lp" },
    { 0x10D31, "sg_ontimerexpired" },
    { 0x10D32, "sg_playerdisconnect" },
    { 0x10D33, "sg_removequestinstance" },
    { 0x10D34, "sg_respawn" },
    { 0x10D35, "sg_think" },
    { 0x10D36, "shared_interaction_structs" },
    { 0x10D37, "shield" },
    { 0x10D38, "shiftbar" },
    { 0x10D39, "shipfx" },
    { 0x10D3A, "shipment_spawnpatchtriggers" },
    { 0x10D3B, "shock_puzzle_completed" },
    { 0x10D3C, "shocklevel" },
    { 0x10D3D, "shoot_at_apc" },
    { 0x10D3E, "shoot_vehicle" },
    { 0x10D3F, "shooting_targets" },
    { 0x10D40, "short_term_goal" },
    { 0x10D41, "shot_by_player" },
    { 0x10D42, "shot_start_offset" },
    { 0x10D43, "shot_to_miss_for_dialog" },
    { 0x10D44, "should_ai_take_damage" },
    { 0x10D45, "should_break_stealth_immediately" },
    { 0x10D46, "should_break_stealth_immediately_func" },
    { 0x10D47, "should_damage_pavelow_boss" },
    { 0x10D48, "should_damage_player_on_bottom" },
    { 0x10D49, "should_display_reinforcement_called_icon" },
    { 0x10D4A, "should_do_damage_check_func_relics" },
    { 0x10D4B, "should_do_vo_call" },
    { 0x10D4C, "should_drop_grenade_pickup" },
    { 0x10D4D, "should_drop_minigun" },
    { 0x10D4E, "should_drop_scavenger_bag" },
    { 0x10D4F, "should_enter_combat_after_checking_decoy_grenade" },
    { 0x10D50, "should_enter_combat_after_checking_gas_grenade" },
    { 0x10D51, "should_enter_combat_after_checking_smoke_grenade" },
    { 0x10D52, "should_enter_combat_after_checking_snapshot_grenade" },
    { 0x10D53, "should_enter_combat_after_checking_throwingknife" },
    { 0x10D54, "should_give_grenades" },
    { 0x10D55, "should_hide_buried_mother_corpse" },
    { 0x10D56, "should_play_player_infil" },
    { 0x10D57, "should_run_sp_stealth" },
    { 0x10D58, "should_save_debug_info" },
    { 0x10D59, "should_show_icon" },
    { 0x10D5A, "should_skip_default_intro_scene" },
    { 0x10D5B, "should_skip_info_loop" },
    { 0x10D5C, "should_spawn_boss_one" },
    { 0x10D5D, "should_spawn_drones" },
    { 0x10D5E, "should_start_cautious_approach_hq" },
    { 0x10D5F, "should_start_cautious_approach_koth" },
    { 0x10D60, "should_take_damage" },
    { 0x10D61, "should_take_damage_from_trigger_hurt" },
    { 0x10D62, "should_update_track_timer" },
    { 0x10D63, "should_use_velo_forward" },
    { 0x10D64, "should_wait_before_spawn_chopper_boss" },
    { 0x10D65, "shouldbekilledoff" },
    { 0x10D66, "shouldblockdamage" },
    { 0x10D67, "shouldburnfromdamage" },
    { 0x10D68, "shouldcheckcustomclosetoscorelimit" },
    { 0x10D69, "shouldcrossbowhitmarker" },
    { 0x10D6A, "shoulddeleteimmediately" },
    { 0x10D6B, "shoulddonodedrop" },
    { 0x10D6C, "shoulddopublicevent" },
    { 0x10D6D, "shoulddropbrprimary" },
    { 0x10D6E, "shouldfinishshootinglongdeath" },
    { 0x10D6F, "shouldgamelobbyremainintact" },
    { 0x10D70, "shouldgetnewspawnpoint" },
    { 0x10D71, "shouldhumanspawntags" },
    { 0x10D72, "shouldlink" },
    { 0x10D73, "shouldmodelognotify" },
    { 0x10D74, "shouldmodeplayfinalmoments" },
    { 0x10D75, "shouldoperatorhideaccessoryworldmodel" },
    { 0x10D76, "shouldpickup" },
    { 0x10D77, "shouldplayerovertimedialog" },
    { 0x10D78, "shouldrecorddamagestats" },
    { 0x10D79, "shouldreflect" },
    { 0x10D7A, "shouldrespawn" },
    { 0x10D7B, "shouldspawndropscommon" },
    { 0x10D7C, "shouldspawnloot" },
    { 0x10D7D, "shouldxmike109hitmarker" },
    { 0x10D7E, "shouldzombiespawntags" },
    { 0x10D7F, "show_balloon_deploy_hint" },
    { 0x10D80, "show_balloon_purchase_hint" },
    { 0x10D81, "show_charge" },
    { 0x10D82, "show_deposit_hint" },
    { 0x10D83, "show_getcash_hint" },
    { 0x10D84, "show_headicon_to" },
    { 0x10D85, "show_hint_after_delay" },
    { 0x10D86, "show_label" },
    { 0x10D87, "show_marker_to_tv_station" },
    { 0x10D88, "show_on_minimap" },
    { 0x10D89, "show_player_clip" },
    { 0x10D8A, "show_players_breadcrumbs_to_safe_house" },
    { 0x10D8B, "show_plunderboxes" },
    { 0x10D8C, "show_regroup_text" },
    { 0x10D8D, "show_rocket_fuel_readings" },
    { 0x10D8E, "showassassinationtargethud" },
    { 0x10D8F, "showcashbag" },
    { 0x10D90, "showclosingmessage" },
    { 0x10D91, "showdangercircle" },
    { 0x10D92, "showdebugresult" },
    { 0x10D93, "showdiscountsplash" },
    { 0x10D94, "showdroplocations" },
    { 0x10D95, "showemergencyhint" },
    { 0x10D96, "showempminimap" },
    { 0x10D97, "showexfilstartsplash" },
    { 0x10D98, "showextractionobjectivetoteam" },
    { 0x10D99, "showextractiontime" },
    { 0x10D9A, "showhint" },
    { 0x10D9B, "showing_bomb_wire_pair_to_player" },
    { 0x10D9C, "showing_ui_record" },
    { 0x10D9D, "showintelinstancetoplayer" },
    { 0x10D9E, "showintelscriptablestoplayer" },
    { 0x10D9F, "showmapchyron" },
    { 0x10DA0, "showmaphinttilused" },
    { 0x10DA1, "shownonscriptableextracticons" },
    { 0x10DA2, "shownonspectatingwinnersplash" },
    { 0x10DA3, "showplacementsplashesandmusic" },
    { 0x10DA4, "showplayerlowermessagehint" },
    { 0x10DA5, "showplunderextracticonsinworld" },
    { 0x10DA6, "showquestcircletoall" },
    { 0x10DA7, "showquestcircletoplayer" },
    { 0x10DA8, "showquestobjicontoall" },
    { 0x10DA9, "showquestobjicontoplayer" },
    { 0x10DAA, "showrespawntimer" },
    { 0x10DAB, "showsafecircle" },
    { 0x10DAC, "showseasonalcontent" },
    { 0x10DAD, "showsplashtoall" },
    { 0x10DAE, "showsplashtoallexceptteam" },
    { 0x10DAF, "showtacmaphint" },
    { 0x10DB0, "showteamlittlebirds" },
    { 0x10DB1, "showteamtanks" },
    { 0x10DB2, "showtozombies" },
    { 0x10DB3, "showtutsplash" },
    { 0x10DB4, "shrink_poi" },
    { 0x10DB5, "shrink_poi_into_the_bank" },
    { 0x10DB6, "shut_down_laser_trap" },
    { 0x10DB7, "shut_down_station" },
    { 0x10DB8, "shutdownattractionicontrigger" },
    { 0x10DB9, "shutdowngulagforalivecount" },
    { 0x10DBA, "shuttingdown" },
    { 0x10DBB, "sidehouse_intel_sequence" },
    { 0x10DBC, "sidekillcount" },
    { 0x10DBD, "siege_bot_team_had_advantage" },
    { 0x10DBE, "siege_bot_team_triple_cap_check" },
    { 0x10DBF, "signal_nag" },
    { 0x10DC0, "signal_strength" },
    { 0x10DC1, "signal_yaw" },
    { 0x10DC2, "signalomnvar" },
    { 0x10DC3, "silencer_pick_up_monitor" },
    { 0x10DC4, "silo_door" },
    { 0x10DC5, "silo_door_clip" },
    { 0x10DC6, "silo_door_cover_jugg" },
    { 0x10DC7, "silo_door_cover_spawners" },
    { 0x10DC8, "silo_door_jugg" },
    { 0x10DC9, "silo_door_left" },
    { 0x10DCA, "silo_door_right" },
    { 0x10DCB, "silo_door_runners" },
    { 0x10DCC, "silo_jump_dogtag_revive" },
    { 0x10DCD, "silo_platforms" },
    { 0x10DCE, "silo_thrust_dogtag_revive" },
    { 0x10DCF, "silo_thrust_platforms" },
    { 0x10DD0, "single_loop" },
    { 0x10DD1, "site_axis_spawnfunc" },
    { 0x10DD2, "site_boss_spawn_think" },
    { 0x10DD3, "site_spawn_think" },
    { 0x10DD4, "sites" },
    { 0x10DD5, "siteused" },
    { 0x10DD6, "siteusedinternal" },
    { 0x10DD7, "sixthsense_inotherplayertargetcone" },
    { 0x10DD8, "sixthsense_playerseesotherplayer" },
    { 0x10DD9, "sixthsense_shouldwarnaboutotherplayer" },
    { 0x10DDA, "sixthsenselastvotime" },
    { 0x10DDB, "skip_basic_combat" },
    { 0x10DDC, "skip_charge_plant" },
    { 0x10DDD, "skip_default_intro_anim_scene" },
    { 0x10DDE, "skip_dko_check" },
    { 0x10DDF, "skip_forward_score_factor" },
    { 0x10DE0, "skip_going_to_alarm_or_nearest_cover" },
    { 0x10DE1, "skip_loadout_menu" },
    { 0x10DE2, "skip_navmesh_check" },
    { 0x10DE3, "skip_overheat" },
    { 0x10DE4, "skip_player_pos_memory" },
    { 0x10DE5, "skip_soldier_spawn" },
    { 0x10DE6, "skipburndown" },
    { 0x10DE7, "skipburndownforclass" },
    { 0x10DE8, "skipburndownforvehicle" },
    { 0x10DE9, "skipburndownhigh" },
    { 0x10DEA, "skipburndownlow" },
    { 0x10DEB, "skipburndownmedium" },
    { 0x10DEC, "skipcorpse" },
    { 0x10DED, "skipdeath" },
    { 0x10DEE, "skipdeathicon" },
    { 0x10DEF, "skipequipmentdropondeath" },
    { 0x10DF0, "skipequippedstreakcheck" },
    { 0x10DF1, "skipfinalkillcamfx" },
    { 0x10DF2, "skipfirstraise" },
    { 0x10DF3, "skipfriendlyfire" },
    { 0x10DF4, "skipignoredamage" },
    { 0x10DF5, "skipinfil" },
    { 0x10DF6, "skipleaderupdate" },
    { 0x10DF7, "skipplaybodycountsound" },
    { 0x10DF8, "skipprematch" },
    { 0x10DF9, "skipscriptable" },
    { 0x10DFA, "skipsplash" },
    { 0x10DFB, "skiptofound" },
    { 0x10DFC, "skipuavupdate" },
    { 0x10DFD, "skipweapondropondeath" },
    { 0x10DFE, "skydivehintnotify" },
    { 0x10DFF, "skydiveontacinsertplacement" },
    { 0x10E00, "skydivestreamhintdvars" },
    { 0x10E01, "slamcamoverlay" },
    { 0x10E02, "slide_airlock" },
    { 0x10E03, "slide_trig" },
    { 0x10E04, "slopelocked" },
    { 0x10E05, "smartwatchinteract" },
    { 0x10E06, "smeansofdeathshitloc" },
    { 0x10E07, "smodelcollections" },
    { 0x10E08, "smoke_door" },
    { 0x10E09, "smoke_emitter" },
    { 0x10E0A, "smoke_enemy_think" },
    { 0x10E0B, "smoke_init" },
    { 0x10E0C, "smoke_screen" },
    { 0x10E0D, "smoke_wheelson_chosen_spawn" },
    { 0x10E0E, "smokeglvfx" },
    { 0x10E0F, "smokekill" },
    { 0x10E10, "smokesignal" },
    { 0x10E11, "smokinggunclassindex" },
    { 0x10E12, "smokinggunprogress" },
    { 0x10E13, "smuggler_killed_early" },
    { 0x10E14, "smuggler_post_tele_kill" },
    { 0x10E15, "snapplayertotoppos" },
    { 0x10E16, "snappointtooutofboundstriggertrace" },
    { 0x10E17, "snapshot_crate_player_at_max_ammo" },
    { 0x10E18, "snapshot_crate_spawn" },
    { 0x10E19, "snapshot_crate_use" },
    { 0x10E1A, "snapshot_grenade_applysnapshot" },
    { 0x10E1B, "snapshot_grenade_createoutlinedata" },
    { 0x10E1C, "sniper_death_watcher" },
    { 0x10E1D, "sniper_init" },
    { 0x10E1E, "sniper_laser_is_on" },
    { 0x10E1F, "sniper_laser_should_turn_on" },
    { 0x10E20, "sniper_laser_vfx" },
    { 0x10E21, "snowballfight" },
    { 0x10E22, "snowballfighthint" },
    { 0x10E23, "snowballmeleewatcher" },
    { 0x10E24, "snowfx" },
    { 0x10E25, "so_displaygameend" },
    { 0x10E26, "so_endgame" },
    { 0x10E27, "so_forceendgame" },
    { 0x10E28, "so_get_played_time" },
    { 0x10E29, "so_getstarinfo" },
    { 0x10E2A, "so_outcomenotify" },
    { 0x10E2B, "so_postmatchfx" },
    { 0x10E2C, "so_setplayerdata" },
    { 0x10E2D, "so_try_restart" },
    { 0x10E2E, "sol_1_pool" },
    { 0x10E2F, "sol_2_pool" },
    { 0x10E30, "sol_3_4_pool" },
    { 0x10E31, "sol_5_6_pool" },
    { 0x10E32, "soldier_agent_lwfn0" },
    { 0x10E33, "soldier_agent_lwfn1" },
    { 0x10E34, "soldier_agent_lwfn2" },
    { 0x10E35, "soldier_agent_lwfn3" },
    { 0x10E36, "soldier_agent_lwfn4" },
    { 0x10E37, "soldier_agent_lwfn5" },
    { 0x10E38, "soldier_agent_lwfn6" },
    { 0x10E39, "soldier_agent_lwfn7" },
    { 0x10E3A, "soldier_agent_lwfn8" },
    { 0x10E3B, "soldier_agent_lwfn9" },
    { 0x10E3C, "soldier_encounter_test" },
    { 0x10E3D, "sololink" },
    { 0x10E3E, "solospawn" },
    { 0x10E3F, "solution_exists_already" },
    { 0x10E40, "solutions" },
    { 0x10E41, "solved" },
    { 0x10E42, "sort_by_ai_assigned" },
    { 0x10E43, "sort_goal_positions_by_priority" },
    { 0x10E44, "sort_wave_spawning_ai" },
    { 0x10E45, "sortbyhvttags" },
    { 0x10E46, "sortbylastzombietime" },
    { 0x10E47, "sortplayerplunderscores" },
    { 0x10E48, "sortsitesbydistance" },
    { 0x10E49, "sortvalue" },
    { 0x10E4A, "sound_distraction_mechanic_init" },
    { 0x10E4B, "sound_ent" },
    { 0x10E4C, "sound_events" },
    { 0x10E4D, "sounddebouncetimestamp" },
    { 0x10E4E, "soundorg_int" },
    { 0x10E4F, "source" },
    { 0x10E50, "sp_stealth_broken_listener" },
    { 0x10E51, "spawn_acceleration" },
    { 0x10E52, "spawn_additional_covernode" },
    { 0x10E53, "spawn_addtoarrays" },
    { 0x10E54, "spawn_ai_and_seat_in_vehicle" },
    { 0x10E55, "spawn_ai_func_ref" },
    { 0x10E56, "spawn_ai_group" },
    { 0x10E57, "spawn_ai_individual" },
    { 0x10E58, "spawn_ai_single" },
    { 0x10E59, "spawn_ai_solo" },
    { 0x10E5A, "spawn_aitype" },
    { 0x10E5B, "spawn_all_unique_drones" },
    { 0x10E5C, "spawn_allies_at_defend" },
    { 0x10E5D, "spawn_and_enter_cargo_truck_mg" },
    { 0x10E5E, "spawn_and_enter_little_bird_mg" },
    { 0x10E5F, "spawn_and_hide_usb" },
    { 0x10E60, "spawn_another_group_and_run_regular_death" },
    { 0x10E61, "spawn_apache_chopper" },
    { 0x10E62, "spawn_assault2_extras" },
    { 0x10E63, "spawn_atmines" },
    { 0x10E64, "spawn_backup_helispawner_jammer2" },
    { 0x10E65, "spawn_bomb" },
    { 0x10E66, "spawn_bomb_hostage" },
    { 0x10E67, "spawn_bombers_after_plant" },
    { 0x10E68, "spawn_boss_wave_1" },
    { 0x10E69, "spawn_boss_wave_2" },
    { 0x10E6A, "spawn_boss_wave_3" },
    { 0x10E6B, "spawn_boss_wave_section" },
    { 0x10E6C, "spawn_boss_wave_suicidebombers" },
    { 0x10E6D, "spawn_boxes" },
    { 0x10E6E, "spawn_cache4_rpgs" },
    { 0x10E6F, "spawn_caches_tank" },
    { 0x10E70, "spawn_carepackage" },
    { 0x10E71, "spawn_carriable_at_struct" },
    { 0x10E72, "spawn_carriables_from_prefabs_all" },
    { 0x10E73, "spawn_carriables_from_prefabs_min_max" },
    { 0x10E74, "spawn_carriables_from_prefabs_percentage" },
    { 0x10E75, "spawn_carriables_from_scriptables_individual_percentage" },
    { 0x10E76, "spawn_carriables_from_scriptables_percentage" },
    { 0x10E77, "spawn_carriables_from_scriptables_total_percentage" },
    { 0x10E78, "spawn_carried_punchcard_if_player_down" },
    { 0x10E79, "spawn_chopper_carepackage" },
    { 0x10E7A, "spawn_claymore_group" },
    { 0x10E7B, "spawn_collision" },
    { 0x10E7C, "spawn_compound_final_push" },
    { 0x10E7D, "spawn_convoy_and_move" },
    { 0x10E7E, "spawn_corpse_hiders" },
    { 0x10E7F, "spawn_cover_nodes" },
    { 0x10E80, "spawn_crew" },
    { 0x10E81, "spawn_custom_type" },
    { 0x10E82, "spawn_custom_type_array" },
    { 0x10E83, "spawn_cypher_monitor_model" },
    { 0x10E84, "spawn_deceleration" },
    { 0x10E85, "spawn_default_player_spawns" },
    { 0x10E86, "spawn_dogtags" },
    { 0x10E87, "spawn_double_cargo" },
    { 0x10E88, "spawn_downed_friendly" },
    { 0x10E89, "spawn_drones" },
    { 0x10E8A, "spawn_dummy_crate" },
    { 0x10E8B, "spawn_dwn_twn_enemy_sentry" },
    { 0x10E8C, "spawn_elevator_gate" },
    { 0x10E8D, "spawn_elevators" },
    { 0x10E8E, "spawn_ending_individual_guys" },
    { 0x10E8F, "spawn_ending_individual_guys_death" },
    { 0x10E90, "spawn_enemies_intro" },
    { 0x10E91, "spawn_enemy_claymore" },
    { 0x10E92, "spawn_enemy_drone_turret" },
    { 0x10E93, "spawn_enemy_juggernaut_single" },
    { 0x10E94, "spawn_entity_carriable" },
    { 0x10E95, "spawn_exfil_chopper" },
    { 0x10E96, "spawn_exfil_enemies" },
    { 0x10E97, "spawn_exfil_heli" },
    { 0x10E98, "spawn_exfil_heli_and_rpgs" },
    { 0x10E99, "spawn_exfil_juggs" },
    { 0x10E9A, "spawn_exfil_paratroopers" },
    { 0x10E9B, "spawn_exfil_techo" },
    { 0x10E9C, "spawn_fake_digit_pool" },
    { 0x10E9D, "spawn_fake_letter" },
    { 0x10E9E, "spawn_fake_number" },
    { 0x10E9F, "spawn_field_ai_manager_middle" },
    { 0x10EA0, "spawn_field_ai_manager_wall" },
    { 0x10EA1, "spawn_finale_wave" },
    { 0x10EA2, "spawn_first_leads_early" },
    { 0x10EA3, "spawn_fulton_ac130_mdl" },
    { 0x10EA4, "spawn_fulton_rope_mdl" },
    { 0x10EA5, "spawn_fx_on_node" },
    { 0x10EA6, "spawn_gate_guards" },
    { 0x10EA7, "spawn_geos" },
    { 0x10EA8, "spawn_group_in_safe_region" },
    { 0x10EA9, "spawn_guys_at_lz" },
    { 0x10EAA, "spawn_guys_into_truck" },
    { 0x10EAB, "spawn_headicon" },
    { 0x10EAC, "spawn_heli_assault2" },
    { 0x10EAD, "spawn_heli_assault3_fob2" },
    { 0x10EAE, "spawn_heli_assault3_hangar" },
    { 0x10EAF, "spawn_heli_assault3_hangar_end" },
    { 0x10EB0, "spawn_helicoper_enemy" },
    { 0x10EB1, "spawn_in_fake_skyhookmodels" },
    { 0x10EB2, "spawn_individual_guys_at_pos" },
    { 0x10EB3, "spawn_infil_lbravo" },
    { 0x10EB4, "spawn_jugg_assault2" },
    { 0x10EB5, "spawn_jugg_backup_trigger" },
    { 0x10EB6, "spawn_jugg_with_objective" },
    { 0x10EB7, "spawn_juggernauts" },
    { 0x10EB8, "spawn_juggernauts_fob" },
    { 0x10EB9, "spawn_juggernauts_hangar" },
    { 0x10EBA, "spawn_killstreak_package_on_ground" },
    { 0x10EBB, "spawn_lbravo" },
    { 0x10EBC, "spawn_little_bird_mg_at_location" },
    { 0x10EBD, "spawn_lmg_soldiers_01" },
    { 0x10EBE, "spawn_lmg_soldiers_02" },
    { 0x10EBF, "spawn_lmg_soldiers_03" },
    { 0x10EC0, "spawn_lmg_soldiers_04" },
    { 0x10EC1, "spawn_lmg_soldiers_05" },
    { 0x10EC2, "spawn_loot_pickups" },
    { 0x10EC3, "spawn_lootcrates_on_each_traincar" },
    { 0x10EC4, "spawn_lot_paratroopers" },
    { 0x10EC5, "spawn_maint_wave" },
    { 0x10EC6, "spawn_maint_wave_1" },
    { 0x10EC7, "spawn_maint_wave_2" },
    { 0x10EC8, "spawn_manual_turret" },
    { 0x10EC9, "spawn_mindia_juggs" },
    { 0x10ECA, "spawn_ml_p1_sentries" },
    { 0x10ECB, "spawn_ml_p2_player_heli" },
    { 0x10ECC, "spawn_ml_p2_sentries" },
    { 0x10ECD, "spawn_module_building_chopper1" },
    { 0x10ECE, "spawn_module_building_chopper2" },
    { 0x10ECF, "spawn_module_intro2b" },
    { 0x10ED0, "spawn_module_intro3" },
    { 0x10ED1, "spawn_module_intro4" },
    { 0x10ED2, "spawn_module_lmg_1" },
    { 0x10ED3, "spawn_module_lmg_2" },
    { 0x10ED4, "spawn_module_lmg_3" },
    { 0x10ED5, "spawn_module_lmg_4" },
    { 0x10ED6, "spawn_module_lmg_5" },
    { 0x10ED7, "spawn_module_p3_form_a" },
    { 0x10ED8, "spawn_module_p3_form_b" },
    { 0x10ED9, "spawn_module_p3_form_c" },
    { 0x10EDA, "spawn_module_p3_form_d" },
    { 0x10EDB, "spawn_module_soldiers1" },
    { 0x10EDC, "spawn_module_trickle" },
    { 0x10EDD, "spawn_new_digits" },
    { 0x10EDE, "spawn_new_ents" },
    { 0x10EDF, "spawn_obit_model" },
    { 0x10EE0, "spawn_obit_struct" },
    { 0x10EE1, "spawn_objective" },
    { 0x10EE2, "spawn_origin" },
    { 0x10EE3, "spawn_overwatch_extra_atvs" },
    { 0x10EE4, "spawn_overwatch_final_tank" },
    { 0x10EE5, "spawn_overwatch_soldiers_01" },
    { 0x10EE6, "spawn_para_and_heli_logic" },
    { 0x10EE7, "spawn_paratrooper_ac130" },
    { 0x10EE8, "spawn_parking_guys" },
    { 0x10EE9, "spawn_pavelow_boss" },
    { 0x10EEA, "spawn_pickup_weapon" },
    { 0x10EEB, "spawn_player_vehicle" },
    { 0x10EEC, "spawn_queue_think" },
    { 0x10EED, "spawn_race_dogtags" },
    { 0x10EEE, "spawn_real_letter" },
    { 0x10EEF, "spawn_real_number" },
    { 0x10EF0, "spawn_reinforcement_group" },
    { 0x10EF1, "spawn_remote_tank_thermite" },
    { 0x10EF2, "spawn_removefromarrays" },
    { 0x10EF3, "spawn_riders_and_play_intro_idle_anim" },
    { 0x10EF4, "spawn_router_model" },
    { 0x10EF5, "spawn_rpgs_for_players" },
    { 0x10EF6, "spawn_script_model" },
    { 0x10EF7, "spawn_script_model_driver_and_passengers" },
    { 0x10EF8, "spawn_sentries_from_targetname" },
    { 0x10EF9, "spawn_sentry_at_pos" },
    { 0x10EFA, "spawn_set_jugg_value" },
    { 0x10EFB, "spawn_silo_door_ai" },
    { 0x10EFC, "spawn_single_cargo" },
    { 0x10EFD, "spawn_size" },
    { 0x10EFE, "spawn_smoke_bombers" },
    { 0x10EFF, "spawn_snipers_assault3" },
    { 0x10F00, "spawn_soldiers" },
    { 0x10F01, "spawn_soldiers_in_convoy_truck" },
    { 0x10F02, "spawn_spawners_multi" },
    { 0x10F03, "spawn_speed" },
    { 0x10F04, "spawn_tac_rovers" },
    { 0x10F05, "spawn_tacrovers" },
    { 0x10F06, "spawn_techo_lmgs" },
    { 0x10F07, "spawn_techo_turret" },
    { 0x10F08, "spawn_techo_turret_2" },
    { 0x10F09, "spawn_transition_camera" },
    { 0x10F0A, "spawn_trap_room_ent" },
    { 0x10F0B, "spawn_truck_group_on_proximity" },
    { 0x10F0C, "spawn_truck_techo" },
    { 0x10F0D, "spawn_trucks" },
    { 0x10F0E, "spawn_tugofwar_tank" },
    { 0x10F0F, "spawn_tut_loot" },
    { 0x10F10, "spawn_unique_drone" },
    { 0x10F11, "spawn_vehicles" },
    { 0x10F12, "spawn_vindia_assault3" },
    { 0x10F13, "spawn_vo_lines" },
    { 0x10F14, "spawn_vo_playing" },
    { 0x10F15, "spawn_weapon" },
    { 0x10F16, "spawn_weapon_box_cache" },
    { 0x10F17, "spawn_weapons_by_player_count" },
    { 0x10F18, "spawn_wheelson_blinking_lights" },
    { 0x10F19, "spawn_wheelson_redroom" },
    { 0x10F1A, "spawn_wheelsons" },
    { 0x10F1B, "spawn_wp" },
    { 0x10F1C, "spawnaccesscards" },
    { 0x10F1D, "spawnangle" },
    { 0x10F1E, "spawnanglemax" },
    { 0x10F1F, "spawnanglemin" },
    { 0x10F20, "spawnapachechopper" },
    { 0x10F21, "spawnballooncash" },
    { 0x10F22, "spawnboardroom_auav" },
    { 0x10F23, "spawnboardroom_gasmask" },
    { 0x10F24, "spawnboardroom_juggdrop" },
    { 0x10F25, "spawnboardroom_loadoutdrop" },
    { 0x10F26, "spawnboardroom_miniguns" },
    { 0x10F27, "spawnboardroom_specialist" },
    { 0x10F28, "spawnboardroomblueprintweapons" },
    { 0x10F29, "spawnbunkerloot" },
    { 0x10F2A, "spawnc130pathstructnewinternal" },
    { 0x10F2B, "spawnchoppers" },
    { 0x10F2C, "spawnclientdevtest" },
    { 0x10F2D, "spawncorpsehider" },
    { 0x10F2E, "spawncrossbowbolt" },
    { 0x10F2F, "spawndangertriggers" },
    { 0x10F30, "spawndistancemax" },
    { 0x10F31, "spawndistancemin" },
    { 0x10F32, "spawndogtagtoken" },
    { 0x10F33, "spawndomplateflag" },
    { 0x10F34, "spawndomplateflagtestmap" },
    { 0x10F35, "spawndomplates" },
    { 0x10F36, "spawndragonsbreathstruct" },
    { 0x10F37, "spawndropbagatposition" },
    { 0x10F38, "spawndropbagsovertime" },
    { 0x10F39, "spawned_warp_traversethink" },
    { 0x10F3A, "spawnedasspectator" },
    { 0x10F3B, "spawnedonce" },
    { 0x10F3C, "spawner_debug_model" },
    { 0x10F3D, "spawner_dropoff" },
    { 0x10F3E, "spawner_invalid_due_to_recently_used" },
    { 0x10F3F, "spawner_poison_structs" },
    { 0x10F40, "spawner_recently_used" },
    { 0x10F41, "spawner_scoring_allow_early_out" },
    { 0x10F42, "spawnerindex" },
    { 0x10F43, "spawnexfilchopper" },
    { 0x10F44, "spawnextractsmoke" },
    { 0x10F45, "spawnfakepistol" },
    { 0x10F46, "spawnflags_check" },
    { 0x10F47, "spawnglobalscriptabledelayed" },
    { 0x10F48, "spawnhandled" },
    { 0x10F49, "spawnheight" },
    { 0x10F4A, "spawnheliactorsfunc" },
    { 0x10F4B, "spawnhumandogtags" },
    { 0x10F4C, "spawninfluencepoints" },
    { 0x10F4D, "spawninfo" },
    { 0x10F4E, "spawninsafehouse" },
    { 0x10F4F, "spawnintermission_nocam" },
    { 0x10F50, "spawnintermissionatplayer" },
    { 0x10F51, "spawnjuggernautcrateatposition" },
    { 0x10F52, "spawnloot" },
    { 0x10F53, "spawnoffsettacinsertmax" },
    { 0x10F54, "spawnoffsettacinsertmin" },
    { 0x10F55, "spawnoutofboundstrigger" },
    { 0x10F56, "spawnpoint_clearspawnpoint" },
    { 0x10F57, "spawnpoint_is_within_sight" },
    { 0x10F58, "spawnpoint_setspawnpoint" },
    { 0x10F59, "spawnpointangles" },
    { 0x10F5A, "spawnpointdanger" },
    { 0x10F5B, "spawnpointdangertime" },
    { 0x10F5C, "spawnposition" },
    { 0x10F5D, "spawnprojectile" },
    { 0x10F5E, "spawnproplist" },
    { 0x10F5F, "spawnprotectionexception" },
    { 0x10F60, "spawnregions" },
    { 0x10F61, "spawnrisktoken" },
    { 0x10F62, "spawnrope" },
    { 0x10F63, "spawnropeandbag" },
    { 0x10F64, "spawnscavengerlootcache" },
    { 0x10F65, "spawnsecretstashlootcache" },
    { 0x10F66, "spawnselectionafktime" },
    { 0x10F67, "spawnselectionmarker" },
    { 0x10F68, "spawnsystem_init" },
    { 0x10F69, "spawntimestamp" },
    { 0x10F6A, "spawntvfix" },
    { 0x10F6B, "spawnuniqueboardroomloot" },
    { 0x10F6C, "spawnvector" },
    { 0x10F6D, "spawnvehicles" },
    { 0x10F6E, "spawnwalltriggers" },
    { 0x10F6F, "spawnx1stashlootcache" },
    { 0x10F70, "spawnziptie" },
    { 0x10F71, "spawnzombiedogtags" },
    { 0x10F72, "specialdayloadouts" },
    { 0x10F73, "specialistbr" },
    { 0x10F74, "specialistperk" },
    { 0x10F75, "spectatableprops" },
    { 0x10F76, "spectate3rdallowed" },
    { 0x10F77, "spectatecommands" },
    { 0x10F78, "spectatekey" },
    { 0x10F79, "spectatenumber" },
    { 0x10F7A, "spectatepoint" },
    { 0x10F7B, "spectateprop" },
    { 0x10F7C, "spectatetestonprematchfadedone" },
    { 0x10F7D, "spectatingthisplayer" },
    { 0x10F7E, "spin_fan_blades" },
    { 0x10F7F, "spin_light" },
    { 0x10F80, "spinafterdelay" },
    { 0x10F81, "spinning" },
    { 0x10F82, "spinpropkey" },
    { 0x10F83, "splashtime_drops" },
    { 0x10F84, "splashtime_helis" },
    { 0x10F85, "splashtime_lzs" },
    { 0x10F86, "splashtime_vip" },
    { 0x10F87, "spot_light_nodes" },
    { 0x10F88, "spotlight_angles_offset" },
    { 0x10F89, "spotlight_goal_node" },
    { 0x10F8A, "spotlight_max_dist_sq_from_node" },
    { 0x10F8B, "spotlight_min_dist_sq_from_node" },
    { 0x10F8C, "spotlight_model" },
    { 0x10F8D, "spotlight_movement_think" },
    { 0x10F8E, "spotlight_origin_offset" },
    { 0x10F8F, "spotlight_reach_goal_node_dist_sq" },
    { 0x10F90, "spotlight_speed" },
    { 0x10F91, "spotlight_sweep_to_loc" },
    { 0x10F92, "spotlight_sweep_to_loc_safe" },
    { 0x10F93, "spotlight_tag" },
    { 0x10F94, "spotlight_target_found_dist_sq" },
    { 0x10F95, "spotlight_target_found_speed" },
    { 0x10F96, "spotlight_turret_info" },
    { 0x10F97, "spotlights" },
    { 0x10F98, "spotlimit" },
    { 0x10F99, "spoutfx" },
    { 0x10F9A, "sprayed" },
    { 0x10F9B, "sprayid" },
    { 0x10F9C, "spreadshotdamagemod" },
    { 0x10F9D, "sprint_hint" },
    { 0x10F9E, "sq_entergulag" },
    { 0x10F9F, "sq_movequestlocale" },
    { 0x10FA0, "sq_ontimerexpired" },
    { 0x10FA1, "sq_playerdisconnect" },
    { 0x10FA2, "sq_respawn" },
    { 0x10FA3, "sqtablet_init" },
    { 0x10FA4, "squadleaderbeacon_circleorigin" },
    { 0x10FA5, "squadleaderbeacon_circleradius" },
    { 0x10FA6, "squadleaderbeacon_fxent" },
    { 0x10FA7, "squadleaderbeacon_isactive" },
    { 0x10FA8, "squadlink_outline_id" },
    { 0x10FA9, "squadlink_wid" },
    { 0x10FAA, "squadspawndebug" },
    { 0x10FAB, "squadwiped" },
    { 0x10FAC, "sr_next_ammo_restock_time" },
    { 0x10FAD, "ss_circletick" },
    { 0x10FAE, "ss_entergulag" },
    { 0x10FAF, "ss_ontimerexpired" },
    { 0x10FB0, "ss_playerdisconnect" },
    { 0x10FB1, "ss_removequestinstance" },
    { 0x10FB2, "ss_respawn" },
    { 0x10FB3, "sstablet_init" },
    { 0x10FB4, "stab_blink_black_fade" },
    { 0x10FB5, "stack_patch_thread" },
    { 0x10FB6, "stack_patch_thread_leaf" },
    { 0x10FB7, "stack_patch_thread_node" },
    { 0x10FB8, "stack_patch_thread_root" },
    { 0x10FB9, "stack_patch_waittill_context" },
    { 0x10FBA, "stack_patch_waittill_context_far" },
    { 0x10FBB, "stack_patch_waittill_context_far_patch" },
    { 0x10FBC, "stack_patch_waittill_context_patch" },
    { 0x10FBD, "stack_patch_waittill_leaf" },
    { 0x10FBE, "stack_patch_waittill_node" },
    { 0x10FBF, "stack_patch_waittill_root" },
    { 0x10FC0, "stack_patch_waittill_stack" },
    { 0x10FC1, "stadium_one_death_func" },
    { 0x10FC2, "stadium_puzzle" },
    { 0x10FC3, "stadium_three_death_func" },
    { 0x10FC4, "stadium_two_death_func" },
    { 0x10FC5, "stadiumpuzzleactive" },
    { 0x10FC6, "stage" },
    { 0x10FC7, "stage1accradius" },
    { 0x10FC8, "stage2accradius" },
    { 0x10FC9, "stage3accradius" },
    { 0x10FCA, "standard_health" },
    { 0x10FCB, "starcount" },
    { 0x10FCC, "starscores" },
    { 0x10FCD, "start_airfield_safehouse" },
    { 0x10FCE, "start_anim_train_scene" },
    { 0x10FCF, "start_area_fx" },
    { 0x10FD0, "start_area_fx_end" },
    { 0x10FD1, "start_authentication_timer" },
    { 0x10FD2, "start_bomb_vest_defusal" },
    { 0x10FD3, "start_bomb_vest_defusal_sequence" },
    { 0x10FD4, "start_bomb_vest_global_timer" },
    { 0x10FD5, "start_box_set_up" },
    { 0x10FD6, "start_chants_on_movement" },
    { 0x10FD7, "start_chopper_boss" },
    { 0x10FD8, "start_conceal_add" },
    { 0x10FD9, "start_coop_bomb_case_defusal" },
    { 0x10FDA, "start_coop_defuse_infiltrate" },
    { 0x10FDB, "start_coop_escape" },
    { 0x10FDC, "start_coop_escape_end_camera" },
    { 0x10FDD, "start_coop_escape_safehouse" },
    { 0x10FDE, "start_coop_escort_enter_vehicles" },
    { 0x10FDF, "start_coop_escort_protect_hvi" },
    { 0x10FE0, "start_countdown_till_sequence_is_cleared" },
    { 0x10FE1, "start_death_from_above_sequence" },
    { 0x10FE2, "start_drones_event" },
    { 0x10FE3, "start_end_breach_fx" },
    { 0x10FE4, "start_escape_silo" },
    { 0x10FE5, "start_eye_barkov" },
    { 0x10FE6, "start_firing_minigun" },
    { 0x10FE7, "start_fly_over" },
    { 0x10FE8, "start_freight_lift" },
    { 0x10FE9, "start_game_end_timer" },
    { 0x10FEA, "start_gas_sequence" },
    { 0x10FEB, "start_gates" },
    { 0x10FEC, "start_hack" },
    { 0x10FED, "start_hack_console" },
    { 0x10FEE, "start_intro" },
    { 0x10FEF, "start_intro_obj" },
    { 0x10FF0, "start_jugg_maze" },
    { 0x10FF1, "start_lap_time" },
    { 0x10FF2, "start_leave_cave" },
    { 0x10FF3, "start_link_logic_on_players" },
    { 0x10FF4, "start_loc" },
    { 0x10FF5, "start_marquee" },
    { 0x10FF6, "start_mine_caves" },
    { 0x10FF7, "start_ml_p3_exfil" },
    { 0x10FF8, "start_mode_after_playerspawn" },
    { 0x10FF9, "start_nuke_vault" },
    { 0x10FFA, "start_periodic_jugg_pulses" },
    { 0x10FFB, "start_persistent_turbulence" },
    { 0x10FFC, "start_pipe_room" },
    { 0x10FFD, "start_pipe_room_menu" },
    { 0x10FFE, "start_player_links" },
    { 0x10FFF, "start_preserverroom_spawners" },
    { 0x11000, "start_puzzle" },
    { 0x11001, "start_race_countdown" },
    { 0x11002, "start_reach_exhaust_waste" },
    { 0x11003, "start_reach_icbm_launch" },
    { 0x11004, "start_reach_pipe_room" },
    { 0x11005, "start_reach_wind_room" },
    { 0x11006, "start_safehouse_gunshop" },
    { 0x11007, "start_safehouse_quarry" },
    { 0x11008, "start_safehouse_regroup" },
    { 0x11009, "start_safehouse_regroup_objective" },
    { 0x1100A, "start_safehouse_restart" },
    { 0x1100B, "start_safehouse_return" },
    { 0x1100C, "start_silo_elevator" },
    { 0x1100D, "start_silo_elevator_menu" },
    { 0x1100E, "start_silo_jump" },
    { 0x1100F, "start_silo_jump_menu" },
    { 0x11010, "start_silo_thrust" },
    { 0x11011, "start_silo_thrust_menu" },
    { 0x11012, "start_smoke_door_fx" },
    { 0x11013, "start_solution_check_timer" },
    { 0x11014, "start_spawn_camera" },
    { 0x11015, "start_spawn_modules" },
    { 0x11016, "start_static_klaxon_lights" },
    { 0x11017, "start_static_plane_lights" },
    { 0x11018, "start_swivelroom_obj" },
    { 0x11019, "start_target_move_loop" },
    { 0x1101A, "start_timed_event_on_detection" },
    { 0x1101B, "start_timer" },
    { 0x1101C, "start_trans_1_obj" },
    { 0x1101D, "start_trap_room" },
    { 0x1101E, "start_trap_room_combat" },
    { 0x1101F, "start_trap_timer" },
    { 0x11020, "start_unlock_silo" },
    { 0x11021, "start_unstable_rocket_fuel_timer" },
    { 0x11022, "start_vault_assault_retrieve_saw" },
    { 0x11023, "start_waypoint" },
    { 0x11024, "start_whack_a_mole_sequence" },
    { 0x11025, "start_whack_a_mole_timer" },
    { 0x11026, "start_with_nvgs" },
    { 0x11027, "startarmoryswitchbeeping" },
    { 0x11028, "startarmsraceapproachobj" },
    { 0x11029, "startarmsracedef1obj" },
    { 0x1102A, "startarmsracedef2obj" },
    { 0x1102B, "startarmsracedef3obj" },
    { 0x1102C, "startarmsracedef4obj" },
    { 0x1102D, "startarmsraceopencrateobj" },
    { 0x1102E, "startbluntwatchvfx" },
    { 0x1102F, "startbmoexfilprocess" },
    { 0x11030, "startchallengetimer" },
    { 0x11031, "startcheck" },
    { 0x11032, "startdeadsilence" },
    { 0x11033, "startdeliveries" },
    { 0x11034, "startdisabled" },
    { 0x11035, "started_breach_process" },
    { 0x11036, "startenemyhelis" },
    { 0x11037, "startexfilchoppers" },
    { 0x11038, "startfightvo" },
    { 0x11039, "startfontscale" },
    { 0x1103A, "starthacktimer" },
    { 0x1103B, "startholowatchvfx" },
    { 0x1103C, "startimes" },
    { 0x1103D, "starting_area_init" },
    { 0x1103E, "starting_boxes" },
    { 0x1103F, "starting_struct" },
    { 0x11040, "starting_trigger_fix" },
    { 0x11041, "startingcodephone" },
    { 0x11042, "startingteamcount" },
    { 0x11043, "startjuggdelivery" },
    { 0x11044, "startlastsurvivorsuavsweep" },
    { 0x11045, "startmatchobjectiveicons" },
    { 0x11046, "startofxptime" },
    { 0x11047, "startpayloadexfilobjective" },
    { 0x11048, "startpayloadpunish" },
    { 0x11049, "startpayloadreturnobj" },
    { 0x1104A, "startpayloadtanksobjective" },
    { 0x1104B, "startplayer" },
    { 0x1104C, "startplunderextractiontimers" },
    { 0x1104D, "startpropcirclelogic" },
    { 0x1104E, "startptui" },
    { 0x1104F, "startstruct" },
    { 0x11050, "startteamcontractchallenge" },
    { 0x11051, "starttmtylapproach" },
    { 0x11052, "startusbanim" },
    { 0x11053, "startuseweapon" },
    { 0x11054, "startusingbomb" },
    { 0x11055, "startvipteamuav" },
    { 0x11056, "staticcircle" },
    { 0x11057, "staticmodelid" },
    { 0x11058, "station_name_chosen_as_starting" },
    { 0x11059, "station_names" },
    { 0x1105A, "stay_on_roof_until_bothered" },
    { 0x1105B, "stay_on_roof_until_bothered_internal" },
    { 0x1105C, "stayfrosty" },
    { 0x1105D, "staytoasty" },
    { 0x1105E, "stealth_alert_music" },
    { 0x1105F, "stealth_alert_music_index" },
    { 0x11060, "stealth_broken_music" },
    { 0x11061, "stealth_broken_music_index" },
    { 0x11062, "stealth_enabled" },
    { 0x11063, "stealthtimeelapsed" },
    { 0x11064, "steam_damage_player" },
    { 0x11065, "steam_damage_players" },
    { 0x11066, "steam_damaged" },
    { 0x11067, "steam_dmg_trigger_think" },
    { 0x11068, "steam_fx_off" },
    { 0x11069, "steam_fx_on" },
    { 0x1106A, "steam_point_think" },
    { 0x1106B, "steam_trigger" },
    { 0x1106C, "steam_trigger_think" },
    { 0x1106D, "steam_valve_think" },
    { 0x1106E, "stepstructsproximity" },
    { 0x1106F, "steve" },
    { 0x11070, "stickers" },
    { 0x11071, "stillalivexp" },
    { 0x11072, "stim_crate_update_hint_logic" },
    { 0x11073, "stim_crate_use_alt" },
    { 0x11074, "stimmodelattached" },
    { 0x11075, "stompeenemyprogressupdate" },
    { 0x11076, "stop_all_ascend_anims" },
    { 0x11077, "stop_clear_players_from_door_way_think" },
    { 0x11078, "stop_counter_beep_sfx_on_bomb_vests" },
    { 0x11079, "stop_end_breach_fx" },
    { 0x1107A, "stop_eye_barkov" },
    { 0x1107B, "stop_firing_minigun" },
    { 0x1107C, "stop_hotjoining" },
    { 0x1107D, "stop_module_on_delay" },
    { 0x1107E, "stop_passedby_once" },
    { 0x1107F, "stop_player_trigger_monitor" },
    { 0x11080, "stop_players_inside_death_or_disconnect_monitor" },
    { 0x11081, "stop_pressure_sensor" },
    { 0x11082, "stop_priming_gesture" },
    { 0x11083, "stop_restock_recharge" },
    { 0x11084, "stop_rpg_guys" },
    { 0x11085, "stop_spawn_modules" },
    { 0x11086, "stop_station_closed_vo" },
    { 0x11087, "stop_strafe_minigun_manager" },
    { 0x11088, "stop_turbulence_just_before_the_end" },
    { 0x11089, "stop_vehicle_on_pilot_death" },
    { 0x1108A, "stop_visited_once" },
    { 0x1108B, "stop_wave" },
    { 0x1108C, "stop_wave_section" },
    { 0x1108D, "stop_with_front_truck" },
    { 0x1108E, "stoparmorinsert" },
    { 0x1108F, "stopchallengetimer" },
    { 0x11090, "stopchallengetimers" },
    { 0x11091, "stopcirclesatgameend" },
    { 0x11092, "stopdragonsbreath" },
    { 0x11093, "stopdragonsbreathburning" },
    { 0x11094, "stopimmediately" },
    { 0x11095, "stopinteract" },
    { 0x11096, "stoppingpower_clearhcrdata" },
    { 0x11097, "stoppingpower_clearhcrongameended" },
    { 0x11098, "stoppingpower_clearhcronperkscleared" },
    { 0x11099, "stoppingpower_getweaponhcrdata" },
    { 0x1109A, "stoppingpower_givehcrdata" },
    { 0x1109B, "stoppingpower_init" },
    { 0x1109C, "stoppingpower_ishcrweapon" },
    { 0x1109D, "stoppingpower_isvalidprimaryoralt" },
    { 0x1109E, "stoppingpower_loadoutchangeremovehcr" },
    { 0x1109F, "stoppingpower_onkill" },
    { 0x110A0, "stoppingpower_onweaponcreated" },
    { 0x110A1, "stoppingpower_onweaponpickedup" },
    { 0x110A2, "stoppingpower_tracklastcrossbowshot" },
    { 0x110A3, "stoppingpower_waitforreload" },
    { 0x110A4, "stoppingpower_watchhcrammodrain" },
    { 0x110A5, "stoppingpowercanonehitkill" },
    { 0x110A6, "stopstreamtomovingplane" },
    { 0x110A7, "stopusingbomb" },
    { 0x110A8, "store_platform_models" },
    { 0x110A9, "str" },
    { 0x110AA, "strafe" },
    { 0x110AB, "strafe_acceleration" },
    { 0x110AC, "strafe_internal" },
    { 0x110AD, "strafe_minigun_manager" },
    { 0x110AE, "strafe_minigun_manager_delta" },
    { 0x110AF, "strafe_pass_target_dist" },
    { 0x110B0, "strafe_speed" },
    { 0x110B1, "strafereverse_cleanup" },
    { 0x110B2, "streakdeploy_playtabletdeploydialog" },
    { 0x110B3, "streakmatchlifeid" },
    { 0x110B4, "stream_hit_location_for_players_inside" },
    { 0x110B5, "stream_time" },
    { 0x110B6, "streamforslamzoomonspawn" },
    { 0x110B7, "streamhintenabled" },
    { 0x110B8, "streampoint" },
    { 0x110B9, "streamtimeout" },
    { 0x110BA, "strict_ff" },
    { 0x110BB, "strict_ff_disable" },
    { 0x110BC, "strict_ff_enable" },
    { 0x110BD, "strike_scriptorigincreate" },
    { 0x110BE, "stringtovec3" },
    { 0x110BF, "strip_node_flag_wait" },
    { 0x110C0, "struct_set_fields" },
    { 0x110C1, "stuckbygrenadeowner" },
    { 0x110C2, "stunboltdelete" },
    { 0x110C3, "stunshoulddetonate" },
    { 0x110C4, "sub_civtarget" },
    { 0x110C5, "submap_cull_targetname" },
    { 0x110C6, "subscribedlocale" },
    { 0x110C7, "subscribetoquestlocale" },
    { 0x110C8, "subscriptions" },
    { 0x110C9, "subtract_from_spawn_count_from_group" },
    { 0x110CA, "subwave_progression" },
    { 0x110CB, "subway_black_screen" },
    { 0x110CC, "subway_black_screen_fade_in" },
    { 0x110CD, "subway_black_screen_fade_out" },
    { 0x110CE, "subway_car_move_think" },
    { 0x110CF, "subway_cars" },
    { 0x110D0, "subway_death_or_disconnect_monitor" },
    { 0x110D1, "subway_fast_travel_teleport_data" },
    { 0x110D2, "subway_tracks" },
    { 0x110D3, "success_zone_center" },
    { 0x110D4, "success_zone_width" },
    { 0x110D5, "successful_vehicle_spawns" },
    { 0x110D6, "successfulteam" },
    { 0x110D7, "successfulteams" },
    { 0x110D8, "successfunction" },
    { 0x110D9, "suicide_on_alive" },
    { 0x110DA, "suicide_on_end_remote" },
    { 0x110DB, "suicideandskydive" },
    { 0x110DC, "suicidedfromspawnwait" },
    { 0x110DD, "suicidemonitorcrouchbuttonpress" },
    { 0x110DE, "suicideonend" },
    { 0x110DF, "suncascademult1" },
    { 0x110E0, "suncascademult2" },
    { 0x110E1, "sunpoissonfiltering" },
    { 0x110E2, "sunsamplesizenear" },
    { 0x110E3, "super_displayed" },
    { 0x110E4, "super_enemy_spawning" },
    { 0x110E5, "super_has_targets" },
    { 0x110E6, "super_onspawned" },
    { 0x110E7, "super_paratrooper_logic" },
    { 0x110E8, "superdeadsilence_watchforgameended" },
    { 0x110E9, "superfultonbeginuse" },
    { 0x110EA, "superonset" },
    { 0x110EB, "superonunset" },
    { 0x110EC, "supersbyextraweapon" },
    { 0x110ED, "superselectonset" },
    { 0x110EE, "superselectonunset" },
    { 0x110EF, "superslotcleanup" },
    { 0x110F0, "supersupplydropbeginuse" },
    { 0x110F1, "superterrainlightbakelodoverride" },
    { 0x110F2, "supply_crate_vo_when_used" },
    { 0x110F3, "supply_station_direction" },
    { 0x110F4, "supplydropprice" },
    { 0x110F5, "support_box_delay_max_ammo_hint" },
    { 0x110F6, "support_box_get_close_anim_length" },
    { 0x110F7, "support_box_get_open_anim_length" },
    { 0x110F8, "support_box_is_scriptable_model" },
    { 0x110F9, "support_box_make_entity_usable" },
    { 0x110FA, "support_box_spawn" },
    { 0x110FB, "support_box_update_hint_logic" },
    { 0x110FC, "support_box_use_logic" },
    { 0x110FD, "support_update_hint_logic" },
    { 0x110FE, "supportbox_playusesound" },
    { 0x110FF, "supportbox_updateheadicon" },
    { 0x11100, "supportbox_updateheadiconallplayers" },
    { 0x11101, "supportbox_updateheadicononjointeam" },
    { 0x11102, "supportbox_watch_flight" },
    { 0x11103, "supportboxmaxammo" },
    { 0x11104, "suppress_spawn_vo" },
    { 0x11105, "suppressdamageflash" },
    { 0x11106, "suppressedgunner" },
    { 0x11107, "suppressedlaser" },
    { 0x11108, "survival_ai_manager" },
    { 0x11109, "survival_wave_struct" },
    { 0x1110A, "survivorstreakoverride" },
    { 0x1110B, "survivorsupertwo" },
    { 0x1110C, "suspensemusic_reset" },
    { 0x1110D, "suspicious_door_monitor" },
    { 0x1110E, "swap_access_card" },
    { 0x1110F, "swaphelifordrivable" },
    { 0x11110, "swapped_car" },
    { 0x11111, "swayingcord" },
    { 0x11112, "swayingcrate" },
    { 0x11113, "swing" },
    { 0x11114, "switch_disabled" },
    { 0x11115, "switch_path" },
    { 0x11116, "switch_structs" },
    { 0x11117, "switch_timer" },
    { 0x11118, "switch_weapon_from_minigun" },
    { 0x11119, "switcharray" },
    { 0x1111A, "switchedtohardpointspawnlogic" },
    { 0x1111B, "switchents" },
    { 0x1111C, "switchespaused" },
    { 0x1111D, "switchminimapid" },
    { 0x1111E, "switchtoteammatereviveweapon" },
    { 0x1111F, "swivel_dogtag_revive" },
    { 0x11120, "sync_currency" },
    { 0x11121, "syncleadmarkers" },
    { 0x11122, "syringe_finish" },
    { 0x11123, "syringe_finish_crouch" },
    { 0x11124, "syringe_finish_stand" },
    { 0x11125, "syringe_inject" },
    { 0x11126, "syringe_out" },
    { 0x11127, "t" },
    { 0x11128, "table_getaddblueprintattachments" },
    { 0x11129, "table_getrole" },
    { 0x1112A, "table_getweaponvariantid" },
    { 0x1112B, "table_parseweaponvariantidvalue" },
    { 0x1112C, "tabletreplace" },
    { 0x1112D, "tabletreplacefrequency" },
    { 0x1112E, "tablettype" },
    { 0x1112F, "tablevalues" },
    { 0x11130, "tac_cover_adjust_damage" },
    { 0x11131, "tac_cover_blocked_by_turret" },
    { 0x11132, "tac_cover_can_be_crushed_by" },
    { 0x11133, "tac_cover_can_place_on" },
    { 0x11134, "tac_cover_get_stuck_to_ent" },
    { 0x11135, "tac_cover_give_new" },
    { 0x11136, "tac_cover_on_destroyed_by_mover" },
    { 0x11137, "tac_cover_spawn_with_door" },
    { 0x11138, "tac_rover" },
    { 0x11139, "tac_rover_horn" },
    { 0x1113A, "tac_rover_initcollision" },
    { 0x1113B, "tac_rover_initdamage" },
    { 0x1113C, "tac_rover_initomnvars" },
    { 0x1113D, "tac_rover_trail" },
    { 0x1113E, "taccover_timeout" },
    { 0x1113F, "taccovertriggerblockers" },
    { 0x11140, "tacinsert_brrespawnsplash" },
    { 0x11141, "tacinsert_cachespawnposition" },
    { 0x11142, "tacinsert_deleteontoofar" },
    { 0x11143, "tacinsert_destroyongameended" },
    { 0x11144, "tacinsert_destroyuselistener" },
    { 0x11145, "tacinsert_gamemode_callback" },
    { 0x11146, "tacinsert_getspawnposition" },
    { 0x11147, "tacinsert_monitorupdatespawnposition" },
    { 0x11148, "tacinsert_onjoinedteam" },
    { 0x11149, "tacinsert_pickuplistener" },
    { 0x1114A, "tacinsert_tacinsertdestroyedfeedback" },
    { 0x1114B, "tacinsert_updatedestroyusability" },
    { 0x1114C, "tacinsert_updatepickupusability" },
    { 0x1114D, "tacinserts" },
    { 0x1114E, "tacmapexplanation" },
    { 0x1114F, "tacmapvo" },
    { 0x11150, "tactical_boxes" },
    { 0x11151, "tactical_crate_spawn" },
    { 0x11152, "tactical_goal_in_action_thread" },
    { 0x11153, "tag_convoy_with_objectives" },
    { 0x11154, "tag_to_shoot_from" },
    { 0x11155, "tag_usb_with_head_icon" },
    { 0x11156, "tagautopickup" },
    { 0x11157, "tags_used" },
    { 0x11158, "tagtaken" },
    { 0x11159, "taillightleft" },
    { 0x1115A, "taillightright" },
    { 0x1115B, "take" },
    { 0x1115C, "take_ai_weapon" },
    { 0x1115D, "take_intro_items" },
    { 0x1115E, "take_time_away_from_bomb_vest_timer" },
    { 0x1115F, "takeaccesscardpickup" },
    { 0x11160, "takelaststandtransitionweapon" },
    { 0x11161, "taken_damage_for_molotov_achievement" },
    { 0x11162, "takeplayerweaponaway" },
    { 0x11163, "takequesttablet" },
    { 0x11164, "takerevivepickup" },
    { 0x11165, "takeriotshield" },
    { 0x11166, "taketeamplunder" },
    { 0x11167, "tango_infil_radio_idle" },
    { 0x11168, "tank_arrive_and_fire" },
    { 0x11169, "tank_check_for_damage" },
    { 0x1116A, "tank_check_player_firing" },
    { 0x1116B, "tank_damage_hit_markers" },
    { 0x1116C, "tank_death" },
    { 0x1116D, "tank_deaths" },
    { 0x1116E, "tank_die_from_explosives" },
    { 0x1116F, "tank_die_from_turret_damage" },
    { 0x11170, "tank_do_extra_damage" },
    { 0x11171, "tank_durations" },
    { 0x11172, "tank_east" },
    { 0x11173, "tank_eastturret" },
    { 0x11174, "tank_empupdate" },
    { 0x11175, "tank_path" },
    { 0x11176, "tank_think" },
    { 0x11177, "tank_turret_get_target_and_fire" },
    { 0x11178, "tank_watchforgameend" },
    { 0x11179, "tank_watchpiggybackexploit" },
    { 0x1117A, "tank_west" },
    { 0x1117B, "tank_westturret" },
    { 0x1117C, "tank_x1" },
    { 0x1117D, "tank_x1_capacity" },
    { 0x1117E, "tank_x2" },
    { 0x1117F, "tank_x2_capacity" },
    { 0x11180, "tankrespawntime" },
    { 0x11181, "tanks_help_reminder" },
    { 0x11182, "tanks_killed" },
    { 0x11183, "target_active_fob_watcher" },
    { 0x11184, "target_check_grenade" },
    { 0x11185, "target_dmg_monitor" },
    { 0x11186, "target_drop_loot" },
    { 0x11187, "target_flip_down_safe" },
    { 0x11188, "target_fob_think" },
    { 0x11189, "target_found_dist_sq" },
    { 0x1118A, "target_found_speed" },
    { 0x1118B, "target_group" },
    { 0x1118C, "target_in_range_and_fov" },
    { 0x1118D, "target_located" },
    { 0x1118E, "target_pity_outline_think" },
    { 0x1118F, "target_play_death_anim" },
    { 0x11190, "target_remap_key_value_pairs" },
    { 0x11191, "target_show_damage" },
    { 0x11192, "target_show_damage_damage_watch" },
    { 0x11193, "target_show_dist" },
    { 0x11194, "target_waves" },
    { 0x11195, "target_wavespawning_to_jammer5" },
    { 0x11196, "targetbrokelos" },
    { 0x11197, "targetdata" },
    { 0x11198, "targeted_enemy" },
    { 0x11199, "targeted_entities" },
    { 0x1119A, "targetedby" },
    { 0x1119B, "targeting" },
    { 0x1119C, "targetkiosk" },
    { 0x1119D, "targetmarkergroup_clearcacheonspawn" },
    { 0x1119E, "targetmarkergroup_watchmarkonspawn" },
    { 0x1119F, "targetoutsidegoal" },
    { 0x111A0, "targetoverride" },
    { 0x111A1, "targets_killed" },
    { 0x111A2, "targets_killed_by_hunters" },
    { 0x111A3, "targets_killed_stat_row" },
    { 0x111A4, "targetsite" },
    { 0x111A5, "targetsshot" },
    { 0x111A6, "targetteamremaining" },
    { 0x111A7, "targetvehicle" },
    { 0x111A8, "targs_done" },
    { 0x111A9, "tarmac_techo_start" },
    { 0x111AA, "tarmac_techo_start_first" },
    { 0x111AB, "team_planted_bomb" },
    { 0x111AC, "team_revive_kbm_override" },
    { 0x111AD, "team_revive_kbm_override_callback" },
    { 0x111AE, "teamanchoredentomnvars" },
    { 0x111AF, "teamanchoredinfoomnvars" },
    { 0x111B0, "teamanchoredwidget" },
    { 0x111B1, "teamanchoredwidgetinstances" },
    { 0x111B2, "teamcanrespawn" },
    { 0x111B3, "teamclearextractplunder" },
    { 0x111B4, "teamcodeprogress" },
    { 0x111B5, "teamextractedspawnspectate" },
    { 0x111B6, "teamextractedvictory" },
    { 0x111B7, "teamfriendlyto" },
    { 0x111B8, "teamhasfreshsquadleadercandidate" },
    { 0x111B9, "teamhasuav_ignorecuav" },
    { 0x111BA, "teamlist" },
    { 0x111BB, "teammarkedfor" },
    { 0x111BC, "teammateoutlineids" },
    { 0x111BD, "teammatereviveweaponwaitputaway" },
    { 0x111BE, "teamplacement" },
    { 0x111BF, "teamplunderexfil" },
    { 0x111C0, "teamplunderexfilshowviponly" },
    { 0x111C1, "teamplunderexfiltimer" },
    { 0x111C2, "teamplunderexfilvipuav" },
    { 0x111C3, "teamplunderscoremechanic" },
    { 0x111C4, "teamrefundplunder" },
    { 0x111C5, "teamrevivecost" },
    { 0x111C6, "teamrevivefiresalediscount" },
    { 0x111C7, "teamreviveperkdiscount" },
    { 0x111C8, "teamsassigned" },
    { 0x111C9, "teamspawnfunc" },
    { 0x111CA, "teamsplashbr" },
    { 0x111CB, "teamstarttime" },
    { 0x111CC, "teamswithcirclepeek" },
    { 0x111CD, "teamuseonly" },
    { 0x111CE, "teamvehicles" },
    { 0x111CF, "teamwipedobituary" },
    { 0x111D0, "technical_initcollision" },
    { 0x111D1, "technical_initdamage" },
    { 0x111D2, "technical_initomnvars" },
    { 0x111D3, "teleport_entities_inside_subway_car" },
    { 0x111D4, "teleport_players_inside_subway_car" },
    { 0x111D5, "teleport_players_on_entering_trigger" },
    { 0x111D6, "teleport_reference_juggmaze" },
    { 0x111D7, "teleport_reference_silo" },
    { 0x111D8, "teleport_room_doors" },
    { 0x111D9, "teleport_text_updated" },
    { 0x111DA, "teleport_to_debug_start_pos" },
    { 0x111DB, "teleport_to_silo_airlock" },
    { 0x111DC, "teleport_to_track_start" },
    { 0x111DD, "teleport_trigger_objective" },
    { 0x111DE, "teleport_trigger_to_airplane" },
    { 0x111DF, "teleportplayertoselection" },
    { 0x111E0, "tell_player_to_pick_up_intel" },
    { 0x111E1, "temp_debug_wait_and_stop_music_loop" },
    { 0x111E2, "terminal_pusher" },
    { 0x111E3, "terminal_pusher_approach_array" },
    { 0x111E4, "terminal_pusher_approach_array_counter" },
    { 0x111E5, "terminal_pusher_approach_entrance_array" },
    { 0x111E6, "terminal_pusher_approaches_init" },
    { 0x111E7, "terminateriotshield" },
    { 0x111E8, "test_ai_anim" },
    { 0x111E9, "test_anim_ai" },
    { 0x111EA, "test_bag_pickup" },
    { 0x111EB, "test_br_ending" },
    { 0x111EC, "test_offset_positions" },
    { 0x111ED, "test_pipe_fire" },
    { 0x111EE, "test_smoke_mortars" },
    { 0x111EF, "test_train_array" },
    { 0x111F0, "test_trigger_spawn" },
    { 0x111F1, "testaccessoryvfx" },
    { 0x111F2, "testclient_dev_laststand" },
    { 0x111F3, "testclient_ignoreme_dvar" },
    { 0x111F4, "testclient_run_funcs" },
    { 0x111F5, "testing" },
    { 0x111F6, "testing_linked_anims" },
    { 0x111F7, "testsplashes" },
    { 0x111F8, "thankyou_photo" },
    { 0x111F9, "thermite_damage_over_time" },
    { 0x111FA, "thermite_damagemodifierignorefunc" },
    { 0x111FB, "thermite_doradiusdamage" },
    { 0x111FC, "thermite_laststand_effects" },
    { 0x111FD, "thermite_linktostuck" },
    { 0x111FE, "thermite_watchglstuck" },
    { 0x111FF, "thermite_watchstucktoterrain" },
    { 0x11200, "thermiteboltburnout" },
    { 0x11201, "thermiteboltradiusdamage" },
    { 0x11202, "thermiteboltstuckto" },
    { 0x11203, "thermiteburnout" },
    { 0x11204, "thermiteradiusdamage" },
    { 0x11205, "thermiteradiusweaponref" },
    { 0x11206, "thermitestuckpains" },
    { 0x11207, "thermitestuckto" },
    { 0x11208, "thermitestucktoshield" },
    { 0x11209, "thermometerwatch" },
    { 0x1120A, "thirdpersonheightoffset" },
    { 0x1120B, "thirdpersonrange" },
    { 0x1120C, "thirtypercent_music" },
    { 0x1120D, "thread_endon_death" },
    { 0x1120E, "thread_hostage_waiting_anim" },
    { 0x1120F, "threat_level" },
    { 0x11210, "threat_sight_monitor" },
    { 0x11211, "throwing_knife_cp_trytopickup" },
    { 0x11212, "throwingknife_fire_begin_fx" },
    { 0x11213, "throwingknife_fire_clear_fx" },
    { 0x11214, "throwingknife_fire_end_fx" },
    { 0x11215, "throwingknife_fire_watch_fx" },
    { 0x11216, "throwingknifemelee" },
    { 0x11217, "thrownoffhand" },
    { 0x11218, "thrownspecialcount" },
    { 0x11219, "thrust_fx_model" },
    { 0x1121A, "tier" },
    { 0x1121B, "tiers" },
    { 0x1121C, "time_after_shoot" },
    { 0x1121D, "time_before_shoot" },
    { 0x1121E, "time_between_rocket_fire" },
    { 0x1121F, "time_on_floor" },
    { 0x11220, "time_passed_no_target_threshold" },
    { 0x11221, "time_passed_with_no_target" },
    { 0x11222, "time_reduction_bonus" },
    { 0x11223, "time_watcher" },
    { 0x11224, "timed_death" },
    { 0x11225, "timed_laser_trap_trigger" },
    { 0x11226, "timed_laser_trap_trigger_array" },
    { 0x11227, "timedrun_finishlinevfx" },
    { 0x11228, "timeoflastexecute" },
    { 0x11229, "timeout_consec_kills" },
    { 0x1122A, "timeoutonabandonedcallback" },
    { 0x1122B, "timeoutonabandoneddelay" },
    { 0x1122C, "timeoutplunderextractionsites" },
    { 0x1122D, "timeoutradialunfill" },
    { 0x1122E, "timeoutvfxname" },
    { 0x1122F, "timer_active" },
    { 0x11230, "timer_sequence" },
    { 0x11231, "timeramount" },
    { 0x11232, "timeremaining" },
    { 0x11233, "timertexthud" },
    { 0x11234, "times_in_a" },
    { 0x11235, "times_in_b" },
    { 0x11236, "times_in_c" },
    { 0x11237, "times_shot" },
    { 0x11238, "timesincelastdeath" },
    { 0x11239, "timestartwaitingtoshoot" },
    { 0x1123A, "timetonextcheckpoint" },
    { 0x1123B, "timevotrigger" },
    { 0x1123C, "tire_repair_start_air_start_sfx" },
    { 0x1123D, "tire_repair_start_air_stop_sfx" },
    { 0x1123E, "tire_repair_start_enter_foley_sfx" },
    { 0x1123F, "tire_repair_start_exit_foley_sfx" },
    { 0x11240, "tmtyl_bomber_squadafterspawnfunc" },
    { 0x11241, "tmtyl_vip_interactions" },
    { 0x11242, "tmtyl_vipobjectives" },
    { 0x11243, "tmtylsquadafterspawnfunc" },
    { 0x11244, "to" },
    { 0x11245, "toggle_ai_settings" },
    { 0x11246, "toggle_ambient_vehicles_on_module" },
    { 0x11247, "toggle_apc_objective" },
    { 0x11248, "toggle_custom_death_anim_settings" },
    { 0x11249, "toggle_farah_lights" },
    { 0x1124A, "toggle_fx_trap" },
    { 0x1124B, "toggle_in_use" },
    { 0x1124C, "toggle_plane_combat_global_settings" },
    { 0x1124D, "toggle_player_pos_memory" },
    { 0x1124E, "toggle_player_settings" },
    { 0x1124F, "toggle_safehouse_doors" },
    { 0x11250, "toggle_safehouse_settings" },
    { 0x11251, "toggle_switch_model" },
    { 0x11252, "toggle_trap" },
    { 0x11253, "toggle_wind" },
    { 0x11254, "toggleconnectpaths" },
    { 0x11255, "togglecpplayerbc" },
    { 0x11256, "togglelightbutton" },
    { 0x11257, "toggleusbstickinhand" },
    { 0x11258, "tokenrespawned" },
    { 0x11259, "tokenrespawnwaittime" },
    { 0x1125A, "tolerance" },
    { 0x1125B, "toma_strike" },
    { 0x1125C, "toma_strike_munitionused" },
    { 0x1125D, "toma_strike_trace_offset" },
    { 0x1125E, "toma_strike_watch_owner" },
    { 0x1125F, "tomastrike_findoptimallaunchpos" },
    { 0x11260, "tomastrike_getrandombombingpoint" },
    { 0x11261, "tomastrike_isflyingkillstreak" },
    { 0x11262, "tomastrike_isflyingvehicle" },
    { 0x11263, "tomastrike_watchgameend" },
    { 0x11264, "too_far_dist" },
    { 0x11265, "top_roof_enemy_watcher" },
    { 0x11266, "toppercentagetoadjusteconomy" },
    { 0x11267, "topteam" },
    { 0x11268, "topteamsever" },
    { 0x11269, "total_killed" },
    { 0x1126A, "total_puddle_count" },
    { 0x1126B, "total_spawns" },
    { 0x1126C, "total_successful_vehicle_spawns" },
    { 0x1126D, "totalapacheresponses" },
    { 0x1126E, "totalcashongroundatstart" },
    { 0x1126F, "totalcollecteditems" },
    { 0x11270, "totaldamage" },
    { 0x11271, "totaldata" },
    { 0x11272, "totalhealth" },
    { 0x11273, "totalmuncurrencyearned" },
    { 0x11274, "totalroundtime" },
    { 0x11275, "totalstructs" },
    { 0x11276, "totaltrainlootcrates" },
    { 0x11277, "totalweaponxpearned" },
    { 0x11278, "touchdown_origin" },
    { 0x11279, "touchedmovingplatform" },
    { 0x1127A, "tower_ground_mortar" },
    { 0x1127B, "tower_ground_mortar_2" },
    { 0x1127C, "tr_circletick" },
    { 0x1127D, "tr_createquestlocale" },
    { 0x1127E, "tr_detectwinners" },
    { 0x1127F, "tr_entergulag" },
    { 0x11280, "tr_findvehicle" },
    { 0x11281, "tr_kiosksearchparams" },
    { 0x11282, "tr_ontimerexpired" },
    { 0x11283, "tr_playerdisconnect" },
    { 0x11284, "tr_removelocaleinstance" },
    { 0x11285, "tr_removequestinstance" },
    { 0x11286, "tr_respawn" },
    { 0x11287, "tr_vehiclesearchparams" },
    { 0x11288, "tr_vis_facing_dist_add_override" },
    { 0x11289, "tr_vis_radius_override_lod1" },
    { 0x1128A, "tr_vis_radius_override_lod2" },
    { 0x1128B, "trace_to_eye_weight" },
    { 0x1128C, "trace_to_origin_weight" },
    { 0x1128D, "tracegroundheightexfil" },
    { 0x1128E, "traceresultisvalid" },
    { 0x1128F, "traceresults" },
    { 0x11290, "traceselectedmaplocation" },
    { 0x11291, "track_consecutive_kills" },
    { 0x11292, "track_get_launch_target" },
    { 0x11293, "track_get_launch_velocity" },
    { 0x11294, "track_get_reward_time" },
    { 0x11295, "track_get_reward_time_string" },
    { 0x11296, "track_get_teleport_target" },
    { 0x11297, "track_get_teleport_velocity" },
    { 0x11298, "track_is_operational" },
    { 0x11299, "track_last_good_position" },
    { 0x1129A, "track_settings" },
    { 0x1129B, "track_target_group_complete" },
    { 0x1129C, "track_timer_think" },
    { 0x1129D, "trackcarpunches" },
    { 0x1129E, "trackcashevent" },
    { 0x1129F, "trackchallengetimers" },
    { 0x112A0, "trackcratemantlingexploit" },
    { 0x112A1, "trackedlittlebirds" },
    { 0x112A2, "trackedtanks" },
    { 0x112A3, "trackendangeredobjs" },
    { 0x112A4, "tracking_max_health" },
    { 0x112A5, "tracking_munitions_purchase" },
    { 0x112A6, "tracking_obit" },
    { 0x112A7, "tracknonoobplayerlocation" },
    { 0x112A8, "trackriotshield_grenadepullbackforc4" },
    { 0x112A9, "trackriotshield_monitorshieldattach" },
    { 0x112AA, "trackriotshield_tryarm" },
    { 0x112AB, "trackriotshield_tryback" },
    { 0x112AC, "trackriotshield_trydetach" },
    { 0x112AD, "trackriotshield_tryreset" },
    { 0x112AE, "trackriotshield_updateoffhandstowignorec4" },
    { 0x112AF, "trackriotshield_watchcancelswitchaway" },
    { 0x112B0, "trackriotshield_watchswitchawayfromshield" },
    { 0x112B1, "tracks" },
    { 0x112B2, "trackserverend" },
    { 0x112B3, "tracktimealive" },
    { 0x112B4, "tracktimeringingfrenzy" },
    { 0x112B5, "train_array" },
    { 0x112B6, "train_associate_models_with_brushes" },
    { 0x112B7, "train_attach_brushes_to_models" },
    { 0x112B8, "train_attach_models_to_assembly" },
    { 0x112B9, "train_attach_player_hurts" },
    { 0x112BA, "train_attach_useable_ammorestocklocation" },
    { 0x112BB, "train_car_audio" },
    { 0x112BC, "train_collision_item_valid" },
    { 0x112BD, "train_delay_handler" },
    { 0x112BE, "train_elements_disable" },
    { 0x112BF, "train_elements_enable" },
    { 0x112C0, "train_get_anim_ents_index" },
    { 0x112C1, "train_get_anim_to_play" },
    { 0x112C2, "train_get_num_of_anim_ents" },
    { 0x112C3, "train_handle_collide_crate_br" },
    { 0x112C4, "train_handle_collide_mines" },
    { 0x112C5, "train_horn_sfx" },
    { 0x112C6, "train_hurt_damage_watcher" },
    { 0x112C7, "train_init_as_vehicle" },
    { 0x112C8, "train_init_lootcrates_on_train" },
    { 0x112C9, "train_initcollision" },
    { 0x112CA, "train_lootcrates_save_offsets" },
    { 0x112CB, "train_minimap_icon_attach" },
    { 0x112CC, "train_minimap_icon_detach" },
    { 0x112CD, "train_move_test_train_car_thread" },
    { 0x112CE, "train_mover_test" },
    { 0x112CF, "train_play_anim" },
    { 0x112D0, "train_play_anim_init" },
    { 0x112D1, "train_scriptable_attach_delay" },
    { 0x112D2, "train_sfx_init" },
    { 0x112D3, "train_start_from_struct" },
    { 0x112D4, "train_stop" },
    { 0x112D5, "train_stopper" },
    { 0x112D6, "train_tag_array" },
    { 0x112D7, "train_tagoffset_array" },
    { 0x112D8, "train_track_velocity" },
    { 0x112D9, "train_vfx_init" },
    { 0x112DA, "train_wzcircle_override" },
    { 0x112DB, "train_wzcircle_time_subtractfrom" },
    { 0x112DC, "traincar_hurt" },
    { 0x112DD, "traincar_wait_until_shown" },
    { 0x112DE, "traincolignorelist" },
    { 0x112DF, "traincylestolink" },
    { 0x112E0, "trainent" },
    { 0x112E1, "trainmove" },
    { 0x112E2, "traintracefails" },
    { 0x112E3, "traintracerelpos" },
    { 0x112E4, "traintracesuccesses" },
    { 0x112E5, "trainwaittime" },
    { 0x112E6, "transient_prefab_group" },
    { 0x112E7, "transient_world_autolod_enabled" },
    { 0x112E8, "transient_world_proxy_collision_distance" },
    { 0x112E9, "transient_world_proxy_cull_playspace_proxies" },
    { 0x112EA, "transientname" },
    { 0x112EB, "transition_parachutestate" },
    { 0x112EC, "transition_snd_org" },
    { 0x112ED, "transition_to_airfield" },
    { 0x112EE, "transition_to_next_section" },
    { 0x112EF, "transitionac130tomovinganim" },
    { 0x112F0, "transitionplayersoutofac130cinematic" },
    { 0x112F1, "transitionplayerstoac130cinematic" },
    { 0x112F2, "translate_and_rotate_from_level_overrides" },
    { 0x112F3, "trap_array" },
    { 0x112F4, "trap_consoles" },
    { 0x112F5, "trap_door_nvg_reset" },
    { 0x112F6, "trap_door_nvg_reset_catch" },
    { 0x112F7, "trap_room_dogtag_revive" },
    { 0x112F8, "trap_room_ents" },
    { 0x112F9, "trap_room_turret_init" },
    { 0x112FA, "trap_room_wave_settings" },
    { 0x112FB, "trap_timer_running" },
    { 0x112FC, "trap_toggle_fx_logic" },
    { 0x112FD, "trap_toggle_logic" },
    { 0x112FE, "trap_trigger_logic" },
    { 0x112FF, "traps_disabled" },
    { 0x11300, "travelspeed" },
    { 0x11301, "traversal_disabled_by_management" },
    { 0x11302, "traversenotvalid" },
    { 0x11303, "tread_sfx" },
    { 0x11304, "tree_think" },
    { 0x11305, "treerootnodesizebitcount" },
    { 0x11306, "trenchdebug" },
    { 0x11307, "triage_ai_campers" },
    { 0x11308, "triage_door_clip" },
    { 0x11309, "triage_glass_break" },
    { 0x1130A, "trial_active_fob" },
    { 0x1130B, "trial_active_ring" },
    { 0x1130C, "trial_ai" },
    { 0x1130D, "trial_ai_jugg" },
    { 0x1130E, "trial_ai_spawn_far" },
    { 0x1130F, "trial_alternate_progression" },
    { 0x11310, "trial_callback_ai_damage" },
    { 0x11311, "trial_callback_ai_killed" },
    { 0x11312, "trial_celebration_flares" },
    { 0x11313, "trial_civilians_killed" },
    { 0x11314, "trial_combo" },
    { 0x11315, "trial_combo_died" },
    { 0x11316, "trial_delete_out_of_bounds" },
    { 0x11317, "trial_dlog_arm_course" },
    { 0x11318, "trial_dlog_clear" },
    { 0x11319, "trial_dlog_func" },
    { 0x1131A, "trial_dlog_gun" },
    { 0x1131B, "trial_dlog_gunslinger" },
    { 0x1131C, "trial_dlog_jugg" },
    { 0x1131D, "trial_dlog_lava" },
    { 0x1131E, "trial_dlog_pitcher" },
    { 0x1131F, "trial_dlog_race" },
    { 0x11320, "trial_dlog_sniper" },
    { 0x11321, "trial_dogtag_setup" },
    { 0x11322, "trial_dogtags" },
    { 0x11323, "trial_end_flares" },
    { 0x11324, "trial_end_time" },
    { 0x11325, "trial_enemies_killed" },
    { 0x11326, "trial_enemy_dont_drop_weapon" },
    { 0x11327, "trial_enemy_quota" },
    { 0x11328, "trial_explosive_clear" },
    { 0x11329, "trial_fetch_mission_table" },
    { 0x1132A, "trial_flare_destruct_missile" },
    { 0x1132B, "trial_flare_watcher" },
    { 0x1132C, "trial_flares" },
    { 0x1132D, "trial_fobs_cleared" },
    { 0x1132E, "trial_gethitmarkerpriority" },
    { 0x1132F, "trial_headicon" },
    { 0x11330, "trial_headicon_origin" },
    { 0x11331, "trial_hitmarker" },
    { 0x11332, "trial_is_event" },
    { 0x11333, "trial_juggernauts_to_spawn" },
    { 0x11334, "trial_lap_time" },
    { 0x11335, "trial_map" },
    { 0x11336, "trial_missionscript_init_funcs" },
    { 0x11337, "trial_mount_nag" },
    { 0x11338, "trial_moving_target_mover" },
    { 0x11339, "trial_moving_target_reset" },
    { 0x1133A, "trial_moving_target_think" },
    { 0x1133B, "trial_other_team" },
    { 0x1133C, "trial_patch_finished" },
    { 0x1133D, "trial_play_flare_fx" },
    { 0x1133E, "trial_player_perks" },
    { 0x1133F, "trial_race_lap_total" },
    { 0x11340, "trial_race_lap_total_override" },
    { 0x11341, "trial_race_uses_heli" },
    { 0x11342, "trial_radar_sweeps" },
    { 0x11343, "trial_restart" },
    { 0x11344, "trial_restart_watcher" },
    { 0x11345, "trial_restarting" },
    { 0x11346, "trial_retrieve_persistent_values" },
    { 0x11347, "trial_rpg_init" },
    { 0x11348, "trial_rpg_settings" },
    { 0x11349, "trial_sentry_turrets" },
    { 0x1134A, "trial_shooters" },
    { 0x1134B, "trial_shooters_quota" },
    { 0x1134C, "trial_small_fire" },
    { 0x1134D, "trial_spawn_vehicle" },
    { 0x1134E, "trial_spawn_wait" },
    { 0x1134F, "trial_spawn_wp" },
    { 0x11350, "trial_special_end" },
    { 0x11351, "trial_special_vfx" },
    { 0x11352, "trial_start_time" },
    { 0x11353, "trial_stat_row" },
    { 0x11354, "trial_target_arm_damage" },
    { 0x11355, "trial_target_civilian_killed_func" },
    { 0x11356, "trial_target_damage" },
    { 0x11357, "trial_target_enemy_killed_func" },
    { 0x11358, "trial_target_flip" },
    { 0x11359, "trial_target_follow_dummy" },
    { 0x1135A, "trial_target_headshot_func" },
    { 0x1135B, "trial_target_requisites" },
    { 0x1135C, "trial_target_think" },
    { 0x1135D, "trial_target_think_func" },
    { 0x1135E, "trial_target_thread_func" },
    { 0x1135F, "trial_targs" },
    { 0x11360, "trial_targs_combo" },
    { 0x11361, "trial_thermite_watcher" },
    { 0x11362, "trial_time_remaining" },
    { 0x11363, "trial_trigger_activated_func" },
    { 0x11364, "trial_trigger_think" },
    { 0x11365, "trial_turret_kill_func" },
    { 0x11366, "trial_turret_thread_func" },
    { 0x11367, "trial_turrets_killed" },
    { 0x11368, "trial_ui_decrease_tries_remaining" },
    { 0x11369, "trial_ui_retry_disabled" },
    { 0x1136A, "trial_ui_return_to_vehicle" },
    { 0x1136B, "trial_ui_set_combo_bar_combo" },
    { 0x1136C, "trial_ui_set_combo_bar_duration" },
    { 0x1136D, "trial_ui_set_lap" },
    { 0x1136E, "trial_updatehitmarker" },
    { 0x1136F, "trial_use_headicon" },
    { 0x11370, "trial_vehicle" },
    { 0x11371, "trial_vehicle_outline_id" },
    { 0x11372, "trial_vehicles" },
    { 0x11373, "trial_weapon_defined" },
    { 0x11374, "trial_white_phosphorus" },
    { 0x11375, "trial_white_phosphorus_activate" },
    { 0x11376, "trialendgame" },
    { 0x11377, "trialympic_fire" },
    { 0x11378, "trialympic_fires" },
    { 0x11379, "trigger_aggro_damage_amount" },
    { 0x1137A, "trigger_elevator_spawners" },
    { 0x1137B, "trigger_explosion_grenades" },
    { 0x1137C, "trigger_kill" },
    { 0x1137D, "trigger_smoke_grenades" },
    { 0x1137E, "trigger_spawn_kill" },
    { 0x1137F, "trigger_spawn_kill_watcher" },
    { 0x11380, "trigger_stop_bombticks" },
    { 0x11381, "trigger_waittill_player_enters" },
    { 0x11382, "trigger_water_fx" },
    { 0x11383, "triggeraddobjectivetext" },
    { 0x11384, "triggeravailablekillstreaks" },
    { 0x11385, "triggerbloodmoneyendcameras" },
    { 0x11386, "triggercombatarea" },
    { 0x11387, "triggered_module" },
    { 0x11388, "triggered_module_spawn" },
    { 0x11389, "triggered_module_spawn_cancel" },
    { 0x1138A, "triggeredwincondition" },
    { 0x1138B, "triggeregg" },
    { 0x1138C, "triggereliminatedoverlay" },
    { 0x1138D, "triggerenterfunc" },
    { 0x1138E, "triggerexitfunc" },
    { 0x1138F, "triggermatchendtimer" },
    { 0x11390, "triggerovertimetimer" },
    { 0x11391, "triggerpromptthink" },
    { 0x11392, "triggerremoveobjectivetext" },
    { 0x11393, "triggerrespawnoverlay" },
    { 0x11394, "triggersafearea" },
    { 0x11395, "triplecheck_jugg_spawned" },
    { 0x11396, "tripledefenderkill" },
    { 0x11397, "tripwire_trackachievementboom" },
    { 0x11398, "tromeo_death_watcher" },
    { 0x11399, "trophy_deployanimation" },
    { 0x1139A, "trophy_get_best_tag" },
    { 0x1139B, "trophy_get_part_by_tag" },
    { 0x1139C, "trophy_protection_success" },
    { 0x1139D, "trophy_tryreflectsnapshot" },
    { 0x1139E, "trophy_watch_flight" },
    { 0x1139F, "trophy_watchtimeoutorgameended" },
    { 0x113A0, "trophy_watchtimeoutorgameendedinternal" },
    { 0x113A1, "trtablet_init" },
    { 0x113A2, "truck_01_node" },
    { 0x113A3, "truck_03_node" },
    { 0x113A4, "truck_04_node" },
    { 0x113A5, "truck_airdrop" },
    { 0x113A6, "truck_airdropinternal" },
    { 0x113A7, "truck_detachvehiclefromairdropsequence" },
    { 0x113A8, "truck_minimap" },
    { 0x113A9, "truck_think" },
    { 0x113AA, "truckcollision" },
    { 0x113AB, "truckdoorleft" },
    { 0x113AC, "truckdoorleftcol" },
    { 0x113AD, "truckdoorright" },
    { 0x113AE, "truckdoorrightcol" },
    { 0x113AF, "trucks_intel_sequence" },
    { 0x113B0, "truckwarspawnlocations" },
    { 0x113B1, "try_add_targetmarkergroup" },
    { 0x113B2, "try_play_tv_station_intro_sequence" },
    { 0x113B3, "try_spawn_heli_group" },
    { 0x113B4, "try_start_driving_func" },
    { 0x113B5, "try_start_fake_infil_chopper" },
    { 0x113B6, "try_to_do_first_entry_room_logic" },
    { 0x113B7, "try_to_do_first_passby_room_logic" },
    { 0x113B8, "try_to_play_custom_death_animation" },
    { 0x113B9, "try_to_punish_with_jugg" },
    { 0x113BA, "trycall" },
    { 0x113BB, "trychangesuitsforplayer" },
    { 0x113BC, "trygetlastpotentiallivingplayer" },
    { 0x113BD, "trying_to_spawn_boss" },
    { 0x113BE, "tryingtoleave" },
    { 0x113BF, "trymarksystem" },
    { 0x113C0, "tryplaycoughaudio" },
    { 0x113C1, "tryreenablescriptablevfx" },
    { 0x113C2, "tryscriptarms" },
    { 0x113C3, "tryspawnscriptable" },
    { 0x113C4, "tryspawnscriptableparenting" },
    { 0x113C5, "tryspawnscriptablereuse" },
    { 0x113C6, "tryspawnweapons" },
    { 0x113C7, "trytoplaydamagesound" },
    { 0x113C8, "tryupdategenericprogress" },
    { 0x113C9, "tryweaponswitchnag" },
    { 0x113CA, "tu0bakechanges" },
    { 0x113CB, "tugofwar_hvt_placed" },
    { 0x113CC, "tugofwar_hvt_taken_firsttime" },
    { 0x113CD, "tugofwar_tank" },
    { 0x113CE, "turbopetchallengewatcher" },
    { 0x113CF, "turbulence_scalar" },
    { 0x113D0, "turn_off_have_target_hud" },
    { 0x113D1, "turn_off_heli_spawners" },
    { 0x113D2, "turn_off_hours_later_chyron_text" },
    { 0x113D3, "turn_off_laser_trap" },
    { 0x113D4, "turn_off_laser_vfx" },
    { 0x113D5, "turn_off_red_lights_along_track" },
    { 0x113D6, "turn_off_search_light" },
    { 0x113D7, "turn_off_silo_lights" },
    { 0x113D8, "turn_off_sniper_laser" },
    { 0x113D9, "turn_off_steam" },
    { 0x113DA, "turn_on_have_target_hud" },
    { 0x113DB, "turn_on_hours_later_chyron_text" },
    { 0x113DC, "turn_on_laser_trap" },
    { 0x113DD, "turn_on_laser_vfx" },
    { 0x113DE, "turn_on_light_when_elevator_close_by" },
    { 0x113DF, "turn_on_nearby_model_screen" },
    { 0x113E0, "turn_on_red_lights_along_track" },
    { 0x113E1, "turn_on_search_light" },
    { 0x113E2, "turn_on_silo_lights" },
    { 0x113E3, "turn_on_sniper_laser" },
    { 0x113E4, "turn_on_steam" },
    { 0x113E5, "turnexfiltoside" },
    { 0x113E6, "turret_aimed_at_last_known" },
    { 0x113E7, "turret_enemy_watcher_internal" },
    { 0x113E8, "turret_fob_self_destruct" },
    { 0x113E9, "turret_fob_watcher" },
    { 0x113EA, "turret_guncourse_explode_on_end" },
    { 0x113EB, "turret_guncourse_think" },
    { 0x113EC, "turret_has_target" },
    { 0x113ED, "turret_headicon" },
    { 0x113EE, "turret_objective_think" },
    { 0x113EF, "turret_op" },
    { 0x113F0, "turret_outline_watcher" },
    { 0x113F1, "turret_struct" },
    { 0x113F2, "turretdisabled" },
    { 0x113F3, "turretlightsonstate" },
    { 0x113F4, "turretobjweapon" },
    { 0x113F5, "turretoverridefunc" },
    { 0x113F6, "turretparent" },
    { 0x113F7, "turrets_shields" },
    { 0x113F8, "turretsactive" },
    { 0x113F9, "tut_bot_nameplate" },
    { 0x113FA, "tut_bots_forcelaststand_onknock" },
    { 0x113FB, "tut_bots_forcelaststand_onspawn" },
    { 0x113FC, "tut_loadout" },
    { 0x113FD, "tut_loot" },
    { 0x113FE, "tut_popup_listener" },
    { 0x113FF, "tutdmzonplayerkilled" },
    { 0x11400, "tutkioskpurchase" },
    { 0x11401, "tutonplayerkilled" },
    { 0x11402, "tutorial_intro" },
    { 0x11403, "tutorial_jumpfromplane" },
    { 0x11404, "tutorial_lead_collected" },
    { 0x11405, "tutorial_playsound" },
    { 0x11406, "tutorial_pullchute" },
    { 0x11407, "tutorial_showtext" },
    { 0x11408, "tutorial_tacmap" },
    { 0x11409, "tutorial_usingparachute" },
    { 0x1140A, "tutorialprint_number" },
    { 0x1140B, "tutorialzoneenter" },
    { 0x1140C, "tutorialzoneexit" },
    { 0x1140D, "tuttxtbox" },
    { 0x1140E, "tutzonetriggerlogic" },
    { 0x1140F, "tv_model" },
    { 0x11410, "tv_station_boss" },
    { 0x11411, "tv_station_boss_should_break_stealth_immediately" },
    { 0x11412, "tv_station_fastrope_one_infil_rider_start_targetname" },
    { 0x11413, "tv_station_fastrope_one_infil_start_targetname_array" },
    { 0x11414, "tv_station_fastrope_one_infil_start_targetname_array_index" },
    { 0x11415, "tv_station_fastrope_two_infil_rider_start_targetname" },
    { 0x11416, "tv_station_fastrope_two_infil_start_targetname_array" },
    { 0x11417, "tv_station_fastrope_two_infil_start_targetname_array_index" },
    { 0x11418, "tv_station_gas_rise" },
    { 0x11419, "tv_station_get_bomb_icon_on_cell_phone" },
    { 0x1141A, "tv_station_global_stealth_broken" },
    { 0x1141B, "tv_station_infil_enemies_attack_logic" },
    { 0x1141C, "tv_station_infil_enemy_combat_logic" },
    { 0x1141D, "tv_station_interior_enemy_should_break_stealth_immediately" },
    { 0x1141E, "tv_station_intro_already_played" },
    { 0x1141F, "tv_station_intro_camera" },
    { 0x11420, "tv_station_marker_player_connect_monitor" },
    { 0x11421, "tv_station_mindia_spawner_think" },
    { 0x11422, "tv_station_reinforcement_spawn_logic" },
    { 0x11423, "tvstation_fastrope_init" },
    { 0x11424, "txt_nag" },
    { 0x11425, "uav_dangernotifyplayersinbrrange" },
    { 0x11426, "uav_getenemyplayersinrange" },
    { 0x11427, "uav_isenemygettingnotified" },
    { 0x11428, "uavbestid" },
    { 0x11429, "uavdirectionalid" },
    { 0x1142A, "uavfastsweepid" },
    { 0x1142B, "uavnoneid" },
    { 0x1142C, "uavworstid" },
    { 0x1142D, "ui_damage_num_cycle" },
    { 0x1142E, "ui_damage_num_elems" },
    { 0x1142F, "ui_damage_num_next_index" },
    { 0x11430, "ui_damage_nums_global_limit" },
    { 0x11431, "ui_init" },
    { 0x11432, "ui_show_dist" },
    { 0x11433, "uid" },
    { 0x11434, "uihidden" },
    { 0x11435, "uiobjectivesetlootid" },
    { 0x11436, "umbra" },
    { 0x11437, "unblockclasschange" },
    { 0x11438, "underbridge_reinforce_enemy_monitor" },
    { 0x11439, "unfreeze_controls_after_spawn" },
    { 0x1143A, "unfreezeplayercontrols" },
    { 0x1143B, "unicornpoints" },
    { 0x1143C, "uniform_suicide_truck_speed_manager" },
    { 0x1143D, "uniquelootcallbacks" },
    { 0x1143E, "uniquelootitemid" },
    { 0x1143F, "uniquelootitemlookup" },
    { 0x11440, "uniquepoolid" },
    { 0x11441, "unlink_on_ai_death" },
    { 0x11442, "unload_after_timeout" },
    { 0x11443, "unload_all_vehicles_in_module" },
    { 0x11444, "unload_type" },
    { 0x11445, "unload_vehicles_on_weapons_free" },
    { 0x11446, "unload_vehicles_on_weapons_free_thread" },
    { 0x11447, "unlockableindex" },
    { 0x11448, "unlockables" },
    { 0x11449, "unlocked_armory" },
    { 0x1144A, "unlocked_escape_door" },
    { 0x1144B, "unlockprop" },
    { 0x1144C, "unlockscriptabledoors" },
    { 0x1144D, "unlockstop" },
    { 0x1144E, "unmark_on_death" },
    { 0x1144F, "unmarkplayeraseliminated" },
    { 0x11450, "unpause_dmz_scoring" },
    { 0x11451, "unpause_wave_hud" },
    { 0x11452, "unreachable_function" },
    { 0x11453, "unrescuable_fail" },
    { 0x11454, "unresolvedcollisiontolerancesqr" },
    { 0x11455, "unset_bullet_shields" },
    { 0x11456, "unset_force_aitype_riotshield" },
    { 0x11457, "unset_force_aitype_rpg" },
    { 0x11458, "unset_force_aitype_shotgun" },
    { 0x11459, "unset_force_aitype_sniper" },
    { 0x1145A, "unset_force_aitype_suicidebomber" },
    { 0x1145B, "unset_forced_aitype" },
    { 0x1145C, "unset_forced_aitype_armored" },
    { 0x1145D, "unset_heavy_hitter" },
    { 0x1145E, "unset_ignoreall_after_notify" },
    { 0x1145F, "unset_jugg_ignoreall_after_notify" },
    { 0x11460, "unset_just_keep_moving" },
    { 0x11461, "unset_maze_ai_stealth_settings" },
    { 0x11462, "unset_relic_aggressive_melee" },
    { 0x11463, "unset_relic_aggressive_melee_params" },
    { 0x11464, "unset_relic_ammo_drain" },
    { 0x11465, "unset_relic_amped" },
    { 0x11466, "unset_relic_bang_and_boom" },
    { 0x11467, "unset_relic_damage_from_above" },
    { 0x11468, "unset_relic_dfa" },
    { 0x11469, "unset_relic_dogtags" },
    { 0x1146A, "unset_relic_doomslayer" },
    { 0x1146B, "unset_relic_doubletap" },
    { 0x1146C, "unset_relic_explodedmg" },
    { 0x1146D, "unset_relic_fastbleedout" },
    { 0x1146E, "unset_relic_focus_fire" },
    { 0x1146F, "unset_relic_gas_martyr" },
    { 0x11470, "unset_relic_grounded" },
    { 0x11471, "unset_relic_gun_game" },
    { 0x11472, "unset_relic_headbullets" },
    { 0x11473, "unset_relic_healthpacks" },
    { 0x11474, "unset_relic_hideobjicons" },
    { 0x11475, "unset_relic_landlocked" },
    { 0x11476, "unset_relic_laststand" },
    { 0x11477, "unset_relic_laststandmelee" },
    { 0x11478, "unset_relic_lfo" },
    { 0x11479, "unset_relic_martyrdom" },
    { 0x1147A, "unset_relic_mythic" },
    { 0x1147B, "unset_relic_no_ammo_mun" },
    { 0x1147C, "unset_relic_nobulletdamage" },
    { 0x1147D, "unset_relic_noks" },
    { 0x1147E, "unset_relic_noluck" },
    { 0x1147F, "unset_relic_noregen" },
    { 0x11480, "unset_relic_nuketimer" },
    { 0x11481, "unset_relic_oneclip" },
    { 0x11482, "unset_relic_punchbullets" },
    { 0x11483, "unset_relic_rocket_kill_ammo" },
    { 0x11484, "unset_relic_shieldsonly" },
    { 0x11485, "unset_relic_squadlink" },
    { 0x11486, "unset_relic_steelballs" },
    { 0x11487, "unset_relic_team_proximity" },
    { 0x11488, "unset_relic_thirdperson" },
    { 0x11489, "unset_relic_trex" },
    { 0x1148A, "unset_relic_vampire" },
    { 0x1148B, "unset_slow_healthregen" },
    { 0x1148C, "unset_stay_at_spawn_flag_on_entering_combat" },
    { 0x1148D, "unset_tank_icon_on_death" },
    { 0x1148E, "unset_vehicle_only_wave" },
    { 0x1148F, "unsetbettermissionrewards" },
    { 0x11490, "unsetchainkillstreaks" },
    { 0x11491, "unsetobjectivemarker" },
    { 0x11492, "unsetreduceregendelayonkill" },
    { 0x11493, "unsetreduceregendelayonkills" },
    { 0x11494, "unsetspecialistbonus" },
    { 0x11495, "unsetweaponcarry" },
    { 0x11496, "unstable_gauge_timer_active" },
    { 0x11497, "untrack_enemy" },
    { 0x11498, "unuseweapon" },
    { 0x11499, "update2v2progress" },
    { 0x1149A, "update_ai_array" },
    { 0x1149B, "update_ai_volumes" },
    { 0x1149C, "update_bomb_interaction_ent" },
    { 0x1149D, "update_bomb_vest_cell_phone_holder_timer" },
    { 0x1149E, "update_bomb_vest_controller" },
    { 0x1149F, "update_bomb_vest_lua" },
    { 0x114A0, "update_current_solution" },
    { 0x114A1, "update_enemies_remaining" },
    { 0x114A2, "update_focus_fire_heahicon" },
    { 0x114A3, "update_focus_fire_objective" },
    { 0x114A4, "update_future_stations_track_timers" },
    { 0x114A5, "update_game_cyber" },
    { 0x114A6, "update_gamebattles_char_loc" },
    { 0x114A7, "update_goal_population" },
    { 0x114A8, "update_hack_objective_marker" },
    { 0x114A9, "update_health_bar_to_player" },
    { 0x114AA, "update_health_bar_to_players" },
    { 0x114AB, "update_health_on_spawn" },
    { 0x114AC, "update_health_think" },
    { 0x114AD, "update_health_value_for_special_cases" },
    { 0x114AE, "update_hint_logic_juggernaut" },
    { 0x114AF, "update_hint_logic_killstreak" },
    { 0x114B0, "update_hint_logic_munitions" },
    { 0x114B1, "update_hint_logic_offhand" },
    { 0x114B2, "update_icon_for_bomb_case_detonator_holder" },
    { 0x114B3, "update_jugg_targets" },
    { 0x114B4, "update_keypad_currentdisplay_models" },
    { 0x114B5, "update_last_stand_id" },
    { 0x114B6, "update_objective_mlgicon" },
    { 0x114B7, "update_objective_mlgicon_reset" },
    { 0x114B8, "update_objective_ownerclient" },
    { 0x114B9, "update_objective_setmlgbackground" },
    { 0x114BA, "update_operator_east_char_loc" },
    { 0x114BB, "update_operator_west_char_loc" },
    { 0x114BC, "update_player_about_remaining_enemies" },
    { 0x114BD, "update_player_enemy_on_death" },
    { 0x114BE, "update_readings" },
    { 0x114BF, "update_restock_ui" },
    { 0x114C0, "update_sentry_settings" },
    { 0x114C1, "update_spot_limit" },
    { 0x114C2, "update_timer_for_bomb_case_detonator_holder" },
    { 0x114C3, "update_timer_for_bomb_vest_detonator_holder" },
    { 0x114C4, "update_track_operational_status" },
    { 0x114C5, "update_track_timer" },
    { 0x114C6, "update_tracks_operational_status" },
    { 0x114C7, "update_volume_flag" },
    { 0x114C8, "updateachievementhangtime" },
    { 0x114C9, "updatearenaomnvardata" },
    { 0x114CA, "updatearenaomnvarplayers" },
    { 0x114CB, "updateassassinationdataomnvar" },
    { 0x114CC, "updateassassinationthreatlevel" },
    { 0x114CD, "updatebotpersonalitybasedonweapon" },
    { 0x114CE, "updatebufferedstatsatgameend" },
    { 0x114CF, "updateburningtodeath" },
    { 0x114D0, "updatec4vehiclemultkill" },
    { 0x114D1, "updatecallback" },
    { 0x114D2, "updatecirclepulse" },
    { 0x114D3, "updateclientmatchdata" },
    { 0x114D4, "updatecollectionui" },
    { 0x114D5, "updatecollectionuiforplayer" },
    { 0x114D6, "updatedragonsbreath" },
    { 0x114D7, "updatedroprelics" },
    { 0x114D8, "updatedroprelicsfunc" },
    { 0x114D9, "updateexpiredlootleader" },
    { 0x114DA, "updatefobindanger" },
    { 0x114DB, "updatefobspawnsindanger" },
    { 0x114DC, "updateghostridekills" },
    { 0x114DD, "updatehistoryhud" },
    { 0x114DE, "updateindangercirclestate" },
    { 0x114DF, "updateinstantclassswapallowedinternal" },
    { 0x114E0, "updateleaders" },
    { 0x114E1, "updateleadmarkers" },
    { 0x114E2, "updatelocationbesttime" },
    { 0x114E3, "updatelocationbesttimehud" },
    { 0x114E4, "updatelootleadercirclesize" },
    { 0x114E5, "updatelootleadermarks" },
    { 0x114E6, "updatelootleadersonfixedinterval" },
    { 0x114E7, "updatematchstatushintonhasflag" },
    { 0x114E8, "updatematchstatushintonnoflag" },
    { 0x114E9, "updatemlgspectatorinfo" },
    { 0x114EA, "updatenukeprogress" },
    { 0x114EB, "updateondamagepredamagemodrelics" },
    { 0x114EC, "updateondamagepredamagemodrelicsfunc" },
    { 0x114ED, "updateparachutestreamhint" },
    { 0x114EE, "updateplayerandteamcountui" },
    { 0x114EF, "updateplayereliminatedomnvar" },
    { 0x114F0, "updateplayerleaderboardstatsinternal" },
    { 0x114F1, "updateplayeromnvarsallmatches" },
    { 0x114F2, "updateplayerspawninputtype" },
    { 0x114F3, "updateprematchloadoutarray" },
    { 0x114F4, "updateprestreamrespawn" },
    { 0x114F5, "updaterectangularzone" },
    { 0x114F6, "updaterespawnstatus" },
    { 0x114F7, "updaterotatedebug" },
    { 0x114F8, "updatescavengerhud" },
    { 0x114F9, "updatescrapassistdata" },
    { 0x114FA, "updatescrapassistdataforcecredit" },
    { 0x114FB, "updatesecretstashhud" },
    { 0x114FC, "updatesixthsensevo" },
    { 0x114FD, "updatesmokinggunhud" },
    { 0x114FE, "updatespecificfobindanger" },
    { 0x114FF, "updatesquadleaderpassstateforteam" },
    { 0x11500, "updatesquadmemberlaststandreviveprogress" },
    { 0x11501, "updatesuperuiprogress" },
    { 0x11502, "updateteambettermissionrewardsui" },
    { 0x11503, "updateteamplunderhud" },
    { 0x11504, "updateteamplunderscore" },
    { 0x11505, "updateteamscoreplacements" },
    { 0x11506, "updatetextongamepadchange" },
    { 0x11507, "updatetimedrunhud" },
    { 0x11508, "updatetriggerforcodcaster" },
    { 0x11509, "updatex1finhud" },
    { 0x1150A, "updatex1prematchloadoutarray" },
    { 0x1150B, "updatex1stashhud" },
    { 0x1150C, "upload_station_interact_used_think" },
    { 0x1150D, "upload_station_players_manager" },
    { 0x1150E, "upper_door_coll" },
    { 0x1150F, "usablecarriables" },
    { 0x11510, "usageloop" },
    { 0x11511, "usb" },
    { 0x11512, "usb_keys" },
    { 0x11513, "usb_left" },
    { 0x11514, "usb_right" },
    { 0x11515, "usb_tape_animation_test" },
    { 0x11516, "usbmodel" },
    { 0x11517, "usbs_pulled_out" },
    { 0x11518, "usbserver" },
    { 0x11519, "usbvm" },
    { 0x1151A, "usbwm" },
    { 0x1151B, "use_airdrop_fx" },
    { 0x1151C, "use_aitype" },
    { 0x1151D, "use_alt_computer_controls" },
    { 0x1151E, "use_armor" },
    { 0x1151F, "use_contract" },
    { 0x11520, "use_csm" },
    { 0x11521, "use_dropkit_marker" },
    { 0x11522, "use_emp_drone" },
    { 0x11523, "use_emp_drone_func" },
    { 0x11524, "use_milcrate" },
    { 0x11525, "use_nvg_think" },
    { 0x11526, "use_respawn_rules" },
    { 0x11527, "use_struct" },
    { 0x11528, "use_trace_radius" },
    { 0x11529, "use_vehicle_turret" },
    { 0x1152A, "useagents" },
    { 0x1152B, "useautorespawn" },
    { 0x1152C, "usecallback" },
    { 0x1152D, "usecellspawns" },
    { 0x1152E, "usedcountinveh" },
    { 0x1152F, "usedprops" },
    { 0x11530, "usedpropsindex" },
    { 0x11531, "usedropspawn" },
    { 0x11532, "usedspawners" },
    { 0x11533, "useeventamount" },
    { 0x11534, "useeventtimestamp" },
    { 0x11535, "useeventtype" },
    { 0x11536, "usefailcapacitymsg" },
    { 0x11537, "usefailextractingmsg" },
    { 0x11538, "usefaillaststandmsg" },
    { 0x11539, "usefailnoplundermsg" },
    { 0x1153A, "usefailvehiclemsg" },
    { 0x1153B, "usefloorrocks" },
    { 0x1153C, "usefuncoverride" },
    { 0x1153D, "usemilestonephases" },
    { 0x1153E, "usepingsystem" },
    { 0x1153F, "useprophudserver" },
    { 0x11540, "usequesttimer" },
    { 0x11541, "usereload" },
    { 0x11542, "usescriptablemeleeblood" },
    { 0x11543, "useserverhud" },
    { 0x11544, "useshouldsucceedcallback" },
    { 0x11545, "usetimeoverride" },
    { 0x11546, "useweaponpickups" },
    { 0x11547, "using_mun" },
    { 0x11548, "using_self_revive" },
    { 0x11549, "usingfallback" },
    { 0x1154A, "usingobject" },
    { 0x1154B, "usingtacmap" },
    { 0x1154C, "utilflare_shootflare" },
    { 0x1154D, "v_end_pos" },
    { 0x1154E, "v_start_pos" },
    { 0x1154F, "va_cluster_spawnpoint_valid" },
    { 0x11550, "va_standard_spawnpoint_valid" },
    { 0x11551, "valid_carriable_pickup_weapon" },
    { 0x11552, "validate_and_activate_stations" },
    { 0x11553, "validate_demeanor" },
    { 0x11554, "validate_station" },
    { 0x11555, "validate_track" },
    { 0x11556, "validatealivecount" },
    { 0x11557, "validateboltent" },
    { 0x11558, "validatedamagerelicswat" },
    { 0x11559, "validateevents" },
    { 0x1155A, "validatefuelstability" },
    { 0x1155B, "validatefunc" },
    { 0x1155C, "validateplundereventtype" },
    { 0x1155D, "validateprojectileent" },
    { 0x1155E, "validautoassignquests" },
    { 0x1155F, "validchallengetimer" },
    { 0x11560, "validtousecosmetic" },
    { 0x11561, "validtousesticker" },
    { 0x11562, "valuehud" },
    { 0x11563, "valve_steam_off" },
    { 0x11564, "valve_steam_on" },
    { 0x11565, "vampirepoints" },
    { 0x11566, "van" },
    { 0x11567, "van_blocker_moves" },
    { 0x11568, "van_infil_sfx_chief" },
    { 0x11569, "van_initdamage" },
    { 0x1156A, "van_initomnvars" },
    { 0x1156B, "van_stop_vo" },
    { 0x1156C, "vandalize" },
    { 0x1156D, "vandalize_attack_max_cooldown" },
    { 0x1156E, "vandalize_attack_min_cooldown" },
    { 0x1156F, "vandalize_attack_nodes" },
    { 0x11570, "vandalize_internal" },
    { 0x11571, "vandalize_minigun_speed" },
    { 0x11572, "vandalize_spotlight_speed" },
    { 0x11573, "vandalize_target_think" },
    { 0x11574, "vars_print" },
    { 0x11575, "vars_update" },
    { 0x11576, "vault_assault_infil" },
    { 0x11577, "vault_gate_cut" },
    { 0x11578, "vcloseangles" },
    { 0x11579, "vector_length" },
    { 0x1157A, "veh_updateomnvarsperframeforclient" },
    { 0x1157B, "vehcolignorelist" },
    { 0x1157C, "vehicle_ai_avoidance_cleanup" },
    { 0x1157D, "vehicle_ai_script_models" },
    { 0x1157E, "vehicle_checkpiggybackexploit" },
    { 0x1157F, "vehicle_checktrailvfx" },
    { 0x11580, "vehicle_clearpreventplayercollisiondamagefortimeafterexit" },
    { 0x11581, "vehicle_collision" },
    { 0x11582, "vehicle_collision_dvarinit" },
    { 0x11583, "vehicle_collision_dvarupdate" },
    { 0x11584, "vehicle_collision_getdamagefactor" },
    { 0x11585, "vehicle_collision_getdamagepercentandburndown" },
    { 0x11586, "vehicle_collision_geteventdata" },
    { 0x11587, "vehicle_collision_getignoreevent" },
    { 0x11588, "vehicle_collision_getleveldata" },
    { 0x11589, "vehicle_collision_getleveldataforvehicle" },
    { 0x1158A, "vehicle_collision_handleevent" },
    { 0x1158B, "vehicle_collision_handlemultievent" },
    { 0x1158C, "vehicle_collision_ignorefutureevent" },
    { 0x1158D, "vehicle_collision_ignorefuturemultievent" },
    { 0x1158E, "vehicle_collision_init" },
    { 0x1158F, "vehicle_collision_loadtable" },
    { 0x11590, "vehicle_collision_loadtablecell" },
    { 0x11591, "vehicle_collision_registerevent" },
    { 0x11592, "vehicle_collision_registereventinternal" },
    { 0x11593, "vehicle_collision_takedamage" },
    { 0x11594, "vehicle_collision_update" },
    { 0x11595, "vehicle_collision_updateinstance" },
    { 0x11596, "vehicle_collision_updateinstanceend" },
    { 0x11597, "vehicle_compass_br_shouldbevisibletoplayer" },
    { 0x11598, "vehicle_compass_cp_init" },
    { 0x11599, "vehicle_compass_cp_shouldbevisibletoplayer" },
    { 0x1159A, "vehicle_compass_deregisterinstance" },
    { 0x1159B, "vehicle_compass_friendlystatuschangedcallback" },
    { 0x1159C, "vehicle_compass_getleveldata" },
    { 0x1159D, "vehicle_compass_hide" },
    { 0x1159E, "vehicle_compass_infect_shouldbevisibletoplayer" },
    { 0x1159F, "vehicle_compass_init" },
    { 0x115A0, "vehicle_compass_instanceisregistered" },
    { 0x115A1, "vehicle_compass_mp_init" },
    { 0x115A2, "vehicle_compass_mp_shouldbevisibletoplayer" },
    { 0x115A3, "vehicle_compass_playerjoinedteamcallback" },
    { 0x115A4, "vehicle_compass_playerspawnedcallback" },
    { 0x115A5, "vehicle_compass_registerinstance" },
    { 0x115A6, "vehicle_compass_setplayerfriendlyto" },
    { 0x115A7, "vehicle_compass_setteamfriendlyto" },
    { 0x115A8, "vehicle_compass_shouldbevisibletoplayer" },
    { 0x115A9, "vehicle_compass_show" },
    { 0x115AA, "vehicle_compass_updateallvisibilityforplayer" },
    { 0x115AB, "vehicle_compass_updatevisibilityforallplayers" },
    { 0x115AC, "vehicle_compass_updatevisibilityforplayer" },
    { 0x115AD, "vehicle_cp_create" },
    { 0x115AE, "vehicle_cp_createlate" },
    { 0x115AF, "vehicle_cp_deletenextframe" },
    { 0x115B0, "vehicle_cp_deletenextframelate" },
    { 0x115B1, "vehicle_create" },
    { 0x115B2, "vehicle_createlate" },
    { 0x115B3, "vehicle_createspawnselectionlittlebirdmarker" },
    { 0x115B4, "vehicle_createspawnselectiontankmarker" },
    { 0x115B5, "vehicle_damage_applytabletovehicle" },
    { 0x115B6, "vehicle_damage_beginburndown" },
    { 0x115B7, "vehicle_damage_cp_init" },
    { 0x115B8, "vehicle_damage_deregisterdefaultvisuals" },
    { 0x115B9, "vehicle_damage_deregisterinstance" },
    { 0x115BA, "vehicle_damage_deregistervisualpercentcallback" },
    { 0x115BB, "vehicle_damage_disablestatedamagefloor" },
    { 0x115BC, "vehicle_damage_endburndown" },
    { 0x115BD, "vehicle_damage_enginevisualcallback" },
    { 0x115BE, "vehicle_damage_enginevisualclearcallback" },
    { 0x115BF, "vehicle_damage_getburndowntime" },
    { 0x115C0, "vehicle_damage_getheavystatehealthadd" },
    { 0x115C1, "vehicle_damage_getheavystatemaxhealth" },
    { 0x115C2, "vehicle_damage_getinstancedataforvehicle" },
    { 0x115C3, "vehicle_damage_getleveldatafordamagestate" },
    { 0x115C4, "vehicle_damage_getmaxhealth" },
    { 0x115C5, "vehicle_damage_getmediumstatehealthratio" },
    { 0x115C6, "vehicle_damage_getpristinestatehealthadd" },
    { 0x115C7, "vehicle_damage_getpristinestateminhealth" },
    { 0x115C8, "vehicle_damage_getstate" },
    { 0x115C9, "vehicle_damage_giveaward" },
    { 0x115CA, "vehicle_damage_givescore" },
    { 0x115CB, "vehicle_damage_givescoreandxp" },
    { 0x115CC, "vehicle_damage_givescoreandxpatframeend" },
    { 0x115CD, "vehicle_damage_heavyvisualcallback" },
    { 0x115CE, "vehicle_damage_inithitdamage" },
    { 0x115CF, "vehicle_damage_inithitdamage_br" },
    { 0x115D0, "vehicle_damage_initmoddamage" },
    { 0x115D1, "vehicle_damage_isburningdown" },
    { 0x115D2, "vehicle_damage_lightvisualcallback" },
    { 0x115D3, "vehicle_damage_loadtable" },
    { 0x115D4, "vehicle_damage_loadtablecell" },
    { 0x115D5, "vehicle_damage_mediumvisualcallback" },
    { 0x115D6, "vehicle_damage_mp_init" },
    { 0x115D7, "vehicle_damage_ondeathscore" },
    { 0x115D8, "vehicle_damage_onenterstateheavy" },
    { 0x115D9, "vehicle_damage_onenterstateheavyscore" },
    { 0x115DA, "vehicle_damage_onenterstatelight" },
    { 0x115DB, "vehicle_damage_onenterstatemedium" },
    { 0x115DC, "vehicle_damage_onexitstateheavy" },
    { 0x115DD, "vehicle_damage_onexitstatelight" },
    { 0x115DE, "vehicle_damage_onexitstatemedium" },
    { 0x115DF, "vehicle_damage_registerdefaultstates" },
    { 0x115E0, "vehicle_damage_registerdefaultvisuals" },
    { 0x115E1, "vehicle_damage_registerinstance" },
    { 0x115E2, "vehicle_damage_registervisualpercentcallback" },
    { 0x115E3, "vehicle_damage_setdeathcallback" },
    { 0x115E4, "vehicle_damage_setperkmoddamage" },
    { 0x115E5, "vehicle_damage_setpostmoddamagecallback" },
    { 0x115E6, "vehicle_damage_setpremoddamagecallback" },
    { 0x115E7, "vehicle_damage_setstate" },
    { 0x115E8, "vehicle_damage_setvehiclehitdamagedata" },
    { 0x115E9, "vehicle_damage_setvehiclehitdamagedataforweapon" },
    { 0x115EA, "vehicle_damage_setweaponclassmoddamageforvehicle" },
    { 0x115EB, "vehicle_damage_setweaponhitdamagedata" },
    { 0x115EC, "vehicle_damage_setweaponhitdamagedataforvehicle" },
    { 0x115ED, "vehicle_damage_shouldskipburndown" },
    { 0x115EE, "vehicle_damage_updatestate" },
    { 0x115EF, "vehicle_damage_updatestate_br" },
    { 0x115F0, "vehicle_damage_updatestatemaxhealthvalues" },
    { 0x115F1, "vehicle_damage_visualwatchspeedchange" },
    { 0x115F2, "vehicle_deletenextframe" },
    { 0x115F3, "vehicle_deletenextframelate" },
    { 0x115F4, "vehicle_deregister_on_death" },
    { 0x115F5, "vehicle_deregisterturret" },
    { 0x115F6, "vehicle_dismount_watcher" },
    { 0x115F7, "vehicle_dlog_enterevent" },
    { 0x115F8, "vehicle_docollisiondamagetoplayer" },
    { 0x115F9, "vehicle_fob_think" },
    { 0x115FA, "vehicle_getteamfriendlyto" },
    { 0x115FB, "vehicle_getturretbyweapon" },
    { 0x115FC, "vehicle_getturrets" },
    { 0x115FD, "vehicle_handleflarefire" },
    { 0x115FE, "vehicle_handleflarerecharge" },
    { 0x115FF, "vehicle_has_flare" },
    { 0x11600, "vehicle_incomingcallback" },
    { 0x11601, "vehicle_incomingremovedcallback" },
    { 0x11602, "vehicle_interact_initdev" },
    { 0x11603, "vehicle_invalid_seats" },
    { 0x11604, "vehicle_is_ambient" },
    { 0x11605, "vehicle_isenemytoplayer" },
    { 0x11606, "vehicle_isenemytoteam" },
    { 0x11607, "vehicle_isfriendlytoplayer" },
    { 0x11608, "vehicle_isfriendlytoteam" },
    { 0x11609, "vehicle_isneutraltoplayer" },
    { 0x1160A, "vehicle_isneutraltoteam" },
    { 0x1160B, "vehicle_lights_manager" },
    { 0x1160C, "vehicle_mp_create" },
    { 0x1160D, "vehicle_mp_createlate" },
    { 0x1160E, "vehicle_mp_deletenextframe" },
    { 0x1160F, "vehicle_mp_deletenextframelate" },
    { 0x11610, "vehicle_occupancy_allowspawninto" },
    { 0x11611, "vehicle_occupancy_canspawninto" },
    { 0x11612, "vehicle_occupancy_cleanfriendlystatus" },
    { 0x11613, "vehicle_occupancy_clearallowmovementplayer" },
    { 0x11614, "vehicle_occupancy_clearforceweaponswitchallowed" },
    { 0x11615, "vehicle_occupancy_clearseatcorpse" },
    { 0x11616, "vehicle_occupancy_cp_giveriotshield" },
    { 0x11617, "vehicle_occupancy_cp_handlesuicidefromvehicles" },
    { 0x11618, "vehicle_occupancy_cp_takeriotshield" },
    { 0x11619, "vehicle_occupancy_cp_updateriotshield" },
    { 0x1161A, "vehicle_occupancy_errormessage" },
    { 0x1161B, "vehicle_occupancy_fadeoutcontrols" },
    { 0x1161C, "vehicle_occupancy_forceweaponswitchallowed" },
    { 0x1161D, "vehicle_occupancy_friendlystatuschangedcallback" },
    { 0x1161E, "vehicle_occupancy_getplayerfriendlyto" },
    { 0x1161F, "vehicle_occupancy_getreserving" },
    { 0x11620, "vehicle_occupancy_getteamfriendlyto" },
    { 0x11621, "vehicle_occupancy_giveriotshield" },
    { 0x11622, "vehicle_occupancy_handleplayerbc" },
    { 0x11623, "vehicle_occupancy_hidecashbag" },
    { 0x11624, "vehicle_occupancy_instanceisregistered" },
    { 0x11625, "vehicle_occupancy_isdriverseat" },
    { 0x11626, "vehicle_occupancy_isenemytoplayer" },
    { 0x11627, "vehicle_occupancy_isenemytoteam" },
    { 0x11628, "vehicle_occupancy_isfriendlytoplayer" },
    { 0x11629, "vehicle_occupancy_isfriendlytoteam" },
    { 0x1162A, "vehicle_occupancy_isneutraltoplayer" },
    { 0x1162B, "vehicle_occupancy_isneutraltoteam" },
    { 0x1162C, "vehicle_occupancy_linktooriginandangles" },
    { 0x1162D, "vehicle_occupancy_monitorcontrols" },
    { 0x1162E, "vehicle_occupancy_monitorgameended" },
    { 0x1162F, "vehicle_occupancy_monitormovementcontrols" },
    { 0x11630, "vehicle_occupancy_monitorturretcontrols" },
    { 0x11631, "vehicle_occupancy_mp_changedseats" },
    { 0x11632, "vehicle_occupancy_mp_giveriotshield" },
    { 0x11633, "vehicle_occupancy_mp_hidecashbag" },
    { 0x11634, "vehicle_occupancy_mp_showcashbag" },
    { 0x11635, "vehicle_occupancy_mp_takeriotshield" },
    { 0x11636, "vehicle_occupancy_mp_updateriotshield" },
    { 0x11637, "vehicle_occupancy_setfriendlystatusdirty" },
    { 0x11638, "vehicle_occupancy_showcashbag" },
    { 0x11639, "vehicle_occupancy_takeriotshield" },
    { 0x1163A, "vehicle_occupancy_updateriotshield" },
    { 0x1163B, "vehicle_on_last_pathing_array" },
    { 0x1163C, "vehicle_outline_watcher" },
    { 0x1163D, "vehicle_playerenteredtrackedlittlebird" },
    { 0x1163E, "vehicle_playerkilledfx" },
    { 0x1163F, "vehicle_playershouldignorecollisiondamage" },
    { 0x11640, "vehicle_preventplayercollisiondamagefortimeafterexit" },
    { 0x11641, "vehicle_preventplayercollisiondamagefortimeafterexitinternal" },
    { 0x11642, "vehicle_process_node_when_at_goal" },
    { 0x11643, "vehicle_register_on_level" },
    { 0x11644, "vehicle_registerturret" },
    { 0x11645, "vehicle_registration_func" },
    { 0x11646, "vehicle_remove_invulnerability_onenter" },
    { 0x11647, "vehicle_rider_think" },
    { 0x11648, "vehicle_shoulddocollisiondamagetoplayer" },
    { 0x11649, "vehicle_showteamtanks" },
    { 0x1164A, "vehicle_showvalidlittlebirds" },
    { 0x1164B, "vehicle_spawn_abandonedtimeout" },
    { 0x1164C, "vehicle_spawn_abandonedtimeoutcallback" },
    { 0x1164D, "vehicle_spawn_cancelpendingrespawns" },
    { 0x1164E, "vehicle_spawn_cp_gamemodesupportsabandonedtimeout" },
    { 0x1164F, "vehicle_spawn_gamemodesupportsabandonedtimeout" },
    { 0x11650, "vehicle_spawn_initdev" },
    { 0x11651, "vehicle_spawn_mp_gamemodesupportsabandonedtimeout" },
    { 0x11652, "vehicle_spawn_preventrespawn" },
    { 0x11653, "vehicle_spawn_stopwatchingabandoned" },
    { 0x11654, "vehicle_spawn_waitandrespawn" },
    { 0x11655, "vehicle_spawn_watchabandoned" },
    { 0x11656, "vehicle_stop_moving" },
    { 0x11657, "vehicle_tracker" },
    { 0x11658, "vehicle_tracking_cp_post_spawn" },
    { 0x11659, "vehicle_trackturretprojectile" },
    { 0x1165A, "vehicle_travel_player_connect_monitor" },
    { 0x1165B, "vehicle_travel_player_disconnect_monitor" },
    { 0x1165C, "vehicle_update" },
    { 0x1165D, "vehicle_watchmarkedlittlebirddeath" },
    { 0x1165E, "vehicle_watchmarkedtankdeath" },
    { 0x1165F, "vehicleaniminit" },
    { 0x11660, "vehiclecankillhealth" },
    { 0x11661, "vehiclecanopendoor" },
    { 0x11662, "vehiclecustomization" },
    { 0x11663, "vehicledamageimmunity" },
    { 0x11664, "vehiclegod" },
    { 0x11665, "vehicleindangertracking" },
    { 0x11666, "vehiclelinkto" },
    { 0x11667, "vehicleoccupantdeathcustomcallback" },
    { 0x11668, "vehicleoccupants" },
    { 0x11669, "vehicleoutline" },
    { 0x1166A, "vehicleparent" },
    { 0x1166B, "vehiclereserved" },
    { 0x1166C, "vehicles_spawned" },
    { 0x1166D, "vehiclespawn_armoredtruck" },
    { 0x1166E, "vehiclespawn_cargotruckmg" },
    { 0x1166F, "vehiclespawn_littlebirdmg" },
    { 0x11670, "vehiclespawninginto" },
    { 0x11671, "vehicletrail" },
    { 0x11672, "vehicleturretshootthread" },
    { 0x11673, "vehicleunlink" },
    { 0x11674, "vehoccupancy_lastbctime" },
    { 0x11675, "vehoccupancy_lastseatbc" },
    { 0x11676, "vehomn_clearcontrols" },
    { 0x11677, "vehomn_clearleveldataforvehicle" },
    { 0x11678, "vehomn_controlsarefadedoutorhidden" },
    { 0x11679, "vehomn_fadeoutcontrols" },
    { 0x1167A, "vehomn_fadeoutcontrolsforclient" },
    { 0x1167B, "vehomn_getleveldata" },
    { 0x1167C, "vehomn_getleveldataforvehicle" },
    { 0x1167D, "vehomn_getrotationentangles" },
    { 0x1167E, "vehomn_hidecontrols" },
    { 0x1167F, "vehomn_showcontrols" },
    { 0x11680, "vehomn_updateomnvarsperframe" },
    { 0x11681, "vehomn_updaterotationomnvarsperframeforclient" },
    { 0x11682, "vehomncontrols" },
    { 0x11683, "velendid" },
    { 0x11684, "velnormals" },
    { 0x11685, "velnumdatapoints" },
    { 0x11686, "velo_forward_memory" },
    { 0x11687, "velstartid" },
    { 0x11688, "verbal_clip" },
    { 0x11689, "verbal_string" },
    { 0x1168A, "verify_chopper_pilot" },
    { 0x1168B, "vfx" },
    { 0x1168C, "vfx_flare" },
    { 0x1168D, "vfx_height" },
    { 0x1168E, "vfx_htown_hadirj_blink" },
    { 0x1168F, "vfx_htown_stab_blink_1" },
    { 0x11690, "vfx_htown_stab_blink_2" },
    { 0x11691, "vfx_htown_stab_blink_3" },
    { 0x11692, "vfx_htown_stab_blink_ak" },
    { 0x11693, "vfx_smoke" },
    { 0x11694, "vfx_special_height" },
    { 0x11695, "vfx_special_time" },
    { 0x11696, "vfx_stab_tear_screenfx_01" },
    { 0x11697, "vfx_start" },
    { 0x11698, "vfx_struct" },
    { 0x11699, "vfx_time" },
    { 0x1169A, "view_list" },
    { 0x1169B, "viewmodel_demeanor" },
    { 0x1169C, "vindia_assault3" },
    { 0x1169D, "vindia_assault3_check_size" },
    { 0x1169E, "vip_bink_vo" },
    { 0x1169F, "vip_completequest" },
    { 0x116A0, "vip_death_player_hits_million" },
    { 0x116A1, "vip_failquest" },
    { 0x116A2, "vip_freeze_link" },
    { 0x116A3, "vip_info" },
    { 0x116A4, "vip_onentergulag" },
    { 0x116A5, "vip_onrespawn" },
    { 0x116A6, "vip_ontimerexpired" },
    { 0x116A7, "vip_playerdied" },
    { 0x116A8, "vip_playerdisconnect" },
    { 0x116A9, "vip_playerremoved" },
    { 0x116AA, "vip_questthink_iconposition" },
    { 0x116AB, "vip_removequestinstance" },
    { 0x116AC, "vip_respawnplayer" },
    { 0x116AD, "vipbot_movesup" },
    { 0x116AE, "viphud_deletehud" },
    { 0x116AF, "viphud_hidefromplayer" },
    { 0x116B0, "viphud_setupvisibility" },
    { 0x116B1, "viphud_showtoplayer" },
    { 0x116B2, "visibilityisscriptcontrolled" },
    { 0x116B3, "visible2state" },
    { 0x116B4, "vo_areas_remaining" },
    { 0x116B5, "vo_boss_heli" },
    { 0x116B6, "vo_control_tower" },
    { 0x116B7, "vo_crates_remaining" },
    { 0x116B8, "vo_death_drop_and_cash_protection" },
    { 0x116B9, "vo_do_loudspeaker" },
    { 0x116BA, "vo_enemy_armor" },
    { 0x116BB, "vo_enemy_heli" },
    { 0x116BC, "vo_exfil_helo_arrived_nag" },
    { 0x116BD, "vo_five_remain" },
    { 0x116BE, "vo_goto_router" },
    { 0x116BF, "vo_hacking_done" },
    { 0x116C0, "vo_hangar_door" },
    { 0x116C1, "vo_incoming_mortar" },
    { 0x116C2, "vo_interrogation_enforcer_ads_family_reaction" },
    { 0x116C3, "vo_interrogation_exit_killed_butcher" },
    { 0x116C4, "vo_jug_wait_to_be_seen" },
    { 0x116C5, "vo_jugg_stealth" },
    { 0x116C6, "vo_manifest_scanned" },
    { 0x116C7, "vo_nag_hangar" },
    { 0x116C8, "vo_nag_mark_crates" },
    { 0x116C9, "vo_nag_plant_router" },
    { 0x116CA, "vo_one_remain" },
    { 0x116CB, "vo_paratroopers" },
    { 0x116CC, "vo_stealth_broken" },
    { 0x116CD, "vo_stealth_exchange" },
    { 0x116CE, "vo_ten_remain" },
    { 0x116CF, "vo_three_remain" },
    { 0x116D0, "vo_two_remain" },
    { 0x116D1, "vo_use_computer" },
    { 0x116D2, "vo_while_reviving" },
    { 0x116D3, "vocalloutstring" },
    { 0x116D4, "vopenangles" },
    { 0x116D5, "voqueue" },
    { 0x116D6, "vote_player_init" },
    { 0x116D7, "vote_player_reset" },
    { 0x116D8, "vote_player_set" },
    { 0x116D9, "votes" },
    { 0x116DA, "votesys_init" },
    { 0x116DB, "votesys_new" },
    { 0x116DC, "votesys_think" },
    { 0x116DD, "votesys_update_playercount" },
    { 0x116DE, "votesys_update_time" },
    { 0x116DF, "voting" },
    { 0x116E0, "vstartposition" },
    { 0x116E1, "wagingplayer" },
    { 0x116E2, "wait_after_first_counter" },
    { 0x116E3, "wait_and_destroy" },
    { 0x116E4, "wait_at_station" },
    { 0x116E5, "wait_between_combat_action" },
    { 0x116E6, "wait_between_stations" },
    { 0x116E7, "wait_display_pavelow_boss_health_bar" },
    { 0x116E8, "wait_fire_mainhouse_flashbangs_and_smokes" },
    { 0x116E9, "wait_for_all_players_in_airlock" },
    { 0x116EA, "wait_for_all_traps_disabled" },
    { 0x116EB, "wait_for_anyone_nearby_hint" },
    { 0x116EC, "wait_for_at_least_one_player_spawns_in" },
    { 0x116ED, "wait_for_chopper_boss_finish_turning" },
    { 0x116EE, "wait_for_computer_power" },
    { 0x116EF, "wait_for_delay_and_then_blowup_plane" },
    { 0x116F0, "wait_for_door_open" },
    { 0x116F1, "wait_for_elevator" },
    { 0x116F2, "wait_for_enemies_cleared" },
    { 0x116F3, "wait_for_enemies_inarea" },
    { 0x116F4, "wait_for_garage_open" },
    { 0x116F5, "wait_for_gl_pickup" },
    { 0x116F6, "wait_for_kills" },
    { 0x116F7, "wait_for_lmg_dead" },
    { 0x116F8, "wait_for_morales_thanks" },
    { 0x116F9, "wait_for_next_hack_complete" },
    { 0x116FA, "wait_for_one_player_near_point" },
    { 0x116FB, "wait_for_open" },
    { 0x116FC, "wait_for_player_eliminated" },
    { 0x116FD, "wait_for_player_gulag_respawn" },
    { 0x116FE, "wait_for_player_in_gas" },
    { 0x116FF, "wait_for_player_in_gulag" },
    { 0x11700, "wait_for_player_to_getup" },
    { 0x11701, "wait_for_players_init_puzzle" },
    { 0x11702, "wait_for_players_on_platform" },
    { 0x11703, "wait_for_sequence_start" },
    { 0x11704, "wait_for_tank_death" },
    { 0x11705, "wait_for_tanks_almost_gone" },
    { 0x11706, "wait_for_time_or_notify" },
    { 0x11707, "wait_for_weapons_free" },
    { 0x11708, "wait_in_spectate_for_time" },
    { 0x11709, "wait_juggernaut_announce" },
    { 0x1170A, "wait_spawn_center_trucks" },
    { 0x1170B, "wait_spawn_final_juggernaut" },
    { 0x1170C, "wait_spawn_sidehouse_trucks" },
    { 0x1170D, "wait_spawn_trucks_smokescreen" },
    { 0x1170E, "wait_till_time" },
    { 0x1170F, "wait_to_advance" },
    { 0x11710, "wait_to_close_in" },
    { 0x11711, "wait_to_play_intro_vo" },
    { 0x11712, "wait_to_reset_wave_loadout" },
    { 0x11713, "wait_to_spawn_ambush_vehicle" },
    { 0x11714, "wait_to_spawn_r0" },
    { 0x11715, "wait_to_start_exfil_obj" },
    { 0x11716, "wait_to_stop_path_vehicle" },
    { 0x11717, "wait_to_stop_pre_tmtyl_spawners" },
    { 0x11718, "wait_unload_chopper" },
    { 0x11719, "wait_unload_chopper_flood_players" },
    { 0x1171A, "wait_unload_jeep" },
    { 0x1171B, "wait_until_done" },
    { 0x1171C, "wait_until_emp_drone_done" },
    { 0x1171D, "wait_until_impact" },
    { 0x1171E, "wait_until_player_is_near" },
    { 0x1171F, "wait_until_trap_room_clear" },
    { 0x11720, "wait_until_truck_arrives_at_station" },
    { 0x11721, "wait_use_respawn" },
    { 0x11722, "waitandapplybrweaponxp" },
    { 0x11723, "waitandgetnewspawnpoint" },
    { 0x11724, "waitandpause" },
    { 0x11725, "waitandspawnprops" },
    { 0x11726, "waitandstartparachuteoverheadmonitoring" },
    { 0x11727, "waitandstartplunderpolling" },
    { 0x11728, "waitandstartscorepolling" },
    { 0x11729, "waitandsuicide" },
    { 0x1172A, "waitandunloadinfils" },
    { 0x1172B, "waitbombusestart" },
    { 0x1172C, "waitfor_firstgroup_killedoffenough" },
    { 0x1172D, "waitfor_trigger_near_obit" },
    { 0x1172E, "waitforallcrates" },
    { 0x1172F, "waitforanyplayernearpoint" },
    { 0x11730, "waitforgulagfightstocomplete" },
    { 0x11731, "waitforhvttrigger" },
    { 0x11732, "waitformeleedamage" },
    { 0x11733, "waitfornukecarriernearlz" },
    { 0x11734, "waitforoneplayernearlz" },
    { 0x11735, "waitforplayerentering" },
    { 0x11736, "waitforplayerstoconnect" },
    { 0x11737, "waitforplayerstoconnect_countdown" },
    { 0x11738, "waitforplayerstospawn" },
    { 0x11739, "waitforremoteend" },
    { 0x1173A, "waitforreturntobattlestance" },
    { 0x1173B, "waitforstreamsynccomplete" },
    { 0x1173C, "waitforstuck" },
    { 0x1173D, "waitfunc" },
    { 0x1173E, "waitgiveammo" },
    { 0x1173F, "waitillcanspawnclient" },
    { 0x11740, "waiting_for_disable" },
    { 0x11741, "waiting_for_lethal_restock" },
    { 0x11742, "waiting_for_tactical_restock" },
    { 0x11743, "waiting_to_connect" },
    { 0x11744, "waitingforteammaterevive" },
    { 0x11745, "waitingtoplayreviveanimation" },
    { 0x11746, "waitteardowninfilmapomnvars" },
    { 0x11747, "waitthencheckendgame" },
    { 0x11748, "waitthenrespawnsnowballs" },
    { 0x11749, "waitthensetgendersoundcontext" },
    { 0x1174A, "waitthensetvisibleteam" },
    { 0x1174B, "waitthenshowinfecttext" },
    { 0x1174C, "waittill_2" },
    { 0x1174D, "waittill_active_agent_count_under" },
    { 0x1174E, "waittill_all_agents_dead" },
    { 0x1174F, "waittill_all_current_vo_plays" },
    { 0x11750, "waittill_all_targets_activated_or_player_death" },
    { 0x11751, "waittill_all_valid_ai_are_gone" },
    { 0x11752, "waittill_any_2" },
    { 0x11753, "waittill_any_3" },
    { 0x11754, "waittill_any_4" },
    { 0x11755, "waittill_any_5" },
    { 0x11756, "waittill_any_6" },
    { 0x11757, "waittill_any_7" },
    { 0x11758, "waittill_any_8" },
    { 0x11759, "waittill_any_return_1" },
    { 0x1175A, "waittill_any_return_2" },
    { 0x1175B, "waittill_any_return_3" },
    { 0x1175C, "waittill_any_return_4" },
    { 0x1175D, "waittill_any_return_5" },
    { 0x1175E, "waittill_any_return_6" },
    { 0x1175F, "waittill_any_return_7" },
    { 0x11760, "waittill_any_return_no_endon_death_1" },
    { 0x11761, "waittill_any_return_no_endon_death_2" },
    { 0x11762, "waittill_any_return_no_endon_death_3" },
    { 0x11763, "waittill_any_return_no_endon_death_4" },
    { 0x11764, "waittill_any_return_no_endon_death_5" },
    { 0x11765, "waittill_any_return_no_endon_death_6" },
    { 0x11766, "waittill_any_timeout_1" },
    { 0x11767, "waittill_any_timeout_2" },
    { 0x11768, "waittill_any_timeout_3" },
    { 0x11769, "waittill_any_timeout_4" },
    { 0x1176A, "waittill_any_timeout_5" },
    { 0x1176B, "waittill_any_timeout_6" },
    { 0x1176C, "waittill_any_timeout_no_endon_death_1" },
    { 0x1176D, "waittill_any_timeout_no_endon_death_2" },
    { 0x1176E, "waittill_any_timeout_no_endon_death_3" },
    { 0x1176F, "waittill_any_timeout_no_endon_death_4" },
    { 0x11770, "waittill_any_timeout_no_endon_death_5" },
    { 0x11771, "waittill_drone_defined" },
    { 0x11772, "waittill_drone_timeout" },
    { 0x11773, "waittill_dropped_cash_collected" },
    { 0x11774, "waittill_end_condition_met" },
    { 0x11775, "waittill_interrogation_dialogue_or_timeout" },
    { 0x11776, "waittill_juggs_alive" },
    { 0x11777, "waittill_near_goal" },
    { 0x11778, "waittill_num_and_all_spawns_dead_and_time_and_player_reset" },
    { 0x11779, "waittill_objective_start" },
    { 0x1177A, "waittill_pickup_or_timeout" },
    { 0x1177B, "waittill_player_behind_cover" },
    { 0x1177C, "waittill_player_closes_tac_map" },
    { 0x1177D, "waittill_player_collects_death_cash" },
    { 0x1177E, "waittill_player_completes_assassination_contract" },
    { 0x1177F, "waittill_player_completes_scavenger_contract" },
    { 0x11780, "waittill_player_deposits" },
    { 0x11781, "waittill_player_dropkit_crate_used" },
    { 0x11782, "waittill_player_dwells_or_wave_min_count" },
    { 0x11783, "waittill_player_has_dropkit_marker" },
    { 0x11784, "waittill_player_is_in_range" },
    { 0x11785, "waittill_player_moves" },
    { 0x11786, "waittill_player_opens_scavenger_cache" },
    { 0x11787, "waittill_player_opens_tac_map" },
    { 0x11788, "waittill_player_picksup_armor" },
    { 0x11789, "waittill_player_pings_location" },
    { 0x1178A, "waittill_player_uses_assassination_contract" },
    { 0x1178B, "waittill_player_uses_munition" },
    { 0x1178C, "waittill_player_uses_scavenger_contract" },
    { 0x1178D, "waittill_plyer_has_ammo_count" },
    { 0x1178E, "waittill_scout_drone_defined" },
    { 0x1178F, "waittill_scout_drone_timeout" },
    { 0x11790, "waittill_see_infl_lbravo_long_enough" },
    { 0x11791, "waittill_target_group_complete" },
    { 0x11792, "waittill_track_is_operational" },
    { 0x11793, "waittill_trigger_player" },
    { 0x11794, "waittill_unload_complete" },
    { 0x11795, "waittill_usebutton_released_or_time_or_bomb_planted" },
    { 0x11796, "waittill_vo_plays" },
    { 0x11797, "waittill_wave_died_to_or_timeout" },
    { 0x11798, "waittill_wave_spawned_or_timeout" },
    { 0x11799, "waittillarenaplayersnotcapturing" },
    { 0x1179A, "waittillhuntersdrop" },
    { 0x1179B, "waittillmatch_loop" },
    { 0x1179C, "waittillmatch_wait" },
    { 0x1179D, "waittillmatchstarts" },
    { 0x1179E, "waittillplayerlanded" },
    { 0x1179F, "waittillspectating" },
    { 0x117A0, "waittokickoffapcescort" },
    { 0x117A1, "waittoopenaltbunker" },
    { 0x117A2, "waittorumbleonslam" },
    { 0x117A3, "waittoshow" },
    { 0x117A4, "waittothrowsmoke" },
    { 0x117A5, "waituntilallchoppersaredead" },
    { 0x117A6, "wake_everyone_up" },
    { 0x117A7, "wake_on_objective_b" },
    { 0x117A8, "walla_lab_civ_scientists" },
    { 0x117A9, "wam_failure_threshold" },
    { 0x117AA, "wam_first_node" },
    { 0x117AB, "wam_interaction_activate" },
    { 0x117AC, "wam_interaction_hint" },
    { 0x117AD, "wam_interaction_init" },
    { 0x117AE, "wam_interaction_structs" },
    { 0x117AF, "wam_number_of_failures" },
    { 0x117B0, "wam_pointer" },
    { 0x117B1, "wam_sequence" },
    { 0x117B2, "wam_timer_between_each_node" },
    { 0x117B3, "warningbits" },
    { 0x117B4, "warningclearcallbacks" },
    { 0x117B5, "warningendcallbacks" },
    { 0x117B6, "warningstartcallbacks" },
    { 0x117B7, "warp_player_debug" },
    { 0x117B8, "warroomtvs" },
    { 0x117B9, "was_seq3_gassed" },
    { 0x117BA, "wasexecuted" },
    { 0x117BB, "wasflagspawned" },
    { 0x117BC, "wasingulag" },
    { 0x117BD, "wasinlaststand" },
    { 0x117BE, "wassquadspawned" },
    { 0x117BF, "watch_and_open_scriptable_doors_in_radius" },
    { 0x117C0, "watch_bullet_count" },
    { 0x117C1, "watch_everyone_entered_caves" },
    { 0x117C2, "watch_flight_collision" },
    { 0x117C3, "watch_for_ashes_achievement" },
    { 0x117C4, "watch_for_attack" },
    { 0x117C5, "watch_for_convoy_escape" },
    { 0x117C6, "watch_for_damage" },
    { 0x117C7, "watch_for_damage_on_trap" },
    { 0x117C8, "watch_for_damage_on_turret" },
    { 0x117C9, "watch_for_driver_death" },
    { 0x117CA, "watch_for_driver_spawned" },
    { 0x117CB, "watch_for_flash_detonation" },
    { 0x117CC, "watch_for_heli_bosses_dead" },
    { 0x117CD, "watch_for_heli_death" },
    { 0x117CE, "watch_for_heli_getting_killed_directly" },
    { 0x117CF, "watch_for_helis_killed" },
    { 0x117D0, "watch_for_icbm_spawners" },
    { 0x117D1, "watch_for_level_weapons_free" },
    { 0x117D2, "watch_for_long_death" },
    { 0x117D3, "watch_for_maze_ai_events" },
    { 0x117D4, "watch_for_molotov_ambush_and_spawners" },
    { 0x117D5, "watch_for_near_objective_point" },
    { 0x117D6, "watch_for_next_sniper" },
    { 0x117D7, "watch_for_objective_failed" },
    { 0x117D8, "watch_for_owner_disconnect" },
    { 0x117D9, "watch_for_payload_approach_cache_1" },
    { 0x117DA, "watch_for_player_death" },
    { 0x117DB, "watch_for_player_enter_puddle_trigger" },
    { 0x117DC, "watch_for_player_enter_trigger" },
    { 0x117DD, "watch_for_player_entered_trap_room" },
    { 0x117DE, "watch_for_player_going_belowmap_or_oob" },
    { 0x117DF, "watch_for_player_in_gulag" },
    { 0x117E0, "watch_for_player_in_los" },
    { 0x117E1, "watch_for_players_activating_juggmaze_map" },
    { 0x117E2, "watch_for_players_approaching_tugofwar" },
    { 0x117E3, "watch_for_players_entering_area_earlier" },
    { 0x117E4, "watch_for_players_in_front" },
    { 0x117E5, "watch_for_players_in_plane_trigger" },
    { 0x117E6, "watch_for_players_joining" },
    { 0x117E7, "watch_for_players_ledgespawners" },
    { 0x117E8, "watch_for_players_regrouping_to_plane" },
    { 0x117E9, "watch_for_players_touching_ground" },
    { 0x117EA, "watch_for_second_input" },
    { 0x117EB, "watch_for_super_ammo_depleted" },
    { 0x117EC, "watch_for_total_counts_below_num" },
    { 0x117ED, "watch_for_usb_notetrack" },
    { 0x117EE, "watch_for_usb_notetrack_switchoff" },
    { 0x117EF, "watch_minigun_ammo_depleted" },
    { 0x117F0, "watch_players_entering_super" },
    { 0x117F1, "watch_rpg_use" },
    { 0x117F2, "watchaddminigunrestrictions" },
    { 0x117F3, "watchallcrateusabilityfast" },
    { 0x117F4, "watchalleyplayerexit" },
    { 0x117F5, "watchbombuse" },
    { 0x117F6, "watchbombuseinternal" },
    { 0x117F7, "watchboxplayerexit" },
    { 0x117F8, "watchbrc130aidropcrateanimend" },
    { 0x117F9, "watchbrc130airdropchuteanimend" },
    { 0x117FA, "watchbrsquadleaderdisconnect" },
    { 0x117FB, "watchcheck" },
    { 0x117FC, "watchcrategastimeout" },
    { 0x117FD, "watchcratetimeout" },
    { 0x117FE, "watchdangerresetaction" },
    { 0x117FF, "watchdumpsterplayerexit" },
    { 0x11800, "watchflashgrenadeexplode" },
    { 0x11801, "watchfor_pain_or_nearby" },
    { 0x11802, "watchforallnewpayloadspawners" },
    { 0x11803, "watchforapcdamage" },
    { 0x11804, "watchforatvtrigger" },
    { 0x11805, "watchforbrsquadleadershift" },
    { 0x11806, "watchforcarrierdisconnect" },
    { 0x11807, "watchforcircuitbreakertriggered" },
    { 0x11808, "watchforcratedrop" },
    { 0x11809, "watchfordeathwhilereviving" },
    { 0x1180A, "watchfordeleteleaderidleanchor" },
    { 0x1180B, "watchfordeposit" },
    { 0x1180C, "watchforearlyprimeexit" },
    { 0x1180D, "watchforentervehicle" },
    { 0x1180E, "watchforexfilallyturntoside" },
    { 0x1180F, "watchforhelistatus" },
    { 0x11810, "watchforjuggernautdisconnect" },
    { 0x11811, "watchforjuggernautgameend" },
    { 0x11812, "watchforleapfrogpathdisconnect" },
    { 0x11813, "watchforlowpopmatchstart" },
    { 0x11814, "watchformoralespickedup" },
    { 0x11815, "watchformoralesunderfire" },
    { 0x11816, "watchfornagstootherplayers" },
    { 0x11817, "watchfornearmisswhizby" },
    { 0x11818, "watchfornewdrop" },
    { 0x11819, "watchforpayloadstage" },
    { 0x1181A, "watchforpayloadtriggersuperwave" },
    { 0x1181B, "watchforplayertouchingwater" },
    { 0x1181C, "watchforscriptabledoorsinradius" },
    { 0x1181D, "watchforsquadleaddisconnect" },
    { 0x1181E, "watchfortapemachineinteraction" },
    { 0x1181F, "watchforteammatedeathwhilereviving" },
    { 0x11820, "watchforteammaterevivedwhilereviving" },
    { 0x11821, "watchforvehicleobjectivedelete" },
    { 0x11822, "watchfraggrenadeexplode" },
    { 0x11823, "watchfx" },
    { 0x11824, "watchgastrapdamage" },
    { 0x11825, "watchheatreduction" },
    { 0x11826, "watchherodrop" },
    { 0x11827, "watchinexecution" },
    { 0x11828, "watchleadchange" },
    { 0x11829, "watchleaderdescriptionchange" },
    { 0x1182A, "watchmapselectexitonemp" },
    { 0x1182B, "watchmidsideplayerexit" },
    { 0x1182C, "watchminigunweapon" },
    { 0x1182D, "watchoverheat" },
    { 0x1182E, "watchparachutersoverhead" },
    { 0x1182F, "watchremoveminigunrestrictions" },
    { 0x11830, "watchsnowballpickup" },
    { 0x11831, "watchspawninput" },
    { 0x11832, "watchspawnwallplayerexit" },
    { 0x11833, "watchspecialgrenadethrow" },
    { 0x11834, "watchspraygesturedosprayevent" },
    { 0x11835, "watchthrowingkifefireswipe" },
    { 0x11836, "watchtrashcanplayerexit" },
    { 0x11837, "watchtrigger" },
    { 0x11838, "watchvehicleingas" },
    { 0x11839, "watchweapondeathordisconnect" },
    { 0x1183A, "watchweapondrop" },
    { 0x1183B, "watchwindowplayerexit" },
    { 0x1183C, "water_immunity_time" },
    { 0x1183D, "water_stage" },
    { 0x1183E, "waterentityarray" },
    { 0x1183F, "waterentitydamagewatcher" },
    { 0x11840, "wave_1_spawned_cave_first" },
    { 0x11841, "wave_aggro_array" },
    { 0x11842, "wave_aggro_monitor" },
    { 0x11843, "wave_ai_debug" },
    { 0x11844, "wave_ai_killed" },
    { 0x11845, "wave_ai_spawned" },
    { 0x11846, "wave_airstrikes_allowed" },
    { 0x11847, "wave_cooldown_sounds" },
    { 0x11848, "wave_default" },
    { 0x11849, "wave_default_internal" },
    { 0x1184A, "wave_enemies_remaining" },
    { 0x1184B, "wave_failsafe_end" },
    { 0x1184C, "wave_goto_on_spawn" },
    { 0x1184D, "wave_paused" },
    { 0x1184E, "wave_progression" },
    { 0x1184F, "wave_revive" },
    { 0x11850, "wave_spawn_selector" },
    { 0x11851, "wave_spawner" },
    { 0x11852, "wave_time_set" },
    { 0x11853, "wavesv_finite_ending" },
    { 0x11854, "wavesv_finite_max" },
    { 0x11855, "wavesv_finitemode" },
    { 0x11856, "wavetime" },
    { 0x11857, "waypoint_active_vfx" },
    { 0x11858, "waypoint_completed_vfx" },
    { 0x11859, "waypoint_endzone_vfx" },
    { 0x1185A, "waypoint_icon" },
    { 0x1185B, "waypoint_inactive_vfx" },
    { 0x1185C, "waypoint_radius_think" },
    { 0x1185D, "waypointid" },
    { 0x1185E, "waypoints" },
    { 0x1185F, "waypoints_creation" },
    { 0x11860, "waypoints_free_flow" },
    { 0x11861, "waypoints_linear_flow" },
    { 0x11862, "waypoints_reached" },
    { 0x11863, "waypoints_structs" },
    { 0x11864, "weapon_box_cache_use" },
    { 0x11865, "weapon_buy_point_watch_death" },
    { 0x11866, "weapon_class" },
    { 0x11867, "weapon_pick_up_monitor" },
    { 0x11868, "weapon_should_not_get_ammo" },
    { 0x11869, "weapon_switch_hint" },
    { 0x1186A, "weapon_xp_iw8_ar_akilo47" },
    { 0x1186B, "weapon_xp_iw8_ar_asierra12" },
    { 0x1186C, "weapon_xp_iw8_ar_falima" },
    { 0x1186D, "weapon_xp_iw8_ar_falpha" },
    { 0x1186E, "weapon_xp_iw8_ar_golf36" },
    { 0x1186F, "weapon_xp_iw8_ar_kilo433" },
    { 0x11870, "weapon_xp_iw8_ar_mcharlie" },
    { 0x11871, "weapon_xp_iw8_ar_mike4" },
    { 0x11872, "weapon_xp_iw8_ar_scharlie" },
    { 0x11873, "weapon_xp_iw8_ar_sierra552" },
    { 0x11874, "weapon_xp_iw8_ar_tango21" },
    { 0x11875, "weapon_xp_iw8_fists" },
    { 0x11876, "weapon_xp_iw8_knife" },
    { 0x11877, "weapon_xp_iw8_la_gromeo" },
    { 0x11878, "weapon_xp_iw8_la_juliet" },
    { 0x11879, "weapon_xp_iw8_la_kgolf" },
    { 0x1187A, "weapon_xp_iw8_la_mike32" },
    { 0x1187B, "weapon_xp_iw8_la_rpapa7" },
    { 0x1187C, "weapon_xp_iw8_lm_kilo121" },
    { 0x1187D, "weapon_xp_iw8_lm_lima86" },
    { 0x1187E, "weapon_xp_iw8_lm_mgolf34" },
    { 0x1187F, "weapon_xp_iw8_lm_mgolf36" },
    { 0x11880, "weapon_xp_iw8_lm_mkilo3" },
    { 0x11881, "weapon_xp_iw8_lm_pkilo" },
    { 0x11882, "weapon_xp_iw8_me_riotshield" },
    { 0x11883, "weapon_xp_iw8_pi_cpapa" },
    { 0x11884, "weapon_xp_iw8_pi_decho" },
    { 0x11885, "weapon_xp_iw8_pi_golf21" },
    { 0x11886, "weapon_xp_iw8_pi_mike1911" },
    { 0x11887, "weapon_xp_iw8_pi_papa320" },
    { 0x11888, "weapon_xp_iw8_sh_charlie725" },
    { 0x11889, "weapon_xp_iw8_sh_dpapa12" },
    { 0x1188A, "weapon_xp_iw8_sh_mike26" },
    { 0x1188B, "weapon_xp_iw8_sh_oscar12" },
    { 0x1188C, "weapon_xp_iw8_sh_romeo870" },
    { 0x1188D, "weapon_xp_iw8_sm_augolf" },
    { 0x1188E, "weapon_xp_iw8_sm_beta" },
    { 0x1188F, "weapon_xp_iw8_sm_charlie9" },
    { 0x11890, "weapon_xp_iw8_sm_mpapa5" },
    { 0x11891, "weapon_xp_iw8_sm_mpapa7" },
    { 0x11892, "weapon_xp_iw8_sm_papa90" },
    { 0x11893, "weapon_xp_iw8_sm_smgolf45" },
    { 0x11894, "weapon_xp_iw8_sm_uzulu" },
    { 0x11895, "weapon_xp_iw8_sm_victor" },
    { 0x11896, "weapon_xp_iw8_sn_alpha50" },
    { 0x11897, "weapon_xp_iw8_sn_awhiskey" },
    { 0x11898, "weapon_xp_iw8_sn_crossbow" },
    { 0x11899, "weapon_xp_iw8_sn_delta" },
    { 0x1189A, "weapon_xp_iw8_sn_golf28" },
    { 0x1189B, "weapon_xp_iw8_sn_hdromeo" },
    { 0x1189C, "weapon_xp_iw8_sn_kilo98" },
    { 0x1189D, "weapon_xp_iw8_sn_mike14" },
    { 0x1189E, "weapon_xp_iw8_sn_sbeta" },
    { 0x1189F, "weaponclassweights" },
    { 0x118A0, "weapondrop_createdropondeath" },
    { 0x118A1, "weaponfixup" },
    { 0x118A2, "weapongetflinchtype" },
    { 0x118A3, "weapongroupdata" },
    { 0x118A4, "weaponignoresbrarmor" },
    { 0x118A5, "weaponisvalid" },
    { 0x118A6, "weaponpickupflyoutbit" },
    { 0x118A7, "weaponpickups" },
    { 0x118A8, "weaponref" },
    { 0x118A9, "weapons_that_can_stun" },
    { 0x118AA, "weaponstocycle" },
    { 0x118AB, "weaponswitchhintlogic" },
    { 0x118AC, "weaponusagecheck" },
    { 0x118AD, "week" },
    { 0x118AE, "weight_spawners_closest_to_forward" },
    { 0x118AF, "wheels_fx" },
    { 0x118B0, "wheelson_build_path" },
    { 0x118B1, "wheelson_damage_monitor" },
    { 0x118B2, "wheelson_delay_allow_attack" },
    { 0x118B3, "wheelson_fire_thermite" },
    { 0x118B4, "wheelson_molotov_damage_over_time" },
    { 0x118B5, "wheelson_remote_tank_follow_path" },
    { 0x118B6, "wheelson_remote_tank_think" },
    { 0x118B7, "wheelson_tank_death" },
    { 0x118B8, "wheelson_thermite_damage_over_time" },
    { 0x118B9, "whistlestarttime" },
    { 0x118BA, "whistlestarttimer" },
    { 0x118BB, "whistlestarttimer_internal" },
    { 0x118BC, "whistletimer" },
    { 0x118BD, "whistling" },
    { 0x118BE, "whizby_onplayerconnect" },
    { 0x118BF, "winbycaptures" },
    { 0x118C0, "wind_trigger_loop" },
    { 0x118C1, "wind_trigger_toggle" },
    { 0x118C2, "wind_triggers" },
    { 0x118C3, "windintensity" },
    { 0x118C4, "winfontscale" },
    { 0x118C5, "winindex" },
    { 0x118C6, "winnerviewsetup" },
    { 0x118C7, "winyoffset" },
    { 0x118C8, "wipeweapon" },
    { 0x118C9, "wire_think" },
    { 0x118CA, "wires_on_bombs" },
    { 0x118CB, "within_points" },
    { 0x118CC, "withinprojectiondistance" },
    { 0x118CD, "woods_one_death_func" },
    { 0x118CE, "woods_three_death_func" },
    { 0x118CF, "woods_two_death_func" },
    { 0x118D0, "worldstreamingkeepalive" },
    { 0x118D1, "wp_delayzonedelete" },
    { 0x118D2, "wp_deletedangerzoneondeath" },
    { 0x118D3, "wp_isactivewpzone" },
    { 0x118D4, "wp_loop" },
    { 0x118D5, "wp_playimpactsound" },
    { 0x118D6, "wp_watchdisownaction" },
    { 0x118D7, "wp_watchforflaredisowned" },
    { 0x118D8, "wp_watchforsmokedisowned" },
    { 0x118D9, "wp_watchgameend" },
    { 0x118DA, "wp_watchplanedisowned" },
    { 0x118DB, "wrapindex" },
    { 0x118DC, "write_to_dlog_runtime_struct_data" },
    { 0x118DD, "wz_tease" },
    { 0x118DE, "wztrain_info" },
    { 0x118DF, "x1airstrikemanager" },
    { 0x118E0, "x1circletime" },
    { 0x118E1, "x1fin_ontimerexpired" },
    { 0x118E2, "x1fin_playerdisconnect" },
    { 0x118E3, "x1fin_removequestinstance" },
    { 0x118E4, "x1fin_respawn" },
    { 0x118E5, "x1fin_think" },
    { 0x118E6, "x1givelaststandoverride" },
    { 0x118E7, "x1infilarmorwatch" },
    { 0x118E8, "x1loadout" },
    { 0x118E9, "x1ops" },
    { 0x118EA, "x1ops1" },
    { 0x118EB, "x1ops2" },
    { 0x118EC, "x1ops3" },
    { 0x118ED, "x1ops4" },
    { 0x118EE, "x1ops5" },
    { 0x118EF, "x1ops6" },
    { 0x118F0, "x1ops7" },
    { 0x118F1, "x1opsbink" },
    { 0x118F2, "x1opsdeletenpcs" },
    { 0x118F3, "x1opsenableelimination" },
    { 0x118F4, "x1opsendgame" },
    { 0x118F5, "x1opsentercalloutarea" },
    { 0x118F6, "x1opsinfilsequenceend" },
    { 0x118F7, "x1opsinfilsequenceendinternal" },
    { 0x118F8, "x1opsnpc" },
    { 0x118F9, "x1opsnpcheadmodel" },
    { 0x118FA, "x1opsnpcs" },
    { 0x118FB, "x1opsnpcweaponbarrelmodel" },
    { 0x118FC, "x1opsnpcweaponmagmodel" },
    { 0x118FD, "x1opsnpcweaponreceivermodel" },
    { 0x118FE, "x1opsnpcweaponstockmodel" },
    { 0x118FF, "x1opsplayertransition" },
    { 0x11900, "x1opspreplayertransition" },
    { 0x11901, "x1opsrespawnselection" },
    { 0x11902, "x1opsruntoicon" },
    { 0x11903, "x1opsspawnnpc" },
    { 0x11904, "x1opstransbink" },
    { 0x11905, "x1opstransition" },
    { 0x11906, "x1opsunitrespawnselection" },
    { 0x11907, "x1playerspawnoverride" },
    { 0x11908, "x1playertransition" },
    { 0x11909, "x1questmanager" },
    { 0x1190A, "x1spawnlocationoverride" },
    { 0x1190B, "x1spyplane" },
    { 0x1190C, "x1stash_detectplayers" },
    { 0x1190D, "x1stash_entergulag" },
    { 0x1190E, "x1stash_ontimerexpired" },
    { 0x1190F, "x1stash_playerdisconnect" },
    { 0x11910, "x1stash_removequestinstance" },
    { 0x11911, "x1stash_respawn" },
    { 0x11912, "x1stashlootcacheused" },
    { 0x11913, "x1timedivision" },
    { 0x11914, "x1timehandler" },
    { 0x11915, "x1unittimedivision" },
    { 0x11916, "xanimlength" },
    { 0x11917, "xmike109" },
    { 0x11918, "xmike109projectiles" },
    { 0x11919, "xpperplayerpershare" },
    { 0x1191A, "xpperweapon" },
    { 0x1191B, "xpteamsatmatchstart" },
    { 0x1191C, "xylimit" },
    { 0x1191D, "xyvelscale_high" },
    { 0x1191E, "xyvelscale_low" },
    { 0x1191F, "xyvelscale_maxheight" },
    { 0x11920, "xyzoffset" },
    { 0x11921, "yaw_delta" },
    { 0x11922, "yaw_updater" },
    { 0x11923, "z_below_check" },
    { 0x11924, "z_delta" },
    { 0x11925, "zdrop" },
    { 0x11926, "zlimit" },
    { 0x11927, "zombie" },
    { 0x11928, "zombiedropstags" },
    { 0x11929, "zombiehealth" },
    { 0x1192A, "zombiehud" },
    { 0x1192B, "zombieingas" },
    { 0x1192C, "zombiejumpbar" },
    { 0x1192D, "zombiejumpbartext" },
    { 0x1192E, "zombiejumping" },
    { 0x1192F, "zombiejumplink" },
    { 0x11930, "zombiekilledlootcachecount" },
    { 0x11931, "zombieloadout" },
    { 0x11932, "zombienumhitsatv" },
    { 0x11933, "zombienumhitscar" },
    { 0x11934, "zombienumhitsheli" },
    { 0x11935, "zombienumhitshuman" },
    { 0x11936, "zombienumhitstruck" },
    { 0x11937, "zombienumtoconsume" },
    { 0x11938, "zombiepingrate" },
    { 0x11939, "zombiepingtime" },
    { 0x1193A, "zombiepower" },
    { 0x1193B, "zombiepowerscooldown" },
    { 0x1193C, "zombiepowersenabled" },
    { 0x1193D, "zombieregendelayscaleingas" },
    { 0x1193E, "zombieregendelayscaleoutgas" },
    { 0x1193F, "zombieregenratescaleingas" },
    { 0x11940, "zombieregenratescaleoutgas" },
    { 0x11941, "zombierespawning" },
    { 0x11942, "zombiesdamagezombies" },
    { 0x11943, "zombiesignorevehicleexplosions" },
    { 0x11944, "zombiespawnabovedeath" },
    { 0x11945, "zombiespawninair" },
    { 0x11946, "zombiethermalon" },
    { 0x11947, "zombievehiclelaststand" },
    { 0x11948, "zone_bounds" },
    { 0x11949, "zone_get_node_nearest_2d_bounds" },
    { 0x1194A, "zone_stompeenemyprogressupdate" },
    { 0x1194B, "zoneislocked" },
    { 0x1194C, "zoomkey" },
    { 0x1194D, "zvelscale" },
//  { 0x1194E, "" },
//  { 0x1194F, "" },
//  { 0x11950, "" },
//  { 0x11951, "" },
//  { 0x11952, "" },
//  { 0x11953, "" },
//  { 0x11954, "" },
//  { 0x11955, "" },
//  { 0x11956, "" },
//  { 0x11957, "" },
//  { 0x11958, "" },
//  { 0x11959, "" },
//  { 0x1195A, "" },
//  { 0x1195B, "" },
//  { 0x1195C, "" },
//  { 0x1195D, "" },
//  { 0x1195E, "" },
//  { 0x1195F, "" },
//  { 0x11960, "" },
//  { 0x11961, "" },
//  { 0x11962, "" },
//  { 0x11963, "" },
//  { 0x11964, "" },
//  { 0x11965, "" },
//  { 0x11966, "" },
//  { 0x11967, "" },
//  { 0x11968, "" },
//  { 0x11969, "" },
//  { 0x1196A, "" },
//  { 0x1196B, "" },
//  { 0x1196C, "" },
//  { 0x1196D, "" },
//  { 0x1196E, "" },
//  { 0x1196F, "" },
//  { 0x11970, "" },
//  { 0x11971, "" },
//  { 0x11972, "" },
//  { 0x11973, "" },
//  { 0x11974, "" },
//  { 0x11975, "" },
//  { 0x11976, "" },
//  { 0x11977, "" },
//  { 0x11978, "" },
//  { 0x11979, "" },
//  { 0x1197A, "" },
//  { 0x1197B, "" },
//  { 0x1197C, "" },
//  { 0x1197D, "" },
//  { 0x1197E, "" },
//  { 0x1197F, "" },
//  { 0x11980, "" },
//  { 0x11981, "" },
//  { 0x11982, "" },
//  { 0x11983, "" },
//  { 0x11984, "" },
//  { 0x11985, "" },
//  { 0x11986, "" },
//  { 0x11987, "" },
//  { 0x11988, "" },
//  { 0x11989, "" },
//  { 0x1198A, "" },
//  { 0x1198B, "" },
//  { 0x1198C, "" },
//  { 0x1198D, "" },
//  { 0x1198E, "" },
//  { 0x1198F, "" },
//  { 0x11990, "" },
//  { 0x11991, "" },
//  { 0x11992, "" },
//  { 0x11993, "" },
//  { 0x11994, "" },
//  { 0x11995, "" },
//  { 0x11996, "" },
//  { 0x11997, "" },
//  { 0x11998, "" },
//  { 0x11999, "" },
//  { 0x1199A, "" },
//  { 0x1199B, "" },
//  { 0x1199C, "" },
//  { 0x1199D, "" },
//  { 0x1199E, "" },
//  { 0x1199F, "" },
//  { 0x119A0, "" },
//  { 0x119A1, "" },
//  { 0x119A2, "" },
//  { 0x119A3, "" },
//  { 0x119A4, "" },
//  { 0x119A5, "" },
//  { 0x119A6, "" },
//  { 0x119A7, "" },
//  { 0x119A8, "" },
//  { 0x119A9, "" },
//  { 0x119AA, "" },
//  { 0x119AB, "" },
//  { 0x119AC, "" },
//  { 0x119AD, "" },
//  { 0x119AE, "" },
//  { 0x119AF, "" },
//  { 0x119B0, "" },
//  { 0x119B1, "" },
//  { 0x119B2, "" },
//  { 0x119B3, "" },
//  { 0x119B4, "" },
//  { 0x119B5, "" },
//  { 0x119B6, "" },
//  { 0x119B7, "" },
//  { 0x119B8, "" },
//  { 0x119B9, "" },
//  { 0x119BA, "" },
//  { 0x119BB, "" },
//  { 0x119BC, "" },
//  { 0x119BD, "" },
//  { 0x119BE, "" },
//  { 0x119BF, "" },
//  { 0x119C0, "" },
//  { 0x119C1, "" },
//  { 0x119C2, "" },
//  { 0x119C3, "" },
//  { 0x119C4, "" },
//  { 0x119C5, "" },
//  { 0x119C6, "" },
//  { 0x119C7, "" },
//  { 0x119C8, "" },
//  { 0x119C9, "" },
//  { 0x119CA, "" },
//  { 0x119CB, "" },
//  { 0x119CC, "" },
//  { 0x119CD, "" },
//  { 0x119CE, "" },
//  { 0x119CF, "" },
//  { 0x119D0, "" },
//  { 0x119D1, "" },
//  { 0x119D2, "" },
//  { 0x119D3, "" },
//  { 0x119D4, "" },
//  { 0x119D5, "" },
//  { 0x119D6, "" },
//  { 0x119D7, "" },
//  { 0x119D8, "" },
//  { 0x119D9, "" },
//  { 0x119DA, "" },
//  { 0x119DB, "" },
//  { 0x119DC, "" },
//  { 0x119DD, "" },
//  { 0x119DE, "" },
//  { 0x119DF, "" },
//  { 0x119E0, "" },
//  { 0x119E1, "" },
//  { 0x119E2, "" },
//  { 0x119E3, "" },
//  { 0x119E4, "" },
//  { 0x119E5, "" },
//  { 0x119E6, "" },
//  { 0x119E7, "" },
//  { 0x119E8, "" },
//  { 0x119E9, "" },
//  { 0x119EA, "" },
//  { 0x119EB, "" },
//  { 0x119EC, "" },
//  { 0x119ED, "" },
//  { 0x119EE, "" },
//  { 0x119EF, "" },
//  { 0x119F0, "" },
//  { 0x119F1, "" },
//  { 0x119F2, "" },
//  { 0x119F3, "" },
//  { 0x119F4, "" },
//  { 0x119F5, "" },
//  { 0x119F6, "" },
//  { 0x119F7, "" },
//  { 0x119F8, "" },
//  { 0x119F9, "" },
//  { 0x119FA, "" },
//  { 0x119FB, "" },
//  { 0x119FC, "" },
//  { 0x119FD, "" },
//  { 0x119FE, "" },
//  { 0x119FF, "" },
//  { 0x11A00, "" },
//  { 0x11A01, "" },
//  { 0x11A02, "" },
//  { 0x11A03, "" },
//  { 0x11A04, "" },
//  { 0x11A05, "" },
//  { 0x11A06, "" },
//  { 0x11A07, "" },
//  { 0x11A08, "" },
//  { 0x11A09, "" },
//  { 0x11A0A, "" },
//  { 0x11A0B, "" },
//  { 0x11A0C, "" },
//  { 0x11A0D, "" },
//  { 0x11A0E, "" },
//  { 0x11A0F, "" },
//  { 0x11A10, "" },
//  { 0x11A11, "" },
//  { 0x11A12, "" },
//  { 0x11A13, "" },
//  { 0x11A14, "" },
//  { 0x11A15, "" },
//  { 0x11A16, "" },
//  { 0x11A17, "" },
//  { 0x11A18, "" },
//  { 0x11A19, "" },
//  { 0x11A1A, "" },
//  { 0x11A1B, "" },
//  { 0x11A1C, "" },
//  { 0x11A1D, "" },
//  { 0x11A1E, "" },
//  { 0x11A1F, "" },
//  { 0x11A20, "" },
//  { 0x11A21, "" },
//  { 0x11A22, "" },
//  { 0x11A23, "" },
//  { 0x11A24, "" },
//  { 0x11A25, "" },
//  { 0x11A26, "" },
//  { 0x11A27, "" },
//  { 0x11A28, "" },
//  { 0x11A29, "" },
//  { 0x11A2A, "" },
//  { 0x11A2B, "" },
//  { 0x11A2C, "" },
//  { 0x11A2D, "" },
//  { 0x11A2E, "" },
//  { 0x11A2F, "" },
//  { 0x11A30, "" },
//  { 0x11A31, "" },
//  { 0x11A32, "" },
//  { 0x11A33, "" },
//  { 0x11A34, "" },
//  { 0x11A35, "" },
//  { 0x11A36, "" },
//  { 0x11A37, "" },
//  { 0x11A38, "" },
//  { 0x11A39, "" },
//  { 0x11A3A, "" },
//  { 0x11A3B, "" },
//  { 0x11A3C, "" },
//  { 0x11A3D, "" },
//  { 0x11A3E, "" },
//  { 0x11A3F, "" },
//  { 0x11A40, "" },
//  { 0x11A41, "" },
//  { 0x11A42, "" },
//  { 0x11A43, "" },
//  { 0x11A44, "" },
//  { 0x11A45, "" },
//  { 0x11A46, "" },
//  { 0x11A47, "" },
//  { 0x11A48, "" },
//  { 0x11A49, "" },
//  { 0x11A4A, "" },
//  { 0x11A4B, "" },
//  { 0x11A4C, "" },
//  { 0x11A4D, "" },
//  { 0x11A4E, "" },
//  { 0x11A4F, "" },
//  { 0x11A50, "" },
//  { 0x11A51, "" },
//  { 0x11A52, "" },
//  { 0x11A53, "" },
//  { 0x11A54, "" },
//  { 0x11A55, "" },
//  { 0x11A56, "" },
//  { 0x11A57, "" },
//  { 0x11A58, "" },
//  { 0x11A59, "" },
//  { 0x11A5A, "" },
//  { 0x11A5B, "" },
//  { 0x11A5C, "" },
//  { 0x11A5D, "" },
//  { 0x11A5E, "" },
//  { 0x11A5F, "" },
//  { 0x11A60, "" },
//  { 0x11A61, "" },
//  { 0x11A62, "" },
//  { 0x11A63, "" },
//  { 0x11A64, "" },
//  { 0x11A65, "" },
//  { 0x11A66, "" },
//  { 0x11A67, "" },
//  { 0x11A68, "" },
//  { 0x11A69, "" },
//  { 0x11A6A, "" },
//  { 0x11A6B, "" },
//  { 0x11A6C, "" },
//  { 0x11A6D, "" },
//  { 0x11A6E, "" },
//  { 0x11A6F, "" },
//  { 0x11A70, "" },
//  { 0x11A71, "" },
//  { 0x11A72, "" },
//  { 0x11A73, "" },
//  { 0x11A74, "" },
//  { 0x11A75, "" },
//  { 0x11A76, "" },
//  { 0x11A77, "" },
//  { 0x11A78, "" },
//  { 0x11A79, "" },
//  { 0x11A7A, "" },
//  { 0x11A7B, "" },
//  { 0x11A7C, "" },
//  { 0x11A7D, "" },
//  { 0x11A7E, "" },
//  { 0x11A7F, "" },
//  { 0x11A80, "" },
//  { 0x11A81, "" },
//  { 0x11A82, "" },
//  { 0x11A83, "" },
//  { 0x11A84, "" },
//  { 0x11A85, "" },
//  { 0x11A86, "" },
//  { 0x11A87, "" },
//  { 0x11A88, "" },
//  { 0x11A89, "" },
//  { 0x11A8A, "" },
//  { 0x11A8B, "" },
//  { 0x11A8C, "" },
//  { 0x11A8D, "" },
//  { 0x11A8E, "" },
//  { 0x11A8F, "" },
//  { 0x11A90, "" },
//  { 0x11A91, "" },
//  { 0x11A92, "" },
//  { 0x11A93, "" },
//  { 0x11A94, "" },
//  { 0x11A95, "" },
//  { 0x11A96, "" },
//  { 0x11A97, "" },
//  { 0x11A98, "" },
//  { 0x11A99, "" },
//  { 0x11A9A, "" },
//  { 0x11A9B, "" },
//  { 0x11A9C, "" },
//  { 0x11A9D, "" },
//  { 0x11A9E, "" },
//  { 0x11A9F, "" },
//  { 0x11AA0, "" },
//  { 0x11AA1, "" },
//  { 0x11AA2, "" },
//  { 0x11AA3, "" },
//  { 0x11AA4, "" },
//  { 0x11AA5, "" },
//  { 0x11AA6, "" },
//  { 0x11AA7, "" },
//  { 0x11AA8, "" },
//  { 0x11AA9, "" },
//  { 0x11AAA, "" },
//  { 0x11AAB, "" },
//  { 0x11AAC, "" },
//  { 0x11AAD, "" },
//  { 0x11AAE, "" },
//  { 0x11AAF, "" },
//  { 0x11AB0, "" },
//  { 0x11AB1, "" },
//  { 0x11AB2, "" },
//  { 0x11AB3, "" },
//  { 0x11AB4, "" },
//  { 0x11AB5, "" },
//  { 0x11AB6, "" },
//  { 0x11AB7, "" },
//  { 0x11AB8, "" },
//  { 0x11AB9, "" },
//  { 0x11ABA, "" },
//  { 0x11ABB, "" },
//  { 0x11ABC, "" },
//  { 0x11ABD, "" },
//  { 0x11ABE, "" },
//  { 0x11ABF, "" },
//  { 0x11AC0, "" },
//  { 0x11AC1, "" },
//  { 0x11AC2, "" },
//  { 0x11AC3, "" },
//  { 0x11AC4, "" },
//  { 0x11AC5, "" },
//  { 0x11AC6, "" },
//  { 0x11AC7, "" },
//  { 0x11AC8, "" },
//  { 0x11AC9, "" },
//  { 0x11ACA, "" },
//  { 0x11ACB, "" },
//  { 0x11ACC, "" },
//  { 0x11ACD, "" },
//  { 0x11ACE, "" },
//  { 0x11ACF, "" },
//  { 0x11AD0, "" },
//  { 0x11AD1, "" },
//  { 0x11AD2, "" },
//  { 0x11AD3, "" },
//  { 0x11AD4, "" },
//  { 0x11AD5, "" },
//  { 0x11AD6, "" },
//  { 0x11AD7, "" },
//  { 0x11AD8, "" },
//  { 0x11AD9, "" },
//  { 0x11ADA, "" },
//  { 0x11ADB, "" },
//  { 0x11ADC, "" },
//  { 0x11ADD, "" },
//  { 0x11ADE, "" },
//  { 0x11ADF, "" },
//  { 0x11AE0, "" },
//  { 0x11AE1, "" },
//  { 0x11AE2, "" },
//  { 0x11AE3, "" },
//  { 0x11AE4, "" },
//  { 0x11AE5, "" },
//  { 0x11AE6, "" },
//  { 0x11AE7, "" },
//  { 0x11AE8, "" },
//  { 0x11AE9, "" },
//  { 0x11AEA, "" },
//  { 0x11AEB, "" },
//  { 0x11AEC, "" },
//  { 0x11AED, "" },
//  { 0x11AEE, "" },
//  { 0x11AEF, "" },
//  { 0x11AF0, "" },
//  { 0x11AF1, "" },
//  { 0x11AF2, "" },
//  { 0x11AF3, "" },
//  { 0x11AF4, "" },
//  { 0x11AF5, "" },
//  { 0x11AF6, "" },
//  { 0x11AF7, "" },
//  { 0x11AF8, "" },
//  { 0x11AF9, "" },
//  { 0x11AFA, "" },
//  { 0x11AFB, "" },
//  { 0x11AFC, "" },
//  { 0x11AFD, "" },
//  { 0x11AFE, "" },
//  { 0x11AFF, "" },
//  { 0x11B00, "" },
//  { 0x11B01, "" },
//  { 0x11B02, "" },
//  { 0x11B03, "" },
//  { 0x11B04, "" },
//  { 0x11B05, "" },
//  { 0x11B06, "" },
//  { 0x11B07, "" },
//  { 0x11B08, "" },
//  { 0x11B09, "" },
//  { 0x11B0A, "" },
//  { 0x11B0B, "" },
//  { 0x11B0C, "" },
//  { 0x11B0D, "" },
//  { 0x11B0E, "" },
//  { 0x11B0F, "" },
//  { 0x11B10, "" },
//  { 0x11B11, "" },
//  { 0x11B12, "" },
//  { 0x11B13, "" },
//  { 0x11B14, "" },
//  { 0x11B15, "" },
//  { 0x11B16, "" },
//  { 0x11B17, "" },
//  { 0x11B18, "" },
//  { 0x11B19, "" },
//  { 0x11B1A, "" },
//  { 0x11B1B, "" },
//  { 0x11B1C, "" },
//  { 0x11B1D, "" },
//  { 0x11B1E, "" },
//  { 0x11B1F, "" },
//  { 0x11B20, "" },
//  { 0x11B21, "" },
//  { 0x11B22, "" },
//  { 0x11B23, "" },
//  { 0x11B24, "" },
//  { 0x11B25, "" },
//  { 0x11B26, "" },
//  { 0x11B27, "" },
//  { 0x11B28, "" },
//  { 0x11B29, "" },
//  { 0x11B2A, "" },
//  { 0x11B2B, "" },
//  { 0x11B2C, "" },
//  { 0x11B2D, "" },
//  { 0x11B2E, "" },
//  { 0x11B2F, "" },
//  { 0x11B30, "" },
//  { 0x11B31, "" },
//  { 0x11B32, "" },
//  { 0x11B33, "" },
//  { 0x11B34, "" },
//  { 0x11B35, "" },
//  { 0x11B36, "" },
//  { 0x11B37, "" },
//  { 0x11B38, "" },
//  { 0x11B39, "" },
//  { 0x11B3A, "" },
//  { 0x11B3B, "" },
//  { 0x11B3C, "" },
//  { 0x11B3D, "" },
//  { 0x11B3E, "" },
//  { 0x11B3F, "" },
//  { 0x11B40, "" },
//  { 0x11B41, "" },
//  { 0x11B42, "" },
//  { 0x11B43, "" },
//  { 0x11B44, "" },
//  { 0x11B45, "" },
//  { 0x11B46, "" },
//  { 0x11B47, "" },
//  { 0x11B48, "" },
//  { 0x11B49, "" },
//  { 0x11B4A, "" },
//  { 0x11B4B, "" },
//  { 0x11B4C, "" },
//  { 0x11B4D, "" },
//  { 0x11B4E, "" },
//  { 0x11B4F, "" },
//  { 0x11B50, "" },
//  { 0x11B51, "" },
//  { 0x11B52, "" },
//  { 0x11B53, "" },
//  { 0x11B54, "" },
//  { 0x11B55, "" },
//  { 0x11B56, "" },
//  { 0x11B57, "" },
//  { 0x11B58, "" },
//  { 0x11B59, "" },
//  { 0x11B5A, "" },
//  { 0x11B5B, "" },
//  { 0x11B5C, "" },
//  { 0x11B5D, "" },
//  { 0x11B5E, "" },
//  { 0x11B5F, "" },
//  { 0x11B60, "" },
//  { 0x11B61, "" },
//  { 0x11B62, "" },
//  { 0x11B63, "" },
//  { 0x11B64, "" },
//  { 0x11B65, "" },
//  { 0x11B66, "" },
//  { 0x11B67, "" },
//  { 0x11B68, "" },
//  { 0x11B69, "" },
//  { 0x11B6A, "" },
//  { 0x11B6B, "" },
//  { 0x11B6C, "" },
//  { 0x11B6D, "" },
//  { 0x11B6E, "" },
//  { 0x11B6F, "" },
//  { 0x11B70, "" },
//  { 0x11B71, "" },
//  { 0x11B72, "" },
//  { 0x11B73, "" },
//  { 0x11B74, "" },
//  { 0x11B75, "" },
//  { 0x11B76, "" },
//  { 0x11B77, "" },
//  { 0x11B78, "" },
//  { 0x11B79, "" },
//  { 0x11B7A, "" },
//  { 0x11B7B, "" },
//  { 0x11B7C, "" },
//  { 0x11B7D, "" },
//  { 0x11B7E, "" },
//  { 0x11B7F, "" },
//  { 0x11B80, "" },
//  { 0x11B81, "" },
//  { 0x11B82, "" },
//  { 0x11B83, "" },
//  { 0x11B84, "" },
//  { 0x11B85, "" },
//  { 0x11B86, "" },
//  { 0x11B87, "" },
//  { 0x11B88, "" },
//  { 0x11B89, "" },
//  { 0x11B8A, "" },
//  { 0x11B8B, "" },
//  { 0x11B8C, "" },
//  { 0x11B8D, "" },
//  { 0x11B8E, "" },
//  { 0x11B8F, "" },
//  { 0x11B90, "" },
//  { 0x11B91, "" },
//  { 0x11B92, "" },
//  { 0x11B93, "" },
//  { 0x11B94, "" },
//  { 0x11B95, "" },
//  { 0x11B96, "" },
//  { 0x11B97, "" },
//  { 0x11B98, "" },
//  { 0x11B99, "" },
//  { 0x11B9A, "" },
//  { 0x11B9B, "" },
//  { 0x11B9C, "" },
//  { 0x11B9D, "" },
//  { 0x11B9E, "" },
//  { 0x11B9F, "" },
//  { 0x11BA0, "" },
//  { 0x11BA1, "" },
//  { 0x11BA2, "" },
//  { 0x11BA3, "" },
//  { 0x11BA4, "" },
//  { 0x11BA5, "" },
//  { 0x11BA6, "" },
//  { 0x11BA7, "" },
//  { 0x11BA8, "" },
//  { 0x11BA9, "" },
//  { 0x11BAA, "" },
//  { 0x11BAB, "" },
//  { 0x11BAC, "" },
//  { 0x11BAD, "" },
//  { 0x11BAE, "" },
//  { 0x11BAF, "" },
//  { 0x11BB0, "" },
//  { 0x11BB1, "" },
//  { 0x11BB2, "" },
//  { 0x11BB3, "" },
//  { 0x11BB4, "" },
//  { 0x11BB5, "" },
//  { 0x11BB6, "" },
//  { 0x11BB7, "" },
//  { 0x11BB8, "" },
//  { 0x11BB9, "" },
//  { 0x11BBA, "" },
//  { 0x11BBB, "" },
//  { 0x11BBC, "" },
//  { 0x11BBD, "" },
//  { 0x11BBE, "" },
//  { 0x11BBF, "" },
//  { 0x11BC0, "" },
//  { 0x11BC1, "" },
//  { 0x11BC2, "" },
//  { 0x11BC3, "" },
//  { 0x11BC4, "" },
//  { 0x11BC5, "" },
//  { 0x11BC6, "" },
//  { 0x11BC7, "" },
//  { 0x11BC8, "" },
//  { 0x11BC9, "" },
//  { 0x11BCA, "" },
//  { 0x11BCB, "" },
//  { 0x11BCC, "" },
//  { 0x11BCD, "" },
//  { 0x11BCE, "" },
//  { 0x11BCF, "" },
//  { 0x11BD0, "" },
//  { 0x11BD1, "" },
//  { 0x11BD2, "" },
//  { 0x11BD3, "" },
//  { 0x11BD4, "" },
//  { 0x11BD5, "" },
//  { 0x11BD6, "" },
//  { 0x11BD7, "" },
//  { 0x11BD8, "" },
//  { 0x11BD9, "" },
//  { 0x11BDA, "" },
//  { 0x11BDB, "" },
//  { 0x11BDC, "" },
//  { 0x11BDD, "" },
//  { 0x11BDE, "" },
//  { 0x11BDF, "" },
//  { 0x11BE0, "" },
//  { 0x11BE1, "" },
//  { 0x11BE2, "" },
//  { 0x11BE3, "" },
//  { 0x11BE4, "" },
//  { 0x11BE5, "" },
//  { 0x11BE6, "" },
//  { 0x11BE7, "" },
//  { 0x11BE8, "" },
//  { 0x11BE9, "" },
//  { 0x11BEA, "" },
//  { 0x11BEB, "" },
//  { 0x11BEC, "" },
//  { 0x11BED, "" },
//  { 0x11BEE, "" },
//  { 0x11BEF, "" },
//  { 0x11BF0, "" },
//  { 0x11BF1, "" },
//  { 0x11BF2, "" },
//  { 0x11BF3, "" },
//  { 0x11BF4, "" },
//  { 0x11BF5, "" },
//  { 0x11BF6, "" },
//  { 0x11BF7, "" },
//  { 0x11BF8, "" },
//  { 0x11BF9, "" },
//  { 0x11BFA, "" },
//  { 0x11BFB, "" },
//  { 0x11BFC, "" },
//  { 0x11BFD, "" },
//  { 0x11BFE, "" },
//  { 0x11BFF, "" },
//  { 0x11C00, "" },
//  { 0x11C01, "" },
//  { 0x11C02, "" },
//  { 0x11C03, "" },
//  { 0x11C04, "" },
//  { 0x11C05, "" },
//  { 0x11C06, "" },
//  { 0x11C07, "" },
//  { 0x11C08, "" },
//  { 0x11C09, "" },
//  { 0x11C0A, "" },
//  { 0x11C0B, "" },
//  { 0x11C0C, "" },
//  { 0x11C0D, "" },
//  { 0x11C0E, "" },
//  { 0x11C0F, "" },
//  { 0x11C10, "" },
//  { 0x11C11, "" },
//  { 0x11C12, "" },
//  { 0x11C13, "" },
//  { 0x11C14, "" },
//  { 0x11C15, "" },
//  { 0x11C16, "" },
//  { 0x11C17, "" },
//  { 0x11C18, "" },
//  { 0x11C19, "" },
//  { 0x11C1A, "" },
//  { 0x11C1B, "" },
//  { 0x11C1C, "" },
//  { 0x11C1D, "" },
//  { 0x11C1E, "" },
//  { 0x11C1F, "" },
//  { 0x11C20, "" },
//  { 0x11C21, "" },
//  { 0x11C22, "" },
//  { 0x11C23, "" },
//  { 0x11C24, "" },
//  { 0x11C25, "" },
//  { 0x11C26, "" },
//  { 0x11C27, "" },
//  { 0x11C28, "" },
//  { 0x11C29, "" },
//  { 0x11C2A, "" },
//  { 0x11C2B, "" },
//  { 0x11C2C, "" },
//  { 0x11C2D, "" },
//  { 0x11C2E, "" },
//  { 0x11C2F, "" },
//  { 0x11C30, "" },
//  { 0x11C31, "" },
//  { 0x11C32, "" },
//  { 0x11C33, "" },
//  { 0x11C34, "" },
//  { 0x11C35, "" },
//  { 0x11C36, "" },
//  { 0x11C37, "" },
//  { 0x11C38, "" },
//  { 0x11C39, "" },
//  { 0x11C3A, "" },
//  { 0x11C3B, "" },
//  { 0x11C3C, "" },
//  { 0x11C3D, "" },
//  { 0x11C3E, "" },
//  { 0x11C3F, "" },
//  { 0x11C40, "" },
//  { 0x11C41, "" },
//  { 0x11C42, "" },
//  { 0x11C43, "" },
//  { 0x11C44, "" },
//  { 0x11C45, "" },
//  { 0x11C46, "" },
//  { 0x11C47, "" },
//  { 0x11C48, "" },
//  { 0x11C49, "" },
//  { 0x11C4A, "" },
//  { 0x11C4B, "" },
//  { 0x11C4C, "" },
//  { 0x11C4D, "" },
//  { 0x11C4E, "" },
//  { 0x11C4F, "" },
//  { 0x11C50, "" },
//  { 0x11C51, "" },
//  { 0x11C52, "" },
//  { 0x11C53, "" },
//  { 0x11C54, "" },
//  { 0x11C55, "" },
//  { 0x11C56, "" },
//  { 0x11C57, "" },
//  { 0x11C58, "" },
//  { 0x11C59, "" },
//  { 0x11C5A, "" },
//  { 0x11C5B, "" },
//  { 0x11C5C, "" },
//  { 0x11C5D, "" },
//  { 0x11C5E, "" },
//  { 0x11C5F, "" },
//  { 0x11C60, "" },
//  { 0x11C61, "" },
//  { 0x11C62, "" },
//  { 0x11C63, "" },
//  { 0x11C64, "" },
//  { 0x11C65, "" },
//  { 0x11C66, "" },
//  { 0x11C67, "" },
//  { 0x11C68, "" },
//  { 0x11C69, "" },
//  { 0x11C6A, "" },
//  { 0x11C6B, "" },
//  { 0x11C6C, "" },
//  { 0x11C6D, "" },
//  { 0x11C6E, "" },
//  { 0x11C6F, "" },
//  { 0x11C70, "" },
//  { 0x11C71, "" },
//  { 0x11C72, "" },
//  { 0x11C73, "" },
//  { 0x11C74, "" },
//  { 0x11C75, "" },
//  { 0x11C76, "" },
//  { 0x11C77, "" },
//  { 0x11C78, "" },
//  { 0x11C79, "" },
//  { 0x11C7A, "" },
//  { 0x11C7B, "" },
//  { 0x11C7C, "" },
//  { 0x11C7D, "" },
//  { 0x11C7E, "" },
//  { 0x11C7F, "" },
//  { 0x11C80, "" },
//  { 0x11C81, "" },
//  { 0x11C82, "" },
//  { 0x11C83, "" },
//  { 0x11C84, "" },
//  { 0x11C85, "" },
//  { 0x11C86, "" },
//  { 0x11C87, "" },
//  { 0x11C88, "" },
//  { 0x11C89, "" },
//  { 0x11C8A, "" },
//  { 0x11C8B, "" },
//  { 0x11C8C, "" },
//  { 0x11C8D, "" },
//  { 0x11C8E, "" },
//  { 0x11C8F, "" },
//  { 0x11C90, "" },
//  { 0x11C91, "" },
//  { 0x11C92, "" },
//  { 0x11C93, "" },
//  { 0x11C94, "" },
//  { 0x11C95, "" },
//  { 0x11C96, "" },
//  { 0x11C97, "" },
//  { 0x11C98, "" },
//  { 0x11C99, "" },
//  { 0x11C9A, "" },
//  { 0x11C9B, "" },
//  { 0x11C9C, "" },
//  { 0x11C9D, "" },
//  { 0x11C9E, "" },
//  { 0x11C9F, "" },
//  { 0x11CA0, "" },
//  { 0x11CA1, "" },
//  { 0x11CA2, "" },
//  { 0x11CA3, "" },
//  { 0x11CA4, "" },
//  { 0x11CA5, "" },
//  { 0x11CA6, "" },
//  { 0x11CA7, "" },
//  { 0x11CA8, "" },
//  { 0x11CA9, "" },
//  { 0x11CAA, "" },
//  { 0x11CAB, "" },
//  { 0x11CAC, "" },
//  { 0x11CAD, "" },
//  { 0x11CAE, "" },
//  { 0x11CAF, "" },
//  { 0x11CB0, "" },
//  { 0x11CB1, "" },
//  { 0x11CB2, "" },
//  { 0x11CB3, "" },
//  { 0x11CB4, "" },
//  { 0x11CB5, "" },
//  { 0x11CB6, "" },
//  { 0x11CB7, "" },
//  { 0x11CB8, "" },
//  { 0x11CB9, "" },
//  { 0x11CBA, "" },
//  { 0x11CBB, "" },
//  { 0x11CBC, "" },
//  { 0x11CBD, "" },
//  { 0x11CBE, "" },
//  { 0x11CBF, "" },
//  { 0x11CC0, "" },
//  { 0x11CC1, "" },
//  { 0x11CC2, "" },
//  { 0x11CC3, "" },
//  { 0x11CC4, "" },
//  { 0x11CC5, "" },
//  { 0x11CC6, "" },
//  { 0x11CC7, "" },
//  { 0x11CC8, "" },
//  { 0x11CC9, "" },
//  { 0x11CCA, "" },
//  { 0x11CCB, "" },
//  { 0x11CCC, "" },
//  { 0x11CCD, "" },
//  { 0x11CCE, "" },
//  { 0x11CCF, "" },
//  { 0x11CD0, "" },
//  { 0x11CD1, "" },
//  { 0x11CD2, "" },
//  { 0x11CD3, "" },
//  { 0x11CD4, "" },
//  { 0x11CD5, "" },
//  { 0x11CD6, "" },
//  { 0x11CD7, "" },
//  { 0x11CD8, "" },
//  { 0x11CD9, "" },
//  { 0x11CDA, "" },
//  { 0x11CDB, "" },
//  { 0x11CDC, "" },
//  { 0x11CDD, "" },
//  { 0x11CDE, "" },
//  { 0x11CDF, "" },
//  { 0x11CE0, "" },
//  { 0x11CE1, "" },
//  { 0x11CE2, "" },
//  { 0x11CE3, "" },
//  { 0x11CE4, "" },
//  { 0x11CE5, "" },
//  { 0x11CE6, "" },
//  { 0x11CE7, "" },
//  { 0x11CE8, "" },
//  { 0x11CE9, "" },
//  { 0x11CEA, "" },
//  { 0x11CEB, "" },
//  { 0x11CEC, "" },
//  { 0x11CED, "" },
//  { 0x11CEE, "" },
//  { 0x11CEF, "" },
//  { 0x11CF0, "" },
//  { 0x11CF1, "" },
//  { 0x11CF2, "" },
//  { 0x11CF3, "" },
//  { 0x11CF4, "" },
//  { 0x11CF5, "" },
//  { 0x11CF6, "" },
//  { 0x11CF7, "" },
//  { 0x11CF8, "" },
//  { 0x11CF9, "" },
//  { 0x11CFA, "" },
//  { 0x11CFB, "" },
//  { 0x11CFC, "" },
//  { 0x11CFD, "" },
//  { 0x11CFE, "" },
//  { 0x11CFF, "" },
//  { 0x11D00, "" },
//  { 0x11D01, "" },
//  { 0x11D02, "" },
//  { 0x11D03, "" },
//  { 0x11D04, "" },
//  { 0x11D05, "" },
//  { 0x11D06, "" },
//  { 0x11D07, "" },
//  { 0x11D08, "" },
//  { 0x11D09, "" },
//  { 0x11D0A, "" },
//  { 0x11D0B, "" },
//  { 0x11D0C, "" },
//  { 0x11D0D, "" },
//  { 0x11D0E, "" },
//  { 0x11D0F, "" },
//  { 0x11D10, "" },
//  { 0x11D11, "" },
//  { 0x11D12, "" },
//  { 0x11D13, "" },
//  { 0x11D14, "" },
//  { 0x11D15, "" },
//  { 0x11D16, "" },
//  { 0x11D17, "" },
//  { 0x11D18, "" },
//  { 0x11D19, "" },
//  { 0x11D1A, "" },
//  { 0x11D1B, "" },
//  { 0x11D1C, "" },
//  { 0x11D1D, "" },
//  { 0x11D1E, "" },
//  { 0x11D1F, "" },
//  { 0x11D20, "" },
//  { 0x11D21, "" },
//  { 0x11D22, "" },
//  { 0x11D23, "" },
//  { 0x11D24, "" },
//  { 0x11D25, "" },
//  { 0x11D26, "" },
//  { 0x11D27, "" },
//  { 0x11D28, "" },
//  { 0x11D29, "" },
//  { 0x11D2A, "" },
//  { 0x11D2B, "" },
//  { 0x11D2C, "" },
//  { 0x11D2D, "" },
//  { 0x11D2E, "" },
//  { 0x11D2F, "" },
//  { 0x11D30, "" },
//  { 0x11D31, "" },
//  { 0x11D32, "" },
//  { 0x11D33, "" },
//  { 0x11D34, "" },
//  { 0x11D35, "" },
//  { 0x11D36, "" },
//  { 0x11D37, "" },
//  { 0x11D38, "" },
//  { 0x11D39, "" },
//  { 0x11D3A, "" },
//  { 0x11D3B, "" },
//  { 0x11D3C, "" },
//  { 0x11D3D, "" },
//  { 0x11D3E, "" },
//  { 0x11D3F, "" },
//  { 0x11D40, "" },
//  { 0x11D41, "" },
//  { 0x11D42, "" },
//  { 0x11D43, "" },
//  { 0x11D44, "" },
//  { 0x11D45, "" },
//  { 0x11D46, "" },
//  { 0x11D47, "" },
//  { 0x11D48, "" },
//  { 0x11D49, "" },
//  { 0x11D4A, "" },
//  { 0x11D4B, "" },
//  { 0x11D4C, "" },
//  { 0x11D4D, "" },
//  { 0x11D4E, "" },
//  { 0x11D4F, "" },
//  { 0x11D50, "" },
//  { 0x11D51, "" },
//  { 0x11D52, "" },
//  { 0x11D53, "" },
//  { 0x11D54, "" },
//  { 0x11D55, "" },
//  { 0x11D56, "" },
//  { 0x11D57, "" },
//  { 0x11D58, "" },
//  { 0x11D59, "" },
//  { 0x11D5A, "" },
//  { 0x11D5B, "" },
//  { 0x11D5C, "" },
//  { 0x11D5D, "" },
//  { 0x11D5E, "" },
//  { 0x11D5F, "" },
//  { 0x11D60, "" },
//  { 0x11D61, "" },
//  { 0x11D62, "" },
//  { 0x11D63, "" },
//  { 0x11D64, "" },
//  { 0x11D65, "" },
//  { 0x11D66, "" },
//  { 0x11D67, "" },
//  { 0x11D68, "" },
//  { 0x11D69, "" },
//  { 0x11D6A, "" },
//  { 0x11D6B, "" },
//  { 0x11D6C, "" },
//  { 0x11D6D, "" },
//  { 0x11D6E, "" },
//  { 0x11D6F, "" },
//  { 0x11D70, "" },
//  { 0x11D71, "" },
//  { 0x11D72, "" },
//  { 0x11D73, "" },
//  { 0x11D74, "" },
//  { 0x11D75, "" },
//  { 0x11D76, "" },
//  { 0x11D77, "" },
//  { 0x11D78, "" },
//  { 0x11D79, "" },
//  { 0x11D7A, "" },
//  { 0x11D7B, "" },
//  { 0x11D7C, "" },
//  { 0x11D7D, "" },
//  { 0x11D7E, "" },
//  { 0x11D7F, "" },
//  { 0x11D80, "" },
//  { 0x11D81, "" },
//  { 0x11D82, "" },
//  { 0x11D83, "" },
//  { 0x11D84, "" },
//  { 0x11D85, "" },
//  { 0x11D86, "" },
//  { 0x11D87, "" },
//  { 0x11D88, "" },
//  { 0x11D89, "" },
//  { 0x11D8A, "" },
//  { 0x11D8B, "" },
//  { 0x11D8C, "" },
//  { 0x11D8D, "" },
//  { 0x11D8E, "" },
//  { 0x11D8F, "" },
//  { 0x11D90, "" },
//  { 0x11D91, "" },
//  { 0x11D92, "" },
//  { 0x11D93, "" },
//  { 0x11D94, "" },
//  { 0x11D95, "" },
//  { 0x11D96, "" },
//  { 0x11D97, "" },
//  { 0x11D98, "" },
//  { 0x11D99, "" },
//  { 0x11D9A, "" },
//  { 0x11D9B, "" },
//  { 0x11D9C, "" },
//  { 0x11D9D, "" },
//  { 0x11D9E, "" },
//  { 0x11D9F, "" },
//  { 0x11DA0, "" },
//  { 0x11DA1, "" },
//  { 0x11DA2, "" },
//  { 0x11DA3, "" },
//  { 0x11DA4, "" },
//  { 0x11DA5, "" },
//  { 0x11DA6, "" },
//  { 0x11DA7, "" },
//  { 0x11DA8, "" },
//  { 0x11DA9, "" },
//  { 0x11DAA, "" },
//  { 0x11DAB, "" },
//  { 0x11DAC, "" },
//  { 0x11DAD, "" },
//  { 0x11DAE, "" },
//  { 0x11DAF, "" },
//  { 0x11DB0, "" },
//  { 0x11DB1, "" },
//  { 0x11DB2, "" },
//  { 0x11DB3, "" },
//  { 0x11DB4, "" },
//  { 0x11DB5, "" },
//  { 0x11DB6, "" },
//  { 0x11DB7, "" },
//  { 0x11DB8, "" },
//  { 0x11DB9, "" },
//  { 0x11DBA, "" },
//  { 0x11DBB, "" },
//  { 0x11DBC, "" },
//  { 0x11DBD, "" },
//  { 0x11DBE, "" },
//  { 0x11DBF, "" },
//  { 0x11DC0, "" },
//  { 0x11DC1, "" },
//  { 0x11DC2, "" },
//  { 0x11DC3, "" },
//  { 0x11DC4, "" },
//  { 0x11DC5, "" },
//  { 0x11DC6, "" },
//  { 0x11DC7, "" },
//  { 0x11DC8, "" },
//  { 0x11DC9, "" },
//  { 0x11DCA, "" },
//  { 0x11DCB, "" },
//  { 0x11DCC, "" },
//  { 0x11DCD, "" },
//  { 0x11DCE, "" },
//  { 0x11DCF, "" },
//  { 0x11DD0, "" },
//  { 0x11DD1, "" },
//  { 0x11DD2, "" },
//  { 0x11DD3, "" },
//  { 0x11DD4, "" },
//  { 0x11DD5, "" },
//  { 0x11DD6, "" },
//  { 0x11DD7, "" },
//  { 0x11DD8, "" },
//  { 0x11DD9, "" },
//  { 0x11DDA, "" },
//  { 0x11DDB, "" },
//  { 0x11DDC, "" },
//  { 0x11DDD, "" },
//  { 0x11DDE, "" },
//  { 0x11DDF, "" },
//  { 0x11DE0, "" },
//  { 0x11DE1, "" },
//  { 0x11DE2, "" },
//  { 0x11DE3, "" },
//  { 0x11DE4, "" },
//  { 0x11DE5, "" },
//  { 0x11DE6, "" },
//  { 0x11DE7, "" },
//  { 0x11DE8, "" },
//  { 0x11DE9, "" },
//  { 0x11DEA, "" },
//  { 0x11DEB, "" },
//  { 0x11DEC, "" },
//  { 0x11DED, "" },
//  { 0x11DEE, "" },
//  { 0x11DEF, "" },
//  { 0x11DF0, "" },
//  { 0x11DF1, "" },
//  { 0x11DF2, "" },
//  { 0x11DF3, "" },
//  { 0x11DF4, "" },
//  { 0x11DF5, "" },
//  { 0x11DF6, "" },
//  { 0x11DF7, "" },
//  { 0x11DF8, "" },
//  { 0x11DF9, "" },
//  { 0x11DFA, "" },
//  { 0x11DFB, "" },
//  { 0x11DFC, "" },
//  { 0x11DFD, "" },
//  { 0x11DFE, "" },
//  { 0x11DFF, "" },
//  { 0x11E00, "" },
//  { 0x11E01, "" },
//  { 0x11E02, "" },
//  { 0x11E03, "" },
//  { 0x11E04, "" },
//  { 0x11E05, "" },
//  { 0x11E06, "" },
//  { 0x11E07, "" },
//  { 0x11E08, "" },
//  { 0x11E09, "" },
//  { 0x11E0A, "" },
//  { 0x11E0B, "" },
//  { 0x11E0C, "" },
//  { 0x11E0D, "" },
//  { 0x11E0E, "" },
//  { 0x11E0F, "" },
//  { 0x11E10, "" },
//  { 0x11E11, "" },
//  { 0x11E12, "" },
//  { 0x11E13, "" },
//  { 0x11E14, "" },
//  { 0x11E15, "" },
//  { 0x11E16, "" },
//  { 0x11E17, "" },
//  { 0x11E18, "" },
//  { 0x11E19, "" },
//  { 0x11E1A, "" },
//  { 0x11E1B, "" },
//  { 0x11E1C, "" },
//  { 0x11E1D, "" },
//  { 0x11E1E, "" },
//  { 0x11E1F, "" },
//  { 0x11E20, "" },
//  { 0x11E21, "" },
//  { 0x11E22, "" },
//  { 0x11E23, "" },
//  { 0x11E24, "" },
//  { 0x11E25, "" },
//  { 0x11E26, "" },
//  { 0x11E27, "" },
//  { 0x11E28, "" },
//  { 0x11E29, "" },
//  { 0x11E2A, "" },
//  { 0x11E2B, "" },
//  { 0x11E2C, "" },
//  { 0x11E2D, "" },
//  { 0x11E2E, "" },
//  { 0x11E2F, "" },
//  { 0x11E30, "" },
//  { 0x11E31, "" },
//  { 0x11E32, "" },
//  { 0x11E33, "" },
//  { 0x11E34, "" },
//  { 0x11E35, "" },
//  { 0x11E36, "" },
//  { 0x11E37, "" },
//  { 0x11E38, "" },
//  { 0x11E39, "" },
//  { 0x11E3A, "" },
//  { 0x11E3B, "" },
//  { 0x11E3C, "" },
//  { 0x11E3D, "" },
//  { 0x11E3E, "" },
//  { 0x11E3F, "" },
//  { 0x11E40, "" },
//  { 0x11E41, "" },
//  { 0x11E42, "" },
//  { 0x11E43, "" },
//  { 0x11E44, "" },
//  { 0x11E45, "" },
//  { 0x11E46, "" },
//  { 0x11E47, "" },
//  { 0x11E48, "" },
//  { 0x11E49, "" },
//  { 0x11E4A, "" },
//  { 0x11E4B, "" },
//  { 0x11E4C, "" },
//  { 0x11E4D, "" },
//  { 0x11E4E, "" },
//  { 0x11E4F, "" },
//  { 0x11E50, "" },
//  { 0x11E51, "" },
//  { 0x11E52, "" },
//  { 0x11E53, "" },
//  { 0x11E54, "" },
//  { 0x11E55, "" },
//  { 0x11E56, "" },
//  { 0x11E57, "" },
//  { 0x11E58, "" },
//  { 0x11E59, "" },
//  { 0x11E5A, "" },
//  { 0x11E5B, "" },
//  { 0x11E5C, "" },
//  { 0x11E5D, "" },
//  { 0x11E5E, "" },
//  { 0x11E5F, "" },
//  { 0x11E60, "" },
//  { 0x11E61, "" },
//  { 0x11E62, "" },
//  { 0x11E63, "" },
//  { 0x11E64, "" },
//  { 0x11E65, "" },
//  { 0x11E66, "" },
//  { 0x11E67, "" },
//  { 0x11E68, "" },
//  { 0x11E69, "" },
//  { 0x11E6A, "" },
//  { 0x11E6B, "" },
//  { 0x11E6C, "" },
//  { 0x11E6D, "" },
//  { 0x11E6E, "" },
//  { 0x11E6F, "" },
//  { 0x11E70, "" },
//  { 0x11E71, "" },
//  { 0x11E72, "" },
//  { 0x11E73, "" },
//  { 0x11E74, "" },
//  { 0x11E75, "" },
//  { 0x11E76, "" },
//  { 0x11E77, "" },
//  { 0x11E78, "" },
//  { 0x11E79, "" },
//  { 0x11E7A, "" },
//  { 0x11E7B, "" },
//  { 0x11E7C, "" },
//  { 0x11E7D, "" },
//  { 0x11E7E, "" },
//  { 0x11E7F, "" },
//  { 0x11E80, "" },
//  { 0x11E81, "" },
//  { 0x11E82, "" },
//  { 0x11E83, "" },
//  { 0x11E84, "" },
//  { 0x11E85, "" },
//  { 0x11E86, "" },
//  { 0x11E87, "" },
//  { 0x11E88, "" },
//  { 0x11E89, "" },
//  { 0x11E8A, "" },
//  { 0x11E8B, "" },
//  { 0x11E8C, "" },
//  { 0x11E8D, "" },
//  { 0x11E8E, "" },
//  { 0x11E8F, "" },
//  { 0x11E90, "" },
//  { 0x11E91, "" },
//  { 0x11E92, "" },
//  { 0x11E93, "" },
//  { 0x11E94, "" },
//  { 0x11E95, "" },
//  { 0x11E96, "" },
//  { 0x11E97, "" },
//  { 0x11E98, "" },
//  { 0x11E99, "" },
//  { 0x11E9A, "" },
//  { 0x11E9B, "" },
//  { 0x11E9C, "" },
//  { 0x11E9D, "" },
//  { 0x11E9E, "" },
//  { 0x11E9F, "" },
//  { 0x11EA0, "" },
//  { 0x11EA1, "" },
//  { 0x11EA2, "" },
//  { 0x11EA3, "" },
//  { 0x11EA4, "" },
//  { 0x11EA5, "" },
//  { 0x11EA6, "" },
//  { 0x11EA7, "" },
//  { 0x11EA8, "" },
//  { 0x11EA9, "" },
//  { 0x11EAA, "" },
//  { 0x11EAB, "" },
//  { 0x11EAC, "" },
//  { 0x11EAD, "" },
//  { 0x11EAE, "" },
//  { 0x11EAF, "" },
//  { 0x11EB0, "" },
//  { 0x11EB1, "" },
//  { 0x11EB2, "" },
//  { 0x11EB3, "" },
//  { 0x11EB4, "" },
//  { 0x11EB5, "" },
//  { 0x11EB6, "" },
//  { 0x11EB7, "" },
//  { 0x11EB8, "" },
//  { 0x11EB9, "" },
//  { 0x11EBA, "" },
//  { 0x11EBB, "" },
//  { 0x11EBC, "" },
//  { 0x11EBD, "" },
//  { 0x11EBE, "" },
//  { 0x11EBF, "" },
//  { 0x11EC0, "" },
//  { 0x11EC1, "" },
//  { 0x11EC2, "" },
//  { 0x11EC3, "" },
//  { 0x11EC4, "" },
//  { 0x11EC5, "" },
//  { 0x11EC6, "" },
//  { 0x11EC7, "" },
//  { 0x11EC8, "" },
//  { 0x11EC9, "" },
//  { 0x11ECA, "" },
//  { 0x11ECB, "" },
//  { 0x11ECC, "" },
//  { 0x11ECD, "" },
//  { 0x11ECE, "" },
//  { 0x11ECF, "" },
//  { 0x11ED0, "" },
//  { 0x11ED1, "" },
//  { 0x11ED2, "" },
//  { 0x11ED3, "" },
//  { 0x11ED4, "" },
//  { 0x11ED5, "" },
//  { 0x11ED6, "" },
//  { 0x11ED7, "" },
//  { 0x11ED8, "" },
//  { 0x11ED9, "" },
//  { 0x11EDA, "" },
//  { 0x11EDB, "" },
//  { 0x11EDC, "" },
//  { 0x11EDD, "" },
//  { 0x11EDE, "" },
//  { 0x11EDF, "" },
//  { 0x11EE0, "" },
//  { 0x11EE1, "" },
//  { 0x11EE2, "" },
//  { 0x11EE3, "" },
//  { 0x11EE4, "" },
//  { 0x11EE5, "" },
//  { 0x11EE6, "" },
//  { 0x11EE7, "" },
//  { 0x11EE8, "" },
//  { 0x11EE9, "" },
//  { 0x11EEA, "" },
//  { 0x11EEB, "" },
//  { 0x11EEC, "" },
//  { 0x11EED, "" },
//  { 0x11EEE, "" },
//  { 0x11EEF, "" },
//  { 0x11EF0, "" },
//  { 0x11EF1, "" },
//  { 0x11EF2, "" },
//  { 0x11EF3, "" },
//  { 0x11EF4, "" },
//  { 0x11EF5, "" },
//  { 0x11EF6, "" },
//  { 0x11EF7, "" },
//  { 0x11EF8, "" },
//  { 0x11EF9, "" },
//  { 0x11EFA, "" },
//  { 0x11EFB, "" },
//  { 0x11EFC, "" },
//  { 0x11EFD, "" },
//  { 0x11EFE, "" },
//  { 0x11EFF, "" },
//  { 0x11F00, "" },
//  { 0x11F01, "" },
//  { 0x11F02, "" },
//  { 0x11F03, "" },
//  { 0x11F04, "" },
//  { 0x11F05, "" },
//  { 0x11F06, "" },
//  { 0x11F07, "" },
//  { 0x11F08, "" },
//  { 0x11F09, "" },
//  { 0x11F0A, "" },
//  { 0x11F0B, "" },
//  { 0x11F0C, "" },
//  { 0x11F0D, "" },
//  { 0x11F0E, "" },
//  { 0x11F0F, "" },
//  { 0x11F10, "" },
//  { 0x11F11, "" },
//  { 0x11F12, "" },
//  { 0x11F13, "" },
//  { 0x11F14, "" },
//  { 0x11F15, "" },
//  { 0x11F16, "" },
//  { 0x11F17, "" },
//  { 0x11F18, "" },
//  { 0x11F19, "" },
//  { 0x11F1A, "" },
//  { 0x11F1B, "" },
//  { 0x11F1C, "" },
//  { 0x11F1D, "" },
//  { 0x11F1E, "" },
//  { 0x11F1F, "" },
//  { 0x11F20, "" },
//  { 0x11F21, "" },
//  { 0x11F22, "" },
//  { 0x11F23, "" },
//  { 0x11F24, "" },
//  { 0x11F25, "" },
//  { 0x11F26, "" },
//  { 0x11F27, "" },
//  { 0x11F28, "" },
//  { 0x11F29, "" },
//  { 0x11F2A, "" },
//  { 0x11F2B, "" },
//  { 0x11F2C, "" },
//  { 0x11F2D, "" },
//  { 0x11F2E, "" },
//  { 0x11F2F, "" },
//  { 0x11F30, "" },
//  { 0x11F31, "" },
//  { 0x11F32, "" },
//  { 0x11F33, "" },
//  { 0x11F34, "" },
//  { 0x11F35, "" },
//  { 0x11F36, "" },
//  { 0x11F37, "" },
//  { 0x11F38, "" },
//  { 0x11F39, "" },
//  { 0x11F3A, "" },
//  { 0x11F3B, "" },
//  { 0x11F3C, "" },
//  { 0x11F3D, "" },
//  { 0x11F3E, "" },
//  { 0x11F3F, "" },
//  { 0x11F40, "" },
//  { 0x11F41, "" },
//  { 0x11F42, "" },
//  { 0x11F43, "" },
//  { 0x11F44, "" },
//  { 0x11F45, "" },
//  { 0x11F46, "" },
//  { 0x11F47, "" },
//  { 0x11F48, "" },
//  { 0x11F49, "" },
//  { 0x11F4A, "" },
//  { 0x11F4B, "" },
//  { 0x11F4C, "" },
//  { 0x11F4D, "" },
//  { 0x11F4E, "" },
//  { 0x11F4F, "" },
//  { 0x11F50, "" },
//  { 0x11F51, "" },
//  { 0x11F52, "" },
//  { 0x11F53, "" },
//  { 0x11F54, "" },
//  { 0x11F55, "" },
//  { 0x11F56, "" },
//  { 0x11F57, "" },
//  { 0x11F58, "" },
//  { 0x11F59, "" },
//  { 0x11F5A, "" },
//  { 0x11F5B, "" },
//  { 0x11F5C, "" },
//  { 0x11F5D, "" },
//  { 0x11F5E, "" },
//  { 0x11F5F, "" },
//  { 0x11F60, "" },
//  { 0x11F61, "" },
//  { 0x11F62, "" },
//  { 0x11F63, "" },
//  { 0x11F64, "" },
//  { 0x11F65, "" },
//  { 0x11F66, "" },
//  { 0x11F67, "" },
//  { 0x11F68, "" },
//  { 0x11F69, "" },
//  { 0x11F6A, "" },
//  { 0x11F6B, "" },
//  { 0x11F6C, "" },
//  { 0x11F6D, "" },
//  { 0x11F6E, "" },
//  { 0x11F6F, "" },
//  { 0x11F70, "" },
//  { 0x11F71, "" },
//  { 0x11F72, "" },
//  { 0x11F73, "" },
//  { 0x11F74, "" },
//  { 0x11F75, "" },
//  { 0x11F76, "" },
//  { 0x11F77, "" },
//  { 0x11F78, "" },
//  { 0x11F79, "" },
//  { 0x11F7A, "" },
//  { 0x11F7B, "" },
//  { 0x11F7C, "" },
//  { 0x11F7D, "" },
//  { 0x11F7E, "" },
//  { 0x11F7F, "" },
//  { 0x11F80, "" },
//  { 0x11F81, "" },
//  { 0x11F82, "" },
//  { 0x11F83, "" },
//  { 0x11F84, "" },
//  { 0x11F85, "" },
//  { 0x11F86, "" },
//  { 0x11F87, "" },
//  { 0x11F88, "" },
//  { 0x11F89, "" },
//  { 0x11F8A, "" },
//  { 0x11F8B, "" },
//  { 0x11F8C, "" },
//  { 0x11F8D, "" },
//  { 0x11F8E, "" },
//  { 0x11F8F, "" },
//  { 0x11F90, "" },
//  { 0x11F91, "" },
//  { 0x11F92, "" },
//  { 0x11F93, "" },
//  { 0x11F94, "" },
//  { 0x11F95, "" },
//  { 0x11F96, "" },
//  { 0x11F97, "" },
//  { 0x11F98, "" },
//  { 0x11F99, "" },
//  { 0x11F9A, "" },
//  { 0x11F9B, "" },
//  { 0x11F9C, "" },
//  { 0x11F9D, "" },
//  { 0x11F9E, "" },
//  { 0x11F9F, "" },
//  { 0x11FA0, "" },
//  { 0x11FA1, "" },
//  { 0x11FA2, "" },
//  { 0x11FA3, "" },
//  { 0x11FA4, "" },
//  { 0x11FA5, "" },
//  { 0x11FA6, "" },
//  { 0x11FA7, "" },
//  { 0x11FA8, "" },
//  { 0x11FA9, "" },
//  { 0x11FAA, "" },
//  { 0x11FAB, "" },
//  { 0x11FAC, "" },
//  { 0x11FAD, "" },
//  { 0x11FAE, "" },
//  { 0x11FAF, "" },
//  { 0x11FB0, "" },
//  { 0x11FB1, "" },
//  { 0x11FB2, "" },
//  { 0x11FB3, "" },
//  { 0x11FB4, "" },
//  { 0x11FB5, "" },
//  { 0x11FB6, "" },
//  { 0x11FB7, "" },
//  { 0x11FB8, "" },
//  { 0x11FB9, "" },
//  { 0x11FBA, "" },
//  { 0x11FBB, "" },
//  { 0x11FBC, "" },
//  { 0x11FBD, "" },
//  { 0x11FBE, "" },
//  { 0x11FBF, "" },
//  { 0x11FC0, "" },
//  { 0x11FC1, "" },
//  { 0x11FC2, "" },
//  { 0x11FC3, "" },
//  { 0x11FC4, "" },
//  { 0x11FC5, "" },
//  { 0x11FC6, "" },
//  { 0x11FC7, "" },
//  { 0x11FC8, "" },
//  { 0x11FC9, "" },
//  { 0x11FCA, "" },
//  { 0x11FCB, "" },
//  { 0x11FCC, "" },
//  { 0x11FCD, "" },
//  { 0x11FCE, "" },
//  { 0x11FCF, "" },
//  { 0x11FD0, "" },
//  { 0x11FD1, "" },
//  { 0x11FD2, "" },
//  { 0x11FD3, "" },
//  { 0x11FD4, "" },
//  { 0x11FD5, "" },
//  { 0x11FD6, "" },
//  { 0x11FD7, "" },
//  { 0x11FD8, "" },
//  { 0x11FD9, "" },
//  { 0x11FDA, "" },
//  { 0x11FDB, "" },
//  { 0x11FDC, "" },
//  { 0x11FDD, "" },
//  { 0x11FDE, "" },
//  { 0x11FDF, "" },
//  { 0x11FE0, "" },
//  { 0x11FE1, "" },
//  { 0x11FE2, "" },
//  { 0x11FE3, "" },
//  { 0x11FE4, "" },
//  { 0x11FE5, "" },
//  { 0x11FE6, "" },
//  { 0x11FE7, "" },
//  { 0x11FE8, "" },
//  { 0x11FE9, "" },
//  { 0x11FEA, "" },
//  { 0x11FEB, "" },
//  { 0x11FEC, "" },
//  { 0x11FED, "" },
//  { 0x11FEE, "" },
//  { 0x11FEF, "" },
//  { 0x11FF0, "" },
//  { 0x11FF1, "" },
//  { 0x11FF2, "" },
//  { 0x11FF3, "" },
//  { 0x11FF4, "" },
//  { 0x11FF5, "" },
//  { 0x11FF6, "" },
//  { 0x11FF7, "" },
//  { 0x11FF8, "" },
//  { 0x11FF9, "" },
//  { 0x11FFA, "" },
//  { 0x11FFB, "" },
//  { 0x11FFC, "" },
//  { 0x11FFD, "" },
//  { 0x11FFE, "" },
//  { 0x11FFF, "" },
//  { 0x12000, "" },
//  { 0x12001, "" },
//  { 0x12002, "" },
//  { 0x12003, "" },
//  { 0x12004, "" },
//  { 0x12005, "" },
//  { 0x12006, "" },
//  { 0x12007, "" },
//  { 0x12008, "" },
//  { 0x12009, "" },
//  { 0x1200A, "" },
//  { 0x1200B, "" },
//  { 0x1200C, "" },
//  { 0x1200D, "" },
//  { 0x1200E, "" },
//  { 0x1200F, "" },
//  { 0x12010, "" },
//  { 0x12011, "" },
//  { 0x12012, "" },
//  { 0x12013, "" },
//  { 0x12014, "" },
//  { 0x12015, "" },
//  { 0x12016, "" },
//  { 0x12017, "" },
//  { 0x12018, "" },
//  { 0x12019, "" },
//  { 0x1201A, "" },
//  { 0x1201B, "" },
//  { 0x1201C, "" },
//  { 0x1201D, "" },
//  { 0x1201E, "" },
//  { 0x1201F, "" },
//  { 0x12020, "" },
//  { 0x12021, "" },
//  { 0x12022, "" },
//  { 0x12023, "" },
//  { 0x12024, "" },
//  { 0x12025, "" },
//  { 0x12026, "" },
//  { 0x12027, "" },
//  { 0x12028, "" },
//  { 0x12029, "" },
//  { 0x1202A, "" },
//  { 0x1202B, "" },
//  { 0x1202C, "" },
//  { 0x1202D, "" },
//  { 0x1202E, "" },
//  { 0x1202F, "" },
//  { 0x12030, "" },
//  { 0x12031, "" },
//  { 0x12032, "" },
//  { 0x12033, "" },
//  { 0x12034, "" },
//  { 0x12035, "" },
//  { 0x12036, "" },
//  { 0x12037, "" },
//  { 0x12038, "" },
//  { 0x12039, "" },
//  { 0x1203A, "" },
//  { 0x1203B, "" },
//  { 0x1203C, "" },
//  { 0x1203D, "" },
//  { 0x1203E, "" },
//  { 0x1203F, "" },
//  { 0x12040, "" },
//  { 0x12041, "" },
//  { 0x12042, "" },
//  { 0x12043, "" },
//  { 0x12044, "" },
//  { 0x12045, "" },
//  { 0x12046, "" },
//  { 0x12047, "" },
//  { 0x12048, "" },
//  { 0x12049, "" },
//  { 0x1204A, "" },
//  { 0x1204B, "" },
//  { 0x1204C, "" },
//  { 0x1204D, "" },
//  { 0x1204E, "" },
//  { 0x1204F, "" },
//  { 0x12050, "" },
//  { 0x12051, "" },
//  { 0x12052, "" },
//  { 0x12053, "" },
//  { 0x12054, "" },
//  { 0x12055, "" },
//  { 0x12056, "" },
//  { 0x12057, "" },
//  { 0x12058, "" },
//  { 0x12059, "" },
//  { 0x1205A, "" },
//  { 0x1205B, "" },
//  { 0x1205C, "" },
//  { 0x1205D, "" },
//  { 0x1205E, "" },
//  { 0x1205F, "" },
//  { 0x12060, "" },
//  { 0x12061, "" },
//  { 0x12062, "" },
//  { 0x12063, "" },
//  { 0x12064, "" },
//  { 0x12065, "" },
//  { 0x12066, "" },
//  { 0x12067, "" },
//  { 0x12068, "" },
//  { 0x12069, "" },
//  { 0x1206A, "" },
//  { 0x1206B, "" },
//  { 0x1206C, "" },
//  { 0x1206D, "" },
//  { 0x1206E, "" },
//  { 0x1206F, "" },
//  { 0x12070, "" },
//  { 0x12071, "" },
//  { 0x12072, "" },
//  { 0x12073, "" },
//  { 0x12074, "" },
//  { 0x12075, "" },
//  { 0x12076, "" },
//  { 0x12077, "" },
//  { 0x12078, "" },
//  { 0x12079, "" },
//  { 0x1207A, "" },
//  { 0x1207B, "" },
//  { 0x1207C, "" },
//  { 0x1207D, "" },
//  { 0x1207E, "" },
//  { 0x1207F, "" },
//  { 0x12080, "" },
//  { 0x12081, "" },
//  { 0x12082, "" },
//  { 0x12083, "" },
//  { 0x12084, "" },
//  { 0x12085, "" },
//  { 0x12086, "" },
//  { 0x12087, "" },
//  { 0x12088, "" },
//  { 0x12089, "" },
//  { 0x1208A, "" },
//  { 0x1208B, "" },
//  { 0x1208C, "" },
//  { 0x1208D, "" },
//  { 0x1208E, "" },
//  { 0x1208F, "" },
//  { 0x12090, "" },
//  { 0x12091, "" },
//  { 0x12092, "" },
//  { 0x12093, "" },
//  { 0x12094, "" },
//  { 0x12095, "" },
//  { 0x12096, "" },
//  { 0x12097, "" },
//  { 0x12098, "" },
//  { 0x12099, "" },
//  { 0x1209A, "" },
//  { 0x1209B, "" },
//  { 0x1209C, "" },
//  { 0x1209D, "" },
//  { 0x1209E, "" },
//  { 0x1209F, "" },
//  { 0x120A0, "" },
//  { 0x120A1, "" },
//  { 0x120A2, "" },
//  { 0x120A3, "" },
//  { 0x120A4, "" },
//  { 0x120A5, "" },
//  { 0x120A6, "" },
//  { 0x120A7, "" },
//  { 0x120A8, "" },
//  { 0x120A9, "" },
//  { 0x120AA, "" },
//  { 0x120AB, "" },
//  { 0x120AC, "" },
//  { 0x120AD, "" },
//  { 0x120AE, "" },
//  { 0x120AF, "" },
//  { 0x120B0, "" },
//  { 0x120B1, "" },
//  { 0x120B2, "" },
//  { 0x120B3, "" },
//  { 0x120B4, "" },
//  { 0x120B5, "" },
//  { 0x120B6, "" },
//  { 0x120B7, "" },
//  { 0x120B8, "" },
//  { 0x120B9, "" },
//  { 0x120BA, "" },
//  { 0x120BB, "" },
//  { 0x120BC, "" },
//  { 0x120BD, "" },
//  { 0x120BE, "" },
//  { 0x120BF, "" },
//  { 0x120C0, "" },
//  { 0x120C1, "" },
//  { 0x120C2, "" },
//  { 0x120C3, "" },
//  { 0x120C4, "" },
//  { 0x120C5, "" },
//  { 0x120C6, "" },
//  { 0x120C7, "" },
//  { 0x120C8, "" },
//  { 0x120C9, "" },
//  { 0x120CA, "" },
//  { 0x120CB, "" },
//  { 0x120CC, "" },
//  { 0x120CD, "" },
//  { 0x120CE, "" },
//  { 0x120CF, "" },
//  { 0x120D0, "" },
//  { 0x120D1, "" },
//  { 0x120D2, "" },
//  { 0x120D3, "" },
//  { 0x120D4, "" },
//  { 0x120D5, "" },
//  { 0x120D6, "" },
//  { 0x120D7, "" },
//  { 0x120D8, "" },
//  { 0x120D9, "" },
//  { 0x120DA, "" },
//  { 0x120DB, "" },
//  { 0x120DC, "" },
//  { 0x120DD, "" },
//  { 0x120DE, "" },
//  { 0x120DF, "" },
//  { 0x120E0, "" },
//  { 0x120E1, "" },
//  { 0x120E2, "" },
//  { 0x120E3, "" },
//  { 0x120E4, "" },
//  { 0x120E5, "" },
//  { 0x120E6, "" },
//  { 0x120E7, "" },
//  { 0x120E8, "" },
//  { 0x120E9, "" },
//  { 0x120EA, "" },
//  { 0x120EB, "" },
//  { 0x120EC, "" },
//  { 0x120ED, "" },
//  { 0x120EE, "" },
//  { 0x120EF, "" },
//  { 0x120F0, "" },
//  { 0x120F1, "" },
//  { 0x120F2, "" },
//  { 0x120F3, "" },
//  { 0x120F4, "" },
//  { 0x120F5, "" },
//  { 0x120F6, "" },
//  { 0x120F7, "" },
//  { 0x120F8, "" },
//  { 0x120F9, "" },
//  { 0x120FA, "" },
//  { 0x120FB, "" },
//  { 0x120FC, "" },
//  { 0x120FD, "" },
//  { 0x120FE, "" },
//  { 0x120FF, "" },
//  { 0x12100, "" },
//  { 0x12101, "" },
//  { 0x12102, "" },
//  { 0x12103, "" },
//  { 0x12104, "" },
//  { 0x12105, "" },
//  { 0x12106, "" },
//  { 0x12107, "" },
//  { 0x12108, "" },
//  { 0x12109, "" },
//  { 0x1210A, "" },
//  { 0x1210B, "" },
//  { 0x1210C, "" },
//  { 0x1210D, "" },
//  { 0x1210E, "" },
//  { 0x1210F, "" },
//  { 0x12110, "" },
//  { 0x12111, "" },
//  { 0x12112, "" },
//  { 0x12113, "" },
//  { 0x12114, "" },
//  { 0x12115, "" },
//  { 0x12116, "" },
//  { 0x12117, "" },
//  { 0x12118, "" },
//  { 0x12119, "" },
//  { 0x1211A, "" },
//  { 0x1211B, "" },
//  { 0x1211C, "" },
//  { 0x1211D, "" },
//  { 0x1211E, "" },
//  { 0x1211F, "" },
//  { 0x12120, "" },
//  { 0x12121, "" },
//  { 0x12122, "" },
//  { 0x12123, "" },
//  { 0x12124, "" },
//  { 0x12125, "" },
//  { 0x12126, "" },
//  { 0x12127, "" },
//  { 0x12128, "" },
//  { 0x12129, "" },
//  { 0x1212A, "" },
//  { 0x1212B, "" },
//  { 0x1212C, "" },
//  { 0x1212D, "" },
//  { 0x1212E, "" },
//  { 0x1212F, "" },
//  { 0x12130, "" },
//  { 0x12131, "" },
//  { 0x12132, "" },
//  { 0x12133, "" },
//  { 0x12134, "" },
//  { 0x12135, "" },
//  { 0x12136, "" },
//  { 0x12137, "" },
//  { 0x12138, "" },
//  { 0x12139, "" },
//  { 0x1213A, "" },
//  { 0x1213B, "" },
//  { 0x1213C, "" },
//  { 0x1213D, "" },
//  { 0x1213E, "" },
//  { 0x1213F, "" },
//  { 0x12140, "" },
//  { 0x12141, "" },
//  { 0x12142, "" },
//  { 0x12143, "" },
//  { 0x12144, "" },
//  { 0x12145, "" },
//  { 0x12146, "" },
//  { 0x12147, "" },
//  { 0x12148, "" },
//  { 0x12149, "" },
//  { 0x1214A, "" },
//  { 0x1214B, "" },
//  { 0x1214C, "" },
//  { 0x1214D, "" },
//  { 0x1214E, "" },
//  { 0x1214F, "" },
//  { 0x12150, "" },
//  { 0x12151, "" },
//  { 0x12152, "" },
//  { 0x12153, "" },
//  { 0x12154, "" },
//  { 0x12155, "" },
//  { 0x12156, "" },
//  { 0x12157, "" },
//  { 0x12158, "" },
//  { 0x12159, "" },
//  { 0x1215A, "" },
//  { 0x1215B, "" },
//  { 0x1215C, "" },
//  { 0x1215D, "" },
//  { 0x1215E, "" },
//  { 0x1215F, "" },
//  { 0x12160, "" },
//  { 0x12161, "" },
//  { 0x12162, "" },
//  { 0x12163, "" },
//  { 0x12164, "" },
//  { 0x12165, "" },
//  { 0x12166, "" },
//  { 0x12167, "" },
//  { 0x12168, "" },
//  { 0x12169, "" },
//  { 0x1216A, "" },
//  { 0x1216B, "" },
//  { 0x1216C, "" },
//  { 0x1216D, "" },
//  { 0x1216E, "" },
//  { 0x1216F, "" },
//  { 0x12170, "" },
//  { 0x12171, "" },
//  { 0x12172, "" },
//  { 0x12173, "" },
//  { 0x12174, "" },
//  { 0x12175, "" },
//  { 0x12176, "" },
//  { 0x12177, "" },
//  { 0x12178, "" },
//  { 0x12179, "" },
//  { 0x1217A, "" },
//  { 0x1217B, "" },
//  { 0x1217C, "" },
//  { 0x1217D, "" },
//  { 0x1217E, "" },
//  { 0x1217F, "" },
//  { 0x12180, "" },
//  { 0x12181, "" },
//  { 0x12182, "" },
//  { 0x12183, "" },
//  { 0x12184, "" },
//  { 0x12185, "" },
//  { 0x12186, "" },
//  { 0x12187, "" },
//  { 0x12188, "" },
//  { 0x12189, "" },
//  { 0x1218A, "" },
//  { 0x1218B, "" },
//  { 0x1218C, "" },
//  { 0x1218D, "" },
//  { 0x1218E, "" },
//  { 0x1218F, "" },
//  { 0x12190, "" },
//  { 0x12191, "" },
//  { 0x12192, "" },
//  { 0x12193, "" },
//  { 0x12194, "" },
//  { 0x12195, "" },
//  { 0x12196, "" },
//  { 0x12197, "" },
//  { 0x12198, "" },
//  { 0x12199, "" },
//  { 0x1219A, "" },
//  { 0x1219B, "" },
//  { 0x1219C, "" },
//  { 0x1219D, "" },
//  { 0x1219E, "" },
//  { 0x1219F, "" },
//  { 0x121A0, "" },
//  { 0x121A1, "" },
//  { 0x121A2, "" },
//  { 0x121A3, "" },
//  { 0x121A4, "" },
//  { 0x121A5, "" },
//  { 0x121A6, "" },
//  { 0x121A7, "" },
//  { 0x121A8, "" },
//  { 0x121A9, "" },
//  { 0x121AA, "" },
//  { 0x121AB, "" },
//  { 0x121AC, "" },
//  { 0x121AD, "" },
//  { 0x121AE, "" },
//  { 0x121AF, "" },
//  { 0x121B0, "" },
//  { 0x121B1, "" },
//  { 0x121B2, "" },
//  { 0x121B3, "" },
//  { 0x121B4, "" },
//  { 0x121B5, "" },
//  { 0x121B6, "" },
//  { 0x121B7, "" },
//  { 0x121B8, "" },
//  { 0x121B9, "" },
//  { 0x121BA, "" },
//  { 0x121BB, "" },
//  { 0x121BC, "" },
//  { 0x121BD, "" },
//  { 0x121BE, "" },
//  { 0x121BF, "" },
//  { 0x121C0, "" },
//  { 0x121C1, "" },
//  { 0x121C2, "" },
//  { 0x121C3, "" },
//  { 0x121C4, "" },
//  { 0x121C5, "" },
//  { 0x121C6, "" },
//  { 0x121C7, "" },
//  { 0x121C8, "" },
//  { 0x121C9, "" },
//  { 0x121CA, "" },
//  { 0x121CB, "" },
//  { 0x121CC, "" },
//  { 0x121CD, "" },
//  { 0x121CE, "" },
//  { 0x121CF, "" },
//  { 0x121D0, "" },
//  { 0x121D1, "" },
//  { 0x121D2, "" },
//  { 0x121D3, "" },
//  { 0x121D4, "" },
//  { 0x121D5, "" },
//  { 0x121D6, "" },
//  { 0x121D7, "" },
//  { 0x121D8, "" },
//  { 0x121D9, "" },
//  { 0x121DA, "" },
//  { 0x121DB, "" },
//  { 0x121DC, "" },
//  { 0x121DD, "" },
//  { 0x121DE, "" },
//  { 0x121DF, "" },
//  { 0x121E0, "" },
//  { 0x121E1, "" },
//  { 0x121E2, "" },
//  { 0x121E3, "" },
//  { 0x121E4, "" },
//  { 0x121E5, "" },
//  { 0x121E6, "" },
//  { 0x121E7, "" },
//  { 0x121E8, "" },
//  { 0x121E9, "" },
//  { 0x121EA, "" },
//  { 0x121EB, "" },
//  { 0x121EC, "" },
//  { 0x121ED, "" },
//  { 0x121EE, "" },
//  { 0x121EF, "" },
//  { 0x121F0, "" },
//  { 0x121F1, "" },
//  { 0x121F2, "" },
//  { 0x121F3, "" },
//  { 0x121F4, "" },
//  { 0x121F5, "" },
//  { 0x121F6, "" },
//  { 0x121F7, "" },
//  { 0x121F8, "" },
//  { 0x121F9, "" },
//  { 0x121FA, "" },
//  { 0x121FB, "" },
//  { 0x121FC, "" },
//  { 0x121FD, "" },
//  { 0x121FE, "" },
//  { 0x121FF, "" },
//  { 0x12200, "" },
//  { 0x12201, "" },
//  { 0x12202, "" },
//  { 0x12203, "" },
//  { 0x12204, "" },
//  { 0x12205, "" },
//  { 0x12206, "" },
//  { 0x12207, "" },
//  { 0x12208, "" },
//  { 0x12209, "" },
//  { 0x1220A, "" },
//  { 0x1220B, "" },
//  { 0x1220C, "" },
//  { 0x1220D, "" },
//  { 0x1220E, "" },
//  { 0x1220F, "" },
//  { 0x12210, "" },
//  { 0x12211, "" },
//  { 0x12212, "" },
//  { 0x12213, "" },
//  { 0x12214, "" },
//  { 0x12215, "" },
//  { 0x12216, "" },
//  { 0x12217, "" },
//  { 0x12218, "" },
//  { 0x12219, "" },
//  { 0x1221A, "" },
//  { 0x1221B, "" },
//  { 0x1221C, "" },
//  { 0x1221D, "" },
//  { 0x1221E, "" },
//  { 0x1221F, "" },
//  { 0x12220, "" },
//  { 0x12221, "" },
//  { 0x12222, "" },
//  { 0x12223, "" },
//  { 0x12224, "" },
//  { 0x12225, "" },
//  { 0x12226, "" },
//  { 0x12227, "" },
//  { 0x12228, "" },
//  { 0x12229, "" },
//  { 0x1222A, "" },
//  { 0x1222B, "" },
//  { 0x1222C, "" },
//  { 0x1222D, "" },
//  { 0x1222E, "" },
//  { 0x1222F, "" },
//  { 0x12230, "" },
//  { 0x12231, "" },
//  { 0x12232, "" },
//  { 0x12233, "" },
//  { 0x12234, "" },
//  { 0x12235, "" },
//  { 0x12236, "" },
//  { 0x12237, "" },
//  { 0x12238, "" },
//  { 0x12239, "" },
//  { 0x1223A, "" },
//  { 0x1223B, "" },
//  { 0x1223C, "" },
//  { 0x1223D, "" },
//  { 0x1223E, "" },
//  { 0x1223F, "" },
//  { 0x12240, "" },
//  { 0x12241, "" },
//  { 0x12242, "" },
//  { 0x12243, "" },
//  { 0x12244, "" },
//  { 0x12245, "" },
//  { 0x12246, "" },
//  { 0x12247, "" },
//  { 0x12248, "" },
//  { 0x12249, "" },
//  { 0x1224A, "" },
//  { 0x1224B, "" },
//  { 0x1224C, "" },
//  { 0x1224D, "" },
//  { 0x1224E, "" },
//  { 0x1224F, "" },
//  { 0x12250, "" },
//  { 0x12251, "" },
//  { 0x12252, "" },
//  { 0x12253, "" },
//  { 0x12254, "" },
//  { 0x12255, "" },
//  { 0x12256, "" },
//  { 0x12257, "" },
//  { 0x12258, "" },
//  { 0x12259, "" },
//  { 0x1225A, "" },
//  { 0x1225B, "" },
//  { 0x1225C, "" },
//  { 0x1225D, "" },
//  { 0x1225E, "" },
//  { 0x1225F, "" },
//  { 0x12260, "" },
//  { 0x12261, "" },
//  { 0x12262, "" },
//  { 0x12263, "" },
//  { 0x12264, "" },
//  { 0x12265, "" },
//  { 0x12266, "" },
//  { 0x12267, "" },
//  { 0x12268, "" },
//  { 0x12269, "" },
//  { 0x1226A, "" },
//  { 0x1226B, "" },
//  { 0x1226C, "" },
//  { 0x1226D, "" },
//  { 0x1226E, "" },
//  { 0x1226F, "" },
//  { 0x12270, "" },
//  { 0x12271, "" },
//  { 0x12272, "" },
//  { 0x12273, "" },
//  { 0x12274, "" },
//  { 0x12275, "" },
//  { 0x12276, "" },
//  { 0x12277, "" },
//  { 0x12278, "" },
//  { 0x12279, "" },
//  { 0x1227A, "" },
//  { 0x1227B, "" },
//  { 0x1227C, "" },
//  { 0x1227D, "" },
//  { 0x1227E, "" },
//  { 0x1227F, "" },
//  { 0x12280, "" },
//  { 0x12281, "" },
//  { 0x12282, "" },
//  { 0x12283, "" },
//  { 0x12284, "" },
//  { 0x12285, "" },
//  { 0x12286, "" },
//  { 0x12287, "" },
//  { 0x12288, "" },
//  { 0x12289, "" },
//  { 0x1228A, "" },
//  { 0x1228B, "" },
//  { 0x1228C, "" },
//  { 0x1228D, "" },
//  { 0x1228E, "" },
//  { 0x1228F, "" },
//  { 0x12290, "" },
//  { 0x12291, "" },
//  { 0x12292, "" },
//  { 0x12293, "" },
//  { 0x12294, "" },
//  { 0x12295, "" },
//  { 0x12296, "" },
//  { 0x12297, "" },
//  { 0x12298, "" },
//  { 0x12299, "" },
//  { 0x1229A, "" },
//  { 0x1229B, "" },
//  { 0x1229C, "" },
//  { 0x1229D, "" },
//  { 0x1229E, "" },
//  { 0x1229F, "" },
//  { 0x122A0, "" },
//  { 0x122A1, "" },
//  { 0x122A2, "" },
//  { 0x122A3, "" },
//  { 0x122A4, "" },
//  { 0x122A5, "" },
//  { 0x122A6, "" },
//  { 0x122A7, "" },
//  { 0x122A8, "" },
//  { 0x122A9, "" },
//  { 0x122AA, "" },
//  { 0x122AB, "" },
//  { 0x122AC, "" },
//  { 0x122AD, "" },
//  { 0x122AE, "" },
//  { 0x122AF, "" },
//  { 0x122B0, "" },
//  { 0x122B1, "" },
//  { 0x122B2, "" },
//  { 0x122B3, "" },
//  { 0x122B4, "" },
//  { 0x122B5, "" },
//  { 0x122B6, "" },
//  { 0x122B7, "" },
//  { 0x122B8, "" },
//  { 0x122B9, "" },
//  { 0x122BA, "" },
//  { 0x122BB, "" },
//  { 0x122BC, "" },
//  { 0x122BD, "" },
//  { 0x122BE, "" },
//  { 0x122BF, "" },
//  { 0x122C0, "" },
//  { 0x122C1, "" },
//  { 0x122C2, "" },
//  { 0x122C3, "" },
//  { 0x122C4, "" },
//  { 0x122C5, "" },
//  { 0x122C6, "" },
//  { 0x122C7, "" },
//  { 0x122C8, "" },
//  { 0x122C9, "" },
//  { 0x122CA, "" },
//  { 0x122CB, "" },
//  { 0x122CC, "" },
//  { 0x122CD, "" },
//  { 0x122CE, "" },
//  { 0x122CF, "" },
//  { 0x122D0, "" },
//  { 0x122D1, "" },
//  { 0x122D2, "" },
//  { 0x122D3, "" },
//  { 0x122D4, "" },
//  { 0x122D5, "" },
//  { 0x122D6, "" },
//  { 0x122D7, "" },
//  { 0x122D8, "" },
//  { 0x122D9, "" },
//  { 0x122DA, "" },
//  { 0x122DB, "" },
//  { 0x122DC, "" },
//  { 0x122DD, "" },
//  { 0x122DE, "" },
//  { 0x122DF, "" },
//  { 0x122E0, "" },
//  { 0x122E1, "" },
//  { 0x122E2, "" },
//  { 0x122E3, "" },
//  { 0x122E4, "" },
//  { 0x122E5, "" },
//  { 0x122E6, "" },
//  { 0x122E7, "" },
//  { 0x122E8, "" },
//  { 0x122E9, "" },
//  { 0x122EA, "" },
//  { 0x122EB, "" },
//  { 0x122EC, "" },
//  { 0x122ED, "" },
//  { 0x122EE, "" },
//  { 0x122EF, "" },
//  { 0x122F0, "" },
//  { 0x122F1, "" },
//  { 0x122F2, "" },
//  { 0x122F3, "" },
//  { 0x122F4, "" },
//  { 0x122F5, "" },
//  { 0x122F6, "" },
//  { 0x122F7, "" },
//  { 0x122F8, "" },
//  { 0x122F9, "" },
//  { 0x122FA, "" },
//  { 0x122FB, "" },
//  { 0x122FC, "" },
//  { 0x122FD, "" },
//  { 0x122FE, "" },
//  { 0x122FF, "" },
//  { 0x12300, "" },
//  { 0x12301, "" },
//  { 0x12302, "" },
//  { 0x12303, "" },
//  { 0x12304, "" },
//  { 0x12305, "" },
//  { 0x12306, "" },
//  { 0x12307, "" },
//  { 0x12308, "" },
//  { 0x12309, "" },
//  { 0x1230A, "" },
//  { 0x1230B, "" },
//  { 0x1230C, "" },
//  { 0x1230D, "" },
//  { 0x1230E, "" },
//  { 0x1230F, "" },
//  { 0x12310, "" },
//  { 0x12311, "" },
//  { 0x12312, "" },
//  { 0x12313, "" },
//  { 0x12314, "" },
//  { 0x12315, "" },
//  { 0x12316, "" },
//  { 0x12317, "" },
//  { 0x12318, "" },
//  { 0x12319, "" },
//  { 0x1231A, "" },
//  { 0x1231B, "" },
//  { 0x1231C, "" },
//  { 0x1231D, "" },
//  { 0x1231E, "" },
//  { 0x1231F, "" },
//  { 0x12320, "" },
//  { 0x12321, "" },
//  { 0x12322, "" },
//  { 0x12323, "" },
//  { 0x12324, "" },
//  { 0x12325, "" },
//  { 0x12326, "" },
//  { 0x12327, "" },
//  { 0x12328, "" },
//  { 0x12329, "" },
//  { 0x1232A, "" },
//  { 0x1232B, "" },
//  { 0x1232C, "" },
//  { 0x1232D, "" },
//  { 0x1232E, "" },
//  { 0x1232F, "" },
//  { 0x12330, "" },
//  { 0x12331, "" },
//  { 0x12332, "" },
//  { 0x12333, "" },
//  { 0x12334, "" },
//  { 0x12335, "" },
//  { 0x12336, "" },
//  { 0x12337, "" },
//  { 0x12338, "" },
//  { 0x12339, "" },
//  { 0x1233A, "" },
//  { 0x1233B, "" },
//  { 0x1233C, "" },
//  { 0x1233D, "" },
//  { 0x1233E, "" },
//  { 0x1233F, "" },
//  { 0x12340, "" },
//  { 0x12341, "" },
//  { 0x12342, "" },
//  { 0x12343, "" },
//  { 0x12344, "" },
//  { 0x12345, "" },
//  { 0x12346, "" },
//  { 0x12347, "" },
//  { 0x12348, "" },
//  { 0x12349, "" },
//  { 0x1234A, "" },
//  { 0x1234B, "" },
//  { 0x1234C, "" },
//  { 0x1234D, "" },
//  { 0x1234E, "" },
//  { 0x1234F, "" },
//  { 0x12350, "" },
//  { 0x12351, "" },
//  { 0x12352, "" },
//  { 0x12353, "" },
//  { 0x12354, "" },
//  { 0x12355, "" },
//  { 0x12356, "" },
//  { 0x12357, "" },
//  { 0x12358, "" },
//  { 0x12359, "" },
//  { 0x1235A, "" },
//  { 0x1235B, "" },
//  { 0x1235C, "" },
//  { 0x1235D, "" },
//  { 0x1235E, "" },
//  { 0x1235F, "" },
//  { 0x12360, "" },
//  { 0x12361, "" },
//  { 0x12362, "" },
//  { 0x12363, "" },
//  { 0x12364, "" },
//  { 0x12365, "" },
//  { 0x12366, "" },
//  { 0x12367, "" },
//  { 0x12368, "" },
//  { 0x12369, "" },
//  { 0x1236A, "" },
//  { 0x1236B, "" },
//  { 0x1236C, "" },
//  { 0x1236D, "" },
//  { 0x1236E, "" },
//  { 0x1236F, "" },
//  { 0x12370, "" },
//  { 0x12371, "" },
//  { 0x12372, "" },
//  { 0x12373, "" },
//  { 0x12374, "" },
//  { 0x12375, "" },
//  { 0x12376, "" },
//  { 0x12377, "" },
//  { 0x12378, "" },
//  { 0x12379, "" },
//  { 0x1237A, "" },
//  { 0x1237B, "" },
//  { 0x1237C, "" },
//  { 0x1237D, "" },
//  { 0x1237E, "" },
//  { 0x1237F, "" },
//  { 0x12380, "" },
//  { 0x12381, "" },
//  { 0x12382, "" },
//  { 0x12383, "" },
//  { 0x12384, "" },
//  { 0x12385, "" },
//  { 0x12386, "" },
//  { 0x12387, "" },
//  { 0x12388, "" },
//  { 0x12389, "" },
//  { 0x1238A, "" },
//  { 0x1238B, "" },
//  { 0x1238C, "" },
//  { 0x1238D, "" },
//  { 0x1238E, "" },
//  { 0x1238F, "" },
//  { 0x12390, "" },
//  { 0x12391, "" },
//  { 0x12392, "" },
//  { 0x12393, "" },
//  { 0x12394, "" },
//  { 0x12395, "" },
//  { 0x12396, "" },
//  { 0x12397, "" },
//  { 0x12398, "" },
//  { 0x12399, "" },
//  { 0x1239A, "" },
//  { 0x1239B, "" },
//  { 0x1239C, "" },
//  { 0x1239D, "" },
//  { 0x1239E, "" },
//  { 0x1239F, "" },
//  { 0x123A0, "" },
//  { 0x123A1, "" },
//  { 0x123A2, "" },
//  { 0x123A3, "" },
//  { 0x123A4, "" },
//  { 0x123A5, "" },
//  { 0x123A6, "" },
//  { 0x123A7, "" },
//  { 0x123A8, "" },
//  { 0x123A9, "" },
//  { 0x123AA, "" },
//  { 0x123AB, "" },
//  { 0x123AC, "" },
//  { 0x123AD, "" },
//  { 0x123AE, "" },
//  { 0x123AF, "" },
//  { 0x123B0, "" },
//  { 0x123B1, "" },
//  { 0x123B2, "" },
//  { 0x123B3, "" },
//  { 0x123B4, "" },
//  { 0x123B5, "" },
//  { 0x123B6, "" },
//  { 0x123B7, "" },
//  { 0x123B8, "" },
//  { 0x123B9, "" },
//  { 0x123BA, "" },
//  { 0x123BB, "" },
//  { 0x123BC, "" },
//  { 0x123BD, "" },
//  { 0x123BE, "" },
//  { 0x123BF, "" },
//  { 0x123C0, "" },
//  { 0x123C1, "" },
//  { 0x123C2, "" },
//  { 0x123C3, "" },
//  { 0x123C4, "" },
//  { 0x123C5, "" },
//  { 0x123C6, "" },
//  { 0x123C7, "" },
//  { 0x123C8, "" },
//  { 0x123C9, "" },
//  { 0x123CA, "" },
//  { 0x123CB, "" },
//  { 0x123CC, "" },
//  { 0x123CD, "" },
//  { 0x123CE, "" },
//  { 0x123CF, "" },
//  { 0x123D0, "" },
//  { 0x123D1, "" },
//  { 0x123D2, "" },
//  { 0x123D3, "" },
//  { 0x123D4, "" },
//  { 0x123D5, "" },
//  { 0x123D6, "" },
//  { 0x123D7, "" },
//  { 0x123D8, "" },
//  { 0x123D9, "" },
//  { 0x123DA, "" },
//  { 0x123DB, "" },
//  { 0x123DC, "" },
//  { 0x123DD, "" },
//  { 0x123DE, "" },
//  { 0x123DF, "" },
//  { 0x123E0, "" },
//  { 0x123E1, "" },
//  { 0x123E2, "" },
//  { 0x123E3, "" },
//  { 0x123E4, "" },
//  { 0x123E5, "" },
//  { 0x123E6, "" },
//  { 0x123E7, "" },
//  { 0x123E8, "" },
//  { 0x123E9, "" },
//  { 0x123EA, "" },
//  { 0x123EB, "" },
//  { 0x123EC, "" },
//  { 0x123ED, "" },
//  { 0x123EE, "" },
//  { 0x123EF, "" },
//  { 0x123F0, "" },
//  { 0x123F1, "" },
//  { 0x123F2, "" },
//  { 0x123F3, "" },
//  { 0x123F4, "" },
//  { 0x123F5, "" },
//  { 0x123F6, "" },
//  { 0x123F7, "" },
//  { 0x123F8, "" },
//  { 0x123F9, "" },
//  { 0x123FA, "" },
//  { 0x123FB, "" },
//  { 0x123FC, "" },
//  { 0x123FD, "" },
//  { 0x123FE, "" },
//  { 0x123FF, "" },
//  { 0x12400, "" },
//  { 0x12401, "" },
//  { 0x12402, "" },
//  { 0x12403, "" },
//  { 0x12404, "" },
//  { 0x12405, "" },
//  { 0x12406, "" },
//  { 0x12407, "" },
//  { 0x12408, "" },
//  { 0x12409, "" },
//  { 0x1240A, "" },
//  { 0x1240B, "" },
//  { 0x1240C, "" },
//  { 0x1240D, "" },
//  { 0x1240E, "" },
//  { 0x1240F, "" },
//  { 0x12410, "" },
//  { 0x12411, "" },
//  { 0x12412, "" },
//  { 0x12413, "" },
//  { 0x12414, "" },
//  { 0x12415, "" },
//  { 0x12416, "" },
//  { 0x12417, "" },
//  { 0x12418, "" },
//  { 0x12419, "" },
//  { 0x1241A, "" },
//  { 0x1241B, "" },
//  { 0x1241C, "" },
//  { 0x1241D, "" },
//  { 0x1241E, "" },
//  { 0x1241F, "" },
//  { 0x12420, "" },
//  { 0x12421, "" },
//  { 0x12422, "" },
//  { 0x12423, "" },
//  { 0x12424, "" },
//  { 0x12425, "" },
//  { 0x12426, "" },
//  { 0x12427, "" },
//  { 0x12428, "" },
//  { 0x12429, "" },
//  { 0x1242A, "" },
//  { 0x1242B, "" },
//  { 0x1242C, "" },
//  { 0x1242D, "" },
//  { 0x1242E, "" },
//  { 0x1242F, "" },
//  { 0x12430, "" },
//  { 0x12431, "" },
//  { 0x12432, "" },
//  { 0x12433, "" },
//  { 0x12434, "" },
//  { 0x12435, "" },
//  { 0x12436, "" },
//  { 0x12437, "" },
//  { 0x12438, "" },
//  { 0x12439, "" },
//  { 0x1243A, "" },
//  { 0x1243B, "" },
//  { 0x1243C, "" },
//  { 0x1243D, "" },
//  { 0x1243E, "" },
//  { 0x1243F, "" },
//  { 0x12440, "" },
//  { 0x12441, "" },
//  { 0x12442, "" },
//  { 0x12443, "" },
//  { 0x12444, "" },
//  { 0x12445, "" },
//  { 0x12446, "" },
//  { 0x12447, "" },
//  { 0x12448, "" },
//  { 0x12449, "" },
//  { 0x1244A, "" },
//  { 0x1244B, "" },
//  { 0x1244C, "" },
//  { 0x1244D, "" },
//  { 0x1244E, "" },
//  { 0x1244F, "" },
//  { 0x12450, "" },
//  { 0x12451, "" },
//  { 0x12452, "" },
//  { 0x12453, "" },
//  { 0x12454, "" },
//  { 0x12455, "" },
//  { 0x12456, "" },
//  { 0x12457, "" },
//  { 0x12458, "" },
//  { 0x12459, "" },
//  { 0x1245A, "" },
//  { 0x1245B, "" },
//  { 0x1245C, "" },
//  { 0x1245D, "" },
//  { 0x1245E, "" },
//  { 0x1245F, "" },
//  { 0x12460, "" },
//  { 0x12461, "" },
//  { 0x12462, "" },
//  { 0x12463, "" },
//  { 0x12464, "" },
//  { 0x12465, "" },
//  { 0x12466, "" },
//  { 0x12467, "" },
//  { 0x12468, "" },
//  { 0x12469, "" },
//  { 0x1246A, "" },
//  { 0x1246B, "" },
//  { 0x1246C, "" },
//  { 0x1246D, "" },
//  { 0x1246E, "" },
//  { 0x1246F, "" },
//  { 0x12470, "" },
//  { 0x12471, "" },
//  { 0x12472, "" },
//  { 0x12473, "" },
//  { 0x12474, "" },
//  { 0x12475, "" },
//  { 0x12476, "" },
//  { 0x12477, "" },
//  { 0x12478, "" },
//  { 0x12479, "" },
//  { 0x1247A, "" },
//  { 0x1247B, "" },
//  { 0x1247C, "" },
//  { 0x1247D, "" },
//  { 0x1247E, "" },
//  { 0x1247F, "" },
//  { 0x12480, "" },
//  { 0x12481, "" },
//  { 0x12482, "" },
//  { 0x12483, "" },
//  { 0x12484, "" },
//  { 0x12485, "" },
//  { 0x12486, "" },
//  { 0x12487, "" },
//  { 0x12488, "" },
//  { 0x12489, "" },
//  { 0x1248A, "" },
//  { 0x1248B, "" },
//  { 0x1248C, "" },
//  { 0x1248D, "" },
//  { 0x1248E, "" },
//  { 0x1248F, "" },
//  { 0x12490, "" },
//  { 0x12491, "" },
//  { 0x12492, "" },
//  { 0x12493, "" },
//  { 0x12494, "" },
//  { 0x12495, "" },
//  { 0x12496, "" },
//  { 0x12497, "" },
//  { 0x12498, "" },
//  { 0x12499, "" },
//  { 0x1249A, "" },
//  { 0x1249B, "" },
//  { 0x1249C, "" },
//  { 0x1249D, "" },
//  { 0x1249E, "" },
//  { 0x1249F, "" },
//  { 0x124A0, "" },
//  { 0x124A1, "" },
//  { 0x124A2, "" },
//  { 0x124A3, "" },
//  { 0x124A4, "" },
//  { 0x124A5, "" },
//  { 0x124A6, "" },
//  { 0x124A7, "" },
//  { 0x124A8, "" },
//  { 0x124A9, "" },
//  { 0x124AA, "" },
//  { 0x124AB, "" },
//  { 0x124AC, "" },
//  { 0x124AD, "" },
//  { 0x124AE, "" },
//  { 0x124AF, "" },
//  { 0x124B0, "" },
//  { 0x124B1, "" },
//  { 0x124B2, "" },
//  { 0x124B3, "" },
//  { 0x124B4, "" },
//  { 0x124B5, "" },
//  { 0x124B6, "" },
//  { 0x124B7, "" },
//  { 0x124B8, "" },
//  { 0x124B9, "" },
//  { 0x124BA, "" },
//  { 0x124BB, "" },
//  { 0x124BC, "" },
//  { 0x124BD, "" },
//  { 0x124BE, "" },
//  { 0x124BF, "" },
//  { 0x124C0, "" },
//  { 0x124C1, "" },
//  { 0x124C2, "" },
//  { 0x124C3, "" },
//  { 0x124C4, "" },
//  { 0x124C5, "" },
//  { 0x124C6, "" },
//  { 0x124C7, "" },
//  { 0x124C8, "" },
//  { 0x124C9, "" },
//  { 0x124CA, "" },
//  { 0x124CB, "" },
//  { 0x124CC, "" },
//  { 0x124CD, "" },
//  { 0x124CE, "" },
//  { 0x124CF, "" },
//  { 0x124D0, "" },
//  { 0x124D1, "" },
//  { 0x124D2, "" },
//  { 0x124D3, "" },
//  { 0x124D4, "" },
//  { 0x124D5, "" },
//  { 0x124D6, "" },
//  { 0x124D7, "" },
//  { 0x124D8, "" },
//  { 0x124D9, "" },
//  { 0x124DA, "" },
//  { 0x124DB, "" },
//  { 0x124DC, "" },
//  { 0x124DD, "" },
//  { 0x124DE, "" },
//  { 0x124DF, "" },
//  { 0x124E0, "" },
//  { 0x124E1, "" },
//  { 0x124E2, "" },
//  { 0x124E3, "" },
//  { 0x124E4, "" },
//  { 0x124E5, "" },
//  { 0x124E6, "" },
//  { 0x124E7, "" },
//  { 0x124E8, "" },
//  { 0x124E9, "" },
//  { 0x124EA, "" },
//  { 0x124EB, "" },
//  { 0x124EC, "" },
//  { 0x124ED, "" },
//  { 0x124EE, "" },
//  { 0x124EF, "" },
//  { 0x124F0, "" },
//  { 0x124F1, "" },
//  { 0x124F2, "" },
//  { 0x124F3, "" },
//  { 0x124F4, "" },
//  { 0x124F5, "" },
//  { 0x124F6, "" },
//  { 0x124F7, "" },
//  { 0x124F8, "" },
//  { 0x124F9, "" },
//  { 0x124FA, "" },
//  { 0x124FB, "" },
//  { 0x124FC, "" },
//  { 0x124FD, "" },
//  { 0x124FE, "" },
//  { 0x124FF, "" },
//  { 0x12500, "" },
//  { 0x12501, "" },
//  { 0x12502, "" },
//  { 0x12503, "" },
//  { 0x12504, "" },
//  { 0x12505, "" },
//  { 0x12506, "" },
//  { 0x12507, "" },
//  { 0x12508, "" },
//  { 0x12509, "" },
//  { 0x1250A, "" },
//  { 0x1250B, "" },
//  { 0x1250C, "" },
//  { 0x1250D, "" },
//  { 0x1250E, "" },
//  { 0x1250F, "" },
//  { 0x12510, "" },
//  { 0x12511, "" },
//  { 0x12512, "" },
//  { 0x12513, "" },
//  { 0x12514, "" },
//  { 0x12515, "" },
//  { 0x12516, "" },
//  { 0x12517, "" },
//  { 0x12518, "" },
//  { 0x12519, "" },
//  { 0x1251A, "" },
//  { 0x1251B, "" },
//  { 0x1251C, "" },
//  { 0x1251D, "" },
//  { 0x1251E, "" },
//  { 0x1251F, "" },
//  { 0x12520, "" },
//  { 0x12521, "" },
//  { 0x12522, "" },
//  { 0x12523, "" },
//  { 0x12524, "" },
//  { 0x12525, "" },
//  { 0x12526, "" },
//  { 0x12527, "" },
//  { 0x12528, "" },
//  { 0x12529, "" },
//  { 0x1252A, "" },
//  { 0x1252B, "" },
//  { 0x1252C, "" },
//  { 0x1252D, "" },
//  { 0x1252E, "" },
//  { 0x1252F, "" },
//  { 0x12530, "" },
//  { 0x12531, "" },
//  { 0x12532, "" },
//  { 0x12533, "" },
//  { 0x12534, "" },
//  { 0x12535, "" },
//  { 0x12536, "" },
//  { 0x12537, "" },
//  { 0x12538, "" },
//  { 0x12539, "" },
//  { 0x1253A, "" },
//  { 0x1253B, "" },
//  { 0x1253C, "" },
//  { 0x1253D, "" },
//  { 0x1253E, "" },
//  { 0x1253F, "" },
//  { 0x12540, "" },
//  { 0x12541, "" },
//  { 0x12542, "" },
//  { 0x12543, "" },
//  { 0x12544, "" },
//  { 0x12545, "" },
//  { 0x12546, "" },
//  { 0x12547, "" },
//  { 0x12548, "" },
//  { 0x12549, "" },
//  { 0x1254A, "" },
//  { 0x1254B, "" },
//  { 0x1254C, "" },
//  { 0x1254D, "" },
//  { 0x1254E, "" },
//  { 0x1254F, "" },
//  { 0x12550, "" },
//  { 0x12551, "" },
//  { 0x12552, "" },
//  { 0x12553, "" },
//  { 0x12554, "" },
//  { 0x12555, "" },
//  { 0x12556, "" },
//  { 0x12557, "" },
//  { 0x12558, "" },
//  { 0x12559, "" },
//  { 0x1255A, "" },
//  { 0x1255B, "" },
//  { 0x1255C, "" },
//  { 0x1255D, "" },
//  { 0x1255E, "" },
//  { 0x1255F, "" },
//  { 0x12560, "" },
//  { 0x12561, "" },
//  { 0x12562, "" },
//  { 0x12563, "" },
//  { 0x12564, "" },
//  { 0x12565, "" },
//  { 0x12566, "" },
//  { 0x12567, "" },
//  { 0x12568, "" },
//  { 0x12569, "" },
//  { 0x1256A, "" },
//  { 0x1256B, "" },
//  { 0x1256C, "" },
//  { 0x1256D, "" },
//  { 0x1256E, "" },
//  { 0x1256F, "" },
//  { 0x12570, "" },
//  { 0x12571, "" },
//  { 0x12572, "" },
//  { 0x12573, "" },
//  { 0x12574, "" },
//  { 0x12575, "" },
//  { 0x12576, "" },
//  { 0x12577, "" },
//  { 0x12578, "" },
//  { 0x12579, "" },
//  { 0x1257A, "" },
//  { 0x1257B, "" },
//  { 0x1257C, "" },
//  { 0x1257D, "" },
//  { 0x1257E, "" },
//  { 0x1257F, "" },
//  { 0x12580, "" },
//  { 0x12581, "" },
//  { 0x12582, "" },
//  { 0x12583, "" },
//  { 0x12584, "" },
//  { 0x12585, "" },
//  { 0x12586, "" },
//  { 0x12587, "" },
//  { 0x12588, "" },
//  { 0x12589, "" },
//  { 0x1258A, "" },
//  { 0x1258B, "" },
//  { 0x1258C, "" },
//  { 0x1258D, "" },
//  { 0x1258E, "" },
//  { 0x1258F, "" },
//  { 0x12590, "" },
//  { 0x12591, "" },
//  { 0x12592, "" },
//  { 0x12593, "" },
//  { 0x12594, "" },
//  { 0x12595, "" },
//  { 0x12596, "" },
//  { 0x12597, "" },
//  { 0x12598, "" },
//  { 0x12599, "" },
//  { 0x1259A, "" },
//  { 0x1259B, "" },
//  { 0x1259C, "" },
//  { 0x1259D, "" },
//  { 0x1259E, "" },
//  { 0x1259F, "" },
//  { 0x125A0, "" },
//  { 0x125A1, "" },
//  { 0x125A2, "" },
//  { 0x125A3, "" },
//  { 0x125A4, "" },
//  { 0x125A5, "" },
//  { 0x125A6, "" },
//  { 0x125A7, "" },
//  { 0x125A8, "" },
//  { 0x125A9, "" },
//  { 0x125AA, "" },
//  { 0x125AB, "" },
//  { 0x125AC, "" },
//  { 0x125AD, "" },
//  { 0x125AE, "" },
//  { 0x125AF, "" },
//  { 0x125B0, "" },
//  { 0x125B1, "" },
//  { 0x125B2, "" },
//  { 0x125B3, "" },
//  { 0x125B4, "" },
//  { 0x125B5, "" },
//  { 0x125B6, "" },
//  { 0x125B7, "" },
//  { 0x125B8, "" },
//  { 0x125B9, "" },
//  { 0x125BA, "" },
//  { 0x125BB, "" },
//  { 0x125BC, "" },
//  { 0x125BD, "" },
//  { 0x125BE, "" },
//  { 0x125BF, "" },
//  { 0x125C0, "" },
//  { 0x125C1, "" },
//  { 0x125C2, "" },
//  { 0x125C3, "" },
//  { 0x125C4, "" },
//  { 0x125C5, "" },
//  { 0x125C6, "" },
//  { 0x125C7, "" },
//  { 0x125C8, "" },
//  { 0x125C9, "" },
//  { 0x125CA, "" },
//  { 0x125CB, "" },
//  { 0x125CC, "" },
//  { 0x125CD, "" },
//  { 0x125CE, "" },
//  { 0x125CF, "" },
//  { 0x125D0, "" },
//  { 0x125D1, "" },
//  { 0x125D2, "" },
//  { 0x125D3, "" },
//  { 0x125D4, "" },
//  { 0x125D5, "" },
//  { 0x125D6, "" },
//  { 0x125D7, "" },
//  { 0x125D8, "" },
//  { 0x125D9, "" },
//  { 0x125DA, "" },
//  { 0x125DB, "" },
//  { 0x125DC, "" },
//  { 0x125DD, "" },
//  { 0x125DE, "" },
//  { 0x125DF, "" },
//  { 0x125E0, "" },
//  { 0x125E1, "" },
//  { 0x125E2, "" },
//  { 0x125E3, "" },
//  { 0x125E4, "" },
//  { 0x125E5, "" },
//  { 0x125E6, "" },
//  { 0x125E7, "" },
//  { 0x125E8, "" },
//  { 0x125E9, "" },
//  { 0x125EA, "" },
//  { 0x125EB, "" },
//  { 0x125EC, "" },
//  { 0x125ED, "" },
//  { 0x125EE, "" },
//  { 0x125EF, "" },
//  { 0x125F0, "" },
//  { 0x125F1, "" },
//  { 0x125F2, "" },
//  { 0x125F3, "" },
//  { 0x125F4, "" },
//  { 0x125F5, "" },
//  { 0x125F6, "" },
//  { 0x125F7, "" },
//  { 0x125F8, "" },
//  { 0x125F9, "" },
//  { 0x125FA, "" },
//  { 0x125FB, "" },
//  { 0x125FC, "" },
//  { 0x125FD, "" },
//  { 0x125FE, "" },
//  { 0x125FF, "" },
//  { 0x12600, "" },
//  { 0x12601, "" },
//  { 0x12602, "" },
//  { 0x12603, "" },
//  { 0x12604, "" },
//  { 0x12605, "" },
//  { 0x12606, "" },
//  { 0x12607, "" },
//  { 0x12608, "" },
//  { 0x12609, "" },
//  { 0x1260A, "" },
//  { 0x1260B, "" },
//  { 0x1260C, "" },
//  { 0x1260D, "" },
//  { 0x1260E, "" },
//  { 0x1260F, "" },
//  { 0x12610, "" },
//  { 0x12611, "" },
//  { 0x12612, "" },
//  { 0x12613, "" },
//  { 0x12614, "" },
//  { 0x12615, "" },
//  { 0x12616, "" },
//  { 0x12617, "" },
//  { 0x12618, "" },
//  { 0x12619, "" },
//  { 0x1261A, "" },
//  { 0x1261B, "" },
//  { 0x1261C, "" },
//  { 0x1261D, "" },
//  { 0x1261E, "" },
//  { 0x1261F, "" },
//  { 0x12620, "" },
//  { 0x12621, "" },
//  { 0x12622, "" },
//  { 0x12623, "" },
//  { 0x12624, "" },
//  { 0x12625, "" },
//  { 0x12626, "" },
//  { 0x12627, "" },
//  { 0x12628, "" },
//  { 0x12629, "" },
//  { 0x1262A, "" },
//  { 0x1262B, "" },
//  { 0x1262C, "" },
//  { 0x1262D, "" },
//  { 0x1262E, "" },
//  { 0x1262F, "" },
//  { 0x12630, "" },
//  { 0x12631, "" },
//  { 0x12632, "" },
//  { 0x12633, "" },
//  { 0x12634, "" },
//  { 0x12635, "" },
//  { 0x12636, "" },
//  { 0x12637, "" },
//  { 0x12638, "" },
//  { 0x12639, "" },
//  { 0x1263A, "" },
//  { 0x1263B, "" },
//  { 0x1263C, "" },
//  { 0x1263D, "" },
//  { 0x1263E, "" },
//  { 0x1263F, "" },
//  { 0x12640, "" },
//  { 0x12641, "" },
//  { 0x12642, "" },
//  { 0x12643, "" },
//  { 0x12644, "" },
//  { 0x12645, "" },
//  { 0x12646, "" },
//  { 0x12647, "" },
//  { 0x12648, "" },
//  { 0x12649, "" },
//  { 0x1264A, "" },
//  { 0x1264B, "" },
//  { 0x1264C, "" },
//  { 0x1264D, "" },
//  { 0x1264E, "" },
//  { 0x1264F, "" },
//  { 0x12650, "" },
//  { 0x12651, "" },
//  { 0x12652, "" },
//  { 0x12653, "" },
//  { 0x12654, "" },
//  { 0x12655, "" },
//  { 0x12656, "" },
//  { 0x12657, "" },
//  { 0x12658, "" },
//  { 0x12659, "" },
//  { 0x1265A, "" },
//  { 0x1265B, "" },
//  { 0x1265C, "" },
//  { 0x1265D, "" },
//  { 0x1265E, "" },
//  { 0x1265F, "" },
//  { 0x12660, "" },
//  { 0x12661, "" },
//  { 0x12662, "" },
//  { 0x12663, "" },
//  { 0x12664, "" },
//  { 0x12665, "" },
//  { 0x12666, "" },
//  { 0x12667, "" },
//  { 0x12668, "" },
//  { 0x12669, "" },
//  { 0x1266A, "" },
//  { 0x1266B, "" },
//  { 0x1266C, "" },
//  { 0x1266D, "" },
//  { 0x1266E, "" },
//  { 0x1266F, "" },
//  { 0x12670, "" },
//  { 0x12671, "" },
//  { 0x12672, "" },
//  { 0x12673, "" },
//  { 0x12674, "" },
//  { 0x12675, "" },
//  { 0x12676, "" },
//  { 0x12677, "" },
//  { 0x12678, "" },
//  { 0x12679, "" },
//  { 0x1267A, "" },
//  { 0x1267B, "" },
//  { 0x1267C, "" },
//  { 0x1267D, "" },
//  { 0x1267E, "" },
//  { 0x1267F, "" },
//  { 0x12680, "" },
//  { 0x12681, "" },
//  { 0x12682, "" },
//  { 0x12683, "" },
//  { 0x12684, "" },
//  { 0x12685, "" },
//  { 0x12686, "" },
//  { 0x12687, "" },
//  { 0x12688, "" },
//  { 0x12689, "" },
//  { 0x1268A, "" },
//  { 0x1268B, "" },
//  { 0x1268C, "" },
//  { 0x1268D, "" },
//  { 0x1268E, "" },
//  { 0x1268F, "" },
//  { 0x12690, "" },
//  { 0x12691, "" },
//  { 0x12692, "" },
//  { 0x12693, "" },
//  { 0x12694, "" },
//  { 0x12695, "" },
//  { 0x12696, "" },
//  { 0x12697, "" },
//  { 0x12698, "" },
//  { 0x12699, "" },
//  { 0x1269A, "" },
//  { 0x1269B, "" },
//  { 0x1269C, "" },
//  { 0x1269D, "" },
//  { 0x1269E, "" },
//  { 0x1269F, "" },
//  { 0x126A0, "" },
//  { 0x126A1, "" },
//  { 0x126A2, "" },
//  { 0x126A3, "" },
//  { 0x126A4, "" },
//  { 0x126A5, "" },
//  { 0x126A6, "" },
//  { 0x126A7, "" },
//  { 0x126A8, "" },
//  { 0x126A9, "" },
//  { 0x126AA, "" },
//  { 0x126AB, "" },
//  { 0x126AC, "" },
//  { 0x126AD, "" },
//  { 0x126AE, "" },
//  { 0x126AF, "" },
//  { 0x126B0, "" },
//  { 0x126B1, "" },
//  { 0x126B2, "" },
//  { 0x126B3, "" },
//  { 0x126B4, "" },
//  { 0x126B5, "" },
//  { 0x126B6, "" },
//  { 0x126B7, "" },
//  { 0x126B8, "" },
//  { 0x126B9, "" },
//  { 0x126BA, "" },
//  { 0x126BB, "" },
//  { 0x126BC, "" },
//  { 0x126BD, "" },
//  { 0x126BE, "" },
//  { 0x126BF, "" },
//  { 0x126C0, "" },
//  { 0x126C1, "" },
//  { 0x126C2, "" },
//  { 0x126C3, "" },
//  { 0x126C4, "" },
//  { 0x126C5, "" },
//  { 0x126C6, "" },
//  { 0x126C7, "" },
//  { 0x126C8, "" },
//  { 0x126C9, "" },
//  { 0x126CA, "" },
//  { 0x126CB, "" },
//  { 0x126CC, "" },
//  { 0x126CD, "" },
//  { 0x126CE, "" },
//  { 0x126CF, "" },
//  { 0x126D0, "" },
//  { 0x126D1, "" },
//  { 0x126D2, "" },
//  { 0x126D3, "" },
//  { 0x126D4, "" },
//  { 0x126D5, "" },
//  { 0x126D6, "" },
//  { 0x126D7, "" },
//  { 0x126D8, "" },
//  { 0x126D9, "" },
//  { 0x126DA, "" },
//  { 0x126DB, "" },
//  { 0x126DC, "" },
//  { 0x126DD, "" },
//  { 0x126DE, "" },
//  { 0x126DF, "" },
//  { 0x126E0, "" },
//  { 0x126E1, "" },
//  { 0x126E2, "" },
//  { 0x126E3, "" },
//  { 0x126E4, "" },
//  { 0x126E5, "" },
//  { 0x126E6, "" },
//  { 0x126E7, "" },
//  { 0x126E8, "" },
//  { 0x126E9, "" },
//  { 0x126EA, "" },
//  { 0x126EB, "" },
//  { 0x126EC, "" },
//  { 0x126ED, "" },
//  { 0x126EE, "" },
//  { 0x126EF, "" },
//  { 0x126F0, "" },
//  { 0x126F1, "" },
//  { 0x126F2, "" },
//  { 0x126F3, "" },
//  { 0x126F4, "" },
//  { 0x126F5, "" },
//  { 0x126F6, "" },
//  { 0x126F7, "" },
//  { 0x126F8, "" },
//  { 0x126F9, "" },
//  { 0x126FA, "" },
//  { 0x126FB, "" },
//  { 0x126FC, "" },
//  { 0x126FD, "" },
//  { 0x126FE, "" },
//  { 0x126FF, "" },
//  { 0x12700, "" },
//  { 0x12701, "" },
//  { 0x12702, "" },
//  { 0x12703, "" },
//  { 0x12704, "" },
//  { 0x12705, "" },
//  { 0x12706, "" },
//  { 0x12707, "" },
//  { 0x12708, "" },
//  { 0x12709, "" },
//  { 0x1270A, "" },
//  { 0x1270B, "" },
//  { 0x1270C, "" },
//  { 0x1270D, "" },
//  { 0x1270E, "" },
//  { 0x1270F, "" },
//  { 0x12710, "" },
//  { 0x12711, "" },
//  { 0x12712, "" },
//  { 0x12713, "" },
//  { 0x12714, "" },
//  { 0x12715, "" },
//  { 0x12716, "" },
//  { 0x12717, "" },
//  { 0x12718, "" },
//  { 0x12719, "" },
//  { 0x1271A, "" },
//  { 0x1271B, "" },
//  { 0x1271C, "" },
//  { 0x1271D, "" },
//  { 0x1271E, "" },
//  { 0x1271F, "" },
//  { 0x12720, "" },
//  { 0x12721, "" },
//  { 0x12722, "" },
//  { 0x12723, "" },
//  { 0x12724, "" },
//  { 0x12725, "" },
//  { 0x12726, "" },
//  { 0x12727, "" },
//  { 0x12728, "" },
//  { 0x12729, "" },
//  { 0x1272A, "" },
//  { 0x1272B, "" },
//  { 0x1272C, "" },
//  { 0x1272D, "" },
//  { 0x1272E, "" },
//  { 0x1272F, "" },
//  { 0x12730, "" },
//  { 0x12731, "" },
//  { 0x12732, "" },
//  { 0x12733, "" },
//  { 0x12734, "" },
//  { 0x12735, "" },
//  { 0x12736, "" },
//  { 0x12737, "" },
//  { 0x12738, "" },
//  { 0x12739, "" },
//  { 0x1273A, "" },
//  { 0x1273B, "" },
//  { 0x1273C, "" },
//  { 0x1273D, "" },
//  { 0x1273E, "" },
//  { 0x1273F, "" },
//  { 0x12740, "" },
//  { 0x12741, "" },
//  { 0x12742, "" },
//  { 0x12743, "" },
//  { 0x12744, "" },
//  { 0x12745, "" },
//  { 0x12746, "" },
//  { 0x12747, "" },
//  { 0x12748, "" },
//  { 0x12749, "" },
//  { 0x1274A, "" },
//  { 0x1274B, "" },
//  { 0x1274C, "" },
//  { 0x1274D, "" },
//  { 0x1274E, "" },
//  { 0x1274F, "" },
//  { 0x12750, "" },
//  { 0x12751, "" },
//  { 0x12752, "" },
//  { 0x12753, "" },
//  { 0x12754, "" },
//  { 0x12755, "" },
//  { 0x12756, "" },
//  { 0x12757, "" },
//  { 0x12758, "" },
//  { 0x12759, "" },
//  { 0x1275A, "" },
//  { 0x1275B, "" },
//  { 0x1275C, "" },
//  { 0x1275D, "" },
//  { 0x1275E, "" },
//  { 0x1275F, "" },
//  { 0x12760, "" },
//  { 0x12761, "" },
//  { 0x12762, "" },
//  { 0x12763, "" },
//  { 0x12764, "" },
//  { 0x12765, "" },
//  { 0x12766, "" },
//  { 0x12767, "" },
//  { 0x12768, "" },
//  { 0x12769, "" },
//  { 0x1276A, "" },
//  { 0x1276B, "" },
//  { 0x1276C, "" },
//  { 0x1276D, "" },
//  { 0x1276E, "" },
//  { 0x1276F, "" },
//  { 0x12770, "" },
//  { 0x12771, "" },
//  { 0x12772, "" },
//  { 0x12773, "" },
//  { 0x12774, "" },
//  { 0x12775, "" },
//  { 0x12776, "" },
//  { 0x12777, "" },
//  { 0x12778, "" },
//  { 0x12779, "" },
//  { 0x1277A, "" },
//  { 0x1277B, "" },
//  { 0x1277C, "" },
//  { 0x1277D, "" },
//  { 0x1277E, "" },
//  { 0x1277F, "" },
//  { 0x12780, "" },
//  { 0x12781, "" },
//  { 0x12782, "" },
//  { 0x12783, "" },
//  { 0x12784, "" },
//  { 0x12785, "" },
//  { 0x12786, "" },
//  { 0x12787, "" },
//  { 0x12788, "" },
//  { 0x12789, "" },
//  { 0x1278A, "" },
//  { 0x1278B, "" },
//  { 0x1278C, "" },
//  { 0x1278D, "" },
//  { 0x1278E, "" },
//  { 0x1278F, "" },
//  { 0x12790, "" },
//  { 0x12791, "" },
//  { 0x12792, "" },
//  { 0x12793, "" },
//  { 0x12794, "" },
//  { 0x12795, "" },
//  { 0x12796, "" },
//  { 0x12797, "" },
//  { 0x12798, "" },
//  { 0x12799, "" },
//  { 0x1279A, "" },
//  { 0x1279B, "" },
//  { 0x1279C, "" },
//  { 0x1279D, "" },
//  { 0x1279E, "" },
//  { 0x1279F, "" },
//  { 0x127A0, "" },
//  { 0x127A1, "" },
//  { 0x127A2, "" },
//  { 0x127A3, "" },
//  { 0x127A4, "" },
//  { 0x127A5, "" },
//  { 0x127A6, "" },
//  { 0x127A7, "" },
//  { 0x127A8, "" },
//  { 0x127A9, "" },
//  { 0x127AA, "" },
//  { 0x127AB, "" },
//  { 0x127AC, "" },
//  { 0x127AD, "" },
//  { 0x127AE, "" },
//  { 0x127AF, "" },
//  { 0x127B0, "" },
//  { 0x127B1, "" },
//  { 0x127B2, "" },
//  { 0x127B3, "" },
//  { 0x127B4, "" },
//  { 0x127B5, "" },
//  { 0x127B6, "" },
//  { 0x127B7, "" },
//  { 0x127B8, "" },
//  { 0x127B9, "" },
//  { 0x127BA, "" },
//  { 0x127BB, "" },
//  { 0x127BC, "" },
//  { 0x127BD, "" },
//  { 0x127BE, "" },
//  { 0x127BF, "" },
//  { 0x127C0, "" },
//  { 0x127C1, "" },
//  { 0x127C2, "" },
//  { 0x127C3, "" },
//  { 0x127C4, "" },
//  { 0x127C5, "" },
//  { 0x127C6, "" },
//  { 0x127C7, "" },
//  { 0x127C8, "" },
//  { 0x127C9, "" },
//  { 0x127CA, "" },
//  { 0x127CB, "" },
//  { 0x127CC, "" },
//  { 0x127CD, "" },
//  { 0x127CE, "" },
//  { 0x127CF, "" },
//  { 0x127D0, "" },
//  { 0x127D1, "" },
//  { 0x127D2, "" },
//  { 0x127D3, "" },
//  { 0x127D4, "" },
//  { 0x127D5, "" },
//  { 0x127D6, "" },
//  { 0x127D7, "" },
//  { 0x127D8, "" },
//  { 0x127D9, "" },
//  { 0x127DA, "" },
//  { 0x127DB, "" },
//  { 0x127DC, "" },
//  { 0x127DD, "" },
//  { 0x127DE, "" },
//  { 0x127DF, "" },
//  { 0x127E0, "" },
//  { 0x127E1, "" },
//  { 0x127E2, "" },
//  { 0x127E3, "" },
//  { 0x127E4, "" },
//  { 0x127E5, "" },
//  { 0x127E6, "" },
//  { 0x127E7, "" },
//  { 0x127E8, "" },
//  { 0x127E9, "" },
//  { 0x127EA, "" },
//  { 0x127EB, "" },
//  { 0x127EC, "" },
//  { 0x127ED, "" },
//  { 0x127EE, "" },
//  { 0x127EF, "" },
//  { 0x127F0, "" },
//  { 0x127F1, "" },
//  { 0x127F2, "" },
//  { 0x127F3, "" },
//  { 0x127F4, "" },
//  { 0x127F5, "" },
//  { 0x127F6, "" },
//  { 0x127F7, "" },
//  { 0x127F8, "" },
//  { 0x127F9, "" },
//  { 0x127FA, "" },
//  { 0x127FB, "" },
//  { 0x127FC, "" },
//  { 0x127FD, "" },
//  { 0x127FE, "" },
//  { 0x127FF, "" },
//  { 0x12800, "" },
//  { 0x12801, "" },
//  { 0x12802, "" },
//  { 0x12803, "" },
//  { 0x12804, "" },
//  { 0x12805, "" },
//  { 0x12806, "" },
//  { 0x12807, "" },
//  { 0x12808, "" },
//  { 0x12809, "" },
//  { 0x1280A, "" },
//  { 0x1280B, "" },
//  { 0x1280C, "" },
//  { 0x1280D, "" },
//  { 0x1280E, "" },
//  { 0x1280F, "" },
//  { 0x12810, "" },
//  { 0x12811, "" },
//  { 0x12812, "" },
//  { 0x12813, "" },
//  { 0x12814, "" },
//  { 0x12815, "" },
//  { 0x12816, "" },
//  { 0x12817, "" },
//  { 0x12818, "" },
//  { 0x12819, "" },
//  { 0x1281A, "" },
//  { 0x1281B, "" },
//  { 0x1281C, "" },
//  { 0x1281D, "" },
//  { 0x1281E, "" },
//  { 0x1281F, "" },
//  { 0x12820, "" },
//  { 0x12821, "" },
//  { 0x12822, "" },
//  { 0x12823, "" },
//  { 0x12824, "" },
//  { 0x12825, "" },
//  { 0x12826, "" },
//  { 0x12827, "" },
//  { 0x12828, "" },
//  { 0x12829, "" },
//  { 0x1282A, "" },
//  { 0x1282B, "" },
//  { 0x1282C, "" },
//  { 0x1282D, "" },
//  { 0x1282E, "" },
//  { 0x1282F, "" },
//  { 0x12830, "" },
//  { 0x12831, "" },
//  { 0x12832, "" },
//  { 0x12833, "" },
//  { 0x12834, "" },
//  { 0x12835, "" },
//  { 0x12836, "" },
//  { 0x12837, "" },
//  { 0x12838, "" },
//  { 0x12839, "" },
//  { 0x1283A, "" },
//  { 0x1283B, "" },
//  { 0x1283C, "" },
//  { 0x1283D, "" },
//  { 0x1283E, "" },
//  { 0x1283F, "" },
//  { 0x12840, "" },
//  { 0x12841, "" },
//  { 0x12842, "" },
//  { 0x12843, "" },
//  { 0x12844, "" },
//  { 0x12845, "" },
//  { 0x12846, "" },
//  { 0x12847, "" },
//  { 0x12848, "" },
//  { 0x12849, "" },
//  { 0x1284A, "" },
//  { 0x1284B, "" },
//  { 0x1284C, "" },
//  { 0x1284D, "" },
//  { 0x1284E, "" },
//  { 0x1284F, "" },
//  { 0x12850, "" },
//  { 0x12851, "" },
//  { 0x12852, "" },
//  { 0x12853, "" },
//  { 0x12854, "" },
//  { 0x12855, "" },
//  { 0x12856, "" },
//  { 0x12857, "" },
//  { 0x12858, "" },
//  { 0x12859, "" },
//  { 0x1285A, "" },
//  { 0x1285B, "" },
//  { 0x1285C, "" },
//  { 0x1285D, "" },
//  { 0x1285E, "" },
//  { 0x1285F, "" },
//  { 0x12860, "" },
//  { 0x12861, "" },
//  { 0x12862, "" },
//  { 0x12863, "" },
//  { 0x12864, "" },
//  { 0x12865, "" },
//  { 0x12866, "" },
//  { 0x12867, "" },
//  { 0x12868, "" },
//  { 0x12869, "" },
//  { 0x1286A, "" },
//  { 0x1286B, "" },
//  { 0x1286C, "" },
//  { 0x1286D, "" },
//  { 0x1286E, "" },
//  { 0x1286F, "" },
//  { 0x12870, "" },
//  { 0x12871, "" },
//  { 0x12872, "" },
//  { 0x12873, "" },
//  { 0x12874, "" },
//  { 0x12875, "" },
//  { 0x12876, "" },
//  { 0x12877, "" },
//  { 0x12878, "" },
//  { 0x12879, "" },
//  { 0x1287A, "" },
//  { 0x1287B, "" },
//  { 0x1287C, "" },
//  { 0x1287D, "" },
//  { 0x1287E, "" },
//  { 0x1287F, "" },
//  { 0x12880, "" },
//  { 0x12881, "" },
//  { 0x12882, "" },
//  { 0x12883, "" },
//  { 0x12884, "" },
//  { 0x12885, "" },
//  { 0x12886, "" },
//  { 0x12887, "" },
//  { 0x12888, "" },
//  { 0x12889, "" },
//  { 0x1288A, "" },
//  { 0x1288B, "" },
//  { 0x1288C, "" },
//  { 0x1288D, "" },
//  { 0x1288E, "" },
//  { 0x1288F, "" },
//  { 0x12890, "" },
//  { 0x12891, "" },
//  { 0x12892, "" },
//  { 0x12893, "" },
//  { 0x12894, "" },
//  { 0x12895, "" },
//  { 0x12896, "" },
//  { 0x12897, "" },
//  { 0x12898, "" },
//  { 0x12899, "" },
//  { 0x1289A, "" },
//  { 0x1289B, "" },
//  { 0x1289C, "" },
//  { 0x1289D, "" },
//  { 0x1289E, "" },
//  { 0x1289F, "" },
//  { 0x128A0, "" },
//  { 0x128A1, "" },
//  { 0x128A2, "" },
//  { 0x128A3, "" },
//  { 0x128A4, "" },
//  { 0x128A5, "" },
//  { 0x128A6, "" },
//  { 0x128A7, "" },
//  { 0x128A8, "" },
//  { 0x128A9, "" },
//  { 0x128AA, "" },
//  { 0x128AB, "" },
//  { 0x128AC, "" },
//  { 0x128AD, "" },
//  { 0x128AE, "" },
//  { 0x128AF, "" },
//  { 0x128B0, "" },
//  { 0x128B1, "" },
//  { 0x128B2, "" },
//  { 0x128B3, "" },
//  { 0x128B4, "" },
//  { 0x128B5, "" },
//  { 0x128B6, "" },
//  { 0x128B7, "" },
//  { 0x128B8, "" },
//  { 0x128B9, "" },
//  { 0x128BA, "" },
//  { 0x128BB, "" },
//  { 0x128BC, "" },
//  { 0x128BD, "" },
//  { 0x128BE, "" },
//  { 0x128BF, "" },
//  { 0x128C0, "" },
//  { 0x128C1, "" },
//  { 0x128C2, "" },
//  { 0x128C3, "" },
//  { 0x128C4, "" },
//  { 0x128C5, "" },
//  { 0x128C6, "" },
//  { 0x128C7, "" },
//  { 0x128C8, "" },
//  { 0x128C9, "" },
//  { 0x128CA, "" },
//  { 0x128CB, "" },
//  { 0x128CC, "" },
//  { 0x128CD, "" },
//  { 0x128CE, "" },
//  { 0x128CF, "" },
//  { 0x128D0, "" },
//  { 0x128D1, "" },
//  { 0x128D2, "" },
//  { 0x128D3, "" },
//  { 0x128D4, "" },
//  { 0x128D5, "" },
//  { 0x128D6, "" },
//  { 0x128D7, "" },
//  { 0x128D8, "" },
//  { 0x128D9, "" },
//  { 0x128DA, "" },
//  { 0x128DB, "" },
//  { 0x128DC, "" },
//  { 0x128DD, "" },
//  { 0x128DE, "" },
//  { 0x128DF, "" },
//  { 0x128E0, "" },
//  { 0x128E1, "" },
//  { 0x128E2, "" },
//  { 0x128E3, "" },
//  { 0x128E4, "" },
//  { 0x128E5, "" },
//  { 0x128E6, "" },
//  { 0x128E7, "" },
//  { 0x128E8, "" },
//  { 0x128E9, "" },
//  { 0x128EA, "" },
//  { 0x128EB, "" },
//  { 0x128EC, "" },
//  { 0x128ED, "" },
//  { 0x128EE, "" },
//  { 0x128EF, "" },
//  { 0x128F0, "" },
//  { 0x128F1, "" },
//  { 0x128F2, "" },
//  { 0x128F3, "" },
//  { 0x128F4, "" },
//  { 0x128F5, "" },
//  { 0x128F6, "" },
//  { 0x128F7, "" },
//  { 0x128F8, "" },
//  { 0x128F9, "" },
//  { 0x128FA, "" },
//  { 0x128FB, "" },
//  { 0x128FC, "" },
//  { 0x128FD, "" },
//  { 0x128FE, "" },
//  { 0x128FF, "" },
//  { 0x12900, "" },
//  { 0x12901, "" },
//  { 0x12902, "" },
//  { 0x12903, "" },
//  { 0x12904, "" },
//  { 0x12905, "" },
//  { 0x12906, "" },
//  { 0x12907, "" },
//  { 0x12908, "" },
//  { 0x12909, "" },
//  { 0x1290A, "" },
//  { 0x1290B, "" },
//  { 0x1290C, "" },
//  { 0x1290D, "" },
//  { 0x1290E, "" },
//  { 0x1290F, "" },
//  { 0x12910, "" },
//  { 0x12911, "" },
//  { 0x12912, "" },
//  { 0x12913, "" },
//  { 0x12914, "" },
//  { 0x12915, "" },
//  { 0x12916, "" },
//  { 0x12917, "" },
//  { 0x12918, "" },
//  { 0x12919, "" },
//  { 0x1291A, "" },
//  { 0x1291B, "" },
//  { 0x1291C, "" },
//  { 0x1291D, "" },
//  { 0x1291E, "" },
//  { 0x1291F, "" },
//  { 0x12920, "" },
//  { 0x12921, "" },
//  { 0x12922, "" },
//  { 0x12923, "" },
//  { 0x12924, "" },
//  { 0x12925, "" },
//  { 0x12926, "" },
//  { 0x12927, "" },
//  { 0x12928, "" },
//  { 0x12929, "" },
//  { 0x1292A, "" },
//  { 0x1292B, "" },
//  { 0x1292C, "" },
//  { 0x1292D, "" },
//  { 0x1292E, "" },
//  { 0x1292F, "" },
//  { 0x12930, "" },
//  { 0x12931, "" },
//  { 0x12932, "" },
//  { 0x12933, "" },
//  { 0x12934, "" },
//  { 0x12935, "" },
//  { 0x12936, "" },
//  { 0x12937, "" },
//  { 0x12938, "" },
//  { 0x12939, "" },
//  { 0x1293A, "" },
//  { 0x1293B, "" },
//  { 0x1293C, "" },
//  { 0x1293D, "" },
//  { 0x1293E, "" },
//  { 0x1293F, "" },
//  { 0x12940, "" },
//  { 0x12941, "" },
//  { 0x12942, "" },
//  { 0x12943, "" },
//  { 0x12944, "" },
//  { 0x12945, "" },
//  { 0x12946, "" },
//  { 0x12947, "" },
//  { 0x12948, "" },
//  { 0x12949, "" },
//  { 0x1294A, "" },
//  { 0x1294B, "" },
//  { 0x1294C, "" },
//  { 0x1294D, "" },
//  { 0x1294E, "" },
//  { 0x1294F, "" },
//  { 0x12950, "" },
//  { 0x12951, "" },
//  { 0x12952, "" },
//  { 0x12953, "" },
//  { 0x12954, "" },
//  { 0x12955, "" },
//  { 0x12956, "" },
//  { 0x12957, "" },
//  { 0x12958, "" },
//  { 0x12959, "" },
//  { 0x1295A, "" },
//  { 0x1295B, "" },
//  { 0x1295C, "" },
//  { 0x1295D, "" },
//  { 0x1295E, "" },
//  { 0x1295F, "" },
//  { 0x12960, "" },
//  { 0x12961, "" },
//  { 0x12962, "" },
//  { 0x12963, "" },
//  { 0x12964, "" },
//  { 0x12965, "" },
//  { 0x12966, "" },
//  { 0x12967, "" },
//  { 0x12968, "" },
//  { 0x12969, "" },
//  { 0x1296A, "" },
//  { 0x1296B, "" },
//  { 0x1296C, "" },
//  { 0x1296D, "" },
//  { 0x1296E, "" },
//  { 0x1296F, "" },
//  { 0x12970, "" },
//  { 0x12971, "" },
//  { 0x12972, "" },
//  { 0x12973, "" },
//  { 0x12974, "" },
//  { 0x12975, "" },
//  { 0x12976, "" },
//  { 0x12977, "" },
//  { 0x12978, "" },
//  { 0x12979, "" },
//  { 0x1297A, "" },
//  { 0x1297B, "" },
//  { 0x1297C, "" },
//  { 0x1297D, "" },
//  { 0x1297E, "" },
//  { 0x1297F, "" },
//  { 0x12980, "" },
//  { 0x12981, "" },
//  { 0x12982, "" },
//  { 0x12983, "" },
//  { 0x12984, "" },
//  { 0x12985, "" },
//  { 0x12986, "" },
//  { 0x12987, "" },
//  { 0x12988, "" },
//  { 0x12989, "" },
//  { 0x1298A, "" },
//  { 0x1298B, "" },
//  { 0x1298C, "" },
//  { 0x1298D, "" },
//  { 0x1298E, "" },
//  { 0x1298F, "" },
//  { 0x12990, "" },
//  { 0x12991, "" },
//  { 0x12992, "" },
//  { 0x12993, "" },
//  { 0x12994, "" },
//  { 0x12995, "" },
//  { 0x12996, "" },
//  { 0x12997, "" },
//  { 0x12998, "" },
//  { 0x12999, "" },
//  { 0x1299A, "" },
//  { 0x1299B, "" },
//  { 0x1299C, "" },
//  { 0x1299D, "" },
//  { 0x1299E, "" },
//  { 0x1299F, "" },
//  { 0x129A0, "" },
//  { 0x129A1, "" },
//  { 0x129A2, "" },
//  { 0x129A3, "" },
//  { 0x129A4, "" },
//  { 0x129A5, "" },
//  { 0x129A6, "" },
//  { 0x129A7, "" },
//  { 0x129A8, "" },
//  { 0x129A9, "" },
//  { 0x129AA, "" },
//  { 0x129AB, "" },
//  { 0x129AC, "" },
//  { 0x129AD, "" },
//  { 0x129AE, "" },
//  { 0x129AF, "" },
//  { 0x129B0, "" },
//  { 0x129B1, "" },
//  { 0x129B2, "" },
//  { 0x129B3, "" },
//  { 0x129B4, "" },
//  { 0x129B5, "" },
//  { 0x129B6, "" },
//  { 0x129B7, "" },
//  { 0x129B8, "" },
//  { 0x129B9, "" },
//  { 0x129BA, "" },
//  { 0x129BB, "" },
//  { 0x129BC, "" },
//  { 0x129BD, "" },
//  { 0x129BE, "" },
//  { 0x129BF, "" },
//  { 0x129C0, "" },
//  { 0x129C1, "" },
//  { 0x129C2, "" },
//  { 0x129C3, "" },
//  { 0x129C4, "" },
//  { 0x129C5, "" },
//  { 0x129C6, "" },
//  { 0x129C7, "" },
//  { 0x129C8, "" },
//  { 0x129C9, "" },
//  { 0x129CA, "" },
//  { 0x129CB, "" },
//  { 0x129CC, "" },
//  { 0x129CD, "" },
//  { 0x129CE, "" },
//  { 0x129CF, "" },
//  { 0x129D0, "" },
//  { 0x129D1, "" },
//  { 0x129D2, "" },
//  { 0x129D3, "" },
//  { 0x129D4, "" },
//  { 0x129D5, "" },
//  { 0x129D6, "" },
//  { 0x129D7, "" },
//  { 0x129D8, "" },
//  { 0x129D9, "" },
//  { 0x129DA, "" },
//  { 0x129DB, "" },
//  { 0x129DC, "" },
//  { 0x129DD, "" },
//  { 0x129DE, "" },
//  { 0x129DF, "" },
//  { 0x129E0, "" },
//  { 0x129E1, "" },
//  { 0x129E2, "" },
//  { 0x129E3, "" },
//  { 0x129E4, "" },
//  { 0x129E5, "" },
//  { 0x129E6, "" },
//  { 0x129E7, "" },
//  { 0x129E8, "" },
//  { 0x129E9, "" },
//  { 0x129EA, "" },
//  { 0x129EB, "" },
//  { 0x129EC, "" },
//  { 0x129ED, "" },
//  { 0x129EE, "" },
//  { 0x129EF, "" },
//  { 0x129F0, "" },
//  { 0x129F1, "" },
//  { 0x129F2, "" },
//  { 0x129F3, "" },
//  { 0x129F4, "" },
//  { 0x129F5, "" },
//  { 0x129F6, "" },
//  { 0x129F7, "" },
//  { 0x129F8, "" },
//  { 0x129F9, "" },
//  { 0x129FA, "" },
//  { 0x129FB, "" },
//  { 0x129FC, "" },
//  { 0x129FD, "" },
//  { 0x129FE, "" },
//  { 0x129FF, "" },
//  { 0x12A00, "" },
//  { 0x12A01, "" },
//  { 0x12A02, "" },
//  { 0x12A03, "" },
//  { 0x12A04, "" },
//  { 0x12A05, "" },
//  { 0x12A06, "" },
//  { 0x12A07, "" },
//  { 0x12A08, "" },
//  { 0x12A09, "" },
//  { 0x12A0A, "" },
//  { 0x12A0B, "" },
//  { 0x12A0C, "" },
//  { 0x12A0D, "" },
//  { 0x12A0E, "" },
//  { 0x12A0F, "" },
//  { 0x12A10, "" },
//  { 0x12A11, "" },
//  { 0x12A12, "" },
//  { 0x12A13, "" },
//  { 0x12A14, "" },
//  { 0x12A15, "" },
//  { 0x12A16, "" },
//  { 0x12A17, "" },
//  { 0x12A18, "" },
//  { 0x12A19, "" },
//  { 0x12A1A, "" },
//  { 0x12A1B, "" },
//  { 0x12A1C, "" },
//  { 0x12A1D, "" },
//  { 0x12A1E, "" },
//  { 0x12A1F, "" },
//  { 0x12A20, "" },
//  { 0x12A21, "" },
//  { 0x12A22, "" },
//  { 0x12A23, "" },
//  { 0x12A24, "" },
//  { 0x12A25, "" },
//  { 0x12A26, "" },
//  { 0x12A27, "" },
//  { 0x12A28, "" },
//  { 0x12A29, "" },
//  { 0x12A2A, "" },
//  { 0x12A2B, "" },
//  { 0x12A2C, "" },
//  { 0x12A2D, "" },
//  { 0x12A2E, "" },
//  { 0x12A2F, "" },
//  { 0x12A30, "" },
//  { 0x12A31, "" },
//  { 0x12A32, "" },
//  { 0x12A33, "" },
//  { 0x12A34, "" },
//  { 0x12A35, "" },
//  { 0x12A36, "" },
//  { 0x12A37, "" },
//  { 0x12A38, "" },
//  { 0x12A39, "" },
//  { 0x12A3A, "" },
//  { 0x12A3B, "" },
//  { 0x12A3C, "" },
//  { 0x12A3D, "" },
//  { 0x12A3E, "" },
//  { 0x12A3F, "" },
//  { 0x12A40, "" },
//  { 0x12A41, "" },
//  { 0x12A42, "" },
//  { 0x12A43, "" },
//  { 0x12A44, "" },
//  { 0x12A45, "" },
//  { 0x12A46, "" },
//  { 0x12A47, "" },
//  { 0x12A48, "" },
//  { 0x12A49, "" },
//  { 0x12A4A, "" },
//  { 0x12A4B, "" },
//  { 0x12A4C, "" },
//  { 0x12A4D, "" },
//  { 0x12A4E, "" },
//  { 0x12A4F, "" },
//  { 0x12A50, "" },
//  { 0x12A51, "" },
//  { 0x12A52, "" },
//  { 0x12A53, "" },
//  { 0x12A54, "" },
//  { 0x12A55, "" },
//  { 0x12A56, "" },
//  { 0x12A57, "" },
//  { 0x12A58, "" },
//  { 0x12A59, "" },
//  { 0x12A5A, "" },
//  { 0x12A5B, "" },
//  { 0x12A5C, "" },
//  { 0x12A5D, "" },
//  { 0x12A5E, "" },
//  { 0x12A5F, "" },
//  { 0x12A60, "" },
//  { 0x12A61, "" },
//  { 0x12A62, "" },
//  { 0x12A63, "" },
//  { 0x12A64, "" },
//  { 0x12A65, "" },
//  { 0x12A66, "" },
//  { 0x12A67, "" },
//  { 0x12A68, "" },
//  { 0x12A69, "" },
//  { 0x12A6A, "" },
//  { 0x12A6B, "" },
//  { 0x12A6C, "" },
//  { 0x12A6D, "" },
//  { 0x12A6E, "" },
//  { 0x12A6F, "" },
//  { 0x12A70, "" },
//  { 0x12A71, "" },
//  { 0x12A72, "" },
//  { 0x12A73, "" },
//  { 0x12A74, "" },
//  { 0x12A75, "" },
//  { 0x12A76, "" },
//  { 0x12A77, "" },
//  { 0x12A78, "" },
//  { 0x12A79, "" },
//  { 0x12A7A, "" },
//  { 0x12A7B, "" },
//  { 0x12A7C, "" },
//  { 0x12A7D, "" },
//  { 0x12A7E, "" },
//  { 0x12A7F, "" },
//  { 0x12A80, "" },
//  { 0x12A81, "" },
//  { 0x12A82, "" },
//  { 0x12A83, "" },
//  { 0x12A84, "" },
//  { 0x12A85, "" },
//  { 0x12A86, "" },
//  { 0x12A87, "" },
//  { 0x12A88, "" },
//  { 0x12A89, "" },
//  { 0x12A8A, "" },
//  { 0x12A8B, "" },
//  { 0x12A8C, "" },
//  { 0x12A8D, "" },
//  { 0x12A8E, "" },
//  { 0x12A8F, "" },
//  { 0x12A90, "" },
//  { 0x12A91, "" },
//  { 0x12A92, "" },
//  { 0x12A93, "" },
//  { 0x12A94, "" },
//  { 0x12A95, "" },
//  { 0x12A96, "" },
//  { 0x12A97, "" },
//  { 0x12A98, "" },
//  { 0x12A99, "" },
//  { 0x12A9A, "" },
//  { 0x12A9B, "" },
//  { 0x12A9C, "" },
//  { 0x12A9D, "" },
//  { 0x12A9E, "" },
//  { 0x12A9F, "" },
//  { 0x12AA0, "" },
//  { 0x12AA1, "" },
//  { 0x12AA2, "" },
//  { 0x12AA3, "" },
//  { 0x12AA4, "" },
//  { 0x12AA5, "" },
//  { 0x12AA6, "" },
//  { 0x12AA7, "" },
//  { 0x12AA8, "" },
//  { 0x12AA9, "" },
//  { 0x12AAA, "" },
//  { 0x12AAB, "" },
//  { 0x12AAC, "" },
//  { 0x12AAD, "" },
//  { 0x12AAE, "" },
//  { 0x12AAF, "" },
//  { 0x12AB0, "" },
//  { 0x12AB1, "" },
//  { 0x12AB2, "" },
//  { 0x12AB3, "" },
//  { 0x12AB4, "" },
//  { 0x12AB5, "" },
//  { 0x12AB6, "" },
//  { 0x12AB7, "" },
//  { 0x12AB8, "" },
//  { 0x12AB9, "" },
//  { 0x12ABA, "" },
//  { 0x12ABB, "" },
//  { 0x12ABC, "" },
//  { 0x12ABD, "" },
//  { 0x12ABE, "" },
//  { 0x12ABF, "" },
//  { 0x12AC0, "" },
//  { 0x12AC1, "" },
//  { 0x12AC2, "" },
//  { 0x12AC3, "" },
//  { 0x12AC4, "" },
//  { 0x12AC5, "" },
//  { 0x12AC6, "" },
//  { 0x12AC7, "" },
//  { 0x12AC8, "" },
//  { 0x12AC9, "" },
//  { 0x12ACA, "" },
//  { 0x12ACB, "" },
//  { 0x12ACC, "" },
//  { 0x12ACD, "" },
//  { 0x12ACE, "" },
//  { 0x12ACF, "" },
//  { 0x12AD0, "" },
//  { 0x12AD1, "" },
//  { 0x12AD2, "" },
//  { 0x12AD3, "" },
//  { 0x12AD4, "" },
//  { 0x12AD5, "" },
//  { 0x12AD6, "" },
//  { 0x12AD7, "" },
//  { 0x12AD8, "" },
//  { 0x12AD9, "" },
//  { 0x12ADA, "" },
//  { 0x12ADB, "" },
//  { 0x12ADC, "" },
//  { 0x12ADD, "" },
//  { 0x12ADE, "" },
//  { 0x12ADF, "" },
//  { 0x12AE0, "" },
//  { 0x12AE1, "" },
//  { 0x12AE2, "" },
//  { 0x12AE3, "" },
//  { 0x12AE4, "" },
//  { 0x12AE5, "" },
//  { 0x12AE6, "" },
//  { 0x12AE7, "" },
//  { 0x12AE8, "" },
//  { 0x12AE9, "" },
//  { 0x12AEA, "" },
//  { 0x12AEB, "" },
//  { 0x12AEC, "" },
//  { 0x12AED, "" },
//  { 0x12AEE, "" },
//  { 0x12AEF, "" },
//  { 0x12AF0, "" },
//  { 0x12AF1, "" },
//  { 0x12AF2, "" },
//  { 0x12AF3, "" },
//  { 0x12AF4, "" },
//  { 0x12AF5, "" },
//  { 0x12AF6, "" },
//  { 0x12AF7, "" },
//  { 0x12AF8, "" },
//  { 0x12AF9, "" },
//  { 0x12AFA, "" },
//  { 0x12AFB, "" },
//  { 0x12AFC, "" },
//  { 0x12AFD, "" },
//  { 0x12AFE, "" },
//  { 0x12AFF, "" },
//  { 0x12B00, "" },
//  { 0x12B01, "" },
//  { 0x12B02, "" },
//  { 0x12B03, "" },
//  { 0x12B04, "" },
//  { 0x12B05, "" },
//  { 0x12B06, "" },
//  { 0x12B07, "" },
//  { 0x12B08, "" },
//  { 0x12B09, "" },
//  { 0x12B0A, "" },
//  { 0x12B0B, "" },
//  { 0x12B0C, "" },
//  { 0x12B0D, "" },
//  { 0x12B0E, "" },
//  { 0x12B0F, "" },
//  { 0x12B10, "" },
//  { 0x12B11, "" },
//  { 0x12B12, "" },
//  { 0x12B13, "" },
//  { 0x12B14, "" },
//  { 0x12B15, "" },
//  { 0x12B16, "" },
//  { 0x12B17, "" },
//  { 0x12B18, "" },
//  { 0x12B19, "" },
//  { 0x12B1A, "" },
//  { 0x12B1B, "" },
//  { 0x12B1C, "" },
//  { 0x12B1D, "" },
//  { 0x12B1E, "" },
//  { 0x12B1F, "" },
//  { 0x12B20, "" },
//  { 0x12B21, "" },
//  { 0x12B22, "" },
//  { 0x12B23, "" },
//  { 0x12B24, "" },
//  { 0x12B25, "" },
//  { 0x12B26, "" },
//  { 0x12B27, "" },
//  { 0x12B28, "" },
//  { 0x12B29, "" },
//  { 0x12B2A, "" },
//  { 0x12B2B, "" },
//  { 0x12B2C, "" },
//  { 0x12B2D, "" },
//  { 0x12B2E, "" },
//  { 0x12B2F, "" },
//  { 0x12B30, "" },
//  { 0x12B31, "" },
//  { 0x12B32, "" },
//  { 0x12B33, "" },
//  { 0x12B34, "" },
//  { 0x12B35, "" },
//  { 0x12B36, "" },
//  { 0x12B37, "" },
//  { 0x12B38, "" },
//  { 0x12B39, "" },
//  { 0x12B3A, "" },
//  { 0x12B3B, "" },
//  { 0x12B3C, "" },
//  { 0x12B3D, "" },
//  { 0x12B3E, "" },
//  { 0x12B3F, "" },
//  { 0x12B40, "" },
//  { 0x12B41, "" },
//  { 0x12B42, "" },
//  { 0x12B43, "" },
//  { 0x12B44, "" },
//  { 0x12B45, "" },
//  { 0x12B46, "" },
//  { 0x12B47, "" },
//  { 0x12B48, "" },
//  { 0x12B49, "" },
//  { 0x12B4A, "" },
//  { 0x12B4B, "" },
//  { 0x12B4C, "" },
//  { 0x12B4D, "" },
//  { 0x12B4E, "" },
//  { 0x12B4F, "" },
//  { 0x12B50, "" },
//  { 0x12B51, "" },
//  { 0x12B52, "" },
//  { 0x12B53, "" },
//  { 0x12B54, "" },
//  { 0x12B55, "" },
//  { 0x12B56, "" },
//  { 0x12B57, "" },
//  { 0x12B58, "" },
//  { 0x12B59, "" },
//  { 0x12B5A, "" },
//  { 0x12B5B, "" },
//  { 0x12B5C, "" },
//  { 0x12B5D, "" },
//  { 0x12B5E, "" },
//  { 0x12B5F, "" },
//  { 0x12B60, "" },
//  { 0x12B61, "" },
//  { 0x12B62, "" },
//  { 0x12B63, "" },
//  { 0x12B64, "" },
//  { 0x12B65, "" },
//  { 0x12B66, "" },
//  { 0x12B67, "" },
//  { 0x12B68, "" },
//  { 0x12B69, "" },
//  { 0x12B6A, "" },
//  { 0x12B6B, "" },
//  { 0x12B6C, "" },
//  { 0x12B6D, "" },
//  { 0x12B6E, "" },
//  { 0x12B6F, "" },
//  { 0x12B70, "" },
//  { 0x12B71, "" },
//  { 0x12B72, "" },
//  { 0x12B73, "" },
//  { 0x12B74, "" },
//  { 0x12B75, "" },
//  { 0x12B76, "" },
//  { 0x12B77, "" },
//  { 0x12B78, "" },
//  { 0x12B79, "" },
//  { 0x12B7A, "" },
//  { 0x12B7B, "" },
//  { 0x12B7C, "" },
//  { 0x12B7D, "" },
//  { 0x12B7E, "" },
//  { 0x12B7F, "" },
//  { 0x12B80, "" },
//  { 0x12B81, "" },
//  { 0x12B82, "" },
//  { 0x12B83, "" },
//  { 0x12B84, "" },
//  { 0x12B85, "" },
//  { 0x12B86, "" },
//  { 0x12B87, "" },
//  { 0x12B88, "" },
//  { 0x12B89, "" },
//  { 0x12B8A, "" },
//  { 0x12B8B, "" },
//  { 0x12B8C, "" },
//  { 0x12B8D, "" },
//  { 0x12B8E, "" },
//  { 0x12B8F, "" },
//  { 0x12B90, "" },
//  { 0x12B91, "" },
//  { 0x12B92, "" },
//  { 0x12B93, "" },
//  { 0x12B94, "" },
//  { 0x12B95, "" },
//  { 0x12B96, "" },
//  { 0x12B97, "" },
//  { 0x12B98, "" },
//  { 0x12B99, "" },
//  { 0x12B9A, "" },
//  { 0x12B9B, "" },
//  { 0x12B9C, "" },
//  { 0x12B9D, "" },
//  { 0x12B9E, "" },
//  { 0x12B9F, "" },
//  { 0x12BA0, "" },
//  { 0x12BA1, "" },
//  { 0x12BA2, "" },
//  { 0x12BA3, "" },
//  { 0x12BA4, "" },
//  { 0x12BA5, "" },
//  { 0x12BA6, "" },
//  { 0x12BA7, "" },
//  { 0x12BA8, "" },
//  { 0x12BA9, "" },
//  { 0x12BAA, "" },
//  { 0x12BAB, "" },
//  { 0x12BAC, "" },
//  { 0x12BAD, "" },
//  { 0x12BAE, "" },
//  { 0x12BAF, "" },
//  { 0x12BB0, "" },
//  { 0x12BB1, "" },
//  { 0x12BB2, "" },
//  { 0x12BB3, "" },
//  { 0x12BB4, "" },
//  { 0x12BB5, "" },
//  { 0x12BB6, "" },
//  { 0x12BB7, "" },
//  { 0x12BB8, "" },
//  { 0x12BB9, "" },
//  { 0x12BBA, "" },
//  { 0x12BBB, "" },
//  { 0x12BBC, "" },
//  { 0x12BBD, "" },
//  { 0x12BBE, "" },
//  { 0x12BBF, "" },
//  { 0x12BC0, "" },
//  { 0x12BC1, "" },
//  { 0x12BC2, "" },
//  { 0x12BC3, "" },
//  { 0x12BC4, "" },
//  { 0x12BC5, "" },
//  { 0x12BC6, "" },
//  { 0x12BC7, "" },
//  { 0x12BC8, "" },
//  { 0x12BC9, "" },
//  { 0x12BCA, "" },
//  { 0x12BCB, "" },
//  { 0x12BCC, "" },
//  { 0x12BCD, "" },
//  { 0x12BCE, "" },
//  { 0x12BCF, "" },
//  { 0x12BD0, "" },
//  { 0x12BD1, "" },
//  { 0x12BD2, "" },
//  { 0x12BD3, "" },
//  { 0x12BD4, "" },
//  { 0x12BD5, "" },
//  { 0x12BD6, "" },
//  { 0x12BD7, "" },
//  { 0x12BD8, "" },
//  { 0x12BD9, "" },
//  { 0x12BDA, "" },
//  { 0x12BDB, "" },
//  { 0x12BDC, "" },
//  { 0x12BDD, "" },
//  { 0x12BDE, "" },
//  { 0x12BDF, "" },
//  { 0x12BE0, "" },
//  { 0x12BE1, "" },
//  { 0x12BE2, "" },
//  { 0x12BE3, "" },
//  { 0x12BE4, "" },
//  { 0x12BE5, "" },
//  { 0x12BE6, "" },
//  { 0x12BE7, "" },
//  { 0x12BE8, "" },
//  { 0x12BE9, "" },
//  { 0x12BEA, "" },
//  { 0x12BEB, "" },
//  { 0x12BEC, "" },
//  { 0x12BED, "" },
//  { 0x12BEE, "" },
//  { 0x12BEF, "" },
//  { 0x12BF0, "" },
//  { 0x12BF1, "" },
//  { 0x12BF2, "" },
//  { 0x12BF3, "" },
//  { 0x12BF4, "" },
//  { 0x12BF5, "" },
//  { 0x12BF6, "" },
//  { 0x12BF7, "" },
//  { 0x12BF8, "" },
//  { 0x12BF9, "" },
//  { 0x12BFA, "" },
//  { 0x12BFB, "" },
//  { 0x12BFC, "" },
//  { 0x12BFD, "" },
//  { 0x12BFE, "" },
//  { 0x12BFF, "" },
//  { 0x12C00, "" },
//  { 0x12C01, "" },
//  { 0x12C02, "" },
//  { 0x12C03, "" },
//  { 0x12C04, "" },
//  { 0x12C05, "" },
//  { 0x12C06, "" },
//  { 0x12C07, "" },
//  { 0x12C08, "" },
//  { 0x12C09, "" },
//  { 0x12C0A, "" },
//  { 0x12C0B, "" },
//  { 0x12C0C, "" },
//  { 0x12C0D, "" },
//  { 0x12C0E, "" },
//  { 0x12C0F, "" },
//  { 0x12C10, "" },
//  { 0x12C11, "" },
//  { 0x12C12, "" },
//  { 0x12C13, "" },
//  { 0x12C14, "" },
//  { 0x12C15, "" },
//  { 0x12C16, "" },
//  { 0x12C17, "" },
//  { 0x12C18, "" },
//  { 0x12C19, "" },
//  { 0x12C1A, "" },
//  { 0x12C1B, "" },
//  { 0x12C1C, "" },
//  { 0x12C1D, "" },
//  { 0x12C1E, "" },
//  { 0x12C1F, "" },
//  { 0x12C20, "" },
//  { 0x12C21, "" },
//  { 0x12C22, "" },
//  { 0x12C23, "" },
//  { 0x12C24, "" },
//  { 0x12C25, "" },
//  { 0x12C26, "" },
//  { 0x12C27, "" },
//  { 0x12C28, "" },
//  { 0x12C29, "" },
//  { 0x12C2A, "" },
//  { 0x12C2B, "" },
//  { 0x12C2C, "" },
//  { 0x12C2D, "" },
//  { 0x12C2E, "" },
//  { 0x12C2F, "" },
//  { 0x12C30, "" },
//  { 0x12C31, "" },
//  { 0x12C32, "" },
//  { 0x12C33, "" },
//  { 0x12C34, "" },
//  { 0x12C35, "" },
//  { 0x12C36, "" },
//  { 0x12C37, "" },
//  { 0x12C38, "" },
//  { 0x12C39, "" },
//  { 0x12C3A, "" },
//  { 0x12C3B, "" },
//  { 0x12C3C, "" },
//  { 0x12C3D, "" },
//  { 0x12C3E, "" },
//  { 0x12C3F, "" },
//  { 0x12C40, "" },
//  { 0x12C41, "" },
//  { 0x12C42, "" },
//  { 0x12C43, "" },
//  { 0x12C44, "" },
//  { 0x12C45, "" },
//  { 0x12C46, "" },
//  { 0x12C47, "" },
//  { 0x12C48, "" },
//  { 0x12C49, "" },
//  { 0x12C4A, "" },
//  { 0x12C4B, "" },
//  { 0x12C4C, "" },
//  { 0x12C4D, "" },
//  { 0x12C4E, "" },
//  { 0x12C4F, "" },
//  { 0x12C50, "" },
//  { 0x12C51, "" },
//  { 0x12C52, "" },
//  { 0x12C53, "" },
//  { 0x12C54, "" },
//  { 0x12C55, "" },
//  { 0x12C56, "" },
//  { 0x12C57, "" },
//  { 0x12C58, "" },
//  { 0x12C59, "" },
//  { 0x12C5A, "" },
//  { 0x12C5B, "" },
//  { 0x12C5C, "" },
//  { 0x12C5D, "" },
//  { 0x12C5E, "" },
//  { 0x12C5F, "" },
//  { 0x12C60, "" },
//  { 0x12C61, "" },
//  { 0x12C62, "" },
//  { 0x12C63, "" },
//  { 0x12C64, "" },
//  { 0x12C65, "" },
//  { 0x12C66, "" },
//  { 0x12C67, "" },
//  { 0x12C68, "" },
//  { 0x12C69, "" },
//  { 0x12C6A, "" },
//  { 0x12C6B, "" },
//  { 0x12C6C, "" },
//  { 0x12C6D, "" },
//  { 0x12C6E, "" },
//  { 0x12C6F, "" },
//  { 0x12C70, "" },
//  { 0x12C71, "" },
//  { 0x12C72, "" },
//  { 0x12C73, "" },
//  { 0x12C74, "" },
//  { 0x12C75, "" },
//  { 0x12C76, "" },
//  { 0x12C77, "" },
//  { 0x12C78, "" },
//  { 0x12C79, "" },
//  { 0x12C7A, "" },
//  { 0x12C7B, "" },
//  { 0x12C7C, "" },
//  { 0x12C7D, "" },
//  { 0x12C7E, "" },
//  { 0x12C7F, "" },
//  { 0x12C80, "" },
//  { 0x12C81, "" },
//  { 0x12C82, "" },
//  { 0x12C83, "" },
//  { 0x12C84, "" },
//  { 0x12C85, "" },
//  { 0x12C86, "" },
//  { 0x12C87, "" },
//  { 0x12C88, "" },
//  { 0x12C89, "" },
//  { 0x12C8A, "" },
//  { 0x12C8B, "" },
//  { 0x12C8C, "" },
//  { 0x12C8D, "" },
//  { 0x12C8E, "" },
//  { 0x12C8F, "" },
//  { 0x12C90, "" },
//  { 0x12C91, "" },
//  { 0x12C92, "" },
//  { 0x12C93, "" },
//  { 0x12C94, "" },
//  { 0x12C95, "" },
//  { 0x12C96, "" },
//  { 0x12C97, "" },
//  { 0x12C98, "" },
//  { 0x12C99, "" },
//  { 0x12C9A, "" },
//  { 0x12C9B, "" },
//  { 0x12C9C, "" },
//  { 0x12C9D, "" },
//  { 0x12C9E, "" },
//  { 0x12C9F, "" },
//  { 0x12CA0, "" },
//  { 0x12CA1, "" },
//  { 0x12CA2, "" },
//  { 0x12CA3, "" },
//  { 0x12CA4, "" },
//  { 0x12CA5, "" },
//  { 0x12CA6, "" },
//  { 0x12CA7, "" },
//  { 0x12CA8, "" },
//  { 0x12CA9, "" },
//  { 0x12CAA, "" },
//  { 0x12CAB, "" },
//  { 0x12CAC, "" },
//  { 0x12CAD, "" },
//  { 0x12CAE, "" },
//  { 0x12CAF, "" },
//  { 0x12CB0, "" },
//  { 0x12CB1, "" },
//  { 0x12CB2, "" },
//  { 0x12CB3, "" },
//  { 0x12CB4, "" },
//  { 0x12CB5, "" },
//  { 0x12CB6, "" },
//  { 0x12CB7, "" },
//  { 0x12CB8, "" },
//  { 0x12CB9, "" },
//  { 0x12CBA, "" },
//  { 0x12CBB, "" },
//  { 0x12CBC, "" },
//  { 0x12CBD, "" },
//  { 0x12CBE, "" },
//  { 0x12CBF, "" },
//  { 0x12CC0, "" },
//  { 0x12CC1, "" },
//  { 0x12CC2, "" },
//  { 0x12CC3, "" },
//  { 0x12CC4, "" },
//  { 0x12CC5, "" },
//  { 0x12CC6, "" },
//  { 0x12CC7, "" },
//  { 0x12CC8, "" },
//  { 0x12CC9, "" },
//  { 0x12CCA, "" },
//  { 0x12CCB, "" },
//  { 0x12CCC, "" },
//  { 0x12CCD, "" },
//  { 0x12CCE, "" },
//  { 0x12CCF, "" },
//  { 0x12CD0, "" },
//  { 0x12CD1, "" },
//  { 0x12CD2, "" },
//  { 0x12CD3, "" },
//  { 0x12CD4, "" },
//  { 0x12CD5, "" },
//  { 0x12CD6, "" },
//  { 0x12CD7, "" },
//  { 0x12CD8, "" },
//  { 0x12CD9, "" },
//  { 0x12CDA, "" },
//  { 0x12CDB, "" },
//  { 0x12CDC, "" },
//  { 0x12CDD, "" },
//  { 0x12CDE, "" },
//  { 0x12CDF, "" },
//  { 0x12CE0, "" },
//  { 0x12CE1, "" },
//  { 0x12CE2, "" },
//  { 0x12CE3, "" },
//  { 0x12CE4, "" },
//  { 0x12CE5, "" },
//  { 0x12CE6, "" },
//  { 0x12CE7, "" },
//  { 0x12CE8, "" },
//  { 0x12CE9, "" },
//  { 0x12CEA, "" },
//  { 0x12CEB, "" },
//  { 0x12CEC, "" },
//  { 0x12CED, "" },
//  { 0x12CEE, "" },
//  { 0x12CEF, "" },
//  { 0x12CF0, "" },
//  { 0x12CF1, "" },
//  { 0x12CF2, "" },
//  { 0x12CF3, "" },
//  { 0x12CF4, "" },
//  { 0x12CF5, "" },
//  { 0x12CF6, "" },
//  { 0x12CF7, "" },
//  { 0x12CF8, "" },
//  { 0x12CF9, "" },
//  { 0x12CFA, "" },
//  { 0x12CFB, "" },
//  { 0x12CFC, "" },
//  { 0x12CFD, "" },
//  { 0x12CFE, "" },
//  { 0x12CFF, "" },
//  { 0x12D00, "" },
//  { 0x12D01, "" },
//  { 0x12D02, "" },
//  { 0x12D03, "" },
//  { 0x12D04, "" },
//  { 0x12D05, "" },
//  { 0x12D06, "" },
//  { 0x12D07, "" },
//  { 0x12D08, "" },
//  { 0x12D09, "" },
//  { 0x12D0A, "" },
//  { 0x12D0B, "" },
//  { 0x12D0C, "" },
//  { 0x12D0D, "" },
//  { 0x12D0E, "" },
//  { 0x12D0F, "" },
//  { 0x12D10, "" },
//  { 0x12D11, "" },
//  { 0x12D12, "" },
//  { 0x12D13, "" },
//  { 0x12D14, "" },
//  { 0x12D15, "" },
//  { 0x12D16, "" },
//  { 0x12D17, "" },
//  { 0x12D18, "" },
//  { 0x12D19, "" },
//  { 0x12D1A, "" },
//  { 0x12D1B, "" },
//  { 0x12D1C, "" },
//  { 0x12D1D, "" },
//  { 0x12D1E, "" },
//  { 0x12D1F, "" },
//  { 0x12D20, "" },
//  { 0x12D21, "" },
//  { 0x12D22, "" },
//  { 0x12D23, "" },
//  { 0x12D24, "" },
//  { 0x12D25, "" },
//  { 0x12D26, "" },
//  { 0x12D27, "" },
//  { 0x12D28, "" },
//  { 0x12D29, "" },
//  { 0x12D2A, "" },
//  { 0x12D2B, "" },
//  { 0x12D2C, "" },
//  { 0x12D2D, "" },
//  { 0x12D2E, "" },
//  { 0x12D2F, "" },
//  { 0x12D30, "" },
//  { 0x12D31, "" },
//  { 0x12D32, "" },
//  { 0x12D33, "" },
//  { 0x12D34, "" },
//  { 0x12D35, "" },
//  { 0x12D36, "" },
//  { 0x12D37, "" },
//  { 0x12D38, "" },
//  { 0x12D39, "" },
//  { 0x12D3A, "" },
//  { 0x12D3B, "" },
//  { 0x12D3C, "" },
//  { 0x12D3D, "" },
//  { 0x12D3E, "" },
//  { 0x12D3F, "" },
//  { 0x12D40, "" },
//  { 0x12D41, "" },
//  { 0x12D42, "" },
//  { 0x12D43, "" },
//  { 0x12D44, "" },
//  { 0x12D45, "" },
//  { 0x12D46, "" },
//  { 0x12D47, "" },
//  { 0x12D48, "" },
//  { 0x12D49, "" },
//  { 0x12D4A, "" },
//  { 0x12D4B, "" },
//  { 0x12D4C, "" },
//  { 0x12D4D, "" },
//  { 0x12D4E, "" },
//  { 0x12D4F, "" },
//  { 0x12D50, "" },
//  { 0x12D51, "" },
//  { 0x12D52, "" },
//  { 0x12D53, "" },
//  { 0x12D54, "" },
//  { 0x12D55, "" },
//  { 0x12D56, "" },
//  { 0x12D57, "" },
//  { 0x12D58, "" },
//  { 0x12D59, "" },
//  { 0x12D5A, "" },
//  { 0x12D5B, "" },
//  { 0x12D5C, "" },
//  { 0x12D5D, "" },
//  { 0x12D5E, "" },
//  { 0x12D5F, "" },
//  { 0x12D60, "" },
//  { 0x12D61, "" },
//  { 0x12D62, "" },
//  { 0x12D63, "" },
//  { 0x12D64, "" },
//  { 0x12D65, "" },
//  { 0x12D66, "" },
//  { 0x12D67, "" },
//  { 0x12D68, "" },
//  { 0x12D69, "" },
//  { 0x12D6A, "" },
//  { 0x12D6B, "" },
//  { 0x12D6C, "" },
//  { 0x12D6D, "" },
//  { 0x12D6E, "" },
//  { 0x12D6F, "" },
//  { 0x12D70, "" },
//  { 0x12D71, "" },
//  { 0x12D72, "" },
//  { 0x12D73, "" },
//  { 0x12D74, "" },
//  { 0x12D75, "" },
//  { 0x12D76, "" },
//  { 0x12D77, "" },
//  { 0x12D78, "" },
//  { 0x12D79, "" },
//  { 0x12D7A, "" },
//  { 0x12D7B, "" },
//  { 0x12D7C, "" },
//  { 0x12D7D, "" },
//  { 0x12D7E, "" },
//  { 0x12D7F, "" },
//  { 0x12D80, "" },
//  { 0x12D81, "" },
//  { 0x12D82, "" },
//  { 0x12D83, "" },
//  { 0x12D84, "" },
//  { 0x12D85, "" },
//  { 0x12D86, "" },
//  { 0x12D87, "" },
//  { 0x12D88, "" },
//  { 0x12D89, "" },
//  { 0x12D8A, "" },
//  { 0x12D8B, "" },
//  { 0x12D8C, "" },
//  { 0x12D8D, "" },
//  { 0x12D8E, "" },
//  { 0x12D8F, "" },
//  { 0x12D90, "" },
//  { 0x12D91, "" },
//  { 0x12D92, "" },
//  { 0x12D93, "" },
//  { 0x12D94, "" },
//  { 0x12D95, "" },
//  { 0x12D96, "" },
//  { 0x12D97, "" },
//  { 0x12D98, "" },
//  { 0x12D99, "" },
//  { 0x12D9A, "" },
//  { 0x12D9B, "" },
//  { 0x12D9C, "" },
//  { 0x12D9D, "" },
//  { 0x12D9E, "" },
//  { 0x12D9F, "" },
//  { 0x12DA0, "" },
//  { 0x12DA1, "" },
//  { 0x12DA2, "" },
//  { 0x12DA3, "" },
//  { 0x12DA4, "" },
//  { 0x12DA5, "" },
//  { 0x12DA6, "" },
//  { 0x12DA7, "" },
//  { 0x12DA8, "" },
//  { 0x12DA9, "" },
//  { 0x12DAA, "" },
//  { 0x12DAB, "" },
//  { 0x12DAC, "" },
//  { 0x12DAD, "" },
//  { 0x12DAE, "" },
//  { 0x12DAF, "" },
//  { 0x12DB0, "" },
//  { 0x12DB1, "" },
//  { 0x12DB2, "" },
//  { 0x12DB3, "" },
//  { 0x12DB4, "" },
//  { 0x12DB5, "" },
//  { 0x12DB6, "" },
//  { 0x12DB7, "" },
//  { 0x12DB8, "" },
//  { 0x12DB9, "" },
//  { 0x12DBA, "" },
//  { 0x12DBB, "" },
//  { 0x12DBC, "" },
//  { 0x12DBD, "" },
//  { 0x12DBE, "" },
//  { 0x12DBF, "" },
//  { 0x12DC0, "" },
//  { 0x12DC1, "" },
//  { 0x12DC2, "" },
//  { 0x12DC3, "" },
//  { 0x12DC4, "" },
//  { 0x12DC5, "" },
//  { 0x12DC6, "" },
//  { 0x12DC7, "" },
//  { 0x12DC8, "" },
//  { 0x12DC9, "" },
//  { 0x12DCA, "" },
//  { 0x12DCB, "" },
//  { 0x12DCC, "" },
//  { 0x12DCD, "" },
//  { 0x12DCE, "" },
//  { 0x12DCF, "" },
//  { 0x12DD0, "" },
//  { 0x12DD1, "" },
//  { 0x12DD2, "" },
//  { 0x12DD3, "" },
//  { 0x12DD4, "" },
//  { 0x12DD5, "" },
//  { 0x12DD6, "" },
//  { 0x12DD7, "" },
//  { 0x12DD8, "" },
//  { 0x12DD9, "" },
//  { 0x12DDA, "" },
//  { 0x12DDB, "" },
//  { 0x12DDC, "" },
//  { 0x12DDD, "" },
//  { 0x12DDE, "" },
//  { 0x12DDF, "" },
//  { 0x12DE0, "" },
//  { 0x12DE1, "" },
//  { 0x12DE2, "" },
//  { 0x12DE3, "" },
//  { 0x12DE4, "" },
//  { 0x12DE5, "" },
//  { 0x12DE6, "" },
//  { 0x12DE7, "" },
//  { 0x12DE8, "" },
//  { 0x12DE9, "" },
//  { 0x12DEA, "" },
//  { 0x12DEB, "" },
//  { 0x12DEC, "" },
//  { 0x12DED, "" },
//  { 0x12DEE, "" },
//  { 0x12DEF, "" },
//  { 0x12DF0, "" },
//  { 0x12DF1, "" },
//  { 0x12DF2, "" },
//  { 0x12DF3, "" },
//  { 0x12DF4, "" },
//  { 0x12DF5, "" },
//  { 0x12DF6, "" },
//  { 0x12DF7, "" },
//  { 0x12DF8, "" },
//  { 0x12DF9, "" },
//  { 0x12DFA, "" },
//  { 0x12DFB, "" },
//  { 0x12DFC, "" },
//  { 0x12DFD, "" },
//  { 0x12DFE, "" },
//  { 0x12DFF, "" },
//  { 0x12E00, "" },
//  { 0x12E01, "" },
//  { 0x12E02, "" },
//  { 0x12E03, "" },
//  { 0x12E04, "" },
//  { 0x12E05, "" },
//  { 0x12E06, "" },
//  { 0x12E07, "" },
//  { 0x12E08, "" },
//  { 0x12E09, "" },
//  { 0x12E0A, "" },
//  { 0x12E0B, "" },
//  { 0x12E0C, "" },
//  { 0x12E0D, "" },
//  { 0x12E0E, "" },
//  { 0x12E0F, "" },
//  { 0x12E10, "" },
//  { 0x12E11, "" },
//  { 0x12E12, "" },
//  { 0x12E13, "" },
//  { 0x12E14, "" },
//  { 0x12E15, "" },
//  { 0x12E16, "" },
//  { 0x12E17, "" },
//  { 0x12E18, "" },
//  { 0x12E19, "" },
//  { 0x12E1A, "" },
//  { 0x12E1B, "" },
//  { 0x12E1C, "" },
//  { 0x12E1D, "" },
//  { 0x12E1E, "" },
//  { 0x12E1F, "" },
//  { 0x12E20, "" },
//  { 0x12E21, "" },
//  { 0x12E22, "" },
//  { 0x12E23, "" },
//  { 0x12E24, "" },
//  { 0x12E25, "" },
//  { 0x12E26, "" },
//  { 0x12E27, "" },
//  { 0x12E28, "" },
//  { 0x12E29, "" },
//  { 0x12E2A, "" },
//  { 0x12E2B, "" },
//  { 0x12E2C, "" },
//  { 0x12E2D, "" },
//  { 0x12E2E, "" },
//  { 0x12E2F, "" },
//  { 0x12E30, "" },
//  { 0x12E31, "" },
//  { 0x12E32, "" },
//  { 0x12E33, "" },
//  { 0x12E34, "" },
//  { 0x12E35, "" },
//  { 0x12E36, "" },
//  { 0x12E37, "" },
//  { 0x12E38, "" },
//  { 0x12E39, "" },
//  { 0x12E3A, "" },
//  { 0x12E3B, "" },
//  { 0x12E3C, "" },
//  { 0x12E3D, "" },
//  { 0x12E3E, "" },
//  { 0x12E3F, "" },
//  { 0x12E40, "" },
//  { 0x12E41, "" },
//  { 0x12E42, "" },
//  { 0x12E43, "" },
//  { 0x12E44, "" },
//  { 0x12E45, "" },
//  { 0x12E46, "" },
//  { 0x12E47, "" },
//  { 0x12E48, "" },
//  { 0x12E49, "" },
//  { 0x12E4A, "" },
//  { 0x12E4B, "" },
//  { 0x12E4C, "" },
//  { 0x12E4D, "" },
//  { 0x12E4E, "" },
//  { 0x12E4F, "" },
//  { 0x12E50, "" },
//  { 0x12E51, "" },
//  { 0x12E52, "" },
//  { 0x12E53, "" },
//  { 0x12E54, "" },
//  { 0x12E55, "" },
//  { 0x12E56, "" },
//  { 0x12E57, "" },
//  { 0x12E58, "" },
//  { 0x12E59, "" },
//  { 0x12E5A, "" },
//  { 0x12E5B, "" },
//  { 0x12E5C, "" },
//  { 0x12E5D, "" },
//  { 0x12E5E, "" },
//  { 0x12E5F, "" },
//  { 0x12E60, "" },
//  { 0x12E61, "" },
//  { 0x12E62, "" },
//  { 0x12E63, "" },
//  { 0x12E64, "" },
//  { 0x12E65, "" },
//  { 0x12E66, "" },
//  { 0x12E67, "" },
//  { 0x12E68, "" },
//  { 0x12E69, "" },
//  { 0x12E6A, "" },
//  { 0x12E6B, "" },
//  { 0x12E6C, "" },
//  { 0x12E6D, "" },
//  { 0x12E6E, "" },
//  { 0x12E6F, "" },
//  { 0x12E70, "" },
//  { 0x12E71, "" },
//  { 0x12E72, "" },
//  { 0x12E73, "" },
//  { 0x12E74, "" },
//  { 0x12E75, "" },
//  { 0x12E76, "" },
//  { 0x12E77, "" },
//  { 0x12E78, "" },
//  { 0x12E79, "" },
//  { 0x12E7A, "" },
//  { 0x12E7B, "" },
//  { 0x12E7C, "" },
//  { 0x12E7D, "" },
//  { 0x12E7E, "" },
//  { 0x12E7F, "" },
//  { 0x12E80, "" },
//  { 0x12E81, "" },
//  { 0x12E82, "" },
//  { 0x12E83, "" },
//  { 0x12E84, "" },
//  { 0x12E85, "" },
//  { 0x12E86, "" },
//  { 0x12E87, "" },
//  { 0x12E88, "" },
//  { 0x12E89, "" },
//  { 0x12E8A, "" },
//  { 0x12E8B, "" },
//  { 0x12E8C, "" },
//  { 0x12E8D, "" },
//  { 0x12E8E, "" },
//  { 0x12E8F, "" },
//  { 0x12E90, "" },
//  { 0x12E91, "" },
//  { 0x12E92, "" },
//  { 0x12E93, "" },
//  { 0x12E94, "" },
//  { 0x12E95, "" },
//  { 0x12E96, "" },
//  { 0x12E97, "" },
//  { 0x12E98, "" },
//  { 0x12E99, "" },
//  { 0x12E9A, "" },
//  { 0x12E9B, "" },
//  { 0x12E9C, "" },
//  { 0x12E9D, "" },
//  { 0x12E9E, "" },
//  { 0x12E9F, "" },
//  { 0x12EA0, "" },
//  { 0x12EA1, "" },
//  { 0x12EA2, "" },
//  { 0x12EA3, "" },
//  { 0x12EA4, "" },
//  { 0x12EA5, "" },
//  { 0x12EA6, "" },
//  { 0x12EA7, "" },
//  { 0x12EA8, "" },
//  { 0x12EA9, "" },
//  { 0x12EAA, "" },
//  { 0x12EAB, "" },
//  { 0x12EAC, "" },
//  { 0x12EAD, "" },
//  { 0x12EAE, "" },
//  { 0x12EAF, "" },
//  { 0x12EB0, "" },
//  { 0x12EB1, "" },
//  { 0x12EB2, "" },
//  { 0x12EB3, "" },
//  { 0x12EB4, "" },
//  { 0x12EB5, "" },
//  { 0x12EB6, "" },
//  { 0x12EB7, "" },
//  { 0x12EB8, "" },
//  { 0x12EB9, "" },
//  { 0x12EBA, "" },
//  { 0x12EBB, "" },
//  { 0x12EBC, "" },
//  { 0x12EBD, "" },
//  { 0x12EBE, "" },
//  { 0x12EBF, "" },
//  { 0x12EC0, "" },
//  { 0x12EC1, "" },
//  { 0x12EC2, "" },
//  { 0x12EC3, "" },
//  { 0x12EC4, "" },
//  { 0x12EC5, "" },
//  { 0x12EC6, "" },
//  { 0x12EC7, "" },
//  { 0x12EC8, "" },
//  { 0x12EC9, "" },
//  { 0x12ECA, "" },
//  { 0x12ECB, "" },
//  { 0x12ECC, "" },
//  { 0x12ECD, "" },
//  { 0x12ECE, "" },
//  { 0x12ECF, "" },
//  { 0x12ED0, "" },
//  { 0x12ED1, "" },
//  { 0x12ED2, "" },
//  { 0x12ED3, "" },
//  { 0x12ED4, "" },
//  { 0x12ED5, "" },
//  { 0x12ED6, "" },
//  { 0x12ED7, "" },
//  { 0x12ED8, "" },
//  { 0x12ED9, "" },
//  { 0x12EDA, "" },
//  { 0x12EDB, "" },
//  { 0x12EDC, "" },
//  { 0x12EDD, "" },
//  { 0x12EDE, "" },
//  { 0x12EDF, "" },
//  { 0x12EE0, "" },
//  { 0x12EE1, "" },
//  { 0x12EE2, "" },
//  { 0x12EE3, "" },
//  { 0x12EE4, "" },
//  { 0x12EE5, "" },
//  { 0x12EE6, "" },
//  { 0x12EE7, "" },
//  { 0x12EE8, "" },
//  { 0x12EE9, "" },
//  { 0x12EEA, "" },
//  { 0x12EEB, "" },
//  { 0x12EEC, "" },
//  { 0x12EED, "" },
//  { 0x12EEE, "" },
//  { 0x12EEF, "" },
//  { 0x12EF0, "" },
//  { 0x12EF1, "" },
//  { 0x12EF2, "" },
//  { 0x12EF3, "" },
//  { 0x12EF4, "" },
//  { 0x12EF5, "" },
//  { 0x12EF6, "" },
//  { 0x12EF7, "" },
//  { 0x12EF8, "" },
//  { 0x12EF9, "" },
//  { 0x12EFA, "" },
//  { 0x12EFB, "" },
//  { 0x12EFC, "" },
//  { 0x12EFD, "" },
//  { 0x12EFE, "" },
//  { 0x12EFF, "" },
//  { 0x12F00, "" },
//  { 0x12F01, "" },
//  { 0x12F02, "" },
//  { 0x12F03, "" },
//  { 0x12F04, "" },
//  { 0x12F05, "" },
//  { 0x12F06, "" },
//  { 0x12F07, "" },
//  { 0x12F08, "" },
//  { 0x12F09, "" },
//  { 0x12F0A, "" },
//  { 0x12F0B, "" },
//  { 0x12F0C, "" },
//  { 0x12F0D, "" },
//  { 0x12F0E, "" },
//  { 0x12F0F, "" },
//  { 0x12F10, "" },
//  { 0x12F11, "" },
//  { 0x12F12, "" },
//  { 0x12F13, "" },
//  { 0x12F14, "" },
//  { 0x12F15, "" },
//  { 0x12F16, "" },
//  { 0x12F17, "" },
//  { 0x12F18, "" },
//  { 0x12F19, "" },
//  { 0x12F1A, "" },
//  { 0x12F1B, "" },
//  { 0x12F1C, "" },
//  { 0x12F1D, "" },
//  { 0x12F1E, "" },
//  { 0x12F1F, "" },
//  { 0x12F20, "" },
//  { 0x12F21, "" },
//  { 0x12F22, "" },
//  { 0x12F23, "" },
//  { 0x12F24, "" },
//  { 0x12F25, "" },
//  { 0x12F26, "" },
//  { 0x12F27, "" },
//  { 0x12F28, "" },
//  { 0x12F29, "" },
//  { 0x12F2A, "" },
//  { 0x12F2B, "" },
//  { 0x12F2C, "" },
//  { 0x12F2D, "" },
//  { 0x12F2E, "" },
//  { 0x12F2F, "" },
//  { 0x12F30, "" },
//  { 0x12F31, "" },
//  { 0x12F32, "" },
//  { 0x12F33, "" },
//  { 0x12F34, "" },
//  { 0x12F35, "" },
//  { 0x12F36, "" },
//  { 0x12F37, "" },
//  { 0x12F38, "" },
//  { 0x12F39, "" },
//  { 0x12F3A, "" },
//  { 0x12F3B, "" },
//  { 0x12F3C, "" },
//  { 0x12F3D, "" },
//  { 0x12F3E, "" },
//  { 0x12F3F, "" },
//  { 0x12F40, "" },
//  { 0x12F41, "" },
//  { 0x12F42, "" },
//  { 0x12F43, "" },
//  { 0x12F44, "" },
//  { 0x12F45, "" },
//  { 0x12F46, "" },
//  { 0x12F47, "" },
//  { 0x12F48, "" },
//  { 0x12F49, "" },
//  { 0x12F4A, "" },
//  { 0x12F4B, "" },
//  { 0x12F4C, "" },
//  { 0x12F4D, "" },
//  { 0x12F4E, "" },
//  { 0x12F4F, "" },
//  { 0x12F50, "" },
//  { 0x12F51, "" },
//  { 0x12F52, "" },
//  { 0x12F53, "" },
//  { 0x12F54, "" },
//  { 0x12F55, "" },
//  { 0x12F56, "" },
//  { 0x12F57, "" },
//  { 0x12F58, "" },
//  { 0x12F59, "" },
//  { 0x12F5A, "" },
//  { 0x12F5B, "" },
//  { 0x12F5C, "" },
//  { 0x12F5D, "" },
//  { 0x12F5E, "" },
//  { 0x12F5F, "" },
//  { 0x12F60, "" },
//  { 0x12F61, "" },
//  { 0x12F62, "" },
//  { 0x12F63, "" },
//  { 0x12F64, "" },
//  { 0x12F65, "" },
//  { 0x12F66, "" },
//  { 0x12F67, "" },
//  { 0x12F68, "" },
//  { 0x12F69, "" },
//  { 0x12F6A, "" },
//  { 0x12F6B, "" },
//  { 0x12F6C, "" },
//  { 0x12F6D, "" },
//  { 0x12F6E, "" },
//  { 0x12F6F, "" },
//  { 0x12F70, "" },
//  { 0x12F71, "" },
//  { 0x12F72, "" },
//  { 0x12F73, "" },
//  { 0x12F74, "" },
//  { 0x12F75, "" },
//  { 0x12F76, "" },
//  { 0x12F77, "" },
//  { 0x12F78, "" },
//  { 0x12F79, "" },
//  { 0x12F7A, "" },
//  { 0x12F7B, "" },
//  { 0x12F7C, "" },
//  { 0x12F7D, "" },
//  { 0x12F7E, "" },
//  { 0x12F7F, "" },
//  { 0x12F80, "" },
//  { 0x12F81, "" },
//  { 0x12F82, "" },
//  { 0x12F83, "" },
//  { 0x12F84, "" },
//  { 0x12F85, "" },
//  { 0x12F86, "" },
//  { 0x12F87, "" },
//  { 0x12F88, "" },
//  { 0x12F89, "" },
//  { 0x12F8A, "" },
//  { 0x12F8B, "" },
//  { 0x12F8C, "" },
//  { 0x12F8D, "" },
//  { 0x12F8E, "" },
//  { 0x12F8F, "" },
//  { 0x12F90, "" },
//  { 0x12F91, "" },
//  { 0x12F92, "" },
//  { 0x12F93, "" },
//  { 0x12F94, "" },
//  { 0x12F95, "" },
//  { 0x12F96, "" },
//  { 0x12F97, "" },
//  { 0x12F98, "" },
//  { 0x12F99, "" },
//  { 0x12F9A, "" },
//  { 0x12F9B, "" },
//  { 0x12F9C, "" },
//  { 0x12F9D, "" },
//  { 0x12F9E, "" },
//  { 0x12F9F, "" },
//  { 0x12FA0, "" },
//  { 0x12FA1, "" },
//  { 0x12FA2, "" },
//  { 0x12FA3, "" },
//  { 0x12FA4, "" },
//  { 0x12FA5, "" },
//  { 0x12FA6, "" },
//  { 0x12FA7, "" },
//  { 0x12FA8, "" },
//  { 0x12FA9, "" },
//  { 0x12FAA, "" },
//  { 0x12FAB, "" },
//  { 0x12FAC, "" },
//  { 0x12FAD, "" },
//  { 0x12FAE, "" },
//  { 0x12FAF, "" },
//  { 0x12FB0, "" },
//  { 0x12FB1, "" },
//  { 0x12FB2, "" },
//  { 0x12FB3, "" },
//  { 0x12FB4, "" },
//  { 0x12FB5, "" },
//  { 0x12FB6, "" },
//  { 0x12FB7, "" },
//  { 0x12FB8, "" },
//  { 0x12FB9, "" },
//  { 0x12FBA, "" },
//  { 0x12FBB, "" },
//  { 0x12FBC, "" },
//  { 0x12FBD, "" },
//  { 0x12FBE, "" },
//  { 0x12FBF, "" },
//  { 0x12FC0, "" },
//  { 0x12FC1, "" },
//  { 0x12FC2, "" },
//  { 0x12FC3, "" },
//  { 0x12FC4, "" },
//  { 0x12FC5, "" },
//  { 0x12FC6, "" },
//  { 0x12FC7, "" },
//  { 0x12FC8, "" },
//  { 0x12FC9, "" },
//  { 0x12FCA, "" },
//  { 0x12FCB, "" },
//  { 0x12FCC, "" },
//  { 0x12FCD, "" },
//  { 0x12FCE, "" },
//  { 0x12FCF, "" },
//  { 0x12FD0, "" },
//  { 0x12FD1, "" },
//  { 0x12FD2, "" },
//  { 0x12FD3, "" },
//  { 0x12FD4, "" },
//  { 0x12FD5, "" },
//  { 0x12FD6, "" },
//  { 0x12FD7, "" },
//  { 0x12FD8, "" },
//  { 0x12FD9, "" },
//  { 0x12FDA, "" },
//  { 0x12FDB, "" },
//  { 0x12FDC, "" },
//  { 0x12FDD, "" },
//  { 0x12FDE, "" },
//  { 0x12FDF, "" },
//  { 0x12FE0, "" },
//  { 0x12FE1, "" },
//  { 0x12FE2, "" },
//  { 0x12FE3, "" },
//  { 0x12FE4, "" },
//  { 0x12FE5, "" },
//  { 0x12FE6, "" },
//  { 0x12FE7, "" },
//  { 0x12FE8, "" },
//  { 0x12FE9, "" },
//  { 0x12FEA, "" },
//  { 0x12FEB, "" },
//  { 0x12FEC, "" },
//  { 0x12FED, "" },
//  { 0x12FEE, "" },
//  { 0x12FEF, "" },
//  { 0x12FF0, "" },
//  { 0x12FF1, "" },
//  { 0x12FF2, "" },
//  { 0x12FF3, "" },
//  { 0x12FF4, "" },
//  { 0x12FF5, "" },
//  { 0x12FF6, "" },
//  { 0x12FF7, "" },
//  { 0x12FF8, "" },
//  { 0x12FF9, "" },
//  { 0x12FFA, "" },
//  { 0x12FFB, "" },
//  { 0x12FFC, "" },
//  { 0x12FFD, "" },
//  { 0x12FFE, "" },
//  { 0x12FFF, "" },
//  { 0x13000, "" },
//  { 0x13001, "" },
//  { 0x13002, "" },
//  { 0x13003, "" },
//  { 0x13004, "" },
//  { 0x13005, "" },
//  { 0x13006, "" },
//  { 0x13007, "" },
//  { 0x13008, "" },
//  { 0x13009, "" },
//  { 0x1300A, "" },
//  { 0x1300B, "" },
//  { 0x1300C, "" },
//  { 0x1300D, "" },
//  { 0x1300E, "" },
//  { 0x1300F, "" },
//  { 0x13010, "" },
//  { 0x13011, "" },
//  { 0x13012, "" },
//  { 0x13013, "" },
//  { 0x13014, "" },
//  { 0x13015, "" },
//  { 0x13016, "" },
//  { 0x13017, "" },
//  { 0x13018, "" },
//  { 0x13019, "" },
//  { 0x1301A, "" },
//  { 0x1301B, "" },
//  { 0x1301C, "" },
//  { 0x1301D, "" },
//  { 0x1301E, "" },
//  { 0x1301F, "" },
//  { 0x13020, "" },
//  { 0x13021, "" },
//  { 0x13022, "" },
//  { 0x13023, "" },
//  { 0x13024, "" },
//  { 0x13025, "" },
//  { 0x13026, "" },
//  { 0x13027, "" },
//  { 0x13028, "" },
//  { 0x13029, "" },
//  { 0x1302A, "" },
//  { 0x1302B, "" },
//  { 0x1302C, "" },
//  { 0x1302D, "" },
//  { 0x1302E, "" },
//  { 0x1302F, "" },
//  { 0x13030, "" },
//  { 0x13031, "" },
//  { 0x13032, "" },
//  { 0x13033, "" },
//  { 0x13034, "" },
//  { 0x13035, "" },
//  { 0x13036, "" },
//  { 0x13037, "" },
//  { 0x13038, "" },
//  { 0x13039, "" },
//  { 0x1303A, "" },
//  { 0x1303B, "" },
//  { 0x1303C, "" },
//  { 0x1303D, "" },
//  { 0x1303E, "" },
//  { 0x1303F, "" },
//  { 0x13040, "" },
//  { 0x13041, "" },
//  { 0x13042, "" },
//  { 0x13043, "" },
//  { 0x13044, "" },
//  { 0x13045, "" },
//  { 0x13046, "" },
//  { 0x13047, "" },
//  { 0x13048, "" },
//  { 0x13049, "" },
//  { 0x1304A, "" },
//  { 0x1304B, "" },
//  { 0x1304C, "" },
//  { 0x1304D, "" },
//  { 0x1304E, "" },
//  { 0x1304F, "" },
//  { 0x13050, "" },
//  { 0x13051, "" },
//  { 0x13052, "" },
//  { 0x13053, "" },
//  { 0x13054, "" },
//  { 0x13055, "" },
//  { 0x13056, "" },
//  { 0x13057, "" },
//  { 0x13058, "" },
//  { 0x13059, "" },
//  { 0x1305A, "" },
//  { 0x1305B, "" },
//  { 0x1305C, "" },
//  { 0x1305D, "" },
//  { 0x1305E, "" },
//  { 0x1305F, "" },
//  { 0x13060, "" },
//  { 0x13061, "" },
//  { 0x13062, "" },
//  { 0x13063, "" },
//  { 0x13064, "" },
//  { 0x13065, "" },
//  { 0x13066, "" },
//  { 0x13067, "" },
//  { 0x13068, "" },
//  { 0x13069, "" },
//  { 0x1306A, "" },
//  { 0x1306B, "" },
//  { 0x1306C, "" },
//  { 0x1306D, "" },
//  { 0x1306E, "" },
//  { 0x1306F, "" },
//  { 0x13070, "" },
//  { 0x13071, "" },
//  { 0x13072, "" },
//  { 0x13073, "" },
//  { 0x13074, "" },
//  { 0x13075, "" },
//  { 0x13076, "" },
//  { 0x13077, "" },
//  { 0x13078, "" },
//  { 0x13079, "" },
//  { 0x1307A, "" },
//  { 0x1307B, "" },
//  { 0x1307C, "" },
//  { 0x1307D, "" },
//  { 0x1307E, "" },
//  { 0x1307F, "" },
//  { 0x13080, "" },
//  { 0x13081, "" },
//  { 0x13082, "" },
//  { 0x13083, "" },
//  { 0x13084, "" },
//  { 0x13085, "" },
//  { 0x13086, "" },
//  { 0x13087, "" },
//  { 0x13088, "" },
//  { 0x13089, "" },
//  { 0x1308A, "" },
//  { 0x1308B, "" },
//  { 0x1308C, "" },
//  { 0x1308D, "" },
//  { 0x1308E, "" },
//  { 0x1308F, "" },
//  { 0x13090, "" },
//  { 0x13091, "" },
//  { 0x13092, "" },
//  { 0x13093, "" },
//  { 0x13094, "" },
//  { 0x13095, "" },
//  { 0x13096, "" },
//  { 0x13097, "" },
//  { 0x13098, "" },
//  { 0x13099, "" },
//  { 0x1309A, "" },
//  { 0x1309B, "" },
//  { 0x1309C, "" },
//  { 0x1309D, "" },
//  { 0x1309E, "" },
//  { 0x1309F, "" },
//  { 0x130A0, "" },
//  { 0x130A1, "" },
//  { 0x130A2, "" },
//  { 0x130A3, "" },
//  { 0x130A4, "" },
//  { 0x130A5, "" },
//  { 0x130A6, "" },
//  { 0x130A7, "" },
//  { 0x130A8, "" },
//  { 0x130A9, "" },
//  { 0x130AA, "" },
//  { 0x130AB, "" },
//  { 0x130AC, "" },
//  { 0x130AD, "" },
//  { 0x130AE, "" },
//  { 0x130AF, "" },
//  { 0x130B0, "" },
//  { 0x130B1, "" },
//  { 0x130B2, "" },
//  { 0x130B3, "" },
//  { 0x130B4, "" },
//  { 0x130B5, "" },
//  { 0x130B6, "" },
//  { 0x130B7, "" },
//  { 0x130B8, "" },
//  { 0x130B9, "" },
//  { 0x130BA, "" },
//  { 0x130BB, "" },
//  { 0x130BC, "" },
//  { 0x130BD, "" },
//  { 0x130BE, "" },
//  { 0x130BF, "" },
//  { 0x130C0, "" },
//  { 0x130C1, "" },
//  { 0x130C2, "" },
//  { 0x130C3, "" },
//  { 0x130C4, "" },
//  { 0x130C5, "" },
//  { 0x130C6, "" },
//  { 0x130C7, "" },
//  { 0x130C8, "" },
//  { 0x130C9, "" },
//  { 0x130CA, "" },
//  { 0x130CB, "" },
//  { 0x130CC, "" },
//  { 0x130CD, "" },
//  { 0x130CE, "" },
//  { 0x130CF, "" },
//  { 0x130D0, "" },
//  { 0x130D1, "" },
//  { 0x130D2, "" },
//  { 0x130D3, "" },
//  { 0x130D4, "" },
//  { 0x130D5, "" },
//  { 0x130D6, "" },
//  { 0x130D7, "" },
//  { 0x130D8, "" },
//  { 0x130D9, "" },
//  { 0x130DA, "" },
//  { 0x130DB, "" },
//  { 0x130DC, "" },
//  { 0x130DD, "" },
//  { 0x130DE, "" },
//  { 0x130DF, "" },
//  { 0x130E0, "" },
//  { 0x130E1, "" },
//  { 0x130E2, "" },
//  { 0x130E3, "" },
//  { 0x130E4, "" },
//  { 0x130E5, "" },
//  { 0x130E6, "" },
//  { 0x130E7, "" },
//  { 0x130E8, "" },
//  { 0x130E9, "" },
//  { 0x130EA, "" },
//  { 0x130EB, "" },
//  { 0x130EC, "" },
//  { 0x130ED, "" },
//  { 0x130EE, "" },
//  { 0x130EF, "" },
//  { 0x130F0, "" },
//  { 0x130F1, "" },
//  { 0x130F2, "" },
//  { 0x130F3, "" },
//  { 0x130F4, "" },
//  { 0x130F5, "" },
//  { 0x130F6, "" },
//  { 0x130F7, "" },
//  { 0x130F8, "" },
//  { 0x130F9, "" },
//  { 0x130FA, "" },
//  { 0x130FB, "" },
//  { 0x130FC, "" },
//  { 0x130FD, "" },
//  { 0x130FE, "" },
//  { 0x130FF, "" },
//  { 0x13100, "" },
//  { 0x13101, "" },
//  { 0x13102, "" },
//  { 0x13103, "" },
//  { 0x13104, "" },
//  { 0x13105, "" },
//  { 0x13106, "" },
//  { 0x13107, "" },
//  { 0x13108, "" },
//  { 0x13109, "" },
//  { 0x1310A, "" },
//  { 0x1310B, "" },
//  { 0x1310C, "" },
//  { 0x1310D, "" },
//  { 0x1310E, "" },
//  { 0x1310F, "" },
//  { 0x13110, "" },
//  { 0x13111, "" },
//  { 0x13112, "" },
//  { 0x13113, "" },
//  { 0x13114, "" },
//  { 0x13115, "" },
//  { 0x13116, "" },
//  { 0x13117, "" },
//  { 0x13118, "" },
//  { 0x13119, "" },
//  { 0x1311A, "" },
//  { 0x1311B, "" },
//  { 0x1311C, "" },
//  { 0x1311D, "" },
//  { 0x1311E, "" },
//  { 0x1311F, "" },
//  { 0x13120, "" },
//  { 0x13121, "" },
//  { 0x13122, "" },
//  { 0x13123, "" },
//  { 0x13124, "" },
//  { 0x13125, "" },
//  { 0x13126, "" },
//  { 0x13127, "" },
//  { 0x13128, "" },
//  { 0x13129, "" },
//  { 0x1312A, "" },
//  { 0x1312B, "" },
//  { 0x1312C, "" },
//  { 0x1312D, "" },
//  { 0x1312E, "" },
//  { 0x1312F, "" },
//  { 0x13130, "" },
//  { 0x13131, "" },
//  { 0x13132, "" },
//  { 0x13133, "" },
//  { 0x13134, "" },
//  { 0x13135, "" },
//  { 0x13136, "" },
//  { 0x13137, "" },
//  { 0x13138, "" },
//  { 0x13139, "" },
//  { 0x1313A, "" },
//  { 0x1313B, "" },
//  { 0x1313C, "" },
//  { 0x1313D, "" },
//  { 0x1313E, "" },
//  { 0x1313F, "" },
//  { 0x13140, "" },
//  { 0x13141, "" },
//  { 0x13142, "" },
//  { 0x13143, "" },
//  { 0x13144, "" },
//  { 0x13145, "" },
//  { 0x13146, "" },
//  { 0x13147, "" },
//  { 0x13148, "" },
//  { 0x13149, "" },
//  { 0x1314A, "" },
//  { 0x1314B, "" },
//  { 0x1314C, "" },
//  { 0x1314D, "" },
//  { 0x1314E, "" },
//  { 0x1314F, "" },
//  { 0x13150, "" },
//  { 0x13151, "" },
//  { 0x13152, "" },
//  { 0x13153, "" },
//  { 0x13154, "" },
//  { 0x13155, "" },
//  { 0x13156, "" },
//  { 0x13157, "" },
//  { 0x13158, "" },
//  { 0x13159, "" },
//  { 0x1315A, "" },
//  { 0x1315B, "" },
//  { 0x1315C, "" },
//  { 0x1315D, "" },
//  { 0x1315E, "" },
//  { 0x1315F, "" },
//  { 0x13160, "" },
//  { 0x13161, "" },
//  { 0x13162, "" },
//  { 0x13163, "" },
//  { 0x13164, "" },
//  { 0x13165, "" },
//  { 0x13166, "" },
//  { 0x13167, "" },
//  { 0x13168, "" },
//  { 0x13169, "" },
//  { 0x1316A, "" },
//  { 0x1316B, "" },
//  { 0x1316C, "" },
//  { 0x1316D, "" },
//  { 0x1316E, "" },
//  { 0x1316F, "" },
//  { 0x13170, "" },
//  { 0x13171, "" },
//  { 0x13172, "" },
//  { 0x13173, "" },
//  { 0x13174, "" },
//  { 0x13175, "" },
//  { 0x13176, "" },
//  { 0x13177, "" },
//  { 0x13178, "" },
//  { 0x13179, "" },
//  { 0x1317A, "" },
//  { 0x1317B, "" },
//  { 0x1317C, "" },
//  { 0x1317D, "" },
//  { 0x1317E, "" },
//  { 0x1317F, "" },
//  { 0x13180, "" },
//  { 0x13181, "" },
//  { 0x13182, "" },
//  { 0x13183, "" },
//  { 0x13184, "" },
//  { 0x13185, "" },
//  { 0x13186, "" },
//  { 0x13187, "" },
//  { 0x13188, "" },
//  { 0x13189, "" },
//  { 0x1318A, "" },
//  { 0x1318B, "" },
//  { 0x1318C, "" },
//  { 0x1318D, "" },
//  { 0x1318E, "" },
//  { 0x1318F, "" },
//  { 0x13190, "" },
//  { 0x13191, "" },
//  { 0x13192, "" },
//  { 0x13193, "" },
//  { 0x13194, "" },
//  { 0x13195, "" },
//  { 0x13196, "" },
//  { 0x13197, "" },
//  { 0x13198, "" },
//  { 0x13199, "" },
//  { 0x1319A, "" },
//  { 0x1319B, "" },
//  { 0x1319C, "" },
//  { 0x1319D, "" },
//  { 0x1319E, "" },
//  { 0x1319F, "" },
//  { 0x131A0, "" },
//  { 0x131A1, "" },
//  { 0x131A2, "" },
//  { 0x131A3, "" },
//  { 0x131A4, "" },
//  { 0x131A5, "" },
//  { 0x131A6, "" },
//  { 0x131A7, "" },
//  { 0x131A8, "" },
//  { 0x131A9, "" },
//  { 0x131AA, "" },
//  { 0x131AB, "" },
//  { 0x131AC, "" },
//  { 0x131AD, "" },
//  { 0x131AE, "" },
//  { 0x131AF, "" },
//  { 0x131B0, "" },
//  { 0x131B1, "" },
//  { 0x131B2, "" },
//  { 0x131B3, "" },
//  { 0x131B4, "" },
//  { 0x131B5, "" },
//  { 0x131B6, "" },
//  { 0x131B7, "" },
//  { 0x131B8, "" },
//  { 0x131B9, "" },
//  { 0x131BA, "" },
//  { 0x131BB, "" },
//  { 0x131BC, "" },
//  { 0x131BD, "" },
//  { 0x131BE, "" },
//  { 0x131BF, "" },
//  { 0x131C0, "" },
//  { 0x131C1, "" },
//  { 0x131C2, "" },
//  { 0x131C3, "" },
//  { 0x131C4, "" },
//  { 0x131C5, "" },
//  { 0x131C6, "" },
//  { 0x131C7, "" },
//  { 0x131C8, "" },
//  { 0x131C9, "" },
//  { 0x131CA, "" },
//  { 0x131CB, "" },
//  { 0x131CC, "" },
//  { 0x131CD, "" },
//  { 0x131CE, "" },
//  { 0x131CF, "" },
//  { 0x131D0, "" },
//  { 0x131D1, "" },
//  { 0x131D2, "" },
//  { 0x131D3, "" },
//  { 0x131D4, "" },
//  { 0x131D5, "" },
//  { 0x131D6, "" },
//  { 0x131D7, "" },
//  { 0x131D8, "" },
//  { 0x131D9, "" },
//  { 0x131DA, "" },
//  { 0x131DB, "" },
//  { 0x131DC, "" },
//  { 0x131DD, "" },
//  { 0x131DE, "" },
//  { 0x131DF, "" },
//  { 0x131E0, "" },
//  { 0x131E1, "" },
//  { 0x131E2, "" },
//  { 0x131E3, "" },
//  { 0x131E4, "" },
//  { 0x131E5, "" },
//  { 0x131E6, "" },
//  { 0x131E7, "" },
//  { 0x131E8, "" },
//  { 0x131E9, "" },
//  { 0x131EA, "" },
//  { 0x131EB, "" },
//  { 0x131EC, "" },
//  { 0x131ED, "" },
//  { 0x131EE, "" },
//  { 0x131EF, "" },
//  { 0x131F0, "" },
//  { 0x131F1, "" },
//  { 0x131F2, "" },
//  { 0x131F3, "" },
//  { 0x131F4, "" },
//  { 0x131F5, "" },
//  { 0x131F6, "" },
//  { 0x131F7, "" },
//  { 0x131F8, "" },
//  { 0x131F9, "" },
//  { 0x131FA, "" },
//  { 0x131FB, "" },
//  { 0x131FC, "" },
//  { 0x131FD, "" },
//  { 0x131FE, "" },
//  { 0x131FF, "" },
//  { 0x13200, "" },
//  { 0x13201, "" },
//  { 0x13202, "" },
//  { 0x13203, "" },
//  { 0x13204, "" },
//  { 0x13205, "" },
//  { 0x13206, "" },
//  { 0x13207, "" },
//  { 0x13208, "" },
//  { 0x13209, "" },
//  { 0x1320A, "" },
//  { 0x1320B, "" },
//  { 0x1320C, "" },
//  { 0x1320D, "" },
//  { 0x1320E, "" },
//  { 0x1320F, "" },
//  { 0x13210, "" },
//  { 0x13211, "" },
//  { 0x13212, "" },
//  { 0x13213, "" },
//  { 0x13214, "" },
//  { 0x13215, "" },
//  { 0x13216, "" },
//  { 0x13217, "" },
//  { 0x13218, "" },
//  { 0x13219, "" },
//  { 0x1321A, "" },
//  { 0x1321B, "" },
//  { 0x1321C, "" },
//  { 0x1321D, "" },
//  { 0x1321E, "" },
//  { 0x1321F, "" },
//  { 0x13220, "" },
//  { 0x13221, "" },
//  { 0x13222, "" },
//  { 0x13223, "" },
//  { 0x13224, "" },
//  { 0x13225, "" },
//  { 0x13226, "" },
//  { 0x13227, "" },
//  { 0x13228, "" },
//  { 0x13229, "" },
//  { 0x1322A, "" },
//  { 0x1322B, "" },
//  { 0x1322C, "" },
//  { 0x1322D, "" },
//  { 0x1322E, "" },
//  { 0x1322F, "" },
//  { 0x13230, "" },
//  { 0x13231, "" },
//  { 0x13232, "" },
//  { 0x13233, "" },
//  { 0x13234, "" },
//  { 0x13235, "" },
//  { 0x13236, "" },
//  { 0x13237, "" },
//  { 0x13238, "" },
//  { 0x13239, "" },
//  { 0x1323A, "" },
//  { 0x1323B, "" },
//  { 0x1323C, "" },
//  { 0x1323D, "" },
//  { 0x1323E, "" },
//  { 0x1323F, "" },
//  { 0x13240, "" },
//  { 0x13241, "" },
//  { 0x13242, "" },
//  { 0x13243, "" },
//  { 0x13244, "" },
//  { 0x13245, "" },
//  { 0x13246, "" },
//  { 0x13247, "" },
//  { 0x13248, "" },
//  { 0x13249, "" },
//  { 0x1324A, "" },
//  { 0x1324B, "" },
//  { 0x1324C, "" },
//  { 0x1324D, "" },
//  { 0x1324E, "" },
//  { 0x1324F, "" },
//  { 0x13250, "" },
//  { 0x13251, "" },
//  { 0x13252, "" },
//  { 0x13253, "" },
//  { 0x13254, "" },
//  { 0x13255, "" },
//  { 0x13256, "" },
//  { 0x13257, "" },
//  { 0x13258, "" },
//  { 0x13259, "" },
//  { 0x1325A, "" },
//  { 0x1325B, "" },
//  { 0x1325C, "" },
//  { 0x1325D, "" },
//  { 0x1325E, "" },
//  { 0x1325F, "" },
//  { 0x13260, "" },
//  { 0x13261, "" },
//  { 0x13262, "" },
//  { 0x13263, "" },
//  { 0x13264, "" },
//  { 0x13265, "" },
//  { 0x13266, "" },
//  { 0x13267, "" },
//  { 0x13268, "" },
//  { 0x13269, "" },
//  { 0x1326A, "" },
//  { 0x1326B, "" },
//  { 0x1326C, "" },
//  { 0x1326D, "" },
//  { 0x1326E, "" },
//  { 0x1326F, "" },
//  { 0x13270, "" },
//  { 0x13271, "" },
//  { 0x13272, "" },
//  { 0x13273, "" },
//  { 0x13274, "" },
//  { 0x13275, "" },
//  { 0x13276, "" },
//  { 0x13277, "" },
//  { 0x13278, "" },
//  { 0x13279, "" },
//  { 0x1327A, "" },
//  { 0x1327B, "" },
//  { 0x1327C, "" },
//  { 0x1327D, "" },
//  { 0x1327E, "" },
//  { 0x1327F, "" },
//  { 0x13280, "" },
//  { 0x13281, "" },
//  { 0x13282, "" },
//  { 0x13283, "" },
//  { 0x13284, "" },
//  { 0x13285, "" },
//  { 0x13286, "" },
//  { 0x13287, "" },
//  { 0x13288, "" },
//  { 0x13289, "" },
//  { 0x1328A, "" },
//  { 0x1328B, "" },
//  { 0x1328C, "" },
//  { 0x1328D, "" },
//  { 0x1328E, "" },
//  { 0x1328F, "" },
//  { 0x13290, "" },
//  { 0x13291, "" },
//  { 0x13292, "" },
//  { 0x13293, "" },
//  { 0x13294, "" },
//  { 0x13295, "" },
//  { 0x13296, "" },
//  { 0x13297, "" },
//  { 0x13298, "" },
//  { 0x13299, "" },
//  { 0x1329A, "" },
//  { 0x1329B, "" },
//  { 0x1329C, "" },
//  { 0x1329D, "" },
//  { 0x1329E, "" },
//  { 0x1329F, "" },
//  { 0x132A0, "" },
//  { 0x132A1, "" },
//  { 0x132A2, "" },
//  { 0x132A3, "" },
//  { 0x132A4, "" },
//  { 0x132A5, "" },
//  { 0x132A6, "" },
//  { 0x132A7, "" },
//  { 0x132A8, "" },
//  { 0x132A9, "" },
//  { 0x132AA, "" },
//  { 0x132AB, "" },
//  { 0x132AC, "" },
//  { 0x132AD, "" },
//  { 0x132AE, "" },
//  { 0x132AF, "" },
//  { 0x132B0, "" },
//  { 0x132B1, "" },
//  { 0x132B2, "" },
//  { 0x132B3, "" },
//  { 0x132B4, "" },
//  { 0x132B5, "" },
//  { 0x132B6, "" },
//  { 0x132B7, "" },
//  { 0x132B8, "" },
//  { 0x132B9, "" },
//  { 0x132BA, "" },
//  { 0x132BB, "" },
//  { 0x132BC, "" },
//  { 0x132BD, "" },
//  { 0x132BE, "" },
//  { 0x132BF, "" },
//  { 0x132C0, "" },
//  { 0x132C1, "" },
//  { 0x132C2, "" },
//  { 0x132C3, "" },
//  { 0x132C4, "" },
//  { 0x132C5, "" },
//  { 0x132C6, "" },
//  { 0x132C7, "" },
//  { 0x132C8, "" },
//  { 0x132C9, "" },
//  { 0x132CA, "" },
//  { 0x132CB, "" },
//  { 0x132CC, "" },
//  { 0x132CD, "" },
//  { 0x132CE, "" },
//  { 0x132CF, "" },
//  { 0x132D0, "" },
//  { 0x132D1, "" },
//  { 0x132D2, "" },
//  { 0x132D3, "" },
//  { 0x132D4, "" },
//  { 0x132D5, "" },
//  { 0x132D6, "" },
//  { 0x132D7, "" },
//  { 0x132D8, "" },
//  { 0x132D9, "" },
//  { 0x132DA, "" },
//  { 0x132DB, "" },
//  { 0x132DC, "" },
//  { 0x132DD, "" },
//  { 0x132DE, "" },
//  { 0x132DF, "" },
//  { 0x132E0, "" },
//  { 0x132E1, "" },
//  { 0x132E2, "" },
//  { 0x132E3, "" },
//  { 0x132E4, "" },
//  { 0x132E5, "" },
//  { 0x132E6, "" },
//  { 0x132E7, "" },
//  { 0x132E8, "" },
//  { 0x132E9, "" },
//  { 0x132EA, "" },
//  { 0x132EB, "" },
//  { 0x132EC, "" },
//  { 0x132ED, "" },
//  { 0x132EE, "" },
//  { 0x132EF, "" },
//  { 0x132F0, "" },
//  { 0x132F1, "" },
//  { 0x132F2, "" },
//  { 0x132F3, "" },
//  { 0x132F4, "" },
//  { 0x132F5, "" },
//  { 0x132F6, "" },
//  { 0x132F7, "" },
//  { 0x132F8, "" },
//  { 0x132F9, "" },
//  { 0x132FA, "" },
//  { 0x132FB, "" },
//  { 0x132FC, "" },
//  { 0x132FD, "" },
//  { 0x132FE, "" },
//  { 0x132FF, "" },
//  { 0x13300, "" },
//  { 0x13301, "" },
//  { 0x13302, "" },
//  { 0x13303, "" },
//  { 0x13304, "" },
//  { 0x13305, "" },
//  { 0x13306, "" },
//  { 0x13307, "" },
//  { 0x13308, "" },
//  { 0x13309, "" },
//  { 0x1330A, "" },
//  { 0x1330B, "" },
//  { 0x1330C, "" },
//  { 0x1330D, "" },
//  { 0x1330E, "" },
//  { 0x1330F, "" },
//  { 0x13310, "" },
//  { 0x13311, "" },
//  { 0x13312, "" },
//  { 0x13313, "" },
//  { 0x13314, "" },
//  { 0x13315, "" },
//  { 0x13316, "" },
//  { 0x13317, "" },
//  { 0x13318, "" },
//  { 0x13319, "" },
//  { 0x1331A, "" },
//  { 0x1331B, "" },
//  { 0x1331C, "" },
//  { 0x1331D, "" },
//  { 0x1331E, "" },
//  { 0x1331F, "" },
//  { 0x13320, "" },
//  { 0x13321, "" },
//  { 0x13322, "" },
//  { 0x13323, "" },
//  { 0x13324, "" },
//  { 0x13325, "" },
//  { 0x13326, "" },
//  { 0x13327, "" },
//  { 0x13328, "" },
//  { 0x13329, "" },
//  { 0x1332A, "" },
//  { 0x1332B, "" },
//  { 0x1332C, "" },
//  { 0x1332D, "" },
//  { 0x1332E, "" },
//  { 0x1332F, "" },
//  { 0x13330, "" },
//  { 0x13331, "" },
//  { 0x13332, "" },
//  { 0x13333, "" },
//  { 0x13334, "" },
//  { 0x13335, "" },
//  { 0x13336, "" },
//  { 0x13337, "" },
//  { 0x13338, "" },
//  { 0x13339, "" },
//  { 0x1333A, "" },
//  { 0x1333B, "" },
//  { 0x1333C, "" },
//  { 0x1333D, "" },
//  { 0x1333E, "" },
//  { 0x1333F, "" },
//  { 0x13340, "" },
//  { 0x13341, "" },
//  { 0x13342, "" },
//  { 0x13343, "" },
//  { 0x13344, "" },
//  { 0x13345, "" },
//  { 0x13346, "" },
//  { 0x13347, "" },
//  { 0x13348, "" },
//  { 0x13349, "" },
//  { 0x1334A, "" },
//  { 0x1334B, "" },
//  { 0x1334C, "" },
//  { 0x1334D, "" },
//  { 0x1334E, "" },
//  { 0x1334F, "" },
//  { 0x13350, "" },
//  { 0x13351, "" },
//  { 0x13352, "" },
//  { 0x13353, "" },
//  { 0x13354, "" },
//  { 0x13355, "" },
//  { 0x13356, "" },
//  { 0x13357, "" },
//  { 0x13358, "" },
//  { 0x13359, "" },
//  { 0x1335A, "" },
//  { 0x1335B, "" },
//  { 0x1335C, "" },
//  { 0x1335D, "" },
//  { 0x1335E, "" },
//  { 0x1335F, "" },
//  { 0x13360, "" },
//  { 0x13361, "" },
//  { 0x13362, "" },
//  { 0x13363, "" },
//  { 0x13364, "" },
//  { 0x13365, "" },
//  { 0x13366, "" },
//  { 0x13367, "" },
//  { 0x13368, "" },
//  { 0x13369, "" },
//  { 0x1336A, "" },
//  { 0x1336B, "" },
//  { 0x1336C, "" },
//  { 0x1336D, "" },
//  { 0x1336E, "" },
//  { 0x1336F, "" },
//  { 0x13370, "" },
//  { 0x13371, "" },
//  { 0x13372, "" },
//  { 0x13373, "" },
//  { 0x13374, "" },
//  { 0x13375, "" },
//  { 0x13376, "" },
//  { 0x13377, "" },
//  { 0x13378, "" },
//  { 0x13379, "" },
//  { 0x1337A, "" },
//  { 0x1337B, "" },
//  { 0x1337C, "" },
//  { 0x1337D, "" },
//  { 0x1337E, "" },
//  { 0x1337F, "" },
//  { 0x13380, "" },
//  { 0x13381, "" },
//  { 0x13382, "" },
//  { 0x13383, "" },
//  { 0x13384, "" },
//  { 0x13385, "" },
//  { 0x13386, "" },
//  { 0x13387, "" },
//  { 0x13388, "" },
//  { 0x13389, "" },
//  { 0x1338A, "" },
//  { 0x1338B, "" },
//  { 0x1338C, "" },
//  { 0x1338D, "" },
//  { 0x1338E, "" },
//  { 0x1338F, "" },
//  { 0x13390, "" },
//  { 0x13391, "" },
//  { 0x13392, "" },
//  { 0x13393, "" },
//  { 0x13394, "" },
//  { 0x13395, "" },
//  { 0x13396, "" },
//  { 0x13397, "" },
//  { 0x13398, "" },
//  { 0x13399, "" },
//  { 0x1339A, "" },
//  { 0x1339B, "" },
//  { 0x1339C, "" },
//  { 0x1339D, "" },
//  { 0x1339E, "" },
//  { 0x1339F, "" },
//  { 0x133A0, "" },
//  { 0x133A1, "" },
//  { 0x133A2, "" },
//  { 0x133A3, "" },
//  { 0x133A4, "" },
//  { 0x133A5, "" },
//  { 0x133A6, "" },
//  { 0x133A7, "" },
//  { 0x133A8, "" },
//  { 0x133A9, "" },
//  { 0x133AA, "" },
//  { 0x133AB, "" },
//  { 0x133AC, "" },
//  { 0x133AD, "" },
//  { 0x133AE, "" },
//  { 0x133AF, "" },
//  { 0x133B0, "" },
//  { 0x133B1, "" },
//  { 0x133B2, "" },
//  { 0x133B3, "" },
//  { 0x133B4, "" },
//  { 0x133B5, "" },
//  { 0x133B6, "" },
//  { 0x133B7, "" },
//  { 0x133B8, "" },
//  { 0x133B9, "" },
//  { 0x133BA, "" },
//  { 0x133BB, "" },
//  { 0x133BC, "" },
//  { 0x133BD, "" },
//  { 0x133BE, "" },
//  { 0x133BF, "" },
//  { 0x133C0, "" },
//  { 0x133C1, "" },
//  { 0x133C2, "" },
//  { 0x133C3, "" },
//  { 0x133C4, "" },
//  { 0x133C5, "" },
//  { 0x133C6, "" },
//  { 0x133C7, "" },
//  { 0x133C8, "" },
//  { 0x133C9, "" },
//  { 0x133CA, "" },
//  { 0x133CB, "" },
//  { 0x133CC, "" },
//  { 0x133CD, "" },
//  { 0x133CE, "" },
//  { 0x133CF, "" },
//  { 0x133D0, "" },
//  { 0x133D1, "" },
//  { 0x133D2, "" },
//  { 0x133D3, "" },
//  { 0x133D4, "" },
//  { 0x133D5, "" },
//  { 0x133D6, "" },
//  { 0x133D7, "" },
//  { 0x133D8, "" },
//  { 0x133D9, "" },
//  { 0x133DA, "" },
//  { 0x133DB, "" },
//  { 0x133DC, "" },
//  { 0x133DD, "" },
//  { 0x133DE, "" },
//  { 0x133DF, "" },
//  { 0x133E0, "" },
//  { 0x133E1, "" },
//  { 0x133E2, "" },
//  { 0x133E3, "" },
//  { 0x133E4, "" },
//  { 0x133E5, "" },
//  { 0x133E6, "" },
//  { 0x133E7, "" },
//  { 0x133E8, "" },
//  { 0x133E9, "" },
//  { 0x133EA, "" },
//  { 0x133EB, "" },
//  { 0x133EC, "" },
//  { 0x133ED, "" },
//  { 0x133EE, "" },
//  { 0x133EF, "" },
//  { 0x133F0, "" },
//  { 0x133F1, "" },
//  { 0x133F2, "" },
//  { 0x133F3, "" },
//  { 0x133F4, "" },
//  { 0x133F5, "" },
//  { 0x133F6, "" },
//  { 0x133F7, "" },
//  { 0x133F8, "" },
//  { 0x133F9, "" },
//  { 0x133FA, "" },
//  { 0x133FB, "" },
//  { 0x133FC, "" },
//  { 0x133FD, "" },
//  { 0x133FE, "" },
//  { 0x133FF, "" },
//  { 0x13400, "" },
//  { 0x13401, "" },
//  { 0x13402, "" },
//  { 0x13403, "" },
//  { 0x13404, "" },
//  { 0x13405, "" },
//  { 0x13406, "" },
//  { 0x13407, "" },
//  { 0x13408, "" },
//  { 0x13409, "" },
//  { 0x1340A, "" },
//  { 0x1340B, "" },
//  { 0x1340C, "" },
//  { 0x1340D, "" },
//  { 0x1340E, "" },
//  { 0x1340F, "" },
//  { 0x13410, "" },
//  { 0x13411, "" },
//  { 0x13412, "" },
//  { 0x13413, "" },
//  { 0x13414, "" },
//  { 0x13415, "" },
//  { 0x13416, "" },
//  { 0x13417, "" },
//  { 0x13418, "" },
//  { 0x13419, "" },
//  { 0x1341A, "" },
//  { 0x1341B, "" },
//  { 0x1341C, "" },
//  { 0x1341D, "" },
//  { 0x1341E, "" },
//  { 0x1341F, "" },
//  { 0x13420, "" },
//  { 0x13421, "" },
//  { 0x13422, "" },
//  { 0x13423, "" },
//  { 0x13424, "" },
//  { 0x13425, "" },
//  { 0x13426, "" },
//  { 0x13427, "" },
//  { 0x13428, "" },
//  { 0x13429, "" },
//  { 0x1342A, "" },
//  { 0x1342B, "" },
//  { 0x1342C, "" },
//  { 0x1342D, "" },
//  { 0x1342E, "" },
//  { 0x1342F, "" },
//  { 0x13430, "" },
//  { 0x13431, "" },
//  { 0x13432, "" },
//  { 0x13433, "" },
//  { 0x13434, "" },
//  { 0x13435, "" },
//  { 0x13436, "" },
//  { 0x13437, "" },
//  { 0x13438, "" },
//  { 0x13439, "" },
//  { 0x1343A, "" },
//  { 0x1343B, "" },
//  { 0x1343C, "" },
//  { 0x1343D, "" },
//  { 0x1343E, "" },
//  { 0x1343F, "" },
//  { 0x13440, "" },
//  { 0x13441, "" },
//  { 0x13442, "" },
//  { 0x13443, "" },
//  { 0x13444, "" },
//  { 0x13445, "" },
//  { 0x13446, "" },
//  { 0x13447, "" },
//  { 0x13448, "" },
//  { 0x13449, "" },
//  { 0x1344A, "" },
//  { 0x1344B, "" },
//  { 0x1344C, "" },
//  { 0x1344D, "" },
//  { 0x1344E, "" },
//  { 0x1344F, "" },
//  { 0x13450, "" },
//  { 0x13451, "" },
//  { 0x13452, "" },
//  { 0x13453, "" },
//  { 0x13454, "" },
//  { 0x13455, "" },
//  { 0x13456, "" },
//  { 0x13457, "" },
//  { 0x13458, "" },
//  { 0x13459, "" },
//  { 0x1345A, "" },
//  { 0x1345B, "" },
//  { 0x1345C, "" },
//  { 0x1345D, "" },
//  { 0x1345E, "" },
//  { 0x1345F, "" },
//  { 0x13460, "" },
//  { 0x13461, "" },
//  { 0x13462, "" },
//  { 0x13463, "" },
//  { 0x13464, "" },
//  { 0x13465, "" },
//  { 0x13466, "" },
//  { 0x13467, "" },
//  { 0x13468, "" },
//  { 0x13469, "" },
//  { 0x1346A, "" },
//  { 0x1346B, "" },
//  { 0x1346C, "" },
//  { 0x1346D, "" },
//  { 0x1346E, "" },
//  { 0x1346F, "" },
//  { 0x13470, "" },
//  { 0x13471, "" },
//  { 0x13472, "" },
//  { 0x13473, "" },
//  { 0x13474, "" },
//  { 0x13475, "" },
//  { 0x13476, "" },
//  { 0x13477, "" },
//  { 0x13478, "" },
//  { 0x13479, "" },
//  { 0x1347A, "" },
//  { 0x1347B, "" },
//  { 0x1347C, "" },
//  { 0x1347D, "" },
//  { 0x1347E, "" },
//  { 0x1347F, "" },
//  { 0x13480, "" },
//  { 0x13481, "" },
//  { 0x13482, "" },
//  { 0x13483, "" },
//  { 0x13484, "" },
//  { 0x13485, "" },
//  { 0x13486, "" },
//  { 0x13487, "" },
//  { 0x13488, "" },
//  { 0x13489, "" },
//  { 0x1348A, "" },
//  { 0x1348B, "" },
//  { 0x1348C, "" },
//  { 0x1348D, "" },
//  { 0x1348E, "" },
//  { 0x1348F, "" },
//  { 0x13490, "" },
//  { 0x13491, "" },
//  { 0x13492, "" },
//  { 0x13493, "" },
//  { 0x13494, "" },
//  { 0x13495, "" },
//  { 0x13496, "" },
//  { 0x13497, "" },
//  { 0x13498, "" },
//  { 0x13499, "" },
//  { 0x1349A, "" },
//  { 0x1349B, "" },
//  { 0x1349C, "" },
//  { 0x1349D, "" },
//  { 0x1349E, "" },
//  { 0x1349F, "" },
//  { 0x134A0, "" },
//  { 0x134A1, "" },
//  { 0x134A2, "" },
//  { 0x134A3, "" },
//  { 0x134A4, "" },
//  { 0x134A5, "" },
//  { 0x134A6, "" },
//  { 0x134A7, "" },
//  { 0x134A8, "" },
//  { 0x134A9, "" },
//  { 0x134AA, "" },
//  { 0x134AB, "" },
//  { 0x134AC, "" },
//  { 0x134AD, "" },
//  { 0x134AE, "" },
//  { 0x134AF, "" },
//  { 0x134B0, "" },
//  { 0x134B1, "" },
//  { 0x134B2, "" },
//  { 0x134B3, "" },
//  { 0x134B4, "" },
//  { 0x134B5, "" },
//  { 0x134B6, "" },
//  { 0x134B7, "" },
//  { 0x134B8, "" },
//  { 0x134B9, "" },
//  { 0x134BA, "" },
//  { 0x134BB, "" },
//  { 0x134BC, "" },
//  { 0x134BD, "" },
//  { 0x134BE, "" },
//  { 0x134BF, "" },
//  { 0x134C0, "" },
//  { 0x134C1, "" },
//  { 0x134C2, "" },
//  { 0x134C3, "" },
//  { 0x134C4, "" },
//  { 0x134C5, "" },
//  { 0x134C6, "" },
//  { 0x134C7, "" },
//  { 0x134C8, "" },
//  { 0x134C9, "" },
//  { 0x134CA, "" },
//  { 0x134CB, "" },
//  { 0x134CC, "" },
//  { 0x134CD, "" },
//  { 0x134CE, "" },
//  { 0x134CF, "" },
//  { 0x134D0, "" },
//  { 0x134D1, "" },
//  { 0x134D2, "" },
//  { 0x134D3, "" },
//  { 0x134D4, "" },
//  { 0x134D5, "" },
//  { 0x134D6, "" },
//  { 0x134D7, "" },
//  { 0x134D8, "" },
//  { 0x134D9, "" },
//  { 0x134DA, "" },
//  { 0x134DB, "" },
//  { 0x134DC, "" },
//  { 0x134DD, "" },
//  { 0x134DE, "" },
//  { 0x134DF, "" },
//  { 0x134E0, "" },
//  { 0x134E1, "" },
//  { 0x134E2, "" },
//  { 0x134E3, "" },
//  { 0x134E4, "" },
//  { 0x134E5, "" },
//  { 0x134E6, "" },
//  { 0x134E7, "" },
//  { 0x134E8, "" },
//  { 0x134E9, "" },
//  { 0x134EA, "" },
//  { 0x134EB, "" },
//  { 0x134EC, "" },
//  { 0x134ED, "" },
//  { 0x134EE, "" },
//  { 0x134EF, "" },
//  { 0x134F0, "" },
//  { 0x134F1, "" },
//  { 0x134F2, "" },
//  { 0x134F3, "" },
//  { 0x134F4, "" },
//  { 0x134F5, "" },
//  { 0x134F6, "" },
//  { 0x134F7, "" },
//  { 0x134F8, "" },
//  { 0x134F9, "" },
//  { 0x134FA, "" },
//  { 0x134FB, "" },
//  { 0x134FC, "" },
//  { 0x134FD, "" },
//  { 0x134FE, "" },
//  { 0x134FF, "" },
//  { 0x13500, "" },
//  { 0x13501, "" },
//  { 0x13502, "" },
//  { 0x13503, "" },
//  { 0x13504, "" },
//  { 0x13505, "" },
//  { 0x13506, "" },
//  { 0x13507, "" },
//  { 0x13508, "" },
//  { 0x13509, "" },
//  { 0x1350A, "" },
//  { 0x1350B, "" },
//  { 0x1350C, "" },
//  { 0x1350D, "" },
//  { 0x1350E, "" },
//  { 0x1350F, "" },
//  { 0x13510, "" },
//  { 0x13511, "" },
//  { 0x13512, "" },
//  { 0x13513, "" },
//  { 0x13514, "" },
//  { 0x13515, "" },
//  { 0x13516, "" },
//  { 0x13517, "" },
//  { 0x13518, "" },
//  { 0x13519, "" },
//  { 0x1351A, "" },
//  { 0x1351B, "" },
//  { 0x1351C, "" },
//  { 0x1351D, "" },
//  { 0x1351E, "" },
//  { 0x1351F, "" },
//  { 0x13520, "" },
//  { 0x13521, "" },
//  { 0x13522, "" },
//  { 0x13523, "" },
//  { 0x13524, "" },
//  { 0x13525, "" },
//  { 0x13526, "" },
//  { 0x13527, "" },
//  { 0x13528, "" },
//  { 0x13529, "" },
//  { 0x1352A, "" },
//  { 0x1352B, "" },
//  { 0x1352C, "" },
//  { 0x1352D, "" },
//  { 0x1352E, "" },
//  { 0x1352F, "" },
//  { 0x13530, "" },
//  { 0x13531, "" },
//  { 0x13532, "" },
//  { 0x13533, "" },
//  { 0x13534, "" },
//  { 0x13535, "" },
//  { 0x13536, "" },
//  { 0x13537, "" },
//  { 0x13538, "" },
//  { 0x13539, "" },
//  { 0x1353A, "" },
//  { 0x1353B, "" },
//  { 0x1353C, "" },
//  { 0x1353D, "" },
//  { 0x1353E, "" },
//  { 0x1353F, "" },
//  { 0x13540, "" },
//  { 0x13541, "" },
//  { 0x13542, "" },
//  { 0x13543, "" },
//  { 0x13544, "" },
//  { 0x13545, "" },
//  { 0x13546, "" },
//  { 0x13547, "" },
//  { 0x13548, "" },
//  { 0x13549, "" },
//  { 0x1354A, "" },
//  { 0x1354B, "" },
//  { 0x1354C, "" },
//  { 0x1354D, "" },
//  { 0x1354E, "" },
//  { 0x1354F, "" },
//  { 0x13550, "" },
//  { 0x13551, "" },
//  { 0x13552, "" },
//  { 0x13553, "" },
//  { 0x13554, "" },
//  { 0x13555, "" },
//  { 0x13556, "" },
//  { 0x13557, "" },
//  { 0x13558, "" },
//  { 0x13559, "" },
//  { 0x1355A, "" },
//  { 0x1355B, "" },
//  { 0x1355C, "" },
//  { 0x1355D, "" },
//  { 0x1355E, "" },
//  { 0x1355F, "" },
//  { 0x13560, "" },
//  { 0x13561, "" },
//  { 0x13562, "" },
//  { 0x13563, "" },
//  { 0x13564, "" },
//  { 0x13565, "" },
//  { 0x13566, "" },
//  { 0x13567, "" },
//  { 0x13568, "" },
//  { 0x13569, "" },
//  { 0x1356A, "" },
//  { 0x1356B, "" },
//  { 0x1356C, "" },
//  { 0x1356D, "" },
//  { 0x1356E, "" },
//  { 0x1356F, "" },
//  { 0x13570, "" },
//  { 0x13571, "" },
//  { 0x13572, "" },
//  { 0x13573, "" },
//  { 0x13574, "" },
//  { 0x13575, "" },
//  { 0x13576, "" },
//  { 0x13577, "" },
//  { 0x13578, "" },
//  { 0x13579, "" },
//  { 0x1357A, "" },
//  { 0x1357B, "" },
//  { 0x1357C, "" },
//  { 0x1357D, "" },
//  { 0x1357E, "" },
//  { 0x1357F, "" },
//  { 0x13580, "" },
//  { 0x13581, "" },
//  { 0x13582, "" },
//  { 0x13583, "" },
//  { 0x13584, "" },
//  { 0x13585, "" },
//  { 0x13586, "" },
//  { 0x13587, "" },
//  { 0x13588, "" },
//  { 0x13589, "" },
//  { 0x1358A, "" },
//  { 0x1358B, "" },
//  { 0x1358C, "" },
//  { 0x1358D, "" },
//  { 0x1358E, "" },
//  { 0x1358F, "" },
//  { 0x13590, "" },
//  { 0x13591, "" },
//  { 0x13592, "" },
//  { 0x13593, "" },
//  { 0x13594, "" },
//  { 0x13595, "" },
//  { 0x13596, "" },
//  { 0x13597, "" },
//  { 0x13598, "" },
//  { 0x13599, "" },
//  { 0x1359A, "" },
//  { 0x1359B, "" },
//  { 0x1359C, "" },
//  { 0x1359D, "" },
//  { 0x1359E, "" },
//  { 0x1359F, "" },
//  { 0x135A0, "" },
//  { 0x135A1, "" },
//  { 0x135A2, "" },
//  { 0x135A3, "" },
//  { 0x135A4, "" },
//  { 0x135A5, "" },
//  { 0x135A6, "" },
//  { 0x135A7, "" },
//  { 0x135A8, "" },
//  { 0x135A9, "" },
//  { 0x135AA, "" },
//  { 0x135AB, "" },
//  { 0x135AC, "" },
//  { 0x135AD, "" },
//  { 0x135AE, "" },
//  { 0x135AF, "" },
//  { 0x135B0, "" },
//  { 0x135B1, "" },
//  { 0x135B2, "" },
//  { 0x135B3, "" },
//  { 0x135B4, "" },
//  { 0x135B5, "" },
//  { 0x135B6, "" },
//  { 0x135B7, "" },
//  { 0x135B8, "" },
//  { 0x135B9, "" },
//  { 0x135BA, "" },
//  { 0x135BB, "" },
//  { 0x135BC, "" },
//  { 0x135BD, "" },
//  { 0x135BE, "" },
//  { 0x135BF, "" },
//  { 0x135C0, "" },
//  { 0x135C1, "" },
//  { 0x135C2, "" },
//  { 0x135C3, "" },
//  { 0x135C4, "" },
//  { 0x135C5, "" },
//  { 0x135C6, "" },
//  { 0x135C7, "" },
//  { 0x135C8, "" },
//  { 0x135C9, "" },
//  { 0x135CA, "" },
//  { 0x135CB, "" },
//  { 0x135CC, "" },
//  { 0x135CD, "" },
//  { 0x135CE, "" },
//  { 0x135CF, "" },
//  { 0x135D0, "" },
//  { 0x135D1, "" },
//  { 0x135D2, "" },
//  { 0x135D3, "" },
//  { 0x135D4, "" },
//  { 0x135D5, "" },
//  { 0x135D6, "" },
//  { 0x135D7, "" },
//  { 0x135D8, "" },
//  { 0x135D9, "" },
//  { 0x135DA, "" },
//  { 0x135DB, "" },
//  { 0x135DC, "" },
//  { 0x135DD, "" },
//  { 0x135DE, "" },
//  { 0x135DF, "" },
//  { 0x135E0, "" },
//  { 0x135E1, "" },
//  { 0x135E2, "" },
//  { 0x135E3, "" },
//  { 0x135E4, "" },
//  { 0x135E5, "" },
//  { 0x135E6, "" },
//  { 0x135E7, "" },
//  { 0x135E8, "" },
//  { 0x135E9, "" },
//  { 0x135EA, "" },
//  { 0x135EB, "" },
//  { 0x135EC, "" },
//  { 0x135ED, "" },
//  { 0x135EE, "" },
//  { 0x135EF, "" },
//  { 0x135F0, "" },
//  { 0x135F1, "" },
//  { 0x135F2, "" },
//  { 0x135F3, "" },
//  { 0x135F4, "" },
//  { 0x135F5, "" },
//  { 0x135F6, "" },
//  { 0x135F7, "" },
//  { 0x135F8, "" },
//  { 0x135F9, "" },
//  { 0x135FA, "" },
//  { 0x135FB, "" },
//  { 0x135FC, "" },
//  { 0x135FD, "" },
//  { 0x135FE, "" },
//  { 0x135FF, "" },
//  { 0x13600, "" },
//  { 0x13601, "" },
//  { 0x13602, "" },
//  { 0x13603, "" },
//  { 0x13604, "" },
//  { 0x13605, "" },
//  { 0x13606, "" },
//  { 0x13607, "" },
//  { 0x13608, "" },
//  { 0x13609, "" },
//  { 0x1360A, "" },
//  { 0x1360B, "" },
//  { 0x1360C, "" },
//  { 0x1360D, "" },
//  { 0x1360E, "" },
//  { 0x1360F, "" },
//  { 0x13610, "" },
//  { 0x13611, "" },
//  { 0x13612, "" },
//  { 0x13613, "" },
//  { 0x13614, "" },
//  { 0x13615, "" },
//  { 0x13616, "" },
//  { 0x13617, "" },
//  { 0x13618, "" },
//  { 0x13619, "" },
//  { 0x1361A, "" },
//  { 0x1361B, "" },
//  { 0x1361C, "" },
//  { 0x1361D, "" },
//  { 0x1361E, "" },
//  { 0x1361F, "" },
//  { 0x13620, "" },
//  { 0x13621, "" },
//  { 0x13622, "" },
//  { 0x13623, "" },
//  { 0x13624, "" },
//  { 0x13625, "" },
//  { 0x13626, "" },
//  { 0x13627, "" },
//  { 0x13628, "" },
//  { 0x13629, "" },
//  { 0x1362A, "" },
//  { 0x1362B, "" },
//  { 0x1362C, "" },
//  { 0x1362D, "" },
//  { 0x1362E, "" },
//  { 0x1362F, "" },
//  { 0x13630, "" },
//  { 0x13631, "" },
//  { 0x13632, "" },
//  { 0x13633, "" },
//  { 0x13634, "" },
//  { 0x13635, "" },
//  { 0x13636, "" },
//  { 0x13637, "" },
//  { 0x13638, "" },
//  { 0x13639, "" },
//  { 0x1363A, "" },
//  { 0x1363B, "" },
//  { 0x1363C, "" },
//  { 0x1363D, "" },
//  { 0x1363E, "" },
//  { 0x1363F, "" },
//  { 0x13640, "" },
//  { 0x13641, "" },
//  { 0x13642, "" },
//  { 0x13643, "" },
//  { 0x13644, "" },
//  { 0x13645, "" },
//  { 0x13646, "" },
//  { 0x13647, "" },
//  { 0x13648, "" },
//  { 0x13649, "" },
//  { 0x1364A, "" },
//  { 0x1364B, "" },
//  { 0x1364C, "" },
//  { 0x1364D, "" },
//  { 0x1364E, "" },
//  { 0x1364F, "" },
//  { 0x13650, "" },
//  { 0x13651, "" },
//  { 0x13652, "" },
//  { 0x13653, "" },
//  { 0x13654, "" },
//  { 0x13655, "" },
//  { 0x13656, "" },
//  { 0x13657, "" },
//  { 0x13658, "" },
//  { 0x13659, "" },
//  { 0x1365A, "" },
//  { 0x1365B, "" },
//  { 0x1365C, "" },
//  { 0x1365D, "" },
//  { 0x1365E, "" },
//  { 0x1365F, "" },
//  { 0x13660, "" },
//  { 0x13661, "" },
//  { 0x13662, "" },
//  { 0x13663, "" },
//  { 0x13664, "" },
//  { 0x13665, "" },
//  { 0x13666, "" },
//  { 0x13667, "" },
//  { 0x13668, "" },
//  { 0x13669, "" },
//  { 0x1366A, "" },
//  { 0x1366B, "" },
//  { 0x1366C, "" },
//  { 0x1366D, "" },
//  { 0x1366E, "" },
//  { 0x1366F, "" },
//  { 0x13670, "" },
//  { 0x13671, "" },
//  { 0x13672, "" },
//  { 0x13673, "" },
//  { 0x13674, "" },
//  { 0x13675, "" },
//  { 0x13676, "" },
//  { 0x13677, "" },
//  { 0x13678, "" },
//  { 0x13679, "" },
//  { 0x1367A, "" },
//  { 0x1367B, "" },
//  { 0x1367C, "" },
//  { 0x1367D, "" },
//  { 0x1367E, "" },
//  { 0x1367F, "" },
//  { 0x13680, "" },
//  { 0x13681, "" },
//  { 0x13682, "" },
//  { 0x13683, "" },
//  { 0x13684, "" },
//  { 0x13685, "" },
//  { 0x13686, "" },
//  { 0x13687, "" },
//  { 0x13688, "" },
//  { 0x13689, "" },
//  { 0x1368A, "" },
//  { 0x1368B, "" },
//  { 0x1368C, "" },
//  { 0x1368D, "" },
//  { 0x1368E, "" },
//  { 0x1368F, "" },
//  { 0x13690, "" },
//  { 0x13691, "" },
//  { 0x13692, "" },
//  { 0x13693, "" },
//  { 0x13694, "" },
//  { 0x13695, "" },
//  { 0x13696, "" },
//  { 0x13697, "" },
//  { 0x13698, "" },
//  { 0x13699, "" },
//  { 0x1369A, "" },
//  { 0x1369B, "" },
//  { 0x1369C, "" },
//  { 0x1369D, "" },
//  { 0x1369E, "" },
//  { 0x1369F, "" },
//  { 0x136A0, "" },
//  { 0x136A1, "" },
//  { 0x136A2, "" },
//  { 0x136A3, "" },
//  { 0x136A4, "" },
//  { 0x136A5, "" },
//  { 0x136A6, "" },
//  { 0x136A7, "" },
//  { 0x136A8, "" },
//  { 0x136A9, "" },
//  { 0x136AA, "" },
//  { 0x136AB, "" },
//  { 0x136AC, "" },
//  { 0x136AD, "" },
//  { 0x136AE, "" },
//  { 0x136AF, "" },
//  { 0x136B0, "" },
//  { 0x136B1, "" },
//  { 0x136B2, "" },
//  { 0x136B3, "" },
//  { 0x136B4, "" },
//  { 0x136B5, "" },
//  { 0x136B6, "" },
//  { 0x136B7, "" },
//  { 0x136B8, "" },
//  { 0x136B9, "" },
//  { 0x136BA, "" },
//  { 0x136BB, "" },
//  { 0x136BC, "" },
//  { 0x136BD, "" },
//  { 0x136BE, "" },
//  { 0x136BF, "" },
//  { 0x136C0, "" },
//  { 0x136C1, "" },
//  { 0x136C2, "" },
//  { 0x136C3, "" },
//  { 0x136C4, "" },
//  { 0x136C5, "" },
//  { 0x136C6, "" },
//  { 0x136C7, "" },
//  { 0x136C8, "" },
//  { 0x136C9, "" },
//  { 0x136CA, "" },
//  { 0x136CB, "" },
//  { 0x136CC, "" },
//  { 0x136CD, "" },
//  { 0x136CE, "" },
//  { 0x136CF, "" },
//  { 0x136D0, "" },
//  { 0x136D1, "" },
//  { 0x136D2, "" },
//  { 0x136D3, "" },
//  { 0x136D4, "" },
//  { 0x136D5, "" },
//  { 0x136D6, "" },
//  { 0x136D7, "" },
//  { 0x136D8, "" },
//  { 0x136D9, "" },
//  { 0x136DA, "" },
//  { 0x136DB, "" },
//  { 0x136DC, "" },
//  { 0x136DD, "" },
//  { 0x136DE, "" },
//  { 0x136DF, "" },
//  { 0x136E0, "" },
//  { 0x136E1, "" },
//  { 0x136E2, "" },
//  { 0x136E3, "" },
//  { 0x136E4, "" },
//  { 0x136E5, "" },
//  { 0x136E6, "" },
//  { 0x136E7, "" },
//  { 0x136E8, "" },
//  { 0x136E9, "" },
//  { 0x136EA, "" },
//  { 0x136EB, "" },
//  { 0x136EC, "" },
//  { 0x136ED, "" },
//  { 0x136EE, "" },
//  { 0x136EF, "" },
//  { 0x136F0, "" },
//  { 0x136F1, "" },
//  { 0x136F2, "" },
//  { 0x136F3, "" },
//  { 0x136F4, "" },
//  { 0x136F5, "" },
//  { 0x136F6, "" },
//  { 0x136F7, "" },
//  { 0x136F8, "" },
//  { 0x136F9, "" },
//  { 0x136FA, "" },
//  { 0x136FB, "" },
//  { 0x136FC, "" },
//  { 0x136FD, "" },
//  { 0x136FE, "" },
//  { 0x136FF, "" },
//  { 0x13700, "" },
//  { 0x13701, "" },
//  { 0x13702, "" },
//  { 0x13703, "" },
//  { 0x13704, "" },
//  { 0x13705, "" },
//  { 0x13706, "" },
//  { 0x13707, "" },
//  { 0x13708, "" },
//  { 0x13709, "" },
//  { 0x1370A, "" },
//  { 0x1370B, "" },
//  { 0x1370C, "" },
//  { 0x1370D, "" },
//  { 0x1370E, "" },
//  { 0x1370F, "" },
//  { 0x13710, "" },
//  { 0x13711, "" },
//  { 0x13712, "" },
//  { 0x13713, "" },
//  { 0x13714, "" },
//  { 0x13715, "" },
//  { 0x13716, "" },
//  { 0x13717, "" },
//  { 0x13718, "" },
//  { 0x13719, "" },
//  { 0x1371A, "" },
//  { 0x1371B, "" },
//  { 0x1371C, "" },
//  { 0x1371D, "" },
//  { 0x1371E, "" },
//  { 0x1371F, "" },
//  { 0x13720, "" },
//  { 0x13721, "" },
//  { 0x13722, "" },
//  { 0x13723, "" },
//  { 0x13724, "" },
//  { 0x13725, "" },
//  { 0x13726, "" },
//  { 0x13727, "" },
//  { 0x13728, "" },
//  { 0x13729, "" },
//  { 0x1372A, "" },
//  { 0x1372B, "" },
//  { 0x1372C, "" },
//  { 0x1372D, "" },
//  { 0x1372E, "" },
//  { 0x1372F, "" },
//  { 0x13730, "" },
//  { 0x13731, "" },
//  { 0x13732, "" },
//  { 0x13733, "" },
//  { 0x13734, "" },
//  { 0x13735, "" },
//  { 0x13736, "" },
//  { 0x13737, "" },
//  { 0x13738, "" },
//  { 0x13739, "" },
//  { 0x1373A, "" },
//  { 0x1373B, "" },
//  { 0x1373C, "" },
//  { 0x1373D, "" },
//  { 0x1373E, "" },
//  { 0x1373F, "" },
//  { 0x13740, "" },
//  { 0x13741, "" },
//  { 0x13742, "" },
//  { 0x13743, "" },
//  { 0x13744, "" },
//  { 0x13745, "" },
//  { 0x13746, "" },
//  { 0x13747, "" },
//  { 0x13748, "" },
//  { 0x13749, "" },
//  { 0x1374A, "" },
//  { 0x1374B, "" },
//  { 0x1374C, "" },
//  { 0x1374D, "" },
//  { 0x1374E, "" },
//  { 0x1374F, "" },
//  { 0x13750, "" },
//  { 0x13751, "" },
//  { 0x13752, "" },
//  { 0x13753, "" },
//  { 0x13754, "" },
//  { 0x13755, "" },
//  { 0x13756, "" },
//  { 0x13757, "" },
//  { 0x13758, "" },
//  { 0x13759, "" },
//  { 0x1375A, "" },
//  { 0x1375B, "" },
//  { 0x1375C, "" },
//  { 0x1375D, "" },
//  { 0x1375E, "" },
//  { 0x1375F, "" },
//  { 0x13760, "" },
//  { 0x13761, "" },
//  { 0x13762, "" },
//  { 0x13763, "" },
//  { 0x13764, "" },
//  { 0x13765, "" },
//  { 0x13766, "" },
//  { 0x13767, "" },
//  { 0x13768, "" },
//  { 0x13769, "" },
//  { 0x1376A, "" },
//  { 0x1376B, "" },
//  { 0x1376C, "" },
//  { 0x1376D, "" },
//  { 0x1376E, "" },
//  { 0x1376F, "" },
//  { 0x13770, "" },
//  { 0x13771, "" },
//  { 0x13772, "" },
//  { 0x13773, "" },
//  { 0x13774, "" },
//  { 0x13775, "" },
//  { 0x13776, "" },
//  { 0x13777, "" },
//  { 0x13778, "" },
//  { 0x13779, "" },
//  { 0x1377A, "" },
//  { 0x1377B, "" },
//  { 0x1377C, "" },
//  { 0x1377D, "" },
//  { 0x1377E, "" },
//  { 0x1377F, "" },
//  { 0x13780, "" },
//  { 0x13781, "" },
//  { 0x13782, "" },
//  { 0x13783, "" },
//  { 0x13784, "" },
//  { 0x13785, "" },
//  { 0x13786, "" },
//  { 0x13787, "" },
//  { 0x13788, "" },
//  { 0x13789, "" },
//  { 0x1378A, "" },
//  { 0x1378B, "" },
//  { 0x1378C, "" },
//  { 0x1378D, "" },
//  { 0x1378E, "" },
//  { 0x1378F, "" },
//  { 0x13790, "" },
//  { 0x13791, "" },
//  { 0x13792, "" },
//  { 0x13793, "" },
//  { 0x13794, "" },
//  { 0x13795, "" },
//  { 0x13796, "" },
//  { 0x13797, "" },
//  { 0x13798, "" },
//  { 0x13799, "" },
//  { 0x1379A, "" },
//  { 0x1379B, "" },
//  { 0x1379C, "" },
//  { 0x1379D, "" },
//  { 0x1379E, "" },
//  { 0x1379F, "" },
//  { 0x137A0, "" },
//  { 0x137A1, "" },
//  { 0x137A2, "" },
//  { 0x137A3, "" },
//  { 0x137A4, "" },
//  { 0x137A5, "" },
//  { 0x137A6, "" },
//  { 0x137A7, "" },
//  { 0x137A8, "" },
//  { 0x137A9, "" },
//  { 0x137AA, "" },
//  { 0x137AB, "" },
//  { 0x137AC, "" },
//  { 0x137AD, "" },
//  { 0x137AE, "" },
//  { 0x137AF, "" },
//  { 0x137B0, "" },
//  { 0x137B1, "" },
//  { 0x137B2, "" },
//  { 0x137B3, "" },
//  { 0x137B4, "" },
//  { 0x137B5, "" },
//  { 0x137B6, "" },
//  { 0x137B7, "" },
//  { 0x137B8, "" },
//  { 0x137B9, "" },
//  { 0x137BA, "" },
//  { 0x137BB, "" },
//  { 0x137BC, "" },
//  { 0x137BD, "" },
//  { 0x137BE, "" },
//  { 0x137BF, "" },
//  { 0x137C0, "" },
//  { 0x137C1, "" },
//  { 0x137C2, "" },
//  { 0x137C3, "" },
//  { 0x137C4, "" },
//  { 0x137C5, "" },
//  { 0x137C6, "" },
//  { 0x137C7, "" },
//  { 0x137C8, "" },
//  { 0x137C9, "" },
//  { 0x137CA, "" },
//  { 0x137CB, "" },
//  { 0x137CC, "" },
//  { 0x137CD, "" },
//  { 0x137CE, "" },
//  { 0x137CF, "" },
//  { 0x137D0, "" },
//  { 0x137D1, "" },
//  { 0x137D2, "" },
//  { 0x137D3, "" },
//  { 0x137D4, "" },
//  { 0x137D5, "" },
//  { 0x137D6, "" },
//  { 0x137D7, "" },
//  { 0x137D8, "" },
//  { 0x137D9, "" },
//  { 0x137DA, "" },
//  { 0x137DB, "" },
//  { 0x137DC, "" },
//  { 0x137DD, "" },
//  { 0x137DE, "" },
//  { 0x137DF, "" },
//  { 0x137E0, "" },
//  { 0x137E1, "" },
//  { 0x137E2, "" },
//  { 0x137E3, "" },
//  { 0x137E4, "" },
//  { 0x137E5, "" },
//  { 0x137E6, "" },
//  { 0x137E7, "" },
//  { 0x137E8, "" },
//  { 0x137E9, "" },
//  { 0x137EA, "" },
//  { 0x137EB, "" },
//  { 0x137EC, "" },
//  { 0x137ED, "" },
//  { 0x137EE, "" },
//  { 0x137EF, "" },
//  { 0x137F0, "" },
//  { 0x137F1, "" },
//  { 0x137F2, "" },
//  { 0x137F3, "" },
//  { 0x137F4, "" },
//  { 0x137F5, "" },
//  { 0x137F6, "" },
//  { 0x137F7, "" },
//  { 0x137F8, "" },
//  { 0x137F9, "" },
//  { 0x137FA, "" },
//  { 0x137FB, "" },
//  { 0x137FC, "" },
//  { 0x137FD, "" },
//  { 0x137FE, "" },
//  { 0x137FF, "" },
//  { 0x13800, "" },
//  { 0x13801, "" },
//  { 0x13802, "" },
//  { 0x13803, "" },
//  { 0x13804, "" },
//  { 0x13805, "" },
//  { 0x13806, "" },
//  { 0x13807, "" },
//  { 0x13808, "" },
//  { 0x13809, "" },
//  { 0x1380A, "" },
//  { 0x1380B, "" },
//  { 0x1380C, "" },
//  { 0x1380D, "" },
//  { 0x1380E, "" },
//  { 0x1380F, "" },
//  { 0x13810, "" },
//  { 0x13811, "" },
//  { 0x13812, "" },
//  { 0x13813, "" },
//  { 0x13814, "" },
//  { 0x13815, "" },
//  { 0x13816, "" },
//  { 0x13817, "" },
//  { 0x13818, "" },
//  { 0x13819, "" },
//  { 0x1381A, "" },
//  { 0x1381B, "" },
//  { 0x1381C, "" },
//  { 0x1381D, "" },
//  { 0x1381E, "" },
//  { 0x1381F, "" },
//  { 0x13820, "" },
//  { 0x13821, "" },
//  { 0x13822, "" },
//  { 0x13823, "" },
//  { 0x13824, "" },
//  { 0x13825, "" },
//  { 0x13826, "" },
//  { 0x13827, "" },
//  { 0x13828, "" },
//  { 0x13829, "" },
//  { 0x1382A, "" },
//  { 0x1382B, "" },
//  { 0x1382C, "" },
//  { 0x1382D, "" },
//  { 0x1382E, "" },
//  { 0x1382F, "" },
//  { 0x13830, "" },
//  { 0x13831, "" },
//  { 0x13832, "" },
//  { 0x13833, "" },
//  { 0x13834, "" },
//  { 0x13835, "" },
//  { 0x13836, "" },
//  { 0x13837, "" },
//  { 0x13838, "" },
//  { 0x13839, "" },
//  { 0x1383A, "" },
//  { 0x1383B, "" },
//  { 0x1383C, "" },
//  { 0x1383D, "" },
//  { 0x1383E, "" },
//  { 0x1383F, "" },
//  { 0x13840, "" },
//  { 0x13841, "" },
//  { 0x13842, "" },
//  { 0x13843, "" },
//  { 0x13844, "" },
//  { 0x13845, "" },
//  { 0x13846, "" },
//  { 0x13847, "" },
//  { 0x13848, "" },
//  { 0x13849, "" },
//  { 0x1384A, "" },
//  { 0x1384B, "" },
//  { 0x1384C, "" },
//  { 0x1384D, "" },
//  { 0x1384E, "" },
//  { 0x1384F, "" },
//  { 0x13850, "" },
//  { 0x13851, "" },
//  { 0x13852, "" },
//  { 0x13853, "" },
//  { 0x13854, "" },
//  { 0x13855, "" },
//  { 0x13856, "" },
//  { 0x13857, "" },
//  { 0x13858, "" },
//  { 0x13859, "" },
//  { 0x1385A, "" },
//  { 0x1385B, "" },
//  { 0x1385C, "" },
//  { 0x1385D, "" },
//  { 0x1385E, "" },
//  { 0x1385F, "" },
//  { 0x13860, "" },
//  { 0x13861, "" },
//  { 0x13862, "" },
//  { 0x13863, "" },
//  { 0x13864, "" },
//  { 0x13865, "" },
//  { 0x13866, "" },
//  { 0x13867, "" },
//  { 0x13868, "" },
//  { 0x13869, "" },
//  { 0x1386A, "" },
//  { 0x1386B, "" },
//  { 0x1386C, "" },
//  { 0x1386D, "" },
//  { 0x1386E, "" },
//  { 0x1386F, "" },
//  { 0x13870, "" },
//  { 0x13871, "" },
//  { 0x13872, "" },
//  { 0x13873, "" },
//  { 0x13874, "" },
//  { 0x13875, "" },
//  { 0x13876, "" },
//  { 0x13877, "" },
//  { 0x13878, "" },
//  { 0x13879, "" },
//  { 0x1387A, "" },
//  { 0x1387B, "" },
//  { 0x1387C, "" },
//  { 0x1387D, "" },
//  { 0x1387E, "" },
//  { 0x1387F, "" },
//  { 0x13880, "" },
//  { 0x13881, "" },
//  { 0x13882, "" },
//  { 0x13883, "" },
//  { 0x13884, "" },
//  { 0x13885, "" },
//  { 0x13886, "" },
//  { 0x13887, "" },
//  { 0x13888, "" },
//  { 0x13889, "" },
//  { 0x1388A, "" },
//  { 0x1388B, "" },
//  { 0x1388C, "" },
//  { 0x1388D, "" },
//  { 0x1388E, "" },
//  { 0x1388F, "" },
//  { 0x13890, "" },
//  { 0x13891, "" },
//  { 0x13892, "" },
//  { 0x13893, "" },
//  { 0x13894, "" },
//  { 0x13895, "" },
//  { 0x13896, "" },
//  { 0x13897, "" },
//  { 0x13898, "" },
//  { 0x13899, "" },
//  { 0x1389A, "" },
//  { 0x1389B, "" },
//  { 0x1389C, "" },
//  { 0x1389D, "" },
//  { 0x1389E, "" },
//  { 0x1389F, "" },
//  { 0x138A0, "" },
//  { 0x138A1, "" },
//  { 0x138A2, "" },
//  { 0x138A3, "" },
//  { 0x138A4, "" },
//  { 0x138A5, "" },
//  { 0x138A6, "" },
//  { 0x138A7, "" },
//  { 0x138A8, "" },
//  { 0x138A9, "" },
//  { 0x138AA, "" },
//  { 0x138AB, "" },
//  { 0x138AC, "" },
//  { 0x138AD, "" },
//  { 0x138AE, "" },
//  { 0x138AF, "" },
//  { 0x138B0, "" },
//  { 0x138B1, "" },
//  { 0x138B2, "" },
//  { 0x138B3, "" },
//  { 0x138B4, "" },
//  { 0x138B5, "" },
//  { 0x138B6, "" },
//  { 0x138B7, "" },
//  { 0x138B8, "" },
//  { 0x138B9, "" },
//  { 0x138BA, "" },
//  { 0x138BB, "" },
//  { 0x138BC, "" },
//  { 0x138BD, "" },
//  { 0x138BE, "" },
//  { 0x138BF, "" },
//  { 0x138C0, "" },
//  { 0x138C1, "" },
//  { 0x138C2, "" },
//  { 0x138C3, "" },
//  { 0x138C4, "" },
//  { 0x138C5, "" },
//  { 0x138C6, "" },
//  { 0x138C7, "" },
//  { 0x138C8, "" },
//  { 0x138C9, "" },
//  { 0x138CA, "" },
//  { 0x138CB, "" },
//  { 0x138CC, "" },
//  { 0x138CD, "" },
//  { 0x138CE, "" },
//  { 0x138CF, "" },
//  { 0x138D0, "" },
//  { 0x138D1, "" },
//  { 0x138D2, "" },
//  { 0x138D3, "" },
//  { 0x138D4, "" },
//  { 0x138D5, "" },
//  { 0x138D6, "" },
//  { 0x138D7, "" },
//  { 0x138D8, "" },
//  { 0x138D9, "" },
//  { 0x138DA, "" },
//  { 0x138DB, "" },
//  { 0x138DC, "" },
//  { 0x138DD, "" },
//  { 0x138DE, "" },
//  { 0x138DF, "" },
//  { 0x138E0, "" },
//  { 0x138E1, "" },
//  { 0x138E2, "" },
//  { 0x138E3, "" },
//  { 0x138E4, "" },
//  { 0x138E5, "" },
//  { 0x138E6, "" },
//  { 0x138E7, "" },
//  { 0x138E8, "" },
//  { 0x138E9, "" },
//  { 0x138EA, "" },
//  { 0x138EB, "" },
//  { 0x138EC, "" },
//  { 0x138ED, "" },
//  { 0x138EE, "" },
//  { 0x138EF, "" },
//  { 0x138F0, "" },
//  { 0x138F1, "" },
//  { 0x138F2, "" },
//  { 0x138F3, "" },
//  { 0x138F4, "" },
//  { 0x138F5, "" },
//  { 0x138F6, "" },
//  { 0x138F7, "" },
//  { 0x138F8, "" },
//  { 0x138F9, "" },
//  { 0x138FA, "" },
//  { 0x138FB, "" },
//  { 0x138FC, "" },
//  { 0x138FD, "" },
//  { 0x138FE, "" },
//  { 0x138FF, "" },
//  { 0x13900, "" },
//  { 0x13901, "" },
//  { 0x13902, "" },
//  { 0x13903, "" },
//  { 0x13904, "" },
//  { 0x13905, "" },
//  { 0x13906, "" },
//  { 0x13907, "" },
//  { 0x13908, "" },
//  { 0x13909, "" },
//  { 0x1390A, "" },
//  { 0x1390B, "" },
//  { 0x1390C, "" },
//  { 0x1390D, "" },
//  { 0x1390E, "" },
//  { 0x1390F, "" },
//  { 0x13910, "" },
//  { 0x13911, "" },
//  { 0x13912, "" },
//  { 0x13913, "" },
//  { 0x13914, "" },
//  { 0x13915, "" },
//  { 0x13916, "" },
//  { 0x13917, "" },
//  { 0x13918, "" },
//  { 0x13919, "" },
//  { 0x1391A, "" },
//  { 0x1391B, "" },
//  { 0x1391C, "" },
//  { 0x1391D, "" },
//  { 0x1391E, "" },
//  { 0x1391F, "" },
//  { 0x13920, "" },
//  { 0x13921, "" },
//  { 0x13922, "" },
//  { 0x13923, "" },
//  { 0x13924, "" },
//  { 0x13925, "" },
//  { 0x13926, "" },
//  { 0x13927, "" },
//  { 0x13928, "" },
//  { 0x13929, "" },
//  { 0x1392A, "" },
//  { 0x1392B, "" },
//  { 0x1392C, "" },
//  { 0x1392D, "" },
//  { 0x1392E, "" },
//  { 0x1392F, "" },
//  { 0x13930, "" },
//  { 0x13931, "" },
//  { 0x13932, "" },
//  { 0x13933, "" },
//  { 0x13934, "" },
//  { 0x13935, "" },
//  { 0x13936, "" },
//  { 0x13937, "" },
//  { 0x13938, "" },
//  { 0x13939, "" },
//  { 0x1393A, "" },
//  { 0x1393B, "" },
//  { 0x1393C, "" },
//  { 0x1393D, "" },
//  { 0x1393E, "" },
//  { 0x1393F, "" },
//  { 0x13940, "" },
//  { 0x13941, "" },
//  { 0x13942, "" },
//  { 0x13943, "" },
//  { 0x13944, "" },
//  { 0x13945, "" },
//  { 0x13946, "" },
//  { 0x13947, "" },
//  { 0x13948, "" },
//  { 0x13949, "" },
//  { 0x1394A, "" },
//  { 0x1394B, "" },
//  { 0x1394C, "" },
//  { 0x1394D, "" },
//  { 0x1394E, "" },
//  { 0x1394F, "" },
//  { 0x13950, "" },
//  { 0x13951, "" },
//  { 0x13952, "" },
//  { 0x13953, "" },
//  { 0x13954, "" },
//  { 0x13955, "" },
//  { 0x13956, "" },
//  { 0x13957, "" },
//  { 0x13958, "" },
//  { 0x13959, "" },
//  { 0x1395A, "" },
//  { 0x1395B, "" },
//  { 0x1395C, "" },
//  { 0x1395D, "" },
//  { 0x1395E, "" },
//  { 0x1395F, "" },
//  { 0x13960, "" },
//  { 0x13961, "" },
//  { 0x13962, "" },
//  { 0x13963, "" },
//  { 0x13964, "" },
//  { 0x13965, "" },
//  { 0x13966, "" },
//  { 0x13967, "" },
//  { 0x13968, "" },
//  { 0x13969, "" },
//  { 0x1396A, "" },
//  { 0x1396B, "" },
//  { 0x1396C, "" },
//  { 0x1396D, "" },
//  { 0x1396E, "" },
//  { 0x1396F, "" },
//  { 0x13970, "" },
//  { 0x13971, "" },
//  { 0x13972, "" },
//  { 0x13973, "" },
//  { 0x13974, "" },
//  { 0x13975, "" },
//  { 0x13976, "" },
//  { 0x13977, "" },
//  { 0x13978, "" },
//  { 0x13979, "" },
//  { 0x1397A, "" },
//  { 0x1397B, "" },
//  { 0x1397C, "" },
//  { 0x1397D, "" },
//  { 0x1397E, "" },
//  { 0x1397F, "" },
//  { 0x13980, "" },
//  { 0x13981, "" },
//  { 0x13982, "" },
//  { 0x13983, "" },
//  { 0x13984, "" },
//  { 0x13985, "" },
//  { 0x13986, "" },
//  { 0x13987, "" },
//  { 0x13988, "" },
//  { 0x13989, "" },
//  { 0x1398A, "" },
//  { 0x1398B, "" },
//  { 0x1398C, "" },
//  { 0x1398D, "" },
//  { 0x1398E, "" },
//  { 0x1398F, "" },
//  { 0x13990, "" },
//  { 0x13991, "" },
//  { 0x13992, "" },
//  { 0x13993, "" },
//  { 0x13994, "" },
//  { 0x13995, "" },
//  { 0x13996, "" },
//  { 0x13997, "" },
//  { 0x13998, "" },
//  { 0x13999, "" },
//  { 0x1399A, "" },
//  { 0x1399B, "" },
//  { 0x1399C, "" },
//  { 0x1399D, "" },
//  { 0x1399E, "" },
//  { 0x1399F, "" },
//  { 0x139A0, "" },
//  { 0x139A1, "" },
//  { 0x139A2, "" },
//  { 0x139A3, "" },
//  { 0x139A4, "" },
//  { 0x139A5, "" },
//  { 0x139A6, "" },
//  { 0x139A7, "" },
//  { 0x139A8, "" },
//  { 0x139A9, "" },
//  { 0x139AA, "" },
//  { 0x139AB, "" },
//  { 0x139AC, "" },
//  { 0x139AD, "" },
//  { 0x139AE, "" },
//  { 0x139AF, "" },
//  { 0x139B0, "" },
//  { 0x139B1, "" },
//  { 0x139B2, "" },
//  { 0x139B3, "" },
//  { 0x139B4, "" },
//  { 0x139B5, "" },
//  { 0x139B6, "" },
//  { 0x139B7, "" },
//  { 0x139B8, "" },
//  { 0x139B9, "" },
//  { 0x139BA, "" },
//  { 0x139BB, "" },
//  { 0x139BC, "" },
//  { 0x139BD, "" },
//  { 0x139BE, "" },
//  { 0x139BF, "" },
//  { 0x139C0, "" },
//  { 0x139C1, "" },
//  { 0x139C2, "" },
//  { 0x139C3, "" },
//  { 0x139C4, "" },
//  { 0x139C5, "" },
//  { 0x139C6, "" },
//  { 0x139C7, "" },
//  { 0x139C8, "" },
//  { 0x139C9, "" },
//  { 0x139CA, "" },
//  { 0x139CB, "" },
//  { 0x139CC, "" },
//  { 0x139CD, "" },
//  { 0x139CE, "" },
//  { 0x139CF, "" },
//  { 0x139D0, "" },
//  { 0x139D1, "" },
//  { 0x139D2, "" },
//  { 0x139D3, "" },
//  { 0x139D4, "" },
//  { 0x139D5, "" },
//  { 0x139D6, "" },
//  { 0x139D7, "" },
//  { 0x139D8, "" },
//  { 0x139D9, "" },
//  { 0x139DA, "" },
//  { 0x139DB, "" },
//  { 0x139DC, "" },
//  { 0x139DD, "" },
//  { 0x139DE, "" },
//  { 0x139DF, "" },
//  { 0x139E0, "" },
//  { 0x139E1, "" },
//  { 0x139E2, "" },
//  { 0x139E3, "" },
//  { 0x139E4, "" },
//  { 0x139E5, "" },
//  { 0x139E6, "" },
//  { 0x139E7, "" },
//  { 0x139E8, "" },
//  { 0x139E9, "" },
//  { 0x139EA, "" },
//  { 0x139EB, "" },
//  { 0x139EC, "" },
//  { 0x139ED, "" },
//  { 0x139EE, "" },
//  { 0x139EF, "" },
//  { 0x139F0, "" },
//  { 0x139F1, "" },
//  { 0x139F2, "" },
//  { 0x139F3, "" },
//  { 0x139F4, "" },
//  { 0x139F5, "" },
//  { 0x139F6, "" },
//  { 0x139F7, "" },
//  { 0x139F8, "" },
//  { 0x139F9, "" },
//  { 0x139FA, "" },
//  { 0x139FB, "" },
//  { 0x139FC, "" },
//  { 0x139FD, "" },
//  { 0x139FE, "" },
//  { 0x139FF, "" },
//  { 0x13A00, "" },
//  { 0x13A01, "" },
//  { 0x13A02, "" },
//  { 0x13A03, "" },
//  { 0x13A04, "" },
//  { 0x13A05, "" },
//  { 0x13A06, "" },
//  { 0x13A07, "" },
//  { 0x13A08, "" },
//  { 0x13A09, "" },
//  { 0x13A0A, "" },
//  { 0x13A0B, "" },
//  { 0x13A0C, "" },
//  { 0x13A0D, "" },
//  { 0x13A0E, "" },
//  { 0x13A0F, "" },
//  { 0x13A10, "" },
//  { 0x13A11, "" },
//  { 0x13A12, "" },
//  { 0x13A13, "" },
//  { 0x13A14, "" },
//  { 0x13A15, "" },
//  { 0x13A16, "" },
//  { 0x13A17, "" },
//  { 0x13A18, "" },
//  { 0x13A19, "" },
//  { 0x13A1A, "" },
//  { 0x13A1B, "" },
//  { 0x13A1C, "" },
//  { 0x13A1D, "" },
//  { 0x13A1E, "" },
//  { 0x13A1F, "" },
//  { 0x13A20, "" },
//  { 0x13A21, "" },
//  { 0x13A22, "" },
//  { 0x13A23, "" },
//  { 0x13A24, "" },
//  { 0x13A25, "" },
//  { 0x13A26, "" },
//  { 0x13A27, "" },
//  { 0x13A28, "" },
//  { 0x13A29, "" },
//  { 0x13A2A, "" },
//  { 0x13A2B, "" },
//  { 0x13A2C, "" },
//  { 0x13A2D, "" },
//  { 0x13A2E, "" },
//  { 0x13A2F, "" },
//  { 0x13A30, "" },
//  { 0x13A31, "" },
//  { 0x13A32, "" },
//  { 0x13A33, "" },
//  { 0x13A34, "" },
//  { 0x13A35, "" },
//  { 0x13A36, "" },
//  { 0x13A37, "" },
//  { 0x13A38, "" },
//  { 0x13A39, "" },
//  { 0x13A3A, "" },
//  { 0x13A3B, "" },
//  { 0x13A3C, "" },
//  { 0x13A3D, "" },
//  { 0x13A3E, "" },
//  { 0x13A3F, "" },
//  { 0x13A40, "" },
//  { 0x13A41, "" },
//  { 0x13A42, "" },
//  { 0x13A43, "" },
//  { 0x13A44, "" },
//  { 0x13A45, "" },
//  { 0x13A46, "" },
//  { 0x13A47, "" },
//  { 0x13A48, "" },
//  { 0x13A49, "" },
//  { 0x13A4A, "" },
//  { 0x13A4B, "" },
//  { 0x13A4C, "" },
//  { 0x13A4D, "" },
//  { 0x13A4E, "" },
//  { 0x13A4F, "" },
//  { 0x13A50, "" },
//  { 0x13A51, "" },
//  { 0x13A52, "" },
//  { 0x13A53, "" },
//  { 0x13A54, "" },
//  { 0x13A55, "" },
//  { 0x13A56, "" },
//  { 0x13A57, "" },
//  { 0x13A58, "" },
//  { 0x13A59, "" },
//  { 0x13A5A, "" },
//  { 0x13A5B, "" },
//  { 0x13A5C, "" },
//  { 0x13A5D, "" },
//  { 0x13A5E, "" },
//  { 0x13A5F, "" },
//  { 0x13A60, "" },
//  { 0x13A61, "" },
//  { 0x13A62, "" },
//  { 0x13A63, "" },
//  { 0x13A64, "" },
//  { 0x13A65, "" },
//  { 0x13A66, "" },
//  { 0x13A67, "" },
//  { 0x13A68, "" },
//  { 0x13A69, "" },
//  { 0x13A6A, "" },
//  { 0x13A6B, "" },
//  { 0x13A6C, "" },
//  { 0x13A6D, "" },
//  { 0x13A6E, "" },
//  { 0x13A6F, "" },
//  { 0x13A70, "" },
//  { 0x13A71, "" },
//  { 0x13A72, "" },
//  { 0x13A73, "" },
//  { 0x13A74, "" },
//  { 0x13A75, "" },
//  { 0x13A76, "" },
//  { 0x13A77, "" },
//  { 0x13A78, "" },
//  { 0x13A79, "" },
//  { 0x13A7A, "" },
//  { 0x13A7B, "" },
//  { 0x13A7C, "" },
//  { 0x13A7D, "" },
//  { 0x13A7E, "" },
//  { 0x13A7F, "" },
//  { 0x13A80, "" },
//  { 0x13A81, "" },
//  { 0x13A82, "" },
//  { 0x13A83, "" },
//  { 0x13A84, "" },
//  { 0x13A85, "" },
//  { 0x13A86, "" },
//  { 0x13A87, "" },
//  { 0x13A88, "" },
//  { 0x13A89, "" },
//  { 0x13A8A, "" },
//  { 0x13A8B, "" },
//  { 0x13A8C, "" },
//  { 0x13A8D, "" },
//  { 0x13A8E, "" },
//  { 0x13A8F, "" },
//  { 0x13A90, "" },
//  { 0x13A91, "" },
//  { 0x13A92, "" },
//  { 0x13A93, "" },
//  { 0x13A94, "" },
//  { 0x13A95, "" },
//  { 0x13A96, "" },
//  { 0x13A97, "" },
//  { 0x13A98, "" },
//  { 0x13A99, "" },
//  { 0x13A9A, "" },
//  { 0x13A9B, "" },
//  { 0x13A9C, "" },
//  { 0x13A9D, "" },
//  { 0x13A9E, "" },
//  { 0x13A9F, "" },
//  { 0x13AA0, "" },
//  { 0x13AA1, "" },
//  { 0x13AA2, "" },
//  { 0x13AA3, "" },
//  { 0x13AA4, "" },
//  { 0x13AA5, "" },
//  { 0x13AA6, "" },
//  { 0x13AA7, "" },
//  { 0x13AA8, "" },
//  { 0x13AA9, "" },
//  { 0x13AAA, "" },
//  { 0x13AAB, "" },
//  { 0x13AAC, "" },
//  { 0x13AAD, "" },
//  { 0x13AAE, "" },
//  { 0x13AAF, "" },
//  { 0x13AB0, "" },
//  { 0x13AB1, "" },
//  { 0x13AB2, "" },
//  { 0x13AB3, "" },
//  { 0x13AB4, "" },
//  { 0x13AB5, "" },
//  { 0x13AB6, "" },
//  { 0x13AB7, "" },
//  { 0x13AB8, "" },
//  { 0x13AB9, "" },
//  { 0x13ABA, "" },
//  { 0x13ABB, "" },
//  { 0x13ABC, "" },
//  { 0x13ABD, "" },
//  { 0x13ABE, "" },
//  { 0x13ABF, "" },
//  { 0x13AC0, "" },
//  { 0x13AC1, "" },
//  { 0x13AC2, "" },
//  { 0x13AC3, "" },
//  { 0x13AC4, "" },
//  { 0x13AC5, "" },
//  { 0x13AC6, "" },
//  { 0x13AC7, "" },
//  { 0x13AC8, "" },
//  { 0x13AC9, "" },
//  { 0x13ACA, "" },
//  { 0x13ACB, "" },
//  { 0x13ACC, "" },
//  { 0x13ACD, "" },
//  { 0x13ACE, "" },
//  { 0x13ACF, "" },
//  { 0x13AD0, "" },
//  { 0x13AD1, "" },
//  { 0x13AD2, "" },
//  { 0x13AD3, "" },
//  { 0x13AD4, "" },
//  { 0x13AD5, "" },
//  { 0x13AD6, "" },
//  { 0x13AD7, "" },
//  { 0x13AD8, "" },
//  { 0x13AD9, "" },
//  { 0x13ADA, "" },
//  { 0x13ADB, "" },
//  { 0x13ADC, "" },
//  { 0x13ADD, "" },
//  { 0x13ADE, "" },
//  { 0x13ADF, "" },
//  { 0x13AE0, "" },
//  { 0x13AE1, "" },
//  { 0x13AE2, "" },
//  { 0x13AE3, "" },
//  { 0x13AE4, "" },
//  { 0x13AE5, "" },
//  { 0x13AE6, "" },
//  { 0x13AE7, "" },
//  { 0x13AE8, "" },
//  { 0x13AE9, "" },
//  { 0x13AEA, "" },
//  { 0x13AEB, "" },
//  { 0x13AEC, "" },
//  { 0x13AED, "" },
//  { 0x13AEE, "" },
//  { 0x13AEF, "" },
//  { 0x13AF0, "" },
//  { 0x13AF1, "" },
//  { 0x13AF2, "" },
//  { 0x13AF3, "" },
//  { 0x13AF4, "" },
//  { 0x13AF5, "" },
//  { 0x13AF6, "" },
//  { 0x13AF7, "" },
//  { 0x13AF8, "" },
//  { 0x13AF9, "" },
//  { 0x13AFA, "" },
//  { 0x13AFB, "" },
//  { 0x13AFC, "" },
//  { 0x13AFD, "" },
//  { 0x13AFE, "" },
//  { 0x13AFF, "" },
//  { 0x13B00, "" },
//  { 0x13B01, "" },
//  { 0x13B02, "" },
//  { 0x13B03, "" },
//  { 0x13B04, "" },
//  { 0x13B05, "" },
//  { 0x13B06, "" },
//  { 0x13B07, "" },
//  { 0x13B08, "" },
//  { 0x13B09, "" },
//  { 0x13B0A, "" },
//  { 0x13B0B, "" },
//  { 0x13B0C, "" },
//  { 0x13B0D, "" },
//  { 0x13B0E, "" },
//  { 0x13B0F, "" },
//  { 0x13B10, "" },
//  { 0x13B11, "" },
//  { 0x13B12, "" },
//  { 0x13B13, "" },
//  { 0x13B14, "" },
//  { 0x13B15, "" },
//  { 0x13B16, "" },
//  { 0x13B17, "" },
//  { 0x13B18, "" },
//  { 0x13B19, "" },
//  { 0x13B1A, "" },
//  { 0x13B1B, "" },
//  { 0x13B1C, "" },
//  { 0x13B1D, "" },
//  { 0x13B1E, "" },
//  { 0x13B1F, "" },
//  { 0x13B20, "" },
//  { 0x13B21, "" },
//  { 0x13B22, "" },
//  { 0x13B23, "" },
//  { 0x13B24, "" },
//  { 0x13B25, "" },
//  { 0x13B26, "" },
//  { 0x13B27, "" },
//  { 0x13B28, "" },
//  { 0x13B29, "" },
//  { 0x13B2A, "" },
//  { 0x13B2B, "" },
//  { 0x13B2C, "" },
//  { 0x13B2D, "" },
//  { 0x13B2E, "" },
//  { 0x13B2F, "" },
//  { 0x13B30, "" },
//  { 0x13B31, "" },
//  { 0x13B32, "" },
//  { 0x13B33, "" },
//  { 0x13B34, "" },
//  { 0x13B35, "" },
//  { 0x13B36, "" },
//  { 0x13B37, "" },
//  { 0x13B38, "" },
//  { 0x13B39, "" },
//  { 0x13B3A, "" },
//  { 0x13B3B, "" },
//  { 0x13B3C, "" },
//  { 0x13B3D, "" },
//  { 0x13B3E, "" },
//  { 0x13B3F, "" },
//  { 0x13B40, "" },
//  { 0x13B41, "" },
//  { 0x13B42, "" },
//  { 0x13B43, "" },
//  { 0x13B44, "" },
//  { 0x13B45, "" },
//  { 0x13B46, "" },
//  { 0x13B47, "" },
//  { 0x13B48, "" },
//  { 0x13B49, "" },
//  { 0x13B4A, "" },
//  { 0x13B4B, "" },
//  { 0x13B4C, "" },
//  { 0x13B4D, "" },
//  { 0x13B4E, "" },
//  { 0x13B4F, "" },
//  { 0x13B50, "" },
//  { 0x13B51, "" },
//  { 0x13B52, "" },
//  { 0x13B53, "" },
//  { 0x13B54, "" },
//  { 0x13B55, "" },
//  { 0x13B56, "" },
//  { 0x13B57, "" },
//  { 0x13B58, "" },
//  { 0x13B59, "" },
//  { 0x13B5A, "" },
//  { 0x13B5B, "" },
//  { 0x13B5C, "" },
//  { 0x13B5D, "" },
//  { 0x13B5E, "" },
//  { 0x13B5F, "" },
//  { 0x13B60, "" },
//  { 0x13B61, "" },
//  { 0x13B62, "" },
//  { 0x13B63, "" },
//  { 0x13B64, "" },
//  { 0x13B65, "" },
//  { 0x13B66, "" },
//  { 0x13B67, "" },
//  { 0x13B68, "" },
//  { 0x13B69, "" },
//  { 0x13B6A, "" },
//  { 0x13B6B, "" },
//  { 0x13B6C, "" },
//  { 0x13B6D, "" },
//  { 0x13B6E, "" },
//  { 0x13B6F, "" },
//  { 0x13B70, "" },
//  { 0x13B71, "" },
//  { 0x13B72, "" },
//  { 0x13B73, "" },
//  { 0x13B74, "" },
//  { 0x13B75, "" },
//  { 0x13B76, "" },
//  { 0x13B77, "" },
//  { 0x13B78, "" },
//  { 0x13B79, "" },
//  { 0x13B7A, "" },
//  { 0x13B7B, "" },
//  { 0x13B7C, "" },
//  { 0x13B7D, "" },
//  { 0x13B7E, "" },
//  { 0x13B7F, "" },
//  { 0x13B80, "" },
//  { 0x13B81, "" },
//  { 0x13B82, "" },
//  { 0x13B83, "" },
//  { 0x13B84, "" },
//  { 0x13B85, "" },
//  { 0x13B86, "" },
//  { 0x13B87, "" },
//  { 0x13B88, "" },
//  { 0x13B89, "" },
//  { 0x13B8A, "" },
//  { 0x13B8B, "" },
//  { 0x13B8C, "" },
//  { 0x13B8D, "" },
//  { 0x13B8E, "" },
//  { 0x13B8F, "" },
//  { 0x13B90, "" },
//  { 0x13B91, "" },
//  { 0x13B92, "" },
//  { 0x13B93, "" },
//  { 0x13B94, "" },
//  { 0x13B95, "" },
//  { 0x13B96, "" },
//  { 0x13B97, "" },
//  { 0x13B98, "" },
//  { 0x13B99, "" },
//  { 0x13B9A, "" },
//  { 0x13B9B, "" },
//  { 0x13B9C, "" },
//  { 0x13B9D, "" },
//  { 0x13B9E, "" },
//  { 0x13B9F, "" },
//  { 0x13BA0, "" },
//  { 0x13BA1, "" },
//  { 0x13BA2, "" },
//  { 0x13BA3, "" },
//  { 0x13BA4, "" },
//  { 0x13BA5, "" },
//  { 0x13BA6, "" },
//  { 0x13BA7, "" },
//  { 0x13BA8, "" },
//  { 0x13BA9, "" },
//  { 0x13BAA, "" },
//  { 0x13BAB, "" },
//  { 0x13BAC, "" },
//  { 0x13BAD, "" },
//  { 0x13BAE, "" },
//  { 0x13BAF, "" },
//  { 0x13BB0, "" },
//  { 0x13BB1, "" },
//  { 0x13BB2, "" },
//  { 0x13BB3, "" },
//  { 0x13BB4, "" },
//  { 0x13BB5, "" },
//  { 0x13BB6, "" },
//  { 0x13BB7, "" },
//  { 0x13BB8, "" },
//  { 0x13BB9, "" },
//  { 0x13BBA, "" },
//  { 0x13BBB, "" },
//  { 0x13BBC, "" },
//  { 0x13BBD, "" },
//  { 0x13BBE, "" },
//  { 0x13BBF, "" },
//  { 0x13BC0, "" },
//  { 0x13BC1, "" },
//  { 0x13BC2, "" },
//  { 0x13BC3, "" },
//  { 0x13BC4, "" },
//  { 0x13BC5, "" },
//  { 0x13BC6, "" },
//  { 0x13BC7, "" },
//  { 0x13BC8, "" },
//  { 0x13BC9, "" },
//  { 0x13BCA, "" },
//  { 0x13BCB, "" },
//  { 0x13BCC, "" },
//  { 0x13BCD, "" },
//  { 0x13BCE, "" },
//  { 0x13BCF, "" },
//  { 0x13BD0, "" },
//  { 0x13BD1, "" },
//  { 0x13BD2, "" },
//  { 0x13BD3, "" },
//  { 0x13BD4, "" },
//  { 0x13BD5, "" },
//  { 0x13BD6, "" },
//  { 0x13BD7, "" },
//  { 0x13BD8, "" },
//  { 0x13BD9, "" },
//  { 0x13BDA, "" },
//  { 0x13BDB, "" },
//  { 0x13BDC, "" },
//  { 0x13BDD, "" },
//  { 0x13BDE, "" },
//  { 0x13BDF, "" },
//  { 0x13BE0, "" },
//  { 0x13BE1, "" },
//  { 0x13BE2, "" },
//  { 0x13BE3, "" },
//  { 0x13BE4, "" },
//  { 0x13BE5, "" },
//  { 0x13BE6, "" },
//  { 0x13BE7, "" },
//  { 0x13BE8, "" },
//  { 0x13BE9, "" },
//  { 0x13BEA, "" },
//  { 0x13BEB, "" },
//  { 0x13BEC, "" },
//  { 0x13BED, "" },
//  { 0x13BEE, "" },
//  { 0x13BEF, "" },
//  { 0x13BF0, "" },
//  { 0x13BF1, "" },
//  { 0x13BF2, "" },
//  { 0x13BF3, "" },
//  { 0x13BF4, "" },
//  { 0x13BF5, "" },
//  { 0x13BF6, "" },
//  { 0x13BF7, "" },
//  { 0x13BF8, "" },
//  { 0x13BF9, "" },
//  { 0x13BFA, "" },
//  { 0x13BFB, "" },
//  { 0x13BFC, "" },
//  { 0x13BFD, "" },
//  { 0x13BFE, "" },
//  { 0x13BFF, "" },
//  { 0x13C00, "" },
//  { 0x13C01, "" },
//  { 0x13C02, "" },
//  { 0x13C03, "" },
//  { 0x13C04, "" },
//  { 0x13C05, "" },
//  { 0x13C06, "" },
//  { 0x13C07, "" },
//  { 0x13C08, "" },
//  { 0x13C09, "" },
//  { 0x13C0A, "" },
//  { 0x13C0B, "" },
//  { 0x13C0C, "" },
//  { 0x13C0D, "" },
//  { 0x13C0E, "" },
//  { 0x13C0F, "" },
//  { 0x13C10, "" },
//  { 0x13C11, "" },
//  { 0x13C12, "" },
//  { 0x13C13, "" },
//  { 0x13C14, "" },
//  { 0x13C15, "" },
//  { 0x13C16, "" },
//  { 0x13C17, "" },
//  { 0x13C18, "" },
//  { 0x13C19, "" },
//  { 0x13C1A, "" },
//  { 0x13C1B, "" },
//  { 0x13C1C, "" },
//  { 0x13C1D, "" },
//  { 0x13C1E, "" },
//  { 0x13C1F, "" },
//  { 0x13C20, "" },
//  { 0x13C21, "" },
//  { 0x13C22, "" },
//  { 0x13C23, "" },
//  { 0x13C24, "" },
//  { 0x13C25, "" },
//  { 0x13C26, "" },
//  { 0x13C27, "" },
//  { 0x13C28, "" },
//  { 0x13C29, "" },
//  { 0x13C2A, "" },
//  { 0x13C2B, "" },
//  { 0x13C2C, "" },
//  { 0x13C2D, "" },
//  { 0x13C2E, "" },
//  { 0x13C2F, "" },
//  { 0x13C30, "" },
//  { 0x13C31, "" },
//  { 0x13C32, "" },
//  { 0x13C33, "" },
//  { 0x13C34, "" },
//  { 0x13C35, "" },
//  { 0x13C36, "" },
//  { 0x13C37, "" },
//  { 0x13C38, "" },
//  { 0x13C39, "" },
//  { 0x13C3A, "" },
//  { 0x13C3B, "" },
//  { 0x13C3C, "" },
//  { 0x13C3D, "" },
//  { 0x13C3E, "" },
//  { 0x13C3F, "" },
//  { 0x13C40, "" },
//  { 0x13C41, "" },
//  { 0x13C42, "" },
//  { 0x13C43, "" },
//  { 0x13C44, "" },
//  { 0x13C45, "" },
//  { 0x13C46, "" },
//  { 0x13C47, "" },
//  { 0x13C48, "" },
//  { 0x13C49, "" },
//  { 0x13C4A, "" },
//  { 0x13C4B, "" },
//  { 0x13C4C, "" },
//  { 0x13C4D, "" },
//  { 0x13C4E, "" },
//  { 0x13C4F, "" },
//  { 0x13C50, "" },
//  { 0x13C51, "" },
//  { 0x13C52, "" },
//  { 0x13C53, "" },
//  { 0x13C54, "" },
//  { 0x13C55, "" },
//  { 0x13C56, "" },
//  { 0x13C57, "" },
//  { 0x13C58, "" },
//  { 0x13C59, "" },
//  { 0x13C5A, "" },
//  { 0x13C5B, "" },
//  { 0x13C5C, "" },
//  { 0x13C5D, "" },
//  { 0x13C5E, "" },
//  { 0x13C5F, "" },
//  { 0x13C60, "" },
//  { 0x13C61, "" },
//  { 0x13C62, "" },
//  { 0x13C63, "" },
//  { 0x13C64, "" },
//  { 0x13C65, "" },
//  { 0x13C66, "" },
//  { 0x13C67, "" },
//  { 0x13C68, "" },
//  { 0x13C69, "" },
//  { 0x13C6A, "" },
//  { 0x13C6B, "" },
//  { 0x13C6C, "" },
//  { 0x13C6D, "" },
//  { 0x13C6E, "" },
//  { 0x13C6F, "" },
//  { 0x13C70, "" },
//  { 0x13C71, "" },
//  { 0x13C72, "" },
//  { 0x13C73, "" },
//  { 0x13C74, "" },
//  { 0x13C75, "" },
//  { 0x13C76, "" },
//  { 0x13C77, "" },
//  { 0x13C78, "" },
//  { 0x13C79, "" },
//  { 0x13C7A, "" },
//  { 0x13C7B, "" },
//  { 0x13C7C, "" },
//  { 0x13C7D, "" },
//  { 0x13C7E, "" },
//  { 0x13C7F, "" },
//  { 0x13C80, "" },
//  { 0x13C81, "" },
//  { 0x13C82, "" },
//  { 0x13C83, "" },
//  { 0x13C84, "" },
//  { 0x13C85, "" },
//  { 0x13C86, "" },
//  { 0x13C87, "" },
//  { 0x13C88, "" },
//  { 0x13C89, "" },
//  { 0x13C8A, "" },
//  { 0x13C8B, "" },
//  { 0x13C8C, "" },
//  { 0x13C8D, "" },
//  { 0x13C8E, "" },
//  { 0x13C8F, "" },
//  { 0x13C90, "" },
//  { 0x13C91, "" },
//  { 0x13C92, "" },
//  { 0x13C93, "" },
//  { 0x13C94, "" },
//  { 0x13C95, "" },
//  { 0x13C96, "" },
//  { 0x13C97, "" },
//  { 0x13C98, "" },
//  { 0x13C99, "" },
//  { 0x13C9A, "" },
//  { 0x13C9B, "" },
//  { 0x13C9C, "" },
//  { 0x13C9D, "" },
//  { 0x13C9E, "" },
//  { 0x13C9F, "" },
//  { 0x13CA0, "" },
//  { 0x13CA1, "" },
//  { 0x13CA2, "" },
//  { 0x13CA3, "" },
//  { 0x13CA4, "" },
//  { 0x13CA5, "" },
//  { 0x13CA6, "" },
//  { 0x13CA7, "" },
//  { 0x13CA8, "" },
//  { 0x13CA9, "" },
//  { 0x13CAA, "" },
//  { 0x13CAB, "" },
//  { 0x13CAC, "" },
//  { 0x13CAD, "" },
//  { 0x13CAE, "" },
//  { 0x13CAF, "" },
//  { 0x13CB0, "" },
//  { 0x13CB1, "" },
//  { 0x13CB2, "" },
//  { 0x13CB3, "" },
//  { 0x13CB4, "" },
//  { 0x13CB5, "" },
//  { 0x13CB6, "" },
//  { 0x13CB7, "" },
//  { 0x13CB8, "" },
//  { 0x13CB9, "" },
//  { 0x13CBA, "" },
//  { 0x13CBB, "" },
//  { 0x13CBC, "" },
//  { 0x13CBD, "" },
//  { 0x13CBE, "" },
//  { 0x13CBF, "" },
//  { 0x13CC0, "" },
//  { 0x13CC1, "" },
//  { 0x13CC2, "" },
//  { 0x13CC3, "" },
//  { 0x13CC4, "" },
//  { 0x13CC5, "" },
//  { 0x13CC6, "" },
//  { 0x13CC7, "" },
//  { 0x13CC8, "" },
//  { 0x13CC9, "" },
//  { 0x13CCA, "" },
//  { 0x13CCB, "" },
//  { 0x13CCC, "" },
//  { 0x13CCD, "" },
//  { 0x13CCE, "" },
//  { 0x13CCF, "" },
//  { 0x13CD0, "" },
//  { 0x13CD1, "" },
//  { 0x13CD2, "" },
//  { 0x13CD3, "" },
//  { 0x13CD4, "" },
//  { 0x13CD5, "" },
//  { 0x13CD6, "" },
//  { 0x13CD7, "" },
//  { 0x13CD8, "" },
//  { 0x13CD9, "" },
//  { 0x13CDA, "" },
//  { 0x13CDB, "" },
//  { 0x13CDC, "" },
//  { 0x13CDD, "" },
//  { 0x13CDE, "" },
//  { 0x13CDF, "" },
//  { 0x13CE0, "" },
//  { 0x13CE1, "" },
//  { 0x13CE2, "" },
//  { 0x13CE3, "" },
//  { 0x13CE4, "" },
//  { 0x13CE5, "" },
//  { 0x13CE6, "" },
//  { 0x13CE7, "" },
//  { 0x13CE8, "" },
//  { 0x13CE9, "" },
//  { 0x13CEA, "" },
//  { 0x13CEB, "" },
//  { 0x13CEC, "" },
//  { 0x13CED, "" },
//  { 0x13CEE, "" },
//  { 0x13CEF, "" },
//  { 0x13CF0, "" },
//  { 0x13CF1, "" },
//  { 0x13CF2, "" },
//  { 0x13CF3, "" },
//  { 0x13CF4, "" },
//  { 0x13CF5, "" },
//  { 0x13CF6, "" },
//  { 0x13CF7, "" },
//  { 0x13CF8, "" },
//  { 0x13CF9, "" },
//  { 0x13CFA, "" },
//  { 0x13CFB, "" },
//  { 0x13CFC, "" },
//  { 0x13CFD, "" },
//  { 0x13CFE, "" },
//  { 0x13CFF, "" },
//  { 0x13D00, "" },
//  { 0x13D01, "" },
//  { 0x13D02, "" },
//  { 0x13D03, "" },
//  { 0x13D04, "" },
//  { 0x13D05, "" },
//  { 0x13D06, "" },
//  { 0x13D07, "" },
//  { 0x13D08, "" },
//  { 0x13D09, "" },
//  { 0x13D0A, "" },
//  { 0x13D0B, "" },
//  { 0x13D0C, "" },
//  { 0x13D0D, "" },
//  { 0x13D0E, "" },
//  { 0x13D0F, "" },
//  { 0x13D10, "" },
//  { 0x13D11, "" },
//  { 0x13D12, "" },
//  { 0x13D13, "" },
//  { 0x13D14, "" },
//  { 0x13D15, "" },
//  { 0x13D16, "" },
//  { 0x13D17, "" },
//  { 0x13D18, "" },
//  { 0x13D19, "" },
//  { 0x13D1A, "" },
//  { 0x13D1B, "" },
//  { 0x13D1C, "" },
//  { 0x13D1D, "" },
//  { 0x13D1E, "" },
//  { 0x13D1F, "" },
//  { 0x13D20, "" },
//  { 0x13D21, "" },
//  { 0x13D22, "" },
//  { 0x13D23, "" },
//  { 0x13D24, "" },
//  { 0x13D25, "" },
//  { 0x13D26, "" },
//  { 0x13D27, "" },
//  { 0x13D28, "" },
//  { 0x13D29, "" },
//  { 0x13D2A, "" },
//  { 0x13D2B, "" },
//  { 0x13D2C, "" },
//  { 0x13D2D, "" },
//  { 0x13D2E, "" },
//  { 0x13D2F, "" },
//  { 0x13D30, "" },
//  { 0x13D31, "" },
//  { 0x13D32, "" },
//  { 0x13D33, "" },
//  { 0x13D34, "" },
//  { 0x13D35, "" },
//  { 0x13D36, "" },
//  { 0x13D37, "" },
//  { 0x13D38, "" },
//  { 0x13D39, "" },
//  { 0x13D3A, "" },
//  { 0x13D3B, "" },
//  { 0x13D3C, "" },
//  { 0x13D3D, "" },
//  { 0x13D3E, "" },
//  { 0x13D3F, "" },
//  { 0x13D40, "" },
//  { 0x13D41, "" },
//  { 0x13D42, "" },
//  { 0x13D43, "" },
//  { 0x13D44, "" },
//  { 0x13D45, "" },
//  { 0x13D46, "" },
//  { 0x13D47, "" },
//  { 0x13D48, "" },
//  { 0x13D49, "" },
//  { 0x13D4A, "" },
//  { 0x13D4B, "" },
//  { 0x13D4C, "" },
//  { 0x13D4D, "" },
//  { 0x13D4E, "" },
//  { 0x13D4F, "" },
//  { 0x13D50, "" },
//  { 0x13D51, "" },
//  { 0x13D52, "" },
//  { 0x13D53, "" },
//  { 0x13D54, "" },
//  { 0x13D55, "" },
//  { 0x13D56, "" },
//  { 0x13D57, "" },
//  { 0x13D58, "" },
//  { 0x13D59, "" },
//  { 0x13D5A, "" },
//  { 0x13D5B, "" },
//  { 0x13D5C, "" },
//  { 0x13D5D, "" },
//  { 0x13D5E, "" },
//  { 0x13D5F, "" },
//  { 0x13D60, "" },
//  { 0x13D61, "" },
//  { 0x13D62, "" },
//  { 0x13D63, "" },
//  { 0x13D64, "" },
//  { 0x13D65, "" },
//  { 0x13D66, "" },
//  { 0x13D67, "" },
//  { 0x13D68, "" },
//  { 0x13D69, "" },
//  { 0x13D6A, "" },
//  { 0x13D6B, "" },
//  { 0x13D6C, "" },
//  { 0x13D6D, "" },
//  { 0x13D6E, "" },
//  { 0x13D6F, "" },
//  { 0x13D70, "" },
//  { 0x13D71, "" },
//  { 0x13D72, "" },
//  { 0x13D73, "" },
//  { 0x13D74, "" },
//  { 0x13D75, "" },
//  { 0x13D76, "" },
//  { 0x13D77, "" },
//  { 0x13D78, "" },
//  { 0x13D79, "" },
//  { 0x13D7A, "" },
//  { 0x13D7B, "" },
//  { 0x13D7C, "" },
//  { 0x13D7D, "" },
//  { 0x13D7E, "" },
//  { 0x13D7F, "" },
//  { 0x13D80, "" },
//  { 0x13D81, "" },
//  { 0x13D82, "" },
//  { 0x13D83, "" },
//  { 0x13D84, "" },
//  { 0x13D85, "" },
//  { 0x13D86, "" },
//  { 0x13D87, "" },
//  { 0x13D88, "" },
//  { 0x13D89, "" },
//  { 0x13D8A, "" },
//  { 0x13D8B, "" },
//  { 0x13D8C, "" },
//  { 0x13D8D, "" },
//  { 0x13D8E, "" },
//  { 0x13D8F, "" },
//  { 0x13D90, "" },
//  { 0x13D91, "" },
//  { 0x13D92, "" },
//  { 0x13D93, "" },
//  { 0x13D94, "" },
//  { 0x13D95, "" },
//  { 0x13D96, "" },
//  { 0x13D97, "" },
//  { 0x13D98, "" },
//  { 0x13D99, "" },
//  { 0x13D9A, "" },
//  { 0x13D9B, "" },
//  { 0x13D9C, "" },
//  { 0x13D9D, "" },
//  { 0x13D9E, "" },
//  { 0x13D9F, "" },
//  { 0x13DA0, "" },
//  { 0x13DA1, "" },
//  { 0x13DA2, "" },
//  { 0x13DA3, "" },
//  { 0x13DA4, "" },
//  { 0x13DA5, "" },
//  { 0x13DA6, "" },
//  { 0x13DA7, "" },
//  { 0x13DA8, "" },
//  { 0x13DA9, "" },
//  { 0x13DAA, "" },
//  { 0x13DAB, "" },
//  { 0x13DAC, "" },
//  { 0x13DAD, "" },
//  { 0x13DAE, "" },
//  { 0x13DAF, "" },
//  { 0x13DB0, "" },
//  { 0x13DB1, "" },
//  { 0x13DB2, "" },
//  { 0x13DB3, "" },
//  { 0x13DB4, "" },
//  { 0x13DB5, "" },
//  { 0x13DB6, "" },
//  { 0x13DB7, "" },
//  { 0x13DB8, "" },
//  { 0x13DB9, "" },
//  { 0x13DBA, "" },
//  { 0x13DBB, "" },
//  { 0x13DBC, "" },
//  { 0x13DBD, "" },
//  { 0x13DBE, "" },
//  { 0x13DBF, "" },
//  { 0x13DC0, "" },
//  { 0x13DC1, "" },
//  { 0x13DC2, "" },
//  { 0x13DC3, "" },
//  { 0x13DC4, "" },
//  { 0x13DC5, "" },
//  { 0x13DC6, "" },
//  { 0x13DC7, "" },
//  { 0x13DC8, "" },
//  { 0x13DC9, "" },
//  { 0x13DCA, "" },
//  { 0x13DCB, "" },
//  { 0x13DCC, "" },
//  { 0x13DCD, "" },
//  { 0x13DCE, "" },
//  { 0x13DCF, "" },
//  { 0x13DD0, "" },
//  { 0x13DD1, "" },
//  { 0x13DD2, "" },
//  { 0x13DD3, "" },
//  { 0x13DD4, "" },
//  { 0x13DD5, "" },
//  { 0x13DD6, "" },
//  { 0x13DD7, "" },
//  { 0x13DD8, "" },
//  { 0x13DD9, "" },
//  { 0x13DDA, "" },
//  { 0x13DDB, "" },
//  { 0x13DDC, "" },
//  { 0x13DDD, "" },
//  { 0x13DDE, "" },
//  { 0x13DDF, "" },
//  { 0x13DE0, "" },
//  { 0x13DE1, "" },
//  { 0x13DE2, "" },
//  { 0x13DE3, "" },
//  { 0x13DE4, "" },
//  { 0x13DE5, "" },
//  { 0x13DE6, "" },
//  { 0x13DE7, "" },
//  { 0x13DE8, "" },
//  { 0x13DE9, "" },
//  { 0x13DEA, "" },
//  { 0x13DEB, "" },
//  { 0x13DEC, "" },
//  { 0x13DED, "" },
//  { 0x13DEE, "" },
//  { 0x13DEF, "" },
//  { 0x13DF0, "" },
//  { 0x13DF1, "" },
//  { 0x13DF2, "" },
//  { 0x13DF3, "" },
//  { 0x13DF4, "" },
//  { 0x13DF5, "" },
//  { 0x13DF6, "" },
//  { 0x13DF7, "" },
//  { 0x13DF8, "" },
//  { 0x13DF9, "" },
//  { 0x13DFA, "" },
//  { 0x13DFB, "" },
//  { 0x13DFC, "" },
//  { 0x13DFD, "" },
//  { 0x13DFE, "" },
//  { 0x13DFF, "" },
//  { 0x13E00, "" },
//  { 0x13E01, "" },
//  { 0x13E02, "" },
//  { 0x13E03, "" },
//  { 0x13E04, "" },
//  { 0x13E05, "" },
//  { 0x13E06, "" },
//  { 0x13E07, "" },
//  { 0x13E08, "" },
//  { 0x13E09, "" },
//  { 0x13E0A, "" },
//  { 0x13E0B, "" },
//  { 0x13E0C, "" },
//  { 0x13E0D, "" },
//  { 0x13E0E, "" },
//  { 0x13E0F, "" },
//  { 0x13E10, "" },
//  { 0x13E11, "" },
//  { 0x13E12, "" },
//  { 0x13E13, "" },
//  { 0x13E14, "" },
//  { 0x13E15, "" },
//  { 0x13E16, "" },
//  { 0x13E17, "" },
//  { 0x13E18, "" },
//  { 0x13E19, "" },
//  { 0x13E1A, "" },
//  { 0x13E1B, "" },
//  { 0x13E1C, "" },
//  { 0x13E1D, "" },
//  { 0x13E1E, "" },
//  { 0x13E1F, "" },
//  { 0x13E20, "" },
//  { 0x13E21, "" },
//  { 0x13E22, "" },
//  { 0x13E23, "" },
//  { 0x13E24, "" },
//  { 0x13E25, "" },
//  { 0x13E26, "" },
//  { 0x13E27, "" },
//  { 0x13E28, "" },
//  { 0x13E29, "" },
//  { 0x13E2A, "" },
//  { 0x13E2B, "" },
//  { 0x13E2C, "" },
//  { 0x13E2D, "" },
//  { 0x13E2E, "" },
//  { 0x13E2F, "" },
//  { 0x13E30, "" },
//  { 0x13E31, "" },
//  { 0x13E32, "" },
//  { 0x13E33, "" },
//  { 0x13E34, "" },
//  { 0x13E35, "" },
//  { 0x13E36, "" },
//  { 0x13E37, "" },
//  { 0x13E38, "" },
//  { 0x13E39, "" },
//  { 0x13E3A, "" },
//  { 0x13E3B, "" },
//  { 0x13E3C, "" },
//  { 0x13E3D, "" },
//  { 0x13E3E, "" },
//  { 0x13E3F, "" },
//  { 0x13E40, "" },
//  { 0x13E41, "" },
//  { 0x13E42, "" },
//  { 0x13E43, "" },
//  { 0x13E44, "" },
//  { 0x13E45, "" },
//  { 0x13E46, "" },
//  { 0x13E47, "" },
//  { 0x13E48, "" },
//  { 0x13E49, "" },
//  { 0x13E4A, "" },
//  { 0x13E4B, "" },
//  { 0x13E4C, "" },
//  { 0x13E4D, "" },
//  { 0x13E4E, "" },
//  { 0x13E4F, "" },
//  { 0x13E50, "" },
//  { 0x13E51, "" },
//  { 0x13E52, "" },
//  { 0x13E53, "" },
//  { 0x13E54, "" },
//  { 0x13E55, "" },
//  { 0x13E56, "" },
//  { 0x13E57, "" },
//  { 0x13E58, "" },
//  { 0x13E59, "" },
//  { 0x13E5A, "" },
//  { 0x13E5B, "" },
//  { 0x13E5C, "" },
//  { 0x13E5D, "" },
//  { 0x13E5E, "" },
//  { 0x13E5F, "" },
//  { 0x13E60, "" },
//  { 0x13E61, "" },
//  { 0x13E62, "" },
//  { 0x13E63, "" },
//  { 0x13E64, "" },
//  { 0x13E65, "" },
//  { 0x13E66, "" },
//  { 0x13E67, "" },
//  { 0x13E68, "" },
//  { 0x13E69, "" },
//  { 0x13E6A, "" },
//  { 0x13E6B, "" },
//  { 0x13E6C, "" },
//  { 0x13E6D, "" },
//  { 0x13E6E, "" },
//  { 0x13E6F, "" },
//  { 0x13E70, "" },
//  { 0x13E71, "" },
//  { 0x13E72, "" },
//  { 0x13E73, "" },
//  { 0x13E74, "" },
//  { 0x13E75, "" },
//  { 0x13E76, "" },
//  { 0x13E77, "" },
//  { 0x13E78, "" },
//  { 0x13E79, "" },
//  { 0x13E7A, "" },
//  { 0x13E7B, "" },
//  { 0x13E7C, "" },
//  { 0x13E7D, "" },
//  { 0x13E7E, "" },
//  { 0x13E7F, "" },
//  { 0x13E80, "" },
//  { 0x13E81, "" },
//  { 0x13E82, "" },
//  { 0x13E83, "" },
//  { 0x13E84, "" },
//  { 0x13E85, "" },
//  { 0x13E86, "" },
//  { 0x13E87, "" },
//  { 0x13E88, "" },
//  { 0x13E89, "" },
//  { 0x13E8A, "" },
//  { 0x13E8B, "" },
//  { 0x13E8C, "" },
//  { 0x13E8D, "" },
//  { 0x13E8E, "" },
//  { 0x13E8F, "" },
//  { 0x13E90, "" },
//  { 0x13E91, "" },
//  { 0x13E92, "" },
//  { 0x13E93, "" },
//  { 0x13E94, "" },
//  { 0x13E95, "" },
//  { 0x13E96, "" },
//  { 0x13E97, "" },
//  { 0x13E98, "" },
//  { 0x13E99, "" },
//  { 0x13E9A, "" },
//  { 0x13E9B, "" },
//  { 0x13E9C, "" },
//  { 0x13E9D, "" },
//  { 0x13E9E, "" },
//  { 0x13E9F, "" },
//  { 0x13EA0, "" },
//  { 0x13EA1, "" },
//  { 0x13EA2, "" },
//  { 0x13EA3, "" },
//  { 0x13EA4, "" },
//  { 0x13EA5, "" },
//  { 0x13EA6, "" },
//  { 0x13EA7, "" },
//  { 0x13EA8, "" },
//  { 0x13EA9, "" },
//  { 0x13EAA, "" },
//  { 0x13EAB, "" },
//  { 0x13EAC, "" },
//  { 0x13EAD, "" },
//  { 0x13EAE, "" },
//  { 0x13EAF, "" },
//  { 0x13EB0, "" },
//  { 0x13EB1, "" },
//  { 0x13EB2, "" },
//  { 0x13EB3, "" },
//  { 0x13EB4, "" },
//  { 0x13EB5, "" },
//  { 0x13EB6, "" },
//  { 0x13EB7, "" },
//  { 0x13EB8, "" },
//  { 0x13EB9, "" },
//  { 0x13EBA, "" },
//  { 0x13EBB, "" },
//  { 0x13EBC, "" },
//  { 0x13EBD, "" },
//  { 0x13EBE, "" },
//  { 0x13EBF, "" },
//  { 0x13EC0, "" },
//  { 0x13EC1, "" },
//  { 0x13EC2, "" },
//  { 0x13EC3, "" },
//  { 0x13EC4, "" },
//  { 0x13EC5, "" },
//  { 0x13EC6, "" },
//  { 0x13EC7, "" },
//  { 0x13EC8, "" },
//  { 0x13EC9, "" },
//  { 0x13ECA, "" },
//  { 0x13ECB, "" },
//  { 0x13ECC, "" },
//  { 0x13ECD, "" },
//  { 0x13ECE, "" },
//  { 0x13ECF, "" },
//  { 0x13ED0, "" },
//  { 0x13ED1, "" },
//  { 0x13ED2, "" },
//  { 0x13ED3, "" },
//  { 0x13ED4, "" },
//  { 0x13ED5, "" },
//  { 0x13ED6, "" },
//  { 0x13ED7, "" },
//  { 0x13ED8, "" },
//  { 0x13ED9, "" },
//  { 0x13EDA, "" },
//  { 0x13EDB, "" },
//  { 0x13EDC, "" },
//  { 0x13EDD, "" },
//  { 0x13EDE, "" },
//  { 0x13EDF, "" },
//  { 0x13EE0, "" },
//  { 0x13EE1, "" },
//  { 0x13EE2, "" },
//  { 0x13EE3, "" },
//  { 0x13EE4, "" },
//  { 0x13EE5, "" },
//  { 0x13EE6, "" },
//  { 0x13EE7, "" },
//  { 0x13EE8, "" },
//  { 0x13EE9, "" },
//  { 0x13EEA, "" },
//  { 0x13EEB, "" },
//  { 0x13EEC, "" },
//  { 0x13EED, "" },
//  { 0x13EEE, "" },
//  { 0x13EEF, "" },
//  { 0x13EF0, "" },
//  { 0x13EF1, "" },
//  { 0x13EF2, "" },
//  { 0x13EF3, "" },
//  { 0x13EF4, "" },
//  { 0x13EF5, "" },
//  { 0x13EF6, "" },
//  { 0x13EF7, "" },
//  { 0x13EF8, "" },
//  { 0x13EF9, "" },
//  { 0x13EFA, "" },
//  { 0x13EFB, "" },
//  { 0x13EFC, "" },
//  { 0x13EFD, "" },
//  { 0x13EFE, "" },
//  { 0x13EFF, "" },
//  { 0x13F00, "" },
//  { 0x13F01, "" },
//  { 0x13F02, "" },
//  { 0x13F03, "" },
//  { 0x13F04, "" },
//  { 0x13F05, "" },
//  { 0x13F06, "" },
//  { 0x13F07, "" },
//  { 0x13F08, "" },
//  { 0x13F09, "" },
//  { 0x13F0A, "" },
//  { 0x13F0B, "" },
//  { 0x13F0C, "" },
//  { 0x13F0D, "" },
//  { 0x13F0E, "" },
//  { 0x13F0F, "" },
//  { 0x13F10, "" },
//  { 0x13F11, "" },
//  { 0x13F12, "" },
//  { 0x13F13, "" },
//  { 0x13F14, "" },
//  { 0x13F15, "" },
//  { 0x13F16, "" },
//  { 0x13F17, "" },
//  { 0x13F18, "" },
//  { 0x13F19, "" },
//  { 0x13F1A, "" },
//  { 0x13F1B, "" },
//  { 0x13F1C, "" },
//  { 0x13F1D, "" },
//  { 0x13F1E, "" },
//  { 0x13F1F, "" },
//  { 0x13F20, "" },
//  { 0x13F21, "" },
//  { 0x13F22, "" },
//  { 0x13F23, "" },
//  { 0x13F24, "" },
//  { 0x13F25, "" },
//  { 0x13F26, "" },
//  { 0x13F27, "" },
//  { 0x13F28, "" },
//  { 0x13F29, "" },
//  { 0x13F2A, "" },
//  { 0x13F2B, "" },
//  { 0x13F2C, "" },
//  { 0x13F2D, "" },
//  { 0x13F2E, "" },
//  { 0x13F2F, "" },
//  { 0x13F30, "" },
//  { 0x13F31, "" },
//  { 0x13F32, "" },
//  { 0x13F33, "" },
//  { 0x13F34, "" },
//  { 0x13F35, "" },
//  { 0x13F36, "" },
//  { 0x13F37, "" },
//  { 0x13F38, "" },
//  { 0x13F39, "" },
//  { 0x13F3A, "" },
//  { 0x13F3B, "" },
//  { 0x13F3C, "" },
//  { 0x13F3D, "" },
//  { 0x13F3E, "" },
//  { 0x13F3F, "" },
//  { 0x13F40, "" },
//  { 0x13F41, "" },
//  { 0x13F42, "" },
//  { 0x13F43, "" },
//  { 0x13F44, "" },
//  { 0x13F45, "" },
//  { 0x13F46, "" },
//  { 0x13F47, "" },
//  { 0x13F48, "" },
//  { 0x13F49, "" },
//  { 0x13F4A, "" },
//  { 0x13F4B, "" },
//  { 0x13F4C, "" },
//  { 0x13F4D, "" },
//  { 0x13F4E, "" },
//  { 0x13F4F, "" },
//  { 0x13F50, "" },
//  { 0x13F51, "" },
//  { 0x13F52, "" },
//  { 0x13F53, "" },
//  { 0x13F54, "" },
//  { 0x13F55, "" },
//  { 0x13F56, "" },
//  { 0x13F57, "" },
//  { 0x13F58, "" },
//  { 0x13F59, "" },
//  { 0x13F5A, "" },
//  { 0x13F5B, "" },
//  { 0x13F5C, "" },
//  { 0x13F5D, "" },
//  { 0x13F5E, "" },
//  { 0x13F5F, "" },
//  { 0x13F60, "" },
//  { 0x13F61, "" },
//  { 0x13F62, "" },
//  { 0x13F63, "" },
//  { 0x13F64, "" },
//  { 0x13F65, "" },
//  { 0x13F66, "" },
//  { 0x13F67, "" },
//  { 0x13F68, "" },
//  { 0x13F69, "" },
//  { 0x13F6A, "" },
//  { 0x13F6B, "" },
//  { 0x13F6C, "" },
//  { 0x13F6D, "" },
//  { 0x13F6E, "" },
//  { 0x13F6F, "" },
//  { 0x13F70, "" },
//  { 0x13F71, "" },
//  { 0x13F72, "" },
//  { 0x13F73, "" },
//  { 0x13F74, "" },
//  { 0x13F75, "" },
//  { 0x13F76, "" },
//  { 0x13F77, "" },
//  { 0x13F78, "" },
//  { 0x13F79, "" },
//  { 0x13F7A, "" },
//  { 0x13F7B, "" },
//  { 0x13F7C, "" },
//  { 0x13F7D, "" },
//  { 0x13F7E, "" },
//  { 0x13F7F, "" },
//  { 0x13F80, "" },
//  { 0x13F81, "" },
//  { 0x13F82, "" },
//  { 0x13F83, "" },
//  { 0x13F84, "" },
//  { 0x13F85, "" },
//  { 0x13F86, "" },
//  { 0x13F87, "" },
//  { 0x13F88, "" },
//  { 0x13F89, "" },
//  { 0x13F8A, "" },
//  { 0x13F8B, "" },
//  { 0x13F8C, "" },
//  { 0x13F8D, "" },
//  { 0x13F8E, "" },
//  { 0x13F8F, "" },
//  { 0x13F90, "" },
//  { 0x13F91, "" },
//  { 0x13F92, "" },
//  { 0x13F93, "" },
//  { 0x13F94, "" },
//  { 0x13F95, "" },
//  { 0x13F96, "" },
//  { 0x13F97, "" },
//  { 0x13F98, "" },
//  { 0x13F99, "" },
//  { 0x13F9A, "" },
//  { 0x13F9B, "" },
//  { 0x13F9C, "" },
//  { 0x13F9D, "" },
//  { 0x13F9E, "" },
//  { 0x13F9F, "" },
//  { 0x13FA0, "" },
//  { 0x13FA1, "" },
//  { 0x13FA2, "" },
//  { 0x13FA3, "" },
//  { 0x13FA4, "" },
//  { 0x13FA5, "" },
//  { 0x13FA6, "" },
//  { 0x13FA7, "" },
//  { 0x13FA8, "" },
//  { 0x13FA9, "" },
//  { 0x13FAA, "" },
//  { 0x13FAB, "" },
//  { 0x13FAC, "" },
//  { 0x13FAD, "" },
//  { 0x13FAE, "" },
//  { 0x13FAF, "" },
//  { 0x13FB0, "" },
//  { 0x13FB1, "" },
//  { 0x13FB2, "" },
//  { 0x13FB3, "" },
//  { 0x13FB4, "" },
//  { 0x13FB5, "" },
//  { 0x13FB6, "" },
//  { 0x13FB7, "" },
//  { 0x13FB8, "" },
//  { 0x13FB9, "" },
//  { 0x13FBA, "" },
//  { 0x13FBB, "" },
//  { 0x13FBC, "" },
//  { 0x13FBD, "" },
//  { 0x13FBE, "" },
//  { 0x13FBF, "" },
//  { 0x13FC0, "" },
//  { 0x13FC1, "" },
//  { 0x13FC2, "" },
//  { 0x13FC3, "" },
//  { 0x13FC4, "" },
//  { 0x13FC5, "" },
//  { 0x13FC6, "" },
//  { 0x13FC7, "" },
//  { 0x13FC8, "" },
//  { 0x13FC9, "" },
//  { 0x13FCA, "" },
//  { 0x13FCB, "" },
//  { 0x13FCC, "" },
//  { 0x13FCD, "" },
//  { 0x13FCE, "" },
//  { 0x13FCF, "" },
//  { 0x13FD0, "" },
//  { 0x13FD1, "" },
//  { 0x13FD2, "" },
//  { 0x13FD3, "" },
//  { 0x13FD4, "" },
//  { 0x13FD5, "" },
//  { 0x13FD6, "" },
//  { 0x13FD7, "" },
//  { 0x13FD8, "" },
//  { 0x13FD9, "" },
//  { 0x13FDA, "" },
//  { 0x13FDB, "" },
//  { 0x13FDC, "" },
//  { 0x13FDD, "" },
//  { 0x13FDE, "" },
//  { 0x13FDF, "" },
//  { 0x13FE0, "" },
//  { 0x13FE1, "" },
//  { 0x13FE2, "" },
//  { 0x13FE3, "" },
//  { 0x13FE4, "" },
//  { 0x13FE5, "" },
//  { 0x13FE6, "" },
//  { 0x13FE7, "" },
//  { 0x13FE8, "" },
//  { 0x13FE9, "" },
//  { 0x13FEA, "" },
//  { 0x13FEB, "" },
//  { 0x13FEC, "" },
//  { 0x13FED, "" },
//  { 0x13FEE, "" },
//  { 0x13FEF, "" },
//  { 0x13FF0, "" },
//  { 0x13FF1, "" },
//  { 0x13FF2, "" },
//  { 0x13FF3, "" },
//  { 0x13FF4, "" },
//  { 0x13FF5, "" },
//  { 0x13FF6, "" },
//  { 0x13FF7, "" },
//  { 0x13FF8, "" },
//  { 0x13FF9, "" },
//  { 0x13FFA, "" },
//  { 0x13FFB, "" },
//  { 0x13FFC, "" },
//  { 0x13FFD, "" },
//  { 0x13FFE, "" },
//  { 0x13FFF, "" },
//  { 0x14000, "" },
//  { 0x14001, "" },
//  { 0x14002, "" },
//  { 0x14003, "" },
//  { 0x14004, "" },
//  { 0x14005, "" },
//  { 0x14006, "" },
//  { 0x14007, "" },
//  { 0x14008, "" },
//  { 0x14009, "" },
//  { 0x1400A, "" },
//  { 0x1400B, "" },
//  { 0x1400C, "" },
//  { 0x1400D, "" },
//  { 0x1400E, "" },
//  { 0x1400F, "" },
//  { 0x14010, "" },
//  { 0x14011, "" },
//  { 0x14012, "" },
//  { 0x14013, "" },
//  { 0x14014, "" },
//  { 0x14015, "" },
//  { 0x14016, "" },
//  { 0x14017, "" },
//  { 0x14018, "" },
//  { 0x14019, "" },
//  { 0x1401A, "" },
//  { 0x1401B, "" },
//  { 0x1401C, "" },
//  { 0x1401D, "" },
//  { 0x1401E, "" },
//  { 0x1401F, "" },
//  { 0x14020, "" },
//  { 0x14021, "" },
//  { 0x14022, "" },
//  { 0x14023, "" },
//  { 0x14024, "" },
//  { 0x14025, "" },
//  { 0x14026, "" },
//  { 0x14027, "" },
//  { 0x14028, "" },
//  { 0x14029, "" },
//  { 0x1402A, "" },
//  { 0x1402B, "" },
//  { 0x1402C, "" },
//  { 0x1402D, "" },
//  { 0x1402E, "" },
//  { 0x1402F, "" },
//  { 0x14030, "" },
//  { 0x14031, "" },
//  { 0x14032, "" },
//  { 0x14033, "" },
//  { 0x14034, "" },
//  { 0x14035, "" },
//  { 0x14036, "" },
//  { 0x14037, "" },
//  { 0x14038, "" },
//  { 0x14039, "" },
//  { 0x1403A, "" },
//  { 0x1403B, "" },
//  { 0x1403C, "" },
//  { 0x1403D, "" },
//  { 0x1403E, "" },
//  { 0x1403F, "" },
//  { 0x14040, "" },
//  { 0x14041, "" },
//  { 0x14042, "" },
//  { 0x14043, "" },
//  { 0x14044, "" },
//  { 0x14045, "" },
//  { 0x14046, "" },
//  { 0x14047, "" },
//  { 0x14048, "" },
//  { 0x14049, "" },
//  { 0x1404A, "" },
//  { 0x1404B, "" },
//  { 0x1404C, "" },
//  { 0x1404D, "" },
//  { 0x1404E, "" },
//  { 0x1404F, "" },
//  { 0x14050, "" },
//  { 0x14051, "" },
//  { 0x14052, "" },
//  { 0x14053, "" },
//  { 0x14054, "" },
//  { 0x14055, "" },
//  { 0x14056, "" },
//  { 0x14057, "" },
//  { 0x14058, "" },
//  { 0x14059, "" },
//  { 0x1405A, "" },
//  { 0x1405B, "" },
//  { 0x1405C, "" },
//  { 0x1405D, "" },
//  { 0x1405E, "" },
//  { 0x1405F, "" },
//  { 0x14060, "" },
//  { 0x14061, "" },
//  { 0x14062, "" },
//  { 0x14063, "" },
//  { 0x14064, "" },
//  { 0x14065, "" },
//  { 0x14066, "" },
//  { 0x14067, "" },
//  { 0x14068, "" },
//  { 0x14069, "" },
//  { 0x1406A, "" },
//  { 0x1406B, "" },
//  { 0x1406C, "" },
//  { 0x1406D, "" },
//  { 0x1406E, "" },
//  { 0x1406F, "" },
//  { 0x14070, "" },
//  { 0x14071, "" },
//  { 0x14072, "" },
//  { 0x14073, "" },
//  { 0x14074, "" },
//  { 0x14075, "" },
//  { 0x14076, "" },
//  { 0x14077, "" },
//  { 0x14078, "" },
//  { 0x14079, "" },
//  { 0x1407A, "" },
//  { 0x1407B, "" },
//  { 0x1407C, "" },
//  { 0x1407D, "" },
//  { 0x1407E, "" },
//  { 0x1407F, "" },
//  { 0x14080, "" },
//  { 0x14081, "" },
//  { 0x14082, "" },
//  { 0x14083, "" },
//  { 0x14084, "" },
//  { 0x14085, "" },
//  { 0x14086, "" },
//  { 0x14087, "" },
//  { 0x14088, "" },
//  { 0x14089, "" },
//  { 0x1408A, "" },
//  { 0x1408B, "" },
//  { 0x1408C, "" },
//  { 0x1408D, "" },
//  { 0x1408E, "" },
//  { 0x1408F, "" },
//  { 0x14090, "" },
//  { 0x14091, "" },
//  { 0x14092, "" },
//  { 0x14093, "" },
//  { 0x14094, "" },
//  { 0x14095, "" },
//  { 0x14096, "" },
//  { 0x14097, "" },
//  { 0x14098, "" },
//  { 0x14099, "" },
//  { 0x1409A, "" },
//  { 0x1409B, "" },
//  { 0x1409C, "" },
//  { 0x1409D, "" },
//  { 0x1409E, "" },
//  { 0x1409F, "" },
//  { 0x140A0, "" },
//  { 0x140A1, "" },
//  { 0x140A2, "" },
//  { 0x140A3, "" },
//  { 0x140A4, "" },
//  { 0x140A5, "" },
//  { 0x140A6, "" },
//  { 0x140A7, "" },
//  { 0x140A8, "" },
//  { 0x140A9, "" },
//  { 0x140AA, "" },
//  { 0x140AB, "" },
//  { 0x140AC, "" },
//  { 0x140AD, "" },
//  { 0x140AE, "" },
//  { 0x140AF, "" },
//  { 0x140B0, "" },
//  { 0x140B1, "" },
//  { 0x140B2, "" },
//  { 0x140B3, "" },
//  { 0x140B4, "" },
//  { 0x140B5, "" },
//  { 0x140B6, "" },
//  { 0x140B7, "" },
//  { 0x140B8, "" },
//  { 0x140B9, "" },
//  { 0x140BA, "" },
//  { 0x140BB, "" },
//  { 0x140BC, "" },
//  { 0x140BD, "" },
//  { 0x140BE, "" },
//  { 0x140BF, "" },
//  { 0x140C0, "" },
//  { 0x140C1, "" },
//  { 0x140C2, "" },
//  { 0x140C3, "" },
//  { 0x140C4, "" },
//  { 0x140C5, "" },
//  { 0x140C6, "" },
//  { 0x140C7, "" },
//  { 0x140C8, "" },
//  { 0x140C9, "" },
//  { 0x140CA, "" },
//  { 0x140CB, "" },
//  { 0x140CC, "" },
//  { 0x140CD, "" },
//  { 0x140CE, "" },
//  { 0x140CF, "" },
//  { 0x140D0, "" },
//  { 0x140D1, "" },
//  { 0x140D2, "" },
//  { 0x140D3, "" },
//  { 0x140D4, "" },
//  { 0x140D5, "" },
//  { 0x140D6, "" },
//  { 0x140D7, "" },
//  { 0x140D8, "" },
//  { 0x140D9, "" },
//  { 0x140DA, "" },
//  { 0x140DB, "" },
//  { 0x140DC, "" },
//  { 0x140DD, "" },
//  { 0x140DE, "" },
//  { 0x140DF, "" },
//  { 0x140E0, "" },
//  { 0x140E1, "" },
//  { 0x140E2, "" },
//  { 0x140E3, "" },
//  { 0x140E4, "" },
//  { 0x140E5, "" },
//  { 0x140E6, "" },
//  { 0x140E7, "" },
//  { 0x140E8, "" },
//  { 0x140E9, "" },
//  { 0x140EA, "" },
//  { 0x140EB, "" },
//  { 0x140EC, "" },
//  { 0x140ED, "" },
//  { 0x140EE, "" },
//  { 0x140EF, "" },
//  { 0x140F0, "" },
//  { 0x140F1, "" },
//  { 0x140F2, "" },
//  { 0x140F3, "" },
//  { 0x140F4, "" },
//  { 0x140F5, "" },
//  { 0x140F6, "" },
//  { 0x140F7, "" },
//  { 0x140F8, "" },
//  { 0x140F9, "" },
//  { 0x140FA, "" },
//  { 0x140FB, "" },
//  { 0x140FC, "" },
//  { 0x140FD, "" },
//  { 0x140FE, "" },
//  { 0x140FF, "" },
//  { 0x14100, "" },
//  { 0x14101, "" },
//  { 0x14102, "" },
//  { 0x14103, "" },
//  { 0x14104, "" },
//  { 0x14105, "" },
//  { 0x14106, "" },
//  { 0x14107, "" },
//  { 0x14108, "" },
//  { 0x14109, "" },
//  { 0x1410A, "" },
//  { 0x1410B, "" },
//  { 0x1410C, "" },
//  { 0x1410D, "" },
//  { 0x1410E, "" },
//  { 0x1410F, "" },
//  { 0x14110, "" },
//  { 0x14111, "" },
//  { 0x14112, "" },
//  { 0x14113, "" },
//  { 0x14114, "" },
//  { 0x14115, "" },
//  { 0x14116, "" },
//  { 0x14117, "" },
//  { 0x14118, "" },
//  { 0x14119, "" },
//  { 0x1411A, "" },
//  { 0x1411B, "" },
//  { 0x1411C, "" },
//  { 0x1411D, "" },
//  { 0x1411E, "" },
//  { 0x1411F, "" },
//  { 0x14120, "" },
//  { 0x14121, "" },
//  { 0x14122, "" },
//  { 0x14123, "" },
//  { 0x14124, "" },
//  { 0x14125, "" },
//  { 0x14126, "" },
//  { 0x14127, "" },
//  { 0x14128, "" },
//  { 0x14129, "" },
//  { 0x1412A, "" },
//  { 0x1412B, "" },
//  { 0x1412C, "" },
//  { 0x1412D, "" },
//  { 0x1412E, "" },
//  { 0x1412F, "" },
//  { 0x14130, "" },
//  { 0x14131, "" },
//  { 0x14132, "" },
//  { 0x14133, "" },
//  { 0x14134, "" },
//  { 0x14135, "" },
//  { 0x14136, "" },
//  { 0x14137, "" },
//  { 0x14138, "" },
//  { 0x14139, "" },
//  { 0x1413A, "" },
//  { 0x1413B, "" },
//  { 0x1413C, "" },
//  { 0x1413D, "" },
//  { 0x1413E, "" },
//  { 0x1413F, "" },
//  { 0x14140, "" },
//  { 0x14141, "" },
//  { 0x14142, "" },
//  { 0x14143, "" },
//  { 0x14144, "" },
//  { 0x14145, "" },
//  { 0x14146, "" },
//  { 0x14147, "" },
//  { 0x14148, "" },
//  { 0x14149, "" },
//  { 0x1414A, "" },
//  { 0x1414B, "" },
//  { 0x1414C, "" },
//  { 0x1414D, "" },
//  { 0x1414E, "" },
//  { 0x1414F, "" },
//  { 0x14150, "" },
//  { 0x14151, "" },
//  { 0x14152, "" },
//  { 0x14153, "" },
//  { 0x14154, "" },
//  { 0x14155, "" },
//  { 0x14156, "" },
//  { 0x14157, "" },
//  { 0x14158, "" },
//  { 0x14159, "" },
//  { 0x1415A, "" },
//  { 0x1415B, "" },
//  { 0x1415C, "" },
//  { 0x1415D, "" },
//  { 0x1415E, "" },
//  { 0x1415F, "" },
//  { 0x14160, "" },
//  { 0x14161, "" },
//  { 0x14162, "" },
//  { 0x14163, "" },
//  { 0x14164, "" },
//  { 0x14165, "" },
//  { 0x14166, "" },
//  { 0x14167, "" },
//  { 0x14168, "" },
//  { 0x14169, "" },
//  { 0x1416A, "" },
//  { 0x1416B, "" },
//  { 0x1416C, "" },
//  { 0x1416D, "" },
//  { 0x1416E, "" },
//  { 0x1416F, "" },
//  { 0x14170, "" },
//  { 0x14171, "" },
//  { 0x14172, "" },
//  { 0x14173, "" },
//  { 0x14174, "" },
//  { 0x14175, "" },
//  { 0x14176, "" },
//  { 0x14177, "" },
//  { 0x14178, "" },
//  { 0x14179, "" },
//  { 0x1417A, "" },
//  { 0x1417B, "" },
//  { 0x1417C, "" },
//  { 0x1417D, "" },
//  { 0x1417E, "" },
//  { 0x1417F, "" },
//  { 0x14180, "" },
//  { 0x14181, "" },
//  { 0x14182, "" },
//  { 0x14183, "" },
//  { 0x14184, "" },
//  { 0x14185, "" },
//  { 0x14186, "" },
//  { 0x14187, "" },
//  { 0x14188, "" },
//  { 0x14189, "" },
//  { 0x1418A, "" },
//  { 0x1418B, "" },
//  { 0x1418C, "" },
//  { 0x1418D, "" },
//  { 0x1418E, "" },
//  { 0x1418F, "" },
//  { 0x14190, "" },
//  { 0x14191, "" },
//  { 0x14192, "" },
//  { 0x14193, "" },
//  { 0x14194, "" },
//  { 0x14195, "" },
//  { 0x14196, "" },
//  { 0x14197, "" },
//  { 0x14198, "" },
//  { 0x14199, "" },
//  { 0x1419A, "" },
//  { 0x1419B, "" },
//  { 0x1419C, "" },
//  { 0x1419D, "" },
//  { 0x1419E, "" },
//  { 0x1419F, "" },
//  { 0x141A0, "" },
//  { 0x141A1, "" },
//  { 0x141A2, "" },
//  { 0x141A3, "" },
//  { 0x141A4, "" },
//  { 0x141A5, "" },
//  { 0x141A6, "" },
//  { 0x141A7, "" },
//  { 0x141A8, "" },
//  { 0x141A9, "" },
//  { 0x141AA, "" },
//  { 0x141AB, "" },
//  { 0x141AC, "" },
//  { 0x141AD, "" },
//  { 0x141AE, "" },
//  { 0x141AF, "" },
//  { 0x141B0, "" },
//  { 0x141B1, "" },
//  { 0x141B2, "" },
//  { 0x141B3, "" },
//  { 0x141B4, "" },
//  { 0x141B5, "" },
//  { 0x141B6, "" },
//  { 0x141B7, "" },
//  { 0x141B8, "" },
//  { 0x141B9, "" },
//  { 0x141BA, "" },
//  { 0x141BB, "" },
//  { 0x141BC, "" },
//  { 0x141BD, "" },
//  { 0x141BE, "" },
//  { 0x141BF, "" },
//  { 0x141C0, "" },
//  { 0x141C1, "" },
//  { 0x141C2, "" },
//  { 0x141C3, "" },
//  { 0x141C4, "" },
//  { 0x141C5, "" },
//  { 0x141C6, "" },
//  { 0x141C7, "" },
//  { 0x141C8, "" },
//  { 0x141C9, "" },
//  { 0x141CA, "" },
//  { 0x141CB, "" },
//  { 0x141CC, "" },
//  { 0x141CD, "" },
//  { 0x141CE, "" },
//  { 0x141CF, "" },
//  { 0x141D0, "" },
//  { 0x141D1, "" },
//  { 0x141D2, "" },
//  { 0x141D3, "" },
//  { 0x141D4, "" },
//  { 0x141D5, "" },
//  { 0x141D6, "" },
//  { 0x141D7, "" },
//  { 0x141D8, "" },
//  { 0x141D9, "" },
//  { 0x141DA, "" },
//  { 0x141DB, "" },
//  { 0x141DC, "" },
//  { 0x141DD, "" },
//  { 0x141DE, "" },
//  { 0x141DF, "" },
//  { 0x141E0, "" },
//  { 0x141E1, "" },
//  { 0x141E2, "" },
//  { 0x141E3, "" },
//  { 0x141E4, "" },
//  { 0x141E5, "" },
//  { 0x141E6, "" },
//  { 0x141E7, "" },
//  { 0x141E8, "" },
//  { 0x141E9, "" },
//  { 0x141EA, "" },
//  { 0x141EB, "" },
//  { 0x141EC, "" },
//  { 0x141ED, "" },
//  { 0x141EE, "" },
//  { 0x141EF, "" },
//  { 0x141F0, "" },
//  { 0x141F1, "" },
//  { 0x141F2, "" },
//  { 0x141F3, "" },
//  { 0x141F4, "" },
//  { 0x141F5, "" },
//  { 0x141F6, "" },
//  { 0x141F7, "" },
//  { 0x141F8, "" },
//  { 0x141F9, "" },
//  { 0x141FA, "" },
//  { 0x141FB, "" },
//  { 0x141FC, "" },
//  { 0x141FD, "" },
//  { 0x141FE, "" },
//  { 0x141FF, "" },
//  { 0x14200, "" },
//  { 0x14201, "" },
//  { 0x14202, "" },
//  { 0x14203, "" },
//  { 0x14204, "" },
//  { 0x14205, "" },
//  { 0x14206, "" },
//  { 0x14207, "" },
//  { 0x14208, "" },
//  { 0x14209, "" },
//  { 0x1420A, "" },
//  { 0x1420B, "" },
//  { 0x1420C, "" },
//  { 0x1420D, "" },
//  { 0x1420E, "" },
//  { 0x1420F, "" },
//  { 0x14210, "" },
//  { 0x14211, "" },
//  { 0x14212, "" },
//  { 0x14213, "" },
//  { 0x14214, "" },
//  { 0x14215, "" },
//  { 0x14216, "" },
//  { 0x14217, "" },
//  { 0x14218, "" },
//  { 0x14219, "" },
//  { 0x1421A, "" },
//  { 0x1421B, "" },
//  { 0x1421C, "" },
//  { 0x1421D, "" },
//  { 0x1421E, "" },
//  { 0x1421F, "" },
//  { 0x14220, "" },
//  { 0x14221, "" },
//  { 0x14222, "" },
//  { 0x14223, "" },
//  { 0x14224, "" },
//  { 0x14225, "" },
//  { 0x14226, "" },
//  { 0x14227, "" },
//  { 0x14228, "" },
//  { 0x14229, "" },
//  { 0x1422A, "" },
//  { 0x1422B, "" },
//  { 0x1422C, "" },
//  { 0x1422D, "" },
//  { 0x1422E, "" },
//  { 0x1422F, "" },
//  { 0x14230, "" },
//  { 0x14231, "" },
//  { 0x14232, "" },
//  { 0x14233, "" },
//  { 0x14234, "" },
//  { 0x14235, "" },
//  { 0x14236, "" },
//  { 0x14237, "" },
//  { 0x14238, "" },
//  { 0x14239, "" },
//  { 0x1423A, "" },
//  { 0x1423B, "" },
//  { 0x1423C, "" },
//  { 0x1423D, "" },
//  { 0x1423E, "" },
//  { 0x1423F, "" },
//  { 0x14240, "" },
//  { 0x14241, "" },
//  { 0x14242, "" },
//  { 0x14243, "" },
//  { 0x14244, "" },
//  { 0x14245, "" },
//  { 0x14246, "" },
//  { 0x14247, "" },
//  { 0x14248, "" },
//  { 0x14249, "" },
//  { 0x1424A, "" },
//  { 0x1424B, "" },
//  { 0x1424C, "" },
//  { 0x1424D, "" },
//  { 0x1424E, "" },
//  { 0x1424F, "" },
//  { 0x14250, "" },
//  { 0x14251, "" },
//  { 0x14252, "" },
//  { 0x14253, "" },
//  { 0x14254, "" },
//  { 0x14255, "" },
//  { 0x14256, "" },
//  { 0x14257, "" },
//  { 0x14258, "" },
//  { 0x14259, "" },
//  { 0x1425A, "" },
//  { 0x1425B, "" },
//  { 0x1425C, "" },
//  { 0x1425D, "" },
//  { 0x1425E, "" },
//  { 0x1425F, "" },
//  { 0x14260, "" },
//  { 0x14261, "" },
//  { 0x14262, "" },
//  { 0x14263, "" },
//  { 0x14264, "" },
//  { 0x14265, "" },
//  { 0x14266, "" },
//  { 0x14267, "" },
//  { 0x14268, "" },
//  { 0x14269, "" },
//  { 0x1426A, "" },
//  { 0x1426B, "" },
//  { 0x1426C, "" },
//  { 0x1426D, "" },
//  { 0x1426E, "" },
//  { 0x1426F, "" },
//  { 0x14270, "" },
//  { 0x14271, "" },
//  { 0x14272, "" },
//  { 0x14273, "" },
//  { 0x14274, "" },
//  { 0x14275, "" },
//  { 0x14276, "" },
//  { 0x14277, "" },
//  { 0x14278, "" },
//  { 0x14279, "" },
//  { 0x1427A, "" },
//  { 0x1427B, "" },
//  { 0x1427C, "" },
//  { 0x1427D, "" },
//  { 0x1427E, "" },
//  { 0x1427F, "" },
//  { 0x14280, "" },
//  { 0x14281, "" },
//  { 0x14282, "" },
//  { 0x14283, "" },
//  { 0x14284, "" },
//  { 0x14285, "" },
//  { 0x14286, "" },
//  { 0x14287, "" },
//  { 0x14288, "" },
//  { 0x14289, "" },
//  { 0x1428A, "" },
//  { 0x1428B, "" },
//  { 0x1428C, "" },
//  { 0x1428D, "" },
//  { 0x1428E, "" },
//  { 0x1428F, "" },
//  { 0x14290, "" },
//  { 0x14291, "" },
//  { 0x14292, "" },
//  { 0x14293, "" },
//  { 0x14294, "" },
//  { 0x14295, "" },
//  { 0x14296, "" },
//  { 0x14297, "" },
//  { 0x14298, "" },
//  { 0x14299, "" },
//  { 0x1429A, "" },
//  { 0x1429B, "" },
//  { 0x1429C, "" },
//  { 0x1429D, "" },
//  { 0x1429E, "" },
//  { 0x1429F, "" },
//  { 0x142A0, "" },
//  { 0x142A1, "" },
//  { 0x142A2, "" },
//  { 0x142A3, "" },
//  { 0x142A4, "" },
//  { 0x142A5, "" },
//  { 0x142A6, "" },
//  { 0x142A7, "" },
//  { 0x142A8, "" },
//  { 0x142A9, "" },
//  { 0x142AA, "" },
//  { 0x142AB, "" },
//  { 0x142AC, "" },
//  { 0x142AD, "" },
//  { 0x142AE, "" },
//  { 0x142AF, "" },
//  { 0x142B0, "" },
//  { 0x142B1, "" },
//  { 0x142B2, "" },
//  { 0x142B3, "" },
//  { 0x142B4, "" },
//  { 0x142B5, "" },
//  { 0x142B6, "" },
//  { 0x142B7, "" },
//  { 0x142B8, "" },
//  { 0x142B9, "" },
//  { 0x142BA, "" },
//  { 0x142BB, "" },
//  { 0x142BC, "" },
//  { 0x142BD, "" },
//  { 0x142BE, "" },
//  { 0x142BF, "" },
//  { 0x142C0, "" },
//  { 0x142C1, "" },
//  { 0x142C2, "" },
//  { 0x142C3, "" },
//  { 0x142C4, "" },
//  { 0x142C5, "" },
//  { 0x142C6, "" },
//  { 0x142C7, "" },
//  { 0x142C8, "" },
//  { 0x142C9, "" },
//  { 0x142CA, "" },
//  { 0x142CB, "" },
//  { 0x142CC, "" },
//  { 0x142CD, "" },
//  { 0x142CE, "" },
//  { 0x142CF, "" },
//  { 0x142D0, "" },
//  { 0x142D1, "" },
//  { 0x142D2, "" },
//  { 0x142D3, "" },
//  { 0x142D4, "" },
//  { 0x142D5, "" },
//  { 0x142D6, "" },
//  { 0x142D7, "" },
//  { 0x142D8, "" },
//  { 0x142D9, "" },
//  { 0x142DA, "" },
//  { 0x142DB, "" },
//  { 0x142DC, "" },
//  { 0x142DD, "" },
//  { 0x142DE, "" },
//  { 0x142DF, "" },
//  { 0x142E0, "" },
//  { 0x142E1, "" },
//  { 0x142E2, "" },
//  { 0x142E3, "" },
//  { 0x142E4, "" },
//  { 0x142E5, "" },
//  { 0x142E6, "" },
//  { 0x142E7, "" },
//  { 0x142E8, "" },
//  { 0x142E9, "" },
//  { 0x142EA, "" },
//  { 0x142EB, "" },
//  { 0x142EC, "" },
//  { 0x142ED, "" },
//  { 0x142EE, "" },
//  { 0x142EF, "" },
//  { 0x142F0, "" },
//  { 0x142F1, "" },
//  { 0x142F2, "" },
//  { 0x142F3, "" },
//  { 0x142F4, "" },
//  { 0x142F5, "" },
//  { 0x142F6, "" },
//  { 0x142F7, "" },
//  { 0x142F8, "" },
//  { 0x142F9, "" },
//  { 0x142FA, "" },
//  { 0x142FB, "" },
//  { 0x142FC, "" },
//  { 0x142FD, "" },
//  { 0x142FE, "" },
//  { 0x142FF, "" },
//  { 0x14300, "" },
//  { 0x14301, "" },
//  { 0x14302, "" },
//  { 0x14303, "" },
//  { 0x14304, "" },
//  { 0x14305, "" },
//  { 0x14306, "" },
//  { 0x14307, "" },
//  { 0x14308, "" },
//  { 0x14309, "" },
//  { 0x1430A, "" },
//  { 0x1430B, "" },
//  { 0x1430C, "" },
//  { 0x1430D, "" },
//  { 0x1430E, "" },
//  { 0x1430F, "" },
//  { 0x14310, "" },
//  { 0x14311, "" },
//  { 0x14312, "" },
//  { 0x14313, "" },
//  { 0x14314, "" },
//  { 0x14315, "" },
//  { 0x14316, "" },
//  { 0x14317, "" },
//  { 0x14318, "" },
//  { 0x14319, "" },
//  { 0x1431A, "" },
//  { 0x1431B, "" },
//  { 0x1431C, "" },
//  { 0x1431D, "" },
//  { 0x1431E, "" },
//  { 0x1431F, "" },
//  { 0x14320, "" },
//  { 0x14321, "" },
//  { 0x14322, "" },
//  { 0x14323, "" },
//  { 0x14324, "" },
//  { 0x14325, "" },
//  { 0x14326, "" },
//  { 0x14327, "" },
//  { 0x14328, "" },
//  { 0x14329, "" },
//  { 0x1432A, "" },
//  { 0x1432B, "" },
//  { 0x1432C, "" },
//  { 0x1432D, "" },
//  { 0x1432E, "" },
//  { 0x1432F, "" },
//  { 0x14330, "" },
//  { 0x14331, "" },
//  { 0x14332, "" },
//  { 0x14333, "" },
//  { 0x14334, "" },
//  { 0x14335, "" },
//  { 0x14336, "" },
//  { 0x14337, "" },
//  { 0x14338, "" },
//  { 0x14339, "" },
//  { 0x1433A, "" },
//  { 0x1433B, "" },
//  { 0x1433C, "" },
//  { 0x1433D, "" },
//  { 0x1433E, "" },
//  { 0x1433F, "" },
//  { 0x14340, "" },
//  { 0x14341, "" },
//  { 0x14342, "" },
//  { 0x14343, "" },
//  { 0x14344, "" },
//  { 0x14345, "" },
//  { 0x14346, "" },
//  { 0x14347, "" },
//  { 0x14348, "" },
//  { 0x14349, "" },
//  { 0x1434A, "" },
//  { 0x1434B, "" },
//  { 0x1434C, "" },
//  { 0x1434D, "" },
//  { 0x1434E, "" },
//  { 0x1434F, "" },
//  { 0x14350, "" },
//  { 0x14351, "" },
//  { 0x14352, "" },
//  { 0x14353, "" },
//  { 0x14354, "" },
//  { 0x14355, "" },
//  { 0x14356, "" },
//  { 0x14357, "" },
//  { 0x14358, "" },
//  { 0x14359, "" },
//  { 0x1435A, "" },
//  { 0x1435B, "" },
//  { 0x1435C, "" },
//  { 0x1435D, "" },
//  { 0x1435E, "" },
//  { 0x1435F, "" },
//  { 0x14360, "" },
//  { 0x14361, "" },
//  { 0x14362, "" },
//  { 0x14363, "" },
//  { 0x14364, "" },
//  { 0x14365, "" },
//  { 0x14366, "" },
//  { 0x14367, "" },
//  { 0x14368, "" },
//  { 0x14369, "" },
//  { 0x1436A, "" },
//  { 0x1436B, "" },
//  { 0x1436C, "" },
//  { 0x1436D, "" },
//  { 0x1436E, "" },
//  { 0x1436F, "" },
//  { 0x14370, "" },
//  { 0x14371, "" },
//  { 0x14372, "" },
//  { 0x14373, "" },
//  { 0x14374, "" },
//  { 0x14375, "" },
//  { 0x14376, "" },
//  { 0x14377, "" },
//  { 0x14378, "" },
//  { 0x14379, "" },
//  { 0x1437A, "" },
//  { 0x1437B, "" },
//  { 0x1437C, "" },
//  { 0x1437D, "" },
//  { 0x1437E, "" },
//  { 0x1437F, "" },
//  { 0x14380, "" },
//  { 0x14381, "" },
//  { 0x14382, "" },
//  { 0x14383, "" },
//  { 0x14384, "" },
//  { 0x14385, "" },
//  { 0x14386, "" },
//  { 0x14387, "" },
//  { 0x14388, "" },
//  { 0x14389, "" },
//  { 0x1438A, "" },
//  { 0x1438B, "" },
//  { 0x1438C, "" },
//  { 0x1438D, "" },
//  { 0x1438E, "" },
//  { 0x1438F, "" },
//  { 0x14390, "" },
//  { 0x14391, "" },
//  { 0x14392, "" },
//  { 0x14393, "" },
//  { 0x14394, "" },
//  { 0x14395, "" },
//  { 0x14396, "" },
//  { 0x14397, "" },
//  { 0x14398, "" },
//  { 0x14399, "" },
//  { 0x1439A, "" },
//  { 0x1439B, "" },
//  { 0x1439C, "" },
//  { 0x1439D, "" },
//  { 0x1439E, "" },
//  { 0x1439F, "" },
//  { 0x143A0, "" },
//  { 0x143A1, "" },
//  { 0x143A2, "" },
//  { 0x143A3, "" },
//  { 0x143A4, "" },
//  { 0x143A5, "" },
//  { 0x143A6, "" },
//  { 0x143A7, "" },
//  { 0x143A8, "" },
//  { 0x143A9, "" },
//  { 0x143AA, "" },
//  { 0x143AB, "" },
//  { 0x143AC, "" },
//  { 0x143AD, "" },
//  { 0x143AE, "" },
//  { 0x143AF, "" },
//  { 0x143B0, "" },
//  { 0x143B1, "" },
//  { 0x143B2, "" },
//  { 0x143B3, "" },
//  { 0x143B4, "" },
//  { 0x143B5, "" },
//  { 0x143B6, "" },
//  { 0x143B7, "" },
//  { 0x143B8, "" },
//  { 0x143B9, "" },
//  { 0x143BA, "" },
//  { 0x143BB, "" },
//  { 0x143BC, "" },
//  { 0x143BD, "" },
//  { 0x143BE, "" },
//  { 0x143BF, "" },
//  { 0x143C0, "" },
//  { 0x143C1, "" },
//  { 0x143C2, "" },
//  { 0x143C3, "" },
//  { 0x143C4, "" },
//  { 0x143C5, "" },
//  { 0x143C6, "" },
//  { 0x143C7, "" },
//  { 0x143C8, "" },
//  { 0x143C9, "" },
//  { 0x143CA, "" },
//  { 0x143CB, "" },
//  { 0x143CC, "" },
//  { 0x143CD, "" },
//  { 0x143CE, "" },
//  { 0x143CF, "" },
//  { 0x143D0, "" },
//  { 0x143D1, "" },
//  { 0x143D2, "" },
//  { 0x143D3, "" },
//  { 0x143D4, "" },
//  { 0x143D5, "" },
//  { 0x143D6, "" },
//  { 0x143D7, "" },
//  { 0x143D8, "" },
//  { 0x143D9, "" },
//  { 0x143DA, "" },
//  { 0x143DB, "" },
//  { 0x143DC, "" },
//  { 0x143DD, "" },
//  { 0x143DE, "" },
//  { 0x143DF, "" },
//  { 0x143E0, "" },
//  { 0x143E1, "" },
//  { 0x143E2, "" },
//  { 0x143E3, "" },
//  { 0x143E4, "" },
//  { 0x143E5, "" },
//  { 0x143E6, "" },
//  { 0x143E7, "" },
//  { 0x143E8, "" },
//  { 0x143E9, "" },
//  { 0x143EA, "" },
//  { 0x143EB, "" },
//  { 0x143EC, "" },
//  { 0x143ED, "" },
//  { 0x143EE, "" },
//  { 0x143EF, "" },
//  { 0x143F0, "" },
//  { 0x143F1, "" },
//  { 0x143F2, "" },
//  { 0x143F3, "" },
//  { 0x143F4, "" },
//  { 0x143F5, "" },
//  { 0x143F6, "" },
//  { 0x143F7, "" },
//  { 0x143F8, "" },
//  { 0x143F9, "" },
//  { 0x143FA, "" },
//  { 0x143FB, "" },
//  { 0x143FC, "" },
//  { 0x143FD, "" },
//  { 0x143FE, "" },
//  { 0x143FF, "" },
//  { 0x14400, "" },
//  { 0x14401, "" },
//  { 0x14402, "" },
//  { 0x14403, "" },
//  { 0x14404, "" },
//  { 0x14405, "" },
//  { 0x14406, "" },
//  { 0x14407, "" },
//  { 0x14408, "" },
//  { 0x14409, "" },
//  { 0x1440A, "" },
//  { 0x1440B, "" },
//  { 0x1440C, "" },
//  { 0x1440D, "" },
//  { 0x1440E, "" },
//  { 0x1440F, "" },
//  { 0x14410, "" },
//  { 0x14411, "" },
//  { 0x14412, "" },
//  { 0x14413, "" },
//  { 0x14414, "" },
//  { 0x14415, "" },
//  { 0x14416, "" },
//  { 0x14417, "" },
//  { 0x14418, "" },
//  { 0x14419, "" },
//  { 0x1441A, "" },
//  { 0x1441B, "" },
//  { 0x1441C, "" },
//  { 0x1441D, "" },
//  { 0x1441E, "" },
//  { 0x1441F, "" },
//  { 0x14420, "" },
//  { 0x14421, "" },
//  { 0x14422, "" },
//  { 0x14423, "" },
//  { 0x14424, "" },
//  { 0x14425, "" },
//  { 0x14426, "" },
//  { 0x14427, "" },
//  { 0x14428, "" },
//  { 0x14429, "" },
//  { 0x1442A, "" },
//  { 0x1442B, "" },
//  { 0x1442C, "" },
//  { 0x1442D, "" },
//  { 0x1442E, "" },
//  { 0x1442F, "" },
//  { 0x14430, "" },
//  { 0x14431, "" },
//  { 0x14432, "" },
//  { 0x14433, "" },
//  { 0x14434, "" },
//  { 0x14435, "" },
//  { 0x14436, "" },
//  { 0x14437, "" },
//  { 0x14438, "" },
//  { 0x14439, "" },
//  { 0x1443A, "" },
//  { 0x1443B, "" },
//  { 0x1443C, "" },
//  { 0x1443D, "" },
//  { 0x1443E, "" },
//  { 0x1443F, "" },
//  { 0x14440, "" },
//  { 0x14441, "" },
//  { 0x14442, "" },
//  { 0x14443, "" },
//  { 0x14444, "" },
//  { 0x14445, "" },
//  { 0x14446, "" },
//  { 0x14447, "" },
//  { 0x14448, "" },
//  { 0x14449, "" },
//  { 0x1444A, "" },
//  { 0x1444B, "" },
//  { 0x1444C, "" },
//  { 0x1444D, "" },
//  { 0x1444E, "" },
//  { 0x1444F, "" },
//  { 0x14450, "" },
//  { 0x14451, "" },
//  { 0x14452, "" },
//  { 0x14453, "" },
//  { 0x14454, "" },
//  { 0x14455, "" },
//  { 0x14456, "" },
//  { 0x14457, "" },
//  { 0x14458, "" },
//  { 0x14459, "" },
//  { 0x1445A, "" },
//  { 0x1445B, "" },
//  { 0x1445C, "" },
//  { 0x1445D, "" },
//  { 0x1445E, "" },
//  { 0x1445F, "" },
//  { 0x14460, "" },
//  { 0x14461, "" },
//  { 0x14462, "" },
//  { 0x14463, "" },
//  { 0x14464, "" },
//  { 0x14465, "" },
//  { 0x14466, "" },
//  { 0x14467, "" },
//  { 0x14468, "" },
//  { 0x14469, "" },
//  { 0x1446A, "" },
//  { 0x1446B, "" },
//  { 0x1446C, "" },
//  { 0x1446D, "" },
//  { 0x1446E, "" },
//  { 0x1446F, "" },
//  { 0x14470, "" },
//  { 0x14471, "" },
//  { 0x14472, "" },
//  { 0x14473, "" },
//  { 0x14474, "" },
//  { 0x14475, "" },
//  { 0x14476, "" },
//  { 0x14477, "" },
//  { 0x14478, "" },
//  { 0x14479, "" },
//  { 0x1447A, "" },
//  { 0x1447B, "" },
//  { 0x1447C, "" },
//  { 0x1447D, "" },
//  { 0x1447E, "" },
//  { 0x1447F, "" },
//  { 0x14480, "" },
//  { 0x14481, "" },
//  { 0x14482, "" },
//  { 0x14483, "" },
//  { 0x14484, "" },
//  { 0x14485, "" },
//  { 0x14486, "" },
//  { 0x14487, "" },
//  { 0x14488, "" },
//  { 0x14489, "" },
//  { 0x1448A, "" },
//  { 0x1448B, "" },
//  { 0x1448C, "" },
//  { 0x1448D, "" },
//  { 0x1448E, "" },
//  { 0x1448F, "" },
//  { 0x14490, "" },
//  { 0x14491, "" },
//  { 0x14492, "" },
//  { 0x14493, "" },
//  { 0x14494, "" },
//  { 0x14495, "" },
//  { 0x14496, "" },
//  { 0x14497, "" },
//  { 0x14498, "" },
//  { 0x14499, "" },
//  { 0x1449A, "" },
//  { 0x1449B, "" },
//  { 0x1449C, "" },
//  { 0x1449D, "" },
//  { 0x1449E, "" },
//  { 0x1449F, "" },
//  { 0x144A0, "" },
//  { 0x144A1, "" },
//  { 0x144A2, "" },
//  { 0x144A3, "" },
//  { 0x144A4, "" },
//  { 0x144A5, "" },
//  { 0x144A6, "" },
//  { 0x144A7, "" },
//  { 0x144A8, "" },
//  { 0x144A9, "" },
//  { 0x144AA, "" },
//  { 0x144AB, "" },
//  { 0x144AC, "" },
//  { 0x144AD, "" },
//  { 0x144AE, "" },
//  { 0x144AF, "" },
//  { 0x144B0, "" },
//  { 0x144B1, "" },
//  { 0x144B2, "" },
//  { 0x144B3, "" },
//  { 0x144B4, "" },
//  { 0x144B5, "" },
//  { 0x144B6, "" },
//  { 0x144B7, "" },
//  { 0x144B8, "" },
//  { 0x144B9, "" },
//  { 0x144BA, "" },
//  { 0x144BB, "" },
//  { 0x144BC, "" },
//  { 0x144BD, "" },
//  { 0x144BE, "" },
//  { 0x144BF, "" },
//  { 0x144C0, "" },
//  { 0x144C1, "" },
//  { 0x144C2, "" },
//  { 0x144C3, "" },
//  { 0x144C4, "" },
//  { 0x144C5, "" },
//  { 0x144C6, "" },
//  { 0x144C7, "" },
//  { 0x144C8, "" },
//  { 0x144C9, "" },
//  { 0x144CA, "" },
//  { 0x144CB, "" },
//  { 0x144CC, "" },
//  { 0x144CD, "" },
//  { 0x144CE, "" },
//  { 0x144CF, "" },
//  { 0x144D0, "" },
//  { 0x144D1, "" },
//  { 0x144D2, "" },
//  { 0x144D3, "" },
//  { 0x144D4, "" },
//  { 0x144D5, "" },
//  { 0x144D6, "" },
//  { 0x144D7, "" },
//  { 0x144D8, "" },
//  { 0x144D9, "" },
//  { 0x144DA, "" },
//  { 0x144DB, "" },
//  { 0x144DC, "" },
//  { 0x144DD, "" },
//  { 0x144DE, "" },
//  { 0x144DF, "" },
//  { 0x144E0, "" },
//  { 0x144E1, "" },
//  { 0x144E2, "" },
//  { 0x144E3, "" },
//  { 0x144E4, "" },
//  { 0x144E5, "" },
//  { 0x144E6, "" },
//  { 0x144E7, "" },
//  { 0x144E8, "" },
//  { 0x144E9, "" },
//  { 0x144EA, "" },
//  { 0x144EB, "" },
//  { 0x144EC, "" },
//  { 0x144ED, "" },
//  { 0x144EE, "" },
//  { 0x144EF, "" },
//  { 0x144F0, "" },
//  { 0x144F1, "" },
//  { 0x144F2, "" },
//  { 0x144F3, "" },
//  { 0x144F4, "" },
//  { 0x144F5, "" },
//  { 0x144F6, "" },
//  { 0x144F7, "" },
//  { 0x144F8, "" },
//  { 0x144F9, "" },
//  { 0x144FA, "" },
//  { 0x144FB, "" },
//  { 0x144FC, "" },
//  { 0x144FD, "" },
//  { 0x144FE, "" },
//  { 0x144FF, "" },
//  { 0x14500, "" },
//  { 0x14501, "" },
//  { 0x14502, "" },
//  { 0x14503, "" },
//  { 0x14504, "" },
//  { 0x14505, "" },
//  { 0x14506, "" },
//  { 0x14507, "" },
//  { 0x14508, "" },
//  { 0x14509, "" },
//  { 0x1450A, "" },
//  { 0x1450B, "" },
//  { 0x1450C, "" },
//  { 0x1450D, "" },
//  { 0x1450E, "" },
//  { 0x1450F, "" },
//  { 0x14510, "" },
//  { 0x14511, "" },
//  { 0x14512, "" },
//  { 0x14513, "" },
//  { 0x14514, "" },
//  { 0x14515, "" },
//  { 0x14516, "" },
//  { 0x14517, "" },
//  { 0x14518, "" },
//  { 0x14519, "" },
//  { 0x1451A, "" },
//  { 0x1451B, "" },
//  { 0x1451C, "" },
//  { 0x1451D, "" },
//  { 0x1451E, "" },
//  { 0x1451F, "" },
//  { 0x14520, "" },
//  { 0x14521, "" },
//  { 0x14522, "" },
//  { 0x14523, "" },
//  { 0x14524, "" },
//  { 0x14525, "" },
//  { 0x14526, "" },
//  { 0x14527, "" },
//  { 0x14528, "" },
//  { 0x14529, "" },
//  { 0x1452A, "" },
//  { 0x1452B, "" },
//  { 0x1452C, "" },
//  { 0x1452D, "" },
//  { 0x1452E, "" },
//  { 0x1452F, "" },
//  { 0x14530, "" },
//  { 0x14531, "" },
//  { 0x14532, "" },
//  { 0x14533, "" },
//  { 0x14534, "" },
//  { 0x14535, "" },
//  { 0x14536, "" },
//  { 0x14537, "" },
//  { 0x14538, "" },
//  { 0x14539, "" },
//  { 0x1453A, "" },
//  { 0x1453B, "" },
//  { 0x1453C, "" },
//  { 0x1453D, "" },
//  { 0x1453E, "" },
//  { 0x1453F, "" },
//  { 0x14540, "" },
//  { 0x14541, "" },
//  { 0x14542, "" },
//  { 0x14543, "" },
//  { 0x14544, "" },
//  { 0x14545, "" },
//  { 0x14546, "" },
//  { 0x14547, "" },
//  { 0x14548, "" },
//  { 0x14549, "" },
//  { 0x1454A, "" },
//  { 0x1454B, "" },
//  { 0x1454C, "" },
//  { 0x1454D, "" },
//  { 0x1454E, "" },
//  { 0x1454F, "" },
//  { 0x14550, "" },
//  { 0x14551, "" },
//  { 0x14552, "" },
//  { 0x14553, "" },
//  { 0x14554, "" },
//  { 0x14555, "" },
//  { 0x14556, "" },
//  { 0x14557, "" },
//  { 0x14558, "" },
//  { 0x14559, "" },
//  { 0x1455A, "" },
//  { 0x1455B, "" },
//  { 0x1455C, "" },
//  { 0x1455D, "" },
//  { 0x1455E, "" },
//  { 0x1455F, "" },
//  { 0x14560, "" },
//  { 0x14561, "" },
//  { 0x14562, "" },
//  { 0x14563, "" },
//  { 0x14564, "" },
//  { 0x14565, "" },
//  { 0x14566, "" },
//  { 0x14567, "" },
//  { 0x14568, "" },
//  { 0x14569, "" },
//  { 0x1456A, "" },
//  { 0x1456B, "" },
//  { 0x1456C, "" },
//  { 0x1456D, "" },
//  { 0x1456E, "" },
//  { 0x1456F, "" },
//  { 0x14570, "" },
//  { 0x14571, "" },
//  { 0x14572, "" },
//  { 0x14573, "" },
//  { 0x14574, "" },
//  { 0x14575, "" },
//  { 0x14576, "" },
//  { 0x14577, "" },
//  { 0x14578, "" },
//  { 0x14579, "" },
//  { 0x1457A, "" },
//  { 0x1457B, "" },
//  { 0x1457C, "" },
//  { 0x1457D, "" },
//  { 0x1457E, "" },
//  { 0x1457F, "" },
//  { 0x14580, "" },
//  { 0x14581, "" },
//  { 0x14582, "" },
//  { 0x14583, "" },
//  { 0x14584, "" },
//  { 0x14585, "" },
//  { 0x14586, "" },
//  { 0x14587, "" },
//  { 0x14588, "" },
//  { 0x14589, "" },
//  { 0x1458A, "" },
//  { 0x1458B, "" },
//  { 0x1458C, "" },
//  { 0x1458D, "" },
//  { 0x1458E, "" },
//  { 0x1458F, "" },
//  { 0x14590, "" },
//  { 0x14591, "" },
//  { 0x14592, "" },
//  { 0x14593, "" },
//  { 0x14594, "" },
//  { 0x14595, "" },
//  { 0x14596, "" },
//  { 0x14597, "" },
//  { 0x14598, "" },
//  { 0x14599, "" },
//  { 0x1459A, "" },
//  { 0x1459B, "" },
//  { 0x1459C, "" },
//  { 0x1459D, "" },
//  { 0x1459E, "" },
//  { 0x1459F, "" },
//  { 0x145A0, "" },
//  { 0x145A1, "" },
//  { 0x145A2, "" },
//  { 0x145A3, "" },
//  { 0x145A4, "" },
//  { 0x145A5, "" },
//  { 0x145A6, "" },
//  { 0x145A7, "" },
//  { 0x145A8, "" },
//  { 0x145A9, "" },
//  { 0x145AA, "" },
//  { 0x145AB, "" },
//  { 0x145AC, "" },
//  { 0x145AD, "" },
//  { 0x145AE, "" },
//  { 0x145AF, "" },
//  { 0x145B0, "" },
//  { 0x145B1, "" },
//  { 0x145B2, "" },
//  { 0x145B3, "" },
//  { 0x145B4, "" },
//  { 0x145B5, "" },
//  { 0x145B6, "" },
//  { 0x145B7, "" },
//  { 0x145B8, "" },
//  { 0x145B9, "" },
//  { 0x145BA, "" },
//  { 0x145BB, "" },
//  { 0x145BC, "" },
//  { 0x145BD, "" },
//  { 0x145BE, "" },
//  { 0x145BF, "" },
//  { 0x145C0, "" },
//  { 0x145C1, "" },
//  { 0x145C2, "" },
//  { 0x145C3, "" },
//  { 0x145C4, "" },
//  { 0x145C5, "" },
//  { 0x145C6, "" },
//  { 0x145C7, "" },
//  { 0x145C8, "" },
//  { 0x145C9, "" },
//  { 0x145CA, "" },
//  { 0x145CB, "" },
//  { 0x145CC, "" },
//  { 0x145CD, "" },
//  { 0x145CE, "" },
//  { 0x145CF, "" },
//  { 0x145D0, "" },
//  { 0x145D1, "" },
//  { 0x145D2, "" },
//  { 0x145D3, "" },
//  { 0x145D4, "" },
//  { 0x145D5, "" },
//  { 0x145D6, "" },
//  { 0x145D7, "" },
//  { 0x145D8, "" },
//  { 0x145D9, "" },
//  { 0x145DA, "" },
//  { 0x145DB, "" },
//  { 0x145DC, "" },
//  { 0x145DD, "" },
//  { 0x145DE, "" },
//  { 0x145DF, "" },
//  { 0x145E0, "" },
//  { 0x145E1, "" },
//  { 0x145E2, "" },
//  { 0x145E3, "" },
//  { 0x145E4, "" },
//  { 0x145E5, "" },
//  { 0x145E6, "" },
//  { 0x145E7, "" },
//  { 0x145E8, "" },
//  { 0x145E9, "" },
//  { 0x145EA, "" },
//  { 0x145EB, "" },
//  { 0x145EC, "" },
//  { 0x145ED, "" },
//  { 0x145EE, "" },
//  { 0x145EF, "" },
//  { 0x145F0, "" },
//  { 0x145F1, "" },
//  { 0x145F2, "" },
//  { 0x145F3, "" },
//  { 0x145F4, "" },
//  { 0x145F5, "" },
//  { 0x145F6, "" },
//  { 0x145F7, "" },
//  { 0x145F8, "" },
//  { 0x145F9, "" },
//  { 0x145FA, "" },
//  { 0x145FB, "" },
//  { 0x145FC, "" },
//  { 0x145FD, "" },
//  { 0x145FE, "" },
//  { 0x145FF, "" },
//  { 0x14600, "" },
//  { 0x14601, "" },
//  { 0x14602, "" },
//  { 0x14603, "" },
//  { 0x14604, "" },
//  { 0x14605, "" },
//  { 0x14606, "" },
//  { 0x14607, "" },
//  { 0x14608, "" },
//  { 0x14609, "" },
//  { 0x1460A, "" },
//  { 0x1460B, "" },
//  { 0x1460C, "" },
//  { 0x1460D, "" },
//  { 0x1460E, "" },
//  { 0x1460F, "" },
//  { 0x14610, "" },
//  { 0x14611, "" },
//  { 0x14612, "" },
//  { 0x14613, "" },
//  { 0x14614, "" },
//  { 0x14615, "" },
//  { 0x14616, "" },
//  { 0x14617, "" },
//  { 0x14618, "" },
//  { 0x14619, "" },
//  { 0x1461A, "" },
//  { 0x1461B, "" },
//  { 0x1461C, "" },
//  { 0x1461D, "" },
//  { 0x1461E, "" },
//  { 0x1461F, "" },
//  { 0x14620, "" },
//  { 0x14621, "" },
//  { 0x14622, "" },
//  { 0x14623, "" },
//  { 0x14624, "" },
//  { 0x14625, "" },
//  { 0x14626, "" },
//  { 0x14627, "" },
//  { 0x14628, "" },
//  { 0x14629, "" },
//  { 0x1462A, "" },
//  { 0x1462B, "" },
//  { 0x1462C, "" },
//  { 0x1462D, "" },
//  { 0x1462E, "" },
//  { 0x1462F, "" },
//  { 0x14630, "" },
//  { 0x14631, "" },
//  { 0x14632, "" },
//  { 0x14633, "" },
//  { 0x14634, "" },
//  { 0x14635, "" },
//  { 0x14636, "" },
//  { 0x14637, "" },
//  { 0x14638, "" },
//  { 0x14639, "" },
//  { 0x1463A, "" },
//  { 0x1463B, "" },
//  { 0x1463C, "" },
//  { 0x1463D, "" },
//  { 0x1463E, "" },
//  { 0x1463F, "" },
//  { 0x14640, "" },
//  { 0x14641, "" },
//  { 0x14642, "" },
//  { 0x14643, "" },
//  { 0x14644, "" },
//  { 0x14645, "" },
//  { 0x14646, "" },
//  { 0x14647, "" },
//  { 0x14648, "" },
//  { 0x14649, "" },
//  { 0x1464A, "" },
//  { 0x1464B, "" },
//  { 0x1464C, "" },
//  { 0x1464D, "" },
//  { 0x1464E, "" },
//  { 0x1464F, "" },
//  { 0x14650, "" },
//  { 0x14651, "" },
//  { 0x14652, "" },
//  { 0x14653, "" },
//  { 0x14654, "" },
//  { 0x14655, "" },
//  { 0x14656, "" },
//  { 0x14657, "" },
//  { 0x14658, "" },
//  { 0x14659, "" },
//  { 0x1465A, "" },
//  { 0x1465B, "" },
//  { 0x1465C, "" },
//  { 0x1465D, "" },
//  { 0x1465E, "" },
//  { 0x1465F, "" },
//  { 0x14660, "" },
//  { 0x14661, "" },
//  { 0x14662, "" },
//  { 0x14663, "" },
//  { 0x14664, "" },
//  { 0x14665, "" },
//  { 0x14666, "" },
//  { 0x14667, "" },
//  { 0x14668, "" },
//  { 0x14669, "" },
//  { 0x1466A, "" },
//  { 0x1466B, "" },
//  { 0x1466C, "" },
//  { 0x1466D, "" },
//  { 0x1466E, "" },
//  { 0x1466F, "" },
//  { 0x14670, "" },
//  { 0x14671, "" },
//  { 0x14672, "" },
//  { 0x14673, "" },
//  { 0x14674, "" },
//  { 0x14675, "" },
//  { 0x14676, "" },
//  { 0x14677, "" },
//  { 0x14678, "" },
//  { 0x14679, "" },
//  { 0x1467A, "" },
//  { 0x1467B, "" },
//  { 0x1467C, "" },
//  { 0x1467D, "" },
//  { 0x1467E, "" },
//  { 0x1467F, "" },
//  { 0x14680, "" },
//  { 0x14681, "" },
//  { 0x14682, "" },
//  { 0x14683, "" },
//  { 0x14684, "" },
//  { 0x14685, "" },
//  { 0x14686, "" },
//  { 0x14687, "" },
//  { 0x14688, "" },
//  { 0x14689, "" },
//  { 0x1468A, "" },
//  { 0x1468B, "" },
//  { 0x1468C, "" },
//  { 0x1468D, "" },
//  { 0x1468E, "" },
//  { 0x1468F, "" },
//  { 0x14690, "" },
//  { 0x14691, "" },
//  { 0x14692, "" },
//  { 0x14693, "" },
//  { 0x14694, "" },
//  { 0x14695, "" },
//  { 0x14696, "" },
//  { 0x14697, "" },
//  { 0x14698, "" },
//  { 0x14699, "" },
//  { 0x1469A, "" },
//  { 0x1469B, "" },
//  { 0x1469C, "" },
//  { 0x1469D, "" },
//  { 0x1469E, "" },
//  { 0x1469F, "" },
//  { 0x146A0, "" },
//  { 0x146A1, "" },
//  { 0x146A2, "" },
//  { 0x146A3, "" },
//  { 0x146A4, "" },
//  { 0x146A5, "" },
//  { 0x146A6, "" },
//  { 0x146A7, "" },
//  { 0x146A8, "" },
//  { 0x146A9, "" },
//  { 0x146AA, "" },
//  { 0x146AB, "" },
//  { 0x146AC, "" },
//  { 0x146AD, "" },
//  { 0x146AE, "" },
//  { 0x146AF, "" },
//  { 0x146B0, "" },
//  { 0x146B1, "" },
//  { 0x146B2, "" },
//  { 0x146B3, "" },
//  { 0x146B4, "" },
//  { 0x146B5, "" },
//  { 0x146B6, "" },
//  { 0x146B7, "" },
//  { 0x146B8, "" },
//  { 0x146B9, "" },
//  { 0x146BA, "" },
//  { 0x146BB, "" },
//  { 0x146BC, "" },
//  { 0x146BD, "" },
//  { 0x146BE, "" },
//  { 0x146BF, "" },
//  { 0x146C0, "" },
//  { 0x146C1, "" },
//  { 0x146C2, "" },
//  { 0x146C3, "" },
//  { 0x146C4, "" },
//  { 0x146C5, "" },
//  { 0x146C6, "" },
//  { 0x146C7, "" },
//  { 0x146C8, "" },
//  { 0x146C9, "" },
//  { 0x146CA, "" },
//  { 0x146CB, "" },
//  { 0x146CC, "" },
//  { 0x146CD, "" },
//  { 0x146CE, "" },
//  { 0x146CF, "" },
//  { 0x146D0, "" },
//  { 0x146D1, "" },
//  { 0x146D2, "" },
//  { 0x146D3, "" },
//  { 0x146D4, "" },
//  { 0x146D5, "" },
//  { 0x146D6, "" },
//  { 0x146D7, "" },
//  { 0x146D8, "" },
//  { 0x146D9, "" },
//  { 0x146DA, "" },
//  { 0x146DB, "" },
//  { 0x146DC, "" },
//  { 0x146DD, "" },
//  { 0x146DE, "" },
//  { 0x146DF, "" },
//  { 0x146E0, "" },
//  { 0x146E1, "" },
//  { 0x146E2, "" },
//  { 0x146E3, "" },
//  { 0x146E4, "" },
//  { 0x146E5, "" },
//  { 0x146E6, "" },
//  { 0x146E7, "" },
//  { 0x146E8, "" },
//  { 0x146E9, "" },
//  { 0x146EA, "" },
//  { 0x146EB, "" },
//  { 0x146EC, "" },
//  { 0x146ED, "" },
//  { 0x146EE, "" },
//  { 0x146EF, "" },
//  { 0x146F0, "" },
//  { 0x146F1, "" },
//  { 0x146F2, "" },
//  { 0x146F3, "" },
//  { 0x146F4, "" },
//  { 0x146F5, "" },
//  { 0x146F6, "" },
//  { 0x146F7, "" },
//  { 0x146F8, "" },
//  { 0x146F9, "" },
//  { 0x146FA, "" },
//  { 0x146FB, "" },
//  { 0x146FC, "" },
//  { 0x146FD, "" },
//  { 0x146FE, "" },
//  { 0x146FF, "" },
//  { 0x14700, "" },
//  { 0x14701, "" },
//  { 0x14702, "" },
//  { 0x14703, "" },
//  { 0x14704, "" },
//  { 0x14705, "" },
//  { 0x14706, "" },
//  { 0x14707, "" },
//  { 0x14708, "" },
//  { 0x14709, "" },
//  { 0x1470A, "" },
//  { 0x1470B, "" },
//  { 0x1470C, "" },
//  { 0x1470D, "" },
//  { 0x1470E, "" },
//  { 0x1470F, "" },
//  { 0x14710, "" },
//  { 0x14711, "" },
//  { 0x14712, "" },
//  { 0x14713, "" },
//  { 0x14714, "" },
//  { 0x14715, "" },
//  { 0x14716, "" },
//  { 0x14717, "" },
//  { 0x14718, "" },
//  { 0x14719, "" },
//  { 0x1471A, "" },
//  { 0x1471B, "" },
//  { 0x1471C, "" },
//  { 0x1471D, "" },
//  { 0x1471E, "" },
//  { 0x1471F, "" },
//  { 0x14720, "" },
//  { 0x14721, "" },
//  { 0x14722, "" },
//  { 0x14723, "" },
//  { 0x14724, "" },
//  { 0x14725, "" },
//  { 0x14726, "" },
//  { 0x14727, "" },
//  { 0x14728, "" },
//  { 0x14729, "" },
//  { 0x1472A, "" },
//  { 0x1472B, "" },
//  { 0x1472C, "" },
//  { 0x1472D, "" },
//  { 0x1472E, "" },
//  { 0x1472F, "" },
}};

} // namespace xsk::gsc::iw8
